'use strict';
/*!
 * Copyright (c) Anaconda, Inc., and Bokeh Contributors
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * 
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 * 
 * Neither the name of Anaconda nor the names of any contributors
 * may be used to endorse or promote products derived from this software
 * without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */
(function(root, factory) {
  const bokeh = factory();
  bokeh.__bokeh__ = true;
  if (typeof root.Bokeh === "undefined" || typeof root.Bokeh.__bokeh__ === "undefined") {
    root.Bokeh = bokeh;
  }
  const Bokeh = root.Bokeh;
  Bokeh[bokeh.version] = bokeh;
})(this, function() {
  let define;
  const parent_require = typeof require === "function" && require
  return (function(modules, entry, aliases, externals) {
  if (aliases === undefined) aliases = {};
  if (externals === undefined) externals = {};

  const cache = {};

  const normalize = function(name) {
    if (typeof name === "number")
      return name;

    if (name === "bokehjs")
      return entry;

    if (!externals[name]) {
      const prefix = "@bokehjs/"
      if (name.slice(0, prefix.length) === prefix)
        name = name.slice(prefix.length)
    }

    const alias = aliases[name]
    if (alias != null)
      return alias;

    const trailing = name.length > 0 && name[name.length-1] === "/";
    const index = aliases[name + (trailing ? "" : "/") + "index"];
    if (index != null)
      return index;

    return name;
  }

  const require = function(name) {
    let mod = cache[name];
    if (!mod) {
      const id = normalize(name);

      mod = cache[id];
      if (!mod) {
        if (!modules[id]) {
          if (externals[id] === false || (externals[id] == true && parent_require)) {
            try {
              mod = {exports: externals[id] ? parent_require(id) : {}};
              cache[id] = cache[name] = mod;
              return mod.exports;
            } catch (e) {}
          }

          const err = new Error("Cannot find module '" + name + "'");
          err.code = 'MODULE_NOT_FOUND';
          throw err;
        }

        mod = {exports: {}};
        cache[id] = cache[name] = mod;

        function __esModule() {
          Object.defineProperty(mod.exports, "__esModule", {value: true});
        }

        function __esExport(name, value) {
          Object.defineProperty(mod.exports, name, {
            enumerable: true, get: function () { return value; }
          });
        }

        modules[id].call(mod.exports, require, mod, mod.exports, __esModule, __esExport);
      } else {
        cache[name] = mod;
      }
    }

    return mod.exports;
  }
  require.resolve = function(name) {
    return ""
  }

  const main = require(entry);
  main.require = require;

  if (typeof Proxy !== "undefined") {
    // allow Bokeh.loader["@bokehjs/module/name"] syntax
    main.loader = new Proxy({}, {
      get: function(_obj, module) {
        return require(module);
      }
    });
  }

  main.register_plugin = function(plugin_modules, plugin_entry, plugin_aliases, plugin_externals) {
    if (plugin_aliases === undefined) plugin_aliases = {};
    if (plugin_externals === undefined) plugin_externals = {};

    for (let name in plugin_modules) {
      modules[name] = plugin_modules[name];
    }

    for (let name in plugin_aliases) {
      aliases[name] = plugin_aliases[name];
    }

    for (let name in plugin_externals) {
      externals[name] = plugin_externals[name];
    }

    const plugin = require(plugin_entry);

    for (let name in plugin) {
      main[name] = plugin[name];
    }

    return plugin;
  }

  return main;
})
([
/* main.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    const yargs_1 = __importDefault(require(1) /* yargs */);
    const path_1 = require("path");
    const sys_1 = require(20) /* ./sys */;
    const build_1 = require(35) /* ./build */;
    const compile_1 = require(220) /* ./compile */;
    const argv = (0, yargs_1.default)(process.argv.slice(2)).options({
        code: { type: "string" },
        file: { type: "string" },
        lang: { type: "string", choices: ["typescript", "javascript"], default: "typescript" },
        "base-dir": { type: "string" },
        "bokehjs-dir": { type: "string", default: "./build" }, // this is what bokeh.settings defaults to
        "bokeh-version": { type: "string" },
        "bokehjs-version": { type: "string" },
        verbose: { type: "boolean", default: false },
        rebuild: { type: "boolean", default: false },
        interactive: { type: "boolean", default: false },
    }).parseSync();
    async function read_stdin() {
        const stdin = process.stdin;
        stdin.setEncoding("utf-8");
        stdin.resume();
        let data = "";
        for await (const chunk of stdin) {
            data += chunk;
        }
        return data;
    }
    function reply(data) {
        process.stdout.write(JSON.stringify(data));
        process.stdout.write("\n");
    }
    async function compile() {
        const input = await (async () => {
            if (argv.file != null) {
                return {
                    code: argv.code != null ? argv.code : (0, sys_1.read)(argv.file),
                    lang: argv.lang,
                    file: argv.file,
                    bokehjs_dir: argv.bokehjsDir,
                };
            }
            else {
                return JSON.parse(await read_stdin());
            }
        })();
        return await (0, compile_1.compile_and_resolve_deps)(input);
    }
    async function main() {
        const cmd = argv._[0];
        if (cmd == "build") {
            try {
                const base_dir = (0, path_1.resolve)(argv.baseDir);
                const bokehjs_dir = (0, path_1.resolve)(argv.bokehjsDir);
                const verbose = argv.verbose;
                const rebuild = argv.rebuild;
                const bokeh_version = argv.bokehVersion;
                const result = await (0, build_1.build)(base_dir, bokehjs_dir, { verbose, rebuild, bokeh_version });
                process.exit(result ? 0 : 1);
            }
            catch (error) {
                const msg = error instanceof Error && error.stack != null ? error.stack : `${error}`;
                console.log(msg);
                process.exit(1);
            }
        }
        else if (cmd == "init") {
            try {
                const base_dir = (0, path_1.resolve)(argv.baseDir);
                const bokehjs_dir = (0, path_1.resolve)(argv.bokehjsDir);
                const interactive = argv.interactive;
                const bokehjs_version = argv.bokehjsVersion;
                const bokeh_version = argv.bokehVersion;
                const result = await (0, build_1.init)(base_dir, bokehjs_dir, { interactive, bokehjs_version, bokeh_version });
                process.exit(result ? 0 : 1);
            }
            catch (error) {
                const msg = error instanceof Error && error.stack != null ? error.stack : `${error}`;
                console.log(msg);
                process.exit(1);
            }
        }
        else {
            try {
                reply(await compile());
            }
            catch (error) {
                const msg = error instanceof Error && error.stack != null ? error.stack : `${error}`;
                reply({ error: msg });
            }
        }
    }
    void main();
    
},
/* yargs/index.cjs */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    // classic singleton yargs API, to use yargs
    // without running as a singleton do:
    // require('yargs/yargs')(process.argv.slice(2))
    const { Yargs, processArgv } = require(2) /* ./build/index.cjs */;
    Argv(processArgv.hideBin(process.argv));
    module.exports = Argv;
    function Argv(processArgs, cwd) {
        const argv = Yargs(processArgs, cwd, require);
        singletonify(argv);
        // TODO(bcoe): warn if argv.parse() or argv.argv is used directly.
        return argv;
    }
    function defineGetter(obj, key, getter) {
        Object.defineProperty(obj, key, {
            configurable: true,
            enumerable: true,
            get: getter,
        });
    }
    function lookupGetter(obj, key) {
        const desc = Object.getOwnPropertyDescriptor(obj, key);
        if (typeof desc !== 'undefined') {
            return desc.get;
        }
    }
    /*  Hack an instance of Argv with process.argv into Argv
        so people can do
        require('yargs')(['--beeble=1','-z','zizzle']).argv
        to parse a list of args and
        require('yargs').argv
        to get a parsed version of process.argv.
    */
    function singletonify(inst) {
        [
            ...Object.keys(inst),
            ...Object.getOwnPropertyNames(inst.constructor.prototype),
        ].forEach(key => {
            if (key === 'argv') {
                defineGetter(Argv, key, lookupGetter(inst, key));
            }
            else if (typeof inst[key] === 'function') {
                Argv[key] = inst[key].bind(inst);
            }
            else {
                defineGetter(Argv, '$0', () => inst.$0);
                defineGetter(Argv, 'parsed', () => inst.parsed);
            }
        });
    }
},
/* yargs/build/index.cjs */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var t = require("assert");
    class e extends Error {
        constructor(t) { super(t || "yargs error"), this.name = "YError", Error.captureStackTrace && Error.captureStackTrace(this, e); }
    }
    let s, i = [];
    function n(t, o, a, h) { s = h; let l = {}; if (Object.prototype.hasOwnProperty.call(t, "extends")) {
        if ("string" != typeof t.extends)
            return l;
        const r = /\.json|\..*rc$/.test(t.extends);
        let h = null;
        if (r)
            h = function (t, e) { return s.path.resolve(t, e); }(o, t.extends);
        else
            try {
                h = require.resolve(t.extends);
            }
            catch (e) {
                return t;
            }
        !function (t) { if (i.indexOf(t) > -1)
            throw new e(`Circular extended configurations: '${t}'.`); }(h), i.push(h), l = r ? JSON.parse(s.readFileSync(h, "utf8")) : require(t.extends), delete t.extends, l = n(l, s.path.dirname(h), a, s);
    } return i = [], a ? r(l, t) : Object.assign({}, l, t); }
    function r(t, e) { const s = {}; function i(t) { return t && "object" == typeof t && !Array.isArray(t); } Object.assign(s, t); for (const n of Object.keys(e))
        i(e[n]) && i(s[n]) ? s[n] = r(t[n], e[n]) : s[n] = e[n]; return s; }
    function o(t) { const e = t.replace(/\s{2,}/g, " ").split(/\s+(?![^[]*]|[^<]*>)/), s = /\.*[\][<>]/g, i = e.shift(); if (!i)
        throw new Error(`No command found in: ${t}`); const n = { cmd: i.replace(s, ""), demanded: [], optional: [] }; return e.forEach(((t, i) => { let r = !1; t = t.replace(/\s/g, ""), /\.+[\]>]/.test(t) && i === e.length - 1 && (r = !0), /^\[/.test(t) ? n.optional.push({ cmd: t.replace(s, "").split("|"), variadic: r }) : n.demanded.push({ cmd: t.replace(s, "").split("|"), variadic: r }); })), n; }
    const a = ["first", "second", "third", "fourth", "fifth", "sixth"];
    function h(t, s, i) { try {
        let n = 0;
        const [r, a, h] = "object" == typeof t ? [{ demanded: [], optional: [] }, t, s] : [o(`cmd ${t}`), s, i], f = [].slice.call(a);
        for (; f.length && void 0 === f[f.length - 1];)
            f.pop();
        const d = h || f.length;
        if (d < r.demanded.length)
            throw new e(`Not enough arguments provided. Expected ${r.demanded.length} but received ${f.length}.`);
        const u = r.demanded.length + r.optional.length;
        if (d > u)
            throw new e(`Too many arguments provided. Expected max ${u} but received ${d}.`);
        r.demanded.forEach((t => { const e = l(f.shift()); 0 === t.cmd.filter((t => t === e || "*" === t)).length && c(e, t.cmd, n), n += 1; })), r.optional.forEach((t => { if (0 === f.length)
            return; const e = l(f.shift()); 0 === t.cmd.filter((t => t === e || "*" === t)).length && c(e, t.cmd, n), n += 1; }));
    }
    catch (t) {
        console.warn(t.stack);
    } }
    function l(t) { return Array.isArray(t) ? "array" : null === t ? "null" : typeof t; }
    function c(t, s, i) { throw new e(`Invalid ${a[i] || "manyith"} argument. Expected ${s.join(" or ")} but received ${t}.`); }
    function f(t) { return !!t && !!t.then && "function" == typeof t.then; }
    function d(t, e, s, i) { s.assert.notStrictEqual(t, e, i); }
    function u(t, e) { e.assert.strictEqual(typeof t, "string"); }
    function p(t) { return Object.keys(t); }
    function g(t = {}, e = (() => !0)) { const s = {}; return p(t).forEach((i => { e(i, t[i]) && (s[i] = t[i]); })), s; }
    function m() { return process.versions.electron && !process.defaultApp ? 0 : 1; }
    function y() { return process.argv[m()]; }
    var b = Object.freeze({ __proto__: null, hideBin: function (t) { return t.slice(m() + 1); }, getProcessArgvBin: y });
    function v(t, e, s, i) { if ("a" === s && !i)
        throw new TypeError("Private accessor was defined without a getter"); if ("function" == typeof e ? t !== e || !i : !e.has(t))
        throw new TypeError("Cannot read private member from an object whose class did not declare it"); return "m" === s ? i : "a" === s ? i.call(t) : i ? i.value : e.get(t); }
    function O(t, e, s, i, n) { if ("m" === i)
        throw new TypeError("Private method is not writable"); if ("a" === i && !n)
        throw new TypeError("Private accessor was defined without a setter"); if ("function" == typeof e ? t !== e || !n : !e.has(t))
        throw new TypeError("Cannot write private member to an object whose class did not declare it"); return "a" === i ? n.call(t, s) : n ? n.value = s : e.set(t, s), s; }
    class w {
        constructor(t) { this.globalMiddleware = [], this.frozens = [], this.yargs = t; }
        addMiddleware(t, e, s = !0, i = !1) { if (h("<array|function> [boolean] [boolean] [boolean]", [t, e, s], arguments.length), Array.isArray(t)) {
            for (let i = 0; i < t.length; i++) {
                if ("function" != typeof t[i])
                    throw Error("middleware must be a function");
                const n = t[i];
                n.applyBeforeValidation = e, n.global = s;
            }
            Array.prototype.push.apply(this.globalMiddleware, t);
        }
        else if ("function" == typeof t) {
            const n = t;
            n.applyBeforeValidation = e, n.global = s, n.mutates = i, this.globalMiddleware.push(t);
        } return this.yargs; }
        addCoerceMiddleware(t, e) { const s = this.yargs.getAliases(); return this.globalMiddleware = this.globalMiddleware.filter((t => { const i = [...s[e] || [], e]; return !t.option || !i.includes(t.option); })), t.option = e, this.addMiddleware(t, !0, !0, !0); }
        getMiddleware() { return this.globalMiddleware; }
        freeze() { this.frozens.push([...this.globalMiddleware]); }
        unfreeze() { const t = this.frozens.pop(); void 0 !== t && (this.globalMiddleware = t); }
        reset() { this.globalMiddleware = this.globalMiddleware.filter((t => t.global)); }
    }
    function C(t, e, s, i) { return s.reduce(((t, s) => { if (s.applyBeforeValidation !== i)
        return t; if (s.mutates) {
        if (s.applied)
            return t;
        s.applied = !0;
    } if (f(t))
        return t.then((t => Promise.all([t, s(t, e)]))).then((([t, e]) => Object.assign(t, e))); {
        const i = s(t, e);
        return f(i) ? i.then((e => Object.assign(t, e))) : Object.assign(t, i);
    } }), t); }
    function j(t, e, s = (t => { throw t; })) { try {
        const s = "function" == typeof t ? t() : t;
        return f(s) ? s.then((t => e(t))) : e(s);
    }
    catch (t) {
        return s(t);
    } }
    const M = /(^\*)|(^\$0)/;
    class _ {
        constructor(t, e, s, i) { this.requireCache = new Set, this.handlers = {}, this.aliasMap = {}, this.frozens = [], this.shim = i, this.usage = t, this.globalMiddleware = s, this.validation = e; }
        addDirectory(t, e, s, i) { "boolean" != typeof (i = i || {}).recurse && (i.recurse = !1), Array.isArray(i.extensions) || (i.extensions = ["js"]); const n = "function" == typeof i.visit ? i.visit : t => t; i.visit = (t, e, s) => { const i = n(t, e, s); if (i) {
            if (this.requireCache.has(e))
                return i;
            this.requireCache.add(e), this.addHandler(i);
        } return i; }, this.shim.requireDirectory({ require: e, filename: s }, t, i); }
        addHandler(t, e, s, i, n, r) { let a = []; const h = function (t) { return t ? t.map((t => (t.applyBeforeValidation = !1, t))) : []; }(n); if (i = i || (() => { }), Array.isArray(t))
            if (function (t) { return t.every((t => "string" == typeof t)); }(t))
                [t, ...a] = t;
            else
                for (const e of t)
                    this.addHandler(e);
        else {
            if (function (t) { return "object" == typeof t && !Array.isArray(t); }(t)) {
                let e = Array.isArray(t.command) || "string" == typeof t.command ? t.command : this.moduleName(t);
                return t.aliases && (e = [].concat(e).concat(t.aliases)), void this.addHandler(e, this.extractDesc(t), t.builder, t.handler, t.middlewares, t.deprecated);
            }
            if (k(s))
                return void this.addHandler([t].concat(a), e, s.builder, s.handler, s.middlewares, s.deprecated);
        } if ("string" == typeof t) {
            const n = o(t);
            a = a.map((t => o(t).cmd));
            let l = !1;
            const c = [n.cmd].concat(a).filter((t => !M.test(t) || (l = !0, !1)));
            0 === c.length && l && c.push("$0"), l && (n.cmd = c[0], a = c.slice(1), t = t.replace(M, n.cmd)), a.forEach((t => { this.aliasMap[t] = n.cmd; })), !1 !== e && this.usage.command(t, e, l, a, r), this.handlers[n.cmd] = { original: t, description: e, handler: i, builder: s || {}, middlewares: h, deprecated: r, demanded: n.demanded, optional: n.optional }, l && (this.defaultCommand = this.handlers[n.cmd]);
        } }
        getCommandHandlers() { return this.handlers; }
        getCommands() { return Object.keys(this.handlers).concat(Object.keys(this.aliasMap)); }
        hasDefaultCommand() { return !!this.defaultCommand; }
        runCommand(t, e, s, i, n, r) { const o = this.handlers[t] || this.handlers[this.aliasMap[t]] || this.defaultCommand, a = e.getInternalMethods().getContext(), h = a.commands.slice(), l = !t; t && (a.commands.push(t), a.fullCommands.push(o.original)); const c = this.applyBuilderUpdateUsageAndParse(l, o, e, s.aliases, h, i, n, r); return f(c) ? c.then((t => this.applyMiddlewareAndGetResult(l, o, t.innerArgv, a, n, t.aliases, e))) : this.applyMiddlewareAndGetResult(l, o, c.innerArgv, a, n, c.aliases, e); }
        applyBuilderUpdateUsageAndParse(t, e, s, i, n, r, o, a) { const h = e.builder; let l = s; if (x(h)) {
            s.getInternalMethods().getUsageInstance().freeze();
            const c = h(s.getInternalMethods().reset(i), a);
            if (f(c))
                return c.then((i => { var a; return l = (a = i) && "function" == typeof a.getInternalMethods ? i : s, this.parseAndUpdateUsage(t, e, l, n, r, o); }));
        }
        else
            (function (t) { return "object" == typeof t; })(h) && (s.getInternalMethods().getUsageInstance().freeze(), l = s.getInternalMethods().reset(i), Object.keys(e.builder).forEach((t => { l.option(t, h[t]); }))); return this.parseAndUpdateUsage(t, e, l, n, r, o); }
        parseAndUpdateUsage(t, e, s, i, n, r) { t && s.getInternalMethods().getUsageInstance().unfreeze(!0), this.shouldUpdateUsage(s) && s.getInternalMethods().getUsageInstance().usage(this.usageFromParentCommandsCommandHandler(i, e), e.description); const o = s.getInternalMethods().runYargsParserAndExecuteCommands(null, void 0, !0, n, r); return f(o) ? o.then((t => ({ aliases: s.parsed.aliases, innerArgv: t }))) : { aliases: s.parsed.aliases, innerArgv: o }; }
        shouldUpdateUsage(t) { return !t.getInternalMethods().getUsageInstance().getUsageDisabled() && 0 === t.getInternalMethods().getUsageInstance().getUsage().length; }
        usageFromParentCommandsCommandHandler(t, e) { const s = M.test(e.original) ? e.original.replace(M, "").trim() : e.original, i = t.filter((t => !M.test(t))); return i.push(s), `$0 ${i.join(" ")}`; }
        handleValidationAndGetResult(t, e, s, i, n, r, o, a) { if (!r.getInternalMethods().getHasOutput()) {
            const e = r.getInternalMethods().runValidation(n, a, r.parsed.error, t);
            s = j(s, (t => (e(t), t)));
        } if (e.handler && !r.getInternalMethods().getHasOutput()) {
            r.getInternalMethods().setHasOutput();
            const i = !!r.getOptions().configuration["populate--"];
            r.getInternalMethods().postProcess(s, i, !1, !1), s = j(s = C(s, r, o, !1), (t => { const s = e.handler(t); return f(s) ? s.then((() => t)) : t; })), t || r.getInternalMethods().getUsageInstance().cacheHelpMessage(), f(s) && !r.getInternalMethods().hasParseCallback() && s.catch((t => { try {
                r.getInternalMethods().getUsageInstance().fail(null, t);
            }
            catch (t) { } }));
        } return t || (i.commands.pop(), i.fullCommands.pop()), s; }
        applyMiddlewareAndGetResult(t, e, s, i, n, r, o) { let a = {}; if (n)
            return s; o.getInternalMethods().getHasOutput() || (a = this.populatePositionals(e, s, i, o)); const h = this.globalMiddleware.getMiddleware().slice(0).concat(e.middlewares), l = C(s, o, h, !0); return f(l) ? l.then((s => this.handleValidationAndGetResult(t, e, s, i, r, o, h, a))) : this.handleValidationAndGetResult(t, e, l, i, r, o, h, a); }
        populatePositionals(t, e, s, i) { e._ = e._.slice(s.commands.length); const n = t.demanded.slice(0), r = t.optional.slice(0), o = {}; for (this.validation.positionalCount(n.length, e._.length); n.length;) {
            const t = n.shift();
            this.populatePositional(t, e, o);
        } for (; r.length;) {
            const t = r.shift();
            this.populatePositional(t, e, o);
        } return e._ = s.commands.concat(e._.map((t => "" + t))), this.postProcessPositionals(e, o, this.cmdToParseOptions(t.original), i), o; }
        populatePositional(t, e, s) { const i = t.cmd[0]; t.variadic ? s[i] = e._.splice(0).map(String) : e._.length && (s[i] = [String(e._.shift())]); }
        cmdToParseOptions(t) { const e = { array: [], default: {}, alias: {}, demand: {} }, s = o(t); return s.demanded.forEach((t => { const [s, ...i] = t.cmd; t.variadic && (e.array.push(s), e.default[s] = []), e.alias[s] = i, e.demand[s] = !0; })), s.optional.forEach((t => { const [s, ...i] = t.cmd; t.variadic && (e.array.push(s), e.default[s] = []), e.alias[s] = i; })), e; }
        postProcessPositionals(t, e, s, i) { const n = Object.assign({}, i.getOptions()); n.default = Object.assign(s.default, n.default); for (const t of Object.keys(s.alias))
            n.alias[t] = (n.alias[t] || []).concat(s.alias[t]); n.array = n.array.concat(s.array), n.config = {}; const r = []; if (Object.keys(e).forEach((t => { e[t].map((e => { n.configuration["unknown-options-as-args"] && (n.key[t] = !0), r.push(`--${t}`), r.push(e); })); })), !r.length)
            return; const o = Object.assign({}, n.configuration, { "populate--": !1 }), a = this.shim.Parser.detailed(r, Object.assign({}, n, { configuration: o })); if (a.error)
            i.getInternalMethods().getUsageInstance().fail(a.error.message, a.error);
        else {
            const s = Object.keys(e);
            Object.keys(e).forEach((t => { s.push(...a.aliases[t]); })), Object.keys(a.argv).forEach((n => { s.includes(n) && (e[n] || (e[n] = a.argv[n]), !this.isInConfigs(i, n) && !this.isDefaulted(i, n) && Object.prototype.hasOwnProperty.call(t, n) && Object.prototype.hasOwnProperty.call(a.argv, n) && (Array.isArray(t[n]) || Array.isArray(a.argv[n])) ? t[n] = [].concat(t[n], a.argv[n]) : t[n] = a.argv[n]); }));
        } }
        isDefaulted(t, e) { const { default: s } = t.getOptions(); return Object.prototype.hasOwnProperty.call(s, e) || Object.prototype.hasOwnProperty.call(s, this.shim.Parser.camelCase(e)); }
        isInConfigs(t, e) { const { configObjects: s } = t.getOptions(); return s.some((t => Object.prototype.hasOwnProperty.call(t, e))) || s.some((t => Object.prototype.hasOwnProperty.call(t, this.shim.Parser.camelCase(e)))); }
        runDefaultBuilderOn(t) { if (!this.defaultCommand)
            return; if (this.shouldUpdateUsage(t)) {
            const e = M.test(this.defaultCommand.original) ? this.defaultCommand.original : this.defaultCommand.original.replace(/^[^[\]<>]*/, "$0 ");
            t.getInternalMethods().getUsageInstance().usage(e, this.defaultCommand.description);
        } const e = this.defaultCommand.builder; if (x(e))
            return e(t, !0); k(e) || Object.keys(e).forEach((s => { t.option(s, e[s]); })); }
        moduleName(t) { const e = function (t) { if ("undefined" == typeof require)
            return null; for (let e, s = 0, i = Object.keys(require.cache); s < i.length; s++)
            if (e = require.cache[i[s]], e.exports === t)
                return e; return null; }(t); if (!e)
            throw new Error(`No command name given for module: ${this.shim.inspect(t)}`); return this.commandFromFilename(e.filename); }
        commandFromFilename(t) { return this.shim.path.basename(t, this.shim.path.extname(t)); }
        extractDesc({ describe: t, description: e, desc: s }) { for (const i of [t, e, s]) {
            if ("string" == typeof i || !1 === i)
                return i;
            d(i, !0, this.shim);
        } return !1; }
        freeze() { this.frozens.push({ handlers: this.handlers, aliasMap: this.aliasMap, defaultCommand: this.defaultCommand }); }
        unfreeze() { const t = this.frozens.pop(); d(t, void 0, this.shim), ({ handlers: this.handlers, aliasMap: this.aliasMap, defaultCommand: this.defaultCommand } = t); }
        reset() { return this.handlers = {}, this.aliasMap = {}, this.defaultCommand = void 0, this.requireCache = new Set, this; }
    }
    function k(t) { return "object" == typeof t && !!t.builder && "function" == typeof t.handler; }
    function x(t) { return "function" == typeof t; }
    function E(t) { "undefined" != typeof process && [process.stdout, process.stderr].forEach((e => { const s = e; s._handle && s.isTTY && "function" == typeof s._handle.setBlocking && s._handle.setBlocking(t); })); }
    function A(t) { return "boolean" == typeof t; }
    function P(t, s) { const i = s.y18n.__, n = {}, r = []; n.failFn = function (t) { r.push(t); }; let o = null, a = null, h = !0; n.showHelpOnFail = function (e = !0, s) { const [i, r] = "string" == typeof e ? [!0, e] : [e, s]; return t.getInternalMethods().isGlobalContext() && (a = r), o = r, h = i, n; }; let l = !1; n.fail = function (s, i) { const c = t.getInternalMethods().getLoggerInstance(); if (!r.length) {
        if (t.getExitProcess() && E(!0), !l) {
            l = !0, h && (t.showHelp("error"), c.error()), (s || i) && c.error(s || i);
            const e = o || a;
            e && ((s || i) && c.error(""), c.error(e));
        }
        if (i = i || new e(s), t.getExitProcess())
            return t.exit(1);
        if (t.getInternalMethods().hasParseCallback())
            return t.exit(1, i);
        throw i;
    } for (let t = r.length - 1; t >= 0; --t) {
        const e = r[t];
        if (A(e)) {
            if (i)
                throw i;
            if (s)
                throw Error(s);
        }
        else
            e(s, i, n);
    } }; let c = [], f = !1; n.usage = (t, e) => null === t ? (f = !0, c = [], n) : (f = !1, c.push([t, e || ""]), n), n.getUsage = () => c, n.getUsageDisabled = () => f, n.getPositionalGroupName = () => i("Positionals:"); let d = []; n.example = (t, e) => { d.push([t, e || ""]); }; let u = []; n.command = function (t, e, s, i, n = !1) { s && (u = u.map((t => (t[2] = !1, t)))), u.push([t, e || "", s, i, n]); }, n.getCommands = () => u; let p = {}; n.describe = function (t, e) { Array.isArray(t) ? t.forEach((t => { n.describe(t, e); })) : "object" == typeof t ? Object.keys(t).forEach((e => { n.describe(e, t[e]); })) : p[t] = e; }, n.getDescriptions = () => p; let m = []; n.epilog = t => { m.push(t); }; let y, b = !1; n.wrap = t => { b = !0, y = t; }, n.getWrap = () => s.getEnv("YARGS_DISABLE_WRAP") ? null : (b || (y = function () { const t = 80; return s.process.stdColumns ? Math.min(t, s.process.stdColumns) : t; }(), b = !0), y); const v = "__yargsString__:"; function O(t, e, i) { let n = 0; return Array.isArray(t) || (t = Object.values(t).map((t => [t]))), t.forEach((t => { n = Math.max(s.stringWidth(i ? `${i} ${I(t[0])}` : I(t[0])) + $(t[0]), n); })), e && (n = Math.min(n, parseInt((.5 * e).toString(), 10))), n; } let w; function C(e) { return t.getOptions().hiddenOptions.indexOf(e) < 0 || t.parsed.argv[t.getOptions().showHiddenOpt]; } function j(t, e) { let s = `[${i("default:")} `; if (void 0 === t && !e)
        return null; if (e)
        s += e;
    else
        switch (typeof t) {
            case "string":
                s += `"${t}"`;
                break;
            case "object":
                s += JSON.stringify(t);
                break;
            default: s += t;
        } return `${s}]`; } n.deferY18nLookup = t => v + t, n.help = function () { if (w)
        return w; !function () { const e = t.getDemandedOptions(), s = t.getOptions(); (Object.keys(s.alias) || []).forEach((i => { s.alias[i].forEach((r => { p[r] && n.describe(i, p[r]), r in e && t.demandOption(i, e[r]), s.boolean.includes(r) && t.boolean(i), s.count.includes(r) && t.count(i), s.string.includes(r) && t.string(i), s.normalize.includes(r) && t.normalize(i), s.array.includes(r) && t.array(i), s.number.includes(r) && t.number(i); })); })); }(); const e = t.customScriptName ? t.$0 : s.path.basename(t.$0), r = t.getDemandedOptions(), o = t.getDemandedCommands(), a = t.getDeprecatedOptions(), h = t.getGroups(), l = t.getOptions(); let g = []; g = g.concat(Object.keys(p)), g = g.concat(Object.keys(r)), g = g.concat(Object.keys(o)), g = g.concat(Object.keys(l.default)), g = g.filter(C), g = Object.keys(g.reduce(((t, e) => ("_" !== e && (t[e] = !0), t)), {})); const y = n.getWrap(), b = s.cliui({ width: y, wrap: !!y }); if (!f)
        if (c.length)
            c.forEach((t => { b.div({ text: `${t[0].replace(/\$0/g, e)}` }), t[1] && b.div({ text: `${t[1]}`, padding: [1, 0, 0, 0] }); })), b.div();
        else if (u.length) {
            let t = null;
            t = o._ ? `${e} <${i("command")}>\n` : `${e} [${i("command")}]\n`, b.div(`${t}`);
        } if (u.length > 1 || 1 === u.length && !u[0][2]) {
        b.div(i("Commands:"));
        const s = t.getInternalMethods().getContext(), n = s.commands.length ? `${s.commands.join(" ")} ` : "";
        !0 === t.getInternalMethods().getParserConfiguration()["sort-commands"] && (u = u.sort(((t, e) => t[0].localeCompare(e[0]))));
        const r = e ? `${e} ` : "";
        u.forEach((t => { const s = `${r}${n}${t[0].replace(/^\$0 ?/, "")}`; b.span({ text: s, padding: [0, 2, 0, 2], width: O(u, y, `${e}${n}`) + 4 }, { text: t[1] }); const o = []; t[2] && o.push(`[${i("default")}]`), t[3] && t[3].length && o.push(`[${i("aliases:")} ${t[3].join(", ")}]`), t[4] && ("string" == typeof t[4] ? o.push(`[${i("deprecated: %s", t[4])}]`) : o.push(`[${i("deprecated")}]`)), o.length ? b.div({ text: o.join(" "), padding: [0, 0, 0, 2], align: "right" }) : b.div(); })), b.div();
    } const M = (Object.keys(l.alias) || []).concat(Object.keys(t.parsed.newAliases) || []); g = g.filter((e => !t.parsed.newAliases[e] && M.every((t => -1 === (l.alias[t] || []).indexOf(e))))); const _ = i("Options:"); h[_] || (h[_] = []), function (t, e, s, i) { let n = [], r = null; Object.keys(s).forEach((t => { n = n.concat(s[t]); })), t.forEach((t => { r = [t].concat(e[t]), r.some((t => -1 !== n.indexOf(t))) || s[i].push(t); })); }(g, l.alias, h, _); const k = t => /^--/.test(I(t)), x = Object.keys(h).filter((t => h[t].length > 0)).map((t => ({ groupName: t, normalizedKeys: h[t].filter(C).map((t => { if (M.includes(t))
            return t; for (let e, s = 0; void 0 !== (e = M[s]); s++)
            if ((l.alias[e] || []).includes(t))
                return e; return t; })) }))).filter((({ normalizedKeys: t }) => t.length > 0)).map((({ groupName: t, normalizedKeys: e }) => { const s = e.reduce(((e, s) => (e[s] = [s].concat(l.alias[s] || []).map((e => t === n.getPositionalGroupName() ? e : (/^[0-9]$/.test(e) ? l.boolean.includes(s) ? "-" : "--" : e.length > 1 ? "--" : "-") + e)).sort(((t, e) => k(t) === k(e) ? 0 : k(t) ? 1 : -1)).join(", "), e)), {}); return { groupName: t, normalizedKeys: e, switches: s }; })); if (x.filter((({ groupName: t }) => t !== n.getPositionalGroupName())).some((({ normalizedKeys: t, switches: e }) => !t.every((t => k(e[t]))))) && x.filter((({ groupName: t }) => t !== n.getPositionalGroupName())).forEach((({ normalizedKeys: t, switches: e }) => { t.forEach((t => { var s, i; k(e[t]) && (e[t] = (s = e[t], i = 4, S(s) ? { text: s.text, indentation: s.indentation + i } : { text: s, indentation: i })); })); })), x.forEach((({ groupName: e, normalizedKeys: s, switches: o }) => { b.div(e), s.forEach((e => { const s = o[e]; let h = p[e] || "", c = null; h.includes(v) && (h = i(h.substring(16))), l.boolean.includes(e) && (c = `[${i("boolean")}]`), l.count.includes(e) && (c = `[${i("count")}]`), l.string.includes(e) && (c = `[${i("string")}]`), l.normalize.includes(e) && (c = `[${i("string")}]`), l.array.includes(e) && (c = `[${i("array")}]`), l.number.includes(e) && (c = `[${i("number")}]`); const f = [e in a ? (d = a[e], "string" == typeof d ? `[${i("deprecated: %s", d)}]` : `[${i("deprecated")}]`) : null, c, e in r ? `[${i("required")}]` : null, l.choices && l.choices[e] ? `[${i("choices:")} ${n.stringifiedValues(l.choices[e])}]` : null, j(l.default[e], l.defaultDescription[e])].filter(Boolean).join(" "); var d; b.span({ text: I(s), padding: [0, 2, 0, 2 + $(s)], width: O(o, y) + 4 }, h); const u = !0 === t.getInternalMethods().getUsageConfiguration()["hide-types"]; f && !u ? b.div({ text: f, padding: [0, 0, 0, 2], align: "right" }) : b.div(); })), b.div(); })), d.length && (b.div(i("Examples:")), d.forEach((t => { t[0] = t[0].replace(/\$0/g, e); })), d.forEach((t => { "" === t[1] ? b.div({ text: t[0], padding: [0, 2, 0, 2] }) : b.div({ text: t[0], padding: [0, 2, 0, 2], width: O(d, y) + 4 }, { text: t[1] }); })), b.div()), m.length > 0) {
        const t = m.map((t => t.replace(/\$0/g, e))).join("\n");
        b.div(`${t}\n`);
    } return b.toString().replace(/\s*$/, ""); }, n.cacheHelpMessage = function () { w = this.help(); }, n.clearCachedHelpMessage = function () { w = void 0; }, n.hasCachedHelpMessage = function () { return !!w; }, n.showHelp = e => { const s = t.getInternalMethods().getLoggerInstance(); e || (e = "error"); ("function" == typeof e ? e : s[e])(n.help()); }, n.functionDescription = t => ["(", t.name ? s.Parser.decamelize(t.name, "-") : i("generated-value"), ")"].join(""), n.stringifiedValues = function (t, e) { let s = ""; const i = e || ", ", n = [].concat(t); return t && n.length ? (n.forEach((t => { s.length && (s += i), s += JSON.stringify(t); })), s) : s; }; let M = null; n.version = t => { M = t; }, n.showVersion = e => { const s = t.getInternalMethods().getLoggerInstance(); e || (e = "error"); ("function" == typeof e ? e : s[e])(M); }, n.reset = function (t) { return o = null, l = !1, c = [], f = !1, m = [], d = [], u = [], p = g(p, (e => !t[e])), n; }; const _ = []; return n.freeze = function () { _.push({ failMessage: o, failureOutput: l, usages: c, usageDisabled: f, epilogs: m, examples: d, commands: u, descriptions: p }); }, n.unfreeze = function (t = !1) { const e = _.pop(); e && (t ? (p = { ...e.descriptions, ...p }, u = [...e.commands, ...u], c = [...e.usages, ...c], d = [...e.examples, ...d], m = [...e.epilogs, ...m]) : ({ failMessage: o, failureOutput: l, usages: c, usageDisabled: f, epilogs: m, examples: d, commands: u, descriptions: p } = e)); }, n; }
    function S(t) { return "object" == typeof t; }
    function $(t) { return S(t) ? t.indentation : 0; }
    function I(t) { return S(t) ? t.text : t; }
    class D {
        constructor(t, e, s, i) { var n, r, o; this.yargs = t, this.usage = e, this.command = s, this.shim = i, this.completionKey = "get-yargs-completions", this.aliases = null, this.customCompletionFunction = null, this.indexAfterLastReset = 0, this.zshShell = null !== (o = (null === (n = this.shim.getEnv("SHELL")) || void 0 === n ? void 0 : n.includes("zsh")) || (null === (r = this.shim.getEnv("ZSH_NAME")) || void 0 === r ? void 0 : r.includes("zsh"))) && void 0 !== o && o; }
        defaultCompletion(t, e, s, i) { const n = this.command.getCommandHandlers(); for (let e = 0, s = t.length; e < s; ++e)
            if (n[t[e]] && n[t[e]].builder) {
                const s = n[t[e]].builder;
                if (x(s)) {
                    this.indexAfterLastReset = e + 1;
                    const t = this.yargs.getInternalMethods().reset();
                    return s(t, !0), t.argv;
                }
            } const r = []; this.commandCompletions(r, t, s), this.optionCompletions(r, t, e, s), this.choicesFromOptionsCompletions(r, t, e, s), this.choicesFromPositionalsCompletions(r, t, e, s), i(null, r); }
        commandCompletions(t, e, s) { const i = this.yargs.getInternalMethods().getContext().commands; s.match(/^-/) || i[i.length - 1] === s || this.previousArgHasChoices(e) || this.usage.getCommands().forEach((s => { const i = o(s[0]).cmd; if (-1 === e.indexOf(i))
            if (this.zshShell) {
                const e = s[1] || "";
                t.push(i.replace(/:/g, "\\:") + ":" + e);
            }
            else
                t.push(i); })); }
        optionCompletions(t, e, s, i) { if ((i.match(/^-/) || "" === i && 0 === t.length) && !this.previousArgHasChoices(e)) {
            const s = this.yargs.getOptions(), n = this.yargs.getGroups()[this.usage.getPositionalGroupName()] || [];
            Object.keys(s.key).forEach((r => { const o = !!s.configuration["boolean-negation"] && s.boolean.includes(r); n.includes(r) || s.hiddenOptions.includes(r) || this.argsContainKey(e, r, o) || this.completeOptionKey(r, t, i, o && !!s.default[r]); }));
        } }
        choicesFromOptionsCompletions(t, e, s, i) { if (this.previousArgHasChoices(e)) {
            const s = this.getPreviousArgChoices(e);
            s && s.length > 0 && t.push(...s.map((t => t.replace(/:/g, "\\:"))));
        } }
        choicesFromPositionalsCompletions(t, e, s, i) { if ("" === i && t.length > 0 && this.previousArgHasChoices(e))
            return; const n = this.yargs.getGroups()[this.usage.getPositionalGroupName()] || [], r = Math.max(this.indexAfterLastReset, this.yargs.getInternalMethods().getContext().commands.length + 1), o = n[s._.length - r - 1]; if (!o)
            return; const a = this.yargs.getOptions().choices[o] || []; for (const e of a)
            e.startsWith(i) && t.push(e.replace(/:/g, "\\:")); }
        getPreviousArgChoices(t) { if (t.length < 1)
            return; let e = t[t.length - 1], s = ""; if (!e.startsWith("-") && t.length > 1 && (s = e, e = t[t.length - 2]), !e.startsWith("-"))
            return; const i = e.replace(/^-+/, ""), n = this.yargs.getOptions(), r = [i, ...this.yargs.getAliases()[i] || []]; let o; for (const t of r)
            if (Object.prototype.hasOwnProperty.call(n.key, t) && Array.isArray(n.choices[t])) {
                o = n.choices[t];
                break;
            } return o ? o.filter((t => !s || t.startsWith(s))) : void 0; }
        previousArgHasChoices(t) { const e = this.getPreviousArgChoices(t); return void 0 !== e && e.length > 0; }
        argsContainKey(t, e, s) { const i = e => -1 !== t.indexOf((/^[^0-9]$/.test(e) ? "-" : "--") + e); if (i(e))
            return !0; if (s && i(`no-${e}`))
            return !0; if (this.aliases)
            for (const t of this.aliases[e])
                if (i(t))
                    return !0; return !1; }
        completeOptionKey(t, e, s, i) { var n, r, o, a; let h = t; if (this.zshShell) {
            const e = this.usage.getDescriptions(), s = null === (r = null === (n = null == this ? void 0 : this.aliases) || void 0 === n ? void 0 : n[t]) || void 0 === r ? void 0 : r.find((t => { const s = e[t]; return "string" == typeof s && s.length > 0; })), i = s ? e[s] : void 0, l = null !== (a = null !== (o = e[t]) && void 0 !== o ? o : i) && void 0 !== a ? a : "";
            h = `${t.replace(/:/g, "\\:")}:${l.replace("__yargsString__:", "").replace(/(\r\n|\n|\r)/gm, " ")}`;
        } const l = !/^--/.test(s) && (t => /^[^0-9]$/.test(t))(t) ? "-" : "--"; e.push(l + h), i && e.push(l + "no-" + h); }
        customCompletion(t, e, s, i) { if (d(this.customCompletionFunction, null, this.shim), this.customCompletionFunction.length < 3) {
            const t = this.customCompletionFunction(s, e);
            return f(t) ? t.then((t => { this.shim.process.nextTick((() => { i(null, t); })); })).catch((t => { this.shim.process.nextTick((() => { i(t, void 0); })); })) : i(null, t);
        } return function (t) { return t.length > 3; }(this.customCompletionFunction) ? this.customCompletionFunction(s, e, ((n = i) => this.defaultCompletion(t, e, s, n)), (t => { i(null, t); })) : this.customCompletionFunction(s, e, (t => { i(null, t); })); }
        getCompletion(t, e) { const s = t.length ? t[t.length - 1] : "", i = this.yargs.parse(t, !0), n = this.customCompletionFunction ? i => this.customCompletion(t, i, s, e) : i => this.defaultCompletion(t, i, s, e); return f(i) ? i.then(n) : n(i); }
        generateCompletionScript(t, e) { let s = this.zshShell ? '#compdef {{app_name}}\n###-begin-{{app_name}}-completions-###\n#\n# yargs command completion script\n#\n# Installation: {{app_path}} {{completion_command}} >> ~/.zshrc\n#    or {{app_path}} {{completion_command}} >> ~/.zprofile on OSX.\n#\n_{{app_name}}_yargs_completions()\n{\n  local reply\n  local si=$IFS\n  IFS=$\'\n\' reply=($(COMP_CWORD="$((CURRENT-1))" COMP_LINE="$BUFFER" COMP_POINT="$CURSOR" {{app_path}} --get-yargs-completions "${words[@]}"))\n  IFS=$si\n  _describe \'values\' reply\n}\ncompdef _{{app_name}}_yargs_completions {{app_name}}\n###-end-{{app_name}}-completions-###\n' : '###-begin-{{app_name}}-completions-###\n#\n# yargs command completion script\n#\n# Installation: {{app_path}} {{completion_command}} >> ~/.bashrc\n#    or {{app_path}} {{completion_command}} >> ~/.bash_profile on OSX.\n#\n_{{app_name}}_yargs_completions()\n{\n    local cur_word args type_list\n\n    cur_word="${COMP_WORDS[COMP_CWORD]}"\n    args=("${COMP_WORDS[@]}")\n\n    # ask yargs to generate completions.\n    type_list=$({{app_path}} --get-yargs-completions "${args[@]}")\n\n    COMPREPLY=( $(compgen -W "${type_list}" -- ${cur_word}) )\n\n    # if no match was found, fall back to filename completion\n    if [ ${#COMPREPLY[@]} -eq 0 ]; then\n      COMPREPLY=()\n    fi\n\n    return 0\n}\ncomplete -o bashdefault -o default -F _{{app_name}}_yargs_completions {{app_name}}\n###-end-{{app_name}}-completions-###\n'; const i = this.shim.path.basename(t); return t.match(/\.js$/) && (t = `./${t}`), s = s.replace(/{{app_name}}/g, i), s = s.replace(/{{completion_command}}/g, e), s.replace(/{{app_path}}/g, t); }
        registerFunction(t) { this.customCompletionFunction = t; }
        setParsed(t) { this.aliases = t.aliases; }
    }
    function N(t, e) { if (0 === t.length)
        return e.length; if (0 === e.length)
        return t.length; const s = []; let i, n; for (i = 0; i <= e.length; i++)
        s[i] = [i]; for (n = 0; n <= t.length; n++)
        s[0][n] = n; for (i = 1; i <= e.length; i++)
        for (n = 1; n <= t.length; n++)
            e.charAt(i - 1) === t.charAt(n - 1) ? s[i][n] = s[i - 1][n - 1] : i > 1 && n > 1 && e.charAt(i - 2) === t.charAt(n - 1) && e.charAt(i - 1) === t.charAt(n - 2) ? s[i][n] = s[i - 2][n - 2] + 1 : s[i][n] = Math.min(s[i - 1][n - 1] + 1, Math.min(s[i][n - 1] + 1, s[i - 1][n] + 1)); return s[e.length][t.length]; }
    const H = ["$0", "--", "_"];
    var z, W, q, U, F, L, V, G, R, T, B, Y, K, J, Z, X, Q, tt, et, st, it, nt, rt, ot, at, ht, lt, ct, ft, dt, ut, pt, gt, mt, yt;
    const bt = Symbol("copyDoubleDash"), vt = Symbol("copyDoubleDash"), Ot = Symbol("deleteFromParserHintObject"), wt = Symbol("emitWarning"), Ct = Symbol("freeze"), jt = Symbol("getDollarZero"), Mt = Symbol("getParserConfiguration"), _t = Symbol("getUsageConfiguration"), kt = Symbol("guessLocale"), xt = Symbol("guessVersion"), Et = Symbol("parsePositionalNumbers"), At = Symbol("pkgUp"), Pt = Symbol("populateParserHintArray"), St = Symbol("populateParserHintSingleValueDictionary"), $t = Symbol("populateParserHintArrayDictionary"), It = Symbol("populateParserHintDictionary"), Dt = Symbol("sanitizeKey"), Nt = Symbol("setKey"), Ht = Symbol("unfreeze"), zt = Symbol("validateAsync"), Wt = Symbol("getCommandInstance"), qt = Symbol("getContext"), Ut = Symbol("getHasOutput"), Ft = Symbol("getLoggerInstance"), Lt = Symbol("getParseContext"), Vt = Symbol("getUsageInstance"), Gt = Symbol("getValidationInstance"), Rt = Symbol("hasParseCallback"), Tt = Symbol("isGlobalContext"), Bt = Symbol("postProcess"), Yt = Symbol("rebase"), Kt = Symbol("reset"), Jt = Symbol("runYargsParserAndExecuteCommands"), Zt = Symbol("runValidation"), Xt = Symbol("setHasOutput"), Qt = Symbol("kTrackManuallySetKeys");
    class te {
        constructor(t = [], e, s, i) { this.customScriptName = !1, this.parsed = !1, z.set(this, void 0), W.set(this, void 0), q.set(this, { commands: [], fullCommands: [] }), U.set(this, null), F.set(this, null), L.set(this, "show-hidden"), V.set(this, null), G.set(this, !0), R.set(this, {}), T.set(this, !0), B.set(this, []), Y.set(this, void 0), K.set(this, {}), J.set(this, !1), Z.set(this, null), X.set(this, !0), Q.set(this, void 0), tt.set(this, ""), et.set(this, void 0), st.set(this, void 0), it.set(this, {}), nt.set(this, null), rt.set(this, null), ot.set(this, {}), at.set(this, {}), ht.set(this, void 0), lt.set(this, !1), ct.set(this, void 0), ft.set(this, !1), dt.set(this, !1), ut.set(this, !1), pt.set(this, void 0), gt.set(this, {}), mt.set(this, null), yt.set(this, void 0), O(this, ct, i, "f"), O(this, ht, t, "f"), O(this, W, e, "f"), O(this, st, s, "f"), O(this, Y, new w(this), "f"), this.$0 = this[jt](), this[Kt](), O(this, z, v(this, z, "f"), "f"), O(this, pt, v(this, pt, "f"), "f"), O(this, yt, v(this, yt, "f"), "f"), O(this, et, v(this, et, "f"), "f"), v(this, et, "f").showHiddenOpt = v(this, L, "f"), O(this, Q, this[vt](), "f"); }
        addHelpOpt(t, e) { return h("[string|boolean] [string]", [t, e], arguments.length), v(this, Z, "f") && (this[Ot](v(this, Z, "f")), O(this, Z, null, "f")), !1 === t && void 0 === e || (O(this, Z, "string" == typeof t ? t : "help", "f"), this.boolean(v(this, Z, "f")), this.describe(v(this, Z, "f"), e || v(this, pt, "f").deferY18nLookup("Show help"))), this; }
        help(t, e) { return this.addHelpOpt(t, e); }
        addShowHiddenOpt(t, e) { if (h("[string|boolean] [string]", [t, e], arguments.length), !1 === t && void 0 === e)
            return this; const s = "string" == typeof t ? t : v(this, L, "f"); return this.boolean(s), this.describe(s, e || v(this, pt, "f").deferY18nLookup("Show hidden options")), v(this, et, "f").showHiddenOpt = s, this; }
        showHidden(t, e) { return this.addShowHiddenOpt(t, e); }
        alias(t, e) { return h("<object|string|array> [string|array]", [t, e], arguments.length), this[$t](this.alias.bind(this), "alias", t, e), this; }
        array(t) { return h("<array|string>", [t], arguments.length), this[Pt]("array", t), this[Qt](t), this; }
        boolean(t) { return h("<array|string>", [t], arguments.length), this[Pt]("boolean", t), this[Qt](t), this; }
        check(t, e) { return h("<function> [boolean]", [t, e], arguments.length), this.middleware(((e, s) => j((() => t(e, s.getOptions())), (s => (s ? ("string" == typeof s || s instanceof Error) && v(this, pt, "f").fail(s.toString(), s) : v(this, pt, "f").fail(v(this, ct, "f").y18n.__("Argument check failed: %s", t.toString())), e)), (t => (v(this, pt, "f").fail(t.message ? t.message : t.toString(), t), e)))), !1, e), this; }
        choices(t, e) { return h("<object|string|array> [string|array]", [t, e], arguments.length), this[$t](this.choices.bind(this), "choices", t, e), this; }
        coerce(t, s) { if (h("<object|string|array> [function]", [t, s], arguments.length), Array.isArray(t)) {
            if (!s)
                throw new e("coerce callback must be provided");
            for (const e of t)
                this.coerce(e, s);
            return this;
        } if ("object" == typeof t) {
            for (const e of Object.keys(t))
                this.coerce(e, t[e]);
            return this;
        } if (!s)
            throw new e("coerce callback must be provided"); return v(this, et, "f").key[t] = !0, v(this, Y, "f").addCoerceMiddleware(((i, n) => { let r; return Object.prototype.hasOwnProperty.call(i, t) ? j((() => (r = n.getAliases(), s(i[t]))), (e => { i[t] = e; const s = n.getInternalMethods().getParserConfiguration()["strip-aliased"]; if (r[t] && !0 !== s)
            for (const s of r[t])
                i[s] = e; return i; }), (t => { throw new e(t.message); })) : i; }), t), this; }
        conflicts(t, e) { return h("<string|object> [string|array]", [t, e], arguments.length), v(this, yt, "f").conflicts(t, e), this; }
        config(t = "config", e, s) { return h("[object|string] [string|function] [function]", [t, e, s], arguments.length), "object" != typeof t || Array.isArray(t) ? ("function" == typeof e && (s = e, e = void 0), this.describe(t, e || v(this, pt, "f").deferY18nLookup("Path to JSON config file")), (Array.isArray(t) ? t : [t]).forEach((t => { v(this, et, "f").config[t] = s || !0; })), this) : (t = n(t, v(this, W, "f"), this[Mt]()["deep-merge-config"] || !1, v(this, ct, "f")), v(this, et, "f").configObjects = (v(this, et, "f").configObjects || []).concat(t), this); }
        completion(t, e, s) { return h("[string] [string|boolean|function] [function]", [t, e, s], arguments.length), "function" == typeof e && (s = e, e = void 0), O(this, F, t || v(this, F, "f") || "completion", "f"), e || !1 === e || (e = "generate completion script"), this.command(v(this, F, "f"), e), s && v(this, U, "f").registerFunction(s), this; }
        command(t, e, s, i, n, r) { return h("<string|array|object> [string|boolean] [function|object] [function] [array] [boolean|string]", [t, e, s, i, n, r], arguments.length), v(this, z, "f").addHandler(t, e, s, i, n, r), this; }
        commands(t, e, s, i, n, r) { return this.command(t, e, s, i, n, r); }
        commandDir(t, e) { h("<string> [object]", [t, e], arguments.length); const s = v(this, st, "f") || v(this, ct, "f").require; return v(this, z, "f").addDirectory(t, s, v(this, ct, "f").getCallerFile(), e), this; }
        count(t) { return h("<array|string>", [t], arguments.length), this[Pt]("count", t), this[Qt](t), this; }
        default(t, e, s) { return h("<object|string|array> [*] [string]", [t, e, s], arguments.length), s && (u(t, v(this, ct, "f")), v(this, et, "f").defaultDescription[t] = s), "function" == typeof e && (u(t, v(this, ct, "f")), v(this, et, "f").defaultDescription[t] || (v(this, et, "f").defaultDescription[t] = v(this, pt, "f").functionDescription(e)), e = e.call()), this[St](this.default.bind(this), "default", t, e), this; }
        defaults(t, e, s) { return this.default(t, e, s); }
        demandCommand(t = 1, e, s, i) { return h("[number] [number|string] [string|null|undefined] [string|null|undefined]", [t, e, s, i], arguments.length), "number" != typeof e && (s = e, e = 1 / 0), this.global("_", !1), v(this, et, "f").demandedCommands._ = { min: t, max: e, minMsg: s, maxMsg: i }, this; }
        demand(t, e, s) { return Array.isArray(e) ? (e.forEach((t => { d(s, !0, v(this, ct, "f")), this.demandOption(t, s); })), e = 1 / 0) : "number" != typeof e && (s = e, e = 1 / 0), "number" == typeof t ? (d(s, !0, v(this, ct, "f")), this.demandCommand(t, e, s, s)) : Array.isArray(t) ? t.forEach((t => { d(s, !0, v(this, ct, "f")), this.demandOption(t, s); })) : "string" == typeof s ? this.demandOption(t, s) : !0 !== s && void 0 !== s || this.demandOption(t), this; }
        demandOption(t, e) { return h("<object|string|array> [string]", [t, e], arguments.length), this[St](this.demandOption.bind(this), "demandedOptions", t, e), this; }
        deprecateOption(t, e) { return h("<string> [string|boolean]", [t, e], arguments.length), v(this, et, "f").deprecatedOptions[t] = e, this; }
        describe(t, e) { return h("<object|string|array> [string]", [t, e], arguments.length), this[Nt](t, !0), v(this, pt, "f").describe(t, e), this; }
        detectLocale(t) { return h("<boolean>", [t], arguments.length), O(this, G, t, "f"), this; }
        env(t) { return h("[string|boolean]", [t], arguments.length), !1 === t ? delete v(this, et, "f").envPrefix : v(this, et, "f").envPrefix = t || "", this; }
        epilogue(t) { return h("<string>", [t], arguments.length), v(this, pt, "f").epilog(t), this; }
        epilog(t) { return this.epilogue(t); }
        example(t, e) { return h("<string|array> [string]", [t, e], arguments.length), Array.isArray(t) ? t.forEach((t => this.example(...t))) : v(this, pt, "f").example(t, e), this; }
        exit(t, e) { O(this, J, !0, "f"), O(this, V, e, "f"), v(this, T, "f") && v(this, ct, "f").process.exit(t); }
        exitProcess(t = !0) { return h("[boolean]", [t], arguments.length), O(this, T, t, "f"), this; }
        fail(t) { if (h("<function|boolean>", [t], arguments.length), "boolean" == typeof t && !1 !== t)
            throw new e("Invalid first argument. Expected function or boolean 'false'"); return v(this, pt, "f").failFn(t), this; }
        getAliases() { return this.parsed ? this.parsed.aliases : {}; }
        async getCompletion(t, e) { return h("<array> [function]", [t, e], arguments.length), e ? v(this, U, "f").getCompletion(t, e) : new Promise(((e, s) => { v(this, U, "f").getCompletion(t, ((t, i) => { t ? s(t) : e(i); })); })); }
        getDemandedOptions() { return h([], 0), v(this, et, "f").demandedOptions; }
        getDemandedCommands() { return h([], 0), v(this, et, "f").demandedCommands; }
        getDeprecatedOptions() { return h([], 0), v(this, et, "f").deprecatedOptions; }
        getDetectLocale() { return v(this, G, "f"); }
        getExitProcess() { return v(this, T, "f"); }
        getGroups() { return Object.assign({}, v(this, K, "f"), v(this, at, "f")); }
        getHelp() { if (O(this, J, !0, "f"), !v(this, pt, "f").hasCachedHelpMessage()) {
            if (!this.parsed) {
                const t = this[Jt](v(this, ht, "f"), void 0, void 0, 0, !0);
                if (f(t))
                    return t.then((() => v(this, pt, "f").help()));
            }
            const t = v(this, z, "f").runDefaultBuilderOn(this);
            if (f(t))
                return t.then((() => v(this, pt, "f").help()));
        } return Promise.resolve(v(this, pt, "f").help()); }
        getOptions() { return v(this, et, "f"); }
        getStrict() { return v(this, ft, "f"); }
        getStrictCommands() { return v(this, dt, "f"); }
        getStrictOptions() { return v(this, ut, "f"); }
        global(t, e) { return h("<string|array> [boolean]", [t, e], arguments.length), t = [].concat(t), !1 !== e ? v(this, et, "f").local = v(this, et, "f").local.filter((e => -1 === t.indexOf(e))) : t.forEach((t => { v(this, et, "f").local.includes(t) || v(this, et, "f").local.push(t); })), this; }
        group(t, e) { h("<string|array> <string>", [t, e], arguments.length); const s = v(this, at, "f")[e] || v(this, K, "f")[e]; v(this, at, "f")[e] && delete v(this, at, "f")[e]; const i = {}; return v(this, K, "f")[e] = (s || []).concat(t).filter((t => !i[t] && (i[t] = !0))), this; }
        hide(t) { return h("<string>", [t], arguments.length), v(this, et, "f").hiddenOptions.push(t), this; }
        implies(t, e) { return h("<string|object> [number|string|array]", [t, e], arguments.length), v(this, yt, "f").implies(t, e), this; }
        locale(t) { return h("[string]", [t], arguments.length), void 0 === t ? (this[kt](), v(this, ct, "f").y18n.getLocale()) : (O(this, G, !1, "f"), v(this, ct, "f").y18n.setLocale(t), this); }
        middleware(t, e, s) { return v(this, Y, "f").addMiddleware(t, !!e, s); }
        nargs(t, e) { return h("<string|object|array> [number]", [t, e], arguments.length), this[St](this.nargs.bind(this), "narg", t, e), this; }
        normalize(t) { return h("<array|string>", [t], arguments.length), this[Pt]("normalize", t), this; }
        number(t) { return h("<array|string>", [t], arguments.length), this[Pt]("number", t), this[Qt](t), this; }
        option(t, e) { if (h("<string|object> [object]", [t, e], arguments.length), "object" == typeof t)
            Object.keys(t).forEach((e => { this.options(e, t[e]); }));
        else {
            "object" != typeof e && (e = {}), this[Qt](t), !v(this, mt, "f") || "version" !== t && "version" !== (null == e ? void 0 : e.alias) || this[wt](['"version" is a reserved word.', "Please do one of the following:", '- Disable version with `yargs.version(false)` if using "version" as an option', "- Use the built-in `yargs.version` method instead (if applicable)", "- Use a different option key", "https://yargs.js.org/docs/#api-reference-version"].join("\n"), void 0, "versionWarning"), v(this, et, "f").key[t] = !0, e.alias && this.alias(t, e.alias);
            const s = e.deprecate || e.deprecated;
            s && this.deprecateOption(t, s);
            const i = e.demand || e.required || e.require;
            i && this.demand(t, i), e.demandOption && this.demandOption(t, "string" == typeof e.demandOption ? e.demandOption : void 0), e.conflicts && this.conflicts(t, e.conflicts), "default" in e && this.default(t, e.default), void 0 !== e.implies && this.implies(t, e.implies), void 0 !== e.nargs && this.nargs(t, e.nargs), e.config && this.config(t, e.configParser), e.normalize && this.normalize(t), e.choices && this.choices(t, e.choices), e.coerce && this.coerce(t, e.coerce), e.group && this.group(t, e.group), (e.boolean || "boolean" === e.type) && (this.boolean(t), e.alias && this.boolean(e.alias)), (e.array || "array" === e.type) && (this.array(t), e.alias && this.array(e.alias)), (e.number || "number" === e.type) && (this.number(t), e.alias && this.number(e.alias)), (e.string || "string" === e.type) && (this.string(t), e.alias && this.string(e.alias)), (e.count || "count" === e.type) && this.count(t), "boolean" == typeof e.global && this.global(t, e.global), e.defaultDescription && (v(this, et, "f").defaultDescription[t] = e.defaultDescription), e.skipValidation && this.skipValidation(t);
            const n = e.describe || e.description || e.desc, r = v(this, pt, "f").getDescriptions();
            Object.prototype.hasOwnProperty.call(r, t) && "string" != typeof n || this.describe(t, n), e.hidden && this.hide(t), e.requiresArg && this.requiresArg(t);
        } return this; }
        options(t, e) { return this.option(t, e); }
        parse(t, e, s) { h("[string|array] [function|boolean|object] [function]", [t, e, s], arguments.length), this[Ct](), void 0 === t && (t = v(this, ht, "f")), "object" == typeof e && (O(this, rt, e, "f"), e = s), "function" == typeof e && (O(this, nt, e, "f"), e = !1), e || O(this, ht, t, "f"), v(this, nt, "f") && O(this, T, !1, "f"); const i = this[Jt](t, !!e), n = this.parsed; return v(this, U, "f").setParsed(this.parsed), f(i) ? i.then((t => (v(this, nt, "f") && v(this, nt, "f").call(this, v(this, V, "f"), t, v(this, tt, "f")), t))).catch((t => { throw v(this, nt, "f") && v(this, nt, "f")(t, this.parsed.argv, v(this, tt, "f")), t; })).finally((() => { this[Ht](), this.parsed = n; })) : (v(this, nt, "f") && v(this, nt, "f").call(this, v(this, V, "f"), i, v(this, tt, "f")), this[Ht](), this.parsed = n, i); }
        parseAsync(t, e, s) { const i = this.parse(t, e, s); return f(i) ? i : Promise.resolve(i); }
        parseSync(t, s, i) { const n = this.parse(t, s, i); if (f(n))
            throw new e(".parseSync() must not be used with asynchronous builders, handlers, or middleware"); return n; }
        parserConfiguration(t) { return h("<object>", [t], arguments.length), O(this, it, t, "f"), this; }
        pkgConf(t, e) { h("<string> [string]", [t, e], arguments.length); let s = null; const i = this[At](e || v(this, W, "f")); return i[t] && "object" == typeof i[t] && (s = n(i[t], e || v(this, W, "f"), this[Mt]()["deep-merge-config"] || !1, v(this, ct, "f")), v(this, et, "f").configObjects = (v(this, et, "f").configObjects || []).concat(s)), this; }
        positional(t, e) { h("<string> <object>", [t, e], arguments.length); const s = ["default", "defaultDescription", "implies", "normalize", "choices", "conflicts", "coerce", "type", "describe", "desc", "description", "alias"]; e = g(e, ((t, e) => !("type" === t && !["string", "number", "boolean"].includes(e)) && s.includes(t))); const i = v(this, q, "f").fullCommands[v(this, q, "f").fullCommands.length - 1], n = i ? v(this, z, "f").cmdToParseOptions(i) : { array: [], alias: {}, default: {}, demand: {} }; return p(n).forEach((s => { const i = n[s]; Array.isArray(i) ? -1 !== i.indexOf(t) && (e[s] = !0) : i[t] && !(s in e) && (e[s] = i[t]); })), this.group(t, v(this, pt, "f").getPositionalGroupName()), this.option(t, e); }
        recommendCommands(t = !0) { return h("[boolean]", [t], arguments.length), O(this, lt, t, "f"), this; }
        required(t, e, s) { return this.demand(t, e, s); }
        require(t, e, s) { return this.demand(t, e, s); }
        requiresArg(t) { return h("<array|string|object> [number]", [t], arguments.length), "string" == typeof t && v(this, et, "f").narg[t] || this[St](this.requiresArg.bind(this), "narg", t, NaN), this; }
        showCompletionScript(t, e) { return h("[string] [string]", [t, e], arguments.length), t = t || this.$0, v(this, Q, "f").log(v(this, U, "f").generateCompletionScript(t, e || v(this, F, "f") || "completion")), this; }
        showHelp(t) { if (h("[string|function]", [t], arguments.length), O(this, J, !0, "f"), !v(this, pt, "f").hasCachedHelpMessage()) {
            if (!this.parsed) {
                const e = this[Jt](v(this, ht, "f"), void 0, void 0, 0, !0);
                if (f(e))
                    return e.then((() => { v(this, pt, "f").showHelp(t); })), this;
            }
            const e = v(this, z, "f").runDefaultBuilderOn(this);
            if (f(e))
                return e.then((() => { v(this, pt, "f").showHelp(t); })), this;
        } return v(this, pt, "f").showHelp(t), this; }
        scriptName(t) { return this.customScriptName = !0, this.$0 = t, this; }
        showHelpOnFail(t, e) { return h("[boolean|string] [string]", [t, e], arguments.length), v(this, pt, "f").showHelpOnFail(t, e), this; }
        showVersion(t) { return h("[string|function]", [t], arguments.length), v(this, pt, "f").showVersion(t), this; }
        skipValidation(t) { return h("<array|string>", [t], arguments.length), this[Pt]("skipValidation", t), this; }
        strict(t) { return h("[boolean]", [t], arguments.length), O(this, ft, !1 !== t, "f"), this; }
        strictCommands(t) { return h("[boolean]", [t], arguments.length), O(this, dt, !1 !== t, "f"), this; }
        strictOptions(t) { return h("[boolean]", [t], arguments.length), O(this, ut, !1 !== t, "f"), this; }
        string(t) { return h("<array|string>", [t], arguments.length), this[Pt]("string", t), this[Qt](t), this; }
        terminalWidth() { return h([], 0), v(this, ct, "f").process.stdColumns; }
        updateLocale(t) { return this.updateStrings(t); }
        updateStrings(t) { return h("<object>", [t], arguments.length), O(this, G, !1, "f"), v(this, ct, "f").y18n.updateLocale(t), this; }
        usage(t, s, i, n) { if (h("<string|null|undefined> [string|boolean] [function|object] [function]", [t, s, i, n], arguments.length), void 0 !== s) {
            if (d(t, null, v(this, ct, "f")), (t || "").match(/^\$0( |$)/))
                return this.command(t, s, i, n);
            throw new e(".usage() description must start with $0 if being used as alias for .command()");
        } return v(this, pt, "f").usage(t), this; }
        usageConfiguration(t) { return h("<object>", [t], arguments.length), O(this, gt, t, "f"), this; }
        version(t, e, s) { const i = "version"; if (h("[boolean|string] [string] [string]", [t, e, s], arguments.length), v(this, mt, "f") && (this[Ot](v(this, mt, "f")), v(this, pt, "f").version(void 0), O(this, mt, null, "f")), 0 === arguments.length)
            s = this[xt](), t = i;
        else if (1 === arguments.length) {
            if (!1 === t)
                return this;
            s = t, t = i;
        }
        else
            2 === arguments.length && (s = e, e = void 0); return O(this, mt, "string" == typeof t ? t : i, "f"), e = e || v(this, pt, "f").deferY18nLookup("Show version number"), v(this, pt, "f").version(s || void 0), this.boolean(v(this, mt, "f")), this.describe(v(this, mt, "f"), e), this; }
        wrap(t) { return h("<number|null|undefined>", [t], arguments.length), v(this, pt, "f").wrap(t), this; }
        [(z = new WeakMap, W = new WeakMap, q = new WeakMap, U = new WeakMap, F = new WeakMap, L = new WeakMap, V = new WeakMap, G = new WeakMap, R = new WeakMap, T = new WeakMap, B = new WeakMap, Y = new WeakMap, K = new WeakMap, J = new WeakMap, Z = new WeakMap, X = new WeakMap, Q = new WeakMap, tt = new WeakMap, et = new WeakMap, st = new WeakMap, it = new WeakMap, nt = new WeakMap, rt = new WeakMap, ot = new WeakMap, at = new WeakMap, ht = new WeakMap, lt = new WeakMap, ct = new WeakMap, ft = new WeakMap, dt = new WeakMap, ut = new WeakMap, pt = new WeakMap, gt = new WeakMap, mt = new WeakMap, yt = new WeakMap, bt)](t) { if (!t._ || !t["--"])
            return t; t._.push.apply(t._, t["--"]); try {
            delete t["--"];
        }
        catch (t) { } return t; }
        [vt]() { return { log: (...t) => { this[Rt]() || console.log(...t), O(this, J, !0, "f"), v(this, tt, "f").length && O(this, tt, v(this, tt, "f") + "\n", "f"), O(this, tt, v(this, tt, "f") + t.join(" "), "f"); }, error: (...t) => { this[Rt]() || console.error(...t), O(this, J, !0, "f"), v(this, tt, "f").length && O(this, tt, v(this, tt, "f") + "\n", "f"), O(this, tt, v(this, tt, "f") + t.join(" "), "f"); } }; }
        [Ot](t) { p(v(this, et, "f")).forEach((e => { if ("configObjects" === e)
            return; const s = v(this, et, "f")[e]; Array.isArray(s) ? s.includes(t) && s.splice(s.indexOf(t), 1) : "object" == typeof s && delete s[t]; })), delete v(this, pt, "f").getDescriptions()[t]; }
        [wt](t, e, s) { v(this, R, "f")[s] || (v(this, ct, "f").process.emitWarning(t, e), v(this, R, "f")[s] = !0); }
        [Ct]() { v(this, B, "f").push({ options: v(this, et, "f"), configObjects: v(this, et, "f").configObjects.slice(0), exitProcess: v(this, T, "f"), groups: v(this, K, "f"), strict: v(this, ft, "f"), strictCommands: v(this, dt, "f"), strictOptions: v(this, ut, "f"), completionCommand: v(this, F, "f"), output: v(this, tt, "f"), exitError: v(this, V, "f"), hasOutput: v(this, J, "f"), parsed: this.parsed, parseFn: v(this, nt, "f"), parseContext: v(this, rt, "f") }), v(this, pt, "f").freeze(), v(this, yt, "f").freeze(), v(this, z, "f").freeze(), v(this, Y, "f").freeze(); }
        [jt]() { let t, e = ""; return t = /\b(node|iojs|electron)(\.exe)?$/.test(v(this, ct, "f").process.argv()[0]) ? v(this, ct, "f").process.argv().slice(1, 2) : v(this, ct, "f").process.argv().slice(0, 1), e = t.map((t => { const e = this[Yt](v(this, W, "f"), t); return t.match(/^(\/|([a-zA-Z]:)?\\)/) && e.length < t.length ? e : t; })).join(" ").trim(), v(this, ct, "f").getEnv("_") && v(this, ct, "f").getProcessArgvBin() === v(this, ct, "f").getEnv("_") && (e = v(this, ct, "f").getEnv("_").replace(`${v(this, ct, "f").path.dirname(v(this, ct, "f").process.execPath())}/`, "")), e; }
        [Mt]() { return v(this, it, "f"); }
        [_t]() { return v(this, gt, "f"); }
        [kt]() { if (!v(this, G, "f"))
            return; const t = v(this, ct, "f").getEnv("LC_ALL") || v(this, ct, "f").getEnv("LC_MESSAGES") || v(this, ct, "f").getEnv("LANG") || v(this, ct, "f").getEnv("LANGUAGE") || "en_US"; this.locale(t.replace(/[.:].*/, "")); }
        [xt]() { return this[At]().version || "unknown"; }
        [Et](t) { const e = t["--"] ? t["--"] : t._; for (let t, s = 0; void 0 !== (t = e[s]); s++)
            v(this, ct, "f").Parser.looksLikeNumber(t) && Number.isSafeInteger(Math.floor(parseFloat(`${t}`))) && (e[s] = Number(t)); return t; }
        [At](t) { const e = t || "*"; if (v(this, ot, "f")[e])
            return v(this, ot, "f")[e]; let s = {}; try {
            let e = t || v(this, ct, "f").mainFilename;
            !t && v(this, ct, "f").path.extname(e) && (e = v(this, ct, "f").path.dirname(e));
            const i = v(this, ct, "f").findUp(e, ((t, e) => e.includes("package.json") ? "package.json" : void 0));
            d(i, void 0, v(this, ct, "f")), s = JSON.parse(v(this, ct, "f").readFileSync(i, "utf8"));
        }
        catch (t) { } return v(this, ot, "f")[e] = s || {}, v(this, ot, "f")[e]; }
        [Pt](t, e) { (e = [].concat(e)).forEach((e => { e = this[Dt](e), v(this, et, "f")[t].push(e); })); }
        [St](t, e, s, i) { this[It](t, e, s, i, ((t, e, s) => { v(this, et, "f")[t][e] = s; })); }
        [$t](t, e, s, i) { this[It](t, e, s, i, ((t, e, s) => { v(this, et, "f")[t][e] = (v(this, et, "f")[t][e] || []).concat(s); })); }
        [It](t, e, s, i, n) { if (Array.isArray(s))
            s.forEach((e => { t(e, i); }));
        else if ((t => "object" == typeof t)(s))
            for (const e of p(s))
                t(e, s[e]);
        else
            n(e, this[Dt](s), i); }
        [Dt](t) { return "__proto__" === t ? "___proto___" : t; }
        [Nt](t, e) { return this[St](this[Nt].bind(this), "key", t, e), this; }
        [Ht]() { var t, e, s, i, n, r, o, a, h, l, c, f; const u = v(this, B, "f").pop(); let p; d(u, void 0, v(this, ct, "f")), t = this, e = this, s = this, i = this, n = this, r = this, o = this, a = this, h = this, l = this, c = this, f = this, ({ options: { set value(e) { O(t, et, e, "f"); } }.value, configObjects: p, exitProcess: { set value(t) { O(e, T, t, "f"); } }.value, groups: { set value(t) { O(s, K, t, "f"); } }.value, output: { set value(t) { O(i, tt, t, "f"); } }.value, exitError: { set value(t) { O(n, V, t, "f"); } }.value, hasOutput: { set value(t) { O(r, J, t, "f"); } }.value, parsed: this.parsed, strict: { set value(t) { O(o, ft, t, "f"); } }.value, strictCommands: { set value(t) { O(a, dt, t, "f"); } }.value, strictOptions: { set value(t) { O(h, ut, t, "f"); } }.value, completionCommand: { set value(t) { O(l, F, t, "f"); } }.value, parseFn: { set value(t) { O(c, nt, t, "f"); } }.value, parseContext: { set value(t) { O(f, rt, t, "f"); } }.value } = u), v(this, et, "f").configObjects = p, v(this, pt, "f").unfreeze(), v(this, yt, "f").unfreeze(), v(this, z, "f").unfreeze(), v(this, Y, "f").unfreeze(); }
        [zt](t, e) { return j(e, (e => (t(e), e))); }
        getInternalMethods() { return { getCommandInstance: this[Wt].bind(this), getContext: this[qt].bind(this), getHasOutput: this[Ut].bind(this), getLoggerInstance: this[Ft].bind(this), getParseContext: this[Lt].bind(this), getParserConfiguration: this[Mt].bind(this), getUsageConfiguration: this[_t].bind(this), getUsageInstance: this[Vt].bind(this), getValidationInstance: this[Gt].bind(this), hasParseCallback: this[Rt].bind(this), isGlobalContext: this[Tt].bind(this), postProcess: this[Bt].bind(this), reset: this[Kt].bind(this), runValidation: this[Zt].bind(this), runYargsParserAndExecuteCommands: this[Jt].bind(this), setHasOutput: this[Xt].bind(this) }; }
        [Wt]() { return v(this, z, "f"); }
        [qt]() { return v(this, q, "f"); }
        [Ut]() { return v(this, J, "f"); }
        [Ft]() { return v(this, Q, "f"); }
        [Lt]() { return v(this, rt, "f") || {}; }
        [Vt]() { return v(this, pt, "f"); }
        [Gt]() { return v(this, yt, "f"); }
        [Rt]() { return !!v(this, nt, "f"); }
        [Tt]() { return v(this, X, "f"); }
        [Bt](t, e, s, i) { if (s)
            return t; if (f(t))
            return t; e || (t = this[bt](t)); return (this[Mt]()["parse-positional-numbers"] || void 0 === this[Mt]()["parse-positional-numbers"]) && (t = this[Et](t)), i && (t = C(t, this, v(this, Y, "f").getMiddleware(), !1)), t; }
        [Kt](t = {}) { O(this, et, v(this, et, "f") || {}, "f"); const e = {}; e.local = v(this, et, "f").local || [], e.configObjects = v(this, et, "f").configObjects || []; const s = {}; e.local.forEach((e => { s[e] = !0, (t[e] || []).forEach((t => { s[t] = !0; })); })), Object.assign(v(this, at, "f"), Object.keys(v(this, K, "f")).reduce(((t, e) => { const i = v(this, K, "f")[e].filter((t => !(t in s))); return i.length > 0 && (t[e] = i), t; }), {})), O(this, K, {}, "f"); return ["array", "boolean", "string", "skipValidation", "count", "normalize", "number", "hiddenOptions"].forEach((t => { e[t] = (v(this, et, "f")[t] || []).filter((t => !s[t])); })), ["narg", "key", "alias", "default", "defaultDescription", "config", "choices", "demandedOptions", "demandedCommands", "deprecatedOptions"].forEach((t => { e[t] = g(v(this, et, "f")[t], (t => !s[t])); })), e.envPrefix = v(this, et, "f").envPrefix, O(this, et, e, "f"), O(this, pt, v(this, pt, "f") ? v(this, pt, "f").reset(s) : P(this, v(this, ct, "f")), "f"), O(this, yt, v(this, yt, "f") ? v(this, yt, "f").reset(s) : function (t, e, s) { const i = s.y18n.__, n = s.y18n.__n, r = { nonOptionCount: function (s) { const i = t.getDemandedCommands(), r = s._.length + (s["--"] ? s["--"].length : 0) - t.getInternalMethods().getContext().commands.length; i._ && (r < i._.min || r > i._.max) && (r < i._.min ? void 0 !== i._.minMsg ? e.fail(i._.minMsg ? i._.minMsg.replace(/\$0/g, r.toString()).replace(/\$1/, i._.min.toString()) : null) : e.fail(n("Not enough non-option arguments: got %s, need at least %s", "Not enough non-option arguments: got %s, need at least %s", r, r.toString(), i._.min.toString())) : r > i._.max && (void 0 !== i._.maxMsg ? e.fail(i._.maxMsg ? i._.maxMsg.replace(/\$0/g, r.toString()).replace(/\$1/, i._.max.toString()) : null) : e.fail(n("Too many non-option arguments: got %s, maximum of %s", "Too many non-option arguments: got %s, maximum of %s", r, r.toString(), i._.max.toString())))); }, positionalCount: function (t, s) { s < t && e.fail(n("Not enough non-option arguments: got %s, need at least %s", "Not enough non-option arguments: got %s, need at least %s", s, s + "", t + "")); }, requiredArguments: function (t, s) { let i = null; for (const e of Object.keys(s))
                Object.prototype.hasOwnProperty.call(t, e) && void 0 !== t[e] || (i = i || {}, i[e] = s[e]); if (i) {
                const t = [];
                for (const e of Object.keys(i)) {
                    const s = i[e];
                    s && t.indexOf(s) < 0 && t.push(s);
                }
                const s = t.length ? `\n${t.join("\n")}` : "";
                e.fail(n("Missing required argument: %s", "Missing required arguments: %s", Object.keys(i).length, Object.keys(i).join(", ") + s));
            } }, unknownArguments: function (s, i, o, a, h = !0) { var l; const c = t.getInternalMethods().getCommandInstance().getCommands(), f = [], d = t.getInternalMethods().getContext(); if (Object.keys(s).forEach((e => { H.includes(e) || Object.prototype.hasOwnProperty.call(o, e) || Object.prototype.hasOwnProperty.call(t.getInternalMethods().getParseContext(), e) || r.isValidAndSomeAliasIsNotNew(e, i) || f.push(e); })), h && (d.commands.length > 0 || c.length > 0 || a) && s._.slice(d.commands.length).forEach((t => { c.includes("" + t) || f.push("" + t); })), h) {
                const e = (null === (l = t.getDemandedCommands()._) || void 0 === l ? void 0 : l.max) || 0, i = d.commands.length + e;
                i < s._.length && s._.slice(i).forEach((t => { t = String(t), d.commands.includes(t) || f.includes(t) || f.push(t); }));
            } f.length && e.fail(n("Unknown argument: %s", "Unknown arguments: %s", f.length, f.map((t => t.trim() ? t : `"${t}"`)).join(", "))); }, unknownCommands: function (s) { const i = t.getInternalMethods().getCommandInstance().getCommands(), r = [], o = t.getInternalMethods().getContext(); return (o.commands.length > 0 || i.length > 0) && s._.slice(o.commands.length).forEach((t => { i.includes("" + t) || r.push("" + t); })), r.length > 0 && (e.fail(n("Unknown command: %s", "Unknown commands: %s", r.length, r.join(", "))), !0); }, isValidAndSomeAliasIsNotNew: function (e, s) { if (!Object.prototype.hasOwnProperty.call(s, e))
                return !1; const i = t.parsed.newAliases; return [e, ...s[e]].some((t => !Object.prototype.hasOwnProperty.call(i, t) || !i[e])); }, limitedChoices: function (s) { const n = t.getOptions(), r = {}; if (!Object.keys(n.choices).length)
                return; Object.keys(s).forEach((t => { -1 === H.indexOf(t) && Object.prototype.hasOwnProperty.call(n.choices, t) && [].concat(s[t]).forEach((e => { -1 === n.choices[t].indexOf(e) && void 0 !== e && (r[t] = (r[t] || []).concat(e)); })); })); const o = Object.keys(r); if (!o.length)
                return; let a = i("Invalid values:"); o.forEach((t => { a += `\n  ${i("Argument: %s, Given: %s, Choices: %s", t, e.stringifiedValues(r[t]), e.stringifiedValues(n.choices[t]))}`; })), e.fail(a); } }; let o = {}; function a(t, e) { const s = Number(e); return "number" == typeof (e = isNaN(s) ? e : s) ? e = t._.length >= e : e.match(/^--no-.+/) ? (e = e.match(/^--no-(.+)/)[1], e = !Object.prototype.hasOwnProperty.call(t, e)) : e = Object.prototype.hasOwnProperty.call(t, e), e; } r.implies = function (e, i) { h("<string|object> [array|number|string]", [e, i], arguments.length), "object" == typeof e ? Object.keys(e).forEach((t => { r.implies(t, e[t]); })) : (t.global(e), o[e] || (o[e] = []), Array.isArray(i) ? i.forEach((t => r.implies(e, t))) : (d(i, void 0, s), o[e].push(i))); }, r.getImplied = function () { return o; }, r.implications = function (t) { const s = []; if (Object.keys(o).forEach((e => { const i = e; (o[e] || []).forEach((e => { let n = i; const r = e; n = a(t, n), e = a(t, e), n && !e && s.push(` ${i} -> ${r}`); })); })), s.length) {
            let t = `${i("Implications failed:")}\n`;
            s.forEach((e => { t += e; })), e.fail(t);
        } }; let l = {}; r.conflicts = function (e, s) { h("<string|object> [array|string]", [e, s], arguments.length), "object" == typeof e ? Object.keys(e).forEach((t => { r.conflicts(t, e[t]); })) : (t.global(e), l[e] || (l[e] = []), Array.isArray(s) ? s.forEach((t => r.conflicts(e, t))) : l[e].push(s)); }, r.getConflicting = () => l, r.conflicting = function (n) { Object.keys(n).forEach((t => { l[t] && l[t].forEach((s => { s && void 0 !== n[t] && void 0 !== n[s] && e.fail(i("Arguments %s and %s are mutually exclusive", t, s)); })); })), t.getInternalMethods().getParserConfiguration()["strip-dashed"] && Object.keys(l).forEach((t => { l[t].forEach((r => { r && void 0 !== n[s.Parser.camelCase(t)] && void 0 !== n[s.Parser.camelCase(r)] && e.fail(i("Arguments %s and %s are mutually exclusive", t, r)); })); })); }, r.recommendCommands = function (t, s) { s = s.sort(((t, e) => e.length - t.length)); let n = null, r = 1 / 0; for (let e, i = 0; void 0 !== (e = s[i]); i++) {
            const s = N(t, e);
            s <= 3 && s < r && (r = s, n = e);
        } n && e.fail(i("Did you mean %s?", n)); }, r.reset = function (t) { return o = g(o, (e => !t[e])), l = g(l, (e => !t[e])), r; }; const c = []; return r.freeze = function () { c.push({ implied: o, conflicting: l }); }, r.unfreeze = function () { const t = c.pop(); d(t, void 0, s), ({ implied: o, conflicting: l } = t); }, r; }(this, v(this, pt, "f"), v(this, ct, "f")), "f"), O(this, z, v(this, z, "f") ? v(this, z, "f").reset() : function (t, e, s, i) { return new _(t, e, s, i); }(v(this, pt, "f"), v(this, yt, "f"), v(this, Y, "f"), v(this, ct, "f")), "f"), v(this, U, "f") || O(this, U, function (t, e, s, i) { return new D(t, e, s, i); }(this, v(this, pt, "f"), v(this, z, "f"), v(this, ct, "f")), "f"), v(this, Y, "f").reset(), O(this, F, null, "f"), O(this, tt, "", "f"), O(this, V, null, "f"), O(this, J, !1, "f"), this.parsed = !1, this; }
        [Yt](t, e) { return v(this, ct, "f").path.relative(t, e); }
        [Jt](t, s, i, n = 0, r = !1) { let o = !!i || r; t = t || v(this, ht, "f"), v(this, et, "f").__ = v(this, ct, "f").y18n.__, v(this, et, "f").configuration = this[Mt](); const a = !!v(this, et, "f").configuration["populate--"], h = Object.assign({}, v(this, et, "f").configuration, { "populate--": !0 }), l = v(this, ct, "f").Parser.detailed(t, Object.assign({}, v(this, et, "f"), { configuration: { "parse-positional-numbers": !1, ...h } })), c = Object.assign(l.argv, v(this, rt, "f")); let d; const u = l.aliases; let p = !1, g = !1; Object.keys(c).forEach((t => { t === v(this, Z, "f") && c[t] ? p = !0 : t === v(this, mt, "f") && c[t] && (g = !0); })), c.$0 = this.$0, this.parsed = l, 0 === n && v(this, pt, "f").clearCachedHelpMessage(); try {
            if (this[kt](), s)
                return this[Bt](c, a, !!i, !1);
            if (v(this, Z, "f")) {
                [v(this, Z, "f")].concat(u[v(this, Z, "f")] || []).filter((t => t.length > 1)).includes("" + c._[c._.length - 1]) && (c._.pop(), p = !0);
            }
            O(this, X, !1, "f");
            const h = v(this, z, "f").getCommands(), m = v(this, U, "f").completionKey in c, y = p || m || r;
            if (c._.length) {
                if (h.length) {
                    let t;
                    for (let e, s = n || 0; void 0 !== c._[s]; s++) {
                        if (e = String(c._[s]), h.includes(e) && e !== v(this, F, "f")) {
                            const t = v(this, z, "f").runCommand(e, this, l, s + 1, r, p || g || r);
                            return this[Bt](t, a, !!i, !1);
                        }
                        if (!t && e !== v(this, F, "f")) {
                            t = e;
                            break;
                        }
                    }
                    !v(this, z, "f").hasDefaultCommand() && v(this, lt, "f") && t && !y && v(this, yt, "f").recommendCommands(t, h);
                }
                v(this, F, "f") && c._.includes(v(this, F, "f")) && !m && (v(this, T, "f") && E(!0), this.showCompletionScript(), this.exit(0));
            }
            if (v(this, z, "f").hasDefaultCommand() && !y) {
                const t = v(this, z, "f").runCommand(null, this, l, 0, r, p || g || r);
                return this[Bt](t, a, !!i, !1);
            }
            if (m) {
                v(this, T, "f") && E(!0);
                const s = (t = [].concat(t)).slice(t.indexOf(`--${v(this, U, "f").completionKey}`) + 1);
                return v(this, U, "f").getCompletion(s, ((t, s) => { if (t)
                    throw new e(t.message); (s || []).forEach((t => { v(this, Q, "f").log(t); })), this.exit(0); })), this[Bt](c, !a, !!i, !1);
            }
            if (v(this, J, "f") || (p ? (v(this, T, "f") && E(!0), o = !0, this.showHelp("log"), this.exit(0)) : g && (v(this, T, "f") && E(!0), o = !0, v(this, pt, "f").showVersion("log"), this.exit(0))), !o && v(this, et, "f").skipValidation.length > 0 && (o = Object.keys(c).some((t => v(this, et, "f").skipValidation.indexOf(t) >= 0 && !0 === c[t]))), !o) {
                if (l.error)
                    throw new e(l.error.message);
                if (!m) {
                    const t = this[Zt](u, {}, l.error);
                    i || (d = C(c, this, v(this, Y, "f").getMiddleware(), !0)), d = this[zt](t, null != d ? d : c), f(d) && !i && (d = d.then((() => C(c, this, v(this, Y, "f").getMiddleware(), !1))));
                }
            }
        }
        catch (t) {
            if (!(t instanceof e))
                throw t;
            v(this, pt, "f").fail(t.message, t);
        } return this[Bt](null != d ? d : c, a, !!i, !0); }
        [Zt](t, s, i, n) { const r = { ...this.getDemandedOptions() }; return o => { if (i)
            throw new e(i.message); v(this, yt, "f").nonOptionCount(o), v(this, yt, "f").requiredArguments(o, r); let a = !1; v(this, dt, "f") && (a = v(this, yt, "f").unknownCommands(o)), v(this, ft, "f") && !a ? v(this, yt, "f").unknownArguments(o, t, s, !!n) : v(this, ut, "f") && v(this, yt, "f").unknownArguments(o, t, {}, !1, !1), v(this, yt, "f").limitedChoices(o), v(this, yt, "f").implications(o), v(this, yt, "f").conflicting(o); }; }
        [Xt]() { O(this, J, !0, "f"); }
        [Qt](t) { if ("string" == typeof t)
            v(this, et, "f").key[t] = !0;
        else
            for (const e of t)
                v(this, et, "f").key[e] = !0; }
    }
    var ee, se;
    const { readFileSync: ie } = require("fs"), { inspect: ne } = require("util"), { resolve: re } = require("path"), oe = require(3) /* y18n */, ae = require(4) /* yargs-parser */;
    var he, le = { assert: { notStrictEqual: t.notStrictEqual, strictEqual: t.strictEqual }, cliui: require(5) /* cliui */, findUp: require(17) /* escalade/sync */, getEnv: t => process.env[t], getCallerFile: require(18) /* get-caller-file */, getProcessArgvBin: y, inspect: ne, mainFilename: null !== (se = null === (ee = null === require || void 0 === require ? void 0 : require.main) || void 0 === ee ? void 0 : ee.filename) && void 0 !== se ? se : process.cwd(), Parser: ae, path: require("path"), process: { argv: () => process.argv, cwd: process.cwd, emitWarning: (t, e) => process.emitWarning(t, e), execPath: () => process.execPath, exit: t => { process.exit(t); }, nextTick: process.nextTick, stdColumns: void 0 !== process.stdout.columns ? process.stdout.columns : null }, readFileSync: ie, require: require, requireDirectory: require(19) /* require-directory */, stringWidth: require(6) /* string-width */, y18n: oe({ directory: re(__dirname, "../locales"), updateFiles: !1 }) };
    const ce = (null === (he = null === process || void 0 === process ? void 0 : process.env) || void 0 === he ? void 0 : he.YARGS_MIN_NODE_VERSION) ? Number(process.env.YARGS_MIN_NODE_VERSION) : 12;
    if (process && process.version) {
        if (Number(process.version.match(/v([^.]+)/)[1]) < ce)
            throw Error(`yargs supports a minimum Node.js version of ${ce}. Read our version support policy: https://github.com/yargs/yargs#supported-nodejs-versions`);
    }
    const fe = require(4) /* yargs-parser */;
    var de, ue = { applyExtends: n, cjsPlatformShim: le, Yargs: (de = le, (t = [], e = de.process.cwd(), s) => { const i = new te(t, e, s, de); return Object.defineProperty(i, "argv", { get: () => i.parse(), enumerable: !0 }), i.help(), i.version(), i; }), argsert: h, isPromise: f, objFilter: g, parseCommand: o, Parser: fe, processArgv: b, YError: e };
    module.exports = ue;
},
/* y18n/build/index.cjs */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    var fs = require('fs');
    var util = require('util');
    var path = require('path');
    let shim;
    class Y18N {
        constructor(opts) {
            // configurable options.
            opts = opts || {};
            this.directory = opts.directory || './locales';
            this.updateFiles = typeof opts.updateFiles === 'boolean' ? opts.updateFiles : true;
            this.locale = opts.locale || 'en';
            this.fallbackToLanguage = typeof opts.fallbackToLanguage === 'boolean' ? opts.fallbackToLanguage : true;
            // internal stuff.
            this.cache = Object.create(null);
            this.writeQueue = [];
        }
        __(...args) {
            if (typeof arguments[0] !== 'string') {
                return this._taggedLiteral(arguments[0], ...arguments);
            }
            const str = args.shift();
            let cb = function () { }; // start with noop.
            if (typeof args[args.length - 1] === 'function')
                cb = args.pop();
            cb = cb || function () { }; // noop.
            if (!this.cache[this.locale])
                this._readLocaleFile();
            // we've observed a new string, update the language file.
            if (!this.cache[this.locale][str] && this.updateFiles) {
                this.cache[this.locale][str] = str;
                // include the current directory and locale,
                // since these values could change before the
                // write is performed.
                this._enqueueWrite({
                    directory: this.directory,
                    locale: this.locale,
                    cb
                });
            }
            else {
                cb();
            }
            return shim.format.apply(shim.format, [this.cache[this.locale][str] || str].concat(args));
        }
        __n() {
            const args = Array.prototype.slice.call(arguments);
            const singular = args.shift();
            const plural = args.shift();
            const quantity = args.shift();
            let cb = function () { }; // start with noop.
            if (typeof args[args.length - 1] === 'function')
                cb = args.pop();
            if (!this.cache[this.locale])
                this._readLocaleFile();
            let str = quantity === 1 ? singular : plural;
            if (this.cache[this.locale][singular]) {
                const entry = this.cache[this.locale][singular];
                str = entry[quantity === 1 ? 'one' : 'other'];
            }
            // we've observed a new string, update the language file.
            if (!this.cache[this.locale][singular] && this.updateFiles) {
                this.cache[this.locale][singular] = {
                    one: singular,
                    other: plural
                };
                // include the current directory and locale,
                // since these values could change before the
                // write is performed.
                this._enqueueWrite({
                    directory: this.directory,
                    locale: this.locale,
                    cb
                });
            }
            else {
                cb();
            }
            // if a %d placeholder is provided, add quantity
            // to the arguments expanded by util.format.
            const values = [str];
            if (~str.indexOf('%d'))
                values.push(quantity);
            return shim.format.apply(shim.format, values.concat(args));
        }
        setLocale(locale) {
            this.locale = locale;
        }
        getLocale() {
            return this.locale;
        }
        updateLocale(obj) {
            if (!this.cache[this.locale])
                this._readLocaleFile();
            for (const key in obj) {
                if (Object.prototype.hasOwnProperty.call(obj, key)) {
                    this.cache[this.locale][key] = obj[key];
                }
            }
        }
        _taggedLiteral(parts, ...args) {
            let str = '';
            parts.forEach(function (part, i) {
                const arg = args[i + 1];
                str += part;
                if (typeof arg !== 'undefined') {
                    str += '%s';
                }
            });
            return this.__.apply(this, [str].concat([].slice.call(args, 1)));
        }
        _enqueueWrite(work) {
            this.writeQueue.push(work);
            if (this.writeQueue.length === 1)
                this._processWriteQueue();
        }
        _processWriteQueue() {
            const _this = this;
            const work = this.writeQueue[0];
            // destructure the enqueued work.
            const directory = work.directory;
            const locale = work.locale;
            const cb = work.cb;
            const languageFile = this._resolveLocaleFile(directory, locale);
            const serializedLocale = JSON.stringify(this.cache[locale], null, 2);
            shim.fs.writeFile(languageFile, serializedLocale, 'utf-8', function (err) {
                _this.writeQueue.shift();
                if (_this.writeQueue.length > 0)
                    _this._processWriteQueue();
                cb(err);
            });
        }
        _readLocaleFile() {
            let localeLookup = {};
            const languageFile = this._resolveLocaleFile(this.directory, this.locale);
            try {
                // When using a bundler such as webpack, readFileSync may not be defined:
                if (shim.fs.readFileSync) {
                    localeLookup = JSON.parse(shim.fs.readFileSync(languageFile, 'utf-8'));
                }
            }
            catch (err) {
                if (err instanceof SyntaxError) {
                    err.message = 'syntax error in ' + languageFile;
                }
                if (err.code === 'ENOENT')
                    localeLookup = {};
                else
                    throw err;
            }
            this.cache[this.locale] = localeLookup;
        }
        _resolveLocaleFile(directory, locale) {
            let file = shim.resolve(directory, './', locale + '.json');
            if (this.fallbackToLanguage && !this._fileExistsSync(file) && ~locale.lastIndexOf('_')) {
                // attempt fallback to language only
                const languageFile = shim.resolve(directory, './', locale.split('_')[0] + '.json');
                if (this._fileExistsSync(languageFile))
                    file = languageFile;
            }
            return file;
        }
        _fileExistsSync(file) {
            return shim.exists(file);
        }
    }
    function y18n$1(opts, _shim) {
        shim = _shim;
        const y18n = new Y18N(opts);
        return {
            __: y18n.__.bind(y18n),
            __n: y18n.__n.bind(y18n),
            setLocale: y18n.setLocale.bind(y18n),
            getLocale: y18n.getLocale.bind(y18n),
            updateLocale: y18n.updateLocale.bind(y18n),
            locale: y18n.locale
        };
    }
    var nodePlatformShim = {
        fs: {
            readFileSync: fs.readFileSync,
            writeFile: fs.writeFile
        },
        format: util.format,
        resolve: path.resolve,
        exists: (file) => {
            try {
                return fs.statSync(file).isFile();
            }
            catch (err) {
                return false;
            }
        }
    };
    const y18n = (opts) => {
        return y18n$1(opts, nodePlatformShim);
    };
    module.exports = y18n;
},
/* yargs-parser/build/index.cjs */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    var util = require('util');
    var path = require('path');
    var fs = require('fs');
    function camelCase(str) {
        const isCamelCase = str !== str.toLowerCase() && str !== str.toUpperCase();
        if (!isCamelCase) {
            str = str.toLowerCase();
        }
        if (str.indexOf('-') === -1 && str.indexOf('_') === -1) {
            return str;
        }
        else {
            let camelcase = '';
            let nextChrUpper = false;
            const leadingHyphens = str.match(/^-+/);
            for (let i = leadingHyphens ? leadingHyphens[0].length : 0; i < str.length; i++) {
                let chr = str.charAt(i);
                if (nextChrUpper) {
                    nextChrUpper = false;
                    chr = chr.toUpperCase();
                }
                if (i !== 0 && (chr === '-' || chr === '_')) {
                    nextChrUpper = true;
                }
                else if (chr !== '-' && chr !== '_') {
                    camelcase += chr;
                }
            }
            return camelcase;
        }
    }
    function decamelize(str, joinString) {
        const lowercase = str.toLowerCase();
        joinString = joinString || '-';
        let notCamelcase = '';
        for (let i = 0; i < str.length; i++) {
            const chrLower = lowercase.charAt(i);
            const chrString = str.charAt(i);
            if (chrLower !== chrString && i > 0) {
                notCamelcase += `${joinString}${lowercase.charAt(i)}`;
            }
            else {
                notCamelcase += chrString;
            }
        }
        return notCamelcase;
    }
    function looksLikeNumber(x) {
        if (x === null || x === undefined)
            return false;
        if (typeof x === 'number')
            return true;
        if (/^0x[0-9a-f]+$/i.test(x))
            return true;
        if (/^0[^.]/.test(x))
            return false;
        return /^[-]?(?:\d+(?:\.\d*)?|\.\d+)(e[-+]?\d+)?$/.test(x);
    }
    function tokenizeArgString(argString) {
        if (Array.isArray(argString)) {
            return argString.map(e => typeof e !== 'string' ? e + '' : e);
        }
        argString = argString.trim();
        let i = 0;
        let prevC = null;
        let c = null;
        let opening = null;
        const args = [];
        for (let ii = 0; ii < argString.length; ii++) {
            prevC = c;
            c = argString.charAt(ii);
            if (c === ' ' && !opening) {
                if (!(prevC === ' ')) {
                    i++;
                }
                continue;
            }
            if (c === opening) {
                opening = null;
            }
            else if ((c === "'" || c === '"') && !opening) {
                opening = c;
            }
            if (!args[i])
                args[i] = '';
            args[i] += c;
        }
        return args;
    }
    var DefaultValuesForTypeKey;
    (function (DefaultValuesForTypeKey) {
        DefaultValuesForTypeKey["BOOLEAN"] = "boolean";
        DefaultValuesForTypeKey["STRING"] = "string";
        DefaultValuesForTypeKey["NUMBER"] = "number";
        DefaultValuesForTypeKey["ARRAY"] = "array";
    })(DefaultValuesForTypeKey || (DefaultValuesForTypeKey = {}));
    let mixin;
    class YargsParser {
        constructor(_mixin) {
            mixin = _mixin;
        }
        parse(argsInput, options) {
            const opts = Object.assign({
                alias: undefined,
                array: undefined,
                boolean: undefined,
                config: undefined,
                configObjects: undefined,
                configuration: undefined,
                coerce: undefined,
                count: undefined,
                default: undefined,
                envPrefix: undefined,
                narg: undefined,
                normalize: undefined,
                string: undefined,
                number: undefined,
                __: undefined,
                key: undefined
            }, options);
            const args = tokenizeArgString(argsInput);
            const inputIsString = typeof argsInput === 'string';
            const aliases = combineAliases(Object.assign(Object.create(null), opts.alias));
            const configuration = Object.assign({
                'boolean-negation': true,
                'camel-case-expansion': true,
                'combine-arrays': false,
                'dot-notation': true,
                'duplicate-arguments-array': true,
                'flatten-duplicate-arrays': true,
                'greedy-arrays': true,
                'halt-at-non-option': false,
                'nargs-eats-options': false,
                'negation-prefix': 'no-',
                'parse-numbers': true,
                'parse-positional-numbers': true,
                'populate--': false,
                'set-placeholder-key': false,
                'short-option-groups': true,
                'strip-aliased': false,
                'strip-dashed': false,
                'unknown-options-as-args': false
            }, opts.configuration);
            const defaults = Object.assign(Object.create(null), opts.default);
            const configObjects = opts.configObjects || [];
            const envPrefix = opts.envPrefix;
            const notFlagsOption = configuration['populate--'];
            const notFlagsArgv = notFlagsOption ? '--' : '_';
            const newAliases = Object.create(null);
            const defaulted = Object.create(null);
            const __ = opts.__ || mixin.format;
            const flags = {
                aliases: Object.create(null),
                arrays: Object.create(null),
                bools: Object.create(null),
                strings: Object.create(null),
                numbers: Object.create(null),
                counts: Object.create(null),
                normalize: Object.create(null),
                configs: Object.create(null),
                nargs: Object.create(null),
                coercions: Object.create(null),
                keys: []
            };
            const negative = /^-([0-9]+(\.[0-9]+)?|\.[0-9]+)$/;
            const negatedBoolean = new RegExp('^--' + configuration['negation-prefix'] + '(.+)');
            [].concat(opts.array || []).filter(Boolean).forEach(function (opt) {
                const key = typeof opt === 'object' ? opt.key : opt;
                const assignment = Object.keys(opt).map(function (key) {
                    const arrayFlagKeys = {
                        boolean: 'bools',
                        string: 'strings',
                        number: 'numbers'
                    };
                    return arrayFlagKeys[key];
                }).filter(Boolean).pop();
                if (assignment) {
                    flags[assignment][key] = true;
                }
                flags.arrays[key] = true;
                flags.keys.push(key);
            });
            [].concat(opts.boolean || []).filter(Boolean).forEach(function (key) {
                flags.bools[key] = true;
                flags.keys.push(key);
            });
            [].concat(opts.string || []).filter(Boolean).forEach(function (key) {
                flags.strings[key] = true;
                flags.keys.push(key);
            });
            [].concat(opts.number || []).filter(Boolean).forEach(function (key) {
                flags.numbers[key] = true;
                flags.keys.push(key);
            });
            [].concat(opts.count || []).filter(Boolean).forEach(function (key) {
                flags.counts[key] = true;
                flags.keys.push(key);
            });
            [].concat(opts.normalize || []).filter(Boolean).forEach(function (key) {
                flags.normalize[key] = true;
                flags.keys.push(key);
            });
            if (typeof opts.narg === 'object') {
                Object.entries(opts.narg).forEach(([key, value]) => {
                    if (typeof value === 'number') {
                        flags.nargs[key] = value;
                        flags.keys.push(key);
                    }
                });
            }
            if (typeof opts.coerce === 'object') {
                Object.entries(opts.coerce).forEach(([key, value]) => {
                    if (typeof value === 'function') {
                        flags.coercions[key] = value;
                        flags.keys.push(key);
                    }
                });
            }
            if (typeof opts.config !== 'undefined') {
                if (Array.isArray(opts.config) || typeof opts.config === 'string') {
                    [].concat(opts.config).filter(Boolean).forEach(function (key) {
                        flags.configs[key] = true;
                    });
                }
                else if (typeof opts.config === 'object') {
                    Object.entries(opts.config).forEach(([key, value]) => {
                        if (typeof value === 'boolean' || typeof value === 'function') {
                            flags.configs[key] = value;
                        }
                    });
                }
            }
            extendAliases(opts.key, aliases, opts.default, flags.arrays);
            Object.keys(defaults).forEach(function (key) {
                (flags.aliases[key] || []).forEach(function (alias) {
                    defaults[alias] = defaults[key];
                });
            });
            let error = null;
            checkConfiguration();
            let notFlags = [];
            const argv = Object.assign(Object.create(null), { _: [] });
            const argvReturn = {};
            for (let i = 0; i < args.length; i++) {
                const arg = args[i];
                const truncatedArg = arg.replace(/^-{3,}/, '---');
                let broken;
                let key;
                let letters;
                let m;
                let next;
                let value;
                if (arg !== '--' && /^-/.test(arg) && isUnknownOptionAsArg(arg)) {
                    pushPositional(arg);
                }
                else if (truncatedArg.match(/^---+(=|$)/)) {
                    pushPositional(arg);
                    continue;
                }
                else if (arg.match(/^--.+=/) || (!configuration['short-option-groups'] && arg.match(/^-.+=/))) {
                    m = arg.match(/^--?([^=]+)=([\s\S]*)$/);
                    if (m !== null && Array.isArray(m) && m.length >= 3) {
                        if (checkAllAliases(m[1], flags.arrays)) {
                            i = eatArray(i, m[1], args, m[2]);
                        }
                        else if (checkAllAliases(m[1], flags.nargs) !== false) {
                            i = eatNargs(i, m[1], args, m[2]);
                        }
                        else {
                            setArg(m[1], m[2], true);
                        }
                    }
                }
                else if (arg.match(negatedBoolean) && configuration['boolean-negation']) {
                    m = arg.match(negatedBoolean);
                    if (m !== null && Array.isArray(m) && m.length >= 2) {
                        key = m[1];
                        setArg(key, checkAllAliases(key, flags.arrays) ? [false] : false);
                    }
                }
                else if (arg.match(/^--.+/) || (!configuration['short-option-groups'] && arg.match(/^-[^-]+/))) {
                    m = arg.match(/^--?(.+)/);
                    if (m !== null && Array.isArray(m) && m.length >= 2) {
                        key = m[1];
                        if (checkAllAliases(key, flags.arrays)) {
                            i = eatArray(i, key, args);
                        }
                        else if (checkAllAliases(key, flags.nargs) !== false) {
                            i = eatNargs(i, key, args);
                        }
                        else {
                            next = args[i + 1];
                            if (next !== undefined && (!next.match(/^-/) ||
                                next.match(negative)) &&
                                !checkAllAliases(key, flags.bools) &&
                                !checkAllAliases(key, flags.counts)) {
                                setArg(key, next);
                                i++;
                            }
                            else if (/^(true|false)$/.test(next)) {
                                setArg(key, next);
                                i++;
                            }
                            else {
                                setArg(key, defaultValue(key));
                            }
                        }
                    }
                }
                else if (arg.match(/^-.\..+=/)) {
                    m = arg.match(/^-([^=]+)=([\s\S]*)$/);
                    if (m !== null && Array.isArray(m) && m.length >= 3) {
                        setArg(m[1], m[2]);
                    }
                }
                else if (arg.match(/^-.\..+/) && !arg.match(negative)) {
                    next = args[i + 1];
                    m = arg.match(/^-(.\..+)/);
                    if (m !== null && Array.isArray(m) && m.length >= 2) {
                        key = m[1];
                        if (next !== undefined && !next.match(/^-/) &&
                            !checkAllAliases(key, flags.bools) &&
                            !checkAllAliases(key, flags.counts)) {
                            setArg(key, next);
                            i++;
                        }
                        else {
                            setArg(key, defaultValue(key));
                        }
                    }
                }
                else if (arg.match(/^-[^-]+/) && !arg.match(negative)) {
                    letters = arg.slice(1, -1).split('');
                    broken = false;
                    for (let j = 0; j < letters.length; j++) {
                        next = arg.slice(j + 2);
                        if (letters[j + 1] && letters[j + 1] === '=') {
                            value = arg.slice(j + 3);
                            key = letters[j];
                            if (checkAllAliases(key, flags.arrays)) {
                                i = eatArray(i, key, args, value);
                            }
                            else if (checkAllAliases(key, flags.nargs) !== false) {
                                i = eatNargs(i, key, args, value);
                            }
                            else {
                                setArg(key, value);
                            }
                            broken = true;
                            break;
                        }
                        if (next === '-') {
                            setArg(letters[j], next);
                            continue;
                        }
                        if (/[A-Za-z]/.test(letters[j]) &&
                            /^-?\d+(\.\d*)?(e-?\d+)?$/.test(next) &&
                            checkAllAliases(next, flags.bools) === false) {
                            setArg(letters[j], next);
                            broken = true;
                            break;
                        }
                        if (letters[j + 1] && letters[j + 1].match(/\W/)) {
                            setArg(letters[j], next);
                            broken = true;
                            break;
                        }
                        else {
                            setArg(letters[j], defaultValue(letters[j]));
                        }
                    }
                    key = arg.slice(-1)[0];
                    if (!broken && key !== '-') {
                        if (checkAllAliases(key, flags.arrays)) {
                            i = eatArray(i, key, args);
                        }
                        else if (checkAllAliases(key, flags.nargs) !== false) {
                            i = eatNargs(i, key, args);
                        }
                        else {
                            next = args[i + 1];
                            if (next !== undefined && (!/^(-|--)[^-]/.test(next) ||
                                next.match(negative)) &&
                                !checkAllAliases(key, flags.bools) &&
                                !checkAllAliases(key, flags.counts)) {
                                setArg(key, next);
                                i++;
                            }
                            else if (/^(true|false)$/.test(next)) {
                                setArg(key, next);
                                i++;
                            }
                            else {
                                setArg(key, defaultValue(key));
                            }
                        }
                    }
                }
                else if (arg.match(/^-[0-9]$/) &&
                    arg.match(negative) &&
                    checkAllAliases(arg.slice(1), flags.bools)) {
                    key = arg.slice(1);
                    setArg(key, defaultValue(key));
                }
                else if (arg === '--') {
                    notFlags = args.slice(i + 1);
                    break;
                }
                else if (configuration['halt-at-non-option']) {
                    notFlags = args.slice(i);
                    break;
                }
                else {
                    pushPositional(arg);
                }
            }
            applyEnvVars(argv, true);
            applyEnvVars(argv, false);
            setConfig(argv);
            setConfigObjects();
            applyDefaultsAndAliases(argv, flags.aliases, defaults, true);
            applyCoercions(argv);
            if (configuration['set-placeholder-key'])
                setPlaceholderKeys(argv);
            Object.keys(flags.counts).forEach(function (key) {
                if (!hasKey(argv, key.split('.')))
                    setArg(key, 0);
            });
            if (notFlagsOption && notFlags.length)
                argv[notFlagsArgv] = [];
            notFlags.forEach(function (key) {
                argv[notFlagsArgv].push(key);
            });
            if (configuration['camel-case-expansion'] && configuration['strip-dashed']) {
                Object.keys(argv).filter(key => key !== '--' && key.includes('-')).forEach(key => {
                    delete argv[key];
                });
            }
            if (configuration['strip-aliased']) {
                [].concat(...Object.keys(aliases).map(k => aliases[k])).forEach(alias => {
                    if (configuration['camel-case-expansion'] && alias.includes('-')) {
                        delete argv[alias.split('.').map(prop => camelCase(prop)).join('.')];
                    }
                    delete argv[alias];
                });
            }
            function pushPositional(arg) {
                const maybeCoercedNumber = maybeCoerceNumber('_', arg);
                if (typeof maybeCoercedNumber === 'string' || typeof maybeCoercedNumber === 'number') {
                    argv._.push(maybeCoercedNumber);
                }
            }
            function eatNargs(i, key, args, argAfterEqualSign) {
                let ii;
                let toEat = checkAllAliases(key, flags.nargs);
                toEat = typeof toEat !== 'number' || isNaN(toEat) ? 1 : toEat;
                if (toEat === 0) {
                    if (!isUndefined(argAfterEqualSign)) {
                        error = Error(__('Argument unexpected for: %s', key));
                    }
                    setArg(key, defaultValue(key));
                    return i;
                }
                let available = isUndefined(argAfterEqualSign) ? 0 : 1;
                if (configuration['nargs-eats-options']) {
                    if (args.length - (i + 1) + available < toEat) {
                        error = Error(__('Not enough arguments following: %s', key));
                    }
                    available = toEat;
                }
                else {
                    for (ii = i + 1; ii < args.length; ii++) {
                        if (!args[ii].match(/^-[^0-9]/) || args[ii].match(negative) || isUnknownOptionAsArg(args[ii]))
                            available++;
                        else
                            break;
                    }
                    if (available < toEat)
                        error = Error(__('Not enough arguments following: %s', key));
                }
                let consumed = Math.min(available, toEat);
                if (!isUndefined(argAfterEqualSign) && consumed > 0) {
                    setArg(key, argAfterEqualSign);
                    consumed--;
                }
                for (ii = i + 1; ii < (consumed + i + 1); ii++) {
                    setArg(key, args[ii]);
                }
                return (i + consumed);
            }
            function eatArray(i, key, args, argAfterEqualSign) {
                let argsToSet = [];
                let next = argAfterEqualSign || args[i + 1];
                const nargsCount = checkAllAliases(key, flags.nargs);
                if (checkAllAliases(key, flags.bools) && !(/^(true|false)$/.test(next))) {
                    argsToSet.push(true);
                }
                else if (isUndefined(next) ||
                    (isUndefined(argAfterEqualSign) && /^-/.test(next) && !negative.test(next) && !isUnknownOptionAsArg(next))) {
                    if (defaults[key] !== undefined) {
                        const defVal = defaults[key];
                        argsToSet = Array.isArray(defVal) ? defVal : [defVal];
                    }
                }
                else {
                    if (!isUndefined(argAfterEqualSign)) {
                        argsToSet.push(processValue(key, argAfterEqualSign, true));
                    }
                    for (let ii = i + 1; ii < args.length; ii++) {
                        if ((!configuration['greedy-arrays'] && argsToSet.length > 0) ||
                            (nargsCount && typeof nargsCount === 'number' && argsToSet.length >= nargsCount))
                            break;
                        next = args[ii];
                        if (/^-/.test(next) && !negative.test(next) && !isUnknownOptionAsArg(next))
                            break;
                        i = ii;
                        argsToSet.push(processValue(key, next, inputIsString));
                    }
                }
                if (typeof nargsCount === 'number' && ((nargsCount && argsToSet.length < nargsCount) ||
                    (isNaN(nargsCount) && argsToSet.length === 0))) {
                    error = Error(__('Not enough arguments following: %s', key));
                }
                setArg(key, argsToSet);
                return i;
            }
            function setArg(key, val, shouldStripQuotes = inputIsString) {
                if (/-/.test(key) && configuration['camel-case-expansion']) {
                    const alias = key.split('.').map(function (prop) {
                        return camelCase(prop);
                    }).join('.');
                    addNewAlias(key, alias);
                }
                const value = processValue(key, val, shouldStripQuotes);
                const splitKey = key.split('.');
                setKey(argv, splitKey, value);
                if (flags.aliases[key]) {
                    flags.aliases[key].forEach(function (x) {
                        const keyProperties = x.split('.');
                        setKey(argv, keyProperties, value);
                    });
                }
                if (splitKey.length > 1 && configuration['dot-notation']) {
                    (flags.aliases[splitKey[0]] || []).forEach(function (x) {
                        let keyProperties = x.split('.');
                        const a = [].concat(splitKey);
                        a.shift();
                        keyProperties = keyProperties.concat(a);
                        if (!(flags.aliases[key] || []).includes(keyProperties.join('.'))) {
                            setKey(argv, keyProperties, value);
                        }
                    });
                }
                if (checkAllAliases(key, flags.normalize) && !checkAllAliases(key, flags.arrays)) {
                    const keys = [key].concat(flags.aliases[key] || []);
                    keys.forEach(function (key) {
                        Object.defineProperty(argvReturn, key, {
                            enumerable: true,
                            get() {
                                return val;
                            },
                            set(value) {
                                val = typeof value === 'string' ? mixin.normalize(value) : value;
                            }
                        });
                    });
                }
            }
            function addNewAlias(key, alias) {
                if (!(flags.aliases[key] && flags.aliases[key].length)) {
                    flags.aliases[key] = [alias];
                    newAliases[alias] = true;
                }
                if (!(flags.aliases[alias] && flags.aliases[alias].length)) {
                    addNewAlias(alias, key);
                }
            }
            function processValue(key, val, shouldStripQuotes) {
                if (shouldStripQuotes) {
                    val = stripQuotes(val);
                }
                if (checkAllAliases(key, flags.bools) || checkAllAliases(key, flags.counts)) {
                    if (typeof val === 'string')
                        val = val === 'true';
                }
                let value = Array.isArray(val)
                    ? val.map(function (v) { return maybeCoerceNumber(key, v); })
                    : maybeCoerceNumber(key, val);
                if (checkAllAliases(key, flags.counts) && (isUndefined(value) || typeof value === 'boolean')) {
                    value = increment();
                }
                if (checkAllAliases(key, flags.normalize) && checkAllAliases(key, flags.arrays)) {
                    if (Array.isArray(val))
                        value = val.map((val) => { return mixin.normalize(val); });
                    else
                        value = mixin.normalize(val);
                }
                return value;
            }
            function maybeCoerceNumber(key, value) {
                if (!configuration['parse-positional-numbers'] && key === '_')
                    return value;
                if (!checkAllAliases(key, flags.strings) && !checkAllAliases(key, flags.bools) && !Array.isArray(value)) {
                    const shouldCoerceNumber = looksLikeNumber(value) && configuration['parse-numbers'] && (Number.isSafeInteger(Math.floor(parseFloat(`${value}`))));
                    if (shouldCoerceNumber || (!isUndefined(value) && checkAllAliases(key, flags.numbers))) {
                        value = Number(value);
                    }
                }
                return value;
            }
            function setConfig(argv) {
                const configLookup = Object.create(null);
                applyDefaultsAndAliases(configLookup, flags.aliases, defaults);
                Object.keys(flags.configs).forEach(function (configKey) {
                    const configPath = argv[configKey] || configLookup[configKey];
                    if (configPath) {
                        try {
                            let config = null;
                            const resolvedConfigPath = mixin.resolve(mixin.cwd(), configPath);
                            const resolveConfig = flags.configs[configKey];
                            if (typeof resolveConfig === 'function') {
                                try {
                                    config = resolveConfig(resolvedConfigPath);
                                }
                                catch (e) {
                                    config = e;
                                }
                                if (config instanceof Error) {
                                    error = config;
                                    return;
                                }
                            }
                            else {
                                config = mixin.require(resolvedConfigPath);
                            }
                            setConfigObject(config);
                        }
                        catch (ex) {
                            if (ex.name === 'PermissionDenied')
                                error = ex;
                            else if (argv[configKey])
                                error = Error(__('Invalid JSON config file: %s', configPath));
                        }
                    }
                });
            }
            function setConfigObject(config, prev) {
                Object.keys(config).forEach(function (key) {
                    const value = config[key];
                    const fullKey = prev ? prev + '.' + key : key;
                    if (typeof value === 'object' && value !== null && !Array.isArray(value) && configuration['dot-notation']) {
                        setConfigObject(value, fullKey);
                    }
                    else {
                        if (!hasKey(argv, fullKey.split('.')) || (checkAllAliases(fullKey, flags.arrays) && configuration['combine-arrays'])) {
                            setArg(fullKey, value);
                        }
                    }
                });
            }
            function setConfigObjects() {
                if (typeof configObjects !== 'undefined') {
                    configObjects.forEach(function (configObject) {
                        setConfigObject(configObject);
                    });
                }
            }
            function applyEnvVars(argv, configOnly) {
                if (typeof envPrefix === 'undefined')
                    return;
                const prefix = typeof envPrefix === 'string' ? envPrefix : '';
                const env = mixin.env();
                Object.keys(env).forEach(function (envVar) {
                    if (prefix === '' || envVar.lastIndexOf(prefix, 0) === 0) {
                        const keys = envVar.split('__').map(function (key, i) {
                            if (i === 0) {
                                key = key.substring(prefix.length);
                            }
                            return camelCase(key);
                        });
                        if (((configOnly && flags.configs[keys.join('.')]) || !configOnly) && !hasKey(argv, keys)) {
                            setArg(keys.join('.'), env[envVar]);
                        }
                    }
                });
            }
            function applyCoercions(argv) {
                let coerce;
                const applied = new Set();
                Object.keys(argv).forEach(function (key) {
                    if (!applied.has(key)) {
                        coerce = checkAllAliases(key, flags.coercions);
                        if (typeof coerce === 'function') {
                            try {
                                const value = maybeCoerceNumber(key, coerce(argv[key]));
                                ([].concat(flags.aliases[key] || [], key)).forEach(ali => {
                                    applied.add(ali);
                                    argv[ali] = value;
                                });
                            }
                            catch (err) {
                                error = err;
                            }
                        }
                    }
                });
            }
            function setPlaceholderKeys(argv) {
                flags.keys.forEach((key) => {
                    if (~key.indexOf('.'))
                        return;
                    if (typeof argv[key] === 'undefined')
                        argv[key] = undefined;
                });
                return argv;
            }
            function applyDefaultsAndAliases(obj, aliases, defaults, canLog = false) {
                Object.keys(defaults).forEach(function (key) {
                    if (!hasKey(obj, key.split('.'))) {
                        setKey(obj, key.split('.'), defaults[key]);
                        if (canLog)
                            defaulted[key] = true;
                        (aliases[key] || []).forEach(function (x) {
                            if (hasKey(obj, x.split('.')))
                                return;
                            setKey(obj, x.split('.'), defaults[key]);
                        });
                    }
                });
            }
            function hasKey(obj, keys) {
                let o = obj;
                if (!configuration['dot-notation'])
                    keys = [keys.join('.')];
                keys.slice(0, -1).forEach(function (key) {
                    o = (o[key] || {});
                });
                const key = keys[keys.length - 1];
                if (typeof o !== 'object')
                    return false;
                else
                    return key in o;
            }
            function setKey(obj, keys, value) {
                let o = obj;
                if (!configuration['dot-notation'])
                    keys = [keys.join('.')];
                keys.slice(0, -1).forEach(function (key) {
                    key = sanitizeKey(key);
                    if (typeof o === 'object' && o[key] === undefined) {
                        o[key] = {};
                    }
                    if (typeof o[key] !== 'object' || Array.isArray(o[key])) {
                        if (Array.isArray(o[key])) {
                            o[key].push({});
                        }
                        else {
                            o[key] = [o[key], {}];
                        }
                        o = o[key][o[key].length - 1];
                    }
                    else {
                        o = o[key];
                    }
                });
                const key = sanitizeKey(keys[keys.length - 1]);
                const isTypeArray = checkAllAliases(keys.join('.'), flags.arrays);
                const isValueArray = Array.isArray(value);
                let duplicate = configuration['duplicate-arguments-array'];
                if (!duplicate && checkAllAliases(key, flags.nargs)) {
                    duplicate = true;
                    if ((!isUndefined(o[key]) && flags.nargs[key] === 1) || (Array.isArray(o[key]) && o[key].length === flags.nargs[key])) {
                        o[key] = undefined;
                    }
                }
                if (value === increment()) {
                    o[key] = increment(o[key]);
                }
                else if (Array.isArray(o[key])) {
                    if (duplicate && isTypeArray && isValueArray) {
                        o[key] = configuration['flatten-duplicate-arrays'] ? o[key].concat(value) : (Array.isArray(o[key][0]) ? o[key] : [o[key]]).concat([value]);
                    }
                    else if (!duplicate && Boolean(isTypeArray) === Boolean(isValueArray)) {
                        o[key] = value;
                    }
                    else {
                        o[key] = o[key].concat([value]);
                    }
                }
                else if (o[key] === undefined && isTypeArray) {
                    o[key] = isValueArray ? value : [value];
                }
                else if (duplicate && !(o[key] === undefined ||
                    checkAllAliases(key, flags.counts) ||
                    checkAllAliases(key, flags.bools))) {
                    o[key] = [o[key], value];
                }
                else {
                    o[key] = value;
                }
            }
            function extendAliases(...args) {
                args.forEach(function (obj) {
                    Object.keys(obj || {}).forEach(function (key) {
                        if (flags.aliases[key])
                            return;
                        flags.aliases[key] = [].concat(aliases[key] || []);
                        flags.aliases[key].concat(key).forEach(function (x) {
                            if (/-/.test(x) && configuration['camel-case-expansion']) {
                                const c = camelCase(x);
                                if (c !== key && flags.aliases[key].indexOf(c) === -1) {
                                    flags.aliases[key].push(c);
                                    newAliases[c] = true;
                                }
                            }
                        });
                        flags.aliases[key].concat(key).forEach(function (x) {
                            if (x.length > 1 && /[A-Z]/.test(x) && configuration['camel-case-expansion']) {
                                const c = decamelize(x, '-');
                                if (c !== key && flags.aliases[key].indexOf(c) === -1) {
                                    flags.aliases[key].push(c);
                                    newAliases[c] = true;
                                }
                            }
                        });
                        flags.aliases[key].forEach(function (x) {
                            flags.aliases[x] = [key].concat(flags.aliases[key].filter(function (y) {
                                return x !== y;
                            }));
                        });
                    });
                });
            }
            function checkAllAliases(key, flag) {
                const toCheck = [].concat(flags.aliases[key] || [], key);
                const keys = Object.keys(flag);
                const setAlias = toCheck.find(key => keys.includes(key));
                return setAlias ? flag[setAlias] : false;
            }
            function hasAnyFlag(key) {
                const flagsKeys = Object.keys(flags);
                const toCheck = [].concat(flagsKeys.map(k => flags[k]));
                return toCheck.some(function (flag) {
                    return Array.isArray(flag) ? flag.includes(key) : flag[key];
                });
            }
            function hasFlagsMatching(arg, ...patterns) {
                const toCheck = [].concat(...patterns);
                return toCheck.some(function (pattern) {
                    const match = arg.match(pattern);
                    return match && hasAnyFlag(match[1]);
                });
            }
            function hasAllShortFlags(arg) {
                if (arg.match(negative) || !arg.match(/^-[^-]+/)) {
                    return false;
                }
                let hasAllFlags = true;
                let next;
                const letters = arg.slice(1).split('');
                for (let j = 0; j < letters.length; j++) {
                    next = arg.slice(j + 2);
                    if (!hasAnyFlag(letters[j])) {
                        hasAllFlags = false;
                        break;
                    }
                    if ((letters[j + 1] && letters[j + 1] === '=') ||
                        next === '-' ||
                        (/[A-Za-z]/.test(letters[j]) && /^-?\d+(\.\d*)?(e-?\d+)?$/.test(next)) ||
                        (letters[j + 1] && letters[j + 1].match(/\W/))) {
                        break;
                    }
                }
                return hasAllFlags;
            }
            function isUnknownOptionAsArg(arg) {
                return configuration['unknown-options-as-args'] && isUnknownOption(arg);
            }
            function isUnknownOption(arg) {
                arg = arg.replace(/^-{3,}/, '--');
                if (arg.match(negative)) {
                    return false;
                }
                if (hasAllShortFlags(arg)) {
                    return false;
                }
                const flagWithEquals = /^-+([^=]+?)=[\s\S]*$/;
                const normalFlag = /^-+([^=]+?)$/;
                const flagEndingInHyphen = /^-+([^=]+?)-$/;
                const flagEndingInDigits = /^-+([^=]+?\d+)$/;
                const flagEndingInNonWordCharacters = /^-+([^=]+?)\W+.*$/;
                return !hasFlagsMatching(arg, flagWithEquals, negatedBoolean, normalFlag, flagEndingInHyphen, flagEndingInDigits, flagEndingInNonWordCharacters);
            }
            function defaultValue(key) {
                if (!checkAllAliases(key, flags.bools) &&
                    !checkAllAliases(key, flags.counts) &&
                    `${key}` in defaults) {
                    return defaults[key];
                }
                else {
                    return defaultForType(guessType(key));
                }
            }
            function defaultForType(type) {
                const def = {
                    [DefaultValuesForTypeKey.BOOLEAN]: true,
                    [DefaultValuesForTypeKey.STRING]: '',
                    [DefaultValuesForTypeKey.NUMBER]: undefined,
                    [DefaultValuesForTypeKey.ARRAY]: []
                };
                return def[type];
            }
            function guessType(key) {
                let type = DefaultValuesForTypeKey.BOOLEAN;
                if (checkAllAliases(key, flags.strings))
                    type = DefaultValuesForTypeKey.STRING;
                else if (checkAllAliases(key, flags.numbers))
                    type = DefaultValuesForTypeKey.NUMBER;
                else if (checkAllAliases(key, flags.bools))
                    type = DefaultValuesForTypeKey.BOOLEAN;
                else if (checkAllAliases(key, flags.arrays))
                    type = DefaultValuesForTypeKey.ARRAY;
                return type;
            }
            function isUndefined(num) {
                return num === undefined;
            }
            function checkConfiguration() {
                Object.keys(flags.counts).find(key => {
                    if (checkAllAliases(key, flags.arrays)) {
                        error = Error(__('Invalid configuration: %s, opts.count excludes opts.array.', key));
                        return true;
                    }
                    else if (checkAllAliases(key, flags.nargs)) {
                        error = Error(__('Invalid configuration: %s, opts.count excludes opts.narg.', key));
                        return true;
                    }
                    return false;
                });
            }
            return {
                aliases: Object.assign({}, flags.aliases),
                argv: Object.assign(argvReturn, argv),
                configuration: configuration,
                defaulted: Object.assign({}, defaulted),
                error: error,
                newAliases: Object.assign({}, newAliases)
            };
        }
    }
    function combineAliases(aliases) {
        const aliasArrays = [];
        const combined = Object.create(null);
        let change = true;
        Object.keys(aliases).forEach(function (key) {
            aliasArrays.push([].concat(aliases[key], key));
        });
        while (change) {
            change = false;
            for (let i = 0; i < aliasArrays.length; i++) {
                for (let ii = i + 1; ii < aliasArrays.length; ii++) {
                    const intersect = aliasArrays[i].filter(function (v) {
                        return aliasArrays[ii].indexOf(v) !== -1;
                    });
                    if (intersect.length) {
                        aliasArrays[i] = aliasArrays[i].concat(aliasArrays[ii]);
                        aliasArrays.splice(ii, 1);
                        change = true;
                        break;
                    }
                }
            }
        }
        aliasArrays.forEach(function (aliasArray) {
            aliasArray = aliasArray.filter(function (v, i, self) {
                return self.indexOf(v) === i;
            });
            const lastAlias = aliasArray.pop();
            if (lastAlias !== undefined && typeof lastAlias === 'string') {
                combined[lastAlias] = aliasArray;
            }
        });
        return combined;
    }
    function increment(orig) {
        return orig !== undefined ? orig + 1 : 1;
    }
    function sanitizeKey(key) {
        if (key === '__proto__')
            return '___proto___';
        return key;
    }
    function stripQuotes(val) {
        return (typeof val === 'string' &&
            (val[0] === "'" || val[0] === '"') &&
            val[val.length - 1] === val[0])
            ? val.substring(1, val.length - 1)
            : val;
    }
    var _a, _b, _c;
    const minNodeVersion = (process && process.env && process.env.YARGS_MIN_NODE_VERSION)
        ? Number(process.env.YARGS_MIN_NODE_VERSION)
        : 12;
    const nodeVersion = (_b = (_a = process === null || process === void 0 ? void 0 : process.versions) === null || _a === void 0 ? void 0 : _a.node) !== null && _b !== void 0 ? _b : (_c = process === null || process === void 0 ? void 0 : process.version) === null || _c === void 0 ? void 0 : _c.slice(1);
    if (nodeVersion) {
        const major = Number(nodeVersion.match(/^([^.]+)/)[1]);
        if (major < minNodeVersion) {
            throw Error(`yargs parser supports a minimum Node.js version of ${minNodeVersion}. Read our version support policy: https://github.com/yargs/yargs-parser#supported-nodejs-versions`);
        }
    }
    const env = process ? process.env : {};
    const parser = new YargsParser({
        cwd: process.cwd,
        env: () => {
            return env;
        },
        format: util.format,
        normalize: path.normalize,
        resolve: path.resolve,
        require: (path) => {
            if (typeof require !== 'undefined') {
                return require(path);
            }
            else if (path.match(/\.json$/)) {
                return JSON.parse(fs.readFileSync(path, 'utf8'));
            }
            else {
                throw Error('only .json config files are supported in ESM');
            }
        }
    });
    const yargsParser = function Parser(args, opts) {
        const result = parser.parse(args.slice(), opts);
        return result.argv;
    };
    yargsParser.detailed = function (args, opts) {
        return parser.parse(args.slice(), opts);
    };
    yargsParser.camelCase = camelCase;
    yargsParser.decamelize = decamelize;
    yargsParser.looksLikeNumber = looksLikeNumber;
    module.exports = yargsParser;
},
/* cliui/build/index.cjs */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const align = {
        right: alignRight,
        center: alignCenter
    };
    const top = 0;
    const right = 1;
    const bottom = 2;
    const left = 3;
    class UI {
        constructor(opts) {
            var _a;
            this.width = opts.width;
            this.wrap = (_a = opts.wrap) !== null && _a !== void 0 ? _a : true;
            this.rows = [];
        }
        span(...args) {
            const cols = this.div(...args);
            cols.span = true;
        }
        resetOutput() {
            this.rows = [];
        }
        div(...args) {
            if (args.length === 0) {
                this.div('');
            }
            if (this.wrap && this.shouldApplyLayoutDSL(...args) && typeof args[0] === 'string') {
                return this.applyLayoutDSL(args[0]);
            }
            const cols = args.map(arg => {
                if (typeof arg === 'string') {
                    return this.colFromString(arg);
                }
                return arg;
            });
            this.rows.push(cols);
            return cols;
        }
        shouldApplyLayoutDSL(...args) {
            return args.length === 1 && typeof args[0] === 'string' &&
                /[\t\n]/.test(args[0]);
        }
        applyLayoutDSL(str) {
            const rows = str.split('\n').map(row => row.split('\t'));
            let leftColumnWidth = 0;
            // simple heuristic for layout, make sure the
            // second column lines up along the left-hand.
            // don't allow the first column to take up more
            // than 50% of the screen.
            rows.forEach(columns => {
                if (columns.length > 1 && mixin.stringWidth(columns[0]) > leftColumnWidth) {
                    leftColumnWidth = Math.min(Math.floor(this.width * 0.5), mixin.stringWidth(columns[0]));
                }
            });
            // generate a table:
            //  replacing ' ' with padding calculations.
            //  using the algorithmically generated width.
            rows.forEach(columns => {
                this.div(...columns.map((r, i) => {
                    return {
                        text: r.trim(),
                        padding: this.measurePadding(r),
                        width: (i === 0 && columns.length > 1) ? leftColumnWidth : undefined
                    };
                }));
            });
            return this.rows[this.rows.length - 1];
        }
        colFromString(text) {
            return {
                text,
                padding: this.measurePadding(text)
            };
        }
        measurePadding(str) {
            // measure padding without ansi escape codes
            const noAnsi = mixin.stripAnsi(str);
            return [0, noAnsi.match(/\s*$/)[0].length, 0, noAnsi.match(/^\s*/)[0].length];
        }
        toString() {
            const lines = [];
            this.rows.forEach(row => {
                this.rowToString(row, lines);
            });
            // don't display any lines with the
            // hidden flag set.
            return lines
                .filter(line => !line.hidden)
                .map(line => line.text)
                .join('\n');
        }
        rowToString(row, lines) {
            this.rasterize(row).forEach((rrow, r) => {
                let str = '';
                rrow.forEach((col, c) => {
                    const { width } = row[c]; // the width with padding.
                    const wrapWidth = this.negatePadding(row[c]); // the width without padding.
                    let ts = col; // temporary string used during alignment/padding.
                    if (wrapWidth > mixin.stringWidth(col)) {
                        ts += ' '.repeat(wrapWidth - mixin.stringWidth(col));
                    }
                    // align the string within its column.
                    if (row[c].align && row[c].align !== 'left' && this.wrap) {
                        const fn = align[row[c].align];
                        ts = fn(ts, wrapWidth);
                        if (mixin.stringWidth(ts) < wrapWidth) {
                            ts += ' '.repeat((width || 0) - mixin.stringWidth(ts) - 1);
                        }
                    }
                    // apply border and padding to string.
                    const padding = row[c].padding || [0, 0, 0, 0];
                    if (padding[left]) {
                        str += ' '.repeat(padding[left]);
                    }
                    str += addBorder(row[c], ts, '| ');
                    str += ts;
                    str += addBorder(row[c], ts, ' |');
                    if (padding[right]) {
                        str += ' '.repeat(padding[right]);
                    }
                    // if prior row is span, try to render the
                    // current row on the prior line.
                    if (r === 0 && lines.length > 0) {
                        str = this.renderInline(str, lines[lines.length - 1]);
                    }
                });
                // remove trailing whitespace.
                lines.push({
                    text: str.replace(/ +$/, ''),
                    span: row.span
                });
            });
            return lines;
        }
        // if the full 'source' can render in
        // the target line, do so.
        renderInline(source, previousLine) {
            const match = source.match(/^ */);
            const leadingWhitespace = match ? match[0].length : 0;
            const target = previousLine.text;
            const targetTextWidth = mixin.stringWidth(target.trimRight());
            if (!previousLine.span) {
                return source;
            }
            // if we're not applying wrapping logic,
            // just always append to the span.
            if (!this.wrap) {
                previousLine.hidden = true;
                return target + source;
            }
            if (leadingWhitespace < targetTextWidth) {
                return source;
            }
            previousLine.hidden = true;
            return target.trimRight() + ' '.repeat(leadingWhitespace - targetTextWidth) + source.trimLeft();
        }
        rasterize(row) {
            const rrows = [];
            const widths = this.columnWidths(row);
            let wrapped;
            // word wrap all columns, and create
            // a data-structure that is easy to rasterize.
            row.forEach((col, c) => {
                // leave room for left and right padding.
                col.width = widths[c];
                if (this.wrap) {
                    wrapped = mixin.wrap(col.text, this.negatePadding(col), { hard: true }).split('\n');
                }
                else {
                    wrapped = col.text.split('\n');
                }
                if (col.border) {
                    wrapped.unshift('.' + '-'.repeat(this.negatePadding(col) + 2) + '.');
                    wrapped.push("'" + '-'.repeat(this.negatePadding(col) + 2) + "'");
                }
                // add top and bottom padding.
                if (col.padding) {
                    wrapped.unshift(...new Array(col.padding[top] || 0).fill(''));
                    wrapped.push(...new Array(col.padding[bottom] || 0).fill(''));
                }
                wrapped.forEach((str, r) => {
                    if (!rrows[r]) {
                        rrows.push([]);
                    }
                    const rrow = rrows[r];
                    for (let i = 0; i < c; i++) {
                        if (rrow[i] === undefined) {
                            rrow.push('');
                        }
                    }
                    rrow.push(str);
                });
            });
            return rrows;
        }
        negatePadding(col) {
            let wrapWidth = col.width || 0;
            if (col.padding) {
                wrapWidth -= (col.padding[left] || 0) + (col.padding[right] || 0);
            }
            if (col.border) {
                wrapWidth -= 4;
            }
            return wrapWidth;
        }
        columnWidths(row) {
            if (!this.wrap) {
                return row.map(col => {
                    return col.width || mixin.stringWidth(col.text);
                });
            }
            let unset = row.length;
            let remainingWidth = this.width;
            // column widths can be set in config.
            const widths = row.map(col => {
                if (col.width) {
                    unset--;
                    remainingWidth -= col.width;
                    return col.width;
                }
                return undefined;
            });
            // any unset widths should be calculated.
            const unsetWidth = unset ? Math.floor(remainingWidth / unset) : 0;
            return widths.map((w, i) => {
                if (w === undefined) {
                    return Math.max(unsetWidth, _minWidth(row[i]));
                }
                return w;
            });
        }
    }
    function addBorder(col, ts, style) {
        if (col.border) {
            if (/[.']-+[.']/.test(ts)) {
                return '';
            }
            if (ts.trim().length !== 0) {
                return style;
            }
            return '  ';
        }
        return '';
    }
    // calculates the minimum width of
    // a column, based on padding preferences.
    function _minWidth(col) {
        const padding = col.padding || [];
        const minWidth = 1 + (padding[left] || 0) + (padding[right] || 0);
        if (col.border) {
            return minWidth + 4;
        }
        return minWidth;
    }
    function getWindowWidth() {
        /* istanbul ignore next: depends on terminal */
        if (typeof process === 'object' && process.stdout && process.stdout.columns) {
            return process.stdout.columns;
        }
        return 80;
    }
    function alignRight(str, width) {
        str = str.trim();
        const strWidth = mixin.stringWidth(str);
        if (strWidth < width) {
            return ' '.repeat(width - strWidth) + str;
        }
        return str;
    }
    function alignCenter(str, width) {
        str = str.trim();
        const strWidth = mixin.stringWidth(str);
        /* istanbul ignore next */
        if (strWidth >= width) {
            return str;
        }
        return ' '.repeat((width - strWidth) >> 1) + str;
    }
    let mixin;
    function cliui(opts, _mixin) {
        mixin = _mixin;
        return new UI({
            width: (opts === null || opts === void 0 ? void 0 : opts.width) || getWindowWidth(),
            wrap: opts === null || opts === void 0 ? void 0 : opts.wrap
        });
    }
    // Bootstrap cliui with CommonJS dependencies:
    const stringWidth = require(6) /* string-width */;
    const stripAnsi = require(7) /* strip-ansi */;
    const wrap = require(11) /* wrap-ansi */;
    function ui(opts) {
        return cliui(opts, {
            stringWidth,
            stripAnsi,
            wrap
        });
    }
    module.exports = ui;
},
/* string-width/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const stripAnsi = require(7) /* strip-ansi */;
    const isFullwidthCodePoint = require(9) /* is-fullwidth-code-point */;
    const emojiRegex = require(10) /* emoji-regex */;
    const stringWidth = string => {
        if (typeof string !== 'string' || string.length === 0) {
            return 0;
        }
        string = stripAnsi(string);
        if (string.length === 0) {
            return 0;
        }
        string = string.replace(emojiRegex(), '  ');
        let width = 0;
        for (let i = 0; i < string.length; i++) {
            const code = string.codePointAt(i);
            // Ignore control characters
            if (code <= 0x1F || (code >= 0x7F && code <= 0x9F)) {
                continue;
            }
            // Ignore combining characters
            if (code >= 0x300 && code <= 0x36F) {
                continue;
            }
            // Surrogates
            if (code > 0xFFFF) {
                i++;
            }
            width += isFullwidthCodePoint(code) ? 2 : 1;
        }
        return width;
    };
    module.exports = stringWidth;
    // TODO: remove this in the next major version
    module.exports.default = stringWidth;
},
/* strip-ansi/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const ansiRegex = require(8) /* ansi-regex */;
    module.exports = string => typeof string === 'string' ? string.replace(ansiRegex(), '') : string;
},
/* ansi-regex/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = ({ onlyFirst = false } = {}) => {
        const pattern = [
            '[\\u001B\\u009B][[\\]()#;?]*(?:(?:(?:(?:;[-a-zA-Z\\d\\/#&.:=?%@~_]+)*|[a-zA-Z\\d]+(?:;[-a-zA-Z\\d\\/#&.:=?%@~_]*)*)?\\u0007)',
            '(?:(?:\\d{1,4}(?:;\\d{0,4})*)?[\\dA-PR-TZcf-ntqry=><~]))'
        ].join('|');
        return new RegExp(pattern, onlyFirst ? undefined : 'g');
    };
},
/* is-fullwidth-code-point/index.js */ function _(require, module, exports, __esModule, __esExport) {
    /* eslint-disable yoda */
    'use strict';
    const isFullwidthCodePoint = codePoint => {
        if (Number.isNaN(codePoint)) {
            return false;
        }
        // Code points are derived from:
        // http://www.unix.org/Public/UNIDATA/EastAsianWidth.txt
        if (codePoint >= 0x1100 && (codePoint <= 0x115F || // Hangul Jamo
            codePoint === 0x2329 || // LEFT-POINTING ANGLE BRACKET
            codePoint === 0x232A || // RIGHT-POINTING ANGLE BRACKET
            // CJK Radicals Supplement .. Enclosed CJK Letters and Months
            (0x2E80 <= codePoint && codePoint <= 0x3247 && codePoint !== 0x303F) ||
            // Enclosed CJK Letters and Months .. CJK Unified Ideographs Extension A
            (0x3250 <= codePoint && codePoint <= 0x4DBF) ||
            // CJK Unified Ideographs .. Yi Radicals
            (0x4E00 <= codePoint && codePoint <= 0xA4C6) ||
            // Hangul Jamo Extended-A
            (0xA960 <= codePoint && codePoint <= 0xA97C) ||
            // Hangul Syllables
            (0xAC00 <= codePoint && codePoint <= 0xD7A3) ||
            // CJK Compatibility Ideographs
            (0xF900 <= codePoint && codePoint <= 0xFAFF) ||
            // Vertical Forms
            (0xFE10 <= codePoint && codePoint <= 0xFE19) ||
            // CJK Compatibility Forms .. Small Form Variants
            (0xFE30 <= codePoint && codePoint <= 0xFE6B) ||
            // Halfwidth and Fullwidth Forms
            (0xFF01 <= codePoint && codePoint <= 0xFF60) ||
            (0xFFE0 <= codePoint && codePoint <= 0xFFE6) ||
            // Kana Supplement
            (0x1B000 <= codePoint && codePoint <= 0x1B001) ||
            // Enclosed Ideographic Supplement
            (0x1F200 <= codePoint && codePoint <= 0x1F251) ||
            // CJK Unified Ideographs Extension B .. Tertiary Ideographic Plane
            (0x20000 <= codePoint && codePoint <= 0x3FFFD))) {
            return true;
        }
        return false;
    };
    module.exports = isFullwidthCodePoint;
    module.exports.default = isFullwidthCodePoint;
},
/* emoji-regex/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    module.exports = function () {
        // https://mths.be/emoji
        return /\uD83C\uDFF4\uDB40\uDC67\uDB40\uDC62(?:\uDB40\uDC65\uDB40\uDC6E\uDB40\uDC67|\uDB40\uDC73\uDB40\uDC63\uDB40\uDC74|\uDB40\uDC77\uDB40\uDC6C\uDB40\uDC73)\uDB40\uDC7F|\uD83D\uDC68(?:\uD83C\uDFFC\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68\uD83C\uDFFB|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFF\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFE])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFE\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFD])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFD\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB\uDFFC])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\u200D(?:\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D)?\uD83D\uDC68|(?:\uD83D[\uDC68\uDC69])\u200D(?:\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67]))|\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67])|(?:\uD83D[\uDC68\uDC69])\u200D(?:\uD83D[\uDC66\uDC67])|[\u2695\u2696\u2708]\uFE0F|\uD83D[\uDC66\uDC67]|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|(?:\uD83C\uDFFB\u200D[\u2695\u2696\u2708]|\uD83C\uDFFF\u200D[\u2695\u2696\u2708]|\uD83C\uDFFE\u200D[\u2695\u2696\u2708]|\uD83C\uDFFD\u200D[\u2695\u2696\u2708]|\uD83C\uDFFC\u200D[\u2695\u2696\u2708])\uFE0F|\uD83C\uDFFB\u200D(?:\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C[\uDFFB-\uDFFF])|(?:\uD83E\uDDD1\uD83C\uDFFB\u200D\uD83E\uDD1D\u200D\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFC\u200D\uD83E\uDD1D\u200D\uD83D\uDC69)\uD83C\uDFFB|\uD83E\uDDD1(?:\uD83C\uDFFF\u200D\uD83E\uDD1D\u200D\uD83E\uDDD1(?:\uD83C[\uDFFB-\uDFFF])|\u200D\uD83E\uDD1D\u200D\uD83E\uDDD1)|(?:\uD83E\uDDD1\uD83C\uDFFE\u200D\uD83E\uDD1D\u200D\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFF\u200D\uD83E\uDD1D\u200D(?:\uD83D[\uDC68\uDC69]))(?:\uD83C[\uDFFB-\uDFFE])|(?:\uD83E\uDDD1\uD83C\uDFFC\u200D\uD83E\uDD1D\u200D\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFD\u200D\uD83E\uDD1D\u200D\uD83D\uDC69)(?:\uD83C[\uDFFB\uDFFC])|\uD83D\uDC69(?:\uD83C\uDFFE\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFD\uDFFF])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFC\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB\uDFFD-\uDFFF])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFB\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFC-\uDFFF])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFD\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB\uDFFC\uDFFE\uDFFF])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\u200D(?:\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D(?:\uD83D[\uDC68\uDC69])|\uD83D[\uDC68\uDC69])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFF\u200D(?:\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD]))|\uD83D\uDC69\u200D\uD83D\uDC69\u200D(?:\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67]))|(?:\uD83E\uDDD1\uD83C\uDFFD\u200D\uD83E\uDD1D\u200D\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFE\u200D\uD83E\uDD1D\u200D\uD83D\uDC69)(?:\uD83C[\uDFFB-\uDFFD])|\uD83D\uDC69\u200D\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC69\u200D\uD83D\uDC69\u200D(?:\uD83D[\uDC66\uDC67])|(?:\uD83D\uDC41\uFE0F\u200D\uD83D\uDDE8|\uD83D\uDC69(?:\uD83C\uDFFF\u200D[\u2695\u2696\u2708]|\uD83C\uDFFE\u200D[\u2695\u2696\u2708]|\uD83C\uDFFC\u200D[\u2695\u2696\u2708]|\uD83C\uDFFB\u200D[\u2695\u2696\u2708]|\uD83C\uDFFD\u200D[\u2695\u2696\u2708]|\u200D[\u2695\u2696\u2708])|(?:(?:\u26F9|\uD83C[\uDFCB\uDFCC]|\uD83D\uDD75)\uFE0F|\uD83D\uDC6F|\uD83E[\uDD3C\uDDDE\uDDDF])\u200D[\u2640\u2642]|(?:\u26F9|\uD83C[\uDFCB\uDFCC]|\uD83D\uDD75)(?:\uD83C[\uDFFB-\uDFFF])\u200D[\u2640\u2642]|(?:\uD83C[\uDFC3\uDFC4\uDFCA]|\uD83D[\uDC6E\uDC71\uDC73\uDC77\uDC81\uDC82\uDC86\uDC87\uDE45-\uDE47\uDE4B\uDE4D\uDE4E\uDEA3\uDEB4-\uDEB6]|\uD83E[\uDD26\uDD37-\uDD39\uDD3D\uDD3E\uDDB8\uDDB9\uDDCD-\uDDCF\uDDD6-\uDDDD])(?:(?:\uD83C[\uDFFB-\uDFFF])\u200D[\u2640\u2642]|\u200D[\u2640\u2642])|\uD83C\uDFF4\u200D\u2620)\uFE0F|\uD83D\uDC69\u200D\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67])|\uD83C\uDFF3\uFE0F\u200D\uD83C\uDF08|\uD83D\uDC15\u200D\uD83E\uDDBA|\uD83D\uDC69\u200D\uD83D\uDC66|\uD83D\uDC69\u200D\uD83D\uDC67|\uD83C\uDDFD\uD83C\uDDF0|\uD83C\uDDF4\uD83C\uDDF2|\uD83C\uDDF6\uD83C\uDDE6|[#\*0-9]\uFE0F\u20E3|\uD83C\uDDE7(?:\uD83C[\uDDE6\uDDE7\uDDE9-\uDDEF\uDDF1-\uDDF4\uDDF6-\uDDF9\uDDFB\uDDFC\uDDFE\uDDFF])|\uD83C\uDDF9(?:\uD83C[\uDDE6\uDDE8\uDDE9\uDDEB-\uDDED\uDDEF-\uDDF4\uDDF7\uDDF9\uDDFB\uDDFC\uDDFF])|\uD83C\uDDEA(?:\uD83C[\uDDE6\uDDE8\uDDEA\uDDEC\uDDED\uDDF7-\uDDFA])|\uD83E\uDDD1(?:\uD83C[\uDFFB-\uDFFF])|\uD83C\uDDF7(?:\uD83C[\uDDEA\uDDF4\uDDF8\uDDFA\uDDFC])|\uD83D\uDC69(?:\uD83C[\uDFFB-\uDFFF])|\uD83C\uDDF2(?:\uD83C[\uDDE6\uDDE8-\uDDED\uDDF0-\uDDFF])|\uD83C\uDDE6(?:\uD83C[\uDDE8-\uDDEC\uDDEE\uDDF1\uDDF2\uDDF4\uDDF6-\uDDFA\uDDFC\uDDFD\uDDFF])|\uD83C\uDDF0(?:\uD83C[\uDDEA\uDDEC-\uDDEE\uDDF2\uDDF3\uDDF5\uDDF7\uDDFC\uDDFE\uDDFF])|\uD83C\uDDED(?:\uD83C[\uDDF0\uDDF2\uDDF3\uDDF7\uDDF9\uDDFA])|\uD83C\uDDE9(?:\uD83C[\uDDEA\uDDEC\uDDEF\uDDF0\uDDF2\uDDF4\uDDFF])|\uD83C\uDDFE(?:\uD83C[\uDDEA\uDDF9])|\uD83C\uDDEC(?:\uD83C[\uDDE6\uDDE7\uDDE9-\uDDEE\uDDF1-\uDDF3\uDDF5-\uDDFA\uDDFC\uDDFE])|\uD83C\uDDF8(?:\uD83C[\uDDE6-\uDDEA\uDDEC-\uDDF4\uDDF7-\uDDF9\uDDFB\uDDFD-\uDDFF])|\uD83C\uDDEB(?:\uD83C[\uDDEE-\uDDF0\uDDF2\uDDF4\uDDF7])|\uD83C\uDDF5(?:\uD83C[\uDDE6\uDDEA-\uDDED\uDDF0-\uDDF3\uDDF7-\uDDF9\uDDFC\uDDFE])|\uD83C\uDDFB(?:\uD83C[\uDDE6\uDDE8\uDDEA\uDDEC\uDDEE\uDDF3\uDDFA])|\uD83C\uDDF3(?:\uD83C[\uDDE6\uDDE8\uDDEA-\uDDEC\uDDEE\uDDF1\uDDF4\uDDF5\uDDF7\uDDFA\uDDFF])|\uD83C\uDDE8(?:\uD83C[\uDDE6\uDDE8\uDDE9\uDDEB-\uDDEE\uDDF0-\uDDF5\uDDF7\uDDFA-\uDDFF])|\uD83C\uDDF1(?:\uD83C[\uDDE6-\uDDE8\uDDEE\uDDF0\uDDF7-\uDDFB\uDDFE])|\uD83C\uDDFF(?:\uD83C[\uDDE6\uDDF2\uDDFC])|\uD83C\uDDFC(?:\uD83C[\uDDEB\uDDF8])|\uD83C\uDDFA(?:\uD83C[\uDDE6\uDDEC\uDDF2\uDDF3\uDDF8\uDDFE\uDDFF])|\uD83C\uDDEE(?:\uD83C[\uDDE8-\uDDEA\uDDF1-\uDDF4\uDDF6-\uDDF9])|\uD83C\uDDEF(?:\uD83C[\uDDEA\uDDF2\uDDF4\uDDF5])|(?:\uD83C[\uDFC3\uDFC4\uDFCA]|\uD83D[\uDC6E\uDC71\uDC73\uDC77\uDC81\uDC82\uDC86\uDC87\uDE45-\uDE47\uDE4B\uDE4D\uDE4E\uDEA3\uDEB4-\uDEB6]|\uD83E[\uDD26\uDD37-\uDD39\uDD3D\uDD3E\uDDB8\uDDB9\uDDCD-\uDDCF\uDDD6-\uDDDD])(?:\uD83C[\uDFFB-\uDFFF])|(?:\u26F9|\uD83C[\uDFCB\uDFCC]|\uD83D\uDD75)(?:\uD83C[\uDFFB-\uDFFF])|(?:[\u261D\u270A-\u270D]|\uD83C[\uDF85\uDFC2\uDFC7]|\uD83D[\uDC42\uDC43\uDC46-\uDC50\uDC66\uDC67\uDC6B-\uDC6D\uDC70\uDC72\uDC74-\uDC76\uDC78\uDC7C\uDC83\uDC85\uDCAA\uDD74\uDD7A\uDD90\uDD95\uDD96\uDE4C\uDE4F\uDEC0\uDECC]|\uD83E[\uDD0F\uDD18-\uDD1C\uDD1E\uDD1F\uDD30-\uDD36\uDDB5\uDDB6\uDDBB\uDDD2-\uDDD5])(?:\uD83C[\uDFFB-\uDFFF])|(?:[\u231A\u231B\u23E9-\u23EC\u23F0\u23F3\u25FD\u25FE\u2614\u2615\u2648-\u2653\u267F\u2693\u26A1\u26AA\u26AB\u26BD\u26BE\u26C4\u26C5\u26CE\u26D4\u26EA\u26F2\u26F3\u26F5\u26FA\u26FD\u2705\u270A\u270B\u2728\u274C\u274E\u2753-\u2755\u2757\u2795-\u2797\u27B0\u27BF\u2B1B\u2B1C\u2B50\u2B55]|\uD83C[\uDC04\uDCCF\uDD8E\uDD91-\uDD9A\uDDE6-\uDDFF\uDE01\uDE1A\uDE2F\uDE32-\uDE36\uDE38-\uDE3A\uDE50\uDE51\uDF00-\uDF20\uDF2D-\uDF35\uDF37-\uDF7C\uDF7E-\uDF93\uDFA0-\uDFCA\uDFCF-\uDFD3\uDFE0-\uDFF0\uDFF4\uDFF8-\uDFFF]|\uD83D[\uDC00-\uDC3E\uDC40\uDC42-\uDCFC\uDCFF-\uDD3D\uDD4B-\uDD4E\uDD50-\uDD67\uDD7A\uDD95\uDD96\uDDA4\uDDFB-\uDE4F\uDE80-\uDEC5\uDECC\uDED0-\uDED2\uDED5\uDEEB\uDEEC\uDEF4-\uDEFA\uDFE0-\uDFEB]|\uD83E[\uDD0D-\uDD3A\uDD3C-\uDD45\uDD47-\uDD71\uDD73-\uDD76\uDD7A-\uDDA2\uDDA5-\uDDAA\uDDAE-\uDDCA\uDDCD-\uDDFF\uDE70-\uDE73\uDE78-\uDE7A\uDE80-\uDE82\uDE90-\uDE95])|(?:[#\*0-9\xA9\xAE\u203C\u2049\u2122\u2139\u2194-\u2199\u21A9\u21AA\u231A\u231B\u2328\u23CF\u23E9-\u23F3\u23F8-\u23FA\u24C2\u25AA\u25AB\u25B6\u25C0\u25FB-\u25FE\u2600-\u2604\u260E\u2611\u2614\u2615\u2618\u261D\u2620\u2622\u2623\u2626\u262A\u262E\u262F\u2638-\u263A\u2640\u2642\u2648-\u2653\u265F\u2660\u2663\u2665\u2666\u2668\u267B\u267E\u267F\u2692-\u2697\u2699\u269B\u269C\u26A0\u26A1\u26AA\u26AB\u26B0\u26B1\u26BD\u26BE\u26C4\u26C5\u26C8\u26CE\u26CF\u26D1\u26D3\u26D4\u26E9\u26EA\u26F0-\u26F5\u26F7-\u26FA\u26FD\u2702\u2705\u2708-\u270D\u270F\u2712\u2714\u2716\u271D\u2721\u2728\u2733\u2734\u2744\u2747\u274C\u274E\u2753-\u2755\u2757\u2763\u2764\u2795-\u2797\u27A1\u27B0\u27BF\u2934\u2935\u2B05-\u2B07\u2B1B\u2B1C\u2B50\u2B55\u3030\u303D\u3297\u3299]|\uD83C[\uDC04\uDCCF\uDD70\uDD71\uDD7E\uDD7F\uDD8E\uDD91-\uDD9A\uDDE6-\uDDFF\uDE01\uDE02\uDE1A\uDE2F\uDE32-\uDE3A\uDE50\uDE51\uDF00-\uDF21\uDF24-\uDF93\uDF96\uDF97\uDF99-\uDF9B\uDF9E-\uDFF0\uDFF3-\uDFF5\uDFF7-\uDFFF]|\uD83D[\uDC00-\uDCFD\uDCFF-\uDD3D\uDD49-\uDD4E\uDD50-\uDD67\uDD6F\uDD70\uDD73-\uDD7A\uDD87\uDD8A-\uDD8D\uDD90\uDD95\uDD96\uDDA4\uDDA5\uDDA8\uDDB1\uDDB2\uDDBC\uDDC2-\uDDC4\uDDD1-\uDDD3\uDDDC-\uDDDE\uDDE1\uDDE3\uDDE8\uDDEF\uDDF3\uDDFA-\uDE4F\uDE80-\uDEC5\uDECB-\uDED2\uDED5\uDEE0-\uDEE5\uDEE9\uDEEB\uDEEC\uDEF0\uDEF3-\uDEFA\uDFE0-\uDFEB]|\uD83E[\uDD0D-\uDD3A\uDD3C-\uDD45\uDD47-\uDD71\uDD73-\uDD76\uDD7A-\uDDA2\uDDA5-\uDDAA\uDDAE-\uDDCA\uDDCD-\uDDFF\uDE70-\uDE73\uDE78-\uDE7A\uDE80-\uDE82\uDE90-\uDE95])\uFE0F|(?:[\u261D\u26F9\u270A-\u270D]|\uD83C[\uDF85\uDFC2-\uDFC4\uDFC7\uDFCA-\uDFCC]|\uD83D[\uDC42\uDC43\uDC46-\uDC50\uDC66-\uDC78\uDC7C\uDC81-\uDC83\uDC85-\uDC87\uDC8F\uDC91\uDCAA\uDD74\uDD75\uDD7A\uDD90\uDD95\uDD96\uDE45-\uDE47\uDE4B-\uDE4F\uDEA3\uDEB4-\uDEB6\uDEC0\uDECC]|\uD83E[\uDD0F\uDD18-\uDD1F\uDD26\uDD30-\uDD39\uDD3C-\uDD3E\uDDB5\uDDB6\uDDB8\uDDB9\uDDBB\uDDCD-\uDDCF\uDDD1-\uDDDD])/g;
    };
},
/* wrap-ansi/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const stringWidth = require(6) /* string-width */;
    const stripAnsi = require(7) /* strip-ansi */;
    const ansiStyles = require(12) /* ansi-styles */;
    const ESCAPES = new Set([
        '\u001B',
        '\u009B'
    ]);
    const END_CODE = 39;
    const ANSI_ESCAPE_BELL = '\u0007';
    const ANSI_CSI = '[';
    const ANSI_OSC = ']';
    const ANSI_SGR_TERMINATOR = 'm';
    const ANSI_ESCAPE_LINK = `${ANSI_OSC}8;;`;
    const wrapAnsi = code => `${ESCAPES.values().next().value}${ANSI_CSI}${code}${ANSI_SGR_TERMINATOR}`;
    const wrapAnsiHyperlink = uri => `${ESCAPES.values().next().value}${ANSI_ESCAPE_LINK}${uri}${ANSI_ESCAPE_BELL}`;
    // Calculate the length of words split on ' ', ignoring
    // the extra characters added by ansi escape codes
    const wordLengths = string => string.split(' ').map(character => stringWidth(character));
    // Wrap a long word across multiple rows
    // Ansi escape codes do not count towards length
    const wrapWord = (rows, word, columns) => {
        const characters = [...word];
        let isInsideEscape = false;
        let isInsideLinkEscape = false;
        let visible = stringWidth(stripAnsi(rows[rows.length - 1]));
        for (const [index, character] of characters.entries()) {
            const characterLength = stringWidth(character);
            if (visible + characterLength <= columns) {
                rows[rows.length - 1] += character;
            }
            else {
                rows.push(character);
                visible = 0;
            }
            if (ESCAPES.has(character)) {
                isInsideEscape = true;
                isInsideLinkEscape = characters.slice(index + 1).join('').startsWith(ANSI_ESCAPE_LINK);
            }
            if (isInsideEscape) {
                if (isInsideLinkEscape) {
                    if (character === ANSI_ESCAPE_BELL) {
                        isInsideEscape = false;
                        isInsideLinkEscape = false;
                    }
                }
                else if (character === ANSI_SGR_TERMINATOR) {
                    isInsideEscape = false;
                }
                continue;
            }
            visible += characterLength;
            if (visible === columns && index < characters.length - 1) {
                rows.push('');
                visible = 0;
            }
        }
        // It's possible that the last row we copy over is only
        // ansi escape characters, handle this edge-case
        if (!visible && rows[rows.length - 1].length > 0 && rows.length > 1) {
            rows[rows.length - 2] += rows.pop();
        }
    };
    // Trims spaces from a string ignoring invisible sequences
    const stringVisibleTrimSpacesRight = string => {
        const words = string.split(' ');
        let last = words.length;
        while (last > 0) {
            if (stringWidth(words[last - 1]) > 0) {
                break;
            }
            last--;
        }
        if (last === words.length) {
            return string;
        }
        return words.slice(0, last).join(' ') + words.slice(last).join('');
    };
    // The wrap-ansi module can be invoked in either 'hard' or 'soft' wrap mode
    //
    // 'hard' will never allow a string to take up more than columns characters
    //
    // 'soft' allows long words to expand past the column length
    const exec = (string, columns, options = {}) => {
        if (options.trim !== false && string.trim() === '') {
            return '';
        }
        let returnValue = '';
        let escapeCode;
        let escapeUrl;
        const lengths = wordLengths(string);
        let rows = [''];
        for (const [index, word] of string.split(' ').entries()) {
            if (options.trim !== false) {
                rows[rows.length - 1] = rows[rows.length - 1].trimStart();
            }
            let rowLength = stringWidth(rows[rows.length - 1]);
            if (index !== 0) {
                if (rowLength >= columns && (options.wordWrap === false || options.trim === false)) {
                    // If we start with a new word but the current row length equals the length of the columns, add a new row
                    rows.push('');
                    rowLength = 0;
                }
                if (rowLength > 0 || options.trim === false) {
                    rows[rows.length - 1] += ' ';
                    rowLength++;
                }
            }
            // In 'hard' wrap mode, the length of a line is never allowed to extend past 'columns'
            if (options.hard && lengths[index] > columns) {
                const remainingColumns = (columns - rowLength);
                const breaksStartingThisLine = 1 + Math.floor((lengths[index] - remainingColumns - 1) / columns);
                const breaksStartingNextLine = Math.floor((lengths[index] - 1) / columns);
                if (breaksStartingNextLine < breaksStartingThisLine) {
                    rows.push('');
                }
                wrapWord(rows, word, columns);
                continue;
            }
            if (rowLength + lengths[index] > columns && rowLength > 0 && lengths[index] > 0) {
                if (options.wordWrap === false && rowLength < columns) {
                    wrapWord(rows, word, columns);
                    continue;
                }
                rows.push('');
            }
            if (rowLength + lengths[index] > columns && options.wordWrap === false) {
                wrapWord(rows, word, columns);
                continue;
            }
            rows[rows.length - 1] += word;
        }
        if (options.trim !== false) {
            rows = rows.map(stringVisibleTrimSpacesRight);
        }
        const pre = [...rows.join('\n')];
        for (const [index, character] of pre.entries()) {
            returnValue += character;
            if (ESCAPES.has(character)) {
                const { groups } = new RegExp(`(?:\\${ANSI_CSI}(?<code>\\d+)m|\\${ANSI_ESCAPE_LINK}(?<uri>.*)${ANSI_ESCAPE_BELL})`).exec(pre.slice(index).join('')) || { groups: {} };
                if (groups.code !== undefined) {
                    const code = Number.parseFloat(groups.code);
                    escapeCode = code === END_CODE ? undefined : code;
                }
                else if (groups.uri !== undefined) {
                    escapeUrl = groups.uri.length === 0 ? undefined : groups.uri;
                }
            }
            const code = ansiStyles.codes.get(Number(escapeCode));
            if (pre[index + 1] === '\n') {
                if (escapeUrl) {
                    returnValue += wrapAnsiHyperlink('');
                }
                if (escapeCode && code) {
                    returnValue += wrapAnsi(code);
                }
            }
            else if (character === '\n') {
                if (escapeCode && code) {
                    returnValue += wrapAnsi(escapeCode);
                }
                if (escapeUrl) {
                    returnValue += wrapAnsiHyperlink(escapeUrl);
                }
            }
        }
        return returnValue;
    };
    // For each newline, invoke the method separately
    module.exports = (string, columns, options) => {
        return String(string)
            .normalize()
            .replace(/\r\n/g, '\n')
            .split('\n')
            .map(line => exec(line, columns, options))
            .join('\n');
    };
},
/* ansi-styles/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const wrapAnsi16 = (fn, offset) => (...args) => {
        const code = fn(...args);
        return `\u001B[${code + offset}m`;
    };
    const wrapAnsi256 = (fn, offset) => (...args) => {
        const code = fn(...args);
        return `\u001B[${38 + offset};5;${code}m`;
    };
    const wrapAnsi16m = (fn, offset) => (...args) => {
        const rgb = fn(...args);
        return `\u001B[${38 + offset};2;${rgb[0]};${rgb[1]};${rgb[2]}m`;
    };
    const ansi2ansi = n => n;
    const rgb2rgb = (r, g, b) => [r, g, b];
    const setLazyProperty = (object, property, get) => {
        Object.defineProperty(object, property, {
            get: () => {
                const value = get();
                Object.defineProperty(object, property, {
                    value,
                    enumerable: true,
                    configurable: true
                });
                return value;
            },
            enumerable: true,
            configurable: true
        });
    };
    /** @type {typeof import('color-convert')} */
    let colorConvert;
    const makeDynamicStyles = (wrap, targetSpace, identity, isBackground) => {
        if (colorConvert === undefined) {
            colorConvert = require(13) /* color-convert */;
        }
        const offset = isBackground ? 10 : 0;
        const styles = {};
        for (const [sourceSpace, suite] of Object.entries(colorConvert)) {
            const name = sourceSpace === 'ansi16' ? 'ansi' : sourceSpace;
            if (sourceSpace === targetSpace) {
                styles[name] = wrap(identity, offset);
            }
            else if (typeof suite === 'object') {
                styles[name] = wrap(suite[targetSpace], offset);
            }
        }
        return styles;
    };
    function assembleStyles() {
        const codes = new Map();
        const styles = {
            modifier: {
                reset: [0, 0],
                // 21 isn't widely supported and 22 does the same thing
                bold: [1, 22],
                dim: [2, 22],
                italic: [3, 23],
                underline: [4, 24],
                inverse: [7, 27],
                hidden: [8, 28],
                strikethrough: [9, 29]
            },
            color: {
                black: [30, 39],
                red: [31, 39],
                green: [32, 39],
                yellow: [33, 39],
                blue: [34, 39],
                magenta: [35, 39],
                cyan: [36, 39],
                white: [37, 39],
                // Bright color
                blackBright: [90, 39],
                redBright: [91, 39],
                greenBright: [92, 39],
                yellowBright: [93, 39],
                blueBright: [94, 39],
                magentaBright: [95, 39],
                cyanBright: [96, 39],
                whiteBright: [97, 39]
            },
            bgColor: {
                bgBlack: [40, 49],
                bgRed: [41, 49],
                bgGreen: [42, 49],
                bgYellow: [43, 49],
                bgBlue: [44, 49],
                bgMagenta: [45, 49],
                bgCyan: [46, 49],
                bgWhite: [47, 49],
                // Bright color
                bgBlackBright: [100, 49],
                bgRedBright: [101, 49],
                bgGreenBright: [102, 49],
                bgYellowBright: [103, 49],
                bgBlueBright: [104, 49],
                bgMagentaBright: [105, 49],
                bgCyanBright: [106, 49],
                bgWhiteBright: [107, 49]
            }
        };
        // Alias bright black as gray (and grey)
        styles.color.gray = styles.color.blackBright;
        styles.bgColor.bgGray = styles.bgColor.bgBlackBright;
        styles.color.grey = styles.color.blackBright;
        styles.bgColor.bgGrey = styles.bgColor.bgBlackBright;
        for (const [groupName, group] of Object.entries(styles)) {
            for (const [styleName, style] of Object.entries(group)) {
                styles[styleName] = {
                    open: `\u001B[${style[0]}m`,
                    close: `\u001B[${style[1]}m`
                };
                group[styleName] = styles[styleName];
                codes.set(style[0], style[1]);
            }
            Object.defineProperty(styles, groupName, {
                value: group,
                enumerable: false
            });
        }
        Object.defineProperty(styles, 'codes', {
            value: codes,
            enumerable: false
        });
        styles.color.close = '\u001B[39m';
        styles.bgColor.close = '\u001B[49m';
        setLazyProperty(styles.color, 'ansi', () => makeDynamicStyles(wrapAnsi16, 'ansi16', ansi2ansi, false));
        setLazyProperty(styles.color, 'ansi256', () => makeDynamicStyles(wrapAnsi256, 'ansi256', ansi2ansi, false));
        setLazyProperty(styles.color, 'ansi16m', () => makeDynamicStyles(wrapAnsi16m, 'rgb', rgb2rgb, false));
        setLazyProperty(styles.bgColor, 'ansi', () => makeDynamicStyles(wrapAnsi16, 'ansi16', ansi2ansi, true));
        setLazyProperty(styles.bgColor, 'ansi256', () => makeDynamicStyles(wrapAnsi256, 'ansi256', ansi2ansi, true));
        setLazyProperty(styles.bgColor, 'ansi16m', () => makeDynamicStyles(wrapAnsi16m, 'rgb', rgb2rgb, true));
        return styles;
    }
    // Make the export immutable
    Object.defineProperty(module, 'exports', {
        enumerable: true,
        get: assembleStyles
    });
},
/* color-convert/index.js */ function _(require, module, exports, __esModule, __esExport) {
    const conversions = require(14) /* ./conversions */;
    const route = require(16) /* ./route */;
    const convert = {};
    const models = Object.keys(conversions);
    function wrapRaw(fn) {
        const wrappedFn = function (...args) {
            const arg0 = args[0];
            if (arg0 === undefined || arg0 === null) {
                return arg0;
            }
            if (arg0.length > 1) {
                args = arg0;
            }
            return fn(args);
        };
        // Preserve .conversion property if there is one
        if ('conversion' in fn) {
            wrappedFn.conversion = fn.conversion;
        }
        return wrappedFn;
    }
    function wrapRounded(fn) {
        const wrappedFn = function (...args) {
            const arg0 = args[0];
            if (arg0 === undefined || arg0 === null) {
                return arg0;
            }
            if (arg0.length > 1) {
                args = arg0;
            }
            const result = fn(args);
            // We're assuming the result is an array here.
            // see notice in conversions.js; don't use box types
            // in conversion functions.
            if (typeof result === 'object') {
                for (let len = result.length, i = 0; i < len; i++) {
                    result[i] = Math.round(result[i]);
                }
            }
            return result;
        };
        // Preserve .conversion property if there is one
        if ('conversion' in fn) {
            wrappedFn.conversion = fn.conversion;
        }
        return wrappedFn;
    }
    models.forEach(fromModel => {
        convert[fromModel] = {};
        Object.defineProperty(convert[fromModel], 'channels', { value: conversions[fromModel].channels });
        Object.defineProperty(convert[fromModel], 'labels', { value: conversions[fromModel].labels });
        const routes = route(fromModel);
        const routeModels = Object.keys(routes);
        routeModels.forEach(toModel => {
            const fn = routes[toModel];
            convert[fromModel][toModel] = wrapRounded(fn);
            convert[fromModel][toModel].raw = wrapRaw(fn);
        });
    });
    module.exports = convert;
},
/* color-convert/conversions.js */ function _(require, module, exports, __esModule, __esExport) {
    /* MIT license */
    /* eslint-disable no-mixed-operators */
    const cssKeywords = require(15) /* color-name */;
    // NOTE: conversions should only return primitive values (i.e. arrays, or
    //       values that give correct `typeof` results).
    //       do not use box values types (i.e. Number(), String(), etc.)
    const reverseKeywords = {};
    for (const key of Object.keys(cssKeywords)) {
        reverseKeywords[cssKeywords[key]] = key;
    }
    const convert = {
        rgb: { channels: 3, labels: 'rgb' },
        hsl: { channels: 3, labels: 'hsl' },
        hsv: { channels: 3, labels: 'hsv' },
        hwb: { channels: 3, labels: 'hwb' },
        cmyk: { channels: 4, labels: 'cmyk' },
        xyz: { channels: 3, labels: 'xyz' },
        lab: { channels: 3, labels: 'lab' },
        lch: { channels: 3, labels: 'lch' },
        hex: { channels: 1, labels: ['hex'] },
        keyword: { channels: 1, labels: ['keyword'] },
        ansi16: { channels: 1, labels: ['ansi16'] },
        ansi256: { channels: 1, labels: ['ansi256'] },
        hcg: { channels: 3, labels: ['h', 'c', 'g'] },
        apple: { channels: 3, labels: ['r16', 'g16', 'b16'] },
        gray: { channels: 1, labels: ['gray'] }
    };
    module.exports = convert;
    // Hide .channels and .labels properties
    for (const model of Object.keys(convert)) {
        if (!('channels' in convert[model])) {
            throw new Error('missing channels property: ' + model);
        }
        if (!('labels' in convert[model])) {
            throw new Error('missing channel labels property: ' + model);
        }
        if (convert[model].labels.length !== convert[model].channels) {
            throw new Error('channel and label counts mismatch: ' + model);
        }
        const { channels, labels } = convert[model];
        delete convert[model].channels;
        delete convert[model].labels;
        Object.defineProperty(convert[model], 'channels', { value: channels });
        Object.defineProperty(convert[model], 'labels', { value: labels });
    }
    convert.rgb.hsl = function (rgb) {
        const r = rgb[0] / 255;
        const g = rgb[1] / 255;
        const b = rgb[2] / 255;
        const min = Math.min(r, g, b);
        const max = Math.max(r, g, b);
        const delta = max - min;
        let h;
        let s;
        if (max === min) {
            h = 0;
        }
        else if (r === max) {
            h = (g - b) / delta;
        }
        else if (g === max) {
            h = 2 + (b - r) / delta;
        }
        else if (b === max) {
            h = 4 + (r - g) / delta;
        }
        h = Math.min(h * 60, 360);
        if (h < 0) {
            h += 360;
        }
        const l = (min + max) / 2;
        if (max === min) {
            s = 0;
        }
        else if (l <= 0.5) {
            s = delta / (max + min);
        }
        else {
            s = delta / (2 - max - min);
        }
        return [h, s * 100, l * 100];
    };
    convert.rgb.hsv = function (rgb) {
        let rdif;
        let gdif;
        let bdif;
        let h;
        let s;
        const r = rgb[0] / 255;
        const g = rgb[1] / 255;
        const b = rgb[2] / 255;
        const v = Math.max(r, g, b);
        const diff = v - Math.min(r, g, b);
        const diffc = function (c) {
            return (v - c) / 6 / diff + 1 / 2;
        };
        if (diff === 0) {
            h = 0;
            s = 0;
        }
        else {
            s = diff / v;
            rdif = diffc(r);
            gdif = diffc(g);
            bdif = diffc(b);
            if (r === v) {
                h = bdif - gdif;
            }
            else if (g === v) {
                h = (1 / 3) + rdif - bdif;
            }
            else if (b === v) {
                h = (2 / 3) + gdif - rdif;
            }
            if (h < 0) {
                h += 1;
            }
            else if (h > 1) {
                h -= 1;
            }
        }
        return [
            h * 360,
            s * 100,
            v * 100
        ];
    };
    convert.rgb.hwb = function (rgb) {
        const r = rgb[0];
        const g = rgb[1];
        let b = rgb[2];
        const h = convert.rgb.hsl(rgb)[0];
        const w = 1 / 255 * Math.min(r, Math.min(g, b));
        b = 1 - 1 / 255 * Math.max(r, Math.max(g, b));
        return [h, w * 100, b * 100];
    };
    convert.rgb.cmyk = function (rgb) {
        const r = rgb[0] / 255;
        const g = rgb[1] / 255;
        const b = rgb[2] / 255;
        const k = Math.min(1 - r, 1 - g, 1 - b);
        const c = (1 - r - k) / (1 - k) || 0;
        const m = (1 - g - k) / (1 - k) || 0;
        const y = (1 - b - k) / (1 - k) || 0;
        return [c * 100, m * 100, y * 100, k * 100];
    };
    function comparativeDistance(x, y) {
        /*
            See https://en.m.wikipedia.org/wiki/Euclidean_distance#Squared_Euclidean_distance
        */
        return (((x[0] - y[0]) ** 2) +
            ((x[1] - y[1]) ** 2) +
            ((x[2] - y[2]) ** 2));
    }
    convert.rgb.keyword = function (rgb) {
        const reversed = reverseKeywords[rgb];
        if (reversed) {
            return reversed;
        }
        let currentClosestDistance = Infinity;
        let currentClosestKeyword;
        for (const keyword of Object.keys(cssKeywords)) {
            const value = cssKeywords[keyword];
            // Compute comparative distance
            const distance = comparativeDistance(rgb, value);
            // Check if its less, if so set as closest
            if (distance < currentClosestDistance) {
                currentClosestDistance = distance;
                currentClosestKeyword = keyword;
            }
        }
        return currentClosestKeyword;
    };
    convert.keyword.rgb = function (keyword) {
        return cssKeywords[keyword];
    };
    convert.rgb.xyz = function (rgb) {
        let r = rgb[0] / 255;
        let g = rgb[1] / 255;
        let b = rgb[2] / 255;
        // Assume sRGB
        r = r > 0.04045 ? (((r + 0.055) / 1.055) ** 2.4) : (r / 12.92);
        g = g > 0.04045 ? (((g + 0.055) / 1.055) ** 2.4) : (g / 12.92);
        b = b > 0.04045 ? (((b + 0.055) / 1.055) ** 2.4) : (b / 12.92);
        const x = (r * 0.4124) + (g * 0.3576) + (b * 0.1805);
        const y = (r * 0.2126) + (g * 0.7152) + (b * 0.0722);
        const z = (r * 0.0193) + (g * 0.1192) + (b * 0.9505);
        return [x * 100, y * 100, z * 100];
    };
    convert.rgb.lab = function (rgb) {
        const xyz = convert.rgb.xyz(rgb);
        let x = xyz[0];
        let y = xyz[1];
        let z = xyz[2];
        x /= 95.047;
        y /= 100;
        z /= 108.883;
        x = x > 0.008856 ? (x ** (1 / 3)) : (7.787 * x) + (16 / 116);
        y = y > 0.008856 ? (y ** (1 / 3)) : (7.787 * y) + (16 / 116);
        z = z > 0.008856 ? (z ** (1 / 3)) : (7.787 * z) + (16 / 116);
        const l = (116 * y) - 16;
        const a = 500 * (x - y);
        const b = 200 * (y - z);
        return [l, a, b];
    };
    convert.hsl.rgb = function (hsl) {
        const h = hsl[0] / 360;
        const s = hsl[1] / 100;
        const l = hsl[2] / 100;
        let t2;
        let t3;
        let val;
        if (s === 0) {
            val = l * 255;
            return [val, val, val];
        }
        if (l < 0.5) {
            t2 = l * (1 + s);
        }
        else {
            t2 = l + s - l * s;
        }
        const t1 = 2 * l - t2;
        const rgb = [0, 0, 0];
        for (let i = 0; i < 3; i++) {
            t3 = h + 1 / 3 * -(i - 1);
            if (t3 < 0) {
                t3++;
            }
            if (t3 > 1) {
                t3--;
            }
            if (6 * t3 < 1) {
                val = t1 + (t2 - t1) * 6 * t3;
            }
            else if (2 * t3 < 1) {
                val = t2;
            }
            else if (3 * t3 < 2) {
                val = t1 + (t2 - t1) * (2 / 3 - t3) * 6;
            }
            else {
                val = t1;
            }
            rgb[i] = val * 255;
        }
        return rgb;
    };
    convert.hsl.hsv = function (hsl) {
        const h = hsl[0];
        let s = hsl[1] / 100;
        let l = hsl[2] / 100;
        let smin = s;
        const lmin = Math.max(l, 0.01);
        l *= 2;
        s *= (l <= 1) ? l : 2 - l;
        smin *= lmin <= 1 ? lmin : 2 - lmin;
        const v = (l + s) / 2;
        const sv = l === 0 ? (2 * smin) / (lmin + smin) : (2 * s) / (l + s);
        return [h, sv * 100, v * 100];
    };
    convert.hsv.rgb = function (hsv) {
        const h = hsv[0] / 60;
        const s = hsv[1] / 100;
        let v = hsv[2] / 100;
        const hi = Math.floor(h) % 6;
        const f = h - Math.floor(h);
        const p = 255 * v * (1 - s);
        const q = 255 * v * (1 - (s * f));
        const t = 255 * v * (1 - (s * (1 - f)));
        v *= 255;
        switch (hi) {
            case 0:
                return [v, t, p];
            case 1:
                return [q, v, p];
            case 2:
                return [p, v, t];
            case 3:
                return [p, q, v];
            case 4:
                return [t, p, v];
            case 5:
                return [v, p, q];
        }
    };
    convert.hsv.hsl = function (hsv) {
        const h = hsv[0];
        const s = hsv[1] / 100;
        const v = hsv[2] / 100;
        const vmin = Math.max(v, 0.01);
        let sl;
        let l;
        l = (2 - s) * v;
        const lmin = (2 - s) * vmin;
        sl = s * vmin;
        sl /= (lmin <= 1) ? lmin : 2 - lmin;
        sl = sl || 0;
        l /= 2;
        return [h, sl * 100, l * 100];
    };
    // http://dev.w3.org/csswg/css-color/#hwb-to-rgb
    convert.hwb.rgb = function (hwb) {
        const h = hwb[0] / 360;
        let wh = hwb[1] / 100;
        let bl = hwb[2] / 100;
        const ratio = wh + bl;
        let f;
        // Wh + bl cant be > 1
        if (ratio > 1) {
            wh /= ratio;
            bl /= ratio;
        }
        const i = Math.floor(6 * h);
        const v = 1 - bl;
        f = 6 * h - i;
        if ((i & 0x01) !== 0) {
            f = 1 - f;
        }
        const n = wh + f * (v - wh); // Linear interpolation
        let r;
        let g;
        let b;
        /* eslint-disable max-statements-per-line,no-multi-spaces */
        switch (i) {
            default:
            case 6:
            case 0:
                r = v;
                g = n;
                b = wh;
                break;
            case 1:
                r = n;
                g = v;
                b = wh;
                break;
            case 2:
                r = wh;
                g = v;
                b = n;
                break;
            case 3:
                r = wh;
                g = n;
                b = v;
                break;
            case 4:
                r = n;
                g = wh;
                b = v;
                break;
            case 5:
                r = v;
                g = wh;
                b = n;
                break;
        }
        /* eslint-enable max-statements-per-line,no-multi-spaces */
        return [r * 255, g * 255, b * 255];
    };
    convert.cmyk.rgb = function (cmyk) {
        const c = cmyk[0] / 100;
        const m = cmyk[1] / 100;
        const y = cmyk[2] / 100;
        const k = cmyk[3] / 100;
        const r = 1 - Math.min(1, c * (1 - k) + k);
        const g = 1 - Math.min(1, m * (1 - k) + k);
        const b = 1 - Math.min(1, y * (1 - k) + k);
        return [r * 255, g * 255, b * 255];
    };
    convert.xyz.rgb = function (xyz) {
        const x = xyz[0] / 100;
        const y = xyz[1] / 100;
        const z = xyz[2] / 100;
        let r;
        let g;
        let b;
        r = (x * 3.2406) + (y * -1.5372) + (z * -0.4986);
        g = (x * -0.9689) + (y * 1.8758) + (z * 0.0415);
        b = (x * 0.0557) + (y * -0.2040) + (z * 1.0570);
        // Assume sRGB
        r = r > 0.0031308
            ? ((1.055 * (r ** (1.0 / 2.4))) - 0.055)
            : r * 12.92;
        g = g > 0.0031308
            ? ((1.055 * (g ** (1.0 / 2.4))) - 0.055)
            : g * 12.92;
        b = b > 0.0031308
            ? ((1.055 * (b ** (1.0 / 2.4))) - 0.055)
            : b * 12.92;
        r = Math.min(Math.max(0, r), 1);
        g = Math.min(Math.max(0, g), 1);
        b = Math.min(Math.max(0, b), 1);
        return [r * 255, g * 255, b * 255];
    };
    convert.xyz.lab = function (xyz) {
        let x = xyz[0];
        let y = xyz[1];
        let z = xyz[2];
        x /= 95.047;
        y /= 100;
        z /= 108.883;
        x = x > 0.008856 ? (x ** (1 / 3)) : (7.787 * x) + (16 / 116);
        y = y > 0.008856 ? (y ** (1 / 3)) : (7.787 * y) + (16 / 116);
        z = z > 0.008856 ? (z ** (1 / 3)) : (7.787 * z) + (16 / 116);
        const l = (116 * y) - 16;
        const a = 500 * (x - y);
        const b = 200 * (y - z);
        return [l, a, b];
    };
    convert.lab.xyz = function (lab) {
        const l = lab[0];
        const a = lab[1];
        const b = lab[2];
        let x;
        let y;
        let z;
        y = (l + 16) / 116;
        x = a / 500 + y;
        z = y - b / 200;
        const y2 = y ** 3;
        const x2 = x ** 3;
        const z2 = z ** 3;
        y = y2 > 0.008856 ? y2 : (y - 16 / 116) / 7.787;
        x = x2 > 0.008856 ? x2 : (x - 16 / 116) / 7.787;
        z = z2 > 0.008856 ? z2 : (z - 16 / 116) / 7.787;
        x *= 95.047;
        y *= 100;
        z *= 108.883;
        return [x, y, z];
    };
    convert.lab.lch = function (lab) {
        const l = lab[0];
        const a = lab[1];
        const b = lab[2];
        let h;
        const hr = Math.atan2(b, a);
        h = hr * 360 / 2 / Math.PI;
        if (h < 0) {
            h += 360;
        }
        const c = Math.sqrt(a * a + b * b);
        return [l, c, h];
    };
    convert.lch.lab = function (lch) {
        const l = lch[0];
        const c = lch[1];
        const h = lch[2];
        const hr = h / 360 * 2 * Math.PI;
        const a = c * Math.cos(hr);
        const b = c * Math.sin(hr);
        return [l, a, b];
    };
    convert.rgb.ansi16 = function (args, saturation = null) {
        const [r, g, b] = args;
        let value = saturation === null ? convert.rgb.hsv(args)[2] : saturation; // Hsv -> ansi16 optimization
        value = Math.round(value / 50);
        if (value === 0) {
            return 30;
        }
        let ansi = 30
            + ((Math.round(b / 255) << 2)
                | (Math.round(g / 255) << 1)
                | Math.round(r / 255));
        if (value === 2) {
            ansi += 60;
        }
        return ansi;
    };
    convert.hsv.ansi16 = function (args) {
        // Optimization here; we already know the value and don't need to get
        // it converted for us.
        return convert.rgb.ansi16(convert.hsv.rgb(args), args[2]);
    };
    convert.rgb.ansi256 = function (args) {
        const r = args[0];
        const g = args[1];
        const b = args[2];
        // We use the extended greyscale palette here, with the exception of
        // black and white. normal palette only has 4 greyscale shades.
        if (r === g && g === b) {
            if (r < 8) {
                return 16;
            }
            if (r > 248) {
                return 231;
            }
            return Math.round(((r - 8) / 247) * 24) + 232;
        }
        const ansi = 16
            + (36 * Math.round(r / 255 * 5))
            + (6 * Math.round(g / 255 * 5))
            + Math.round(b / 255 * 5);
        return ansi;
    };
    convert.ansi16.rgb = function (args) {
        let color = args % 10;
        // Handle greyscale
        if (color === 0 || color === 7) {
            if (args > 50) {
                color += 3.5;
            }
            color = color / 10.5 * 255;
            return [color, color, color];
        }
        const mult = (~~(args > 50) + 1) * 0.5;
        const r = ((color & 1) * mult) * 255;
        const g = (((color >> 1) & 1) * mult) * 255;
        const b = (((color >> 2) & 1) * mult) * 255;
        return [r, g, b];
    };
    convert.ansi256.rgb = function (args) {
        // Handle greyscale
        if (args >= 232) {
            const c = (args - 232) * 10 + 8;
            return [c, c, c];
        }
        args -= 16;
        let rem;
        const r = Math.floor(args / 36) / 5 * 255;
        const g = Math.floor((rem = args % 36) / 6) / 5 * 255;
        const b = (rem % 6) / 5 * 255;
        return [r, g, b];
    };
    convert.rgb.hex = function (args) {
        const integer = ((Math.round(args[0]) & 0xFF) << 16)
            + ((Math.round(args[1]) & 0xFF) << 8)
            + (Math.round(args[2]) & 0xFF);
        const string = integer.toString(16).toUpperCase();
        return '000000'.substring(string.length) + string;
    };
    convert.hex.rgb = function (args) {
        const match = args.toString(16).match(/[a-f0-9]{6}|[a-f0-9]{3}/i);
        if (!match) {
            return [0, 0, 0];
        }
        let colorString = match[0];
        if (match[0].length === 3) {
            colorString = colorString.split('').map(char => {
                return char + char;
            }).join('');
        }
        const integer = parseInt(colorString, 16);
        const r = (integer >> 16) & 0xFF;
        const g = (integer >> 8) & 0xFF;
        const b = integer & 0xFF;
        return [r, g, b];
    };
    convert.rgb.hcg = function (rgb) {
        const r = rgb[0] / 255;
        const g = rgb[1] / 255;
        const b = rgb[2] / 255;
        const max = Math.max(Math.max(r, g), b);
        const min = Math.min(Math.min(r, g), b);
        const chroma = (max - min);
        let grayscale;
        let hue;
        if (chroma < 1) {
            grayscale = min / (1 - chroma);
        }
        else {
            grayscale = 0;
        }
        if (chroma <= 0) {
            hue = 0;
        }
        else if (max === r) {
            hue = ((g - b) / chroma) % 6;
        }
        else if (max === g) {
            hue = 2 + (b - r) / chroma;
        }
        else {
            hue = 4 + (r - g) / chroma;
        }
        hue /= 6;
        hue %= 1;
        return [hue * 360, chroma * 100, grayscale * 100];
    };
    convert.hsl.hcg = function (hsl) {
        const s = hsl[1] / 100;
        const l = hsl[2] / 100;
        const c = l < 0.5 ? (2.0 * s * l) : (2.0 * s * (1.0 - l));
        let f = 0;
        if (c < 1.0) {
            f = (l - 0.5 * c) / (1.0 - c);
        }
        return [hsl[0], c * 100, f * 100];
    };
    convert.hsv.hcg = function (hsv) {
        const s = hsv[1] / 100;
        const v = hsv[2] / 100;
        const c = s * v;
        let f = 0;
        if (c < 1.0) {
            f = (v - c) / (1 - c);
        }
        return [hsv[0], c * 100, f * 100];
    };
    convert.hcg.rgb = function (hcg) {
        const h = hcg[0] / 360;
        const c = hcg[1] / 100;
        const g = hcg[2] / 100;
        if (c === 0.0) {
            return [g * 255, g * 255, g * 255];
        }
        const pure = [0, 0, 0];
        const hi = (h % 1) * 6;
        const v = hi % 1;
        const w = 1 - v;
        let mg = 0;
        /* eslint-disable max-statements-per-line */
        switch (Math.floor(hi)) {
            case 0:
                pure[0] = 1;
                pure[1] = v;
                pure[2] = 0;
                break;
            case 1:
                pure[0] = w;
                pure[1] = 1;
                pure[2] = 0;
                break;
            case 2:
                pure[0] = 0;
                pure[1] = 1;
                pure[2] = v;
                break;
            case 3:
                pure[0] = 0;
                pure[1] = w;
                pure[2] = 1;
                break;
            case 4:
                pure[0] = v;
                pure[1] = 0;
                pure[2] = 1;
                break;
            default:
                pure[0] = 1;
                pure[1] = 0;
                pure[2] = w;
        }
        /* eslint-enable max-statements-per-line */
        mg = (1.0 - c) * g;
        return [
            (c * pure[0] + mg) * 255,
            (c * pure[1] + mg) * 255,
            (c * pure[2] + mg) * 255
        ];
    };
    convert.hcg.hsv = function (hcg) {
        const c = hcg[1] / 100;
        const g = hcg[2] / 100;
        const v = c + g * (1.0 - c);
        let f = 0;
        if (v > 0.0) {
            f = c / v;
        }
        return [hcg[0], f * 100, v * 100];
    };
    convert.hcg.hsl = function (hcg) {
        const c = hcg[1] / 100;
        const g = hcg[2] / 100;
        const l = g * (1.0 - c) + 0.5 * c;
        let s = 0;
        if (l > 0.0 && l < 0.5) {
            s = c / (2 * l);
        }
        else if (l >= 0.5 && l < 1.0) {
            s = c / (2 * (1 - l));
        }
        return [hcg[0], s * 100, l * 100];
    };
    convert.hcg.hwb = function (hcg) {
        const c = hcg[1] / 100;
        const g = hcg[2] / 100;
        const v = c + g * (1.0 - c);
        return [hcg[0], (v - c) * 100, (1 - v) * 100];
    };
    convert.hwb.hcg = function (hwb) {
        const w = hwb[1] / 100;
        const b = hwb[2] / 100;
        const v = 1 - b;
        const c = v - w;
        let g = 0;
        if (c < 1) {
            g = (v - c) / (1 - c);
        }
        return [hwb[0], c * 100, g * 100];
    };
    convert.apple.rgb = function (apple) {
        return [(apple[0] / 65535) * 255, (apple[1] / 65535) * 255, (apple[2] / 65535) * 255];
    };
    convert.rgb.apple = function (rgb) {
        return [(rgb[0] / 255) * 65535, (rgb[1] / 255) * 65535, (rgb[2] / 255) * 65535];
    };
    convert.gray.rgb = function (args) {
        return [args[0] / 100 * 255, args[0] / 100 * 255, args[0] / 100 * 255];
    };
    convert.gray.hsl = function (args) {
        return [0, 0, args[0]];
    };
    convert.gray.hsv = convert.gray.hsl;
    convert.gray.hwb = function (gray) {
        return [0, 100, gray[0]];
    };
    convert.gray.cmyk = function (gray) {
        return [0, 0, 0, gray[0]];
    };
    convert.gray.lab = function (gray) {
        return [gray[0], 0, 0];
    };
    convert.gray.hex = function (gray) {
        const val = Math.round(gray[0] / 100 * 255) & 0xFF;
        const integer = (val << 16) + (val << 8) + val;
        const string = integer.toString(16).toUpperCase();
        return '000000'.substring(string.length) + string;
    };
    convert.rgb.gray = function (rgb) {
        const val = (rgb[0] + rgb[1] + rgb[2]) / 3;
        return [val / 255 * 100];
    };
},
/* color-name/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = {
        "aliceblue": [240, 248, 255],
        "antiquewhite": [250, 235, 215],
        "aqua": [0, 255, 255],
        "aquamarine": [127, 255, 212],
        "azure": [240, 255, 255],
        "beige": [245, 245, 220],
        "bisque": [255, 228, 196],
        "black": [0, 0, 0],
        "blanchedalmond": [255, 235, 205],
        "blue": [0, 0, 255],
        "blueviolet": [138, 43, 226],
        "brown": [165, 42, 42],
        "burlywood": [222, 184, 135],
        "cadetblue": [95, 158, 160],
        "chartreuse": [127, 255, 0],
        "chocolate": [210, 105, 30],
        "coral": [255, 127, 80],
        "cornflowerblue": [100, 149, 237],
        "cornsilk": [255, 248, 220],
        "crimson": [220, 20, 60],
        "cyan": [0, 255, 255],
        "darkblue": [0, 0, 139],
        "darkcyan": [0, 139, 139],
        "darkgoldenrod": [184, 134, 11],
        "darkgray": [169, 169, 169],
        "darkgreen": [0, 100, 0],
        "darkgrey": [169, 169, 169],
        "darkkhaki": [189, 183, 107],
        "darkmagenta": [139, 0, 139],
        "darkolivegreen": [85, 107, 47],
        "darkorange": [255, 140, 0],
        "darkorchid": [153, 50, 204],
        "darkred": [139, 0, 0],
        "darksalmon": [233, 150, 122],
        "darkseagreen": [143, 188, 143],
        "darkslateblue": [72, 61, 139],
        "darkslategray": [47, 79, 79],
        "darkslategrey": [47, 79, 79],
        "darkturquoise": [0, 206, 209],
        "darkviolet": [148, 0, 211],
        "deeppink": [255, 20, 147],
        "deepskyblue": [0, 191, 255],
        "dimgray": [105, 105, 105],
        "dimgrey": [105, 105, 105],
        "dodgerblue": [30, 144, 255],
        "firebrick": [178, 34, 34],
        "floralwhite": [255, 250, 240],
        "forestgreen": [34, 139, 34],
        "fuchsia": [255, 0, 255],
        "gainsboro": [220, 220, 220],
        "ghostwhite": [248, 248, 255],
        "gold": [255, 215, 0],
        "goldenrod": [218, 165, 32],
        "gray": [128, 128, 128],
        "green": [0, 128, 0],
        "greenyellow": [173, 255, 47],
        "grey": [128, 128, 128],
        "honeydew": [240, 255, 240],
        "hotpink": [255, 105, 180],
        "indianred": [205, 92, 92],
        "indigo": [75, 0, 130],
        "ivory": [255, 255, 240],
        "khaki": [240, 230, 140],
        "lavender": [230, 230, 250],
        "lavenderblush": [255, 240, 245],
        "lawngreen": [124, 252, 0],
        "lemonchiffon": [255, 250, 205],
        "lightblue": [173, 216, 230],
        "lightcoral": [240, 128, 128],
        "lightcyan": [224, 255, 255],
        "lightgoldenrodyellow": [250, 250, 210],
        "lightgray": [211, 211, 211],
        "lightgreen": [144, 238, 144],
        "lightgrey": [211, 211, 211],
        "lightpink": [255, 182, 193],
        "lightsalmon": [255, 160, 122],
        "lightseagreen": [32, 178, 170],
        "lightskyblue": [135, 206, 250],
        "lightslategray": [119, 136, 153],
        "lightslategrey": [119, 136, 153],
        "lightsteelblue": [176, 196, 222],
        "lightyellow": [255, 255, 224],
        "lime": [0, 255, 0],
        "limegreen": [50, 205, 50],
        "linen": [250, 240, 230],
        "magenta": [255, 0, 255],
        "maroon": [128, 0, 0],
        "mediumaquamarine": [102, 205, 170],
        "mediumblue": [0, 0, 205],
        "mediumorchid": [186, 85, 211],
        "mediumpurple": [147, 112, 219],
        "mediumseagreen": [60, 179, 113],
        "mediumslateblue": [123, 104, 238],
        "mediumspringgreen": [0, 250, 154],
        "mediumturquoise": [72, 209, 204],
        "mediumvioletred": [199, 21, 133],
        "midnightblue": [25, 25, 112],
        "mintcream": [245, 255, 250],
        "mistyrose": [255, 228, 225],
        "moccasin": [255, 228, 181],
        "navajowhite": [255, 222, 173],
        "navy": [0, 0, 128],
        "oldlace": [253, 245, 230],
        "olive": [128, 128, 0],
        "olivedrab": [107, 142, 35],
        "orange": [255, 165, 0],
        "orangered": [255, 69, 0],
        "orchid": [218, 112, 214],
        "palegoldenrod": [238, 232, 170],
        "palegreen": [152, 251, 152],
        "paleturquoise": [175, 238, 238],
        "palevioletred": [219, 112, 147],
        "papayawhip": [255, 239, 213],
        "peachpuff": [255, 218, 185],
        "peru": [205, 133, 63],
        "pink": [255, 192, 203],
        "plum": [221, 160, 221],
        "powderblue": [176, 224, 230],
        "purple": [128, 0, 128],
        "rebeccapurple": [102, 51, 153],
        "red": [255, 0, 0],
        "rosybrown": [188, 143, 143],
        "royalblue": [65, 105, 225],
        "saddlebrown": [139, 69, 19],
        "salmon": [250, 128, 114],
        "sandybrown": [244, 164, 96],
        "seagreen": [46, 139, 87],
        "seashell": [255, 245, 238],
        "sienna": [160, 82, 45],
        "silver": [192, 192, 192],
        "skyblue": [135, 206, 235],
        "slateblue": [106, 90, 205],
        "slategray": [112, 128, 144],
        "slategrey": [112, 128, 144],
        "snow": [255, 250, 250],
        "springgreen": [0, 255, 127],
        "steelblue": [70, 130, 180],
        "tan": [210, 180, 140],
        "teal": [0, 128, 128],
        "thistle": [216, 191, 216],
        "tomato": [255, 99, 71],
        "turquoise": [64, 224, 208],
        "violet": [238, 130, 238],
        "wheat": [245, 222, 179],
        "white": [255, 255, 255],
        "whitesmoke": [245, 245, 245],
        "yellow": [255, 255, 0],
        "yellowgreen": [154, 205, 50]
    };
},
/* color-convert/route.js */ function _(require, module, exports, __esModule, __esExport) {
    const conversions = require(14) /* ./conversions */;
    /*
        This function routes a model to all other models.
    
        all functions that are routed have a property `.conversion` attached
        to the returned synthetic function. This property is an array
        of strings, each with the steps in between the 'from' and 'to'
        color models (inclusive).
    
        conversions that are not possible simply are not included.
    */
    function buildGraph() {
        const graph = {};
        // https://jsperf.com/object-keys-vs-for-in-with-closure/3
        const models = Object.keys(conversions);
        for (let len = models.length, i = 0; i < len; i++) {
            graph[models[i]] = {
                // http://jsperf.com/1-vs-infinity
                // micro-opt, but this is simple.
                distance: -1,
                parent: null
            };
        }
        return graph;
    }
    // https://en.wikipedia.org/wiki/Breadth-first_search
    function deriveBFS(fromModel) {
        const graph = buildGraph();
        const queue = [fromModel]; // Unshift -> queue -> pop
        graph[fromModel].distance = 0;
        while (queue.length) {
            const current = queue.pop();
            const adjacents = Object.keys(conversions[current]);
            for (let len = adjacents.length, i = 0; i < len; i++) {
                const adjacent = adjacents[i];
                const node = graph[adjacent];
                if (node.distance === -1) {
                    node.distance = graph[current].distance + 1;
                    node.parent = current;
                    queue.unshift(adjacent);
                }
            }
        }
        return graph;
    }
    function link(from, to) {
        return function (args) {
            return to(from(args));
        };
    }
    function wrapConversion(toModel, graph) {
        const path = [graph[toModel].parent, toModel];
        let fn = conversions[graph[toModel].parent][toModel];
        let cur = graph[toModel].parent;
        while (graph[cur].parent) {
            path.unshift(graph[cur].parent);
            fn = link(conversions[graph[cur].parent][cur], fn);
            cur = graph[cur].parent;
        }
        fn.conversion = path;
        return fn;
    }
    module.exports = function (fromModel) {
        const graph = deriveBFS(fromModel);
        const conversion = {};
        const models = Object.keys(graph);
        for (let len = models.length, i = 0; i < len; i++) {
            const toModel = models[i];
            const node = graph[toModel];
            if (node.parent === null) {
                // No possible conversion, or this node is the source model.
                continue;
            }
            conversion[toModel] = wrapConversion(toModel, graph);
        }
        return conversion;
    };
},
/* escalade/sync/index.js */ function _(require, module, exports, __esModule, __esExport) {
    const { dirname, resolve } = require('path');
    const { readdirSync, statSync } = require('fs');
    module.exports = function (start, callback) {
        let dir = resolve('.', start);
        let tmp, stats = statSync(dir);
        if (!stats.isDirectory()) {
            dir = dirname(dir);
        }
        while (true) {
            tmp = callback(dir, readdirSync(dir));
            if (tmp)
                return resolve(dir, tmp);
            dir = dirname(tmp = dir);
            if (tmp === dir)
                break;
        }
    };
},
/* get-caller-file/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // Call this function in a another function to find out the file from
    // which that function was called from. (Inspects the v8 stack trace)
    //
    // Inspired by http://stackoverflow.com/questions/13227489
    module.exports = function getCallerFile(position) {
        if (position === void 0) {
            position = 2;
        }
        if (position >= Error.stackTraceLimit) {
            throw new TypeError('getCallerFile(position) requires position be less then Error.stackTraceLimit but position was: `' + position + '` and Error.stackTraceLimit was: `' + Error.stackTraceLimit + '`');
        }
        var oldPrepareStackTrace = Error.prepareStackTrace;
        Error.prepareStackTrace = function (_, stack) { return stack; };
        var stack = new Error().stack;
        Error.prepareStackTrace = oldPrepareStackTrace;
        if (stack !== null && typeof stack === 'object') {
            // stack[0] holds this file
            // stack[1] holds where this function was called
            // stack[2] holds the file we're interested in
            return stack[position] ? stack[position].getFileName() : undefined;
        }
    };
    
},
/* require-directory/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    var fs = require('fs'), join = require('path').join, resolve = require('path').resolve, dirname = require('path').dirname, defaultOptions = {
        extensions: ['js', 'json', 'coffee'],
        recurse: true,
        rename: function (name) {
            return name;
        },
        visit: function (obj) {
            return obj;
        }
    };
    function checkFileInclusion(path, filename, options) {
        return (
        // verify file has valid extension
        (new RegExp('\\.(' + options.extensions.join('|') + ')$', 'i').test(filename)) &&
            // if options.include is a RegExp, evaluate it and make sure the path passes
            !(options.include && options.include instanceof RegExp && !options.include.test(path)) &&
            // if options.include is a function, evaluate it and make sure the path passes
            !(options.include && typeof options.include === 'function' && !options.include(path, filename)) &&
            // if options.exclude is a RegExp, evaluate it and make sure the path doesn't pass
            !(options.exclude && options.exclude instanceof RegExp && options.exclude.test(path)) &&
            // if options.exclude is a function, evaluate it and make sure the path doesn't pass
            !(options.exclude && typeof options.exclude === 'function' && options.exclude(path, filename)));
    }
    function requireDirectory(m, path, options) {
        var retval = {};
        // path is optional
        if (path && !options && typeof path !== 'string') {
            options = path;
            path = null;
        }
        // default options
        options = options || {};
        for (var prop in defaultOptions) {
            if (typeof options[prop] === 'undefined') {
                options[prop] = defaultOptions[prop];
            }
        }
        // if no path was passed in, assume the equivelant of __dirname from caller
        // otherwise, resolve path relative to the equivalent of __dirname
        path = !path ? dirname(m.filename) : resolve(dirname(m.filename), path);
        // get the path of each file in specified directory, append to current tree node, recurse
        fs.readdirSync(path).forEach(function (filename) {
            var joined = join(path, filename), files, key, obj;
            if (fs.statSync(joined).isDirectory() && options.recurse) {
                // this node is a directory; recurse
                files = requireDirectory(m, joined, options);
                // exclude empty directories
                if (Object.keys(files).length) {
                    retval[options.rename(filename, joined, filename)] = files;
                }
            }
            else {
                if (joined !== m.filename && checkFileInclusion(joined, filename, options)) {
                    // hash node key shouldn't include file extension
                    key = filename.substring(0, filename.lastIndexOf('.'));
                    obj = m.require(joined);
                    retval[options.rename(key, joined, filename)] = options.visit(obj, joined, filename) || obj;
                }
            }
        });
        return retval;
    }
    module.exports = requireDirectory;
    module.exports.defaults = defaultOptions;
},
/* sys.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.read_json = exports.hash_file = exports.hash = exports.rename = exports.directory_exists = exports.file_exists = exports.write = exports.read = exports.glob = exports.scan = void 0;
    const ts = __importStar(require(21) /* typescript */);
    const crypto_1 = __importDefault(require("crypto"));
    const path_1 = require("path");
    function scan(path, extensions, exclude, include, depth) {
        return ts.sys.readDirectory(path, extensions, exclude, include, depth).map((p) => (0, path_1.normalize)(p));
    }
    exports.scan = scan;
    function glob(...patterns) {
        return scan(".", undefined, undefined, patterns);
    }
    exports.glob = glob;
    exports.read = ts.sys.readFile;
    exports.write = ts.sys.writeFile;
    exports.file_exists = ts.sys.fileExists;
    exports.directory_exists = ts.sys.directoryExists;
    function rename(path, options) {
        let { dir, name, ext } = (0, path_1.parse)(path);
        if (options.dir != null) {
            if (options.base != null) {
                dir = dir.replace(options.base, options.dir);
            }
            else {
                dir = options.dir;
            }
        }
        if (options.name != null) {
            name = options.name(name);
        }
        if (options.ext != null) {
            ext = options.ext;
        }
        return (0, path_1.format)({ dir, name, ext });
    }
    exports.rename = rename;
    function hash(data) {
        return crypto_1.default.createHash("sha256").update(data).digest("hex");
    }
    exports.hash = hash;
    function hash_file(path) {
        const contents = (0, exports.read)(path);
        return contents != null ? hash(contents) : null;
    }
    exports.hash_file = hash_file;
    function read_json(path) {
        const data = (0, exports.read)(path);
        if (data == null) {
            return undefined;
        }
        else {
            try {
                return JSON.parse(data);
            }
            catch {
                return undefined;
            }
        }
    }
    exports.read_json = read_json;
    
},
/* typescript/lib/typescript.js */ function _(require, module, exports, __esModule, __esExport) {/*! *****************************************************************************
    Copyright (c) Microsoft Corporation. All rights reserved.
    Licensed under the Apache License, Version 2.0 (the "License"); you may not use
    this file except in compliance with the License. You may obtain a copy of the
    License at http://www.apache.org/licenses/LICENSE-2.0
    
    THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
    WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
    MERCHANTABLITY OR NON-INFRINGEMENT.
    
    See the Apache Version 2.0 License for specific language governing permissions
    and limitations under the License.
    ***************************************************************************** */
    "use strict";
    var ts = (() => {
        var __defProp = Object.defineProperty;
        var __getOwnPropNames = Object.getOwnPropertyNames;
        var __esm = (fn, res) => function __init() {
            return fn && (res = (0, fn[__getOwnPropNames(fn)[0]])(fn = 0)), res;
        };
        var __commonJS = (cb, mod) => function __require() {
            return mod || (0, cb[__getOwnPropNames(cb)[0]])((mod = { exports: {} }).exports, mod), mod.exports;
        };
        var __export = (target, all) => {
            for (var name in all)
                __defProp(target, name, { get: all[name], enumerable: true });
        };
        // src/compiler/corePublic.ts
        var versionMajorMinor, version, Comparison;
        var init_corePublic = __esm({
            "src/compiler/corePublic.ts"() {
                "use strict";
                versionMajorMinor = "5.4";
                version = "5.4.3";
                Comparison = /* @__PURE__ */ ((Comparison3) => {
                    Comparison3[Comparison3["LessThan"] = -1] = "LessThan";
                    Comparison3[Comparison3["EqualTo"] = 0] = "EqualTo";
                    Comparison3[Comparison3["GreaterThan"] = 1] = "GreaterThan";
                    return Comparison3;
                })(Comparison || {});
            }
        });
        // src/compiler/core.ts
        function length(array) {
            return array ? array.length : 0;
        }
        function forEach(array, callback) {
            if (array) {
                for (let i = 0; i < array.length; i++) {
                    const result = callback(array[i], i);
                    if (result) {
                        return result;
                    }
                }
            }
            return void 0;
        }
        function forEachRight(array, callback) {
            if (array) {
                for (let i = array.length - 1; i >= 0; i--) {
                    const result = callback(array[i], i);
                    if (result) {
                        return result;
                    }
                }
            }
            return void 0;
        }
        function firstDefined(array, callback) {
            if (array === void 0) {
                return void 0;
            }
            for (let i = 0; i < array.length; i++) {
                const result = callback(array[i], i);
                if (result !== void 0) {
                    return result;
                }
            }
            return void 0;
        }
        function firstDefinedIterator(iter, callback) {
            for (const value of iter) {
                const result = callback(value);
                if (result !== void 0) {
                    return result;
                }
            }
            return void 0;
        }
        function reduceLeftIterator(iterator, f, initial) {
            let result = initial;
            if (iterator) {
                let pos = 0;
                for (const value of iterator) {
                    result = f(result, value, pos);
                    pos++;
                }
            }
            return result;
        }
        function zipWith(arrayA, arrayB, callback) {
            const result = [];
            Debug.assertEqual(arrayA.length, arrayB.length);
            for (let i = 0; i < arrayA.length; i++) {
                result.push(callback(arrayA[i], arrayB[i], i));
            }
            return result;
        }
        function intersperse(input, element) {
            if (input.length <= 1) {
                return input;
            }
            const result = [];
            for (let i = 0, n = input.length; i < n; i++) {
                if (i)
                    result.push(element);
                result.push(input[i]);
            }
            return result;
        }
        function every(array, callback) {
            if (array) {
                for (let i = 0; i < array.length; i++) {
                    if (!callback(array[i], i)) {
                        return false;
                    }
                }
            }
            return true;
        }
        function find(array, predicate, startIndex) {
            if (array === void 0)
                return void 0;
            for (let i = startIndex ?? 0; i < array.length; i++) {
                const value = array[i];
                if (predicate(value, i)) {
                    return value;
                }
            }
            return void 0;
        }
        function findLast(array, predicate, startIndex) {
            if (array === void 0)
                return void 0;
            for (let i = startIndex ?? array.length - 1; i >= 0; i--) {
                const value = array[i];
                if (predicate(value, i)) {
                    return value;
                }
            }
            return void 0;
        }
        function findIndex(array, predicate, startIndex) {
            if (array === void 0)
                return -1;
            for (let i = startIndex ?? 0; i < array.length; i++) {
                if (predicate(array[i], i)) {
                    return i;
                }
            }
            return -1;
        }
        function findLastIndex(array, predicate, startIndex) {
            if (array === void 0)
                return -1;
            for (let i = startIndex ?? array.length - 1; i >= 0; i--) {
                if (predicate(array[i], i)) {
                    return i;
                }
            }
            return -1;
        }
        function findMap(array, callback) {
            for (let i = 0; i < array.length; i++) {
                const result = callback(array[i], i);
                if (result) {
                    return result;
                }
            }
            return Debug.fail();
        }
        function contains(array, value, equalityComparer = equateValues) {
            if (array) {
                for (const v of array) {
                    if (equalityComparer(v, value)) {
                        return true;
                    }
                }
            }
            return false;
        }
        function arraysEqual(a, b, equalityComparer = equateValues) {
            return a.length === b.length && a.every((x, i) => equalityComparer(x, b[i]));
        }
        function indexOfAnyCharCode(text, charCodes, start) {
            for (let i = start || 0; i < text.length; i++) {
                if (contains(charCodes, text.charCodeAt(i))) {
                    return i;
                }
            }
            return -1;
        }
        function countWhere(array, predicate) {
            let count = 0;
            if (array) {
                for (let i = 0; i < array.length; i++) {
                    const v = array[i];
                    if (predicate(v, i)) {
                        count++;
                    }
                }
            }
            return count;
        }
        function filter(array, f) {
            if (array) {
                const len = array.length;
                let i = 0;
                while (i < len && f(array[i]))
                    i++;
                if (i < len) {
                    const result = array.slice(0, i);
                    i++;
                    while (i < len) {
                        const item = array[i];
                        if (f(item)) {
                            result.push(item);
                        }
                        i++;
                    }
                    return result;
                }
            }
            return array;
        }
        function filterMutate(array, f) {
            let outIndex = 0;
            for (let i = 0; i < array.length; i++) {
                if (f(array[i], i, array)) {
                    array[outIndex] = array[i];
                    outIndex++;
                }
            }
            array.length = outIndex;
        }
        function clear(array) {
            array.length = 0;
        }
        function map(array, f) {
            let result;
            if (array) {
                result = [];
                for (let i = 0; i < array.length; i++) {
                    result.push(f(array[i], i));
                }
            }
            return result;
        }
        function* mapIterator(iter, mapFn) {
            for (const x of iter) {
                yield mapFn(x);
            }
        }
        function sameMap(array, f) {
            if (array) {
                for (let i = 0; i < array.length; i++) {
                    const item = array[i];
                    const mapped = f(item, i);
                    if (item !== mapped) {
                        const result = array.slice(0, i);
                        result.push(mapped);
                        for (i++; i < array.length; i++) {
                            result.push(f(array[i], i));
                        }
                        return result;
                    }
                }
            }
            return array;
        }
        function flatten(array) {
            const result = [];
            for (const v of array) {
                if (v) {
                    if (isArray(v)) {
                        addRange(result, v);
                    }
                    else {
                        result.push(v);
                    }
                }
            }
            return result;
        }
        function flatMap(array, mapfn) {
            let result;
            if (array) {
                for (let i = 0; i < array.length; i++) {
                    const v = mapfn(array[i], i);
                    if (v) {
                        if (isArray(v)) {
                            result = addRange(result, v);
                        }
                        else {
                            result = append(result, v);
                        }
                    }
                }
            }
            return result || emptyArray;
        }
        function flatMapToMutable(array, mapfn) {
            const result = [];
            if (array) {
                for (let i = 0; i < array.length; i++) {
                    const v = mapfn(array[i], i);
                    if (v) {
                        if (isArray(v)) {
                            addRange(result, v);
                        }
                        else {
                            result.push(v);
                        }
                    }
                }
            }
            return result;
        }
        function* flatMapIterator(iter, mapfn) {
            for (const x of iter) {
                const iter2 = mapfn(x);
                if (!iter2)
                    continue;
                yield* iter2;
            }
        }
        function sameFlatMap(array, mapfn) {
            let result;
            if (array) {
                for (let i = 0; i < array.length; i++) {
                    const item = array[i];
                    const mapped = mapfn(item, i);
                    if (result || item !== mapped || isArray(mapped)) {
                        if (!result) {
                            result = array.slice(0, i);
                        }
                        if (isArray(mapped)) {
                            addRange(result, mapped);
                        }
                        else {
                            result.push(mapped);
                        }
                    }
                }
            }
            return result || array;
        }
        function mapAllOrFail(array, mapFn) {
            const result = [];
            for (let i = 0; i < array.length; i++) {
                const mapped = mapFn(array[i], i);
                if (mapped === void 0) {
                    return void 0;
                }
                result.push(mapped);
            }
            return result;
        }
        function mapDefined(array, mapFn) {
            const result = [];
            if (array) {
                for (let i = 0; i < array.length; i++) {
                    const mapped = mapFn(array[i], i);
                    if (mapped !== void 0) {
                        result.push(mapped);
                    }
                }
            }
            return result;
        }
        function* mapDefinedIterator(iter, mapFn) {
            for (const x of iter) {
                const value = mapFn(x);
                if (value !== void 0) {
                    yield value;
                }
            }
        }
        function mapDefinedEntries(map2, f) {
            if (!map2) {
                return void 0;
            }
            const result = /* @__PURE__ */ new Map();
            map2.forEach((value, key) => {
                const entry = f(key, value);
                if (entry !== void 0) {
                    const [newKey, newValue] = entry;
                    if (newKey !== void 0 && newValue !== void 0) {
                        result.set(newKey, newValue);
                    }
                }
            });
            return result;
        }
        function getOrUpdate(map2, key, callback) {
            if (map2.has(key)) {
                return map2.get(key);
            }
            const value = callback();
            map2.set(key, value);
            return value;
        }
        function tryAddToSet(set, value) {
            if (!set.has(value)) {
                set.add(value);
                return true;
            }
            return false;
        }
        function* singleIterator(value) {
            yield value;
        }
        function spanMap(array, keyfn, mapfn) {
            let result;
            if (array) {
                result = [];
                const len = array.length;
                let previousKey;
                let key;
                let start = 0;
                let pos = 0;
                while (start < len) {
                    while (pos < len) {
                        const value = array[pos];
                        key = keyfn(value, pos);
                        if (pos === 0) {
                            previousKey = key;
                        }
                        else if (key !== previousKey) {
                            break;
                        }
                        pos++;
                    }
                    if (start < pos) {
                        const v = mapfn(array.slice(start, pos), previousKey, start, pos);
                        if (v) {
                            result.push(v);
                        }
                        start = pos;
                    }
                    previousKey = key;
                    pos++;
                }
            }
            return result;
        }
        function mapEntries(map2, f) {
            if (!map2) {
                return void 0;
            }
            const result = /* @__PURE__ */ new Map();
            map2.forEach((value, key) => {
                const [newKey, newValue] = f(key, value);
                result.set(newKey, newValue);
            });
            return result;
        }
        function some(array, predicate) {
            if (array) {
                if (predicate) {
                    for (const v of array) {
                        if (predicate(v)) {
                            return true;
                        }
                    }
                }
                else {
                    return array.length > 0;
                }
            }
            return false;
        }
        function getRangesWhere(arr, pred, cb) {
            let start;
            for (let i = 0; i < arr.length; i++) {
                if (pred(arr[i])) {
                    start = start === void 0 ? i : start;
                }
                else {
                    if (start !== void 0) {
                        cb(start, i);
                        start = void 0;
                    }
                }
            }
            if (start !== void 0)
                cb(start, arr.length);
        }
        function concatenate(array1, array2) {
            if (!some(array2))
                return array1;
            if (!some(array1))
                return array2;
            return [...array1, ...array2];
        }
        function selectIndex(_, i) {
            return i;
        }
        function indicesOf(array) {
            return array.map(selectIndex);
        }
        function deduplicateRelational(array, equalityComparer, comparer) {
            const indices = indicesOf(array);
            stableSortIndices(array, indices, comparer);
            let last2 = array[indices[0]];
            const deduplicated = [indices[0]];
            for (let i = 1; i < indices.length; i++) {
                const index = indices[i];
                const item = array[index];
                if (!equalityComparer(last2, item)) {
                    deduplicated.push(index);
                    last2 = item;
                }
            }
            deduplicated.sort();
            return deduplicated.map((i) => array[i]);
        }
        function deduplicateEquality(array, equalityComparer) {
            const result = [];
            for (const item of array) {
                pushIfUnique(result, item, equalityComparer);
            }
            return result;
        }
        function deduplicate(array, equalityComparer, comparer) {
            return array.length === 0 ? [] : array.length === 1 ? array.slice() : comparer ? deduplicateRelational(array, equalityComparer, comparer) : deduplicateEquality(array, equalityComparer);
        }
        function deduplicateSorted(array, comparer) {
            if (array.length === 0)
                return emptyArray;
            let last2 = array[0];
            const deduplicated = [last2];
            for (let i = 1; i < array.length; i++) {
                const next = array[i];
                switch (comparer(next, last2)) {
                    case true:
                    case 0 /* EqualTo */:
                        continue;
                    case -1 /* LessThan */:
                        return Debug.fail("Array is unsorted.");
                }
                deduplicated.push(last2 = next);
            }
            return deduplicated;
        }
        function createSortedArray() {
            return [];
        }
        function insertSorted(array, insert, compare, allowDuplicates) {
            if (array.length === 0) {
                array.push(insert);
                return true;
            }
            const insertIndex = binarySearch(array, insert, identity, compare);
            if (insertIndex < 0) {
                array.splice(~insertIndex, 0, insert);
                return true;
            }
            if (allowDuplicates) {
                array.splice(insertIndex, 0, insert);
                return true;
            }
            return false;
        }
        function sortAndDeduplicate(array, comparer, equalityComparer) {
            return deduplicateSorted(sort(array, comparer), equalityComparer || comparer || compareStringsCaseSensitive);
        }
        function arrayIsSorted(array, comparer) {
            if (array.length < 2)
                return true;
            for (let i = 1, len = array.length; i < len; i++) {
                if (comparer(array[i - 1], array[i]) === 1 /* GreaterThan */) {
                    return false;
                }
            }
            return true;
        }
        function detectSortCaseSensitivity(array, getString, compareStringsCaseSensitive2, compareStringsCaseInsensitive2) {
            let kind = 3 /* Both */;
            if (array.length < 2)
                return kind;
            let prevElement = getString(array[0]);
            for (let i = 1, len = array.length; i < len && kind !== 0 /* None */; i++) {
                const element = getString(array[i]);
                if (kind & 1 /* CaseSensitive */ && compareStringsCaseSensitive2(prevElement, element) > 0) {
                    kind &= ~1 /* CaseSensitive */;
                }
                if (kind & 2 /* CaseInsensitive */ && compareStringsCaseInsensitive2(prevElement, element) > 0) {
                    kind &= ~2 /* CaseInsensitive */;
                }
                prevElement = element;
            }
            return kind;
        }
        function arrayIsEqualTo(array1, array2, equalityComparer = equateValues) {
            if (!array1 || !array2) {
                return array1 === array2;
            }
            if (array1.length !== array2.length) {
                return false;
            }
            for (let i = 0; i < array1.length; i++) {
                if (!equalityComparer(array1[i], array2[i], i)) {
                    return false;
                }
            }
            return true;
        }
        function compact(array) {
            let result;
            if (array) {
                for (let i = 0; i < array.length; i++) {
                    const v = array[i];
                    if (result || !v) {
                        if (!result) {
                            result = array.slice(0, i);
                        }
                        if (v) {
                            result.push(v);
                        }
                    }
                }
            }
            return result || array;
        }
        function relativeComplement(arrayA, arrayB, comparer) {
            if (!arrayB || !arrayA || arrayB.length === 0 || arrayA.length === 0)
                return arrayB;
            const result = [];
            loopB: for (let offsetA = 0, offsetB = 0; offsetB < arrayB.length; offsetB++) {
                if (offsetB > 0) {
                    Debug.assertGreaterThanOrEqual(comparer(arrayB[offsetB], arrayB[offsetB - 1]), 0 /* EqualTo */);
                }
                loopA: for (const startA = offsetA; offsetA < arrayA.length; offsetA++) {
                    if (offsetA > startA) {
                        Debug.assertGreaterThanOrEqual(comparer(arrayA[offsetA], arrayA[offsetA - 1]), 0 /* EqualTo */);
                    }
                    switch (comparer(arrayB[offsetB], arrayA[offsetA])) {
                        case -1 /* LessThan */:
                            result.push(arrayB[offsetB]);
                            continue loopB;
                        case 0 /* EqualTo */:
                            continue loopB;
                        case 1 /* GreaterThan */:
                            continue loopA;
                    }
                }
            }
            return result;
        }
        function append(to, value) {
            if (value === void 0)
                return to;
            if (to === void 0)
                return [value];
            to.push(value);
            return to;
        }
        function combine(xs, ys) {
            if (xs === void 0)
                return ys;
            if (ys === void 0)
                return xs;
            if (isArray(xs))
                return isArray(ys) ? concatenate(xs, ys) : append(xs, ys);
            if (isArray(ys))
                return append(ys, xs);
            return [xs, ys];
        }
        function toOffset(array, offset) {
            return offset < 0 ? array.length + offset : offset;
        }
        function addRange(to, from, start, end) {
            if (from === void 0 || from.length === 0)
                return to;
            if (to === void 0)
                return from.slice(start, end);
            start = start === void 0 ? 0 : toOffset(from, start);
            end = end === void 0 ? from.length : toOffset(from, end);
            for (let i = start; i < end && i < from.length; i++) {
                if (from[i] !== void 0) {
                    to.push(from[i]);
                }
            }
            return to;
        }
        function pushIfUnique(array, toAdd, equalityComparer) {
            if (contains(array, toAdd, equalityComparer)) {
                return false;
            }
            else {
                array.push(toAdd);
                return true;
            }
        }
        function appendIfUnique(array, toAdd, equalityComparer) {
            if (array) {
                pushIfUnique(array, toAdd, equalityComparer);
                return array;
            }
            else {
                return [toAdd];
            }
        }
        function stableSortIndices(array, indices, comparer) {
            indices.sort((x, y) => comparer(array[x], array[y]) || compareValues(x, y));
        }
        function sort(array, comparer) {
            return array.length === 0 ? array : array.slice().sort(comparer);
        }
        function* arrayReverseIterator(array) {
            for (let i = array.length - 1; i >= 0; i--) {
                yield array[i];
            }
        }
        function stableSort(array, comparer) {
            const indices = indicesOf(array);
            stableSortIndices(array, indices, comparer);
            return indices.map((i) => array[i]);
        }
        function rangeEquals(array1, array2, pos, end) {
            while (pos < end) {
                if (array1[pos] !== array2[pos]) {
                    return false;
                }
                pos++;
            }
            return true;
        }
        function firstOrUndefined(array) {
            return array === void 0 || array.length === 0 ? void 0 : array[0];
        }
        function firstOrUndefinedIterator(iter) {
            if (iter) {
                for (const value of iter) {
                    return value;
                }
            }
            return void 0;
        }
        function first(array) {
            Debug.assert(array.length !== 0);
            return array[0];
        }
        function firstIterator(iter) {
            for (const value of iter) {
                return value;
            }
            Debug.fail("iterator is empty");
        }
        function lastOrUndefined(array) {
            return array === void 0 || array.length === 0 ? void 0 : array[array.length - 1];
        }
        function last(array) {
            Debug.assert(array.length !== 0);
            return array[array.length - 1];
        }
        function singleOrUndefined(array) {
            return array && array.length === 1 ? array[0] : void 0;
        }
        function single(array) {
            return Debug.checkDefined(singleOrUndefined(array));
        }
        function singleOrMany(array) {
            return array && array.length === 1 ? array[0] : array;
        }
        function replaceElement(array, index, value) {
            const result = array.slice(0);
            result[index] = value;
            return result;
        }
        function binarySearch(array, value, keySelector, keyComparer, offset) {
            return binarySearchKey(array, keySelector(value), keySelector, keyComparer, offset);
        }
        function binarySearchKey(array, key, keySelector, keyComparer, offset) {
            if (!some(array)) {
                return -1;
            }
            let low = offset || 0;
            let high = array.length - 1;
            while (low <= high) {
                const middle = low + (high - low >> 1);
                const midKey = keySelector(array[middle], middle);
                switch (keyComparer(midKey, key)) {
                    case -1 /* LessThan */:
                        low = middle + 1;
                        break;
                    case 0 /* EqualTo */:
                        return middle;
                    case 1 /* GreaterThan */:
                        high = middle - 1;
                        break;
                }
            }
            return ~low;
        }
        function reduceLeft(array, f, initial, start, count) {
            if (array && array.length > 0) {
                const size = array.length;
                if (size > 0) {
                    let pos = start === void 0 || start < 0 ? 0 : start;
                    const end = count === void 0 || pos + count > size - 1 ? size - 1 : pos + count;
                    let result;
                    if (arguments.length <= 2) {
                        result = array[pos];
                        pos++;
                    }
                    else {
                        result = initial;
                    }
                    while (pos <= end) {
                        result = f(result, array[pos], pos);
                        pos++;
                    }
                    return result;
                }
            }
            return initial;
        }
        function hasProperty(map2, key) {
            return hasOwnProperty.call(map2, key);
        }
        function getProperty(map2, key) {
            return hasOwnProperty.call(map2, key) ? map2[key] : void 0;
        }
        function getOwnKeys(map2) {
            const keys = [];
            for (const key in map2) {
                if (hasOwnProperty.call(map2, key)) {
                    keys.push(key);
                }
            }
            return keys;
        }
        function getAllKeys(obj) {
            const result = [];
            do {
                const names = Object.getOwnPropertyNames(obj);
                for (const name of names) {
                    pushIfUnique(result, name);
                }
            } while (obj = Object.getPrototypeOf(obj));
            return result;
        }
        function getOwnValues(collection) {
            const values = [];
            for (const key in collection) {
                if (hasOwnProperty.call(collection, key)) {
                    values.push(collection[key]);
                }
            }
            return values;
        }
        function arrayOf(count, f) {
            const result = new Array(count);
            for (let i = 0; i < count; i++) {
                result[i] = f(i);
            }
            return result;
        }
        function arrayFrom(iterator, map2) {
            const result = [];
            for (const value of iterator) {
                result.push(map2 ? map2(value) : value);
            }
            return result;
        }
        function assign(t, ...args) {
            for (const arg of args) {
                if (arg === void 0)
                    continue;
                for (const p in arg) {
                    if (hasProperty(arg, p)) {
                        t[p] = arg[p];
                    }
                }
            }
            return t;
        }
        function equalOwnProperties(left, right, equalityComparer = equateValues) {
            if (left === right)
                return true;
            if (!left || !right)
                return false;
            for (const key in left) {
                if (hasOwnProperty.call(left, key)) {
                    if (!hasOwnProperty.call(right, key))
                        return false;
                    if (!equalityComparer(left[key], right[key]))
                        return false;
                }
            }
            for (const key in right) {
                if (hasOwnProperty.call(right, key)) {
                    if (!hasOwnProperty.call(left, key))
                        return false;
                }
            }
            return true;
        }
        function arrayToMap(array, makeKey, makeValue = identity) {
            const result = /* @__PURE__ */ new Map();
            for (const value of array) {
                const key = makeKey(value);
                if (key !== void 0)
                    result.set(key, makeValue(value));
            }
            return result;
        }
        function arrayToNumericMap(array, makeKey, makeValue = identity) {
            const result = [];
            for (const value of array) {
                result[makeKey(value)] = makeValue(value);
            }
            return result;
        }
        function arrayToMultiMap(values, makeKey, makeValue = identity) {
            const result = createMultiMap();
            for (const value of values) {
                result.add(makeKey(value), makeValue(value));
            }
            return result;
        }
        function group(values, getGroupId, resultSelector = identity) {
            return arrayFrom(arrayToMultiMap(values, getGroupId).values(), resultSelector);
        }
        function groupBy(values, keySelector) {
            const result = {};
            if (values) {
                for (const value of values) {
                    const key = `${keySelector(value)}`;
                    const array = result[key] ?? (result[key] = []);
                    array.push(value);
                }
            }
            return result;
        }
        function clone(object) {
            const result = {};
            for (const id in object) {
                if (hasOwnProperty.call(object, id)) {
                    result[id] = object[id];
                }
            }
            return result;
        }
        function extend(first2, second) {
            const result = {};
            for (const id in second) {
                if (hasOwnProperty.call(second, id)) {
                    result[id] = second[id];
                }
            }
            for (const id in first2) {
                if (hasOwnProperty.call(first2, id)) {
                    result[id] = first2[id];
                }
            }
            return result;
        }
        function copyProperties(first2, second) {
            for (const id in second) {
                if (hasOwnProperty.call(second, id)) {
                    first2[id] = second[id];
                }
            }
        }
        function maybeBind(obj, fn) {
            return fn ? fn.bind(obj) : void 0;
        }
        function createMultiMap() {
            const map2 = /* @__PURE__ */ new Map();
            map2.add = multiMapAdd;
            map2.remove = multiMapRemove;
            return map2;
        }
        function multiMapAdd(key, value) {
            let values = this.get(key);
            if (values) {
                values.push(value);
            }
            else {
                this.set(key, values = [value]);
            }
            return values;
        }
        function multiMapRemove(key, value) {
            const values = this.get(key);
            if (values) {
                unorderedRemoveItem(values, value);
                if (!values.length) {
                    this.delete(key);
                }
            }
        }
        function createQueue(items) {
            const elements = (items == null ? void 0 : items.slice()) || [];
            let headIndex = 0;
            function isEmpty() {
                return headIndex === elements.length;
            }
            function enqueue(...items2) {
                elements.push(...items2);
            }
            function dequeue() {
                if (isEmpty()) {
                    throw new Error("Queue is empty");
                }
                const result = elements[headIndex];
                elements[headIndex] = void 0;
                headIndex++;
                if (headIndex > 100 && headIndex > elements.length >> 1) {
                    const newLength = elements.length - headIndex;
                    elements.copyWithin(
                    /*target*/
                    0, 
                    /*start*/
                    headIndex);
                    elements.length = newLength;
                    headIndex = 0;
                }
                return result;
            }
            return {
                enqueue,
                dequeue,
                isEmpty
            };
        }
        function createSet(getHashCode, equals) {
            const multiMap = /* @__PURE__ */ new Map();
            let size = 0;
            function* getElementIterator() {
                for (const value of multiMap.values()) {
                    if (isArray(value)) {
                        yield* value;
                    }
                    else {
                        yield value;
                    }
                }
            }
            const set = {
                has(element) {
                    const hash = getHashCode(element);
                    if (!multiMap.has(hash))
                        return false;
                    const candidates = multiMap.get(hash);
                    if (!isArray(candidates))
                        return equals(candidates, element);
                    for (const candidate of candidates) {
                        if (equals(candidate, element)) {
                            return true;
                        }
                    }
                    return false;
                },
                add(element) {
                    const hash = getHashCode(element);
                    if (multiMap.has(hash)) {
                        const values = multiMap.get(hash);
                        if (isArray(values)) {
                            if (!contains(values, element, equals)) {
                                values.push(element);
                                size++;
                            }
                        }
                        else {
                            const value = values;
                            if (!equals(value, element)) {
                                multiMap.set(hash, [value, element]);
                                size++;
                            }
                        }
                    }
                    else {
                        multiMap.set(hash, element);
                        size++;
                    }
                    return this;
                },
                delete(element) {
                    const hash = getHashCode(element);
                    if (!multiMap.has(hash))
                        return false;
                    const candidates = multiMap.get(hash);
                    if (isArray(candidates)) {
                        for (let i = 0; i < candidates.length; i++) {
                            if (equals(candidates[i], element)) {
                                if (candidates.length === 1) {
                                    multiMap.delete(hash);
                                }
                                else if (candidates.length === 2) {
                                    multiMap.set(hash, candidates[1 - i]);
                                }
                                else {
                                    unorderedRemoveItemAt(candidates, i);
                                }
                                size--;
                                return true;
                            }
                        }
                    }
                    else {
                        const candidate = candidates;
                        if (equals(candidate, element)) {
                            multiMap.delete(hash);
                            size--;
                            return true;
                        }
                    }
                    return false;
                },
                clear() {
                    multiMap.clear();
                    size = 0;
                },
                get size() {
                    return size;
                },
                forEach(action) {
                    for (const elements of arrayFrom(multiMap.values())) {
                        if (isArray(elements)) {
                            for (const element of elements) {
                                action(element, element, set);
                            }
                        }
                        else {
                            const element = elements;
                            action(element, element, set);
                        }
                    }
                },
                keys() {
                    return getElementIterator();
                },
                values() {
                    return getElementIterator();
                },
                *entries() {
                    for (const value of getElementIterator()) {
                        yield [value, value];
                    }
                },
                [Symbol.iterator]: () => {
                    return getElementIterator();
                },
                [Symbol.toStringTag]: multiMap[Symbol.toStringTag]
            };
            return set;
        }
        function isArray(value) {
            return Array.isArray(value);
        }
        function toArray(value) {
            return isArray(value) ? value : [value];
        }
        function isString(text) {
            return typeof text === "string";
        }
        function isNumber(x) {
            return typeof x === "number";
        }
        function tryCast(value, test) {
            return value !== void 0 && test(value) ? value : void 0;
        }
        function cast(value, test) {
            if (value !== void 0 && test(value))
                return value;
            return Debug.fail(`Invalid cast. The supplied value ${value} did not pass the test '${Debug.getFunctionName(test)}'.`);
        }
        function noop(_) {
        }
        function returnFalse() {
            return false;
        }
        function returnTrue() {
            return true;
        }
        function returnUndefined() {
            return void 0;
        }
        function identity(x) {
            return x;
        }
        function toLowerCase(x) {
            return x.toLowerCase();
        }
        function toFileNameLowerCase(x) {
            return fileNameLowerCaseRegExp.test(x) ? x.replace(fileNameLowerCaseRegExp, toLowerCase) : x;
        }
        function notImplemented() {
            throw new Error("Not implemented");
        }
        function memoize(callback) {
            let value;
            return () => {
                if (callback) {
                    value = callback();
                    callback = void 0;
                }
                return value;
            };
        }
        function memoizeOne(callback) {
            const map2 = /* @__PURE__ */ new Map();
            return (arg) => {
                const key = `${typeof arg}:${arg}`;
                let value = map2.get(key);
                if (value === void 0 && !map2.has(key)) {
                    value = callback(arg);
                    map2.set(key, value);
                }
                return value;
            };
        }
        function memoizeWeak(callback) {
            const map2 = /* @__PURE__ */ new WeakMap();
            return (arg) => {
                let value = map2.get(arg);
                if (value === void 0 && !map2.has(arg)) {
                    value = callback(arg);
                    map2.set(arg, value);
                }
                return value;
            };
        }
        function memoizeCached(callback, cache) {
            return (...args) => {
                let value = cache.get(args);
                if (value === void 0 && !cache.has(args)) {
                    value = callback(...args);
                    cache.set(args, value);
                }
                return value;
            };
        }
        function compose(a, b, c, d, e) {
            if (!!e) {
                const args = [];
                for (let i = 0; i < arguments.length; i++) {
                    args[i] = arguments[i];
                }
                return (t) => reduceLeft(args, (u, f) => f(u), t);
            }
            else if (d) {
                return (t) => d(c(b(a(t))));
            }
            else if (c) {
                return (t) => c(b(a(t)));
            }
            else if (b) {
                return (t) => b(a(t));
            }
            else if (a) {
                return (t) => a(t);
            }
            else {
                return (t) => t;
            }
        }
        function equateValues(a, b) {
            return a === b;
        }
        function equateStringsCaseInsensitive(a, b) {
            return a === b || a !== void 0 && b !== void 0 && a.toUpperCase() === b.toUpperCase();
        }
        function equateStringsCaseSensitive(a, b) {
            return equateValues(a, b);
        }
        function compareComparableValues(a, b) {
            return a === b ? 0 /* EqualTo */ : a === void 0 ? -1 /* LessThan */ : b === void 0 ? 1 /* GreaterThan */ : a < b ? -1 /* LessThan */ : 1 /* GreaterThan */;
        }
        function compareValues(a, b) {
            return compareComparableValues(a, b);
        }
        function compareTextSpans(a, b) {
            return compareValues(a == null ? void 0 : a.start, b == null ? void 0 : b.start) || compareValues(a == null ? void 0 : a.length, b == null ? void 0 : b.length);
        }
        function min(items, compare) {
            return reduceLeft(items, (x, y) => compare(x, y) === -1 /* LessThan */ ? x : y);
        }
        function compareStringsCaseInsensitive(a, b) {
            if (a === b)
                return 0 /* EqualTo */;
            if (a === void 0)
                return -1 /* LessThan */;
            if (b === void 0)
                return 1 /* GreaterThan */;
            a = a.toUpperCase();
            b = b.toUpperCase();
            return a < b ? -1 /* LessThan */ : a > b ? 1 /* GreaterThan */ : 0 /* EqualTo */;
        }
        function compareStringsCaseInsensitiveEslintCompatible(a, b) {
            if (a === b)
                return 0 /* EqualTo */;
            if (a === void 0)
                return -1 /* LessThan */;
            if (b === void 0)
                return 1 /* GreaterThan */;
            a = a.toLowerCase();
            b = b.toLowerCase();
            return a < b ? -1 /* LessThan */ : a > b ? 1 /* GreaterThan */ : 0 /* EqualTo */;
        }
        function compareStringsCaseSensitive(a, b) {
            return compareComparableValues(a, b);
        }
        function getStringComparer(ignoreCase) {
            return ignoreCase ? compareStringsCaseInsensitive : compareStringsCaseSensitive;
        }
        function getUILocale() {
            return uiLocale;
        }
        function setUILocale(value) {
            if (uiLocale !== value) {
                uiLocale = value;
                uiComparerCaseSensitive = void 0;
            }
        }
        function compareStringsCaseSensitiveUI(a, b) {
            const comparer = uiComparerCaseSensitive || (uiComparerCaseSensitive = createUIStringComparer(uiLocale));
            return comparer(a, b);
        }
        function compareProperties(a, b, key, comparer) {
            return a === b ? 0 /* EqualTo */ : a === void 0 ? -1 /* LessThan */ : b === void 0 ? 1 /* GreaterThan */ : comparer(a[key], b[key]);
        }
        function compareBooleans(a, b) {
            return compareValues(a ? 1 : 0, b ? 1 : 0);
        }
        function getSpellingSuggestion(name, candidates, getName) {
            const maximumLengthDifference = Math.max(2, Math.floor(name.length * 0.34));
            let bestDistance = Math.floor(name.length * 0.4) + 1;
            let bestCandidate;
            for (const candidate of candidates) {
                const candidateName = getName(candidate);
                if (candidateName !== void 0 && Math.abs(candidateName.length - name.length) <= maximumLengthDifference) {
                    if (candidateName === name) {
                        continue;
                    }
                    if (candidateName.length < 3 && candidateName.toLowerCase() !== name.toLowerCase()) {
                        continue;
                    }
                    const distance = levenshteinWithMax(name, candidateName, bestDistance - 0.1);
                    if (distance === void 0) {
                        continue;
                    }
                    Debug.assert(distance < bestDistance);
                    bestDistance = distance;
                    bestCandidate = candidate;
                }
            }
            return bestCandidate;
        }
        function levenshteinWithMax(s1, s2, max) {
            let previous = new Array(s2.length + 1);
            let current = new Array(s2.length + 1);
            const big = max + 0.01;
            for (let i = 0; i <= s2.length; i++) {
                previous[i] = i;
            }
            for (let i = 1; i <= s1.length; i++) {
                const c1 = s1.charCodeAt(i - 1);
                const minJ = Math.ceil(i > max ? i - max : 1);
                const maxJ = Math.floor(s2.length > max + i ? max + i : s2.length);
                current[0] = i;
                let colMin = i;
                for (let j = 1; j < minJ; j++) {
                    current[j] = big;
                }
                for (let j = minJ; j <= maxJ; j++) {
                    const substitutionDistance = s1[i - 1].toLowerCase() === s2[j - 1].toLowerCase() ? previous[j - 1] + 0.1 : previous[j - 1] + 2;
                    const dist = c1 === s2.charCodeAt(j - 1) ? previous[j - 1] : Math.min(
                    /*delete*/
                    previous[j] + 1, 
                    /*insert*/
                    current[j - 1] + 1, 
                    /*substitute*/
                    substitutionDistance);
                    current[j] = dist;
                    colMin = Math.min(colMin, dist);
                }
                for (let j = maxJ + 1; j <= s2.length; j++) {
                    current[j] = big;
                }
                if (colMin > max) {
                    return void 0;
                }
                const temp = previous;
                previous = current;
                current = temp;
            }
            const res = previous[s2.length];
            return res > max ? void 0 : res;
        }
        function endsWith(str, suffix, ignoreCase) {
            const expectedPos = str.length - suffix.length;
            return expectedPos >= 0 && (ignoreCase ? equateStringsCaseInsensitive(str.slice(expectedPos), suffix) : str.indexOf(suffix, expectedPos) === expectedPos);
        }
        function removeSuffix(str, suffix) {
            return endsWith(str, suffix) ? str.slice(0, str.length - suffix.length) : str;
        }
        function tryRemoveSuffix(str, suffix) {
            return endsWith(str, suffix) ? str.slice(0, str.length - suffix.length) : void 0;
        }
        function removeMinAndVersionNumbers(fileName) {
            let end = fileName.length;
            for (let pos = end - 1; pos > 0; pos--) {
                let ch = fileName.charCodeAt(pos);
                if (ch >= 48 /* _0 */ && ch <= 57 /* _9 */) {
                    do {
                        --pos;
                        ch = fileName.charCodeAt(pos);
                    } while (pos > 0 && ch >= 48 /* _0 */ && ch <= 57 /* _9 */);
                }
                else if (pos > 4 && (ch === 110 /* n */ || ch === 78 /* N */)) {
                    --pos;
                    ch = fileName.charCodeAt(pos);
                    if (ch !== 105 /* i */ && ch !== 73 /* I */) {
                        break;
                    }
                    --pos;
                    ch = fileName.charCodeAt(pos);
                    if (ch !== 109 /* m */ && ch !== 77 /* M */) {
                        break;
                    }
                    --pos;
                    ch = fileName.charCodeAt(pos);
                }
                else {
                    break;
                }
                if (ch !== 45 /* minus */ && ch !== 46 /* dot */) {
                    break;
                }
                end = pos;
            }
            return end === fileName.length ? fileName : fileName.slice(0, end);
        }
        function orderedRemoveItem(array, item) {
            for (let i = 0; i < array.length; i++) {
                if (array[i] === item) {
                    orderedRemoveItemAt(array, i);
                    return true;
                }
            }
            return false;
        }
        function orderedRemoveItemAt(array, index) {
            for (let i = index; i < array.length - 1; i++) {
                array[i] = array[i + 1];
            }
            array.pop();
        }
        function unorderedRemoveItemAt(array, index) {
            array[index] = array[array.length - 1];
            array.pop();
        }
        function unorderedRemoveItem(array, item) {
            return unorderedRemoveFirstItemWhere(array, (element) => element === item);
        }
        function unorderedRemoveFirstItemWhere(array, predicate) {
            for (let i = 0; i < array.length; i++) {
                if (predicate(array[i])) {
                    unorderedRemoveItemAt(array, i);
                    return true;
                }
            }
            return false;
        }
        function createGetCanonicalFileName(useCaseSensitiveFileNames2) {
            return useCaseSensitiveFileNames2 ? identity : toFileNameLowerCase;
        }
        function patternText({ prefix, suffix }) {
            return `${prefix}*${suffix}`;
        }
        function matchedText(pattern, candidate) {
            Debug.assert(isPatternMatch(pattern, candidate));
            return candidate.substring(pattern.prefix.length, candidate.length - pattern.suffix.length);
        }
        function findBestPatternMatch(values, getPattern, candidate) {
            let matchedValue;
            let longestMatchPrefixLength = -1;
            for (const v of values) {
                const pattern = getPattern(v);
                if (isPatternMatch(pattern, candidate) && pattern.prefix.length > longestMatchPrefixLength) {
                    longestMatchPrefixLength = pattern.prefix.length;
                    matchedValue = v;
                }
            }
            return matchedValue;
        }
        function startsWith(str, prefix, ignoreCase) {
            return ignoreCase ? equateStringsCaseInsensitive(str.slice(0, prefix.length), prefix) : str.lastIndexOf(prefix, 0) === 0;
        }
        function removePrefix(str, prefix) {
            return startsWith(str, prefix) ? str.substr(prefix.length) : str;
        }
        function tryRemovePrefix(str, prefix, getCanonicalFileName = identity) {
            return startsWith(getCanonicalFileName(str), getCanonicalFileName(prefix)) ? str.substring(prefix.length) : void 0;
        }
        function isPatternMatch({ prefix, suffix }, candidate) {
            return candidate.length >= prefix.length + suffix.length && startsWith(candidate, prefix) && endsWith(candidate, suffix);
        }
        function and(f, g) {
            return (arg) => f(arg) && g(arg);
        }
        function or(...fs) {
            return (...args) => {
                let lastResult;
                for (const f of fs) {
                    lastResult = f(...args);
                    if (lastResult) {
                        return lastResult;
                    }
                }
                return lastResult;
            };
        }
        function not(fn) {
            return (...args) => !fn(...args);
        }
        function assertType(_) {
        }
        function singleElementArray(t) {
            return t === void 0 ? void 0 : [t];
        }
        function enumerateInsertsAndDeletes(newItems, oldItems, comparer, inserted, deleted, unchanged) {
            unchanged = unchanged || noop;
            let newIndex = 0;
            let oldIndex = 0;
            const newLen = newItems.length;
            const oldLen = oldItems.length;
            let hasChanges = false;
            while (newIndex < newLen && oldIndex < oldLen) {
                const newItem = newItems[newIndex];
                const oldItem = oldItems[oldIndex];
                const compareResult = comparer(newItem, oldItem);
                if (compareResult === -1 /* LessThan */) {
                    inserted(newItem);
                    newIndex++;
                    hasChanges = true;
                }
                else if (compareResult === 1 /* GreaterThan */) {
                    deleted(oldItem);
                    oldIndex++;
                    hasChanges = true;
                }
                else {
                    unchanged(oldItem, newItem);
                    newIndex++;
                    oldIndex++;
                }
            }
            while (newIndex < newLen) {
                inserted(newItems[newIndex++]);
                hasChanges = true;
            }
            while (oldIndex < oldLen) {
                deleted(oldItems[oldIndex++]);
                hasChanges = true;
            }
            return hasChanges;
        }
        function cartesianProduct(arrays) {
            const result = [];
            cartesianProductWorker(arrays, result, 
            /*outer*/
            void 0, 0);
            return result;
        }
        function cartesianProductWorker(arrays, result, outer, index) {
            for (const element of arrays[index]) {
                let inner;
                if (outer) {
                    inner = outer.slice();
                    inner.push(element);
                }
                else {
                    inner = [element];
                }
                if (index === arrays.length - 1) {
                    result.push(inner);
                }
                else {
                    cartesianProductWorker(arrays, result, inner, index + 1);
                }
            }
        }
        function takeWhile(array, predicate) {
            if (array) {
                const len = array.length;
                let index = 0;
                while (index < len && predicate(array[index])) {
                    index++;
                }
                return array.slice(0, index);
            }
        }
        function skipWhile(array, predicate) {
            if (array) {
                const len = array.length;
                let index = 0;
                while (index < len && predicate(array[index])) {
                    index++;
                }
                return array.slice(index);
            }
        }
        function isNodeLikeSystem() {
            return typeof process !== "undefined" && !!process.nextTick && !process.browser && typeof module === "object";
        }
        var emptyArray, emptyMap, emptySet, SortKind, elementAt, hasOwnProperty, fileNameLowerCaseRegExp, AssertionLevel, createUIStringComparer, uiComparerCaseSensitive, uiLocale;
        var init_core = __esm({
            "src/compiler/core.ts"() {
                "use strict";
                init_ts2();
                emptyArray = [];
                emptyMap = /* @__PURE__ */ new Map();
                emptySet = /* @__PURE__ */ new Set();
                SortKind = /* @__PURE__ */ ((SortKind2) => {
                    SortKind2[SortKind2["None"] = 0] = "None";
                    SortKind2[SortKind2["CaseSensitive"] = 1] = "CaseSensitive";
                    SortKind2[SortKind2["CaseInsensitive"] = 2] = "CaseInsensitive";
                    SortKind2[SortKind2["Both"] = 3] = "Both";
                    return SortKind2;
                })(SortKind || {});
                elementAt = !!Array.prototype.at ? (array, offset) => array == null ? void 0 : array.at(offset) : (array, offset) => {
                    if (array) {
                        offset = toOffset(array, offset);
                        if (offset < array.length) {
                            return array[offset];
                        }
                    }
                    return void 0;
                };
                hasOwnProperty = Object.prototype.hasOwnProperty;
                fileNameLowerCaseRegExp = /[^\u0130\u0131\u00DFa-z0-9\\/:\-_. ]+/g;
                AssertionLevel = /* @__PURE__ */ ((AssertionLevel2) => {
                    AssertionLevel2[AssertionLevel2["None"] = 0] = "None";
                    AssertionLevel2[AssertionLevel2["Normal"] = 1] = "Normal";
                    AssertionLevel2[AssertionLevel2["Aggressive"] = 2] = "Aggressive";
                    AssertionLevel2[AssertionLevel2["VeryAggressive"] = 3] = "VeryAggressive";
                    return AssertionLevel2;
                })(AssertionLevel || {});
                createUIStringComparer = /* @__PURE__ */ (() => {
                    return createIntlCollatorStringComparer;
                    function compareWithCallback(a, b, comparer) {
                        if (a === b)
                            return 0 /* EqualTo */;
                        if (a === void 0)
                            return -1 /* LessThan */;
                        if (b === void 0)
                            return 1 /* GreaterThan */;
                        const value = comparer(a, b);
                        return value < 0 ? -1 /* LessThan */ : value > 0 ? 1 /* GreaterThan */ : 0 /* EqualTo */;
                    }
                    function createIntlCollatorStringComparer(locale) {
                        const comparer = new Intl.Collator(locale, { usage: "sort", sensitivity: "variant" }).compare;
                        return (a, b) => compareWithCallback(a, b, comparer);
                    }
                })();
            }
        });
        // src/compiler/debug.ts
        var LogLevel, Debug;
        var init_debug = __esm({
            "src/compiler/debug.ts"() {
                "use strict";
                init_ts2();
                init_ts2();
                LogLevel = /* @__PURE__ */ ((LogLevel3) => {
                    LogLevel3[LogLevel3["Off"] = 0] = "Off";
                    LogLevel3[LogLevel3["Error"] = 1] = "Error";
                    LogLevel3[LogLevel3["Warning"] = 2] = "Warning";
                    LogLevel3[LogLevel3["Info"] = 3] = "Info";
                    LogLevel3[LogLevel3["Verbose"] = 4] = "Verbose";
                    return LogLevel3;
                })(LogLevel || {});
                ((Debug2) => {
                    let currentAssertionLevel = 0 /* None */;
                    Debug2.currentLogLevel = 2 /* Warning */;
                    Debug2.isDebugging = false;
                    function shouldLog(level) {
                        return Debug2.currentLogLevel <= level;
                    }
                    Debug2.shouldLog = shouldLog;
                    function logMessage(level, s) {
                        if (Debug2.loggingHost && shouldLog(level)) {
                            Debug2.loggingHost.log(level, s);
                        }
                    }
                    function log(s) {
                        logMessage(3 /* Info */, s);
                    }
                    Debug2.log = log;
                    ((_log) => {
                        function error2(s) {
                            logMessage(1 /* Error */, s);
                        }
                        _log.error = error2;
                        function warn(s) {
                            logMessage(2 /* Warning */, s);
                        }
                        _log.warn = warn;
                        function log2(s) {
                            logMessage(3 /* Info */, s);
                        }
                        _log.log = log2;
                        function trace2(s) {
                            logMessage(4 /* Verbose */, s);
                        }
                        _log.trace = trace2;
                    })(log = Debug2.log || (Debug2.log = {}));
                    const assertionCache = {};
                    function getAssertionLevel() {
                        return currentAssertionLevel;
                    }
                    Debug2.getAssertionLevel = getAssertionLevel;
                    function setAssertionLevel(level) {
                        const prevAssertionLevel = currentAssertionLevel;
                        currentAssertionLevel = level;
                        if (level > prevAssertionLevel) {
                            for (const key of getOwnKeys(assertionCache)) {
                                const cachedFunc = assertionCache[key];
                                if (cachedFunc !== void 0 && Debug2[key] !== cachedFunc.assertion && level >= cachedFunc.level) {
                                    Debug2[key] = cachedFunc;
                                    assertionCache[key] = void 0;
                                }
                            }
                        }
                    }
                    Debug2.setAssertionLevel = setAssertionLevel;
                    function shouldAssert(level) {
                        return currentAssertionLevel >= level;
                    }
                    Debug2.shouldAssert = shouldAssert;
                    function shouldAssertFunction(level, name) {
                        if (!shouldAssert(level)) {
                            assertionCache[name] = { level, assertion: Debug2[name] };
                            Debug2[name] = noop;
                            return false;
                        }
                        return true;
                    }
                    function fail(message, stackCrawlMark) {
                        debugger;
                        const e = new Error(message ? `Debug Failure. ${message}` : "Debug Failure.");
                        if (Error.captureStackTrace) {
                            Error.captureStackTrace(e, stackCrawlMark || fail);
                        }
                        throw e;
                    }
                    Debug2.fail = fail;
                    function failBadSyntaxKind(node, message, stackCrawlMark) {
                        return fail(`${message || "Unexpected node."}\r
Node ${formatSyntaxKind(node.kind)} was unexpected.`, stackCrawlMark || failBadSyntaxKind);
                    }
                    Debug2.failBadSyntaxKind = failBadSyntaxKind;
                    function assert(expression, message, verboseDebugInfo, stackCrawlMark) {
                        if (!expression) {
                            message = message ? `False expression: ${message}` : "False expression.";
                            if (verboseDebugInfo) {
                                message += "\r\nVerbose Debug Information: " + (typeof verboseDebugInfo === "string" ? verboseDebugInfo : verboseDebugInfo());
                            }
                            fail(message, stackCrawlMark || assert);
                        }
                    }
                    Debug2.assert = assert;
                    function assertEqual(a, b, msg, msg2, stackCrawlMark) {
                        if (a !== b) {
                            const message = msg ? msg2 ? `${msg} ${msg2}` : msg : "";
                            fail(`Expected ${a} === ${b}. ${message}`, stackCrawlMark || assertEqual);
                        }
                    }
                    Debug2.assertEqual = assertEqual;
                    function assertLessThan(a, b, msg, stackCrawlMark) {
                        if (a >= b) {
                            fail(`Expected ${a} < ${b}. ${msg || ""}`, stackCrawlMark || assertLessThan);
                        }
                    }
                    Debug2.assertLessThan = assertLessThan;
                    function assertLessThanOrEqual(a, b, stackCrawlMark) {
                        if (a > b) {
                            fail(`Expected ${a} <= ${b}`, stackCrawlMark || assertLessThanOrEqual);
                        }
                    }
                    Debug2.assertLessThanOrEqual = assertLessThanOrEqual;
                    function assertGreaterThanOrEqual(a, b, stackCrawlMark) {
                        if (a < b) {
                            fail(`Expected ${a} >= ${b}`, stackCrawlMark || assertGreaterThanOrEqual);
                        }
                    }
                    Debug2.assertGreaterThanOrEqual = assertGreaterThanOrEqual;
                    function assertIsDefined(value, message, stackCrawlMark) {
                        if (value === void 0 || value === null) {
                            fail(message, stackCrawlMark || assertIsDefined);
                        }
                    }
                    Debug2.assertIsDefined = assertIsDefined;
                    function checkDefined(value, message, stackCrawlMark) {
                        assertIsDefined(value, message, stackCrawlMark || checkDefined);
                        return value;
                    }
                    Debug2.checkDefined = checkDefined;
                    function assertEachIsDefined(value, message, stackCrawlMark) {
                        for (const v of value) {
                            assertIsDefined(v, message, stackCrawlMark || assertEachIsDefined);
                        }
                    }
                    Debug2.assertEachIsDefined = assertEachIsDefined;
                    function checkEachDefined(value, message, stackCrawlMark) {
                        assertEachIsDefined(value, message, stackCrawlMark || checkEachDefined);
                        return value;
                    }
                    Debug2.checkEachDefined = checkEachDefined;
                    function assertNever(member, message = "Illegal value:", stackCrawlMark) {
                        const detail = typeof member === "object" && hasProperty(member, "kind") && hasProperty(member, "pos") ? "SyntaxKind: " + formatSyntaxKind(member.kind) : JSON.stringify(member);
                        return fail(`${message} ${detail}`, stackCrawlMark || assertNever);
                    }
                    Debug2.assertNever = assertNever;
                    function assertEachNode(nodes, test, message, stackCrawlMark) {
                        if (shouldAssertFunction(1 /* Normal */, "assertEachNode")) {
                            assert(test === void 0 || every(nodes, test), message || "Unexpected node.", () => `Node array did not pass test '${getFunctionName(test)}'.`, stackCrawlMark || assertEachNode);
                        }
                    }
                    Debug2.assertEachNode = assertEachNode;
                    function assertNode(node, test, message, stackCrawlMark) {
                        if (shouldAssertFunction(1 /* Normal */, "assertNode")) {
                            assert(node !== void 0 && (test === void 0 || test(node)), message || "Unexpected node.", () => `Node ${formatSyntaxKind(node == null ? void 0 : node.kind)} did not pass test '${getFunctionName(test)}'.`, stackCrawlMark || assertNode);
                        }
                    }
                    Debug2.assertNode = assertNode;
                    function assertNotNode(node, test, message, stackCrawlMark) {
                        if (shouldAssertFunction(1 /* Normal */, "assertNotNode")) {
                            assert(node === void 0 || test === void 0 || !test(node), message || "Unexpected node.", () => `Node ${formatSyntaxKind(node.kind)} should not have passed test '${getFunctionName(test)}'.`, stackCrawlMark || assertNotNode);
                        }
                    }
                    Debug2.assertNotNode = assertNotNode;
                    function assertOptionalNode(node, test, message, stackCrawlMark) {
                        if (shouldAssertFunction(1 /* Normal */, "assertOptionalNode")) {
                            assert(test === void 0 || node === void 0 || test(node), message || "Unexpected node.", () => `Node ${formatSyntaxKind(node == null ? void 0 : node.kind)} did not pass test '${getFunctionName(test)}'.`, stackCrawlMark || assertOptionalNode);
                        }
                    }
                    Debug2.assertOptionalNode = assertOptionalNode;
                    function assertOptionalToken(node, kind, message, stackCrawlMark) {
                        if (shouldAssertFunction(1 /* Normal */, "assertOptionalToken")) {
                            assert(kind === void 0 || node === void 0 || node.kind === kind, message || "Unexpected node.", () => `Node ${formatSyntaxKind(node == null ? void 0 : node.kind)} was not a '${formatSyntaxKind(kind)}' token.`, stackCrawlMark || assertOptionalToken);
                        }
                    }
                    Debug2.assertOptionalToken = assertOptionalToken;
                    function assertMissingNode(node, message, stackCrawlMark) {
                        if (shouldAssertFunction(1 /* Normal */, "assertMissingNode")) {
                            assert(node === void 0, message || "Unexpected node.", () => `Node ${formatSyntaxKind(node.kind)} was unexpected'.`, stackCrawlMark || assertMissingNode);
                        }
                    }
                    Debug2.assertMissingNode = assertMissingNode;
                    function type(_value) {
                    }
                    Debug2.type = type;
                    function getFunctionName(func) {
                        if (typeof func !== "function") {
                            return "";
                        }
                        else if (hasProperty(func, "name")) {
                            return func.name;
                        }
                        else {
                            const text = Function.prototype.toString.call(func);
                            const match = /^function\s+([\w$]+)\s*\(/.exec(text);
                            return match ? match[1] : "";
                        }
                    }
                    Debug2.getFunctionName = getFunctionName;
                    function formatSymbol(symbol) {
                        return `{ name: ${unescapeLeadingUnderscores(symbol.escapedName)}; flags: ${formatSymbolFlags(symbol.flags)}; declarations: ${map(symbol.declarations, (node) => formatSyntaxKind(node.kind))} }`;
                    }
                    Debug2.formatSymbol = formatSymbol;
                    function formatEnum(value = 0, enumObject, isFlags) {
                        const members = getEnumMembers(enumObject);
                        if (value === 0) {
                            return members.length > 0 && members[0][0] === 0 ? members[0][1] : "0";
                        }
                        if (isFlags) {
                            const result = [];
                            let remainingFlags = value;
                            for (const [enumValue, enumName] of members) {
                                if (enumValue > value) {
                                    break;
                                }
                                if (enumValue !== 0 && enumValue & value) {
                                    result.push(enumName);
                                    remainingFlags &= ~enumValue;
                                }
                            }
                            if (remainingFlags === 0) {
                                return result.join("|");
                            }
                        }
                        else {
                            for (const [enumValue, enumName] of members) {
                                if (enumValue === value) {
                                    return enumName;
                                }
                            }
                        }
                        return value.toString();
                    }
                    Debug2.formatEnum = formatEnum;
                    const enumMemberCache = /* @__PURE__ */ new Map();
                    function getEnumMembers(enumObject) {
                        const existing = enumMemberCache.get(enumObject);
                        if (existing) {
                            return existing;
                        }
                        const result = [];
                        for (const name in enumObject) {
                            const value = enumObject[name];
                            if (typeof value === "number") {
                                result.push([value, name]);
                            }
                        }
                        const sorted = stableSort(result, (x, y) => compareValues(x[0], y[0]));
                        enumMemberCache.set(enumObject, sorted);
                        return sorted;
                    }
                    function formatSyntaxKind(kind) {
                        return formatEnum(kind, SyntaxKind, 
                        /*isFlags*/
                        false);
                    }
                    Debug2.formatSyntaxKind = formatSyntaxKind;
                    function formatSnippetKind(kind) {
                        return formatEnum(kind, SnippetKind, 
                        /*isFlags*/
                        false);
                    }
                    Debug2.formatSnippetKind = formatSnippetKind;
                    function formatScriptKind(kind) {
                        return formatEnum(kind, ScriptKind, 
                        /*isFlags*/
                        false);
                    }
                    Debug2.formatScriptKind = formatScriptKind;
                    function formatNodeFlags(flags) {
                        return formatEnum(flags, NodeFlags, 
                        /*isFlags*/
                        true);
                    }
                    Debug2.formatNodeFlags = formatNodeFlags;
                    function formatModifierFlags(flags) {
                        return formatEnum(flags, ModifierFlags, 
                        /*isFlags*/
                        true);
                    }
                    Debug2.formatModifierFlags = formatModifierFlags;
                    function formatTransformFlags(flags) {
                        return formatEnum(flags, TransformFlags, 
                        /*isFlags*/
                        true);
                    }
                    Debug2.formatTransformFlags = formatTransformFlags;
                    function formatEmitFlags(flags) {
                        return formatEnum(flags, EmitFlags, 
                        /*isFlags*/
                        true);
                    }
                    Debug2.formatEmitFlags = formatEmitFlags;
                    function formatSymbolFlags(flags) {
                        return formatEnum(flags, SymbolFlags, 
                        /*isFlags*/
                        true);
                    }
                    Debug2.formatSymbolFlags = formatSymbolFlags;
                    function formatTypeFlags(flags) {
                        return formatEnum(flags, TypeFlags, 
                        /*isFlags*/
                        true);
                    }
                    Debug2.formatTypeFlags = formatTypeFlags;
                    function formatSignatureFlags(flags) {
                        return formatEnum(flags, SignatureFlags, 
                        /*isFlags*/
                        true);
                    }
                    Debug2.formatSignatureFlags = formatSignatureFlags;
                    function formatObjectFlags(flags) {
                        return formatEnum(flags, ObjectFlags, 
                        /*isFlags*/
                        true);
                    }
                    Debug2.formatObjectFlags = formatObjectFlags;
                    function formatFlowFlags(flags) {
                        return formatEnum(flags, FlowFlags, 
                        /*isFlags*/
                        true);
                    }
                    Debug2.formatFlowFlags = formatFlowFlags;
                    function formatRelationComparisonResult(result) {
                        return formatEnum(result, RelationComparisonResult, 
                        /*isFlags*/
                        true);
                    }
                    Debug2.formatRelationComparisonResult = formatRelationComparisonResult;
                    function formatCheckMode(mode) {
                        return formatEnum(mode, CheckMode, 
                        /*isFlags*/
                        true);
                    }
                    Debug2.formatCheckMode = formatCheckMode;
                    function formatSignatureCheckMode(mode) {
                        return formatEnum(mode, SignatureCheckMode, 
                        /*isFlags*/
                        true);
                    }
                    Debug2.formatSignatureCheckMode = formatSignatureCheckMode;
                    function formatTypeFacts(facts) {
                        return formatEnum(facts, TypeFacts, 
                        /*isFlags*/
                        true);
                    }
                    Debug2.formatTypeFacts = formatTypeFacts;
                    let isDebugInfoEnabled = false;
                    let flowNodeProto;
                    function attachFlowNodeDebugInfoWorker(flowNode) {
                        if (!("__debugFlowFlags" in flowNode)) {
                            Object.defineProperties(flowNode, {
                                // for use with vscode-js-debug's new customDescriptionGenerator in launch.json
                                __tsDebuggerDisplay: {
                                    value() {
                                        const flowHeader = this.flags & 2 /* Start */ ? "FlowStart" : this.flags & 4 /* BranchLabel */ ? "FlowBranchLabel" : this.flags & 8 /* LoopLabel */ ? "FlowLoopLabel" : this.flags & 16 /* Assignment */ ? "FlowAssignment" : this.flags & 32 /* TrueCondition */ ? "FlowTrueCondition" : this.flags & 64 /* FalseCondition */ ? "FlowFalseCondition" : this.flags & 128 /* SwitchClause */ ? "FlowSwitchClause" : this.flags & 256 /* ArrayMutation */ ? "FlowArrayMutation" : this.flags & 512 /* Call */ ? "FlowCall" : this.flags & 1024 /* ReduceLabel */ ? "FlowReduceLabel" : this.flags & 1 /* Unreachable */ ? "FlowUnreachable" : "UnknownFlow";
                                        const remainingFlags = this.flags & ~(2048 /* Referenced */ - 1);
                                        return `${flowHeader}${remainingFlags ? ` (${formatFlowFlags(remainingFlags)})` : ""}`;
                                    }
                                },
                                __debugFlowFlags: {
                                    get() {
                                        return formatEnum(this.flags, FlowFlags, 
                                        /*isFlags*/
                                        true);
                                    }
                                },
                                __debugToString: {
                                    value() {
                                        return formatControlFlowGraph(this);
                                    }
                                }
                            });
                        }
                    }
                    function attachFlowNodeDebugInfo(flowNode) {
                        if (isDebugInfoEnabled) {
                            if (typeof Object.setPrototypeOf === "function") {
                                if (!flowNodeProto) {
                                    flowNodeProto = Object.create(Object.prototype);
                                    attachFlowNodeDebugInfoWorker(flowNodeProto);
                                }
                                Object.setPrototypeOf(flowNode, flowNodeProto);
                            }
                            else {
                                attachFlowNodeDebugInfoWorker(flowNode);
                            }
                        }
                    }
                    Debug2.attachFlowNodeDebugInfo = attachFlowNodeDebugInfo;
                    let nodeArrayProto;
                    function attachNodeArrayDebugInfoWorker(array) {
                        if (!("__tsDebuggerDisplay" in array)) {
                            Object.defineProperties(array, {
                                __tsDebuggerDisplay: {
                                    value(defaultValue) {
                                        defaultValue = String(defaultValue).replace(/(?:,[\s\w\d_]+:[^,]+)+\]$/, "]");
                                        return `NodeArray ${defaultValue}`;
                                    }
                                }
                            });
                        }
                    }
                    function attachNodeArrayDebugInfo(array) {
                        if (isDebugInfoEnabled) {
                            if (typeof Object.setPrototypeOf === "function") {
                                if (!nodeArrayProto) {
                                    nodeArrayProto = Object.create(Array.prototype);
                                    attachNodeArrayDebugInfoWorker(nodeArrayProto);
                                }
                                Object.setPrototypeOf(array, nodeArrayProto);
                            }
                            else {
                                attachNodeArrayDebugInfoWorker(array);
                            }
                        }
                    }
                    Debug2.attachNodeArrayDebugInfo = attachNodeArrayDebugInfo;
                    function enableDebugInfo() {
                        if (isDebugInfoEnabled)
                            return;
                        const weakTypeTextMap = /* @__PURE__ */ new WeakMap();
                        const weakNodeTextMap = /* @__PURE__ */ new WeakMap();
                        Object.defineProperties(objectAllocator.getSymbolConstructor().prototype, {
                            // for use with vscode-js-debug's new customDescriptionGenerator in launch.json
                            __tsDebuggerDisplay: {
                                value() {
                                    const symbolHeader = this.flags & 33554432 /* Transient */ ? "TransientSymbol" : "Symbol";
                                    const remainingSymbolFlags = this.flags & ~33554432 /* Transient */;
                                    return `${symbolHeader} '${symbolName(this)}'${remainingSymbolFlags ? ` (${formatSymbolFlags(remainingSymbolFlags)})` : ""}`;
                                }
                            },
                            __debugFlags: {
                                get() {
                                    return formatSymbolFlags(this.flags);
                                }
                            }
                        });
                        Object.defineProperties(objectAllocator.getTypeConstructor().prototype, {
                            // for use with vscode-js-debug's new customDescriptionGenerator in launch.json
                            __tsDebuggerDisplay: {
                                value() {
                                    const typeHeader = this.flags & 67359327 /* Intrinsic */ ? `IntrinsicType ${this.intrinsicName}${this.debugIntrinsicName ? ` (${this.debugIntrinsicName})` : ""}` : this.flags & 98304 /* Nullable */ ? "NullableType" : this.flags & 384 /* StringOrNumberLiteral */ ? `LiteralType ${JSON.stringify(this.value)}` : this.flags & 2048 /* BigIntLiteral */ ? `LiteralType ${this.value.negative ? "-" : ""}${this.value.base10Value}n` : this.flags & 8192 /* UniqueESSymbol */ ? "UniqueESSymbolType" : this.flags & 32 /* Enum */ ? "EnumType" : this.flags & 1048576 /* Union */ ? "UnionType" : this.flags & 2097152 /* Intersection */ ? "IntersectionType" : this.flags & 4194304 /* Index */ ? "IndexType" : this.flags & 8388608 /* IndexedAccess */ ? "IndexedAccessType" : this.flags & 16777216 /* Conditional */ ? "ConditionalType" : this.flags & 33554432 /* Substitution */ ? "SubstitutionType" : this.flags & 262144 /* TypeParameter */ ? "TypeParameter" : this.flags & 524288 /* Object */ ? this.objectFlags & 3 /* ClassOrInterface */ ? "InterfaceType" : this.objectFlags & 4 /* Reference */ ? "TypeReference" : this.objectFlags & 8 /* Tuple */ ? "TupleType" : this.objectFlags & 16 /* Anonymous */ ? "AnonymousType" : this.objectFlags & 32 /* Mapped */ ? "MappedType" : this.objectFlags & 1024 /* ReverseMapped */ ? "ReverseMappedType" : this.objectFlags & 256 /* EvolvingArray */ ? "EvolvingArrayType" : "ObjectType" : "Type";
                                    const remainingObjectFlags = this.flags & 524288 /* Object */ ? this.objectFlags & ~1343 /* ObjectTypeKindMask */ : 0;
                                    return `${typeHeader}${this.symbol ? ` '${symbolName(this.symbol)}'` : ""}${remainingObjectFlags ? ` (${formatObjectFlags(remainingObjectFlags)})` : ""}`;
                                }
                            },
                            __debugFlags: {
                                get() {
                                    return formatTypeFlags(this.flags);
                                }
                            },
                            __debugObjectFlags: {
                                get() {
                                    return this.flags & 524288 /* Object */ ? formatObjectFlags(this.objectFlags) : "";
                                }
                            },
                            __debugTypeToString: {
                                value() {
                                    let text = weakTypeTextMap.get(this);
                                    if (text === void 0) {
                                        text = this.checker.typeToString(this);
                                        weakTypeTextMap.set(this, text);
                                    }
                                    return text;
                                }
                            }
                        });
                        Object.defineProperties(objectAllocator.getSignatureConstructor().prototype, {
                            __debugFlags: {
                                get() {
                                    return formatSignatureFlags(this.flags);
                                }
                            },
                            __debugSignatureToString: {
                                value() {
                                    var _a;
                                    return (_a = this.checker) == null ? void 0 : _a.signatureToString(this);
                                }
                            }
                        });
                        const nodeConstructors = [
                            objectAllocator.getNodeConstructor(),
                            objectAllocator.getIdentifierConstructor(),
                            objectAllocator.getTokenConstructor(),
                            objectAllocator.getSourceFileConstructor()
                        ];
                        for (const ctor of nodeConstructors) {
                            if (!hasProperty(ctor.prototype, "__debugKind")) {
                                Object.defineProperties(ctor.prototype, {
                                    // for use with vscode-js-debug's new customDescriptionGenerator in launch.json
                                    __tsDebuggerDisplay: {
                                        value() {
                                            const nodeHeader = isGeneratedIdentifier(this) ? "GeneratedIdentifier" : isIdentifier(this) ? `Identifier '${idText(this)}'` : isPrivateIdentifier(this) ? `PrivateIdentifier '${idText(this)}'` : isStringLiteral(this) ? `StringLiteral ${JSON.stringify(this.text.length < 10 ? this.text : this.text.slice(10) + "...")}` : isNumericLiteral(this) ? `NumericLiteral ${this.text}` : isBigIntLiteral(this) ? `BigIntLiteral ${this.text}n` : isTypeParameterDeclaration(this) ? "TypeParameterDeclaration" : isParameter(this) ? "ParameterDeclaration" : isConstructorDeclaration(this) ? "ConstructorDeclaration" : isGetAccessorDeclaration(this) ? "GetAccessorDeclaration" : isSetAccessorDeclaration(this) ? "SetAccessorDeclaration" : isCallSignatureDeclaration(this) ? "CallSignatureDeclaration" : isConstructSignatureDeclaration(this) ? "ConstructSignatureDeclaration" : isIndexSignatureDeclaration(this) ? "IndexSignatureDeclaration" : isTypePredicateNode(this) ? "TypePredicateNode" : isTypeReferenceNode(this) ? "TypeReferenceNode" : isFunctionTypeNode(this) ? "FunctionTypeNode" : isConstructorTypeNode(this) ? "ConstructorTypeNode" : isTypeQueryNode(this) ? "TypeQueryNode" : isTypeLiteralNode(this) ? "TypeLiteralNode" : isArrayTypeNode(this) ? "ArrayTypeNode" : isTupleTypeNode(this) ? "TupleTypeNode" : isOptionalTypeNode(this) ? "OptionalTypeNode" : isRestTypeNode(this) ? "RestTypeNode" : isUnionTypeNode(this) ? "UnionTypeNode" : isIntersectionTypeNode(this) ? "IntersectionTypeNode" : isConditionalTypeNode(this) ? "ConditionalTypeNode" : isInferTypeNode(this) ? "InferTypeNode" : isParenthesizedTypeNode(this) ? "ParenthesizedTypeNode" : isThisTypeNode(this) ? "ThisTypeNode" : isTypeOperatorNode(this) ? "TypeOperatorNode" : isIndexedAccessTypeNode(this) ? "IndexedAccessTypeNode" : isMappedTypeNode(this) ? "MappedTypeNode" : isLiteralTypeNode(this) ? "LiteralTypeNode" : isNamedTupleMember(this) ? "NamedTupleMember" : isImportTypeNode(this) ? "ImportTypeNode" : formatSyntaxKind(this.kind);
                                            return `${nodeHeader}${this.flags ? ` (${formatNodeFlags(this.flags)})` : ""}`;
                                        }
                                    },
                                    __debugKind: {
                                        get() {
                                            return formatSyntaxKind(this.kind);
                                        }
                                    },
                                    __debugNodeFlags: {
                                        get() {
                                            return formatNodeFlags(this.flags);
                                        }
                                    },
                                    __debugModifierFlags: {
                                        get() {
                                            return formatModifierFlags(getEffectiveModifierFlagsNoCache(this));
                                        }
                                    },
                                    __debugTransformFlags: {
                                        get() {
                                            return formatTransformFlags(this.transformFlags);
                                        }
                                    },
                                    __debugIsParseTreeNode: {
                                        get() {
                                            return isParseTreeNode(this);
                                        }
                                    },
                                    __debugEmitFlags: {
                                        get() {
                                            return formatEmitFlags(getEmitFlags(this));
                                        }
                                    },
                                    __debugGetText: {
                                        value(includeTrivia) {
                                            if (nodeIsSynthesized(this))
                                                return "";
                                            let text = weakNodeTextMap.get(this);
                                            if (text === void 0) {
                                                const parseNode = getParseTreeNode(this);
                                                const sourceFile = parseNode && getSourceFileOfNode(parseNode);
                                                text = sourceFile ? getSourceTextOfNodeFromSourceFile(sourceFile, parseNode, includeTrivia) : "";
                                                weakNodeTextMap.set(this, text);
                                            }
                                            return text;
                                        }
                                    }
                                });
                            }
                        }
                        isDebugInfoEnabled = true;
                    }
                    Debug2.enableDebugInfo = enableDebugInfo;
                    function formatVariance(varianceFlags) {
                        const variance = varianceFlags & 7 /* VarianceMask */;
                        let result = variance === 0 /* Invariant */ ? "in out" : variance === 3 /* Bivariant */ ? "[bivariant]" : variance === 2 /* Contravariant */ ? "in" : variance === 1 /* Covariant */ ? "out" : variance === 4 /* Independent */ ? "[independent]" : "";
                        if (varianceFlags & 8 /* Unmeasurable */) {
                            result += " (unmeasurable)";
                        }
                        else if (varianceFlags & 16 /* Unreliable */) {
                            result += " (unreliable)";
                        }
                        return result;
                    }
                    Debug2.formatVariance = formatVariance;
                    class DebugTypeMapper {
                        __debugToString() {
                            var _a;
                            type(this);
                            switch (this.kind) {
                                case 3 /* Function */:
                                    return ((_a = this.debugInfo) == null ? void 0 : _a.call(this)) || "(function mapper)";
                                case 0 /* Simple */:
                                    return `${this.source.__debugTypeToString()} -> ${this.target.__debugTypeToString()}`;
                                case 1 /* Array */:
                                    return zipWith(this.sources, this.targets || map(this.sources, () => "any"), (s, t) => `${s.__debugTypeToString()} -> ${typeof t === "string" ? t : t.__debugTypeToString()}`).join(", ");
                                case 2 /* Deferred */:
                                    return zipWith(this.sources, this.targets, (s, t) => `${s.__debugTypeToString()} -> ${t().__debugTypeToString()}`).join(", ");
                                case 5 /* Merged */:
                                case 4 /* Composite */:
                                    return `m1: ${this.mapper1.__debugToString().split("\n").join("\n    ")}
m2: ${this.mapper2.__debugToString().split("\n").join("\n    ")}`;
                                default:
                                    return assertNever(this);
                            }
                        }
                    }
                    Debug2.DebugTypeMapper = DebugTypeMapper;
                    function attachDebugPrototypeIfDebug(mapper) {
                        if (Debug2.isDebugging) {
                            return Object.setPrototypeOf(mapper, DebugTypeMapper.prototype);
                        }
                        return mapper;
                    }
                    Debug2.attachDebugPrototypeIfDebug = attachDebugPrototypeIfDebug;
                    function printControlFlowGraph(flowNode) {
                        return console.log(formatControlFlowGraph(flowNode));
                    }
                    Debug2.printControlFlowGraph = printControlFlowGraph;
                    function formatControlFlowGraph(flowNode) {
                        let nextDebugFlowId = -1;
                        function getDebugFlowNodeId(f) {
                            if (!f.id) {
                                f.id = nextDebugFlowId;
                                nextDebugFlowId--;
                            }
                            return f.id;
                        }
                        let BoxCharacter;
                        ((BoxCharacter2) => {
                            BoxCharacter2["lr"] = "\u2500";
                            BoxCharacter2["ud"] = "\u2502";
                            BoxCharacter2["dr"] = "\u256D";
                            BoxCharacter2["dl"] = "\u256E";
                            BoxCharacter2["ul"] = "\u256F";
                            BoxCharacter2["ur"] = "\u2570";
                            BoxCharacter2["udr"] = "\u251C";
                            BoxCharacter2["udl"] = "\u2524";
                            BoxCharacter2["dlr"] = "\u252C";
                            BoxCharacter2["ulr"] = "\u2534";
                            BoxCharacter2["udlr"] = "\u256B";
                        })(BoxCharacter || (BoxCharacter = {}));
                        let Connection;
                        ((Connection2) => {
                            Connection2[Connection2["None"] = 0] = "None";
                            Connection2[Connection2["Up"] = 1] = "Up";
                            Connection2[Connection2["Down"] = 2] = "Down";
                            Connection2[Connection2["Left"] = 4] = "Left";
                            Connection2[Connection2["Right"] = 8] = "Right";
                            Connection2[Connection2["UpDown"] = 3] = "UpDown";
                            Connection2[Connection2["LeftRight"] = 12] = "LeftRight";
                            Connection2[Connection2["UpLeft"] = 5] = "UpLeft";
                            Connection2[Connection2["UpRight"] = 9] = "UpRight";
                            Connection2[Connection2["DownLeft"] = 6] = "DownLeft";
                            Connection2[Connection2["DownRight"] = 10] = "DownRight";
                            Connection2[Connection2["UpDownLeft"] = 7] = "UpDownLeft";
                            Connection2[Connection2["UpDownRight"] = 11] = "UpDownRight";
                            Connection2[Connection2["UpLeftRight"] = 13] = "UpLeftRight";
                            Connection2[Connection2["DownLeftRight"] = 14] = "DownLeftRight";
                            Connection2[Connection2["UpDownLeftRight"] = 15] = "UpDownLeftRight";
                            Connection2[Connection2["NoChildren"] = 16] = "NoChildren";
                        })(Connection || (Connection = {}));
                        const hasAntecedentFlags = 16 /* Assignment */ | 96 /* Condition */ | 128 /* SwitchClause */ | 256 /* ArrayMutation */ | 512 /* Call */ | 1024 /* ReduceLabel */;
                        const hasNodeFlags = 2 /* Start */ | 16 /* Assignment */ | 512 /* Call */ | 96 /* Condition */ | 256 /* ArrayMutation */;
                        const links = /* @__PURE__ */ Object.create(
                        /*o*/
                        null);
                        const nodes = [];
                        const edges = [];
                        const root = buildGraphNode(flowNode, /* @__PURE__ */ new Set());
                        for (const node of nodes) {
                            node.text = renderFlowNode(node.flowNode, node.circular);
                            computeLevel(node);
                        }
                        const height = computeHeight(root);
                        const columnWidths = computeColumnWidths(height);
                        computeLanes(root, 0);
                        return renderGraph();
                        function isFlowSwitchClause(f) {
                            return !!(f.flags & 128 /* SwitchClause */);
                        }
                        function hasAntecedents(f) {
                            return !!(f.flags & 12 /* Label */) && !!f.antecedents;
                        }
                        function hasAntecedent(f) {
                            return !!(f.flags & hasAntecedentFlags);
                        }
                        function hasNode(f) {
                            return !!(f.flags & hasNodeFlags);
                        }
                        function getChildren(node) {
                            const children = [];
                            for (const edge of node.edges) {
                                if (edge.source === node) {
                                    children.push(edge.target);
                                }
                            }
                            return children;
                        }
                        function getParents(node) {
                            const parents = [];
                            for (const edge of node.edges) {
                                if (edge.target === node) {
                                    parents.push(edge.source);
                                }
                            }
                            return parents;
                        }
                        function buildGraphNode(flowNode2, seen) {
                            const id = getDebugFlowNodeId(flowNode2);
                            let graphNode = links[id];
                            if (graphNode && seen.has(flowNode2)) {
                                graphNode.circular = true;
                                graphNode = {
                                    id: -1,
                                    flowNode: flowNode2,
                                    edges: [],
                                    text: "",
                                    lane: -1,
                                    endLane: -1,
                                    level: -1,
                                    circular: "circularity"
                                };
                                nodes.push(graphNode);
                                return graphNode;
                            }
                            seen.add(flowNode2);
                            if (!graphNode) {
                                links[id] = graphNode = { id, flowNode: flowNode2, edges: [], text: "", lane: -1, endLane: -1, level: -1, circular: false };
                                nodes.push(graphNode);
                                if (hasAntecedents(flowNode2)) {
                                    for (const antecedent of flowNode2.antecedents) {
                                        buildGraphEdge(graphNode, antecedent, seen);
                                    }
                                }
                                else if (hasAntecedent(flowNode2)) {
                                    buildGraphEdge(graphNode, flowNode2.antecedent, seen);
                                }
                            }
                            seen.delete(flowNode2);
                            return graphNode;
                        }
                        function buildGraphEdge(source, antecedent, seen) {
                            const target = buildGraphNode(antecedent, seen);
                            const edge = { source, target };
                            edges.push(edge);
                            source.edges.push(edge);
                            target.edges.push(edge);
                        }
                        function computeLevel(node) {
                            if (node.level !== -1) {
                                return node.level;
                            }
                            let level = 0;
                            for (const parent2 of getParents(node)) {
                                level = Math.max(level, computeLevel(parent2) + 1);
                            }
                            return node.level = level;
                        }
                        function computeHeight(node) {
                            let height2 = 0;
                            for (const child of getChildren(node)) {
                                height2 = Math.max(height2, computeHeight(child));
                            }
                            return height2 + 1;
                        }
                        function computeColumnWidths(height2) {
                            const columns = fill(Array(height2), 0);
                            for (const node of nodes) {
                                columns[node.level] = Math.max(columns[node.level], node.text.length);
                            }
                            return columns;
                        }
                        function computeLanes(node, lane) {
                            if (node.lane === -1) {
                                node.lane = lane;
                                node.endLane = lane;
                                const children = getChildren(node);
                                for (let i = 0; i < children.length; i++) {
                                    if (i > 0)
                                        lane++;
                                    const child = children[i];
                                    computeLanes(child, lane);
                                    if (child.endLane > node.endLane) {
                                        lane = child.endLane;
                                    }
                                }
                                node.endLane = lane;
                            }
                        }
                        function getHeader(flags) {
                            if (flags & 2 /* Start */)
                                return "Start";
                            if (flags & 4 /* BranchLabel */)
                                return "Branch";
                            if (flags & 8 /* LoopLabel */)
                                return "Loop";
                            if (flags & 16 /* Assignment */)
                                return "Assignment";
                            if (flags & 32 /* TrueCondition */)
                                return "True";
                            if (flags & 64 /* FalseCondition */)
                                return "False";
                            if (flags & 128 /* SwitchClause */)
                                return "SwitchClause";
                            if (flags & 256 /* ArrayMutation */)
                                return "ArrayMutation";
                            if (flags & 512 /* Call */)
                                return "Call";
                            if (flags & 1024 /* ReduceLabel */)
                                return "ReduceLabel";
                            if (flags & 1 /* Unreachable */)
                                return "Unreachable";
                            throw new Error();
                        }
                        function getNodeText(node) {
                            const sourceFile = getSourceFileOfNode(node);
                            return getSourceTextOfNodeFromSourceFile(sourceFile, node, 
                            /*includeTrivia*/
                            false);
                        }
                        function renderFlowNode(flowNode2, circular) {
                            let text = getHeader(flowNode2.flags);
                            if (circular) {
                                text = `${text}#${getDebugFlowNodeId(flowNode2)}`;
                            }
                            if (hasNode(flowNode2)) {
                                if (flowNode2.node) {
                                    text += ` (${getNodeText(flowNode2.node)})`;
                                }
                            }
                            else if (isFlowSwitchClause(flowNode2)) {
                                const clauses = [];
                                for (let i = flowNode2.clauseStart; i < flowNode2.clauseEnd; i++) {
                                    const clause = flowNode2.switchStatement.caseBlock.clauses[i];
                                    if (isDefaultClause(clause)) {
                                        clauses.push("default");
                                    }
                                    else {
                                        clauses.push(getNodeText(clause.expression));
                                    }
                                }
                                text += ` (${clauses.join(", ")})`;
                            }
                            return circular === "circularity" ? `Circular(${text})` : text;
                        }
                        function renderGraph() {
                            const columnCount = columnWidths.length;
                            const laneCount = nodes.reduce((x, n) => Math.max(x, n.lane), 0) + 1;
                            const lanes = fill(Array(laneCount), "");
                            const grid = columnWidths.map(() => Array(laneCount));
                            const connectors = columnWidths.map(() => fill(Array(laneCount), 0));
                            for (const node of nodes) {
                                grid[node.level][node.lane] = node;
                                const children = getChildren(node);
                                for (let i = 0; i < children.length; i++) {
                                    const child = children[i];
                                    let connector = 8 /* Right */;
                                    if (child.lane === node.lane)
                                        connector |= 4 /* Left */;
                                    if (i > 0)
                                        connector |= 1 /* Up */;
                                    if (i < children.length - 1)
                                        connector |= 2 /* Down */;
                                    connectors[node.level][child.lane] |= connector;
                                }
                                if (children.length === 0) {
                                    connectors[node.level][node.lane] |= 16 /* NoChildren */;
                                }
                                const parents = getParents(node);
                                for (let i = 0; i < parents.length; i++) {
                                    const parent2 = parents[i];
                                    let connector = 4 /* Left */;
                                    if (i > 0)
                                        connector |= 1 /* Up */;
                                    if (i < parents.length - 1)
                                        connector |= 2 /* Down */;
                                    connectors[node.level - 1][parent2.lane] |= connector;
                                }
                            }
                            for (let column = 0; column < columnCount; column++) {
                                for (let lane = 0; lane < laneCount; lane++) {
                                    const left = column > 0 ? connectors[column - 1][lane] : 0;
                                    const above = lane > 0 ? connectors[column][lane - 1] : 0;
                                    let connector = connectors[column][lane];
                                    if (!connector) {
                                        if (left & 8 /* Right */)
                                            connector |= 12 /* LeftRight */;
                                        if (above & 2 /* Down */)
                                            connector |= 3 /* UpDown */;
                                        connectors[column][lane] = connector;
                                    }
                                }
                            }
                            for (let column = 0; column < columnCount; column++) {
                                for (let lane = 0; lane < lanes.length; lane++) {
                                    const connector = connectors[column][lane];
                                    const fill2 = connector & 4 /* Left */ ? "\u2500" /* lr */ : " ";
                                    const node = grid[column][lane];
                                    if (!node) {
                                        if (column < columnCount - 1) {
                                            writeLane(lane, repeat(fill2, columnWidths[column] + 1));
                                        }
                                    }
                                    else {
                                        writeLane(lane, node.text);
                                        if (column < columnCount - 1) {
                                            writeLane(lane, " ");
                                            writeLane(lane, repeat(fill2, columnWidths[column] - node.text.length));
                                        }
                                    }
                                    writeLane(lane, getBoxCharacter(connector));
                                    writeLane(lane, connector & 8 /* Right */ && column < columnCount - 1 && !grid[column + 1][lane] ? "\u2500" /* lr */ : " ");
                                }
                            }
                            return `
${lanes.join("\n")}
`;
                            function writeLane(lane, text) {
                                lanes[lane] += text;
                            }
                        }
                        function getBoxCharacter(connector) {
                            switch (connector) {
                                case 3 /* UpDown */:
                                    return "\u2502" /* ud */;
                                case 12 /* LeftRight */:
                                    return "\u2500" /* lr */;
                                case 5 /* UpLeft */:
                                    return "\u256F" /* ul */;
                                case 9 /* UpRight */:
                                    return "\u2570" /* ur */;
                                case 6 /* DownLeft */:
                                    return "\u256E" /* dl */;
                                case 10 /* DownRight */:
                                    return "\u256D" /* dr */;
                                case 7 /* UpDownLeft */:
                                    return "\u2524" /* udl */;
                                case 11 /* UpDownRight */:
                                    return "\u251C" /* udr */;
                                case 13 /* UpLeftRight */:
                                    return "\u2534" /* ulr */;
                                case 14 /* DownLeftRight */:
                                    return "\u252C" /* dlr */;
                                case 15 /* UpDownLeftRight */:
                                    return "\u256B" /* udlr */;
                            }
                            return " ";
                        }
                        function fill(array, value) {
                            if (array.fill) {
                                array.fill(value);
                            }
                            else {
                                for (let i = 0; i < array.length; i++) {
                                    array[i] = value;
                                }
                            }
                            return array;
                        }
                        function repeat(ch, length2) {
                            if (ch.repeat) {
                                return length2 > 0 ? ch.repeat(length2) : "";
                            }
                            let s = "";
                            while (s.length < length2) {
                                s += ch;
                            }
                            return s;
                        }
                    }
                    Debug2.formatControlFlowGraph = formatControlFlowGraph;
                })(Debug || (Debug = {}));
            }
        });
        // src/compiler/semver.ts
        function tryParseComponents(text) {
            const match = versionRegExp.exec(text);
            if (!match)
                return void 0;
            const [, major, minor = "0", patch = "0", prerelease = "", build2 = ""] = match;
            if (prerelease && !prereleaseRegExp.test(prerelease))
                return void 0;
            if (build2 && !buildRegExp.test(build2))
                return void 0;
            return {
                major: parseInt(major, 10),
                minor: parseInt(minor, 10),
                patch: parseInt(patch, 10),
                prerelease,
                build: build2
            };
        }
        function comparePrereleaseIdentifiers(left, right) {
            if (left === right)
                return 0 /* EqualTo */;
            if (left.length === 0)
                return right.length === 0 ? 0 /* EqualTo */ : 1 /* GreaterThan */;
            if (right.length === 0)
                return -1 /* LessThan */;
            const length2 = Math.min(left.length, right.length);
            for (let i = 0; i < length2; i++) {
                const leftIdentifier = left[i];
                const rightIdentifier = right[i];
                if (leftIdentifier === rightIdentifier)
                    continue;
                const leftIsNumeric = numericIdentifierRegExp.test(leftIdentifier);
                const rightIsNumeric = numericIdentifierRegExp.test(rightIdentifier);
                if (leftIsNumeric || rightIsNumeric) {
                    if (leftIsNumeric !== rightIsNumeric)
                        return leftIsNumeric ? -1 /* LessThan */ : 1 /* GreaterThan */;
                    const result = compareValues(+leftIdentifier, +rightIdentifier);
                    if (result)
                        return result;
                }
                else {
                    const result = compareStringsCaseSensitive(leftIdentifier, rightIdentifier);
                    if (result)
                        return result;
                }
            }
            return compareValues(left.length, right.length);
        }
        function parseRange(text) {
            const alternatives = [];
            for (let range of text.trim().split(logicalOrRegExp)) {
                if (!range)
                    continue;
                const comparators = [];
                range = range.trim();
                const match = hyphenRegExp.exec(range);
                if (match) {
                    if (!parseHyphen(match[1], match[2], comparators))
                        return void 0;
                }
                else {
                    for (const simple of range.split(whitespaceRegExp)) {
                        const match2 = rangeRegExp.exec(simple.trim());
                        if (!match2 || !parseComparator(match2[1], match2[2], comparators))
                            return void 0;
                    }
                }
                alternatives.push(comparators);
            }
            return alternatives;
        }
        function parsePartial(text) {
            const match = partialRegExp.exec(text);
            if (!match)
                return void 0;
            const [, major, minor = "*", patch = "*", prerelease, build2] = match;
            const version2 = new Version(isWildcard(major) ? 0 : parseInt(major, 10), isWildcard(major) || isWildcard(minor) ? 0 : parseInt(minor, 10), isWildcard(major) || isWildcard(minor) || isWildcard(patch) ? 0 : parseInt(patch, 10), prerelease, build2);
            return { version: version2, major, minor, patch };
        }
        function parseHyphen(left, right, comparators) {
            const leftResult = parsePartial(left);
            if (!leftResult)
                return false;
            const rightResult = parsePartial(right);
            if (!rightResult)
                return false;
            if (!isWildcard(leftResult.major)) {
                comparators.push(createComparator(">=", leftResult.version));
            }
            if (!isWildcard(rightResult.major)) {
                comparators.push(isWildcard(rightResult.minor) ? createComparator("<", rightResult.version.increment("major")) : isWildcard(rightResult.patch) ? createComparator("<", rightResult.version.increment("minor")) : createComparator("<=", rightResult.version));
            }
            return true;
        }
        function parseComparator(operator, text, comparators) {
            const result = parsePartial(text);
            if (!result)
                return false;
            const { version: version2, major, minor, patch } = result;
            if (!isWildcard(major)) {
                switch (operator) {
                    case "~":
                        comparators.push(createComparator(">=", version2));
                        comparators.push(createComparator("<", version2.increment(isWildcard(minor) ? "major" : "minor")));
                        break;
                    case "^":
                        comparators.push(createComparator(">=", version2));
                        comparators.push(createComparator("<", version2.increment(version2.major > 0 || isWildcard(minor) ? "major" : version2.minor > 0 || isWildcard(patch) ? "minor" : "patch")));
                        break;
                    case "<":
                    case ">=":
                        comparators.push(isWildcard(minor) || isWildcard(patch) ? createComparator(operator, version2.with({ prerelease: "0" })) : createComparator(operator, version2));
                        break;
                    case "<=":
                    case ">":
                        comparators.push(isWildcard(minor) ? createComparator(operator === "<=" ? "<" : ">=", version2.increment("major").with({ prerelease: "0" })) : isWildcard(patch) ? createComparator(operator === "<=" ? "<" : ">=", version2.increment("minor").with({ prerelease: "0" })) : createComparator(operator, version2));
                        break;
                    case "=":
                    case void 0:
                        if (isWildcard(minor) || isWildcard(patch)) {
                            comparators.push(createComparator(">=", version2.with({ prerelease: "0" })));
                            comparators.push(createComparator("<", version2.increment(isWildcard(minor) ? "major" : "minor").with({ prerelease: "0" })));
                        }
                        else {
                            comparators.push(createComparator("=", version2));
                        }
                        break;
                    default:
                        return false;
                }
            }
            else if (operator === "<" || operator === ">") {
                comparators.push(createComparator("<", Version.zero));
            }
            return true;
        }
        function isWildcard(part) {
            return part === "*" || part === "x" || part === "X";
        }
        function createComparator(operator, operand) {
            return { operator, operand };
        }
        function testDisjunction(version2, alternatives) {
            if (alternatives.length === 0)
                return true;
            for (const alternative of alternatives) {
                if (testAlternative(version2, alternative))
                    return true;
            }
            return false;
        }
        function testAlternative(version2, comparators) {
            for (const comparator of comparators) {
                if (!testComparator(version2, comparator.operator, comparator.operand))
                    return false;
            }
            return true;
        }
        function testComparator(version2, operator, operand) {
            const cmp = version2.compareTo(operand);
            switch (operator) {
                case "<":
                    return cmp < 0;
                case "<=":
                    return cmp <= 0;
                case ">":
                    return cmp > 0;
                case ">=":
                    return cmp >= 0;
                case "=":
                    return cmp === 0;
                default:
                    return Debug.assertNever(operator);
            }
        }
        function formatDisjunction(alternatives) {
            return map(alternatives, formatAlternative).join(" || ") || "*";
        }
        function formatAlternative(comparators) {
            return map(comparators, formatComparator).join(" ");
        }
        function formatComparator(comparator) {
            return `${comparator.operator}${comparator.operand}`;
        }
        var versionRegExp, prereleaseRegExp, prereleasePartRegExp, buildRegExp, buildPartRegExp, numericIdentifierRegExp, _Version, Version, VersionRange, logicalOrRegExp, whitespaceRegExp, partialRegExp, hyphenRegExp, rangeRegExp;
        var init_semver = __esm({
            "src/compiler/semver.ts"() {
                "use strict";
                init_ts2();
                versionRegExp = /^(0|[1-9]\d*)(?:\.(0|[1-9]\d*)(?:\.(0|[1-9]\d*)(?:-([a-z0-9-.]+))?(?:\+([a-z0-9-.]+))?)?)?$/i;
                prereleaseRegExp = /^(?:0|[1-9]\d*|[a-z-][a-z0-9-]*)(?:\.(?:0|[1-9]\d*|[a-z-][a-z0-9-]*))*$/i;
                prereleasePartRegExp = /^(?:0|[1-9]\d*|[a-z-][a-z0-9-]*)$/i;
                buildRegExp = /^[a-z0-9-]+(?:\.[a-z0-9-]+)*$/i;
                buildPartRegExp = /^[a-z0-9-]+$/i;
                numericIdentifierRegExp = /^(0|[1-9]\d*)$/;
                _Version = class _Version {
                    constructor(major, minor = 0, patch = 0, prerelease = "", build2 = "") {
                        if (typeof major === "string") {
                            const result = Debug.checkDefined(tryParseComponents(major), "Invalid version");
                            ({ major, minor, patch, prerelease, build: build2 } = result);
                        }
                        Debug.assert(major >= 0, "Invalid argument: major");
                        Debug.assert(minor >= 0, "Invalid argument: minor");
                        Debug.assert(patch >= 0, "Invalid argument: patch");
                        const prereleaseArray = prerelease ? isArray(prerelease) ? prerelease : prerelease.split(".") : emptyArray;
                        const buildArray = build2 ? isArray(build2) ? build2 : build2.split(".") : emptyArray;
                        Debug.assert(every(prereleaseArray, (s) => prereleasePartRegExp.test(s)), "Invalid argument: prerelease");
                        Debug.assert(every(buildArray, (s) => buildPartRegExp.test(s)), "Invalid argument: build");
                        this.major = major;
                        this.minor = minor;
                        this.patch = patch;
                        this.prerelease = prereleaseArray;
                        this.build = buildArray;
                    }
                    static tryParse(text) {
                        const result = tryParseComponents(text);
                        if (!result)
                            return void 0;
                        const { major, minor, patch, prerelease, build: build2 } = result;
                        return new _Version(major, minor, patch, prerelease, build2);
                    }
                    compareTo(other) {
                        if (this === other)
                            return 0 /* EqualTo */;
                        if (other === void 0)
                            return 1 /* GreaterThan */;
                        return compareValues(this.major, other.major) || compareValues(this.minor, other.minor) || compareValues(this.patch, other.patch) || comparePrereleaseIdentifiers(this.prerelease, other.prerelease);
                    }
                    increment(field) {
                        switch (field) {
                            case "major":
                                return new _Version(this.major + 1, 0, 0);
                            case "minor":
                                return new _Version(this.major, this.minor + 1, 0);
                            case "patch":
                                return new _Version(this.major, this.minor, this.patch + 1);
                            default:
                                return Debug.assertNever(field);
                        }
                    }
                    with(fields) {
                        const { major = this.major, minor = this.minor, patch = this.patch, prerelease = this.prerelease, build: build2 = this.build } = fields;
                        return new _Version(major, minor, patch, prerelease, build2);
                    }
                    toString() {
                        let result = `${this.major}.${this.minor}.${this.patch}`;
                        if (some(this.prerelease))
                            result += `-${this.prerelease.join(".")}`;
                        if (some(this.build))
                            result += `+${this.build.join(".")}`;
                        return result;
                    }
                };
                _Version.zero = new _Version(0, 0, 0, ["0"]);
                Version = _Version;
                VersionRange = class _VersionRange {
                    constructor(spec) {
                        this._alternatives = spec ? Debug.checkDefined(parseRange(spec), "Invalid range spec.") : emptyArray;
                    }
                    static tryParse(text) {
                        const sets = parseRange(text);
                        if (sets) {
                            const range = new _VersionRange("");
                            range._alternatives = sets;
                            return range;
                        }
                        return void 0;
                    }
                    /**
                     * Tests whether a version matches the range. This is equivalent to `satisfies(version, range, { includePrerelease: true })`.
                     * in `node-semver`.
                     */
                    test(version2) {
                        if (typeof version2 === "string")
                            version2 = new Version(version2);
                        return testDisjunction(version2, this._alternatives);
                    }
                    toString() {
                        return formatDisjunction(this._alternatives);
                    }
                };
                logicalOrRegExp = /\|\|/g;
                whitespaceRegExp = /\s+/g;
                partialRegExp = /^([xX*0]|[1-9]\d*)(?:\.([xX*0]|[1-9]\d*)(?:\.([xX*0]|[1-9]\d*)(?:-([a-z0-9-.]+))?(?:\+([a-z0-9-.]+))?)?)?$/i;
                hyphenRegExp = /^\s*([a-z0-9-+.*]+)\s+-\s+([a-z0-9-+.*]+)\s*$/i;
                rangeRegExp = /^(~|\^|<|<=|>|>=|=)?\s*([a-z0-9-+.*]+)$/i;
            }
        });
        // src/compiler/performanceCore.ts
        function hasRequiredAPI(performance2, PerformanceObserver2) {
            return typeof performance2 === "object" && typeof performance2.timeOrigin === "number" && typeof performance2.mark === "function" && typeof performance2.measure === "function" && typeof performance2.now === "function" && typeof performance2.clearMarks === "function" && typeof performance2.clearMeasures === "function" && typeof PerformanceObserver2 === "function";
        }
        function tryGetWebPerformanceHooks() {
            if (typeof performance === "object" && typeof PerformanceObserver === "function" && hasRequiredAPI(performance, PerformanceObserver)) {
                return {
                    // For now we always write native performance events when running in the browser. We may
                    // make this conditional in the future if we find that native web performance hooks
                    // in the browser also slow down compilation.
                    shouldWriteNativeEvents: true,
                    performance,
                    PerformanceObserver
                };
            }
        }
        function tryGetNodePerformanceHooks() {
            if (isNodeLikeSystem()) {
                try {
                    const { performance: performance2, PerformanceObserver: PerformanceObserver2 } = require("perf_hooks");
                    if (hasRequiredAPI(performance2, PerformanceObserver2)) {
                        return {
                            // By default, only write native events when generating a cpu profile or using the v8 profiler.
                            shouldWriteNativeEvents: false,
                            performance: performance2,
                            PerformanceObserver: PerformanceObserver2
                        };
                    }
                }
                catch {
                }
            }
        }
        function tryGetNativePerformanceHooks() {
            return nativePerformanceHooks;
        }
        var nativePerformanceHooks, nativePerformance, timestamp;
        var init_performanceCore = __esm({
            "src/compiler/performanceCore.ts"() {
                "use strict";
                init_ts2();
                nativePerformanceHooks = tryGetWebPerformanceHooks() || tryGetNodePerformanceHooks();
                nativePerformance = nativePerformanceHooks == null ? void 0 : nativePerformanceHooks.performance;
                timestamp = nativePerformance ? () => nativePerformance.now() : Date.now ? Date.now : () => +new Date();
            }
        });
        // src/compiler/perfLogger.ts
        var etwModule, perfLogger;
        var init_perfLogger = __esm({
            "src/compiler/perfLogger.ts"() {
                "use strict";
                try {
                    const etwModulePath = process.env.TS_ETW_MODULE_PATH ?? "./node_modules/@microsoft/typescript-etw";
                    etwModule = require(etwModulePath);
                }
                catch (e) {
                    etwModule = void 0;
                }
                perfLogger = (etwModule == null ? void 0 : etwModule.logEvent) ? etwModule : void 0;
            }
        });
        // src/compiler/performance.ts
        function createTimerIf(condition, measureName, startMarkName, endMarkName) {
            return condition ? createTimer(measureName, startMarkName, endMarkName) : nullTimer;
        }
        function createTimer(measureName, startMarkName, endMarkName) {
            let enterCount = 0;
            return {
                enter,
                exit
            };
            function enter() {
                if (++enterCount === 1) {
                    mark(startMarkName);
                }
            }
            function exit() {
                if (--enterCount === 0) {
                    mark(endMarkName);
                    measure(measureName, startMarkName, endMarkName);
                }
                else if (enterCount < 0) {
                    Debug.fail("enter/exit count does not match.");
                }
            }
        }
        function mark(markName) {
            if (enabled) {
                const count = counts.get(markName) ?? 0;
                counts.set(markName, count + 1);
                marks.set(markName, timestamp());
                performanceImpl == null ? void 0 : performanceImpl.mark(markName);
                if (typeof onProfilerEvent === "function") {
                    onProfilerEvent(markName);
                }
            }
        }
        function measure(measureName, startMarkName, endMarkName) {
            if (enabled) {
                const end = (endMarkName !== void 0 ? marks.get(endMarkName) : void 0) ?? timestamp();
                const start = (startMarkName !== void 0 ? marks.get(startMarkName) : void 0) ?? timeorigin;
                const previousDuration = durations.get(measureName) || 0;
                durations.set(measureName, previousDuration + (end - start));
                performanceImpl == null ? void 0 : performanceImpl.measure(measureName, startMarkName, endMarkName);
            }
        }
        function getCount(markName) {
            return counts.get(markName) || 0;
        }
        function getDuration(measureName) {
            return durations.get(measureName) || 0;
        }
        function forEachMeasure(cb) {
            durations.forEach((duration, measureName) => cb(measureName, duration));
        }
        function forEachMark(cb) {
            marks.forEach((_time, markName) => cb(markName));
        }
        function clearMeasures(name) {
            if (name !== void 0)
                durations.delete(name);
            else
                durations.clear();
            performanceImpl == null ? void 0 : performanceImpl.clearMeasures(name);
        }
        function clearMarks(name) {
            if (name !== void 0) {
                counts.delete(name);
                marks.delete(name);
            }
            else {
                counts.clear();
                marks.clear();
            }
            performanceImpl == null ? void 0 : performanceImpl.clearMarks(name);
        }
        function isEnabled() {
            return enabled;
        }
        function enable(system = sys) {
            var _a;
            if (!enabled) {
                enabled = true;
                perfHooks || (perfHooks = tryGetNativePerformanceHooks());
                if (perfHooks) {
                    timeorigin = perfHooks.performance.timeOrigin;
                    if (perfHooks.shouldWriteNativeEvents || ((_a = system == null ? void 0 : system.cpuProfilingEnabled) == null ? void 0 : _a.call(system)) || (system == null ? void 0 : system.debugMode)) {
                        performanceImpl = perfHooks.performance;
                    }
                }
            }
            return true;
        }
        function disable() {
            if (enabled) {
                marks.clear();
                counts.clear();
                durations.clear();
                performanceImpl = void 0;
                enabled = false;
            }
        }
        var perfHooks, performanceImpl, nullTimer, enabled, timeorigin, marks, counts, durations;
        var init_performance = __esm({
            "src/compiler/performance.ts"() {
                "use strict";
                init_ts2();
                nullTimer = { enter: noop, exit: noop };
                enabled = false;
                timeorigin = timestamp();
                marks = /* @__PURE__ */ new Map();
                counts = /* @__PURE__ */ new Map();
                durations = /* @__PURE__ */ new Map();
            }
        });
        // src/compiler/_namespaces/ts.performance.ts
        var ts_performance_exports = {};
        __export(ts_performance_exports, {
            clearMarks: () => clearMarks,
            clearMeasures: () => clearMeasures,
            createTimer: () => createTimer,
            createTimerIf: () => createTimerIf,
            disable: () => disable,
            enable: () => enable,
            forEachMark: () => forEachMark,
            forEachMeasure: () => forEachMeasure,
            getCount: () => getCount,
            getDuration: () => getDuration,
            isEnabled: () => isEnabled,
            mark: () => mark,
            measure: () => measure,
            nullTimer: () => nullTimer
        });
        var init_ts_performance = __esm({
            "src/compiler/_namespaces/ts.performance.ts"() {
                "use strict";
                init_performance();
            }
        });
        // src/compiler/tracing.ts
        var tracing, tracingEnabled, startTracing, dumpTracingLegend;
        var init_tracing = __esm({
            "src/compiler/tracing.ts"() {
                "use strict";
                init_ts2();
                init_ts_performance();
                ((tracingEnabled2) => {
                    let fs;
                    let traceCount = 0;
                    let traceFd = 0;
                    let mode;
                    const typeCatalog = [];
                    let legendPath;
                    const legend = [];
                    function startTracing2(tracingMode, traceDir, configFilePath) {
                        Debug.assert(!tracing, "Tracing already started");
                        if (fs === void 0) {
                            try {
                                fs = require("fs");
                            }
                            catch (e) {
                                throw new Error(`tracing requires having fs
(original error: ${e.message || e})`);
                            }
                        }
                        mode = tracingMode;
                        typeCatalog.length = 0;
                        if (legendPath === void 0) {
                            legendPath = combinePaths(traceDir, "legend.json");
                        }
                        if (!fs.existsSync(traceDir)) {
                            fs.mkdirSync(traceDir, { recursive: true });
                        }
                        const countPart = mode === "build" ? `.${process.pid}-${++traceCount}` : mode === "server" ? `.${process.pid}` : ``;
                        const tracePath = combinePaths(traceDir, `trace${countPart}.json`);
                        const typesPath = combinePaths(traceDir, `types${countPart}.json`);
                        legend.push({
                            configFilePath,
                            tracePath,
                            typesPath
                        });
                        traceFd = fs.openSync(tracePath, "w");
                        tracing = tracingEnabled2;
                        const meta = { cat: "__metadata", ph: "M", ts: 1e3 * timestamp(), pid: 1, tid: 1 };
                        fs.writeSync(traceFd, "[\n" + [{ name: "process_name", args: { name: "tsc" }, ...meta }, { name: "thread_name", args: { name: "Main" }, ...meta }, { name: "TracingStartedInBrowser", ...meta, cat: "disabled-by-default-devtools.timeline" }].map((v) => JSON.stringify(v)).join(",\n"));
                    }
                    tracingEnabled2.startTracing = startTracing2;
                    function stopTracing() {
                        Debug.assert(tracing, "Tracing is not in progress");
                        Debug.assert(!!typeCatalog.length === (mode !== "server"));
                        fs.writeSync(traceFd, `
]
`);
                        fs.closeSync(traceFd);
                        tracing = void 0;
                        if (typeCatalog.length) {
                            dumpTypes(typeCatalog);
                        }
                        else {
                            legend[legend.length - 1].typesPath = void 0;
                        }
                    }
                    tracingEnabled2.stopTracing = stopTracing;
                    function recordType(type) {
                        if (mode !== "server") {
                            typeCatalog.push(type);
                        }
                    }
                    tracingEnabled2.recordType = recordType;
                    let Phase;
                    ((Phase2) => {
                        Phase2["Parse"] = "parse";
                        Phase2["Program"] = "program";
                        Phase2["Bind"] = "bind";
                        Phase2["Check"] = "check";
                        Phase2["CheckTypes"] = "checkTypes";
                        Phase2["Emit"] = "emit";
                        Phase2["Session"] = "session";
                    })(Phase = tracingEnabled2.Phase || (tracingEnabled2.Phase = {}));
                    function instant(phase, name, args) {
                        writeEvent("I", phase, name, args, `"s":"g"`);
                    }
                    tracingEnabled2.instant = instant;
                    const eventStack = [];
                    function push(phase, name, args, separateBeginAndEnd = false) {
                        if (separateBeginAndEnd) {
                            writeEvent("B", phase, name, args);
                        }
                        eventStack.push({ phase, name, args, time: 1e3 * timestamp(), separateBeginAndEnd });
                    }
                    tracingEnabled2.push = push;
                    function pop(results) {
                        Debug.assert(eventStack.length > 0);
                        writeStackEvent(eventStack.length - 1, 1e3 * timestamp(), results);
                        eventStack.length--;
                    }
                    tracingEnabled2.pop = pop;
                    function popAll() {
                        const endTime = 1e3 * timestamp();
                        for (let i = eventStack.length - 1; i >= 0; i--) {
                            writeStackEvent(i, endTime);
                        }
                        eventStack.length = 0;
                    }
                    tracingEnabled2.popAll = popAll;
                    const sampleInterval = 1e3 * 10;
                    function writeStackEvent(index, endTime, results) {
                        const { phase, name, args, time, separateBeginAndEnd } = eventStack[index];
                        if (separateBeginAndEnd) {
                            Debug.assert(!results, "`results` are not supported for events with `separateBeginAndEnd`");
                            writeEvent("E", phase, name, args, 
                            /*extras*/
                            void 0, endTime);
                        }
                        else if (sampleInterval - time % sampleInterval <= endTime - time) {
                            writeEvent("X", phase, name, { ...args, results }, `"dur":${endTime - time}`, time);
                        }
                    }
                    function writeEvent(eventType, phase, name, args, extras, time = 1e3 * timestamp()) {
                        if (mode === "server" && phase === "checkTypes" /* CheckTypes */)
                            return;
                        mark("beginTracing");
                        fs.writeSync(traceFd, `,
{"pid":1,"tid":1,"ph":"${eventType}","cat":"${phase}","ts":${time},"name":"${name}"`);
                        if (extras)
                            fs.writeSync(traceFd, `,${extras}`);
                        if (args)
                            fs.writeSync(traceFd, `,"args":${JSON.stringify(args)}`);
                        fs.writeSync(traceFd, `}`);
                        mark("endTracing");
                        measure("Tracing", "beginTracing", "endTracing");
                    }
                    function getLocation(node) {
                        const file = getSourceFileOfNode(node);
                        return !file ? void 0 : {
                            path: file.path,
                            start: indexFromOne(getLineAndCharacterOfPosition(file, node.pos)),
                            end: indexFromOne(getLineAndCharacterOfPosition(file, node.end))
                        };
                        function indexFromOne(lc) {
                            return {
                                line: lc.line + 1,
                                character: lc.character + 1
                            };
                        }
                    }
                    function dumpTypes(types) {
                        var _a, _b, _c, _d, _e, _f, _g, _h, _i, _j, _k, _l, _m, _n, _o, _p, _q, _r, _s;
                        mark("beginDumpTypes");
                        const typesPath = legend[legend.length - 1].typesPath;
                        const typesFd = fs.openSync(typesPath, "w");
                        const recursionIdentityMap = /* @__PURE__ */ new Map();
                        fs.writeSync(typesFd, "[");
                        const numTypes = types.length;
                        for (let i = 0; i < numTypes; i++) {
                            const type = types[i];
                            const objectFlags = type.objectFlags;
                            const symbol = type.aliasSymbol ?? type.symbol;
                            let display;
                            if (objectFlags & 16 /* Anonymous */ | type.flags & 2944 /* Literal */) {
                                try {
                                    display = (_a = type.checker) == null ? void 0 : _a.typeToString(type);
                                }
                                catch {
                                    display = void 0;
                                }
                            }
                            let indexedAccessProperties = {};
                            if (type.flags & 8388608 /* IndexedAccess */) {
                                const indexedAccessType = type;
                                indexedAccessProperties = {
                                    indexedAccessObjectType: (_b = indexedAccessType.objectType) == null ? void 0 : _b.id,
                                    indexedAccessIndexType: (_c = indexedAccessType.indexType) == null ? void 0 : _c.id
                                };
                            }
                            let referenceProperties = {};
                            if (objectFlags & 4 /* Reference */) {
                                const referenceType = type;
                                referenceProperties = {
                                    instantiatedType: (_d = referenceType.target) == null ? void 0 : _d.id,
                                    typeArguments: (_e = referenceType.resolvedTypeArguments) == null ? void 0 : _e.map((t) => t.id),
                                    referenceLocation: getLocation(referenceType.node)
                                };
                            }
                            let conditionalProperties = {};
                            if (type.flags & 16777216 /* Conditional */) {
                                const conditionalType = type;
                                conditionalProperties = {
                                    conditionalCheckType: (_f = conditionalType.checkType) == null ? void 0 : _f.id,
                                    conditionalExtendsType: (_g = conditionalType.extendsType) == null ? void 0 : _g.id,
                                    conditionalTrueType: ((_h = conditionalType.resolvedTrueType) == null ? void 0 : _h.id) ?? -1,
                                    conditionalFalseType: ((_i = conditionalType.resolvedFalseType) == null ? void 0 : _i.id) ?? -1
                                };
                            }
                            let substitutionProperties = {};
                            if (type.flags & 33554432 /* Substitution */) {
                                const substitutionType = type;
                                substitutionProperties = {
                                    substitutionBaseType: (_j = substitutionType.baseType) == null ? void 0 : _j.id,
                                    constraintType: (_k = substitutionType.constraint) == null ? void 0 : _k.id
                                };
                            }
                            let reverseMappedProperties = {};
                            if (objectFlags & 1024 /* ReverseMapped */) {
                                const reverseMappedType = type;
                                reverseMappedProperties = {
                                    reverseMappedSourceType: (_l = reverseMappedType.source) == null ? void 0 : _l.id,
                                    reverseMappedMappedType: (_m = reverseMappedType.mappedType) == null ? void 0 : _m.id,
                                    reverseMappedConstraintType: (_n = reverseMappedType.constraintType) == null ? void 0 : _n.id
                                };
                            }
                            let evolvingArrayProperties = {};
                            if (objectFlags & 256 /* EvolvingArray */) {
                                const evolvingArrayType = type;
                                evolvingArrayProperties = {
                                    evolvingArrayElementType: evolvingArrayType.elementType.id,
                                    evolvingArrayFinalType: (_o = evolvingArrayType.finalArrayType) == null ? void 0 : _o.id
                                };
                            }
                            let recursionToken;
                            const recursionIdentity = type.checker.getRecursionIdentity(type);
                            if (recursionIdentity) {
                                recursionToken = recursionIdentityMap.get(recursionIdentity);
                                if (!recursionToken) {
                                    recursionToken = recursionIdentityMap.size;
                                    recursionIdentityMap.set(recursionIdentity, recursionToken);
                                }
                            }
                            const descriptor = {
                                id: type.id,
                                intrinsicName: type.intrinsicName,
                                symbolName: (symbol == null ? void 0 : symbol.escapedName) && unescapeLeadingUnderscores(symbol.escapedName),
                                recursionId: recursionToken,
                                isTuple: objectFlags & 8 /* Tuple */ ? true : void 0,
                                unionTypes: type.flags & 1048576 /* Union */ ? (_p = type.types) == null ? void 0 : _p.map((t) => t.id) : void 0,
                                intersectionTypes: type.flags & 2097152 /* Intersection */ ? type.types.map((t) => t.id) : void 0,
                                aliasTypeArguments: (_q = type.aliasTypeArguments) == null ? void 0 : _q.map((t) => t.id),
                                keyofType: type.flags & 4194304 /* Index */ ? (_r = type.type) == null ? void 0 : _r.id : void 0,
                                ...indexedAccessProperties,
                                ...referenceProperties,
                                ...conditionalProperties,
                                ...substitutionProperties,
                                ...reverseMappedProperties,
                                ...evolvingArrayProperties,
                                destructuringPattern: getLocation(type.pattern),
                                firstDeclaration: getLocation((_s = symbol == null ? void 0 : symbol.declarations) == null ? void 0 : _s[0]),
                                flags: Debug.formatTypeFlags(type.flags).split("|"),
                                display
                            };
                            fs.writeSync(typesFd, JSON.stringify(descriptor));
                            if (i < numTypes - 1) {
                                fs.writeSync(typesFd, ",\n");
                            }
                        }
                        fs.writeSync(typesFd, "]\n");
                        fs.closeSync(typesFd);
                        mark("endDumpTypes");
                        measure("Dump types", "beginDumpTypes", "endDumpTypes");
                    }
                    function dumpLegend() {
                        if (!legendPath) {
                            return;
                        }
                        fs.writeFileSync(legendPath, JSON.stringify(legend));
                    }
                    tracingEnabled2.dumpLegend = dumpLegend;
                })(tracingEnabled || (tracingEnabled = {}));
                startTracing = tracingEnabled.startTracing;
                dumpTracingLegend = tracingEnabled.dumpLegend;
            }
        });
        // src/compiler/types.ts
        function diagnosticCategoryName(d, lowerCase = true) {
            const name = DiagnosticCategory[d.category];
            return lowerCase ? name.toLowerCase() : name;
        }
        var SyntaxKind, NodeFlags, ModifierFlags, JsxFlags, RelationComparisonResult, GeneratedIdentifierFlags, TokenFlags, FlowFlags, CommentDirectiveType, OperationCanceledException, FileIncludeKind, FilePreprocessingDiagnosticsKind, EmitOnly, StructureIsReused, ExitStatus, MemberOverrideStatus, UnionReduction, ContextFlags, NodeBuilderFlags, TypeFormatFlags, SymbolFormatFlags, SymbolAccessibility, SyntheticSymbolKind, TypePredicateKind, TypeReferenceSerializationKind, SymbolFlags, EnumKind, CheckFlags, InternalSymbolName, NodeCheckFlags, TypeFlags, ObjectFlags, VarianceFlags, ElementFlags, AccessFlags, IndexFlags, JsxReferenceKind, SignatureKind, SignatureFlags, IndexKind, TypeMapKind, InferencePriority, InferenceFlags, Ternary, AssignmentDeclarationKind, DiagnosticCategory, ModuleResolutionKind, ModuleDetectionKind, WatchFileKind, WatchDirectoryKind, PollingWatchKind, ModuleKind, JsxEmit, ImportsNotUsedAsValues, NewLineKind, ScriptKind, ScriptTarget, LanguageVariant, WatchDirectoryFlags, CharacterCodes, Extension, TransformFlags, SnippetKind, EmitFlags, InternalEmitFlags, ExternalEmitHelpers, EmitHint, OuterExpressionKinds, LexicalEnvironmentFlags, BundleFileSectionKind, ListFormat, PragmaKindFlags, commentPragmas, JSDocParsingMode;
        var init_types = __esm({
            "src/compiler/types.ts"() {
                "use strict";
                SyntaxKind = /* @__PURE__ */ ((SyntaxKind5) => {
                    SyntaxKind5[SyntaxKind5["Unknown"] = 0] = "Unknown";
                    SyntaxKind5[SyntaxKind5["EndOfFileToken"] = 1] = "EndOfFileToken";
                    SyntaxKind5[SyntaxKind5["SingleLineCommentTrivia"] = 2] = "SingleLineCommentTrivia";
                    SyntaxKind5[SyntaxKind5["MultiLineCommentTrivia"] = 3] = "MultiLineCommentTrivia";
                    SyntaxKind5[SyntaxKind5["NewLineTrivia"] = 4] = "NewLineTrivia";
                    SyntaxKind5[SyntaxKind5["WhitespaceTrivia"] = 5] = "WhitespaceTrivia";
                    SyntaxKind5[SyntaxKind5["ShebangTrivia"] = 6] = "ShebangTrivia";
                    SyntaxKind5[SyntaxKind5["ConflictMarkerTrivia"] = 7] = "ConflictMarkerTrivia";
                    SyntaxKind5[SyntaxKind5["NonTextFileMarkerTrivia"] = 8] = "NonTextFileMarkerTrivia";
                    SyntaxKind5[SyntaxKind5["NumericLiteral"] = 9] = "NumericLiteral";
                    SyntaxKind5[SyntaxKind5["BigIntLiteral"] = 10] = "BigIntLiteral";
                    SyntaxKind5[SyntaxKind5["StringLiteral"] = 11] = "StringLiteral";
                    SyntaxKind5[SyntaxKind5["JsxText"] = 12] = "JsxText";
                    SyntaxKind5[SyntaxKind5["JsxTextAllWhiteSpaces"] = 13] = "JsxTextAllWhiteSpaces";
                    SyntaxKind5[SyntaxKind5["RegularExpressionLiteral"] = 14] = "RegularExpressionLiteral";
                    SyntaxKind5[SyntaxKind5["NoSubstitutionTemplateLiteral"] = 15] = "NoSubstitutionTemplateLiteral";
                    SyntaxKind5[SyntaxKind5["TemplateHead"] = 16] = "TemplateHead";
                    SyntaxKind5[SyntaxKind5["TemplateMiddle"] = 17] = "TemplateMiddle";
                    SyntaxKind5[SyntaxKind5["TemplateTail"] = 18] = "TemplateTail";
                    SyntaxKind5[SyntaxKind5["OpenBraceToken"] = 19] = "OpenBraceToken";
                    SyntaxKind5[SyntaxKind5["CloseBraceToken"] = 20] = "CloseBraceToken";
                    SyntaxKind5[SyntaxKind5["OpenParenToken"] = 21] = "OpenParenToken";
                    SyntaxKind5[SyntaxKind5["CloseParenToken"] = 22] = "CloseParenToken";
                    SyntaxKind5[SyntaxKind5["OpenBracketToken"] = 23] = "OpenBracketToken";
                    SyntaxKind5[SyntaxKind5["CloseBracketToken"] = 24] = "CloseBracketToken";
                    SyntaxKind5[SyntaxKind5["DotToken"] = 25] = "DotToken";
                    SyntaxKind5[SyntaxKind5["DotDotDotToken"] = 26] = "DotDotDotToken";
                    SyntaxKind5[SyntaxKind5["SemicolonToken"] = 27] = "SemicolonToken";
                    SyntaxKind5[SyntaxKind5["CommaToken"] = 28] = "CommaToken";
                    SyntaxKind5[SyntaxKind5["QuestionDotToken"] = 29] = "QuestionDotToken";
                    SyntaxKind5[SyntaxKind5["LessThanToken"] = 30] = "LessThanToken";
                    SyntaxKind5[SyntaxKind5["LessThanSlashToken"] = 31] = "LessThanSlashToken";
                    SyntaxKind5[SyntaxKind5["GreaterThanToken"] = 32] = "GreaterThanToken";
                    SyntaxKind5[SyntaxKind5["LessThanEqualsToken"] = 33] = "LessThanEqualsToken";
                    SyntaxKind5[SyntaxKind5["GreaterThanEqualsToken"] = 34] = "GreaterThanEqualsToken";
                    SyntaxKind5[SyntaxKind5["EqualsEqualsToken"] = 35] = "EqualsEqualsToken";
                    SyntaxKind5[SyntaxKind5["ExclamationEqualsToken"] = 36] = "ExclamationEqualsToken";
                    SyntaxKind5[SyntaxKind5["EqualsEqualsEqualsToken"] = 37] = "EqualsEqualsEqualsToken";
                    SyntaxKind5[SyntaxKind5["ExclamationEqualsEqualsToken"] = 38] = "ExclamationEqualsEqualsToken";
                    SyntaxKind5[SyntaxKind5["EqualsGreaterThanToken"] = 39] = "EqualsGreaterThanToken";
                    SyntaxKind5[SyntaxKind5["PlusToken"] = 40] = "PlusToken";
                    SyntaxKind5[SyntaxKind5["MinusToken"] = 41] = "MinusToken";
                    SyntaxKind5[SyntaxKind5["AsteriskToken"] = 42] = "AsteriskToken";
                    SyntaxKind5[SyntaxKind5["AsteriskAsteriskToken"] = 43] = "AsteriskAsteriskToken";
                    SyntaxKind5[SyntaxKind5["SlashToken"] = 44] = "SlashToken";
                    SyntaxKind5[SyntaxKind5["PercentToken"] = 45] = "PercentToken";
                    SyntaxKind5[SyntaxKind5["PlusPlusToken"] = 46] = "PlusPlusToken";
                    SyntaxKind5[SyntaxKind5["MinusMinusToken"] = 47] = "MinusMinusToken";
                    SyntaxKind5[SyntaxKind5["LessThanLessThanToken"] = 48] = "LessThanLessThanToken";
                    SyntaxKind5[SyntaxKind5["GreaterThanGreaterThanToken"] = 49] = "GreaterThanGreaterThanToken";
                    SyntaxKind5[SyntaxKind5["GreaterThanGreaterThanGreaterThanToken"] = 50] = "GreaterThanGreaterThanGreaterThanToken";
                    SyntaxKind5[SyntaxKind5["AmpersandToken"] = 51] = "AmpersandToken";
                    SyntaxKind5[SyntaxKind5["BarToken"] = 52] = "BarToken";
                    SyntaxKind5[SyntaxKind5["CaretToken"] = 53] = "CaretToken";
                    SyntaxKind5[SyntaxKind5["ExclamationToken"] = 54] = "ExclamationToken";
                    SyntaxKind5[SyntaxKind5["TildeToken"] = 55] = "TildeToken";
                    SyntaxKind5[SyntaxKind5["AmpersandAmpersandToken"] = 56] = "AmpersandAmpersandToken";
                    SyntaxKind5[SyntaxKind5["BarBarToken"] = 57] = "BarBarToken";
                    SyntaxKind5[SyntaxKind5["QuestionToken"] = 58] = "QuestionToken";
                    SyntaxKind5[SyntaxKind5["ColonToken"] = 59] = "ColonToken";
                    SyntaxKind5[SyntaxKind5["AtToken"] = 60] = "AtToken";
                    SyntaxKind5[SyntaxKind5["QuestionQuestionToken"] = 61] = "QuestionQuestionToken";
                    SyntaxKind5[SyntaxKind5["BacktickToken"] = 62] = "BacktickToken";
                    SyntaxKind5[SyntaxKind5["HashToken"] = 63] = "HashToken";
                    SyntaxKind5[SyntaxKind5["EqualsToken"] = 64] = "EqualsToken";
                    SyntaxKind5[SyntaxKind5["PlusEqualsToken"] = 65] = "PlusEqualsToken";
                    SyntaxKind5[SyntaxKind5["MinusEqualsToken"] = 66] = "MinusEqualsToken";
                    SyntaxKind5[SyntaxKind5["AsteriskEqualsToken"] = 67] = "AsteriskEqualsToken";
                    SyntaxKind5[SyntaxKind5["AsteriskAsteriskEqualsToken"] = 68] = "AsteriskAsteriskEqualsToken";
                    SyntaxKind5[SyntaxKind5["SlashEqualsToken"] = 69] = "SlashEqualsToken";
                    SyntaxKind5[SyntaxKind5["PercentEqualsToken"] = 70] = "PercentEqualsToken";
                    SyntaxKind5[SyntaxKind5["LessThanLessThanEqualsToken"] = 71] = "LessThanLessThanEqualsToken";
                    SyntaxKind5[SyntaxKind5["GreaterThanGreaterThanEqualsToken"] = 72] = "GreaterThanGreaterThanEqualsToken";
                    SyntaxKind5[SyntaxKind5["GreaterThanGreaterThanGreaterThanEqualsToken"] = 73] = "GreaterThanGreaterThanGreaterThanEqualsToken";
                    SyntaxKind5[SyntaxKind5["AmpersandEqualsToken"] = 74] = "AmpersandEqualsToken";
                    SyntaxKind5[SyntaxKind5["BarEqualsToken"] = 75] = "BarEqualsToken";
                    SyntaxKind5[SyntaxKind5["BarBarEqualsToken"] = 76] = "BarBarEqualsToken";
                    SyntaxKind5[SyntaxKind5["AmpersandAmpersandEqualsToken"] = 77] = "AmpersandAmpersandEqualsToken";
                    SyntaxKind5[SyntaxKind5["QuestionQuestionEqualsToken"] = 78] = "QuestionQuestionEqualsToken";
                    SyntaxKind5[SyntaxKind5["CaretEqualsToken"] = 79] = "CaretEqualsToken";
                    SyntaxKind5[SyntaxKind5["Identifier"] = 80] = "Identifier";
                    SyntaxKind5[SyntaxKind5["PrivateIdentifier"] = 81] = "PrivateIdentifier";
                    SyntaxKind5[SyntaxKind5["JSDocCommentTextToken"] = 82] = "JSDocCommentTextToken";
                    SyntaxKind5[SyntaxKind5["BreakKeyword"] = 83] = "BreakKeyword";
                    SyntaxKind5[SyntaxKind5["CaseKeyword"] = 84] = "CaseKeyword";
                    SyntaxKind5[SyntaxKind5["CatchKeyword"] = 85] = "CatchKeyword";
                    SyntaxKind5[SyntaxKind5["ClassKeyword"] = 86] = "ClassKeyword";
                    SyntaxKind5[SyntaxKind5["ConstKeyword"] = 87] = "ConstKeyword";
                    SyntaxKind5[SyntaxKind5["ContinueKeyword"] = 88] = "ContinueKeyword";
                    SyntaxKind5[SyntaxKind5["DebuggerKeyword"] = 89] = "DebuggerKeyword";
                    SyntaxKind5[SyntaxKind5["DefaultKeyword"] = 90] = "DefaultKeyword";
                    SyntaxKind5[SyntaxKind5["DeleteKeyword"] = 91] = "DeleteKeyword";
                    SyntaxKind5[SyntaxKind5["DoKeyword"] = 92] = "DoKeyword";
                    SyntaxKind5[SyntaxKind5["ElseKeyword"] = 93] = "ElseKeyword";
                    SyntaxKind5[SyntaxKind5["EnumKeyword"] = 94] = "EnumKeyword";
                    SyntaxKind5[SyntaxKind5["ExportKeyword"] = 95] = "ExportKeyword";
                    SyntaxKind5[SyntaxKind5["ExtendsKeyword"] = 96] = "ExtendsKeyword";
                    SyntaxKind5[SyntaxKind5["FalseKeyword"] = 97] = "FalseKeyword";
                    SyntaxKind5[SyntaxKind5["FinallyKeyword"] = 98] = "FinallyKeyword";
                    SyntaxKind5[SyntaxKind5["ForKeyword"] = 99] = "ForKeyword";
                    SyntaxKind5[SyntaxKind5["FunctionKeyword"] = 100] = "FunctionKeyword";
                    SyntaxKind5[SyntaxKind5["IfKeyword"] = 101] = "IfKeyword";
                    SyntaxKind5[SyntaxKind5["ImportKeyword"] = 102] = "ImportKeyword";
                    SyntaxKind5[SyntaxKind5["InKeyword"] = 103] = "InKeyword";
                    SyntaxKind5[SyntaxKind5["InstanceOfKeyword"] = 104] = "InstanceOfKeyword";
                    SyntaxKind5[SyntaxKind5["NewKeyword"] = 105] = "NewKeyword";
                    SyntaxKind5[SyntaxKind5["NullKeyword"] = 106] = "NullKeyword";
                    SyntaxKind5[SyntaxKind5["ReturnKeyword"] = 107] = "ReturnKeyword";
                    SyntaxKind5[SyntaxKind5["SuperKeyword"] = 108] = "SuperKeyword";
                    SyntaxKind5[SyntaxKind5["SwitchKeyword"] = 109] = "SwitchKeyword";
                    SyntaxKind5[SyntaxKind5["ThisKeyword"] = 110] = "ThisKeyword";
                    SyntaxKind5[SyntaxKind5["ThrowKeyword"] = 111] = "ThrowKeyword";
                    SyntaxKind5[SyntaxKind5["TrueKeyword"] = 112] = "TrueKeyword";
                    SyntaxKind5[SyntaxKind5["TryKeyword"] = 113] = "TryKeyword";
                    SyntaxKind5[SyntaxKind5["TypeOfKeyword"] = 114] = "TypeOfKeyword";
                    SyntaxKind5[SyntaxKind5["VarKeyword"] = 115] = "VarKeyword";
                    SyntaxKind5[SyntaxKind5["VoidKeyword"] = 116] = "VoidKeyword";
                    SyntaxKind5[SyntaxKind5["WhileKeyword"] = 117] = "WhileKeyword";
                    SyntaxKind5[SyntaxKind5["WithKeyword"] = 118] = "WithKeyword";
                    SyntaxKind5[SyntaxKind5["ImplementsKeyword"] = 119] = "ImplementsKeyword";
                    SyntaxKind5[SyntaxKind5["InterfaceKeyword"] = 120] = "InterfaceKeyword";
                    SyntaxKind5[SyntaxKind5["LetKeyword"] = 121] = "LetKeyword";
                    SyntaxKind5[SyntaxKind5["PackageKeyword"] = 122] = "PackageKeyword";
                    SyntaxKind5[SyntaxKind5["PrivateKeyword"] = 123] = "PrivateKeyword";
                    SyntaxKind5[SyntaxKind5["ProtectedKeyword"] = 124] = "ProtectedKeyword";
                    SyntaxKind5[SyntaxKind5["PublicKeyword"] = 125] = "PublicKeyword";
                    SyntaxKind5[SyntaxKind5["StaticKeyword"] = 126] = "StaticKeyword";
                    SyntaxKind5[SyntaxKind5["YieldKeyword"] = 127] = "YieldKeyword";
                    SyntaxKind5[SyntaxKind5["AbstractKeyword"] = 128] = "AbstractKeyword";
                    SyntaxKind5[SyntaxKind5["AccessorKeyword"] = 129] = "AccessorKeyword";
                    SyntaxKind5[SyntaxKind5["AsKeyword"] = 130] = "AsKeyword";
                    SyntaxKind5[SyntaxKind5["AssertsKeyword"] = 131] = "AssertsKeyword";
                    SyntaxKind5[SyntaxKind5["AssertKeyword"] = 132] = "AssertKeyword";
                    SyntaxKind5[SyntaxKind5["AnyKeyword"] = 133] = "AnyKeyword";
                    SyntaxKind5[SyntaxKind5["AsyncKeyword"] = 134] = "AsyncKeyword";
                    SyntaxKind5[SyntaxKind5["AwaitKeyword"] = 135] = "AwaitKeyword";
                    SyntaxKind5[SyntaxKind5["BooleanKeyword"] = 136] = "BooleanKeyword";
                    SyntaxKind5[SyntaxKind5["ConstructorKeyword"] = 137] = "ConstructorKeyword";
                    SyntaxKind5[SyntaxKind5["DeclareKeyword"] = 138] = "DeclareKeyword";
                    SyntaxKind5[SyntaxKind5["GetKeyword"] = 139] = "GetKeyword";
                    SyntaxKind5[SyntaxKind5["InferKeyword"] = 140] = "InferKeyword";
                    SyntaxKind5[SyntaxKind5["IntrinsicKeyword"] = 141] = "IntrinsicKeyword";
                    SyntaxKind5[SyntaxKind5["IsKeyword"] = 142] = "IsKeyword";
                    SyntaxKind5[SyntaxKind5["KeyOfKeyword"] = 143] = "KeyOfKeyword";
                    SyntaxKind5[SyntaxKind5["ModuleKeyword"] = 144] = "ModuleKeyword";
                    SyntaxKind5[SyntaxKind5["NamespaceKeyword"] = 145] = "NamespaceKeyword";
                    SyntaxKind5[SyntaxKind5["NeverKeyword"] = 146] = "NeverKeyword";
                    SyntaxKind5[SyntaxKind5["OutKeyword"] = 147] = "OutKeyword";
                    SyntaxKind5[SyntaxKind5["ReadonlyKeyword"] = 148] = "ReadonlyKeyword";
                    SyntaxKind5[SyntaxKind5["RequireKeyword"] = 149] = "RequireKeyword";
                    SyntaxKind5[SyntaxKind5["NumberKeyword"] = 150] = "NumberKeyword";
                    SyntaxKind5[SyntaxKind5["ObjectKeyword"] = 151] = "ObjectKeyword";
                    SyntaxKind5[SyntaxKind5["SatisfiesKeyword"] = 152] = "SatisfiesKeyword";
                    SyntaxKind5[SyntaxKind5["SetKeyword"] = 153] = "SetKeyword";
                    SyntaxKind5[SyntaxKind5["StringKeyword"] = 154] = "StringKeyword";
                    SyntaxKind5[SyntaxKind5["SymbolKeyword"] = 155] = "SymbolKeyword";
                    SyntaxKind5[SyntaxKind5["TypeKeyword"] = 156] = "TypeKeyword";
                    SyntaxKind5[SyntaxKind5["UndefinedKeyword"] = 157] = "UndefinedKeyword";
                    SyntaxKind5[SyntaxKind5["UniqueKeyword"] = 158] = "UniqueKeyword";
                    SyntaxKind5[SyntaxKind5["UnknownKeyword"] = 159] = "UnknownKeyword";
                    SyntaxKind5[SyntaxKind5["UsingKeyword"] = 160] = "UsingKeyword";
                    SyntaxKind5[SyntaxKind5["FromKeyword"] = 161] = "FromKeyword";
                    SyntaxKind5[SyntaxKind5["GlobalKeyword"] = 162] = "GlobalKeyword";
                    SyntaxKind5[SyntaxKind5["BigIntKeyword"] = 163] = "BigIntKeyword";
                    SyntaxKind5[SyntaxKind5["OverrideKeyword"] = 164] = "OverrideKeyword";
                    SyntaxKind5[SyntaxKind5["OfKeyword"] = 165] = "OfKeyword";
                    SyntaxKind5[SyntaxKind5["QualifiedName"] = 166] = "QualifiedName";
                    SyntaxKind5[SyntaxKind5["ComputedPropertyName"] = 167] = "ComputedPropertyName";
                    SyntaxKind5[SyntaxKind5["TypeParameter"] = 168] = "TypeParameter";
                    SyntaxKind5[SyntaxKind5["Parameter"] = 169] = "Parameter";
                    SyntaxKind5[SyntaxKind5["Decorator"] = 170] = "Decorator";
                    SyntaxKind5[SyntaxKind5["PropertySignature"] = 171] = "PropertySignature";
                    SyntaxKind5[SyntaxKind5["PropertyDeclaration"] = 172] = "PropertyDeclaration";
                    SyntaxKind5[SyntaxKind5["MethodSignature"] = 173] = "MethodSignature";
                    SyntaxKind5[SyntaxKind5["MethodDeclaration"] = 174] = "MethodDeclaration";
                    SyntaxKind5[SyntaxKind5["ClassStaticBlockDeclaration"] = 175] = "ClassStaticBlockDeclaration";
                    SyntaxKind5[SyntaxKind5["Constructor"] = 176] = "Constructor";
                    SyntaxKind5[SyntaxKind5["GetAccessor"] = 177] = "GetAccessor";
                    SyntaxKind5[SyntaxKind5["SetAccessor"] = 178] = "SetAccessor";
                    SyntaxKind5[SyntaxKind5["CallSignature"] = 179] = "CallSignature";
                    SyntaxKind5[SyntaxKind5["ConstructSignature"] = 180] = "ConstructSignature";
                    SyntaxKind5[SyntaxKind5["IndexSignature"] = 181] = "IndexSignature";
                    SyntaxKind5[SyntaxKind5["TypePredicate"] = 182] = "TypePredicate";
                    SyntaxKind5[SyntaxKind5["TypeReference"] = 183] = "TypeReference";
                    SyntaxKind5[SyntaxKind5["FunctionType"] = 184] = "FunctionType";
                    SyntaxKind5[SyntaxKind5["ConstructorType"] = 185] = "ConstructorType";
                    SyntaxKind5[SyntaxKind5["TypeQuery"] = 186] = "TypeQuery";
                    SyntaxKind5[SyntaxKind5["TypeLiteral"] = 187] = "TypeLiteral";
                    SyntaxKind5[SyntaxKind5["ArrayType"] = 188] = "ArrayType";
                    SyntaxKind5[SyntaxKind5["TupleType"] = 189] = "TupleType";
                    SyntaxKind5[SyntaxKind5["OptionalType"] = 190] = "OptionalType";
                    SyntaxKind5[SyntaxKind5["RestType"] = 191] = "RestType";
                    SyntaxKind5[SyntaxKind5["UnionType"] = 192] = "UnionType";
                    SyntaxKind5[SyntaxKind5["IntersectionType"] = 193] = "IntersectionType";
                    SyntaxKind5[SyntaxKind5["ConditionalType"] = 194] = "ConditionalType";
                    SyntaxKind5[SyntaxKind5["InferType"] = 195] = "InferType";
                    SyntaxKind5[SyntaxKind5["ParenthesizedType"] = 196] = "ParenthesizedType";
                    SyntaxKind5[SyntaxKind5["ThisType"] = 197] = "ThisType";
                    SyntaxKind5[SyntaxKind5["TypeOperator"] = 198] = "TypeOperator";
                    SyntaxKind5[SyntaxKind5["IndexedAccessType"] = 199] = "IndexedAccessType";
                    SyntaxKind5[SyntaxKind5["MappedType"] = 200] = "MappedType";
                    SyntaxKind5[SyntaxKind5["LiteralType"] = 201] = "LiteralType";
                    SyntaxKind5[SyntaxKind5["NamedTupleMember"] = 202] = "NamedTupleMember";
                    SyntaxKind5[SyntaxKind5["TemplateLiteralType"] = 203] = "TemplateLiteralType";
                    SyntaxKind5[SyntaxKind5["TemplateLiteralTypeSpan"] = 204] = "TemplateLiteralTypeSpan";
                    SyntaxKind5[SyntaxKind5["ImportType"] = 205] = "ImportType";
                    SyntaxKind5[SyntaxKind5["ObjectBindingPattern"] = 206] = "ObjectBindingPattern";
                    SyntaxKind5[SyntaxKind5["ArrayBindingPattern"] = 207] = "ArrayBindingPattern";
                    SyntaxKind5[SyntaxKind5["BindingElement"] = 208] = "BindingElement";
                    SyntaxKind5[SyntaxKind5["ArrayLiteralExpression"] = 209] = "ArrayLiteralExpression";
                    SyntaxKind5[SyntaxKind5["ObjectLiteralExpression"] = 210] = "ObjectLiteralExpression";
                    SyntaxKind5[SyntaxKind5["PropertyAccessExpression"] = 211] = "PropertyAccessExpression";
                    SyntaxKind5[SyntaxKind5["ElementAccessExpression"] = 212] = "ElementAccessExpression";
                    SyntaxKind5[SyntaxKind5["CallExpression"] = 213] = "CallExpression";
                    SyntaxKind5[SyntaxKind5["NewExpression"] = 214] = "NewExpression";
                    SyntaxKind5[SyntaxKind5["TaggedTemplateExpression"] = 215] = "TaggedTemplateExpression";
                    SyntaxKind5[SyntaxKind5["TypeAssertionExpression"] = 216] = "TypeAssertionExpression";
                    SyntaxKind5[SyntaxKind5["ParenthesizedExpression"] = 217] = "ParenthesizedExpression";
                    SyntaxKind5[SyntaxKind5["FunctionExpression"] = 218] = "FunctionExpression";
                    SyntaxKind5[SyntaxKind5["ArrowFunction"] = 219] = "ArrowFunction";
                    SyntaxKind5[SyntaxKind5["DeleteExpression"] = 220] = "DeleteExpression";
                    SyntaxKind5[SyntaxKind5["TypeOfExpression"] = 221] = "TypeOfExpression";
                    SyntaxKind5[SyntaxKind5["VoidExpression"] = 222] = "VoidExpression";
                    SyntaxKind5[SyntaxKind5["AwaitExpression"] = 223] = "AwaitExpression";
                    SyntaxKind5[SyntaxKind5["PrefixUnaryExpression"] = 224] = "PrefixUnaryExpression";
                    SyntaxKind5[SyntaxKind5["PostfixUnaryExpression"] = 225] = "PostfixUnaryExpression";
                    SyntaxKind5[SyntaxKind5["BinaryExpression"] = 226] = "BinaryExpression";
                    SyntaxKind5[SyntaxKind5["ConditionalExpression"] = 227] = "ConditionalExpression";
                    SyntaxKind5[SyntaxKind5["TemplateExpression"] = 228] = "TemplateExpression";
                    SyntaxKind5[SyntaxKind5["YieldExpression"] = 229] = "YieldExpression";
                    SyntaxKind5[SyntaxKind5["SpreadElement"] = 230] = "SpreadElement";
                    SyntaxKind5[SyntaxKind5["ClassExpression"] = 231] = "ClassExpression";
                    SyntaxKind5[SyntaxKind5["OmittedExpression"] = 232] = "OmittedExpression";
                    SyntaxKind5[SyntaxKind5["ExpressionWithTypeArguments"] = 233] = "ExpressionWithTypeArguments";
                    SyntaxKind5[SyntaxKind5["AsExpression"] = 234] = "AsExpression";
                    SyntaxKind5[SyntaxKind5["NonNullExpression"] = 235] = "NonNullExpression";
                    SyntaxKind5[SyntaxKind5["MetaProperty"] = 236] = "MetaProperty";
                    SyntaxKind5[SyntaxKind5["SyntheticExpression"] = 237] = "SyntheticExpression";
                    SyntaxKind5[SyntaxKind5["SatisfiesExpression"] = 238] = "SatisfiesExpression";
                    SyntaxKind5[SyntaxKind5["TemplateSpan"] = 239] = "TemplateSpan";
                    SyntaxKind5[SyntaxKind5["SemicolonClassElement"] = 240] = "SemicolonClassElement";
                    SyntaxKind5[SyntaxKind5["Block"] = 241] = "Block";
                    SyntaxKind5[SyntaxKind5["EmptyStatement"] = 242] = "EmptyStatement";
                    SyntaxKind5[SyntaxKind5["VariableStatement"] = 243] = "VariableStatement";
                    SyntaxKind5[SyntaxKind5["ExpressionStatement"] = 244] = "ExpressionStatement";
                    SyntaxKind5[SyntaxKind5["IfStatement"] = 245] = "IfStatement";
                    SyntaxKind5[SyntaxKind5["DoStatement"] = 246] = "DoStatement";
                    SyntaxKind5[SyntaxKind5["WhileStatement"] = 247] = "WhileStatement";
                    SyntaxKind5[SyntaxKind5["ForStatement"] = 248] = "ForStatement";
                    SyntaxKind5[SyntaxKind5["ForInStatement"] = 249] = "ForInStatement";
                    SyntaxKind5[SyntaxKind5["ForOfStatement"] = 250] = "ForOfStatement";
                    SyntaxKind5[SyntaxKind5["ContinueStatement"] = 251] = "ContinueStatement";
                    SyntaxKind5[SyntaxKind5["BreakStatement"] = 252] = "BreakStatement";
                    SyntaxKind5[SyntaxKind5["ReturnStatement"] = 253] = "ReturnStatement";
                    SyntaxKind5[SyntaxKind5["WithStatement"] = 254] = "WithStatement";
                    SyntaxKind5[SyntaxKind5["SwitchStatement"] = 255] = "SwitchStatement";
                    SyntaxKind5[SyntaxKind5["LabeledStatement"] = 256] = "LabeledStatement";
                    SyntaxKind5[SyntaxKind5["ThrowStatement"] = 257] = "ThrowStatement";
                    SyntaxKind5[SyntaxKind5["TryStatement"] = 258] = "TryStatement";
                    SyntaxKind5[SyntaxKind5["DebuggerStatement"] = 259] = "DebuggerStatement";
                    SyntaxKind5[SyntaxKind5["VariableDeclaration"] = 260] = "VariableDeclaration";
                    SyntaxKind5[SyntaxKind5["VariableDeclarationList"] = 261] = "VariableDeclarationList";
                    SyntaxKind5[SyntaxKind5["FunctionDeclaration"] = 262] = "FunctionDeclaration";
                    SyntaxKind5[SyntaxKind5["ClassDeclaration"] = 263] = "ClassDeclaration";
                    SyntaxKind5[SyntaxKind5["InterfaceDeclaration"] = 264] = "InterfaceDeclaration";
                    SyntaxKind5[SyntaxKind5["TypeAliasDeclaration"] = 265] = "TypeAliasDeclaration";
                    SyntaxKind5[SyntaxKind5["EnumDeclaration"] = 266] = "EnumDeclaration";
                    SyntaxKind5[SyntaxKind5["ModuleDeclaration"] = 267] = "ModuleDeclaration";
                    SyntaxKind5[SyntaxKind5["ModuleBlock"] = 268] = "ModuleBlock";
                    SyntaxKind5[SyntaxKind5["CaseBlock"] = 269] = "CaseBlock";
                    SyntaxKind5[SyntaxKind5["NamespaceExportDeclaration"] = 270] = "NamespaceExportDeclaration";
                    SyntaxKind5[SyntaxKind5["ImportEqualsDeclaration"] = 271] = "ImportEqualsDeclaration";
                    SyntaxKind5[SyntaxKind5["ImportDeclaration"] = 272] = "ImportDeclaration";
                    SyntaxKind5[SyntaxKind5["ImportClause"] = 273] = "ImportClause";
                    SyntaxKind5[SyntaxKind5["NamespaceImport"] = 274] = "NamespaceImport";
                    SyntaxKind5[SyntaxKind5["NamedImports"] = 275] = "NamedImports";
                    SyntaxKind5[SyntaxKind5["ImportSpecifier"] = 276] = "ImportSpecifier";
                    SyntaxKind5[SyntaxKind5["ExportAssignment"] = 277] = "ExportAssignment";
                    SyntaxKind5[SyntaxKind5["ExportDeclaration"] = 278] = "ExportDeclaration";
                    SyntaxKind5[SyntaxKind5["NamedExports"] = 279] = "NamedExports";
                    SyntaxKind5[SyntaxKind5["NamespaceExport"] = 280] = "NamespaceExport";
                    SyntaxKind5[SyntaxKind5["ExportSpecifier"] = 281] = "ExportSpecifier";
                    SyntaxKind5[SyntaxKind5["MissingDeclaration"] = 282] = "MissingDeclaration";
                    SyntaxKind5[SyntaxKind5["ExternalModuleReference"] = 283] = "ExternalModuleReference";
                    SyntaxKind5[SyntaxKind5["JsxElement"] = 284] = "JsxElement";
                    SyntaxKind5[SyntaxKind5["JsxSelfClosingElement"] = 285] = "JsxSelfClosingElement";
                    SyntaxKind5[SyntaxKind5["JsxOpeningElement"] = 286] = "JsxOpeningElement";
                    SyntaxKind5[SyntaxKind5["JsxClosingElement"] = 287] = "JsxClosingElement";
                    SyntaxKind5[SyntaxKind5["JsxFragment"] = 288] = "JsxFragment";
                    SyntaxKind5[SyntaxKind5["JsxOpeningFragment"] = 289] = "JsxOpeningFragment";
                    SyntaxKind5[SyntaxKind5["JsxClosingFragment"] = 290] = "JsxClosingFragment";
                    SyntaxKind5[SyntaxKind5["JsxAttribute"] = 291] = "JsxAttribute";
                    SyntaxKind5[SyntaxKind5["JsxAttributes"] = 292] = "JsxAttributes";
                    SyntaxKind5[SyntaxKind5["JsxSpreadAttribute"] = 293] = "JsxSpreadAttribute";
                    SyntaxKind5[SyntaxKind5["JsxExpression"] = 294] = "JsxExpression";
                    SyntaxKind5[SyntaxKind5["JsxNamespacedName"] = 295] = "JsxNamespacedName";
                    SyntaxKind5[SyntaxKind5["CaseClause"] = 296] = "CaseClause";
                    SyntaxKind5[SyntaxKind5["DefaultClause"] = 297] = "DefaultClause";
                    SyntaxKind5[SyntaxKind5["HeritageClause"] = 298] = "HeritageClause";
                    SyntaxKind5[SyntaxKind5["CatchClause"] = 299] = "CatchClause";
                    SyntaxKind5[SyntaxKind5["ImportAttributes"] = 300] = "ImportAttributes";
                    SyntaxKind5[SyntaxKind5["ImportAttribute"] = 301] = "ImportAttribute";
                    SyntaxKind5[SyntaxKind5["AssertClause"] = 300 /* ImportAttributes */] = "AssertClause";
                    SyntaxKind5[SyntaxKind5["AssertEntry"] = 301 /* ImportAttribute */] = "AssertEntry";
                    SyntaxKind5[SyntaxKind5["ImportTypeAssertionContainer"] = 302] = "ImportTypeAssertionContainer";
                    SyntaxKind5[SyntaxKind5["PropertyAssignment"] = 303] = "PropertyAssignment";
                    SyntaxKind5[SyntaxKind5["ShorthandPropertyAssignment"] = 304] = "ShorthandPropertyAssignment";
                    SyntaxKind5[SyntaxKind5["SpreadAssignment"] = 305] = "SpreadAssignment";
                    SyntaxKind5[SyntaxKind5["EnumMember"] = 306] = "EnumMember";
                    SyntaxKind5[SyntaxKind5["UnparsedPrologue"] = 307] = "UnparsedPrologue";
                    SyntaxKind5[SyntaxKind5["UnparsedPrepend"] = 308] = "UnparsedPrepend";
                    SyntaxKind5[SyntaxKind5["UnparsedText"] = 309] = "UnparsedText";
                    SyntaxKind5[SyntaxKind5["UnparsedInternalText"] = 310] = "UnparsedInternalText";
                    SyntaxKind5[SyntaxKind5["UnparsedSyntheticReference"] = 311] = "UnparsedSyntheticReference";
                    SyntaxKind5[SyntaxKind5["SourceFile"] = 312] = "SourceFile";
                    SyntaxKind5[SyntaxKind5["Bundle"] = 313] = "Bundle";
                    SyntaxKind5[SyntaxKind5["UnparsedSource"] = 314] = "UnparsedSource";
                    SyntaxKind5[SyntaxKind5["InputFiles"] = 315] = "InputFiles";
                    SyntaxKind5[SyntaxKind5["JSDocTypeExpression"] = 316] = "JSDocTypeExpression";
                    SyntaxKind5[SyntaxKind5["JSDocNameReference"] = 317] = "JSDocNameReference";
                    SyntaxKind5[SyntaxKind5["JSDocMemberName"] = 318] = "JSDocMemberName";
                    SyntaxKind5[SyntaxKind5["JSDocAllType"] = 319] = "JSDocAllType";
                    SyntaxKind5[SyntaxKind5["JSDocUnknownType"] = 320] = "JSDocUnknownType";
                    SyntaxKind5[SyntaxKind5["JSDocNullableType"] = 321] = "JSDocNullableType";
                    SyntaxKind5[SyntaxKind5["JSDocNonNullableType"] = 322] = "JSDocNonNullableType";
                    SyntaxKind5[SyntaxKind5["JSDocOptionalType"] = 323] = "JSDocOptionalType";
                    SyntaxKind5[SyntaxKind5["JSDocFunctionType"] = 324] = "JSDocFunctionType";
                    SyntaxKind5[SyntaxKind5["JSDocVariadicType"] = 325] = "JSDocVariadicType";
                    SyntaxKind5[SyntaxKind5["JSDocNamepathType"] = 326] = "JSDocNamepathType";
                    SyntaxKind5[SyntaxKind5["JSDoc"] = 327] = "JSDoc";
                    SyntaxKind5[SyntaxKind5["JSDocComment"] = 327 /* JSDoc */] = "JSDocComment";
                    SyntaxKind5[SyntaxKind5["JSDocText"] = 328] = "JSDocText";
                    SyntaxKind5[SyntaxKind5["JSDocTypeLiteral"] = 329] = "JSDocTypeLiteral";
                    SyntaxKind5[SyntaxKind5["JSDocSignature"] = 330] = "JSDocSignature";
                    SyntaxKind5[SyntaxKind5["JSDocLink"] = 331] = "JSDocLink";
                    SyntaxKind5[SyntaxKind5["JSDocLinkCode"] = 332] = "JSDocLinkCode";
                    SyntaxKind5[SyntaxKind5["JSDocLinkPlain"] = 333] = "JSDocLinkPlain";
                    SyntaxKind5[SyntaxKind5["JSDocTag"] = 334] = "JSDocTag";
                    SyntaxKind5[SyntaxKind5["JSDocAugmentsTag"] = 335] = "JSDocAugmentsTag";
                    SyntaxKind5[SyntaxKind5["JSDocImplementsTag"] = 336] = "JSDocImplementsTag";
                    SyntaxKind5[SyntaxKind5["JSDocAuthorTag"] = 337] = "JSDocAuthorTag";
                    SyntaxKind5[SyntaxKind5["JSDocDeprecatedTag"] = 338] = "JSDocDeprecatedTag";
                    SyntaxKind5[SyntaxKind5["JSDocClassTag"] = 339] = "JSDocClassTag";
                    SyntaxKind5[SyntaxKind5["JSDocPublicTag"] = 340] = "JSDocPublicTag";
                    SyntaxKind5[SyntaxKind5["JSDocPrivateTag"] = 341] = "JSDocPrivateTag";
                    SyntaxKind5[SyntaxKind5["JSDocProtectedTag"] = 342] = "JSDocProtectedTag";
                    SyntaxKind5[SyntaxKind5["JSDocReadonlyTag"] = 343] = "JSDocReadonlyTag";
                    SyntaxKind5[SyntaxKind5["JSDocOverrideTag"] = 344] = "JSDocOverrideTag";
                    SyntaxKind5[SyntaxKind5["JSDocCallbackTag"] = 345] = "JSDocCallbackTag";
                    SyntaxKind5[SyntaxKind5["JSDocOverloadTag"] = 346] = "JSDocOverloadTag";
                    SyntaxKind5[SyntaxKind5["JSDocEnumTag"] = 347] = "JSDocEnumTag";
                    SyntaxKind5[SyntaxKind5["JSDocParameterTag"] = 348] = "JSDocParameterTag";
                    SyntaxKind5[SyntaxKind5["JSDocReturnTag"] = 349] = "JSDocReturnTag";
                    SyntaxKind5[SyntaxKind5["JSDocThisTag"] = 350] = "JSDocThisTag";
                    SyntaxKind5[SyntaxKind5["JSDocTypeTag"] = 351] = "JSDocTypeTag";
                    SyntaxKind5[SyntaxKind5["JSDocTemplateTag"] = 352] = "JSDocTemplateTag";
                    SyntaxKind5[SyntaxKind5["JSDocTypedefTag"] = 353] = "JSDocTypedefTag";
                    SyntaxKind5[SyntaxKind5["JSDocSeeTag"] = 354] = "JSDocSeeTag";
                    SyntaxKind5[SyntaxKind5["JSDocPropertyTag"] = 355] = "JSDocPropertyTag";
                    SyntaxKind5[SyntaxKind5["JSDocThrowsTag"] = 356] = "JSDocThrowsTag";
                    SyntaxKind5[SyntaxKind5["JSDocSatisfiesTag"] = 357] = "JSDocSatisfiesTag";
                    SyntaxKind5[SyntaxKind5["SyntaxList"] = 358] = "SyntaxList";
                    SyntaxKind5[SyntaxKind5["NotEmittedStatement"] = 359] = "NotEmittedStatement";
                    SyntaxKind5[SyntaxKind5["PartiallyEmittedExpression"] = 360] = "PartiallyEmittedExpression";
                    SyntaxKind5[SyntaxKind5["CommaListExpression"] = 361] = "CommaListExpression";
                    SyntaxKind5[SyntaxKind5["SyntheticReferenceExpression"] = 362] = "SyntheticReferenceExpression";
                    SyntaxKind5[SyntaxKind5["Count"] = 363] = "Count";
                    SyntaxKind5[SyntaxKind5["FirstAssignment"] = 64 /* EqualsToken */] = "FirstAssignment";
                    SyntaxKind5[SyntaxKind5["LastAssignment"] = 79 /* CaretEqualsToken */] = "LastAssignment";
                    SyntaxKind5[SyntaxKind5["FirstCompoundAssignment"] = 65 /* PlusEqualsToken */] = "FirstCompoundAssignment";
                    SyntaxKind5[SyntaxKind5["LastCompoundAssignment"] = 79 /* CaretEqualsToken */] = "LastCompoundAssignment";
                    SyntaxKind5[SyntaxKind5["FirstReservedWord"] = 83 /* BreakKeyword */] = "FirstReservedWord";
                    SyntaxKind5[SyntaxKind5["LastReservedWord"] = 118 /* WithKeyword */] = "LastReservedWord";
                    SyntaxKind5[SyntaxKind5["FirstKeyword"] = 83 /* BreakKeyword */] = "FirstKeyword";
                    SyntaxKind5[SyntaxKind5["LastKeyword"] = 165 /* OfKeyword */] = "LastKeyword";
                    SyntaxKind5[SyntaxKind5["FirstFutureReservedWord"] = 119 /* ImplementsKeyword */] = "FirstFutureReservedWord";
                    SyntaxKind5[SyntaxKind5["LastFutureReservedWord"] = 127 /* YieldKeyword */] = "LastFutureReservedWord";
                    SyntaxKind5[SyntaxKind5["FirstTypeNode"] = 182 /* TypePredicate */] = "FirstTypeNode";
                    SyntaxKind5[SyntaxKind5["LastTypeNode"] = 205 /* ImportType */] = "LastTypeNode";
                    SyntaxKind5[SyntaxKind5["FirstPunctuation"] = 19 /* OpenBraceToken */] = "FirstPunctuation";
                    SyntaxKind5[SyntaxKind5["LastPunctuation"] = 79 /* CaretEqualsToken */] = "LastPunctuation";
                    SyntaxKind5[SyntaxKind5["FirstToken"] = 0 /* Unknown */] = "FirstToken";
                    SyntaxKind5[SyntaxKind5["LastToken"] = 165 /* LastKeyword */] = "LastToken";
                    SyntaxKind5[SyntaxKind5["FirstTriviaToken"] = 2 /* SingleLineCommentTrivia */] = "FirstTriviaToken";
                    SyntaxKind5[SyntaxKind5["LastTriviaToken"] = 7 /* ConflictMarkerTrivia */] = "LastTriviaToken";
                    SyntaxKind5[SyntaxKind5["FirstLiteralToken"] = 9 /* NumericLiteral */] = "FirstLiteralToken";
                    SyntaxKind5[SyntaxKind5["LastLiteralToken"] = 15 /* NoSubstitutionTemplateLiteral */] = "LastLiteralToken";
                    SyntaxKind5[SyntaxKind5["FirstTemplateToken"] = 15 /* NoSubstitutionTemplateLiteral */] = "FirstTemplateToken";
                    SyntaxKind5[SyntaxKind5["LastTemplateToken"] = 18 /* TemplateTail */] = "LastTemplateToken";
                    SyntaxKind5[SyntaxKind5["FirstBinaryOperator"] = 30 /* LessThanToken */] = "FirstBinaryOperator";
                    SyntaxKind5[SyntaxKind5["LastBinaryOperator"] = 79 /* CaretEqualsToken */] = "LastBinaryOperator";
                    SyntaxKind5[SyntaxKind5["FirstStatement"] = 243 /* VariableStatement */] = "FirstStatement";
                    SyntaxKind5[SyntaxKind5["LastStatement"] = 259 /* DebuggerStatement */] = "LastStatement";
                    SyntaxKind5[SyntaxKind5["FirstNode"] = 166 /* QualifiedName */] = "FirstNode";
                    SyntaxKind5[SyntaxKind5["FirstJSDocNode"] = 316 /* JSDocTypeExpression */] = "FirstJSDocNode";
                    SyntaxKind5[SyntaxKind5["LastJSDocNode"] = 357 /* JSDocSatisfiesTag */] = "LastJSDocNode";
                    SyntaxKind5[SyntaxKind5["FirstJSDocTagNode"] = 334 /* JSDocTag */] = "FirstJSDocTagNode";
                    SyntaxKind5[SyntaxKind5["LastJSDocTagNode"] = 357 /* JSDocSatisfiesTag */] = "LastJSDocTagNode";
                    SyntaxKind5[SyntaxKind5["FirstContextualKeyword"] = 128 /* AbstractKeyword */] = "FirstContextualKeyword";
                    SyntaxKind5[SyntaxKind5["LastContextualKeyword"] = 165 /* OfKeyword */] = "LastContextualKeyword";
                    return SyntaxKind5;
                })(SyntaxKind || {});
                NodeFlags = /* @__PURE__ */ ((NodeFlags3) => {
                    NodeFlags3[NodeFlags3["None"] = 0] = "None";
                    NodeFlags3[NodeFlags3["Let"] = 1] = "Let";
                    NodeFlags3[NodeFlags3["Const"] = 2] = "Const";
                    NodeFlags3[NodeFlags3["Using"] = 4] = "Using";
                    NodeFlags3[NodeFlags3["AwaitUsing"] = 6] = "AwaitUsing";
                    NodeFlags3[NodeFlags3["NestedNamespace"] = 8] = "NestedNamespace";
                    NodeFlags3[NodeFlags3["Synthesized"] = 16] = "Synthesized";
                    NodeFlags3[NodeFlags3["Namespace"] = 32] = "Namespace";
                    NodeFlags3[NodeFlags3["OptionalChain"] = 64] = "OptionalChain";
                    NodeFlags3[NodeFlags3["ExportContext"] = 128] = "ExportContext";
                    NodeFlags3[NodeFlags3["ContainsThis"] = 256] = "ContainsThis";
                    NodeFlags3[NodeFlags3["HasImplicitReturn"] = 512] = "HasImplicitReturn";
                    NodeFlags3[NodeFlags3["HasExplicitReturn"] = 1024] = "HasExplicitReturn";
                    NodeFlags3[NodeFlags3["GlobalAugmentation"] = 2048] = "GlobalAugmentation";
                    NodeFlags3[NodeFlags3["HasAsyncFunctions"] = 4096] = "HasAsyncFunctions";
                    NodeFlags3[NodeFlags3["DisallowInContext"] = 8192] = "DisallowInContext";
                    NodeFlags3[NodeFlags3["YieldContext"] = 16384] = "YieldContext";
                    NodeFlags3[NodeFlags3["DecoratorContext"] = 32768] = "DecoratorContext";
                    NodeFlags3[NodeFlags3["AwaitContext"] = 65536] = "AwaitContext";
                    NodeFlags3[NodeFlags3["DisallowConditionalTypesContext"] = 131072] = "DisallowConditionalTypesContext";
                    NodeFlags3[NodeFlags3["ThisNodeHasError"] = 262144] = "ThisNodeHasError";
                    NodeFlags3[NodeFlags3["JavaScriptFile"] = 524288] = "JavaScriptFile";
                    NodeFlags3[NodeFlags3["ThisNodeOrAnySubNodesHasError"] = 1048576] = "ThisNodeOrAnySubNodesHasError";
                    NodeFlags3[NodeFlags3["HasAggregatedChildData"] = 2097152] = "HasAggregatedChildData";
                    NodeFlags3[NodeFlags3["PossiblyContainsDynamicImport"] = 4194304] = "PossiblyContainsDynamicImport";
                    NodeFlags3[NodeFlags3["PossiblyContainsImportMeta"] = 8388608] = "PossiblyContainsImportMeta";
                    NodeFlags3[NodeFlags3["JSDoc"] = 16777216] = "JSDoc";
                    NodeFlags3[NodeFlags3["Ambient"] = 33554432] = "Ambient";
                    NodeFlags3[NodeFlags3["InWithStatement"] = 67108864] = "InWithStatement";
                    NodeFlags3[NodeFlags3["JsonFile"] = 134217728] = "JsonFile";
                    NodeFlags3[NodeFlags3["TypeCached"] = 268435456] = "TypeCached";
                    NodeFlags3[NodeFlags3["Deprecated"] = 536870912] = "Deprecated";
                    NodeFlags3[NodeFlags3["BlockScoped"] = 7] = "BlockScoped";
                    NodeFlags3[NodeFlags3["Constant"] = 6] = "Constant";
                    NodeFlags3[NodeFlags3["ReachabilityCheckFlags"] = 1536] = "ReachabilityCheckFlags";
                    NodeFlags3[NodeFlags3["ReachabilityAndEmitFlags"] = 5632] = "ReachabilityAndEmitFlags";
                    NodeFlags3[NodeFlags3["ContextFlags"] = 101441536] = "ContextFlags";
                    NodeFlags3[NodeFlags3["TypeExcludesFlags"] = 81920] = "TypeExcludesFlags";
                    NodeFlags3[NodeFlags3["PermanentlySetIncrementalFlags"] = 12582912] = "PermanentlySetIncrementalFlags";
                    NodeFlags3[NodeFlags3["IdentifierHasExtendedUnicodeEscape"] = 256 /* ContainsThis */] = "IdentifierHasExtendedUnicodeEscape";
                    NodeFlags3[NodeFlags3["IdentifierIsInJSDocNamespace"] = 4096 /* HasAsyncFunctions */] = "IdentifierIsInJSDocNamespace";
                    return NodeFlags3;
                })(NodeFlags || {});
                ModifierFlags = /* @__PURE__ */ ((ModifierFlags3) => {
                    ModifierFlags3[ModifierFlags3["None"] = 0] = "None";
                    ModifierFlags3[ModifierFlags3["Public"] = 1] = "Public";
                    ModifierFlags3[ModifierFlags3["Private"] = 2] = "Private";
                    ModifierFlags3[ModifierFlags3["Protected"] = 4] = "Protected";
                    ModifierFlags3[ModifierFlags3["Readonly"] = 8] = "Readonly";
                    ModifierFlags3[ModifierFlags3["Override"] = 16] = "Override";
                    ModifierFlags3[ModifierFlags3["Export"] = 32] = "Export";
                    ModifierFlags3[ModifierFlags3["Abstract"] = 64] = "Abstract";
                    ModifierFlags3[ModifierFlags3["Ambient"] = 128] = "Ambient";
                    ModifierFlags3[ModifierFlags3["Static"] = 256] = "Static";
                    ModifierFlags3[ModifierFlags3["Accessor"] = 512] = "Accessor";
                    ModifierFlags3[ModifierFlags3["Async"] = 1024] = "Async";
                    ModifierFlags3[ModifierFlags3["Default"] = 2048] = "Default";
                    ModifierFlags3[ModifierFlags3["Const"] = 4096] = "Const";
                    ModifierFlags3[ModifierFlags3["In"] = 8192] = "In";
                    ModifierFlags3[ModifierFlags3["Out"] = 16384] = "Out";
                    ModifierFlags3[ModifierFlags3["Decorator"] = 32768] = "Decorator";
                    ModifierFlags3[ModifierFlags3["Deprecated"] = 65536] = "Deprecated";
                    ModifierFlags3[ModifierFlags3["JSDocPublic"] = 8388608] = "JSDocPublic";
                    ModifierFlags3[ModifierFlags3["JSDocPrivate"] = 16777216] = "JSDocPrivate";
                    ModifierFlags3[ModifierFlags3["JSDocProtected"] = 33554432] = "JSDocProtected";
                    ModifierFlags3[ModifierFlags3["JSDocReadonly"] = 67108864] = "JSDocReadonly";
                    ModifierFlags3[ModifierFlags3["JSDocOverride"] = 134217728] = "JSDocOverride";
                    ModifierFlags3[ModifierFlags3["SyntacticOrJSDocModifiers"] = 31] = "SyntacticOrJSDocModifiers";
                    ModifierFlags3[ModifierFlags3["SyntacticOnlyModifiers"] = 65504] = "SyntacticOnlyModifiers";
                    ModifierFlags3[ModifierFlags3["SyntacticModifiers"] = 65535] = "SyntacticModifiers";
                    ModifierFlags3[ModifierFlags3["JSDocCacheOnlyModifiers"] = 260046848] = "JSDocCacheOnlyModifiers";
                    ModifierFlags3[ModifierFlags3["JSDocOnlyModifiers"] = 65536 /* Deprecated */] = "JSDocOnlyModifiers";
                    ModifierFlags3[ModifierFlags3["NonCacheOnlyModifiers"] = 131071] = "NonCacheOnlyModifiers";
                    ModifierFlags3[ModifierFlags3["HasComputedJSDocModifiers"] = 268435456] = "HasComputedJSDocModifiers";
                    ModifierFlags3[ModifierFlags3["HasComputedFlags"] = 536870912] = "HasComputedFlags";
                    ModifierFlags3[ModifierFlags3["AccessibilityModifier"] = 7] = "AccessibilityModifier";
                    ModifierFlags3[ModifierFlags3["ParameterPropertyModifier"] = 31] = "ParameterPropertyModifier";
                    ModifierFlags3[ModifierFlags3["NonPublicAccessibilityModifier"] = 6] = "NonPublicAccessibilityModifier";
                    ModifierFlags3[ModifierFlags3["TypeScriptModifier"] = 28895] = "TypeScriptModifier";
                    ModifierFlags3[ModifierFlags3["ExportDefault"] = 2080] = "ExportDefault";
                    ModifierFlags3[ModifierFlags3["All"] = 131071] = "All";
                    ModifierFlags3[ModifierFlags3["Modifier"] = 98303] = "Modifier";
                    return ModifierFlags3;
                })(ModifierFlags || {});
                JsxFlags = /* @__PURE__ */ ((JsxFlags2) => {
                    JsxFlags2[JsxFlags2["None"] = 0] = "None";
                    JsxFlags2[JsxFlags2["IntrinsicNamedElement"] = 1] = "IntrinsicNamedElement";
                    JsxFlags2[JsxFlags2["IntrinsicIndexedElement"] = 2] = "IntrinsicIndexedElement";
                    JsxFlags2[JsxFlags2["IntrinsicElement"] = 3] = "IntrinsicElement";
                    return JsxFlags2;
                })(JsxFlags || {});
                RelationComparisonResult = /* @__PURE__ */ ((RelationComparisonResult3) => {
                    RelationComparisonResult3[RelationComparisonResult3["None"] = 0] = "None";
                    RelationComparisonResult3[RelationComparisonResult3["Succeeded"] = 1] = "Succeeded";
                    RelationComparisonResult3[RelationComparisonResult3["Failed"] = 2] = "Failed";
                    RelationComparisonResult3[RelationComparisonResult3["Reported"] = 4] = "Reported";
                    RelationComparisonResult3[RelationComparisonResult3["ReportsUnmeasurable"] = 8] = "ReportsUnmeasurable";
                    RelationComparisonResult3[RelationComparisonResult3["ReportsUnreliable"] = 16] = "ReportsUnreliable";
                    RelationComparisonResult3[RelationComparisonResult3["ReportsMask"] = 24] = "ReportsMask";
                    return RelationComparisonResult3;
                })(RelationComparisonResult || {});
                GeneratedIdentifierFlags = /* @__PURE__ */ ((GeneratedIdentifierFlags2) => {
                    GeneratedIdentifierFlags2[GeneratedIdentifierFlags2["None"] = 0] = "None";
                    GeneratedIdentifierFlags2[GeneratedIdentifierFlags2["Auto"] = 1] = "Auto";
                    GeneratedIdentifierFlags2[GeneratedIdentifierFlags2["Loop"] = 2] = "Loop";
                    GeneratedIdentifierFlags2[GeneratedIdentifierFlags2["Unique"] = 3] = "Unique";
                    GeneratedIdentifierFlags2[GeneratedIdentifierFlags2["Node"] = 4] = "Node";
                    GeneratedIdentifierFlags2[GeneratedIdentifierFlags2["KindMask"] = 7] = "KindMask";
                    GeneratedIdentifierFlags2[GeneratedIdentifierFlags2["ReservedInNestedScopes"] = 8] = "ReservedInNestedScopes";
                    GeneratedIdentifierFlags2[GeneratedIdentifierFlags2["Optimistic"] = 16] = "Optimistic";
                    GeneratedIdentifierFlags2[GeneratedIdentifierFlags2["FileLevel"] = 32] = "FileLevel";
                    GeneratedIdentifierFlags2[GeneratedIdentifierFlags2["AllowNameSubstitution"] = 64] = "AllowNameSubstitution";
                    return GeneratedIdentifierFlags2;
                })(GeneratedIdentifierFlags || {});
                TokenFlags = /* @__PURE__ */ ((TokenFlags2) => {
                    TokenFlags2[TokenFlags2["None"] = 0] = "None";
                    TokenFlags2[TokenFlags2["PrecedingLineBreak"] = 1] = "PrecedingLineBreak";
                    TokenFlags2[TokenFlags2["PrecedingJSDocComment"] = 2] = "PrecedingJSDocComment";
                    TokenFlags2[TokenFlags2["Unterminated"] = 4] = "Unterminated";
                    TokenFlags2[TokenFlags2["ExtendedUnicodeEscape"] = 8] = "ExtendedUnicodeEscape";
                    TokenFlags2[TokenFlags2["Scientific"] = 16] = "Scientific";
                    TokenFlags2[TokenFlags2["Octal"] = 32] = "Octal";
                    TokenFlags2[TokenFlags2["HexSpecifier"] = 64] = "HexSpecifier";
                    TokenFlags2[TokenFlags2["BinarySpecifier"] = 128] = "BinarySpecifier";
                    TokenFlags2[TokenFlags2["OctalSpecifier"] = 256] = "OctalSpecifier";
                    TokenFlags2[TokenFlags2["ContainsSeparator"] = 512] = "ContainsSeparator";
                    TokenFlags2[TokenFlags2["UnicodeEscape"] = 1024] = "UnicodeEscape";
                    TokenFlags2[TokenFlags2["ContainsInvalidEscape"] = 2048] = "ContainsInvalidEscape";
                    TokenFlags2[TokenFlags2["HexEscape"] = 4096] = "HexEscape";
                    TokenFlags2[TokenFlags2["ContainsLeadingZero"] = 8192] = "ContainsLeadingZero";
                    TokenFlags2[TokenFlags2["ContainsInvalidSeparator"] = 16384] = "ContainsInvalidSeparator";
                    TokenFlags2[TokenFlags2["BinaryOrOctalSpecifier"] = 384] = "BinaryOrOctalSpecifier";
                    TokenFlags2[TokenFlags2["WithSpecifier"] = 448] = "WithSpecifier";
                    TokenFlags2[TokenFlags2["StringLiteralFlags"] = 7176] = "StringLiteralFlags";
                    TokenFlags2[TokenFlags2["NumericLiteralFlags"] = 25584] = "NumericLiteralFlags";
                    TokenFlags2[TokenFlags2["TemplateLiteralLikeFlags"] = 7176] = "TemplateLiteralLikeFlags";
                    TokenFlags2[TokenFlags2["IsInvalid"] = 26656] = "IsInvalid";
                    return TokenFlags2;
                })(TokenFlags || {});
                FlowFlags = /* @__PURE__ */ ((FlowFlags2) => {
                    FlowFlags2[FlowFlags2["Unreachable"] = 1] = "Unreachable";
                    FlowFlags2[FlowFlags2["Start"] = 2] = "Start";
                    FlowFlags2[FlowFlags2["BranchLabel"] = 4] = "BranchLabel";
                    FlowFlags2[FlowFlags2["LoopLabel"] = 8] = "LoopLabel";
                    FlowFlags2[FlowFlags2["Assignment"] = 16] = "Assignment";
                    FlowFlags2[FlowFlags2["TrueCondition"] = 32] = "TrueCondition";
                    FlowFlags2[FlowFlags2["FalseCondition"] = 64] = "FalseCondition";
                    FlowFlags2[FlowFlags2["SwitchClause"] = 128] = "SwitchClause";
                    FlowFlags2[FlowFlags2["ArrayMutation"] = 256] = "ArrayMutation";
                    FlowFlags2[FlowFlags2["Call"] = 512] = "Call";
                    FlowFlags2[FlowFlags2["ReduceLabel"] = 1024] = "ReduceLabel";
                    FlowFlags2[FlowFlags2["Referenced"] = 2048] = "Referenced";
                    FlowFlags2[FlowFlags2["Shared"] = 4096] = "Shared";
                    FlowFlags2[FlowFlags2["Label"] = 12] = "Label";
                    FlowFlags2[FlowFlags2["Condition"] = 96] = "Condition";
                    return FlowFlags2;
                })(FlowFlags || {});
                CommentDirectiveType = /* @__PURE__ */ ((CommentDirectiveType2) => {
                    CommentDirectiveType2[CommentDirectiveType2["ExpectError"] = 0] = "ExpectError";
                    CommentDirectiveType2[CommentDirectiveType2["Ignore"] = 1] = "Ignore";
                    return CommentDirectiveType2;
                })(CommentDirectiveType || {});
                OperationCanceledException = class {
                };
                FileIncludeKind = /* @__PURE__ */ ((FileIncludeKind2) => {
                    FileIncludeKind2[FileIncludeKind2["RootFile"] = 0] = "RootFile";
                    FileIncludeKind2[FileIncludeKind2["SourceFromProjectReference"] = 1] = "SourceFromProjectReference";
                    FileIncludeKind2[FileIncludeKind2["OutputFromProjectReference"] = 2] = "OutputFromProjectReference";
                    FileIncludeKind2[FileIncludeKind2["Import"] = 3] = "Import";
                    FileIncludeKind2[FileIncludeKind2["ReferenceFile"] = 4] = "ReferenceFile";
                    FileIncludeKind2[FileIncludeKind2["TypeReferenceDirective"] = 5] = "TypeReferenceDirective";
                    FileIncludeKind2[FileIncludeKind2["LibFile"] = 6] = "LibFile";
                    FileIncludeKind2[FileIncludeKind2["LibReferenceDirective"] = 7] = "LibReferenceDirective";
                    FileIncludeKind2[FileIncludeKind2["AutomaticTypeDirectiveFile"] = 8] = "AutomaticTypeDirectiveFile";
                    return FileIncludeKind2;
                })(FileIncludeKind || {});
                FilePreprocessingDiagnosticsKind = /* @__PURE__ */ ((FilePreprocessingDiagnosticsKind2) => {
                    FilePreprocessingDiagnosticsKind2[FilePreprocessingDiagnosticsKind2["FilePreprocessingReferencedDiagnostic"] = 0] = "FilePreprocessingReferencedDiagnostic";
                    FilePreprocessingDiagnosticsKind2[FilePreprocessingDiagnosticsKind2["FilePreprocessingFileExplainingDiagnostic"] = 1] = "FilePreprocessingFileExplainingDiagnostic";
                    FilePreprocessingDiagnosticsKind2[FilePreprocessingDiagnosticsKind2["ResolutionDiagnostics"] = 2] = "ResolutionDiagnostics";
                    return FilePreprocessingDiagnosticsKind2;
                })(FilePreprocessingDiagnosticsKind || {});
                EmitOnly = /* @__PURE__ */ ((EmitOnly4) => {
                    EmitOnly4[EmitOnly4["Js"] = 0] = "Js";
                    EmitOnly4[EmitOnly4["Dts"] = 1] = "Dts";
                    return EmitOnly4;
                })(EmitOnly || {});
                StructureIsReused = /* @__PURE__ */ ((StructureIsReused2) => {
                    StructureIsReused2[StructureIsReused2["Not"] = 0] = "Not";
                    StructureIsReused2[StructureIsReused2["SafeModules"] = 1] = "SafeModules";
                    StructureIsReused2[StructureIsReused2["Completely"] = 2] = "Completely";
                    return StructureIsReused2;
                })(StructureIsReused || {});
                ExitStatus = /* @__PURE__ */ ((ExitStatus2) => {
                    ExitStatus2[ExitStatus2["Success"] = 0] = "Success";
                    ExitStatus2[ExitStatus2["DiagnosticsPresent_OutputsSkipped"] = 1] = "DiagnosticsPresent_OutputsSkipped";
                    ExitStatus2[ExitStatus2["DiagnosticsPresent_OutputsGenerated"] = 2] = "DiagnosticsPresent_OutputsGenerated";
                    ExitStatus2[ExitStatus2["InvalidProject_OutputsSkipped"] = 3] = "InvalidProject_OutputsSkipped";
                    ExitStatus2[ExitStatus2["ProjectReferenceCycle_OutputsSkipped"] = 4] = "ProjectReferenceCycle_OutputsSkipped";
                    return ExitStatus2;
                })(ExitStatus || {});
                MemberOverrideStatus = /* @__PURE__ */ ((MemberOverrideStatus2) => {
                    MemberOverrideStatus2[MemberOverrideStatus2["Ok"] = 0] = "Ok";
                    MemberOverrideStatus2[MemberOverrideStatus2["NeedsOverride"] = 1] = "NeedsOverride";
                    MemberOverrideStatus2[MemberOverrideStatus2["HasInvalidOverride"] = 2] = "HasInvalidOverride";
                    return MemberOverrideStatus2;
                })(MemberOverrideStatus || {});
                UnionReduction = /* @__PURE__ */ ((UnionReduction2) => {
                    UnionReduction2[UnionReduction2["None"] = 0] = "None";
                    UnionReduction2[UnionReduction2["Literal"] = 1] = "Literal";
                    UnionReduction2[UnionReduction2["Subtype"] = 2] = "Subtype";
                    return UnionReduction2;
                })(UnionReduction || {});
                ContextFlags = /* @__PURE__ */ ((ContextFlags3) => {
                    ContextFlags3[ContextFlags3["None"] = 0] = "None";
                    ContextFlags3[ContextFlags3["Signature"] = 1] = "Signature";
                    ContextFlags3[ContextFlags3["NoConstraints"] = 2] = "NoConstraints";
                    ContextFlags3[ContextFlags3["Completions"] = 4] = "Completions";
                    ContextFlags3[ContextFlags3["SkipBindingPatterns"] = 8] = "SkipBindingPatterns";
                    return ContextFlags3;
                })(ContextFlags || {});
                NodeBuilderFlags = /* @__PURE__ */ ((NodeBuilderFlags2) => {
                    NodeBuilderFlags2[NodeBuilderFlags2["None"] = 0] = "None";
                    NodeBuilderFlags2[NodeBuilderFlags2["NoTruncation"] = 1] = "NoTruncation";
                    NodeBuilderFlags2[NodeBuilderFlags2["WriteArrayAsGenericType"] = 2] = "WriteArrayAsGenericType";
                    NodeBuilderFlags2[NodeBuilderFlags2["GenerateNamesForShadowedTypeParams"] = 4] = "GenerateNamesForShadowedTypeParams";
                    NodeBuilderFlags2[NodeBuilderFlags2["UseStructuralFallback"] = 8] = "UseStructuralFallback";
                    NodeBuilderFlags2[NodeBuilderFlags2["ForbidIndexedAccessSymbolReferences"] = 16] = "ForbidIndexedAccessSymbolReferences";
                    NodeBuilderFlags2[NodeBuilderFlags2["WriteTypeArgumentsOfSignature"] = 32] = "WriteTypeArgumentsOfSignature";
                    NodeBuilderFlags2[NodeBuilderFlags2["UseFullyQualifiedType"] = 64] = "UseFullyQualifiedType";
                    NodeBuilderFlags2[NodeBuilderFlags2["UseOnlyExternalAliasing"] = 128] = "UseOnlyExternalAliasing";
                    NodeBuilderFlags2[NodeBuilderFlags2["SuppressAnyReturnType"] = 256] = "SuppressAnyReturnType";
                    NodeBuilderFlags2[NodeBuilderFlags2["WriteTypeParametersInQualifiedName"] = 512] = "WriteTypeParametersInQualifiedName";
                    NodeBuilderFlags2[NodeBuilderFlags2["MultilineObjectLiterals"] = 1024] = "MultilineObjectLiterals";
                    NodeBuilderFlags2[NodeBuilderFlags2["WriteClassExpressionAsTypeLiteral"] = 2048] = "WriteClassExpressionAsTypeLiteral";
                    NodeBuilderFlags2[NodeBuilderFlags2["UseTypeOfFunction"] = 4096] = "UseTypeOfFunction";
                    NodeBuilderFlags2[NodeBuilderFlags2["OmitParameterModifiers"] = 8192] = "OmitParameterModifiers";
                    NodeBuilderFlags2[NodeBuilderFlags2["UseAliasDefinedOutsideCurrentScope"] = 16384] = "UseAliasDefinedOutsideCurrentScope";
                    NodeBuilderFlags2[NodeBuilderFlags2["UseSingleQuotesForStringLiteralType"] = 268435456] = "UseSingleQuotesForStringLiteralType";
                    NodeBuilderFlags2[NodeBuilderFlags2["NoTypeReduction"] = 536870912] = "NoTypeReduction";
                    NodeBuilderFlags2[NodeBuilderFlags2["OmitThisParameter"] = 33554432] = "OmitThisParameter";
                    NodeBuilderFlags2[NodeBuilderFlags2["AllowThisInObjectLiteral"] = 32768] = "AllowThisInObjectLiteral";
                    NodeBuilderFlags2[NodeBuilderFlags2["AllowQualifiedNameInPlaceOfIdentifier"] = 65536] = "AllowQualifiedNameInPlaceOfIdentifier";
                    NodeBuilderFlags2[NodeBuilderFlags2["AllowAnonymousIdentifier"] = 131072] = "AllowAnonymousIdentifier";
                    NodeBuilderFlags2[NodeBuilderFlags2["AllowEmptyUnionOrIntersection"] = 262144] = "AllowEmptyUnionOrIntersection";
                    NodeBuilderFlags2[NodeBuilderFlags2["AllowEmptyTuple"] = 524288] = "AllowEmptyTuple";
                    NodeBuilderFlags2[NodeBuilderFlags2["AllowUniqueESSymbolType"] = 1048576] = "AllowUniqueESSymbolType";
                    NodeBuilderFlags2[NodeBuilderFlags2["AllowEmptyIndexInfoType"] = 2097152] = "AllowEmptyIndexInfoType";
                    NodeBuilderFlags2[NodeBuilderFlags2["WriteComputedProps"] = 1073741824] = "WriteComputedProps";
                    NodeBuilderFlags2[NodeBuilderFlags2["AllowNodeModulesRelativePaths"] = 67108864] = "AllowNodeModulesRelativePaths";
                    NodeBuilderFlags2[NodeBuilderFlags2["DoNotIncludeSymbolChain"] = 134217728] = "DoNotIncludeSymbolChain";
                    NodeBuilderFlags2[NodeBuilderFlags2["IgnoreErrors"] = 70221824] = "IgnoreErrors";
                    NodeBuilderFlags2[NodeBuilderFlags2["InObjectTypeLiteral"] = 4194304] = "InObjectTypeLiteral";
                    NodeBuilderFlags2[NodeBuilderFlags2["InTypeAlias"] = 8388608] = "InTypeAlias";
                    NodeBuilderFlags2[NodeBuilderFlags2["InInitialEntityName"] = 16777216] = "InInitialEntityName";
                    return NodeBuilderFlags2;
                })(NodeBuilderFlags || {});
                TypeFormatFlags = /* @__PURE__ */ ((TypeFormatFlags2) => {
                    TypeFormatFlags2[TypeFormatFlags2["None"] = 0] = "None";
                    TypeFormatFlags2[TypeFormatFlags2["NoTruncation"] = 1] = "NoTruncation";
                    TypeFormatFlags2[TypeFormatFlags2["WriteArrayAsGenericType"] = 2] = "WriteArrayAsGenericType";
                    TypeFormatFlags2[TypeFormatFlags2["GenerateNamesForShadowedTypeParams"] = 4] = "GenerateNamesForShadowedTypeParams";
                    TypeFormatFlags2[TypeFormatFlags2["UseStructuralFallback"] = 8] = "UseStructuralFallback";
                    TypeFormatFlags2[TypeFormatFlags2["WriteTypeArgumentsOfSignature"] = 32] = "WriteTypeArgumentsOfSignature";
                    TypeFormatFlags2[TypeFormatFlags2["UseFullyQualifiedType"] = 64] = "UseFullyQualifiedType";
                    TypeFormatFlags2[TypeFormatFlags2["SuppressAnyReturnType"] = 256] = "SuppressAnyReturnType";
                    TypeFormatFlags2[TypeFormatFlags2["MultilineObjectLiterals"] = 1024] = "MultilineObjectLiterals";
                    TypeFormatFlags2[TypeFormatFlags2["WriteClassExpressionAsTypeLiteral"] = 2048] = "WriteClassExpressionAsTypeLiteral";
                    TypeFormatFlags2[TypeFormatFlags2["UseTypeOfFunction"] = 4096] = "UseTypeOfFunction";
                    TypeFormatFlags2[TypeFormatFlags2["OmitParameterModifiers"] = 8192] = "OmitParameterModifiers";
                    TypeFormatFlags2[TypeFormatFlags2["UseAliasDefinedOutsideCurrentScope"] = 16384] = "UseAliasDefinedOutsideCurrentScope";
                    TypeFormatFlags2[TypeFormatFlags2["UseSingleQuotesForStringLiteralType"] = 268435456] = "UseSingleQuotesForStringLiteralType";
                    TypeFormatFlags2[TypeFormatFlags2["NoTypeReduction"] = 536870912] = "NoTypeReduction";
                    TypeFormatFlags2[TypeFormatFlags2["OmitThisParameter"] = 33554432] = "OmitThisParameter";
                    TypeFormatFlags2[TypeFormatFlags2["AllowUniqueESSymbolType"] = 1048576] = "AllowUniqueESSymbolType";
                    TypeFormatFlags2[TypeFormatFlags2["AddUndefined"] = 131072] = "AddUndefined";
                    TypeFormatFlags2[TypeFormatFlags2["WriteArrowStyleSignature"] = 262144] = "WriteArrowStyleSignature";
                    TypeFormatFlags2[TypeFormatFlags2["InArrayType"] = 524288] = "InArrayType";
                    TypeFormatFlags2[TypeFormatFlags2["InElementType"] = 2097152] = "InElementType";
                    TypeFormatFlags2[TypeFormatFlags2["InFirstTypeArgument"] = 4194304] = "InFirstTypeArgument";
                    TypeFormatFlags2[TypeFormatFlags2["InTypeAlias"] = 8388608] = "InTypeAlias";
                    TypeFormatFlags2[TypeFormatFlags2["NodeBuilderFlagsMask"] = 848330095] = "NodeBuilderFlagsMask";
                    return TypeFormatFlags2;
                })(TypeFormatFlags || {});
                SymbolFormatFlags = /* @__PURE__ */ ((SymbolFormatFlags2) => {
                    SymbolFormatFlags2[SymbolFormatFlags2["None"] = 0] = "None";
                    SymbolFormatFlags2[SymbolFormatFlags2["WriteTypeParametersOrArguments"] = 1] = "WriteTypeParametersOrArguments";
                    SymbolFormatFlags2[SymbolFormatFlags2["UseOnlyExternalAliasing"] = 2] = "UseOnlyExternalAliasing";
                    SymbolFormatFlags2[SymbolFormatFlags2["AllowAnyNodeKind"] = 4] = "AllowAnyNodeKind";
                    SymbolFormatFlags2[SymbolFormatFlags2["UseAliasDefinedOutsideCurrentScope"] = 8] = "UseAliasDefinedOutsideCurrentScope";
                    SymbolFormatFlags2[SymbolFormatFlags2["WriteComputedProps"] = 16] = "WriteComputedProps";
                    SymbolFormatFlags2[SymbolFormatFlags2["DoNotIncludeSymbolChain"] = 32] = "DoNotIncludeSymbolChain";
                    return SymbolFormatFlags2;
                })(SymbolFormatFlags || {});
                SymbolAccessibility = /* @__PURE__ */ ((SymbolAccessibility2) => {
                    SymbolAccessibility2[SymbolAccessibility2["Accessible"] = 0] = "Accessible";
                    SymbolAccessibility2[SymbolAccessibility2["NotAccessible"] = 1] = "NotAccessible";
                    SymbolAccessibility2[SymbolAccessibility2["CannotBeNamed"] = 2] = "CannotBeNamed";
                    return SymbolAccessibility2;
                })(SymbolAccessibility || {});
                SyntheticSymbolKind = /* @__PURE__ */ ((SyntheticSymbolKind2) => {
                    SyntheticSymbolKind2[SyntheticSymbolKind2["UnionOrIntersection"] = 0] = "UnionOrIntersection";
                    SyntheticSymbolKind2[SyntheticSymbolKind2["Spread"] = 1] = "Spread";
                    return SyntheticSymbolKind2;
                })(SyntheticSymbolKind || {});
                TypePredicateKind = /* @__PURE__ */ ((TypePredicateKind2) => {
                    TypePredicateKind2[TypePredicateKind2["This"] = 0] = "This";
                    TypePredicateKind2[TypePredicateKind2["Identifier"] = 1] = "Identifier";
                    TypePredicateKind2[TypePredicateKind2["AssertsThis"] = 2] = "AssertsThis";
                    TypePredicateKind2[TypePredicateKind2["AssertsIdentifier"] = 3] = "AssertsIdentifier";
                    return TypePredicateKind2;
                })(TypePredicateKind || {});
                TypeReferenceSerializationKind = /* @__PURE__ */ ((TypeReferenceSerializationKind2) => {
                    TypeReferenceSerializationKind2[TypeReferenceSerializationKind2["Unknown"] = 0] = "Unknown";
                    TypeReferenceSerializationKind2[TypeReferenceSerializationKind2["TypeWithConstructSignatureAndValue"] = 1] = "TypeWithConstructSignatureAndValue";
                    TypeReferenceSerializationKind2[TypeReferenceSerializationKind2["VoidNullableOrNeverType"] = 2] = "VoidNullableOrNeverType";
                    TypeReferenceSerializationKind2[TypeReferenceSerializationKind2["NumberLikeType"] = 3] = "NumberLikeType";
                    TypeReferenceSerializationKind2[TypeReferenceSerializationKind2["BigIntLikeType"] = 4] = "BigIntLikeType";
                    TypeReferenceSerializationKind2[TypeReferenceSerializationKind2["StringLikeType"] = 5] = "StringLikeType";
                    TypeReferenceSerializationKind2[TypeReferenceSerializationKind2["BooleanType"] = 6] = "BooleanType";
                    TypeReferenceSerializationKind2[TypeReferenceSerializationKind2["ArrayLikeType"] = 7] = "ArrayLikeType";
                    TypeReferenceSerializationKind2[TypeReferenceSerializationKind2["ESSymbolType"] = 8] = "ESSymbolType";
                    TypeReferenceSerializationKind2[TypeReferenceSerializationKind2["Promise"] = 9] = "Promise";
                    TypeReferenceSerializationKind2[TypeReferenceSerializationKind2["TypeWithCallSignature"] = 10] = "TypeWithCallSignature";
                    TypeReferenceSerializationKind2[TypeReferenceSerializationKind2["ObjectType"] = 11] = "ObjectType";
                    return TypeReferenceSerializationKind2;
                })(TypeReferenceSerializationKind || {});
                SymbolFlags = /* @__PURE__ */ ((SymbolFlags3) => {
                    SymbolFlags3[SymbolFlags3["None"] = 0] = "None";
                    SymbolFlags3[SymbolFlags3["FunctionScopedVariable"] = 1] = "FunctionScopedVariable";
                    SymbolFlags3[SymbolFlags3["BlockScopedVariable"] = 2] = "BlockScopedVariable";
                    SymbolFlags3[SymbolFlags3["Property"] = 4] = "Property";
                    SymbolFlags3[SymbolFlags3["EnumMember"] = 8] = "EnumMember";
                    SymbolFlags3[SymbolFlags3["Function"] = 16] = "Function";
                    SymbolFlags3[SymbolFlags3["Class"] = 32] = "Class";
                    SymbolFlags3[SymbolFlags3["Interface"] = 64] = "Interface";
                    SymbolFlags3[SymbolFlags3["ConstEnum"] = 128] = "ConstEnum";
                    SymbolFlags3[SymbolFlags3["RegularEnum"] = 256] = "RegularEnum";
                    SymbolFlags3[SymbolFlags3["ValueModule"] = 512] = "ValueModule";
                    SymbolFlags3[SymbolFlags3["NamespaceModule"] = 1024] = "NamespaceModule";
                    SymbolFlags3[SymbolFlags3["TypeLiteral"] = 2048] = "TypeLiteral";
                    SymbolFlags3[SymbolFlags3["ObjectLiteral"] = 4096] = "ObjectLiteral";
                    SymbolFlags3[SymbolFlags3["Method"] = 8192] = "Method";
                    SymbolFlags3[SymbolFlags3["Constructor"] = 16384] = "Constructor";
                    SymbolFlags3[SymbolFlags3["GetAccessor"] = 32768] = "GetAccessor";
                    SymbolFlags3[SymbolFlags3["SetAccessor"] = 65536] = "SetAccessor";
                    SymbolFlags3[SymbolFlags3["Signature"] = 131072] = "Signature";
                    SymbolFlags3[SymbolFlags3["TypeParameter"] = 262144] = "TypeParameter";
                    SymbolFlags3[SymbolFlags3["TypeAlias"] = 524288] = "TypeAlias";
                    SymbolFlags3[SymbolFlags3["ExportValue"] = 1048576] = "ExportValue";
                    SymbolFlags3[SymbolFlags3["Alias"] = 2097152] = "Alias";
                    SymbolFlags3[SymbolFlags3["Prototype"] = 4194304] = "Prototype";
                    SymbolFlags3[SymbolFlags3["ExportStar"] = 8388608] = "ExportStar";
                    SymbolFlags3[SymbolFlags3["Optional"] = 16777216] = "Optional";
                    SymbolFlags3[SymbolFlags3["Transient"] = 33554432] = "Transient";
                    SymbolFlags3[SymbolFlags3["Assignment"] = 67108864] = "Assignment";
                    SymbolFlags3[SymbolFlags3["ModuleExports"] = 134217728] = "ModuleExports";
                    SymbolFlags3[SymbolFlags3["All"] = -1] = "All";
                    SymbolFlags3[SymbolFlags3["Enum"] = 384] = "Enum";
                    SymbolFlags3[SymbolFlags3["Variable"] = 3] = "Variable";
                    SymbolFlags3[SymbolFlags3["Value"] = 111551] = "Value";
                    SymbolFlags3[SymbolFlags3["Type"] = 788968] = "Type";
                    SymbolFlags3[SymbolFlags3["Namespace"] = 1920] = "Namespace";
                    SymbolFlags3[SymbolFlags3["Module"] = 1536] = "Module";
                    SymbolFlags3[SymbolFlags3["Accessor"] = 98304] = "Accessor";
                    SymbolFlags3[SymbolFlags3["FunctionScopedVariableExcludes"] = 111550] = "FunctionScopedVariableExcludes";
                    SymbolFlags3[SymbolFlags3["BlockScopedVariableExcludes"] = 111551 /* Value */] = "BlockScopedVariableExcludes";
                    SymbolFlags3[SymbolFlags3["ParameterExcludes"] = 111551 /* Value */] = "ParameterExcludes";
                    SymbolFlags3[SymbolFlags3["PropertyExcludes"] = 0 /* None */] = "PropertyExcludes";
                    SymbolFlags3[SymbolFlags3["EnumMemberExcludes"] = 900095] = "EnumMemberExcludes";
                    SymbolFlags3[SymbolFlags3["FunctionExcludes"] = 110991] = "FunctionExcludes";
                    SymbolFlags3[SymbolFlags3["ClassExcludes"] = 899503] = "ClassExcludes";
                    SymbolFlags3[SymbolFlags3["InterfaceExcludes"] = 788872] = "InterfaceExcludes";
                    SymbolFlags3[SymbolFlags3["RegularEnumExcludes"] = 899327] = "RegularEnumExcludes";
                    SymbolFlags3[SymbolFlags3["ConstEnumExcludes"] = 899967] = "ConstEnumExcludes";
                    SymbolFlags3[SymbolFlags3["ValueModuleExcludes"] = 110735] = "ValueModuleExcludes";
                    SymbolFlags3[SymbolFlags3["NamespaceModuleExcludes"] = 0] = "NamespaceModuleExcludes";
                    SymbolFlags3[SymbolFlags3["MethodExcludes"] = 103359] = "MethodExcludes";
                    SymbolFlags3[SymbolFlags3["GetAccessorExcludes"] = 46015] = "GetAccessorExcludes";
                    SymbolFlags3[SymbolFlags3["SetAccessorExcludes"] = 78783] = "SetAccessorExcludes";
                    SymbolFlags3[SymbolFlags3["AccessorExcludes"] = 13247] = "AccessorExcludes";
                    SymbolFlags3[SymbolFlags3["TypeParameterExcludes"] = 526824] = "TypeParameterExcludes";
                    SymbolFlags3[SymbolFlags3["TypeAliasExcludes"] = 788968 /* Type */] = "TypeAliasExcludes";
                    SymbolFlags3[SymbolFlags3["AliasExcludes"] = 2097152 /* Alias */] = "AliasExcludes";
                    SymbolFlags3[SymbolFlags3["ModuleMember"] = 2623475] = "ModuleMember";
                    SymbolFlags3[SymbolFlags3["ExportHasLocal"] = 944] = "ExportHasLocal";
                    SymbolFlags3[SymbolFlags3["BlockScoped"] = 418] = "BlockScoped";
                    SymbolFlags3[SymbolFlags3["PropertyOrAccessor"] = 98308] = "PropertyOrAccessor";
                    SymbolFlags3[SymbolFlags3["ClassMember"] = 106500] = "ClassMember";
                    SymbolFlags3[SymbolFlags3["ExportSupportsDefaultModifier"] = 112] = "ExportSupportsDefaultModifier";
                    SymbolFlags3[SymbolFlags3["ExportDoesNotSupportDefaultModifier"] = -113] = "ExportDoesNotSupportDefaultModifier";
                    SymbolFlags3[SymbolFlags3["Classifiable"] = 2885600] = "Classifiable";
                    SymbolFlags3[SymbolFlags3["LateBindingContainer"] = 6256] = "LateBindingContainer";
                    return SymbolFlags3;
                })(SymbolFlags || {});
                EnumKind = /* @__PURE__ */ ((EnumKind2) => {
                    EnumKind2[EnumKind2["Numeric"] = 0] = "Numeric";
                    EnumKind2[EnumKind2["Literal"] = 1] = "Literal";
                    return EnumKind2;
                })(EnumKind || {});
                CheckFlags = /* @__PURE__ */ ((CheckFlags2) => {
                    CheckFlags2[CheckFlags2["None"] = 0] = "None";
                    CheckFlags2[CheckFlags2["Instantiated"] = 1] = "Instantiated";
                    CheckFlags2[CheckFlags2["SyntheticProperty"] = 2] = "SyntheticProperty";
                    CheckFlags2[CheckFlags2["SyntheticMethod"] = 4] = "SyntheticMethod";
                    CheckFlags2[CheckFlags2["Readonly"] = 8] = "Readonly";
                    CheckFlags2[CheckFlags2["ReadPartial"] = 16] = "ReadPartial";
                    CheckFlags2[CheckFlags2["WritePartial"] = 32] = "WritePartial";
                    CheckFlags2[CheckFlags2["HasNonUniformType"] = 64] = "HasNonUniformType";
                    CheckFlags2[CheckFlags2["HasLiteralType"] = 128] = "HasLiteralType";
                    CheckFlags2[CheckFlags2["ContainsPublic"] = 256] = "ContainsPublic";
                    CheckFlags2[CheckFlags2["ContainsProtected"] = 512] = "ContainsProtected";
                    CheckFlags2[CheckFlags2["ContainsPrivate"] = 1024] = "ContainsPrivate";
                    CheckFlags2[CheckFlags2["ContainsStatic"] = 2048] = "ContainsStatic";
                    CheckFlags2[CheckFlags2["Late"] = 4096] = "Late";
                    CheckFlags2[CheckFlags2["ReverseMapped"] = 8192] = "ReverseMapped";
                    CheckFlags2[CheckFlags2["OptionalParameter"] = 16384] = "OptionalParameter";
                    CheckFlags2[CheckFlags2["RestParameter"] = 32768] = "RestParameter";
                    CheckFlags2[CheckFlags2["DeferredType"] = 65536] = "DeferredType";
                    CheckFlags2[CheckFlags2["HasNeverType"] = 131072] = "HasNeverType";
                    CheckFlags2[CheckFlags2["Mapped"] = 262144] = "Mapped";
                    CheckFlags2[CheckFlags2["StripOptional"] = 524288] = "StripOptional";
                    CheckFlags2[CheckFlags2["Unresolved"] = 1048576] = "Unresolved";
                    CheckFlags2[CheckFlags2["Synthetic"] = 6] = "Synthetic";
                    CheckFlags2[CheckFlags2["Discriminant"] = 192] = "Discriminant";
                    CheckFlags2[CheckFlags2["Partial"] = 48] = "Partial";
                    return CheckFlags2;
                })(CheckFlags || {});
                InternalSymbolName = /* @__PURE__ */ ((InternalSymbolName2) => {
                    InternalSymbolName2["Call"] = "__call";
                    InternalSymbolName2["Constructor"] = "__constructor";
                    InternalSymbolName2["New"] = "__new";
                    InternalSymbolName2["Index"] = "__index";
                    InternalSymbolName2["ExportStar"] = "__export";
                    InternalSymbolName2["Global"] = "__global";
                    InternalSymbolName2["Missing"] = "__missing";
                    InternalSymbolName2["Type"] = "__type";
                    InternalSymbolName2["Object"] = "__object";
                    InternalSymbolName2["JSXAttributes"] = "__jsxAttributes";
                    InternalSymbolName2["Class"] = "__class";
                    InternalSymbolName2["Function"] = "__function";
                    InternalSymbolName2["Computed"] = "__computed";
                    InternalSymbolName2["Resolving"] = "__resolving__";
                    InternalSymbolName2["ExportEquals"] = "export=";
                    InternalSymbolName2["Default"] = "default";
                    InternalSymbolName2["This"] = "this";
                    InternalSymbolName2["InstantiationExpression"] = "__instantiationExpression";
                    InternalSymbolName2["ImportAttributes"] = "__importAttributes";
                    return InternalSymbolName2;
                })(InternalSymbolName || {});
                NodeCheckFlags = /* @__PURE__ */ ((NodeCheckFlags2) => {
                    NodeCheckFlags2[NodeCheckFlags2["None"] = 0] = "None";
                    NodeCheckFlags2[NodeCheckFlags2["TypeChecked"] = 1] = "TypeChecked";
                    NodeCheckFlags2[NodeCheckFlags2["LexicalThis"] = 2] = "LexicalThis";
                    NodeCheckFlags2[NodeCheckFlags2["CaptureThis"] = 4] = "CaptureThis";
                    NodeCheckFlags2[NodeCheckFlags2["CaptureNewTarget"] = 8] = "CaptureNewTarget";
                    NodeCheckFlags2[NodeCheckFlags2["SuperInstance"] = 16] = "SuperInstance";
                    NodeCheckFlags2[NodeCheckFlags2["SuperStatic"] = 32] = "SuperStatic";
                    NodeCheckFlags2[NodeCheckFlags2["ContextChecked"] = 64] = "ContextChecked";
                    NodeCheckFlags2[NodeCheckFlags2["MethodWithSuperPropertyAccessInAsync"] = 128] = "MethodWithSuperPropertyAccessInAsync";
                    NodeCheckFlags2[NodeCheckFlags2["MethodWithSuperPropertyAssignmentInAsync"] = 256] = "MethodWithSuperPropertyAssignmentInAsync";
                    NodeCheckFlags2[NodeCheckFlags2["CaptureArguments"] = 512] = "CaptureArguments";
                    NodeCheckFlags2[NodeCheckFlags2["EnumValuesComputed"] = 1024] = "EnumValuesComputed";
                    NodeCheckFlags2[NodeCheckFlags2["LexicalModuleMergesWithClass"] = 2048] = "LexicalModuleMergesWithClass";
                    NodeCheckFlags2[NodeCheckFlags2["LoopWithCapturedBlockScopedBinding"] = 4096] = "LoopWithCapturedBlockScopedBinding";
                    NodeCheckFlags2[NodeCheckFlags2["ContainsCapturedBlockScopeBinding"] = 8192] = "ContainsCapturedBlockScopeBinding";
                    NodeCheckFlags2[NodeCheckFlags2["CapturedBlockScopedBinding"] = 16384] = "CapturedBlockScopedBinding";
                    NodeCheckFlags2[NodeCheckFlags2["BlockScopedBindingInLoop"] = 32768] = "BlockScopedBindingInLoop";
                    NodeCheckFlags2[NodeCheckFlags2["NeedsLoopOutParameter"] = 65536] = "NeedsLoopOutParameter";
                    NodeCheckFlags2[NodeCheckFlags2["AssignmentsMarked"] = 131072] = "AssignmentsMarked";
                    NodeCheckFlags2[NodeCheckFlags2["ContainsConstructorReference"] = 262144] = "ContainsConstructorReference";
                    NodeCheckFlags2[NodeCheckFlags2["ConstructorReference"] = 536870912] = "ConstructorReference";
                    NodeCheckFlags2[NodeCheckFlags2["ContainsClassWithPrivateIdentifiers"] = 1048576] = "ContainsClassWithPrivateIdentifiers";
                    NodeCheckFlags2[NodeCheckFlags2["ContainsSuperPropertyInStaticInitializer"] = 2097152] = "ContainsSuperPropertyInStaticInitializer";
                    NodeCheckFlags2[NodeCheckFlags2["InCheckIdentifier"] = 4194304] = "InCheckIdentifier";
                    return NodeCheckFlags2;
                })(NodeCheckFlags || {});
                TypeFlags = /* @__PURE__ */ ((TypeFlags2) => {
                    TypeFlags2[TypeFlags2["Any"] = 1] = "Any";
                    TypeFlags2[TypeFlags2["Unknown"] = 2] = "Unknown";
                    TypeFlags2[TypeFlags2["String"] = 4] = "String";
                    TypeFlags2[TypeFlags2["Number"] = 8] = "Number";
                    TypeFlags2[TypeFlags2["Boolean"] = 16] = "Boolean";
                    TypeFlags2[TypeFlags2["Enum"] = 32] = "Enum";
                    TypeFlags2[TypeFlags2["BigInt"] = 64] = "BigInt";
                    TypeFlags2[TypeFlags2["StringLiteral"] = 128] = "StringLiteral";
                    TypeFlags2[TypeFlags2["NumberLiteral"] = 256] = "NumberLiteral";
                    TypeFlags2[TypeFlags2["BooleanLiteral"] = 512] = "BooleanLiteral";
                    TypeFlags2[TypeFlags2["EnumLiteral"] = 1024] = "EnumLiteral";
                    TypeFlags2[TypeFlags2["BigIntLiteral"] = 2048] = "BigIntLiteral";
                    TypeFlags2[TypeFlags2["ESSymbol"] = 4096] = "ESSymbol";
                    TypeFlags2[TypeFlags2["UniqueESSymbol"] = 8192] = "UniqueESSymbol";
                    TypeFlags2[TypeFlags2["Void"] = 16384] = "Void";
                    TypeFlags2[TypeFlags2["Undefined"] = 32768] = "Undefined";
                    TypeFlags2[TypeFlags2["Null"] = 65536] = "Null";
                    TypeFlags2[TypeFlags2["Never"] = 131072] = "Never";
                    TypeFlags2[TypeFlags2["TypeParameter"] = 262144] = "TypeParameter";
                    TypeFlags2[TypeFlags2["Object"] = 524288] = "Object";
                    TypeFlags2[TypeFlags2["Union"] = 1048576] = "Union";
                    TypeFlags2[TypeFlags2["Intersection"] = 2097152] = "Intersection";
                    TypeFlags2[TypeFlags2["Index"] = 4194304] = "Index";
                    TypeFlags2[TypeFlags2["IndexedAccess"] = 8388608] = "IndexedAccess";
                    TypeFlags2[TypeFlags2["Conditional"] = 16777216] = "Conditional";
                    TypeFlags2[TypeFlags2["Substitution"] = 33554432] = "Substitution";
                    TypeFlags2[TypeFlags2["NonPrimitive"] = 67108864] = "NonPrimitive";
                    TypeFlags2[TypeFlags2["TemplateLiteral"] = 134217728] = "TemplateLiteral";
                    TypeFlags2[TypeFlags2["StringMapping"] = 268435456] = "StringMapping";
                    TypeFlags2[TypeFlags2["Reserved1"] = 536870912] = "Reserved1";
                    TypeFlags2[TypeFlags2["AnyOrUnknown"] = 3] = "AnyOrUnknown";
                    TypeFlags2[TypeFlags2["Nullable"] = 98304] = "Nullable";
                    TypeFlags2[TypeFlags2["Literal"] = 2944] = "Literal";
                    TypeFlags2[TypeFlags2["Unit"] = 109472] = "Unit";
                    TypeFlags2[TypeFlags2["Freshable"] = 2976] = "Freshable";
                    TypeFlags2[TypeFlags2["StringOrNumberLiteral"] = 384] = "StringOrNumberLiteral";
                    TypeFlags2[TypeFlags2["StringOrNumberLiteralOrUnique"] = 8576] = "StringOrNumberLiteralOrUnique";
                    TypeFlags2[TypeFlags2["DefinitelyFalsy"] = 117632] = "DefinitelyFalsy";
                    TypeFlags2[TypeFlags2["PossiblyFalsy"] = 117724] = "PossiblyFalsy";
                    TypeFlags2[TypeFlags2["Intrinsic"] = 67359327] = "Intrinsic";
                    TypeFlags2[TypeFlags2["StringLike"] = 402653316] = "StringLike";
                    TypeFlags2[TypeFlags2["NumberLike"] = 296] = "NumberLike";
                    TypeFlags2[TypeFlags2["BigIntLike"] = 2112] = "BigIntLike";
                    TypeFlags2[TypeFlags2["BooleanLike"] = 528] = "BooleanLike";
                    TypeFlags2[TypeFlags2["EnumLike"] = 1056] = "EnumLike";
                    TypeFlags2[TypeFlags2["ESSymbolLike"] = 12288] = "ESSymbolLike";
                    TypeFlags2[TypeFlags2["VoidLike"] = 49152] = "VoidLike";
                    TypeFlags2[TypeFlags2["Primitive"] = 402784252] = "Primitive";
                    TypeFlags2[TypeFlags2["DefinitelyNonNullable"] = 470302716] = "DefinitelyNonNullable";
                    TypeFlags2[TypeFlags2["DisjointDomains"] = 469892092] = "DisjointDomains";
                    TypeFlags2[TypeFlags2["UnionOrIntersection"] = 3145728] = "UnionOrIntersection";
                    TypeFlags2[TypeFlags2["StructuredType"] = 3670016] = "StructuredType";
                    TypeFlags2[TypeFlags2["TypeVariable"] = 8650752] = "TypeVariable";
                    TypeFlags2[TypeFlags2["InstantiableNonPrimitive"] = 58982400] = "InstantiableNonPrimitive";
                    TypeFlags2[TypeFlags2["InstantiablePrimitive"] = 406847488] = "InstantiablePrimitive";
                    TypeFlags2[TypeFlags2["Instantiable"] = 465829888] = "Instantiable";
                    TypeFlags2[TypeFlags2["StructuredOrInstantiable"] = 469499904] = "StructuredOrInstantiable";
                    TypeFlags2[TypeFlags2["ObjectFlagsType"] = 3899393] = "ObjectFlagsType";
                    TypeFlags2[TypeFlags2["Simplifiable"] = 25165824] = "Simplifiable";
                    TypeFlags2[TypeFlags2["Singleton"] = 67358815] = "Singleton";
                    TypeFlags2[TypeFlags2["Narrowable"] = 536624127] = "Narrowable";
                    TypeFlags2[TypeFlags2["IncludesMask"] = 473694207] = "IncludesMask";
                    TypeFlags2[TypeFlags2["IncludesMissingType"] = 262144 /* TypeParameter */] = "IncludesMissingType";
                    TypeFlags2[TypeFlags2["IncludesNonWideningType"] = 4194304 /* Index */] = "IncludesNonWideningType";
                    TypeFlags2[TypeFlags2["IncludesWildcard"] = 8388608 /* IndexedAccess */] = "IncludesWildcard";
                    TypeFlags2[TypeFlags2["IncludesEmptyObject"] = 16777216 /* Conditional */] = "IncludesEmptyObject";
                    TypeFlags2[TypeFlags2["IncludesInstantiable"] = 33554432 /* Substitution */] = "IncludesInstantiable";
                    TypeFlags2[TypeFlags2["IncludesConstrainedTypeVariable"] = 536870912 /* Reserved1 */] = "IncludesConstrainedTypeVariable";
                    TypeFlags2[TypeFlags2["NotPrimitiveUnion"] = 36323331] = "NotPrimitiveUnion";
                    return TypeFlags2;
                })(TypeFlags || {});
                ObjectFlags = /* @__PURE__ */ ((ObjectFlags3) => {
                    ObjectFlags3[ObjectFlags3["None"] = 0] = "None";
                    ObjectFlags3[ObjectFlags3["Class"] = 1] = "Class";
                    ObjectFlags3[ObjectFlags3["Interface"] = 2] = "Interface";
                    ObjectFlags3[ObjectFlags3["Reference"] = 4] = "Reference";
                    ObjectFlags3[ObjectFlags3["Tuple"] = 8] = "Tuple";
                    ObjectFlags3[ObjectFlags3["Anonymous"] = 16] = "Anonymous";
                    ObjectFlags3[ObjectFlags3["Mapped"] = 32] = "Mapped";
                    ObjectFlags3[ObjectFlags3["Instantiated"] = 64] = "Instantiated";
                    ObjectFlags3[ObjectFlags3["ObjectLiteral"] = 128] = "ObjectLiteral";
                    ObjectFlags3[ObjectFlags3["EvolvingArray"] = 256] = "EvolvingArray";
                    ObjectFlags3[ObjectFlags3["ObjectLiteralPatternWithComputedProperties"] = 512] = "ObjectLiteralPatternWithComputedProperties";
                    ObjectFlags3[ObjectFlags3["ReverseMapped"] = 1024] = "ReverseMapped";
                    ObjectFlags3[ObjectFlags3["JsxAttributes"] = 2048] = "JsxAttributes";
                    ObjectFlags3[ObjectFlags3["JSLiteral"] = 4096] = "JSLiteral";
                    ObjectFlags3[ObjectFlags3["FreshLiteral"] = 8192] = "FreshLiteral";
                    ObjectFlags3[ObjectFlags3["ArrayLiteral"] = 16384] = "ArrayLiteral";
                    ObjectFlags3[ObjectFlags3["PrimitiveUnion"] = 32768] = "PrimitiveUnion";
                    ObjectFlags3[ObjectFlags3["ContainsWideningType"] = 65536] = "ContainsWideningType";
                    ObjectFlags3[ObjectFlags3["ContainsObjectOrArrayLiteral"] = 131072] = "ContainsObjectOrArrayLiteral";
                    ObjectFlags3[ObjectFlags3["NonInferrableType"] = 262144] = "NonInferrableType";
                    ObjectFlags3[ObjectFlags3["CouldContainTypeVariablesComputed"] = 524288] = "CouldContainTypeVariablesComputed";
                    ObjectFlags3[ObjectFlags3["CouldContainTypeVariables"] = 1048576] = "CouldContainTypeVariables";
                    ObjectFlags3[ObjectFlags3["ClassOrInterface"] = 3] = "ClassOrInterface";
                    ObjectFlags3[ObjectFlags3["RequiresWidening"] = 196608] = "RequiresWidening";
                    ObjectFlags3[ObjectFlags3["PropagatingFlags"] = 458752] = "PropagatingFlags";
                    ObjectFlags3[ObjectFlags3["InstantiatedMapped"] = 96] = "InstantiatedMapped";
                    ObjectFlags3[ObjectFlags3["ObjectTypeKindMask"] = 1343] = "ObjectTypeKindMask";
                    ObjectFlags3[ObjectFlags3["ContainsSpread"] = 2097152] = "ContainsSpread";
                    ObjectFlags3[ObjectFlags3["ObjectRestType"] = 4194304] = "ObjectRestType";
                    ObjectFlags3[ObjectFlags3["InstantiationExpressionType"] = 8388608] = "InstantiationExpressionType";
                    ObjectFlags3[ObjectFlags3["IsClassInstanceClone"] = 16777216] = "IsClassInstanceClone";
                    ObjectFlags3[ObjectFlags3["IdenticalBaseTypeCalculated"] = 33554432] = "IdenticalBaseTypeCalculated";
                    ObjectFlags3[ObjectFlags3["IdenticalBaseTypeExists"] = 67108864] = "IdenticalBaseTypeExists";
                    ObjectFlags3[ObjectFlags3["IsGenericTypeComputed"] = 2097152] = "IsGenericTypeComputed";
                    ObjectFlags3[ObjectFlags3["IsGenericObjectType"] = 4194304] = "IsGenericObjectType";
                    ObjectFlags3[ObjectFlags3["IsGenericIndexType"] = 8388608] = "IsGenericIndexType";
                    ObjectFlags3[ObjectFlags3["IsGenericType"] = 12582912] = "IsGenericType";
                    ObjectFlags3[ObjectFlags3["ContainsIntersections"] = 16777216] = "ContainsIntersections";
                    ObjectFlags3[ObjectFlags3["IsUnknownLikeUnionComputed"] = 33554432] = "IsUnknownLikeUnionComputed";
                    ObjectFlags3[ObjectFlags3["IsUnknownLikeUnion"] = 67108864] = "IsUnknownLikeUnion";
                    ObjectFlags3[ObjectFlags3["IsNeverIntersectionComputed"] = 16777216] = "IsNeverIntersectionComputed";
                    ObjectFlags3[ObjectFlags3["IsNeverIntersection"] = 33554432] = "IsNeverIntersection";
                    ObjectFlags3[ObjectFlags3["IsConstrainedTypeVariable"] = 67108864] = "IsConstrainedTypeVariable";
                    return ObjectFlags3;
                })(ObjectFlags || {});
                VarianceFlags = /* @__PURE__ */ ((VarianceFlags2) => {
                    VarianceFlags2[VarianceFlags2["Invariant"] = 0] = "Invariant";
                    VarianceFlags2[VarianceFlags2["Covariant"] = 1] = "Covariant";
                    VarianceFlags2[VarianceFlags2["Contravariant"] = 2] = "Contravariant";
                    VarianceFlags2[VarianceFlags2["Bivariant"] = 3] = "Bivariant";
                    VarianceFlags2[VarianceFlags2["Independent"] = 4] = "Independent";
                    VarianceFlags2[VarianceFlags2["VarianceMask"] = 7] = "VarianceMask";
                    VarianceFlags2[VarianceFlags2["Unmeasurable"] = 8] = "Unmeasurable";
                    VarianceFlags2[VarianceFlags2["Unreliable"] = 16] = "Unreliable";
                    VarianceFlags2[VarianceFlags2["AllowsStructuralFallback"] = 24] = "AllowsStructuralFallback";
                    return VarianceFlags2;
                })(VarianceFlags || {});
                ElementFlags = /* @__PURE__ */ ((ElementFlags2) => {
                    ElementFlags2[ElementFlags2["Required"] = 1] = "Required";
                    ElementFlags2[ElementFlags2["Optional"] = 2] = "Optional";
                    ElementFlags2[ElementFlags2["Rest"] = 4] = "Rest";
                    ElementFlags2[ElementFlags2["Variadic"] = 8] = "Variadic";
                    ElementFlags2[ElementFlags2["Fixed"] = 3] = "Fixed";
                    ElementFlags2[ElementFlags2["Variable"] = 12] = "Variable";
                    ElementFlags2[ElementFlags2["NonRequired"] = 14] = "NonRequired";
                    ElementFlags2[ElementFlags2["NonRest"] = 11] = "NonRest";
                    return ElementFlags2;
                })(ElementFlags || {});
                AccessFlags = /* @__PURE__ */ ((AccessFlags2) => {
                    AccessFlags2[AccessFlags2["None"] = 0] = "None";
                    AccessFlags2[AccessFlags2["IncludeUndefined"] = 1] = "IncludeUndefined";
                    AccessFlags2[AccessFlags2["NoIndexSignatures"] = 2] = "NoIndexSignatures";
                    AccessFlags2[AccessFlags2["Writing"] = 4] = "Writing";
                    AccessFlags2[AccessFlags2["CacheSymbol"] = 8] = "CacheSymbol";
                    AccessFlags2[AccessFlags2["NoTupleBoundsCheck"] = 16] = "NoTupleBoundsCheck";
                    AccessFlags2[AccessFlags2["ExpressionPosition"] = 32] = "ExpressionPosition";
                    AccessFlags2[AccessFlags2["ReportDeprecated"] = 64] = "ReportDeprecated";
                    AccessFlags2[AccessFlags2["SuppressNoImplicitAnyError"] = 128] = "SuppressNoImplicitAnyError";
                    AccessFlags2[AccessFlags2["Contextual"] = 256] = "Contextual";
                    AccessFlags2[AccessFlags2["Persistent"] = 1 /* IncludeUndefined */] = "Persistent";
                    return AccessFlags2;
                })(AccessFlags || {});
                IndexFlags = /* @__PURE__ */ ((IndexFlags2) => {
                    IndexFlags2[IndexFlags2["None"] = 0] = "None";
                    IndexFlags2[IndexFlags2["StringsOnly"] = 1] = "StringsOnly";
                    IndexFlags2[IndexFlags2["NoIndexSignatures"] = 2] = "NoIndexSignatures";
                    IndexFlags2[IndexFlags2["NoReducibleCheck"] = 4] = "NoReducibleCheck";
                    return IndexFlags2;
                })(IndexFlags || {});
                JsxReferenceKind = /* @__PURE__ */ ((JsxReferenceKind2) => {
                    JsxReferenceKind2[JsxReferenceKind2["Component"] = 0] = "Component";
                    JsxReferenceKind2[JsxReferenceKind2["Function"] = 1] = "Function";
                    JsxReferenceKind2[JsxReferenceKind2["Mixed"] = 2] = "Mixed";
                    return JsxReferenceKind2;
                })(JsxReferenceKind || {});
                SignatureKind = /* @__PURE__ */ ((SignatureKind2) => {
                    SignatureKind2[SignatureKind2["Call"] = 0] = "Call";
                    SignatureKind2[SignatureKind2["Construct"] = 1] = "Construct";
                    return SignatureKind2;
                })(SignatureKind || {});
                SignatureFlags = /* @__PURE__ */ ((SignatureFlags5) => {
                    SignatureFlags5[SignatureFlags5["None"] = 0] = "None";
                    SignatureFlags5[SignatureFlags5["HasRestParameter"] = 1] = "HasRestParameter";
                    SignatureFlags5[SignatureFlags5["HasLiteralTypes"] = 2] = "HasLiteralTypes";
                    SignatureFlags5[SignatureFlags5["Abstract"] = 4] = "Abstract";
                    SignatureFlags5[SignatureFlags5["IsInnerCallChain"] = 8] = "IsInnerCallChain";
                    SignatureFlags5[SignatureFlags5["IsOuterCallChain"] = 16] = "IsOuterCallChain";
                    SignatureFlags5[SignatureFlags5["IsUntypedSignatureInJSFile"] = 32] = "IsUntypedSignatureInJSFile";
                    SignatureFlags5[SignatureFlags5["IsNonInferrable"] = 64] = "IsNonInferrable";
                    SignatureFlags5[SignatureFlags5["IsSignatureCandidateForOverloadFailure"] = 128] = "IsSignatureCandidateForOverloadFailure";
                    SignatureFlags5[SignatureFlags5["PropagatingFlags"] = 167] = "PropagatingFlags";
                    SignatureFlags5[SignatureFlags5["CallChainFlags"] = 24] = "CallChainFlags";
                    return SignatureFlags5;
                })(SignatureFlags || {});
                IndexKind = /* @__PURE__ */ ((IndexKind2) => {
                    IndexKind2[IndexKind2["String"] = 0] = "String";
                    IndexKind2[IndexKind2["Number"] = 1] = "Number";
                    return IndexKind2;
                })(IndexKind || {});
                TypeMapKind = /* @__PURE__ */ ((TypeMapKind2) => {
                    TypeMapKind2[TypeMapKind2["Simple"] = 0] = "Simple";
                    TypeMapKind2[TypeMapKind2["Array"] = 1] = "Array";
                    TypeMapKind2[TypeMapKind2["Deferred"] = 2] = "Deferred";
                    TypeMapKind2[TypeMapKind2["Function"] = 3] = "Function";
                    TypeMapKind2[TypeMapKind2["Composite"] = 4] = "Composite";
                    TypeMapKind2[TypeMapKind2["Merged"] = 5] = "Merged";
                    return TypeMapKind2;
                })(TypeMapKind || {});
                InferencePriority = /* @__PURE__ */ ((InferencePriority2) => {
                    InferencePriority2[InferencePriority2["None"] = 0] = "None";
                    InferencePriority2[InferencePriority2["NakedTypeVariable"] = 1] = "NakedTypeVariable";
                    InferencePriority2[InferencePriority2["SpeculativeTuple"] = 2] = "SpeculativeTuple";
                    InferencePriority2[InferencePriority2["SubstituteSource"] = 4] = "SubstituteSource";
                    InferencePriority2[InferencePriority2["HomomorphicMappedType"] = 8] = "HomomorphicMappedType";
                    InferencePriority2[InferencePriority2["PartialHomomorphicMappedType"] = 16] = "PartialHomomorphicMappedType";
                    InferencePriority2[InferencePriority2["MappedTypeConstraint"] = 32] = "MappedTypeConstraint";
                    InferencePriority2[InferencePriority2["ContravariantConditional"] = 64] = "ContravariantConditional";
                    InferencePriority2[InferencePriority2["ReturnType"] = 128] = "ReturnType";
                    InferencePriority2[InferencePriority2["LiteralKeyof"] = 256] = "LiteralKeyof";
                    InferencePriority2[InferencePriority2["NoConstraints"] = 512] = "NoConstraints";
                    InferencePriority2[InferencePriority2["AlwaysStrict"] = 1024] = "AlwaysStrict";
                    InferencePriority2[InferencePriority2["MaxValue"] = 2048] = "MaxValue";
                    InferencePriority2[InferencePriority2["PriorityImpliesCombination"] = 416] = "PriorityImpliesCombination";
                    InferencePriority2[InferencePriority2["Circularity"] = -1] = "Circularity";
                    return InferencePriority2;
                })(InferencePriority || {});
                InferenceFlags = /* @__PURE__ */ ((InferenceFlags2) => {
                    InferenceFlags2[InferenceFlags2["None"] = 0] = "None";
                    InferenceFlags2[InferenceFlags2["NoDefault"] = 1] = "NoDefault";
                    InferenceFlags2[InferenceFlags2["AnyDefault"] = 2] = "AnyDefault";
                    InferenceFlags2[InferenceFlags2["SkippedGenericFunction"] = 4] = "SkippedGenericFunction";
                    return InferenceFlags2;
                })(InferenceFlags || {});
                Ternary = /* @__PURE__ */ ((Ternary2) => {
                    Ternary2[Ternary2["False"] = 0] = "False";
                    Ternary2[Ternary2["Unknown"] = 1] = "Unknown";
                    Ternary2[Ternary2["Maybe"] = 3] = "Maybe";
                    Ternary2[Ternary2["True"] = -1] = "True";
                    return Ternary2;
                })(Ternary || {});
                AssignmentDeclarationKind = /* @__PURE__ */ ((AssignmentDeclarationKind2) => {
                    AssignmentDeclarationKind2[AssignmentDeclarationKind2["None"] = 0] = "None";
                    AssignmentDeclarationKind2[AssignmentDeclarationKind2["ExportsProperty"] = 1] = "ExportsProperty";
                    AssignmentDeclarationKind2[AssignmentDeclarationKind2["ModuleExports"] = 2] = "ModuleExports";
                    AssignmentDeclarationKind2[AssignmentDeclarationKind2["PrototypeProperty"] = 3] = "PrototypeProperty";
                    AssignmentDeclarationKind2[AssignmentDeclarationKind2["ThisProperty"] = 4] = "ThisProperty";
                    AssignmentDeclarationKind2[AssignmentDeclarationKind2["Property"] = 5] = "Property";
                    AssignmentDeclarationKind2[AssignmentDeclarationKind2["Prototype"] = 6] = "Prototype";
                    AssignmentDeclarationKind2[AssignmentDeclarationKind2["ObjectDefinePropertyValue"] = 7] = "ObjectDefinePropertyValue";
                    AssignmentDeclarationKind2[AssignmentDeclarationKind2["ObjectDefinePropertyExports"] = 8] = "ObjectDefinePropertyExports";
                    AssignmentDeclarationKind2[AssignmentDeclarationKind2["ObjectDefinePrototypeProperty"] = 9] = "ObjectDefinePrototypeProperty";
                    return AssignmentDeclarationKind2;
                })(AssignmentDeclarationKind || {});
                DiagnosticCategory = /* @__PURE__ */ ((DiagnosticCategory2) => {
                    DiagnosticCategory2[DiagnosticCategory2["Warning"] = 0] = "Warning";
                    DiagnosticCategory2[DiagnosticCategory2["Error"] = 1] = "Error";
                    DiagnosticCategory2[DiagnosticCategory2["Suggestion"] = 2] = "Suggestion";
                    DiagnosticCategory2[DiagnosticCategory2["Message"] = 3] = "Message";
                    return DiagnosticCategory2;
                })(DiagnosticCategory || {});
                ModuleResolutionKind = /* @__PURE__ */ ((ModuleResolutionKind3) => {
                    ModuleResolutionKind3[ModuleResolutionKind3["Classic"] = 1] = "Classic";
                    ModuleResolutionKind3[ModuleResolutionKind3["NodeJs"] = 2] = "NodeJs";
                    ModuleResolutionKind3[ModuleResolutionKind3["Node10"] = 2] = "Node10";
                    ModuleResolutionKind3[ModuleResolutionKind3["Node16"] = 3] = "Node16";
                    ModuleResolutionKind3[ModuleResolutionKind3["NodeNext"] = 99] = "NodeNext";
                    ModuleResolutionKind3[ModuleResolutionKind3["Bundler"] = 100] = "Bundler";
                    return ModuleResolutionKind3;
                })(ModuleResolutionKind || {});
                ModuleDetectionKind = /* @__PURE__ */ ((ModuleDetectionKind2) => {
                    ModuleDetectionKind2[ModuleDetectionKind2["Legacy"] = 1] = "Legacy";
                    ModuleDetectionKind2[ModuleDetectionKind2["Auto"] = 2] = "Auto";
                    ModuleDetectionKind2[ModuleDetectionKind2["Force"] = 3] = "Force";
                    return ModuleDetectionKind2;
                })(ModuleDetectionKind || {});
                WatchFileKind = /* @__PURE__ */ ((WatchFileKind3) => {
                    WatchFileKind3[WatchFileKind3["FixedPollingInterval"] = 0] = "FixedPollingInterval";
                    WatchFileKind3[WatchFileKind3["PriorityPollingInterval"] = 1] = "PriorityPollingInterval";
                    WatchFileKind3[WatchFileKind3["DynamicPriorityPolling"] = 2] = "DynamicPriorityPolling";
                    WatchFileKind3[WatchFileKind3["FixedChunkSizePolling"] = 3] = "FixedChunkSizePolling";
                    WatchFileKind3[WatchFileKind3["UseFsEvents"] = 4] = "UseFsEvents";
                    WatchFileKind3[WatchFileKind3["UseFsEventsOnParentDirectory"] = 5] = "UseFsEventsOnParentDirectory";
                    return WatchFileKind3;
                })(WatchFileKind || {});
                WatchDirectoryKind = /* @__PURE__ */ ((WatchDirectoryKind3) => {
                    WatchDirectoryKind3[WatchDirectoryKind3["UseFsEvents"] = 0] = "UseFsEvents";
                    WatchDirectoryKind3[WatchDirectoryKind3["FixedPollingInterval"] = 1] = "FixedPollingInterval";
                    WatchDirectoryKind3[WatchDirectoryKind3["DynamicPriorityPolling"] = 2] = "DynamicPriorityPolling";
                    WatchDirectoryKind3[WatchDirectoryKind3["FixedChunkSizePolling"] = 3] = "FixedChunkSizePolling";
                    return WatchDirectoryKind3;
                })(WatchDirectoryKind || {});
                PollingWatchKind = /* @__PURE__ */ ((PollingWatchKind3) => {
                    PollingWatchKind3[PollingWatchKind3["FixedInterval"] = 0] = "FixedInterval";
                    PollingWatchKind3[PollingWatchKind3["PriorityInterval"] = 1] = "PriorityInterval";
                    PollingWatchKind3[PollingWatchKind3["DynamicPriority"] = 2] = "DynamicPriority";
                    PollingWatchKind3[PollingWatchKind3["FixedChunkSize"] = 3] = "FixedChunkSize";
                    return PollingWatchKind3;
                })(PollingWatchKind || {});
                ModuleKind = /* @__PURE__ */ ((ModuleKind3) => {
                    ModuleKind3[ModuleKind3["None"] = 0] = "None";
                    ModuleKind3[ModuleKind3["CommonJS"] = 1] = "CommonJS";
                    ModuleKind3[ModuleKind3["AMD"] = 2] = "AMD";
                    ModuleKind3[ModuleKind3["UMD"] = 3] = "UMD";
                    ModuleKind3[ModuleKind3["System"] = 4] = "System";
                    ModuleKind3[ModuleKind3["ES2015"] = 5] = "ES2015";
                    ModuleKind3[ModuleKind3["ES2020"] = 6] = "ES2020";
                    ModuleKind3[ModuleKind3["ES2022"] = 7] = "ES2022";
                    ModuleKind3[ModuleKind3["ESNext"] = 99] = "ESNext";
                    ModuleKind3[ModuleKind3["Node16"] = 100] = "Node16";
                    ModuleKind3[ModuleKind3["NodeNext"] = 199] = "NodeNext";
                    ModuleKind3[ModuleKind3["Preserve"] = 200] = "Preserve";
                    return ModuleKind3;
                })(ModuleKind || {});
                JsxEmit = /* @__PURE__ */ ((JsxEmit3) => {
                    JsxEmit3[JsxEmit3["None"] = 0] = "None";
                    JsxEmit3[JsxEmit3["Preserve"] = 1] = "Preserve";
                    JsxEmit3[JsxEmit3["React"] = 2] = "React";
                    JsxEmit3[JsxEmit3["ReactNative"] = 3] = "ReactNative";
                    JsxEmit3[JsxEmit3["ReactJSX"] = 4] = "ReactJSX";
                    JsxEmit3[JsxEmit3["ReactJSXDev"] = 5] = "ReactJSXDev";
                    return JsxEmit3;
                })(JsxEmit || {});
                ImportsNotUsedAsValues = /* @__PURE__ */ ((ImportsNotUsedAsValues2) => {
                    ImportsNotUsedAsValues2[ImportsNotUsedAsValues2["Remove"] = 0] = "Remove";
                    ImportsNotUsedAsValues2[ImportsNotUsedAsValues2["Preserve"] = 1] = "Preserve";
                    ImportsNotUsedAsValues2[ImportsNotUsedAsValues2["Error"] = 2] = "Error";
                    return ImportsNotUsedAsValues2;
                })(ImportsNotUsedAsValues || {});
                NewLineKind = /* @__PURE__ */ ((NewLineKind3) => {
                    NewLineKind3[NewLineKind3["CarriageReturnLineFeed"] = 0] = "CarriageReturnLineFeed";
                    NewLineKind3[NewLineKind3["LineFeed"] = 1] = "LineFeed";
                    return NewLineKind3;
                })(NewLineKind || {});
                ScriptKind = /* @__PURE__ */ ((ScriptKind7) => {
                    ScriptKind7[ScriptKind7["Unknown"] = 0] = "Unknown";
                    ScriptKind7[ScriptKind7["JS"] = 1] = "JS";
                    ScriptKind7[ScriptKind7["JSX"] = 2] = "JSX";
                    ScriptKind7[ScriptKind7["TS"] = 3] = "TS";
                    ScriptKind7[ScriptKind7["TSX"] = 4] = "TSX";
                    ScriptKind7[ScriptKind7["External"] = 5] = "External";
                    ScriptKind7[ScriptKind7["JSON"] = 6] = "JSON";
                    ScriptKind7[ScriptKind7["Deferred"] = 7] = "Deferred";
                    return ScriptKind7;
                })(ScriptKind || {});
                ScriptTarget = /* @__PURE__ */ ((ScriptTarget11) => {
                    ScriptTarget11[ScriptTarget11["ES3"] = 0] = "ES3";
                    ScriptTarget11[ScriptTarget11["ES5"] = 1] = "ES5";
                    ScriptTarget11[ScriptTarget11["ES2015"] = 2] = "ES2015";
                    ScriptTarget11[ScriptTarget11["ES2016"] = 3] = "ES2016";
                    ScriptTarget11[ScriptTarget11["ES2017"] = 4] = "ES2017";
                    ScriptTarget11[ScriptTarget11["ES2018"] = 5] = "ES2018";
                    ScriptTarget11[ScriptTarget11["ES2019"] = 6] = "ES2019";
                    ScriptTarget11[ScriptTarget11["ES2020"] = 7] = "ES2020";
                    ScriptTarget11[ScriptTarget11["ES2021"] = 8] = "ES2021";
                    ScriptTarget11[ScriptTarget11["ES2022"] = 9] = "ES2022";
                    ScriptTarget11[ScriptTarget11["ESNext"] = 99] = "ESNext";
                    ScriptTarget11[ScriptTarget11["JSON"] = 100] = "JSON";
                    ScriptTarget11[ScriptTarget11["Latest"] = 99 /* ESNext */] = "Latest";
                    return ScriptTarget11;
                })(ScriptTarget || {});
                LanguageVariant = /* @__PURE__ */ ((LanguageVariant4) => {
                    LanguageVariant4[LanguageVariant4["Standard"] = 0] = "Standard";
                    LanguageVariant4[LanguageVariant4["JSX"] = 1] = "JSX";
                    return LanguageVariant4;
                })(LanguageVariant || {});
                WatchDirectoryFlags = /* @__PURE__ */ ((WatchDirectoryFlags3) => {
                    WatchDirectoryFlags3[WatchDirectoryFlags3["None"] = 0] = "None";
                    WatchDirectoryFlags3[WatchDirectoryFlags3["Recursive"] = 1] = "Recursive";
                    return WatchDirectoryFlags3;
                })(WatchDirectoryFlags || {});
                CharacterCodes = /* @__PURE__ */ ((CharacterCodes2) => {
                    CharacterCodes2[CharacterCodes2["nullCharacter"] = 0] = "nullCharacter";
                    CharacterCodes2[CharacterCodes2["maxAsciiCharacter"] = 127] = "maxAsciiCharacter";
                    CharacterCodes2[CharacterCodes2["lineFeed"] = 10] = "lineFeed";
                    CharacterCodes2[CharacterCodes2["carriageReturn"] = 13] = "carriageReturn";
                    CharacterCodes2[CharacterCodes2["lineSeparator"] = 8232] = "lineSeparator";
                    CharacterCodes2[CharacterCodes2["paragraphSeparator"] = 8233] = "paragraphSeparator";
                    CharacterCodes2[CharacterCodes2["nextLine"] = 133] = "nextLine";
                    CharacterCodes2[CharacterCodes2["space"] = 32] = "space";
                    CharacterCodes2[CharacterCodes2["nonBreakingSpace"] = 160] = "nonBreakingSpace";
                    CharacterCodes2[CharacterCodes2["enQuad"] = 8192] = "enQuad";
                    CharacterCodes2[CharacterCodes2["emQuad"] = 8193] = "emQuad";
                    CharacterCodes2[CharacterCodes2["enSpace"] = 8194] = "enSpace";
                    CharacterCodes2[CharacterCodes2["emSpace"] = 8195] = "emSpace";
                    CharacterCodes2[CharacterCodes2["threePerEmSpace"] = 8196] = "threePerEmSpace";
                    CharacterCodes2[CharacterCodes2["fourPerEmSpace"] = 8197] = "fourPerEmSpace";
                    CharacterCodes2[CharacterCodes2["sixPerEmSpace"] = 8198] = "sixPerEmSpace";
                    CharacterCodes2[CharacterCodes2["figureSpace"] = 8199] = "figureSpace";
                    CharacterCodes2[CharacterCodes2["punctuationSpace"] = 8200] = "punctuationSpace";
                    CharacterCodes2[CharacterCodes2["thinSpace"] = 8201] = "thinSpace";
                    CharacterCodes2[CharacterCodes2["hairSpace"] = 8202] = "hairSpace";
                    CharacterCodes2[CharacterCodes2["zeroWidthSpace"] = 8203] = "zeroWidthSpace";
                    CharacterCodes2[CharacterCodes2["narrowNoBreakSpace"] = 8239] = "narrowNoBreakSpace";
                    CharacterCodes2[CharacterCodes2["ideographicSpace"] = 12288] = "ideographicSpace";
                    CharacterCodes2[CharacterCodes2["mathematicalSpace"] = 8287] = "mathematicalSpace";
                    CharacterCodes2[CharacterCodes2["ogham"] = 5760] = "ogham";
                    CharacterCodes2[CharacterCodes2["_"] = 95] = "_";
                    CharacterCodes2[CharacterCodes2["$"] = 36] = "$";
                    CharacterCodes2[CharacterCodes2["_0"] = 48] = "_0";
                    CharacterCodes2[CharacterCodes2["_1"] = 49] = "_1";
                    CharacterCodes2[CharacterCodes2["_2"] = 50] = "_2";
                    CharacterCodes2[CharacterCodes2["_3"] = 51] = "_3";
                    CharacterCodes2[CharacterCodes2["_4"] = 52] = "_4";
                    CharacterCodes2[CharacterCodes2["_5"] = 53] = "_5";
                    CharacterCodes2[CharacterCodes2["_6"] = 54] = "_6";
                    CharacterCodes2[CharacterCodes2["_7"] = 55] = "_7";
                    CharacterCodes2[CharacterCodes2["_8"] = 56] = "_8";
                    CharacterCodes2[CharacterCodes2["_9"] = 57] = "_9";
                    CharacterCodes2[CharacterCodes2["a"] = 97] = "a";
                    CharacterCodes2[CharacterCodes2["b"] = 98] = "b";
                    CharacterCodes2[CharacterCodes2["c"] = 99] = "c";
                    CharacterCodes2[CharacterCodes2["d"] = 100] = "d";
                    CharacterCodes2[CharacterCodes2["e"] = 101] = "e";
                    CharacterCodes2[CharacterCodes2["f"] = 102] = "f";
                    CharacterCodes2[CharacterCodes2["g"] = 103] = "g";
                    CharacterCodes2[CharacterCodes2["h"] = 104] = "h";
                    CharacterCodes2[CharacterCodes2["i"] = 105] = "i";
                    CharacterCodes2[CharacterCodes2["j"] = 106] = "j";
                    CharacterCodes2[CharacterCodes2["k"] = 107] = "k";
                    CharacterCodes2[CharacterCodes2["l"] = 108] = "l";
                    CharacterCodes2[CharacterCodes2["m"] = 109] = "m";
                    CharacterCodes2[CharacterCodes2["n"] = 110] = "n";
                    CharacterCodes2[CharacterCodes2["o"] = 111] = "o";
                    CharacterCodes2[CharacterCodes2["p"] = 112] = "p";
                    CharacterCodes2[CharacterCodes2["q"] = 113] = "q";
                    CharacterCodes2[CharacterCodes2["r"] = 114] = "r";
                    CharacterCodes2[CharacterCodes2["s"] = 115] = "s";
                    CharacterCodes2[CharacterCodes2["t"] = 116] = "t";
                    CharacterCodes2[CharacterCodes2["u"] = 117] = "u";
                    CharacterCodes2[CharacterCodes2["v"] = 118] = "v";
                    CharacterCodes2[CharacterCodes2["w"] = 119] = "w";
                    CharacterCodes2[CharacterCodes2["x"] = 120] = "x";
                    CharacterCodes2[CharacterCodes2["y"] = 121] = "y";
                    CharacterCodes2[CharacterCodes2["z"] = 122] = "z";
                    CharacterCodes2[CharacterCodes2["A"] = 65] = "A";
                    CharacterCodes2[CharacterCodes2["B"] = 66] = "B";
                    CharacterCodes2[CharacterCodes2["C"] = 67] = "C";
                    CharacterCodes2[CharacterCodes2["D"] = 68] = "D";
                    CharacterCodes2[CharacterCodes2["E"] = 69] = "E";
                    CharacterCodes2[CharacterCodes2["F"] = 70] = "F";
                    CharacterCodes2[CharacterCodes2["G"] = 71] = "G";
                    CharacterCodes2[CharacterCodes2["H"] = 72] = "H";
                    CharacterCodes2[CharacterCodes2["I"] = 73] = "I";
                    CharacterCodes2[CharacterCodes2["J"] = 74] = "J";
                    CharacterCodes2[CharacterCodes2["K"] = 75] = "K";
                    CharacterCodes2[CharacterCodes2["L"] = 76] = "L";
                    CharacterCodes2[CharacterCodes2["M"] = 77] = "M";
                    CharacterCodes2[CharacterCodes2["N"] = 78] = "N";
                    CharacterCodes2[CharacterCodes2["O"] = 79] = "O";
                    CharacterCodes2[CharacterCodes2["P"] = 80] = "P";
                    CharacterCodes2[CharacterCodes2["Q"] = 81] = "Q";
                    CharacterCodes2[CharacterCodes2["R"] = 82] = "R";
                    CharacterCodes2[CharacterCodes2["S"] = 83] = "S";
                    CharacterCodes2[CharacterCodes2["T"] = 84] = "T";
                    CharacterCodes2[CharacterCodes2["U"] = 85] = "U";
                    CharacterCodes2[CharacterCodes2["V"] = 86] = "V";
                    CharacterCodes2[CharacterCodes2["W"] = 87] = "W";
                    CharacterCodes2[CharacterCodes2["X"] = 88] = "X";
                    CharacterCodes2[CharacterCodes2["Y"] = 89] = "Y";
                    CharacterCodes2[CharacterCodes2["Z"] = 90] = "Z";
                    CharacterCodes2[CharacterCodes2["ampersand"] = 38] = "ampersand";
                    CharacterCodes2[CharacterCodes2["asterisk"] = 42] = "asterisk";
                    CharacterCodes2[CharacterCodes2["at"] = 64] = "at";
                    CharacterCodes2[CharacterCodes2["backslash"] = 92] = "backslash";
                    CharacterCodes2[CharacterCodes2["backtick"] = 96] = "backtick";
                    CharacterCodes2[CharacterCodes2["bar"] = 124] = "bar";
                    CharacterCodes2[CharacterCodes2["caret"] = 94] = "caret";
                    CharacterCodes2[CharacterCodes2["closeBrace"] = 125] = "closeBrace";
                    CharacterCodes2[CharacterCodes2["closeBracket"] = 93] = "closeBracket";
                    CharacterCodes2[CharacterCodes2["closeParen"] = 41] = "closeParen";
                    CharacterCodes2[CharacterCodes2["colon"] = 58] = "colon";
                    CharacterCodes2[CharacterCodes2["comma"] = 44] = "comma";
                    CharacterCodes2[CharacterCodes2["dot"] = 46] = "dot";
                    CharacterCodes2[CharacterCodes2["doubleQuote"] = 34] = "doubleQuote";
                    CharacterCodes2[CharacterCodes2["equals"] = 61] = "equals";
                    CharacterCodes2[CharacterCodes2["exclamation"] = 33] = "exclamation";
                    CharacterCodes2[CharacterCodes2["greaterThan"] = 62] = "greaterThan";
                    CharacterCodes2[CharacterCodes2["hash"] = 35] = "hash";
                    CharacterCodes2[CharacterCodes2["lessThan"] = 60] = "lessThan";
                    CharacterCodes2[CharacterCodes2["minus"] = 45] = "minus";
                    CharacterCodes2[CharacterCodes2["openBrace"] = 123] = "openBrace";
                    CharacterCodes2[CharacterCodes2["openBracket"] = 91] = "openBracket";
                    CharacterCodes2[CharacterCodes2["openParen"] = 40] = "openParen";
                    CharacterCodes2[CharacterCodes2["percent"] = 37] = "percent";
                    CharacterCodes2[CharacterCodes2["plus"] = 43] = "plus";
                    CharacterCodes2[CharacterCodes2["question"] = 63] = "question";
                    CharacterCodes2[CharacterCodes2["semicolon"] = 59] = "semicolon";
                    CharacterCodes2[CharacterCodes2["singleQuote"] = 39] = "singleQuote";
                    CharacterCodes2[CharacterCodes2["slash"] = 47] = "slash";
                    CharacterCodes2[CharacterCodes2["tilde"] = 126] = "tilde";
                    CharacterCodes2[CharacterCodes2["backspace"] = 8] = "backspace";
                    CharacterCodes2[CharacterCodes2["formFeed"] = 12] = "formFeed";
                    CharacterCodes2[CharacterCodes2["byteOrderMark"] = 65279] = "byteOrderMark";
                    CharacterCodes2[CharacterCodes2["tab"] = 9] = "tab";
                    CharacterCodes2[CharacterCodes2["verticalTab"] = 11] = "verticalTab";
                    return CharacterCodes2;
                })(CharacterCodes || {});
                Extension = /* @__PURE__ */ ((Extension2) => {
                    Extension2["Ts"] = ".ts";
                    Extension2["Tsx"] = ".tsx";
                    Extension2["Dts"] = ".d.ts";
                    Extension2["Js"] = ".js";
                    Extension2["Jsx"] = ".jsx";
                    Extension2["Json"] = ".json";
                    Extension2["TsBuildInfo"] = ".tsbuildinfo";
                    Extension2["Mjs"] = ".mjs";
                    Extension2["Mts"] = ".mts";
                    Extension2["Dmts"] = ".d.mts";
                    Extension2["Cjs"] = ".cjs";
                    Extension2["Cts"] = ".cts";
                    Extension2["Dcts"] = ".d.cts";
                    return Extension2;
                })(Extension || {});
                TransformFlags = /* @__PURE__ */ ((TransformFlags3) => {
                    TransformFlags3[TransformFlags3["None"] = 0] = "None";
                    TransformFlags3[TransformFlags3["ContainsTypeScript"] = 1] = "ContainsTypeScript";
                    TransformFlags3[TransformFlags3["ContainsJsx"] = 2] = "ContainsJsx";
                    TransformFlags3[TransformFlags3["ContainsESNext"] = 4] = "ContainsESNext";
                    TransformFlags3[TransformFlags3["ContainsES2022"] = 8] = "ContainsES2022";
                    TransformFlags3[TransformFlags3["ContainsES2021"] = 16] = "ContainsES2021";
                    TransformFlags3[TransformFlags3["ContainsES2020"] = 32] = "ContainsES2020";
                    TransformFlags3[TransformFlags3["ContainsES2019"] = 64] = "ContainsES2019";
                    TransformFlags3[TransformFlags3["ContainsES2018"] = 128] = "ContainsES2018";
                    TransformFlags3[TransformFlags3["ContainsES2017"] = 256] = "ContainsES2017";
                    TransformFlags3[TransformFlags3["ContainsES2016"] = 512] = "ContainsES2016";
                    TransformFlags3[TransformFlags3["ContainsES2015"] = 1024] = "ContainsES2015";
                    TransformFlags3[TransformFlags3["ContainsGenerator"] = 2048] = "ContainsGenerator";
                    TransformFlags3[TransformFlags3["ContainsDestructuringAssignment"] = 4096] = "ContainsDestructuringAssignment";
                    TransformFlags3[TransformFlags3["ContainsTypeScriptClassSyntax"] = 8192] = "ContainsTypeScriptClassSyntax";
                    TransformFlags3[TransformFlags3["ContainsLexicalThis"] = 16384] = "ContainsLexicalThis";
                    TransformFlags3[TransformFlags3["ContainsRestOrSpread"] = 32768] = "ContainsRestOrSpread";
                    TransformFlags3[TransformFlags3["ContainsObjectRestOrSpread"] = 65536] = "ContainsObjectRestOrSpread";
                    TransformFlags3[TransformFlags3["ContainsComputedPropertyName"] = 131072] = "ContainsComputedPropertyName";
                    TransformFlags3[TransformFlags3["ContainsBlockScopedBinding"] = 262144] = "ContainsBlockScopedBinding";
                    TransformFlags3[TransformFlags3["ContainsBindingPattern"] = 524288] = "ContainsBindingPattern";
                    TransformFlags3[TransformFlags3["ContainsYield"] = 1048576] = "ContainsYield";
                    TransformFlags3[TransformFlags3["ContainsAwait"] = 2097152] = "ContainsAwait";
                    TransformFlags3[TransformFlags3["ContainsHoistedDeclarationOrCompletion"] = 4194304] = "ContainsHoistedDeclarationOrCompletion";
                    TransformFlags3[TransformFlags3["ContainsDynamicImport"] = 8388608] = "ContainsDynamicImport";
                    TransformFlags3[TransformFlags3["ContainsClassFields"] = 16777216] = "ContainsClassFields";
                    TransformFlags3[TransformFlags3["ContainsDecorators"] = 33554432] = "ContainsDecorators";
                    TransformFlags3[TransformFlags3["ContainsPossibleTopLevelAwait"] = 67108864] = "ContainsPossibleTopLevelAwait";
                    TransformFlags3[TransformFlags3["ContainsLexicalSuper"] = 134217728] = "ContainsLexicalSuper";
                    TransformFlags3[TransformFlags3["ContainsUpdateExpressionForIdentifier"] = 268435456] = "ContainsUpdateExpressionForIdentifier";
                    TransformFlags3[TransformFlags3["ContainsPrivateIdentifierInExpression"] = 536870912] = "ContainsPrivateIdentifierInExpression";
                    TransformFlags3[TransformFlags3["HasComputedFlags"] = -2147483648] = "HasComputedFlags";
                    TransformFlags3[TransformFlags3["AssertTypeScript"] = 1 /* ContainsTypeScript */] = "AssertTypeScript";
                    TransformFlags3[TransformFlags3["AssertJsx"] = 2 /* ContainsJsx */] = "AssertJsx";
                    TransformFlags3[TransformFlags3["AssertESNext"] = 4 /* ContainsESNext */] = "AssertESNext";
                    TransformFlags3[TransformFlags3["AssertES2022"] = 8 /* ContainsES2022 */] = "AssertES2022";
                    TransformFlags3[TransformFlags3["AssertES2021"] = 16 /* ContainsES2021 */] = "AssertES2021";
                    TransformFlags3[TransformFlags3["AssertES2020"] = 32 /* ContainsES2020 */] = "AssertES2020";
                    TransformFlags3[TransformFlags3["AssertES2019"] = 64 /* ContainsES2019 */] = "AssertES2019";
                    TransformFlags3[TransformFlags3["AssertES2018"] = 128 /* ContainsES2018 */] = "AssertES2018";
                    TransformFlags3[TransformFlags3["AssertES2017"] = 256 /* ContainsES2017 */] = "AssertES2017";
                    TransformFlags3[TransformFlags3["AssertES2016"] = 512 /* ContainsES2016 */] = "AssertES2016";
                    TransformFlags3[TransformFlags3["AssertES2015"] = 1024 /* ContainsES2015 */] = "AssertES2015";
                    TransformFlags3[TransformFlags3["AssertGenerator"] = 2048 /* ContainsGenerator */] = "AssertGenerator";
                    TransformFlags3[TransformFlags3["AssertDestructuringAssignment"] = 4096 /* ContainsDestructuringAssignment */] = "AssertDestructuringAssignment";
                    TransformFlags3[TransformFlags3["OuterExpressionExcludes"] = -2147483648 /* HasComputedFlags */] = "OuterExpressionExcludes";
                    TransformFlags3[TransformFlags3["PropertyAccessExcludes"] = -2147483648 /* OuterExpressionExcludes */] = "PropertyAccessExcludes";
                    TransformFlags3[TransformFlags3["NodeExcludes"] = -2147483648 /* PropertyAccessExcludes */] = "NodeExcludes";
                    TransformFlags3[TransformFlags3["ArrowFunctionExcludes"] = -2072174592] = "ArrowFunctionExcludes";
                    TransformFlags3[TransformFlags3["FunctionExcludes"] = -1937940480] = "FunctionExcludes";
                    TransformFlags3[TransformFlags3["ConstructorExcludes"] = -1937948672] = "ConstructorExcludes";
                    TransformFlags3[TransformFlags3["MethodOrAccessorExcludes"] = -2005057536] = "MethodOrAccessorExcludes";
                    TransformFlags3[TransformFlags3["PropertyExcludes"] = -2013249536] = "PropertyExcludes";
                    TransformFlags3[TransformFlags3["ClassExcludes"] = -2147344384] = "ClassExcludes";
                    TransformFlags3[TransformFlags3["ModuleExcludes"] = -1941676032] = "ModuleExcludes";
                    TransformFlags3[TransformFlags3["TypeExcludes"] = -2] = "TypeExcludes";
                    TransformFlags3[TransformFlags3["ObjectLiteralExcludes"] = -2147278848] = "ObjectLiteralExcludes";
                    TransformFlags3[TransformFlags3["ArrayLiteralOrCallOrNewExcludes"] = -2147450880] = "ArrayLiteralOrCallOrNewExcludes";
                    TransformFlags3[TransformFlags3["VariableDeclarationListExcludes"] = -2146893824] = "VariableDeclarationListExcludes";
                    TransformFlags3[TransformFlags3["ParameterExcludes"] = -2147483648 /* NodeExcludes */] = "ParameterExcludes";
                    TransformFlags3[TransformFlags3["CatchClauseExcludes"] = -2147418112] = "CatchClauseExcludes";
                    TransformFlags3[TransformFlags3["BindingPatternExcludes"] = -2147450880] = "BindingPatternExcludes";
                    TransformFlags3[TransformFlags3["ContainsLexicalThisOrSuper"] = 134234112] = "ContainsLexicalThisOrSuper";
                    TransformFlags3[TransformFlags3["PropertyNamePropagatingFlags"] = 134234112] = "PropertyNamePropagatingFlags";
                    return TransformFlags3;
                })(TransformFlags || {});
                SnippetKind = /* @__PURE__ */ ((SnippetKind3) => {
                    SnippetKind3[SnippetKind3["TabStop"] = 0] = "TabStop";
                    SnippetKind3[SnippetKind3["Placeholder"] = 1] = "Placeholder";
                    SnippetKind3[SnippetKind3["Choice"] = 2] = "Choice";
                    SnippetKind3[SnippetKind3["Variable"] = 3] = "Variable";
                    return SnippetKind3;
                })(SnippetKind || {});
                EmitFlags = /* @__PURE__ */ ((EmitFlags3) => {
                    EmitFlags3[EmitFlags3["None"] = 0] = "None";
                    EmitFlags3[EmitFlags3["SingleLine"] = 1] = "SingleLine";
                    EmitFlags3[EmitFlags3["MultiLine"] = 2] = "MultiLine";
                    EmitFlags3[EmitFlags3["AdviseOnEmitNode"] = 4] = "AdviseOnEmitNode";
                    EmitFlags3[EmitFlags3["NoSubstitution"] = 8] = "NoSubstitution";
                    EmitFlags3[EmitFlags3["CapturesThis"] = 16] = "CapturesThis";
                    EmitFlags3[EmitFlags3["NoLeadingSourceMap"] = 32] = "NoLeadingSourceMap";
                    EmitFlags3[EmitFlags3["NoTrailingSourceMap"] = 64] = "NoTrailingSourceMap";
                    EmitFlags3[EmitFlags3["NoSourceMap"] = 96] = "NoSourceMap";
                    EmitFlags3[EmitFlags3["NoNestedSourceMaps"] = 128] = "NoNestedSourceMaps";
                    EmitFlags3[EmitFlags3["NoTokenLeadingSourceMaps"] = 256] = "NoTokenLeadingSourceMaps";
                    EmitFlags3[EmitFlags3["NoTokenTrailingSourceMaps"] = 512] = "NoTokenTrailingSourceMaps";
                    EmitFlags3[EmitFlags3["NoTokenSourceMaps"] = 768] = "NoTokenSourceMaps";
                    EmitFlags3[EmitFlags3["NoLeadingComments"] = 1024] = "NoLeadingComments";
                    EmitFlags3[EmitFlags3["NoTrailingComments"] = 2048] = "NoTrailingComments";
                    EmitFlags3[EmitFlags3["NoComments"] = 3072] = "NoComments";
                    EmitFlags3[EmitFlags3["NoNestedComments"] = 4096] = "NoNestedComments";
                    EmitFlags3[EmitFlags3["HelperName"] = 8192] = "HelperName";
                    EmitFlags3[EmitFlags3["ExportName"] = 16384] = "ExportName";
                    EmitFlags3[EmitFlags3["LocalName"] = 32768] = "LocalName";
                    EmitFlags3[EmitFlags3["InternalName"] = 65536] = "InternalName";
                    EmitFlags3[EmitFlags3["Indented"] = 131072] = "Indented";
                    EmitFlags3[EmitFlags3["NoIndentation"] = 262144] = "NoIndentation";
                    EmitFlags3[EmitFlags3["AsyncFunctionBody"] = 524288] = "AsyncFunctionBody";
                    EmitFlags3[EmitFlags3["ReuseTempVariableScope"] = 1048576] = "ReuseTempVariableScope";
                    EmitFlags3[EmitFlags3["CustomPrologue"] = 2097152] = "CustomPrologue";
                    EmitFlags3[EmitFlags3["NoHoisting"] = 4194304] = "NoHoisting";
                    EmitFlags3[EmitFlags3["Iterator"] = 8388608] = "Iterator";
                    EmitFlags3[EmitFlags3["NoAsciiEscaping"] = 16777216] = "NoAsciiEscaping";
                    return EmitFlags3;
                })(EmitFlags || {});
                InternalEmitFlags = /* @__PURE__ */ ((InternalEmitFlags3) => {
                    InternalEmitFlags3[InternalEmitFlags3["None"] = 0] = "None";
                    InternalEmitFlags3[InternalEmitFlags3["TypeScriptClassWrapper"] = 1] = "TypeScriptClassWrapper";
                    InternalEmitFlags3[InternalEmitFlags3["NeverApplyImportHelper"] = 2] = "NeverApplyImportHelper";
                    InternalEmitFlags3[InternalEmitFlags3["IgnoreSourceNewlines"] = 4] = "IgnoreSourceNewlines";
                    InternalEmitFlags3[InternalEmitFlags3["Immutable"] = 8] = "Immutable";
                    InternalEmitFlags3[InternalEmitFlags3["IndirectCall"] = 16] = "IndirectCall";
                    InternalEmitFlags3[InternalEmitFlags3["TransformPrivateStaticElements"] = 32] = "TransformPrivateStaticElements";
                    return InternalEmitFlags3;
                })(InternalEmitFlags || {});
                ExternalEmitHelpers = /* @__PURE__ */ ((ExternalEmitHelpers2) => {
                    ExternalEmitHelpers2[ExternalEmitHelpers2["Extends"] = 1] = "Extends";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["Assign"] = 2] = "Assign";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["Rest"] = 4] = "Rest";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["Decorate"] = 8] = "Decorate";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["ESDecorateAndRunInitializers"] = 8 /* Decorate */] = "ESDecorateAndRunInitializers";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["Metadata"] = 16] = "Metadata";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["Param"] = 32] = "Param";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["Awaiter"] = 64] = "Awaiter";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["Generator"] = 128] = "Generator";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["Values"] = 256] = "Values";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["Read"] = 512] = "Read";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["SpreadArray"] = 1024] = "SpreadArray";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["Await"] = 2048] = "Await";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["AsyncGenerator"] = 4096] = "AsyncGenerator";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["AsyncDelegator"] = 8192] = "AsyncDelegator";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["AsyncValues"] = 16384] = "AsyncValues";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["ExportStar"] = 32768] = "ExportStar";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["ImportStar"] = 65536] = "ImportStar";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["ImportDefault"] = 131072] = "ImportDefault";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["MakeTemplateObject"] = 262144] = "MakeTemplateObject";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["ClassPrivateFieldGet"] = 524288] = "ClassPrivateFieldGet";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["ClassPrivateFieldSet"] = 1048576] = "ClassPrivateFieldSet";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["ClassPrivateFieldIn"] = 2097152] = "ClassPrivateFieldIn";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["CreateBinding"] = 4194304] = "CreateBinding";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["SetFunctionName"] = 8388608] = "SetFunctionName";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["PropKey"] = 16777216] = "PropKey";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["AddDisposableResourceAndDisposeResources"] = 33554432] = "AddDisposableResourceAndDisposeResources";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["FirstEmitHelper"] = 1 /* Extends */] = "FirstEmitHelper";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["LastEmitHelper"] = 33554432 /* AddDisposableResourceAndDisposeResources */] = "LastEmitHelper";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["ForOfIncludes"] = 256 /* Values */] = "ForOfIncludes";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["ForAwaitOfIncludes"] = 16384 /* AsyncValues */] = "ForAwaitOfIncludes";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["AsyncGeneratorIncludes"] = 6144] = "AsyncGeneratorIncludes";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["AsyncDelegatorIncludes"] = 26624] = "AsyncDelegatorIncludes";
                    ExternalEmitHelpers2[ExternalEmitHelpers2["SpreadIncludes"] = 1536] = "SpreadIncludes";
                    return ExternalEmitHelpers2;
                })(ExternalEmitHelpers || {});
                EmitHint = /* @__PURE__ */ ((EmitHint6) => {
                    EmitHint6[EmitHint6["SourceFile"] = 0] = "SourceFile";
                    EmitHint6[EmitHint6["Expression"] = 1] = "Expression";
                    EmitHint6[EmitHint6["IdentifierName"] = 2] = "IdentifierName";
                    EmitHint6[EmitHint6["MappedTypeParameter"] = 3] = "MappedTypeParameter";
                    EmitHint6[EmitHint6["Unspecified"] = 4] = "Unspecified";
                    EmitHint6[EmitHint6["EmbeddedStatement"] = 5] = "EmbeddedStatement";
                    EmitHint6[EmitHint6["JsxAttributeValue"] = 6] = "JsxAttributeValue";
                    EmitHint6[EmitHint6["ImportTypeNodeAttributes"] = 7] = "ImportTypeNodeAttributes";
                    return EmitHint6;
                })(EmitHint || {});
                OuterExpressionKinds = /* @__PURE__ */ ((OuterExpressionKinds2) => {
                    OuterExpressionKinds2[OuterExpressionKinds2["Parentheses"] = 1] = "Parentheses";
                    OuterExpressionKinds2[OuterExpressionKinds2["TypeAssertions"] = 2] = "TypeAssertions";
                    OuterExpressionKinds2[OuterExpressionKinds2["NonNullAssertions"] = 4] = "NonNullAssertions";
                    OuterExpressionKinds2[OuterExpressionKinds2["PartiallyEmittedExpressions"] = 8] = "PartiallyEmittedExpressions";
                    OuterExpressionKinds2[OuterExpressionKinds2["Assertions"] = 6] = "Assertions";
                    OuterExpressionKinds2[OuterExpressionKinds2["All"] = 15] = "All";
                    OuterExpressionKinds2[OuterExpressionKinds2["ExcludeJSDocTypeAssertion"] = 16] = "ExcludeJSDocTypeAssertion";
                    return OuterExpressionKinds2;
                })(OuterExpressionKinds || {});
                LexicalEnvironmentFlags = /* @__PURE__ */ ((LexicalEnvironmentFlags2) => {
                    LexicalEnvironmentFlags2[LexicalEnvironmentFlags2["None"] = 0] = "None";
                    LexicalEnvironmentFlags2[LexicalEnvironmentFlags2["InParameters"] = 1] = "InParameters";
                    LexicalEnvironmentFlags2[LexicalEnvironmentFlags2["VariablesHoistedInParameters"] = 2] = "VariablesHoistedInParameters";
                    return LexicalEnvironmentFlags2;
                })(LexicalEnvironmentFlags || {});
                BundleFileSectionKind = /* @__PURE__ */ ((BundleFileSectionKind2) => {
                    BundleFileSectionKind2["Prologue"] = "prologue";
                    BundleFileSectionKind2["EmitHelpers"] = "emitHelpers";
                    BundleFileSectionKind2["NoDefaultLib"] = "no-default-lib";
                    BundleFileSectionKind2["Reference"] = "reference";
                    BundleFileSectionKind2["Type"] = "type";
                    BundleFileSectionKind2["TypeResolutionModeRequire"] = "type-require";
                    BundleFileSectionKind2["TypeResolutionModeImport"] = "type-import";
                    BundleFileSectionKind2["Lib"] = "lib";
                    BundleFileSectionKind2["Prepend"] = "prepend";
                    BundleFileSectionKind2["Text"] = "text";
                    BundleFileSectionKind2["Internal"] = "internal";
                    return BundleFileSectionKind2;
                })(BundleFileSectionKind || {});
                ListFormat = /* @__PURE__ */ ((ListFormat2) => {
                    ListFormat2[ListFormat2["None"] = 0] = "None";
                    ListFormat2[ListFormat2["SingleLine"] = 0] = "SingleLine";
                    ListFormat2[ListFormat2["MultiLine"] = 1] = "MultiLine";
                    ListFormat2[ListFormat2["PreserveLines"] = 2] = "PreserveLines";
                    ListFormat2[ListFormat2["LinesMask"] = 3] = "LinesMask";
                    ListFormat2[ListFormat2["NotDelimited"] = 0] = "NotDelimited";
                    ListFormat2[ListFormat2["BarDelimited"] = 4] = "BarDelimited";
                    ListFormat2[ListFormat2["AmpersandDelimited"] = 8] = "AmpersandDelimited";
                    ListFormat2[ListFormat2["CommaDelimited"] = 16] = "CommaDelimited";
                    ListFormat2[ListFormat2["AsteriskDelimited"] = 32] = "AsteriskDelimited";
                    ListFormat2[ListFormat2["DelimitersMask"] = 60] = "DelimitersMask";
                    ListFormat2[ListFormat2["AllowTrailingComma"] = 64] = "AllowTrailingComma";
                    ListFormat2[ListFormat2["Indented"] = 128] = "Indented";
                    ListFormat2[ListFormat2["SpaceBetweenBraces"] = 256] = "SpaceBetweenBraces";
                    ListFormat2[ListFormat2["SpaceBetweenSiblings"] = 512] = "SpaceBetweenSiblings";
                    ListFormat2[ListFormat2["Braces"] = 1024] = "Braces";
                    ListFormat2[ListFormat2["Parenthesis"] = 2048] = "Parenthesis";
                    ListFormat2[ListFormat2["AngleBrackets"] = 4096] = "AngleBrackets";
                    ListFormat2[ListFormat2["SquareBrackets"] = 8192] = "SquareBrackets";
                    ListFormat2[ListFormat2["BracketsMask"] = 15360] = "BracketsMask";
                    ListFormat2[ListFormat2["OptionalIfUndefined"] = 16384] = "OptionalIfUndefined";
                    ListFormat2[ListFormat2["OptionalIfEmpty"] = 32768] = "OptionalIfEmpty";
                    ListFormat2[ListFormat2["Optional"] = 49152] = "Optional";
                    ListFormat2[ListFormat2["PreferNewLine"] = 65536] = "PreferNewLine";
                    ListFormat2[ListFormat2["NoTrailingNewLine"] = 131072] = "NoTrailingNewLine";
                    ListFormat2[ListFormat2["NoInterveningComments"] = 262144] = "NoInterveningComments";
                    ListFormat2[ListFormat2["NoSpaceIfEmpty"] = 524288] = "NoSpaceIfEmpty";
                    ListFormat2[ListFormat2["SingleElement"] = 1048576] = "SingleElement";
                    ListFormat2[ListFormat2["SpaceAfterList"] = 2097152] = "SpaceAfterList";
                    ListFormat2[ListFormat2["Modifiers"] = 2359808] = "Modifiers";
                    ListFormat2[ListFormat2["HeritageClauses"] = 512] = "HeritageClauses";
                    ListFormat2[ListFormat2["SingleLineTypeLiteralMembers"] = 768] = "SingleLineTypeLiteralMembers";
                    ListFormat2[ListFormat2["MultiLineTypeLiteralMembers"] = 32897] = "MultiLineTypeLiteralMembers";
                    ListFormat2[ListFormat2["SingleLineTupleTypeElements"] = 528] = "SingleLineTupleTypeElements";
                    ListFormat2[ListFormat2["MultiLineTupleTypeElements"] = 657] = "MultiLineTupleTypeElements";
                    ListFormat2[ListFormat2["UnionTypeConstituents"] = 516] = "UnionTypeConstituents";
                    ListFormat2[ListFormat2["IntersectionTypeConstituents"] = 520] = "IntersectionTypeConstituents";
                    ListFormat2[ListFormat2["ObjectBindingPatternElements"] = 525136] = "ObjectBindingPatternElements";
                    ListFormat2[ListFormat2["ArrayBindingPatternElements"] = 524880] = "ArrayBindingPatternElements";
                    ListFormat2[ListFormat2["ObjectLiteralExpressionProperties"] = 526226] = "ObjectLiteralExpressionProperties";
                    ListFormat2[ListFormat2["ImportAttributes"] = 526226] = "ImportAttributes";
                    ListFormat2[ListFormat2["ImportClauseEntries"] = 526226 /* ImportAttributes */] = "ImportClauseEntries";
                    ListFormat2[ListFormat2["ArrayLiteralExpressionElements"] = 8914] = "ArrayLiteralExpressionElements";
                    ListFormat2[ListFormat2["CommaListElements"] = 528] = "CommaListElements";
                    ListFormat2[ListFormat2["CallExpressionArguments"] = 2576] = "CallExpressionArguments";
                    ListFormat2[ListFormat2["NewExpressionArguments"] = 18960] = "NewExpressionArguments";
                    ListFormat2[ListFormat2["TemplateExpressionSpans"] = 262144] = "TemplateExpressionSpans";
                    ListFormat2[ListFormat2["SingleLineBlockStatements"] = 768] = "SingleLineBlockStatements";
                    ListFormat2[ListFormat2["MultiLineBlockStatements"] = 129] = "MultiLineBlockStatements";
                    ListFormat2[ListFormat2["VariableDeclarationList"] = 528] = "VariableDeclarationList";
                    ListFormat2[ListFormat2["SingleLineFunctionBodyStatements"] = 768] = "SingleLineFunctionBodyStatements";
                    ListFormat2[ListFormat2["MultiLineFunctionBodyStatements"] = 1 /* MultiLine */] = "MultiLineFunctionBodyStatements";
                    ListFormat2[ListFormat2["ClassHeritageClauses"] = 0 /* SingleLine */] = "ClassHeritageClauses";
                    ListFormat2[ListFormat2["ClassMembers"] = 129] = "ClassMembers";
                    ListFormat2[ListFormat2["InterfaceMembers"] = 129] = "InterfaceMembers";
                    ListFormat2[ListFormat2["EnumMembers"] = 145] = "EnumMembers";
                    ListFormat2[ListFormat2["CaseBlockClauses"] = 129] = "CaseBlockClauses";
                    ListFormat2[ListFormat2["NamedImportsOrExportsElements"] = 525136] = "NamedImportsOrExportsElements";
                    ListFormat2[ListFormat2["JsxElementOrFragmentChildren"] = 262144] = "JsxElementOrFragmentChildren";
                    ListFormat2[ListFormat2["JsxElementAttributes"] = 262656] = "JsxElementAttributes";
                    ListFormat2[ListFormat2["CaseOrDefaultClauseStatements"] = 163969] = "CaseOrDefaultClauseStatements";
                    ListFormat2[ListFormat2["HeritageClauseTypes"] = 528] = "HeritageClauseTypes";
                    ListFormat2[ListFormat2["SourceFileStatements"] = 131073] = "SourceFileStatements";
                    ListFormat2[ListFormat2["Decorators"] = 2146305] = "Decorators";
                    ListFormat2[ListFormat2["TypeArguments"] = 53776] = "TypeArguments";
                    ListFormat2[ListFormat2["TypeParameters"] = 53776] = "TypeParameters";
                    ListFormat2[ListFormat2["Parameters"] = 2576] = "Parameters";
                    ListFormat2[ListFormat2["IndexSignatureParameters"] = 8848] = "IndexSignatureParameters";
                    ListFormat2[ListFormat2["JSDocComment"] = 33] = "JSDocComment";
                    return ListFormat2;
                })(ListFormat || {});
                PragmaKindFlags = /* @__PURE__ */ ((PragmaKindFlags2) => {
                    PragmaKindFlags2[PragmaKindFlags2["None"] = 0] = "None";
                    PragmaKindFlags2[PragmaKindFlags2["TripleSlashXML"] = 1] = "TripleSlashXML";
                    PragmaKindFlags2[PragmaKindFlags2["SingleLine"] = 2] = "SingleLine";
                    PragmaKindFlags2[PragmaKindFlags2["MultiLine"] = 4] = "MultiLine";
                    PragmaKindFlags2[PragmaKindFlags2["All"] = 7] = "All";
                    PragmaKindFlags2[PragmaKindFlags2["Default"] = 7 /* All */] = "Default";
                    return PragmaKindFlags2;
                })(PragmaKindFlags || {});
                commentPragmas = {
                    "reference": {
                        args: [
                            { name: "types", optional: true, captureSpan: true },
                            { name: "lib", optional: true, captureSpan: true },
                            { name: "path", optional: true, captureSpan: true },
                            { name: "no-default-lib", optional: true },
                            { name: "resolution-mode", optional: true }
                        ],
                        kind: 1 /* TripleSlashXML */
                    },
                    "amd-dependency": {
                        args: [{ name: "path" }, { name: "name", optional: true }],
                        kind: 1 /* TripleSlashXML */
                    },
                    "amd-module": {
                        args: [{ name: "name" }],
                        kind: 1 /* TripleSlashXML */
                    },
                    "ts-check": {
                        kind: 2 /* SingleLine */
                    },
                    "ts-nocheck": {
                        kind: 2 /* SingleLine */
                    },
                    "jsx": {
                        args: [{ name: "factory" }],
                        kind: 4 /* MultiLine */
                    },
                    "jsxfrag": {
                        args: [{ name: "factory" }],
                        kind: 4 /* MultiLine */
                    },
                    "jsximportsource": {
                        args: [{ name: "factory" }],
                        kind: 4 /* MultiLine */
                    },
                    "jsxruntime": {
                        args: [{ name: "factory" }],
                        kind: 4 /* MultiLine */
                    }
                };
                JSDocParsingMode = /* @__PURE__ */ ((JSDocParsingMode6) => {
                    JSDocParsingMode6[JSDocParsingMode6["ParseAll"] = 0] = "ParseAll";
                    JSDocParsingMode6[JSDocParsingMode6["ParseNone"] = 1] = "ParseNone";
                    JSDocParsingMode6[JSDocParsingMode6["ParseForTypeErrors"] = 2] = "ParseForTypeErrors";
                    JSDocParsingMode6[JSDocParsingMode6["ParseForTypeInfo"] = 3] = "ParseForTypeInfo";
                    return JSDocParsingMode6;
                })(JSDocParsingMode || {});
            }
        });
        // src/compiler/sys.ts
        function generateDjb2Hash(data) {
            let acc = 5381;
            for (let i = 0; i < data.length; i++) {
                acc = (acc << 5) + acc + data.charCodeAt(i);
            }
            return acc.toString();
        }
        function setStackTraceLimit() {
            if (Error.stackTraceLimit < 100) {
                Error.stackTraceLimit = 100;
            }
        }
        function getModifiedTime(host, fileName) {
            return host.getModifiedTime(fileName) || missingFileModifiedTime;
        }
        function createPollingIntervalBasedLevels(levels) {
            return {
                [250 /* Low */]: levels.Low,
                [500 /* Medium */]: levels.Medium,
                [2e3 /* High */]: levels.High
            };
        }
        function setCustomPollingValues(system) {
            if (!system.getEnvironmentVariable) {
                return;
            }
            const pollingIntervalChanged = setCustomLevels("TSC_WATCH_POLLINGINTERVAL", PollingInterval);
            pollingChunkSize = getCustomPollingBasedLevels("TSC_WATCH_POLLINGCHUNKSIZE", defaultChunkLevels) || pollingChunkSize;
            unchangedPollThresholds = getCustomPollingBasedLevels("TSC_WATCH_UNCHANGEDPOLLTHRESHOLDS", defaultChunkLevels) || unchangedPollThresholds;
            function getLevel(envVar, level) {
                return system.getEnvironmentVariable(`${envVar}_${level.toUpperCase()}`);
            }
            function getCustomLevels(baseVariable) {
                let customLevels;
                setCustomLevel("Low");
                setCustomLevel("Medium");
                setCustomLevel("High");
                return customLevels;
                function setCustomLevel(level) {
                    const customLevel = getLevel(baseVariable, level);
                    if (customLevel) {
                        (customLevels || (customLevels = {}))[level] = Number(customLevel);
                    }
                }
            }
            function setCustomLevels(baseVariable, levels) {
                const customLevels = getCustomLevels(baseVariable);
                if (customLevels) {
                    setLevel("Low");
                    setLevel("Medium");
                    setLevel("High");
                    return true;
                }
                return false;
                function setLevel(level) {
                    levels[level] = customLevels[level] || levels[level];
                }
            }
            function getCustomPollingBasedLevels(baseVariable, defaultLevels) {
                const customLevels = getCustomLevels(baseVariable);
                return (pollingIntervalChanged || customLevels) && createPollingIntervalBasedLevels(customLevels ? { ...defaultLevels, ...customLevels } : defaultLevels);
            }
        }
        function pollWatchedFileQueue(host, queue, pollIndex, chunkSize, callbackOnWatchFileStat) {
            let definedValueCopyToIndex = pollIndex;
            for (let canVisit = queue.length; chunkSize && canVisit; nextPollIndex(), canVisit--) {
                const watchedFile = queue[pollIndex];
                if (!watchedFile) {
                    continue;
                }
                else if (watchedFile.isClosed) {
                    queue[pollIndex] = void 0;
                    continue;
                }
                chunkSize--;
                const fileChanged = onWatchedFileStat(watchedFile, getModifiedTime(host, watchedFile.fileName));
                if (watchedFile.isClosed) {
                    queue[pollIndex] = void 0;
                    continue;
                }
                callbackOnWatchFileStat == null ? void 0 : callbackOnWatchFileStat(watchedFile, pollIndex, fileChanged);
                if (queue[pollIndex]) {
                    if (definedValueCopyToIndex < pollIndex) {
                        queue[definedValueCopyToIndex] = watchedFile;
                        queue[pollIndex] = void 0;
                    }
                    definedValueCopyToIndex++;
                }
            }
            return pollIndex;
            function nextPollIndex() {
                pollIndex++;
                if (pollIndex === queue.length) {
                    if (definedValueCopyToIndex < pollIndex) {
                        queue.length = definedValueCopyToIndex;
                    }
                    pollIndex = 0;
                    definedValueCopyToIndex = 0;
                }
            }
        }
        function createDynamicPriorityPollingWatchFile(host) {
            const watchedFiles = [];
            const changedFilesInLastPoll = [];
            const lowPollingIntervalQueue = createPollingIntervalQueue(250 /* Low */);
            const mediumPollingIntervalQueue = createPollingIntervalQueue(500 /* Medium */);
            const highPollingIntervalQueue = createPollingIntervalQueue(2e3 /* High */);
            return watchFile2;
            function watchFile2(fileName, callback, defaultPollingInterval) {
                const file = {
                    fileName,
                    callback,
                    unchangedPolls: 0,
                    mtime: getModifiedTime(host, fileName)
                };
                watchedFiles.push(file);
                addToPollingIntervalQueue(file, defaultPollingInterval);
                return {
                    close: () => {
                        file.isClosed = true;
                        unorderedRemoveItem(watchedFiles, file);
                    }
                };
            }
            function createPollingIntervalQueue(pollingInterval) {
                const queue = [];
                queue.pollingInterval = pollingInterval;
                queue.pollIndex = 0;
                queue.pollScheduled = false;
                return queue;
            }
            function pollPollingIntervalQueue(_timeoutType, queue) {
                queue.pollIndex = pollQueue(queue, queue.pollingInterval, queue.pollIndex, pollingChunkSize[queue.pollingInterval]);
                if (queue.length) {
                    scheduleNextPoll(queue.pollingInterval);
                }
                else {
                    Debug.assert(queue.pollIndex === 0);
                    queue.pollScheduled = false;
                }
            }
            function pollLowPollingIntervalQueue(_timeoutType, queue) {
                pollQueue(changedFilesInLastPoll, 250 /* Low */, 
                /*pollIndex*/
                0, changedFilesInLastPoll.length);
                pollPollingIntervalQueue(_timeoutType, queue);
                if (!queue.pollScheduled && changedFilesInLastPoll.length) {
                    scheduleNextPoll(250 /* Low */);
                }
            }
            function pollQueue(queue, pollingInterval, pollIndex, chunkSize) {
                return pollWatchedFileQueue(host, queue, pollIndex, chunkSize, onWatchFileStat);
                function onWatchFileStat(watchedFile, pollIndex2, fileChanged) {
                    if (fileChanged) {
                        watchedFile.unchangedPolls = 0;
                        if (queue !== changedFilesInLastPoll) {
                            queue[pollIndex2] = void 0;
                            addChangedFileToLowPollingIntervalQueue(watchedFile);
                        }
                    }
                    else if (watchedFile.unchangedPolls !== unchangedPollThresholds[pollingInterval]) {
                        watchedFile.unchangedPolls++;
                    }
                    else if (queue === changedFilesInLastPoll) {
                        watchedFile.unchangedPolls = 1;
                        queue[pollIndex2] = void 0;
                        addToPollingIntervalQueue(watchedFile, 250 /* Low */);
                    }
                    else if (pollingInterval !== 2e3 /* High */) {
                        watchedFile.unchangedPolls++;
                        queue[pollIndex2] = void 0;
                        addToPollingIntervalQueue(watchedFile, pollingInterval === 250 /* Low */ ? 500 /* Medium */ : 2e3 /* High */);
                    }
                }
            }
            function pollingIntervalQueue(pollingInterval) {
                switch (pollingInterval) {
                    case 250 /* Low */:
                        return lowPollingIntervalQueue;
                    case 500 /* Medium */:
                        return mediumPollingIntervalQueue;
                    case 2e3 /* High */:
                        return highPollingIntervalQueue;
                }
            }
            function addToPollingIntervalQueue(file, pollingInterval) {
                pollingIntervalQueue(pollingInterval).push(file);
                scheduleNextPollIfNotAlreadyScheduled(pollingInterval);
            }
            function addChangedFileToLowPollingIntervalQueue(file) {
                changedFilesInLastPoll.push(file);
                scheduleNextPollIfNotAlreadyScheduled(250 /* Low */);
            }
            function scheduleNextPollIfNotAlreadyScheduled(pollingInterval) {
                if (!pollingIntervalQueue(pollingInterval).pollScheduled) {
                    scheduleNextPoll(pollingInterval);
                }
            }
            function scheduleNextPoll(pollingInterval) {
                pollingIntervalQueue(pollingInterval).pollScheduled = host.setTimeout(pollingInterval === 250 /* Low */ ? pollLowPollingIntervalQueue : pollPollingIntervalQueue, pollingInterval, pollingInterval === 250 /* Low */ ? "pollLowPollingIntervalQueue" : "pollPollingIntervalQueue", pollingIntervalQueue(pollingInterval));
            }
        }
        function createUseFsEventsOnParentDirectoryWatchFile(fsWatch, useCaseSensitiveFileNames2) {
            const fileWatcherCallbacks = createMultiMap();
            const dirWatchers = /* @__PURE__ */ new Map();
            const toCanonicalName = createGetCanonicalFileName(useCaseSensitiveFileNames2);
            return nonPollingWatchFile;
            function nonPollingWatchFile(fileName, callback, _pollingInterval, fallbackOptions) {
                const filePath = toCanonicalName(fileName);
                fileWatcherCallbacks.add(filePath, callback);
                const dirPath = getDirectoryPath(filePath) || ".";
                const watcher = dirWatchers.get(dirPath) || createDirectoryWatcher(getDirectoryPath(fileName) || ".", dirPath, fallbackOptions);
                watcher.referenceCount++;
                return {
                    close: () => {
                        if (watcher.referenceCount === 1) {
                            watcher.close();
                            dirWatchers.delete(dirPath);
                        }
                        else {
                            watcher.referenceCount--;
                        }
                        fileWatcherCallbacks.remove(filePath, callback);
                    }
                };
            }
            function createDirectoryWatcher(dirName, dirPath, fallbackOptions) {
                const watcher = fsWatch(dirName, 1 /* Directory */, (_eventName, relativeFileName, modifiedTime) => {
                    if (!isString(relativeFileName))
                        return;
                    const fileName = getNormalizedAbsolutePath(relativeFileName, dirName);
                    const callbacks = fileName && fileWatcherCallbacks.get(toCanonicalName(fileName));
                    if (callbacks) {
                        for (const fileCallback of callbacks) {
                            fileCallback(fileName, 1 /* Changed */, modifiedTime);
                        }
                    }
                }, 
                /*recursive*/
                false, 500 /* Medium */, fallbackOptions);
                watcher.referenceCount = 0;
                dirWatchers.set(dirPath, watcher);
                return watcher;
            }
        }
        function createFixedChunkSizePollingWatchFile(host) {
            const watchedFiles = [];
            let pollIndex = 0;
            let pollScheduled;
            return watchFile2;
            function watchFile2(fileName, callback) {
                const file = {
                    fileName,
                    callback,
                    mtime: getModifiedTime(host, fileName)
                };
                watchedFiles.push(file);
                scheduleNextPoll();
                return {
                    close: () => {
                        file.isClosed = true;
                        unorderedRemoveItem(watchedFiles, file);
                    }
                };
            }
            function pollQueue() {
                pollScheduled = void 0;
                pollIndex = pollWatchedFileQueue(host, watchedFiles, pollIndex, pollingChunkSize[250 /* Low */]);
                scheduleNextPoll();
            }
            function scheduleNextPoll() {
                if (!watchedFiles.length || pollScheduled)
                    return;
                pollScheduled = host.setTimeout(pollQueue, 2e3 /* High */, "pollQueue");
            }
        }
        function createSingleWatcherPerName(cache, useCaseSensitiveFileNames2, name, callback, createWatcher) {
            const toCanonicalFileName = createGetCanonicalFileName(useCaseSensitiveFileNames2);
            const path = toCanonicalFileName(name);
            const existing = cache.get(path);
            if (existing) {
                existing.callbacks.push(callback);
            }
            else {
                cache.set(path, {
                    watcher: createWatcher(
                    // Cant infer types correctly so lets satisfy checker
                    (param1, param2, param3) => {
                        var _a;
                        return (_a = cache.get(path)) == null ? void 0 : _a.callbacks.slice().forEach((cb) => cb(param1, param2, param3));
                    }),
                    callbacks: [callback]
                });
            }
            return {
                close: () => {
                    const watcher = cache.get(path);
                    if (!watcher)
                        return;
                    if (!orderedRemoveItem(watcher.callbacks, callback) || watcher.callbacks.length)
                        return;
                    cache.delete(path);
                    closeFileWatcherOf(watcher);
                }
            };
        }
        function onWatchedFileStat(watchedFile, modifiedTime) {
            const oldTime = watchedFile.mtime.getTime();
            const newTime = modifiedTime.getTime();
            if (oldTime !== newTime) {
                watchedFile.mtime = modifiedTime;
                watchedFile.callback(watchedFile.fileName, getFileWatcherEventKind(oldTime, newTime), modifiedTime);
                return true;
            }
            return false;
        }
        function getFileWatcherEventKind(oldTime, newTime) {
            return oldTime === 0 ? 0 /* Created */ : newTime === 0 ? 2 /* Deleted */ : 1 /* Changed */;
        }
        function sysLog(s) {
            return curSysLog(s);
        }
        function setSysLog(logger) {
            curSysLog = logger;
        }
        function createDirectoryWatcherSupportingRecursive({ watchDirectory, useCaseSensitiveFileNames: useCaseSensitiveFileNames2, getCurrentDirectory, getAccessibleSortedChildDirectories, fileSystemEntryExists, realpath, setTimeout: setTimeout2, clearTimeout: clearTimeout2 }) {
            const cache = /* @__PURE__ */ new Map();
            const callbackCache = createMultiMap();
            const cacheToUpdateChildWatches = /* @__PURE__ */ new Map();
            let timerToUpdateChildWatches;
            const filePathComparer = getStringComparer(!useCaseSensitiveFileNames2);
            const toCanonicalFilePath = createGetCanonicalFileName(useCaseSensitiveFileNames2);
            return (dirName, callback, recursive, options) => recursive ? createDirectoryWatcher(dirName, options, callback) : watchDirectory(dirName, callback, recursive, options);
            function createDirectoryWatcher(dirName, options, callback) {
                const dirPath = toCanonicalFilePath(dirName);
                let directoryWatcher = cache.get(dirPath);
                if (directoryWatcher) {
                    directoryWatcher.refCount++;
                }
                else {
                    directoryWatcher = {
                        watcher: watchDirectory(dirName, (fileName) => {
                            if (isIgnoredPath(fileName, options))
                                return;
                            if (options == null ? void 0 : options.synchronousWatchDirectory) {
                                invokeCallbacks(dirPath, fileName);
                                updateChildWatches(dirName, dirPath, options);
                            }
                            else {
                                nonSyncUpdateChildWatches(dirName, dirPath, fileName, options);
                            }
                        }, 
                        /*recursive*/
                        false, options),
                        refCount: 1,
                        childWatches: emptyArray
                    };
                    cache.set(dirPath, directoryWatcher);
                    updateChildWatches(dirName, dirPath, options);
                }
                const callbackToAdd = callback && { dirName, callback };
                if (callbackToAdd) {
                    callbackCache.add(dirPath, callbackToAdd);
                }
                return {
                    dirName,
                    close: () => {
                        const directoryWatcher2 = Debug.checkDefined(cache.get(dirPath));
                        if (callbackToAdd)
                            callbackCache.remove(dirPath, callbackToAdd);
                        directoryWatcher2.refCount--;
                        if (directoryWatcher2.refCount)
                            return;
                        cache.delete(dirPath);
                        closeFileWatcherOf(directoryWatcher2);
                        directoryWatcher2.childWatches.forEach(closeFileWatcher);
                    }
                };
            }
            function invokeCallbacks(dirPath, fileNameOrInvokeMap, fileNames) {
                let fileName;
                let invokeMap;
                if (isString(fileNameOrInvokeMap)) {
                    fileName = fileNameOrInvokeMap;
                }
                else {
                    invokeMap = fileNameOrInvokeMap;
                }
                callbackCache.forEach((callbacks, rootDirName) => {
                    if (invokeMap && invokeMap.get(rootDirName) === true)
                        return;
                    if (rootDirName === dirPath || startsWith(dirPath, rootDirName) && dirPath[rootDirName.length] === directorySeparator) {
                        if (invokeMap) {
                            if (fileNames) {
                                const existing = invokeMap.get(rootDirName);
                                if (existing) {
                                    existing.push(...fileNames);
                                }
                                else {
                                    invokeMap.set(rootDirName, fileNames.slice());
                                }
                            }
                            else {
                                invokeMap.set(rootDirName, true);
                            }
                        }
                        else {
                            callbacks.forEach(({ callback }) => callback(fileName));
                        }
                    }
                });
            }
            function nonSyncUpdateChildWatches(dirName, dirPath, fileName, options) {
                const parentWatcher = cache.get(dirPath);
                if (parentWatcher && fileSystemEntryExists(dirName, 1 /* Directory */)) {
                    scheduleUpdateChildWatches(dirName, dirPath, fileName, options);
                    return;
                }
                invokeCallbacks(dirPath, fileName);
                removeChildWatches(parentWatcher);
            }
            function scheduleUpdateChildWatches(dirName, dirPath, fileName, options) {
                const existing = cacheToUpdateChildWatches.get(dirPath);
                if (existing) {
                    existing.fileNames.push(fileName);
                }
                else {
                    cacheToUpdateChildWatches.set(dirPath, { dirName, options, fileNames: [fileName] });
                }
                if (timerToUpdateChildWatches) {
                    clearTimeout2(timerToUpdateChildWatches);
                    timerToUpdateChildWatches = void 0;
                }
                timerToUpdateChildWatches = setTimeout2(onTimerToUpdateChildWatches, 1e3, "timerToUpdateChildWatches");
            }
            function onTimerToUpdateChildWatches() {
                timerToUpdateChildWatches = void 0;
                sysLog(`sysLog:: onTimerToUpdateChildWatches:: ${cacheToUpdateChildWatches.size}`);
                const start = timestamp();
                const invokeMap = /* @__PURE__ */ new Map();
                while (!timerToUpdateChildWatches && cacheToUpdateChildWatches.size) {
                    const result = cacheToUpdateChildWatches.entries().next();
                    Debug.assert(!result.done);
                    const { value: [dirPath, { dirName, options, fileNames }] } = result;
                    cacheToUpdateChildWatches.delete(dirPath);
                    const hasChanges = updateChildWatches(dirName, dirPath, options);
                    invokeCallbacks(dirPath, invokeMap, hasChanges ? void 0 : fileNames);
                }
                sysLog(`sysLog:: invokingWatchers:: Elapsed:: ${timestamp() - start}ms:: ${cacheToUpdateChildWatches.size}`);
                callbackCache.forEach((callbacks, rootDirName) => {
                    const existing = invokeMap.get(rootDirName);
                    if (existing) {
                        callbacks.forEach(({ callback, dirName }) => {
                            if (isArray(existing)) {
                                existing.forEach(callback);
                            }
                            else {
                                callback(dirName);
                            }
                        });
                    }
                });
                const elapsed = timestamp() - start;
                sysLog(`sysLog:: Elapsed:: ${elapsed}ms:: onTimerToUpdateChildWatches:: ${cacheToUpdateChildWatches.size} ${timerToUpdateChildWatches}`);
            }
            function removeChildWatches(parentWatcher) {
                if (!parentWatcher)
                    return;
                const existingChildWatches = parentWatcher.childWatches;
                parentWatcher.childWatches = emptyArray;
                for (const childWatcher of existingChildWatches) {
                    childWatcher.close();
                    removeChildWatches(cache.get(toCanonicalFilePath(childWatcher.dirName)));
                }
            }
            function updateChildWatches(parentDir, parentDirPath, options) {
                const parentWatcher = cache.get(parentDirPath);
                if (!parentWatcher)
                    return false;
                let newChildWatches;
                const hasChanges = enumerateInsertsAndDeletes(fileSystemEntryExists(parentDir, 1 /* Directory */) ? mapDefined(getAccessibleSortedChildDirectories(parentDir), (child) => {
                    const childFullName = getNormalizedAbsolutePath(child, parentDir);
                    return !isIgnoredPath(childFullName, options) && filePathComparer(childFullName, normalizePath(realpath(childFullName))) === 0 /* EqualTo */ ? childFullName : void 0;
                }) : emptyArray, parentWatcher.childWatches, (child, childWatcher) => filePathComparer(child, childWatcher.dirName), createAndAddChildDirectoryWatcher, closeFileWatcher, addChildDirectoryWatcher);
                parentWatcher.childWatches = newChildWatches || emptyArray;
                return hasChanges;
                function createAndAddChildDirectoryWatcher(childName) {
                    const result = createDirectoryWatcher(childName, options);
                    addChildDirectoryWatcher(result);
                }
                function addChildDirectoryWatcher(childWatcher) {
                    (newChildWatches || (newChildWatches = [])).push(childWatcher);
                }
            }
            function isIgnoredPath(path, options) {
                return some(ignoredPaths, (searchPath) => isInPath(path, searchPath)) || isIgnoredByWatchOptions(path, options, useCaseSensitiveFileNames2, getCurrentDirectory);
            }
            function isInPath(path, searchPath) {
                if (path.includes(searchPath))
                    return true;
                if (useCaseSensitiveFileNames2)
                    return false;
                return toCanonicalFilePath(path).includes(searchPath);
            }
        }
        function createFileWatcherCallback(callback) {
            return (_fileName, eventKind, modifiedTime) => callback(eventKind === 1 /* Changed */ ? "change" : "rename", "", modifiedTime);
        }
        function createFsWatchCallbackForFileWatcherCallback(fileName, callback, getModifiedTime3) {
            return (eventName, _relativeFileName, modifiedTime) => {
                if (eventName === "rename") {
                    modifiedTime || (modifiedTime = getModifiedTime3(fileName) || missingFileModifiedTime);
                    callback(fileName, modifiedTime !== missingFileModifiedTime ? 0 /* Created */ : 2 /* Deleted */, modifiedTime);
                }
                else {
                    callback(fileName, 1 /* Changed */, modifiedTime);
                }
            };
        }
        function isIgnoredByWatchOptions(pathToCheck, options, useCaseSensitiveFileNames2, getCurrentDirectory) {
            return ((options == null ? void 0 : options.excludeDirectories) || (options == null ? void 0 : options.excludeFiles)) && (matchesExclude(pathToCheck, options == null ? void 0 : options.excludeFiles, useCaseSensitiveFileNames2, getCurrentDirectory()) || matchesExclude(pathToCheck, options == null ? void 0 : options.excludeDirectories, useCaseSensitiveFileNames2, getCurrentDirectory()));
        }
        function createFsWatchCallbackForDirectoryWatcherCallback(directoryName, callback, options, useCaseSensitiveFileNames2, getCurrentDirectory) {
            return (eventName, relativeFileName) => {
                if (eventName === "rename") {
                    const fileName = !relativeFileName ? directoryName : normalizePath(combinePaths(directoryName, relativeFileName));
                    if (!relativeFileName || !isIgnoredByWatchOptions(fileName, options, useCaseSensitiveFileNames2, getCurrentDirectory)) {
                        callback(fileName);
                    }
                }
            };
        }
        function createSystemWatchFunctions({ pollingWatchFileWorker, getModifiedTime: getModifiedTime3, setTimeout: setTimeout2, clearTimeout: clearTimeout2, fsWatchWorker, fileSystemEntryExists, useCaseSensitiveFileNames: useCaseSensitiveFileNames2, getCurrentDirectory, fsSupportsRecursiveFsWatch, getAccessibleSortedChildDirectories, realpath, tscWatchFile, useNonPollingWatchers, tscWatchDirectory, inodeWatching, fsWatchWithTimestamp, sysLog: sysLog2 }) {
            const pollingWatches = /* @__PURE__ */ new Map();
            const fsWatches = /* @__PURE__ */ new Map();
            const fsWatchesRecursive = /* @__PURE__ */ new Map();
            let dynamicPollingWatchFile;
            let fixedChunkSizePollingWatchFile;
            let nonPollingWatchFile;
            let hostRecursiveDirectoryWatcher;
            let hitSystemWatcherLimit = false;
            return {
                watchFile: watchFile2,
                watchDirectory
            };
            function watchFile2(fileName, callback, pollingInterval, options) {
                options = updateOptionsForWatchFile(options, useNonPollingWatchers);
                const watchFileKind = Debug.checkDefined(options.watchFile);
                switch (watchFileKind) {
                    case 0 /* FixedPollingInterval */:
                        return pollingWatchFile(fileName, callback, 250 /* Low */, 
                        /*options*/
                        void 0);
                    case 1 /* PriorityPollingInterval */:
                        return pollingWatchFile(fileName, callback, pollingInterval, 
                        /*options*/
                        void 0);
                    case 2 /* DynamicPriorityPolling */:
                        return ensureDynamicPollingWatchFile()(fileName, callback, pollingInterval, 
                        /*options*/
                        void 0);
                    case 3 /* FixedChunkSizePolling */:
                        return ensureFixedChunkSizePollingWatchFile()(fileName, callback, 
                        /* pollingInterval */
                        void 0, 
                        /*options*/
                        void 0);
                    case 4 /* UseFsEvents */:
                        return fsWatch(fileName, 0 /* File */, createFsWatchCallbackForFileWatcherCallback(fileName, callback, getModifiedTime3), 
                        /*recursive*/
                        false, pollingInterval, getFallbackOptions(options));
                    case 5 /* UseFsEventsOnParentDirectory */:
                        if (!nonPollingWatchFile) {
                            nonPollingWatchFile = createUseFsEventsOnParentDirectoryWatchFile(fsWatch, useCaseSensitiveFileNames2);
                        }
                        return nonPollingWatchFile(fileName, callback, pollingInterval, getFallbackOptions(options));
                    default:
                        Debug.assertNever(watchFileKind);
                }
            }
            function ensureDynamicPollingWatchFile() {
                return dynamicPollingWatchFile || (dynamicPollingWatchFile = createDynamicPriorityPollingWatchFile({ getModifiedTime: getModifiedTime3, setTimeout: setTimeout2 }));
            }
            function ensureFixedChunkSizePollingWatchFile() {
                return fixedChunkSizePollingWatchFile || (fixedChunkSizePollingWatchFile = createFixedChunkSizePollingWatchFile({ getModifiedTime: getModifiedTime3, setTimeout: setTimeout2 }));
            }
            function updateOptionsForWatchFile(options, useNonPollingWatchers2) {
                if (options && options.watchFile !== void 0)
                    return options;
                switch (tscWatchFile) {
                    case "PriorityPollingInterval":
                        return { watchFile: 1 /* PriorityPollingInterval */ };
                    case "DynamicPriorityPolling":
                        return { watchFile: 2 /* DynamicPriorityPolling */ };
                    case "UseFsEvents":
                        return generateWatchFileOptions(4 /* UseFsEvents */, 1 /* PriorityInterval */, options);
                    case "UseFsEventsWithFallbackDynamicPolling":
                        return generateWatchFileOptions(4 /* UseFsEvents */, 2 /* DynamicPriority */, options);
                    case "UseFsEventsOnParentDirectory":
                        useNonPollingWatchers2 = true;
                    default:
                        return useNonPollingWatchers2 ? (
                        // Use notifications from FS to watch with falling back to fs.watchFile
                        generateWatchFileOptions(5 /* UseFsEventsOnParentDirectory */, 1 /* PriorityInterval */, options)) : (
                        // Default to using fs events
                        { watchFile: 4 /* UseFsEvents */ });
                }
            }
            function generateWatchFileOptions(watchFile3, fallbackPolling, options) {
                const defaultFallbackPolling = options == null ? void 0 : options.fallbackPolling;
                return {
                    watchFile: watchFile3,
                    fallbackPolling: defaultFallbackPolling === void 0 ? fallbackPolling : defaultFallbackPolling
                };
            }
            function watchDirectory(directoryName, callback, recursive, options) {
                if (fsSupportsRecursiveFsWatch) {
                    return fsWatch(directoryName, 1 /* Directory */, createFsWatchCallbackForDirectoryWatcherCallback(directoryName, callback, options, useCaseSensitiveFileNames2, getCurrentDirectory), recursive, 500 /* Medium */, getFallbackOptions(options));
                }
                if (!hostRecursiveDirectoryWatcher) {
                    hostRecursiveDirectoryWatcher = createDirectoryWatcherSupportingRecursive({
                        useCaseSensitiveFileNames: useCaseSensitiveFileNames2,
                        getCurrentDirectory,
                        fileSystemEntryExists,
                        getAccessibleSortedChildDirectories,
                        watchDirectory: nonRecursiveWatchDirectory,
                        realpath,
                        setTimeout: setTimeout2,
                        clearTimeout: clearTimeout2
                    });
                }
                return hostRecursiveDirectoryWatcher(directoryName, callback, recursive, options);
            }
            function nonRecursiveWatchDirectory(directoryName, callback, recursive, options) {
                Debug.assert(!recursive);
                const watchDirectoryOptions = updateOptionsForWatchDirectory(options);
                const watchDirectoryKind = Debug.checkDefined(watchDirectoryOptions.watchDirectory);
                switch (watchDirectoryKind) {
                    case 1 /* FixedPollingInterval */:
                        return pollingWatchFile(directoryName, () => callback(directoryName), 500 /* Medium */, 
                        /*options*/
                        void 0);
                    case 2 /* DynamicPriorityPolling */:
                        return ensureDynamicPollingWatchFile()(directoryName, () => callback(directoryName), 500 /* Medium */, 
                        /*options*/
                        void 0);
                    case 3 /* FixedChunkSizePolling */:
                        return ensureFixedChunkSizePollingWatchFile()(directoryName, () => callback(directoryName), 
                        /* pollingInterval */
                        void 0, 
                        /*options*/
                        void 0);
                    case 0 /* UseFsEvents */:
                        return fsWatch(directoryName, 1 /* Directory */, createFsWatchCallbackForDirectoryWatcherCallback(directoryName, callback, options, useCaseSensitiveFileNames2, getCurrentDirectory), recursive, 500 /* Medium */, getFallbackOptions(watchDirectoryOptions));
                    default:
                        Debug.assertNever(watchDirectoryKind);
                }
            }
            function updateOptionsForWatchDirectory(options) {
                if (options && options.watchDirectory !== void 0)
                    return options;
                switch (tscWatchDirectory) {
                    case "RecursiveDirectoryUsingFsWatchFile":
                        return { watchDirectory: 1 /* FixedPollingInterval */ };
                    case "RecursiveDirectoryUsingDynamicPriorityPolling":
                        return { watchDirectory: 2 /* DynamicPriorityPolling */ };
                    default:
                        const defaultFallbackPolling = options == null ? void 0 : options.fallbackPolling;
                        return {
                            watchDirectory: 0 /* UseFsEvents */,
                            fallbackPolling: defaultFallbackPolling !== void 0 ? defaultFallbackPolling : void 0
                        };
                }
            }
            function pollingWatchFile(fileName, callback, pollingInterval, options) {
                return createSingleWatcherPerName(pollingWatches, useCaseSensitiveFileNames2, fileName, callback, (cb) => pollingWatchFileWorker(fileName, cb, pollingInterval, options));
            }
            function fsWatch(fileOrDirectory, entryKind, callback, recursive, fallbackPollingInterval, fallbackOptions) {
                return createSingleWatcherPerName(recursive ? fsWatchesRecursive : fsWatches, useCaseSensitiveFileNames2, fileOrDirectory, callback, (cb) => fsWatchHandlingExistenceOnHost(fileOrDirectory, entryKind, cb, recursive, fallbackPollingInterval, fallbackOptions));
            }
            function fsWatchHandlingExistenceOnHost(fileOrDirectory, entryKind, callback, recursive, fallbackPollingInterval, fallbackOptions) {
                let lastDirectoryPartWithDirectorySeparator;
                let lastDirectoryPart;
                if (inodeWatching) {
                    lastDirectoryPartWithDirectorySeparator = fileOrDirectory.substring(fileOrDirectory.lastIndexOf(directorySeparator));
                    lastDirectoryPart = lastDirectoryPartWithDirectorySeparator.slice(directorySeparator.length);
                }
                let watcher = !fileSystemEntryExists(fileOrDirectory, entryKind) ? watchMissingFileSystemEntry() : watchPresentFileSystemEntry();
                return {
                    close: () => {
                        if (watcher) {
                            watcher.close();
                            watcher = void 0;
                        }
                    }
                };
                function updateWatcher(createWatcher) {
                    if (watcher) {
                        sysLog2(`sysLog:: ${fileOrDirectory}:: Changing watcher to ${createWatcher === watchPresentFileSystemEntry ? "Present" : "Missing"}FileSystemEntryWatcher`);
                        watcher.close();
                        watcher = createWatcher();
                    }
                }
                function watchPresentFileSystemEntry() {
                    if (hitSystemWatcherLimit) {
                        sysLog2(`sysLog:: ${fileOrDirectory}:: Defaulting to watchFile`);
                        return watchPresentFileSystemEntryWithFsWatchFile();
                    }
                    try {
                        const presentWatcher = (!fsWatchWithTimestamp ? fsWatchWorker : fsWatchWorkerHandlingTimestamp)(fileOrDirectory, recursive, inodeWatching ? callbackChangingToMissingFileSystemEntry : callback);
                        presentWatcher.on("error", () => {
                            callback("rename", "");
                            updateWatcher(watchMissingFileSystemEntry);
                        });
                        return presentWatcher;
                    }
                    catch (e) {
                        hitSystemWatcherLimit || (hitSystemWatcherLimit = e.code === "ENOSPC");
                        sysLog2(`sysLog:: ${fileOrDirectory}:: Changing to watchFile`);
                        return watchPresentFileSystemEntryWithFsWatchFile();
                    }
                }
                function callbackChangingToMissingFileSystemEntry(event, relativeName) {
                    let originalRelativeName;
                    if (relativeName && endsWith(relativeName, "~")) {
                        originalRelativeName = relativeName;
                        relativeName = relativeName.slice(0, relativeName.length - 1);
                    }
                    if (event === "rename" && (!relativeName || relativeName === lastDirectoryPart || endsWith(relativeName, lastDirectoryPartWithDirectorySeparator))) {
                        const modifiedTime = getModifiedTime3(fileOrDirectory) || missingFileModifiedTime;
                        if (originalRelativeName)
                            callback(event, originalRelativeName, modifiedTime);
                        callback(event, relativeName, modifiedTime);
                        if (inodeWatching) {
                            updateWatcher(modifiedTime === missingFileModifiedTime ? watchMissingFileSystemEntry : watchPresentFileSystemEntry);
                        }
                        else if (modifiedTime === missingFileModifiedTime) {
                            updateWatcher(watchMissingFileSystemEntry);
                        }
                    }
                    else {
                        if (originalRelativeName)
                            callback(event, originalRelativeName);
                        callback(event, relativeName);
                    }
                }
                function watchPresentFileSystemEntryWithFsWatchFile() {
                    return watchFile2(fileOrDirectory, createFileWatcherCallback(callback), fallbackPollingInterval, fallbackOptions);
                }
                function watchMissingFileSystemEntry() {
                    return watchFile2(fileOrDirectory, (_fileName, eventKind, modifiedTime) => {
                        if (eventKind === 0 /* Created */) {
                            modifiedTime || (modifiedTime = getModifiedTime3(fileOrDirectory) || missingFileModifiedTime);
                            if (modifiedTime !== missingFileModifiedTime) {
                                callback("rename", "", modifiedTime);
                                updateWatcher(watchPresentFileSystemEntry);
                            }
                        }
                    }, fallbackPollingInterval, fallbackOptions);
                }
            }
            function fsWatchWorkerHandlingTimestamp(fileOrDirectory, recursive, callback) {
                let modifiedTime = getModifiedTime3(fileOrDirectory) || missingFileModifiedTime;
                return fsWatchWorker(fileOrDirectory, recursive, (eventName, relativeFileName, currentModifiedTime) => {
                    if (eventName === "change") {
                        currentModifiedTime || (currentModifiedTime = getModifiedTime3(fileOrDirectory) || missingFileModifiedTime);
                        if (currentModifiedTime.getTime() === modifiedTime.getTime())
                            return;
                    }
                    modifiedTime = currentModifiedTime || getModifiedTime3(fileOrDirectory) || missingFileModifiedTime;
                    callback(eventName, relativeFileName, modifiedTime);
                });
            }
        }
        function patchWriteFileEnsuringDirectory(sys2) {
            const originalWriteFile = sys2.writeFile;
            sys2.writeFile = (path, data, writeBom) => writeFileEnsuringDirectories(path, data, !!writeBom, (path2, data2, writeByteOrderMark) => originalWriteFile.call(sys2, path2, data2, writeByteOrderMark), (path2) => sys2.createDirectory(path2), (path2) => sys2.directoryExists(path2));
        }
        function setSys(s) {
            sys = s;
        }
        var FileWatcherEventKind, PollingInterval, missingFileModifiedTime, defaultChunkLevels, pollingChunkSize, unchangedPollThresholds, ignoredPaths, curSysLog, FileSystemEntryKind, sys;
        var init_sys = __esm({
            "src/compiler/sys.ts"() {
                "use strict";
                init_ts2();
                FileWatcherEventKind = /* @__PURE__ */ ((FileWatcherEventKind2) => {
                    FileWatcherEventKind2[FileWatcherEventKind2["Created"] = 0] = "Created";
                    FileWatcherEventKind2[FileWatcherEventKind2["Changed"] = 1] = "Changed";
                    FileWatcherEventKind2[FileWatcherEventKind2["Deleted"] = 2] = "Deleted";
                    return FileWatcherEventKind2;
                })(FileWatcherEventKind || {});
                PollingInterval = /* @__PURE__ */ ((PollingInterval3) => {
                    PollingInterval3[PollingInterval3["High"] = 2e3] = "High";
                    PollingInterval3[PollingInterval3["Medium"] = 500] = "Medium";
                    PollingInterval3[PollingInterval3["Low"] = 250] = "Low";
                    return PollingInterval3;
                })(PollingInterval || {});
                missingFileModifiedTime = /* @__PURE__ */ new Date(0);
                defaultChunkLevels = { Low: 32, Medium: 64, High: 256 };
                pollingChunkSize = createPollingIntervalBasedLevels(defaultChunkLevels);
                unchangedPollThresholds = createPollingIntervalBasedLevels(defaultChunkLevels);
                ignoredPaths = ["/node_modules/.", "/.git", "/.#"];
                curSysLog = noop;
                FileSystemEntryKind = /* @__PURE__ */ ((FileSystemEntryKind2) => {
                    FileSystemEntryKind2[FileSystemEntryKind2["File"] = 0] = "File";
                    FileSystemEntryKind2[FileSystemEntryKind2["Directory"] = 1] = "Directory";
                    return FileSystemEntryKind2;
                })(FileSystemEntryKind || {});
                sys = (() => {
                    const byteOrderMarkIndicator = "\uFEFF";
                    function getNodeSystem() {
                        const nativePattern = /^native |^\([^)]+\)$|^(internal[\\/]|[a-zA-Z0-9_\s]+(\.js)?$)/;
                        const _fs = require("fs");
                        const _path = require("path");
                        const _os = require("os");
                        let _crypto;
                        try {
                            _crypto = require("crypto");
                        }
                        catch {
                            _crypto = void 0;
                        }
                        let activeSession;
                        let profilePath = "./profile.cpuprofile";
                        const Buffer2 = require("buffer").Buffer;
                        const isMacOs = process.platform === "darwin";
                        const isLinuxOrMacOs = process.platform === "linux" || isMacOs;
                        const platform = _os.platform();
                        const useCaseSensitiveFileNames2 = isFileSystemCaseSensitive();
                        const fsRealpath = !!_fs.realpathSync.native ? process.platform === "win32" ? fsRealPathHandlingLongPath : _fs.realpathSync.native : _fs.realpathSync;
                        const executingFilePath = __filename.endsWith("sys.js") ? _path.join(_path.dirname(__dirname), "__fake__.js") : __filename;
                        const fsSupportsRecursiveFsWatch = process.platform === "win32" || isMacOs;
                        const getCurrentDirectory = memoize(() => process.cwd());
                        const { watchFile: watchFile2, watchDirectory } = createSystemWatchFunctions({
                            pollingWatchFileWorker: fsWatchFileWorker,
                            getModifiedTime: getModifiedTime3,
                            setTimeout,
                            clearTimeout,
                            fsWatchWorker,
                            useCaseSensitiveFileNames: useCaseSensitiveFileNames2,
                            getCurrentDirectory,
                            fileSystemEntryExists,
                            // Node 4.0 `fs.watch` function supports the "recursive" option on both OSX and Windows
                            // (ref: https://github.com/nodejs/node/pull/2649 and https://github.com/Microsoft/TypeScript/issues/4643)
                            fsSupportsRecursiveFsWatch,
                            getAccessibleSortedChildDirectories: (path) => getAccessibleFileSystemEntries(path).directories,
                            realpath,
                            tscWatchFile: process.env.TSC_WATCHFILE,
                            useNonPollingWatchers: !!process.env.TSC_NONPOLLING_WATCHER,
                            tscWatchDirectory: process.env.TSC_WATCHDIRECTORY,
                            inodeWatching: isLinuxOrMacOs,
                            fsWatchWithTimestamp: isMacOs,
                            sysLog
                        });
                        const nodeSystem = {
                            args: process.argv.slice(2),
                            newLine: _os.EOL,
                            useCaseSensitiveFileNames: useCaseSensitiveFileNames2,
                            write(s) {
                                process.stdout.write(s);
                            },
                            getWidthOfTerminal() {
                                return process.stdout.columns;
                            },
                            writeOutputIsTTY() {
                                return process.stdout.isTTY;
                            },
                            readFile,
                            writeFile: writeFile2,
                            watchFile: watchFile2,
                            watchDirectory,
                            resolvePath: (path) => _path.resolve(path),
                            fileExists,
                            directoryExists,
                            getAccessibleFileSystemEntries,
                            createDirectory(directoryName) {
                                if (!nodeSystem.directoryExists(directoryName)) {
                                    try {
                                        _fs.mkdirSync(directoryName);
                                    }
                                    catch (e) {
                                        if (e.code !== "EEXIST") {
                                            throw e;
                                        }
                                    }
                                }
                            },
                            getExecutingFilePath() {
                                return executingFilePath;
                            },
                            getCurrentDirectory,
                            getDirectories,
                            getEnvironmentVariable(name) {
                                return process.env[name] || "";
                            },
                            readDirectory,
                            getModifiedTime: getModifiedTime3,
                            setModifiedTime,
                            deleteFile,
                            createHash: _crypto ? createSHA256Hash : generateDjb2Hash,
                            createSHA256Hash: _crypto ? createSHA256Hash : void 0,
                            getMemoryUsage() {
                                if (global.gc) {
                                    global.gc();
                                }
                                return process.memoryUsage().heapUsed;
                            },
                            getFileSize(path) {
                                try {
                                    const stat = statSync(path);
                                    if (stat == null ? void 0 : stat.isFile()) {
                                        return stat.size;
                                    }
                                }
                                catch {
                                }
                                return 0;
                            },
                            exit(exitCode) {
                                disableCPUProfiler(() => process.exit(exitCode));
                            },
                            enableCPUProfiler,
                            disableCPUProfiler,
                            cpuProfilingEnabled: () => !!activeSession || contains(process.execArgv, "--cpu-prof") || contains(process.execArgv, "--prof"),
                            realpath,
                            debugMode: !!process.env.NODE_INSPECTOR_IPC || !!process.env.VSCODE_INSPECTOR_OPTIONS || some(process.execArgv, (arg) => /^--(inspect|debug)(-brk)?(=\d+)?$/i.test(arg)) || !!process.recordreplay,
                            tryEnableSourceMapsForHost() {
                                try {
                                    require(22) /* source-map-support */.install();
                                }
                                catch {
                                }
                            },
                            setTimeout,
                            clearTimeout,
                            clearScreen: () => {
                                process.stdout.write("\x1Bc");
                            },
                            setBlocking: () => {
                                var _a;
                                const handle = (_a = process.stdout) == null ? void 0 : _a._handle;
                                if (handle && handle.setBlocking) {
                                    handle.setBlocking(true);
                                }
                            },
                            bufferFrom,
                            base64decode: (input) => bufferFrom(input, "base64").toString("utf8"),
                            base64encode: (input) => bufferFrom(input).toString("base64"),
                            require: (baseDir, moduleName) => {
                                try {
                                    const modulePath = resolveJSModule(moduleName, baseDir, nodeSystem);
                                    return { module: require(modulePath), modulePath, error: void 0 };
                                }
                                catch (error2) {
                                    return { module: void 0, modulePath: void 0, error: error2 };
                                }
                            }
                        };
                        return nodeSystem;
                        function statSync(path) {
                            return _fs.statSync(path, { throwIfNoEntry: false });
                        }
                        function enableCPUProfiler(path, cb) {
                            if (activeSession) {
                                cb();
                                return false;
                            }
                            const inspector = require("inspector");
                            if (!inspector || !inspector.Session) {
                                cb();
                                return false;
                            }
                            const session = new inspector.Session();
                            session.connect();
                            session.post("Profiler.enable", () => {
                                session.post("Profiler.start", () => {
                                    activeSession = session;
                                    profilePath = path;
                                    cb();
                                });
                            });
                            return true;
                        }
                        function cleanupPaths(profile) {
                            let externalFileCounter = 0;
                            const remappedPaths = /* @__PURE__ */ new Map();
                            const normalizedDir = normalizeSlashes(_path.dirname(executingFilePath));
                            const fileUrlRoot = `file://${getRootLength(normalizedDir) === 1 ? "" : "/"}${normalizedDir}`;
                            for (const node of profile.nodes) {
                                if (node.callFrame.url) {
                                    const url = normalizeSlashes(node.callFrame.url);
                                    if (containsPath(fileUrlRoot, url, useCaseSensitiveFileNames2)) {
                                        node.callFrame.url = getRelativePathToDirectoryOrUrl(fileUrlRoot, url, fileUrlRoot, createGetCanonicalFileName(useCaseSensitiveFileNames2), 
                                        /*isAbsolutePathAnUrl*/
                                        true);
                                    }
                                    else if (!nativePattern.test(url)) {
                                        node.callFrame.url = (remappedPaths.has(url) ? remappedPaths : remappedPaths.set(url, `external${externalFileCounter}.js`)).get(url);
                                        externalFileCounter++;
                                    }
                                }
                            }
                            return profile;
                        }
                        function disableCPUProfiler(cb) {
                            if (activeSession && activeSession !== "stopping") {
                                const s = activeSession;
                                activeSession.post("Profiler.stop", (err, { profile }) => {
                                    var _a;
                                    if (!err) {
                                        try {
                                            if ((_a = statSync(profilePath)) == null ? void 0 : _a.isDirectory()) {
                                                profilePath = _path.join(profilePath, `${( /* @__PURE__ */new Date()).toISOString().replace(/:/g, "-")}+P${process.pid}.cpuprofile`);
                                            }
                                        }
                                        catch {
                                        }
                                        try {
                                            _fs.mkdirSync(_path.dirname(profilePath), { recursive: true });
                                        }
                                        catch {
                                        }
                                        _fs.writeFileSync(profilePath, JSON.stringify(cleanupPaths(profile)));
                                    }
                                    activeSession = void 0;
                                    s.disconnect();
                                    cb();
                                });
                                activeSession = "stopping";
                                return true;
                            }
                            else {
                                cb();
                                return false;
                            }
                        }
                        function bufferFrom(input, encoding) {
                            return Buffer2.from && Buffer2.from !== Int8Array.from ? Buffer2.from(input, encoding) : new Buffer2(input, encoding);
                        }
                        function isFileSystemCaseSensitive() {
                            if (platform === "win32" || platform === "win64") {
                                return false;
                            }
                            return !fileExists(swapCase(__filename));
                        }
                        function swapCase(s) {
                            return s.replace(/\w/g, (ch) => {
                                const up = ch.toUpperCase();
                                return ch === up ? ch.toLowerCase() : up;
                            });
                        }
                        function fsWatchFileWorker(fileName, callback, pollingInterval) {
                            _fs.watchFile(fileName, { persistent: true, interval: pollingInterval }, fileChanged);
                            let eventKind;
                            return {
                                close: () => _fs.unwatchFile(fileName, fileChanged)
                            };
                            function fileChanged(curr, prev) {
                                const isPreviouslyDeleted = +prev.mtime === 0 || eventKind === 2 /* Deleted */;
                                if (+curr.mtime === 0) {
                                    if (isPreviouslyDeleted) {
                                        return;
                                    }
                                    eventKind = 2 /* Deleted */;
                                }
                                else if (isPreviouslyDeleted) {
                                    eventKind = 0 /* Created */;
                                }
                                else if (+curr.mtime === +prev.mtime) {
                                    return;
                                }
                                else {
                                    eventKind = 1 /* Changed */;
                                }
                                callback(fileName, eventKind, curr.mtime);
                            }
                        }
                        function fsWatchWorker(fileOrDirectory, recursive, callback) {
                            return _fs.watch(fileOrDirectory, fsSupportsRecursiveFsWatch ? { persistent: true, recursive: !!recursive } : { persistent: true }, callback);
                        }
                        function readFileWorker(fileName, _encoding) {
                            let buffer;
                            try {
                                buffer = _fs.readFileSync(fileName);
                            }
                            catch (e) {
                                return void 0;
                            }
                            let len = buffer.length;
                            if (len >= 2 && buffer[0] === 254 && buffer[1] === 255) {
                                len &= ~1;
                                for (let i = 0; i < len; i += 2) {
                                    const temp = buffer[i];
                                    buffer[i] = buffer[i + 1];
                                    buffer[i + 1] = temp;
                                }
                                return buffer.toString("utf16le", 2);
                            }
                            if (len >= 2 && buffer[0] === 255 && buffer[1] === 254) {
                                return buffer.toString("utf16le", 2);
                            }
                            if (len >= 3 && buffer[0] === 239 && buffer[1] === 187 && buffer[2] === 191) {
                                return buffer.toString("utf8", 3);
                            }
                            return buffer.toString("utf8");
                        }
                        function readFile(fileName, _encoding) {
                            var _a, _b;
                            (_a = perfLogger) == null ? void 0 : _a.logStartReadFile(fileName);
                            const file = readFileWorker(fileName, _encoding);
                            (_b = perfLogger) == null ? void 0 : _b.logStopReadFile();
                            return file;
                        }
                        function writeFile2(fileName, data, writeByteOrderMark) {
                            var _a;
                            (_a = perfLogger) == null ? void 0 : _a.logEvent("WriteFile: " + fileName);
                            if (writeByteOrderMark) {
                                data = byteOrderMarkIndicator + data;
                            }
                            let fd;
                            try {
                                fd = _fs.openSync(fileName, "w");
                                _fs.writeSync(fd, data, 
                                /*position*/
                                void 0, "utf8");
                            }
                            finally {
                                if (fd !== void 0) {
                                    _fs.closeSync(fd);
                                }
                            }
                        }
                        function getAccessibleFileSystemEntries(path) {
                            var _a;
                            (_a = perfLogger) == null ? void 0 : _a.logEvent("ReadDir: " + (path || "."));
                            try {
                                const entries = _fs.readdirSync(path || ".", { withFileTypes: true });
                                const files = [];
                                const directories = [];
                                for (const dirent of entries) {
                                    const entry = typeof dirent === "string" ? dirent : dirent.name;
                                    if (entry === "." || entry === "..") {
                                        continue;
                                    }
                                    let stat;
                                    if (typeof dirent === "string" || dirent.isSymbolicLink()) {
                                        const name = combinePaths(path, entry);
                                        try {
                                            stat = statSync(name);
                                            if (!stat) {
                                                continue;
                                            }
                                        }
                                        catch (e) {
                                            continue;
                                        }
                                    }
                                    else {
                                        stat = dirent;
                                    }
                                    if (stat.isFile()) {
                                        files.push(entry);
                                    }
                                    else if (stat.isDirectory()) {
                                        directories.push(entry);
                                    }
                                }
                                files.sort();
                                directories.sort();
                                return { files, directories };
                            }
                            catch (e) {
                                return emptyFileSystemEntries;
                            }
                        }
                        function readDirectory(path, extensions, excludes, includes, depth) {
                            return matchFiles(path, extensions, excludes, includes, useCaseSensitiveFileNames2, process.cwd(), depth, getAccessibleFileSystemEntries, realpath);
                        }
                        function fileSystemEntryExists(path, entryKind) {
                            const originalStackTraceLimit = Error.stackTraceLimit;
                            Error.stackTraceLimit = 0;
                            try {
                                const stat = statSync(path);
                                if (!stat) {
                                    return false;
                                }
                                switch (entryKind) {
                                    case 0 /* File */:
                                        return stat.isFile();
                                    case 1 /* Directory */:
                                        return stat.isDirectory();
                                    default:
                                        return false;
                                }
                            }
                            catch (e) {
                                return false;
                            }
                            finally {
                                Error.stackTraceLimit = originalStackTraceLimit;
                            }
                        }
                        function fileExists(path) {
                            return fileSystemEntryExists(path, 0 /* File */);
                        }
                        function directoryExists(path) {
                            return fileSystemEntryExists(path, 1 /* Directory */);
                        }
                        function getDirectories(path) {
                            return getAccessibleFileSystemEntries(path).directories.slice();
                        }
                        function fsRealPathHandlingLongPath(path) {
                            return path.length < 260 ? _fs.realpathSync.native(path) : _fs.realpathSync(path);
                        }
                        function realpath(path) {
                            try {
                                return fsRealpath(path);
                            }
                            catch {
                                return path;
                            }
                        }
                        function getModifiedTime3(path) {
                            var _a;
                            const originalStackTraceLimit = Error.stackTraceLimit;
                            Error.stackTraceLimit = 0;
                            try {
                                return (_a = statSync(path)) == null ? void 0 : _a.mtime;
                            }
                            catch (e) {
                                return void 0;
                            }
                            finally {
                                Error.stackTraceLimit = originalStackTraceLimit;
                            }
                        }
                        function setModifiedTime(path, time) {
                            try {
                                _fs.utimesSync(path, time, time);
                            }
                            catch (e) {
                                return;
                            }
                        }
                        function deleteFile(path) {
                            try {
                                return _fs.unlinkSync(path);
                            }
                            catch (e) {
                                return;
                            }
                        }
                        function createSHA256Hash(data) {
                            const hash = _crypto.createHash("sha256");
                            hash.update(data);
                            return hash.digest("hex");
                        }
                    }
                    let sys2;
                    if (isNodeLikeSystem()) {
                        sys2 = getNodeSystem();
                    }
                    if (sys2) {
                        patchWriteFileEnsuringDirectory(sys2);
                    }
                    return sys2;
                })();
                if (sys && sys.getEnvironmentVariable) {
                    setCustomPollingValues(sys);
                    Debug.setAssertionLevel(/^development$/i.test(sys.getEnvironmentVariable("NODE_ENV")) ? 1 /* Normal */ : 0 /* None */);
                }
                if (sys && sys.debugMode) {
                    Debug.isDebugging = true;
                }
            }
        });
        // src/compiler/path.ts
        function isAnyDirectorySeparator(charCode) {
            return charCode === 47 /* slash */ || charCode === 92 /* backslash */;
        }
        function isUrl(path) {
            return getEncodedRootLength(path) < 0;
        }
        function isRootedDiskPath(path) {
            return getEncodedRootLength(path) > 0;
        }
        function isDiskPathRoot(path) {
            const rootLength = getEncodedRootLength(path);
            return rootLength > 0 && rootLength === path.length;
        }
        function pathIsAbsolute(path) {
            return getEncodedRootLength(path) !== 0;
        }
        function pathIsRelative(path) {
            return /^\.\.?($|[\\/])/.test(path);
        }
        function pathIsBareSpecifier(path) {
            return !pathIsAbsolute(path) && !pathIsRelative(path);
        }
        function hasExtension(fileName) {
            return getBaseFileName(fileName).includes(".");
        }
        function fileExtensionIs(path, extension) {
            return path.length > extension.length && endsWith(path, extension);
        }
        function fileExtensionIsOneOf(path, extensions) {
            for (const extension of extensions) {
                if (fileExtensionIs(path, extension)) {
                    return true;
                }
            }
            return false;
        }
        function hasTrailingDirectorySeparator(path) {
            return path.length > 0 && isAnyDirectorySeparator(path.charCodeAt(path.length - 1));
        }
        function isVolumeCharacter(charCode) {
            return charCode >= 97 /* a */ && charCode <= 122 /* z */ || charCode >= 65 /* A */ && charCode <= 90 /* Z */;
        }
        function getFileUrlVolumeSeparatorEnd(url, start) {
            const ch0 = url.charCodeAt(start);
            if (ch0 === 58 /* colon */)
                return start + 1;
            if (ch0 === 37 /* percent */ && url.charCodeAt(start + 1) === 51 /* _3 */) {
                const ch2 = url.charCodeAt(start + 2);
                if (ch2 === 97 /* a */ || ch2 === 65 /* A */)
                    return start + 3;
            }
            return -1;
        }
        function getEncodedRootLength(path) {
            if (!path)
                return 0;
            const ch0 = path.charCodeAt(0);
            if (ch0 === 47 /* slash */ || ch0 === 92 /* backslash */) {
                if (path.charCodeAt(1) !== ch0)
                    return 1;
                const p1 = path.indexOf(ch0 === 47 /* slash */ ? directorySeparator : altDirectorySeparator, 2);
                if (p1 < 0)
                    return path.length;
                return p1 + 1;
            }
            if (isVolumeCharacter(ch0) && path.charCodeAt(1) === 58 /* colon */) {
                const ch2 = path.charCodeAt(2);
                if (ch2 === 47 /* slash */ || ch2 === 92 /* backslash */)
                    return 3;
                if (path.length === 2)
                    return 2;
            }
            const schemeEnd = path.indexOf(urlSchemeSeparator);
            if (schemeEnd !== -1) {
                const authorityStart = schemeEnd + urlSchemeSeparator.length;
                const authorityEnd = path.indexOf(directorySeparator, authorityStart);
                if (authorityEnd !== -1) {
                    const scheme = path.slice(0, schemeEnd);
                    const authority = path.slice(authorityStart, authorityEnd);
                    if (scheme === "file" && (authority === "" || authority === "localhost") && isVolumeCharacter(path.charCodeAt(authorityEnd + 1))) {
                        const volumeSeparatorEnd = getFileUrlVolumeSeparatorEnd(path, authorityEnd + 2);
                        if (volumeSeparatorEnd !== -1) {
                            if (path.charCodeAt(volumeSeparatorEnd) === 47 /* slash */) {
                                return ~(volumeSeparatorEnd + 1);
                            }
                            if (volumeSeparatorEnd === path.length) {
                                return ~volumeSeparatorEnd;
                            }
                        }
                    }
                    return ~(authorityEnd + 1);
                }
                return ~path.length;
            }
            return 0;
        }
        function getRootLength(path) {
            const rootLength = getEncodedRootLength(path);
            return rootLength < 0 ? ~rootLength : rootLength;
        }
        function getDirectoryPath(path) {
            path = normalizeSlashes(path);
            const rootLength = getRootLength(path);
            if (rootLength === path.length)
                return path;
            path = removeTrailingDirectorySeparator(path);
            return path.slice(0, Math.max(rootLength, path.lastIndexOf(directorySeparator)));
        }
        function getBaseFileName(path, extensions, ignoreCase) {
            path = normalizeSlashes(path);
            const rootLength = getRootLength(path);
            if (rootLength === path.length)
                return "";
            path = removeTrailingDirectorySeparator(path);
            const name = path.slice(Math.max(getRootLength(path), path.lastIndexOf(directorySeparator) + 1));
            const extension = extensions !== void 0 && ignoreCase !== void 0 ? getAnyExtensionFromPath(name, extensions, ignoreCase) : void 0;
            return extension ? name.slice(0, name.length - extension.length) : name;
        }
        function tryGetExtensionFromPath(path, extension, stringEqualityComparer) {
            if (!startsWith(extension, "."))
                extension = "." + extension;
            if (path.length >= extension.length && path.charCodeAt(path.length - extension.length) === 46 /* dot */) {
                const pathExtension = path.slice(path.length - extension.length);
                if (stringEqualityComparer(pathExtension, extension)) {
                    return pathExtension;
                }
            }
        }
        function getAnyExtensionFromPathWorker(path, extensions, stringEqualityComparer) {
            if (typeof extensions === "string") {
                return tryGetExtensionFromPath(path, extensions, stringEqualityComparer) || "";
            }
            for (const extension of extensions) {
                const result = tryGetExtensionFromPath(path, extension, stringEqualityComparer);
                if (result)
                    return result;
            }
            return "";
        }
        function getAnyExtensionFromPath(path, extensions, ignoreCase) {
            if (extensions) {
                return getAnyExtensionFromPathWorker(removeTrailingDirectorySeparator(path), extensions, ignoreCase ? equateStringsCaseInsensitive : equateStringsCaseSensitive);
            }
            const baseFileName = getBaseFileName(path);
            const extensionIndex = baseFileName.lastIndexOf(".");
            if (extensionIndex >= 0) {
                return baseFileName.substring(extensionIndex);
            }
            return "";
        }
        function pathComponents(path, rootLength) {
            const root = path.substring(0, rootLength);
            const rest = path.substring(rootLength).split(directorySeparator);
            if (rest.length && !lastOrUndefined(rest))
                rest.pop();
            return [root, ...rest];
        }
        function getPathComponents(path, currentDirectory = "") {
            path = combinePaths(currentDirectory, path);
            return pathComponents(path, getRootLength(path));
        }
        function getPathFromPathComponents(pathComponents2, length2) {
            if (pathComponents2.length === 0)
                return "";
            const root = pathComponents2[0] && ensureTrailingDirectorySeparator(pathComponents2[0]);
            return root + pathComponents2.slice(1, length2).join(directorySeparator);
        }
        function normalizeSlashes(path) {
            return path.includes("\\") ? path.replace(backslashRegExp, directorySeparator) : path;
        }
        function reducePathComponents(components) {
            if (!some(components))
                return [];
            const reduced = [components[0]];
            for (let i = 1; i < components.length; i++) {
                const component = components[i];
                if (!component)
                    continue;
                if (component === ".")
                    continue;
                if (component === "..") {
                    if (reduced.length > 1) {
                        if (reduced[reduced.length - 1] !== "..") {
                            reduced.pop();
                            continue;
                        }
                    }
                    else if (reduced[0])
                        continue;
                }
                reduced.push(component);
            }
            return reduced;
        }
        function combinePaths(path, ...paths) {
            if (path)
                path = normalizeSlashes(path);
            for (let relativePath of paths) {
                if (!relativePath)
                    continue;
                relativePath = normalizeSlashes(relativePath);
                if (!path || getRootLength(relativePath) !== 0) {
                    path = relativePath;
                }
                else {
                    path = ensureTrailingDirectorySeparator(path) + relativePath;
                }
            }
            return path;
        }
        function resolvePath(path, ...paths) {
            return normalizePath(some(paths) ? combinePaths(path, ...paths) : normalizeSlashes(path));
        }
        function getNormalizedPathComponents(path, currentDirectory) {
            return reducePathComponents(getPathComponents(path, currentDirectory));
        }
        function getNormalizedAbsolutePath(fileName, currentDirectory) {
            return getPathFromPathComponents(getNormalizedPathComponents(fileName, currentDirectory));
        }
        function normalizePath(path) {
            path = normalizeSlashes(path);
            if (!relativePathSegmentRegExp.test(path)) {
                return path;
            }
            const simplified = path.replace(/\/\.\//g, "/").replace(/^\.\//, "");
            if (simplified !== path) {
                path = simplified;
                if (!relativePathSegmentRegExp.test(path)) {
                    return path;
                }
            }
            const normalized = getPathFromPathComponents(reducePathComponents(getPathComponents(path)));
            return normalized && hasTrailingDirectorySeparator(path) ? ensureTrailingDirectorySeparator(normalized) : normalized;
        }
        function getPathWithoutRoot(pathComponents2) {
            if (pathComponents2.length === 0)
                return "";
            return pathComponents2.slice(1).join(directorySeparator);
        }
        function getNormalizedAbsolutePathWithoutRoot(fileName, currentDirectory) {
            return getPathWithoutRoot(getNormalizedPathComponents(fileName, currentDirectory));
        }
        function toPath(fileName, basePath, getCanonicalFileName) {
            const nonCanonicalizedPath = isRootedDiskPath(fileName) ? normalizePath(fileName) : getNormalizedAbsolutePath(fileName, basePath);
            return getCanonicalFileName(nonCanonicalizedPath);
        }
        function removeTrailingDirectorySeparator(path) {
            if (hasTrailingDirectorySeparator(path)) {
                return path.substr(0, path.length - 1);
            }
            return path;
        }
        function ensureTrailingDirectorySeparator(path) {
            if (!hasTrailingDirectorySeparator(path)) {
                return path + directorySeparator;
            }
            return path;
        }
        function ensurePathIsNonModuleName(path) {
            return !pathIsAbsolute(path) && !pathIsRelative(path) ? "./" + path : path;
        }
        function changeAnyExtension(path, ext, extensions, ignoreCase) {
            const pathext = extensions !== void 0 && ignoreCase !== void 0 ? getAnyExtensionFromPath(path, extensions, ignoreCase) : getAnyExtensionFromPath(path);
            return pathext ? path.slice(0, path.length - pathext.length) + (startsWith(ext, ".") ? ext : "." + ext) : path;
        }
        function changeFullExtension(path, newExtension) {
            const declarationExtension = getDeclarationFileExtension(path);
            if (declarationExtension) {
                return path.slice(0, path.length - declarationExtension.length) + (startsWith(newExtension, ".") ? newExtension : "." + newExtension);
            }
            return changeAnyExtension(path, newExtension);
        }
        function comparePathsWorker(a, b, componentComparer) {
            if (a === b)
                return 0 /* EqualTo */;
            if (a === void 0)
                return -1 /* LessThan */;
            if (b === void 0)
                return 1 /* GreaterThan */;
            const aRoot = a.substring(0, getRootLength(a));
            const bRoot = b.substring(0, getRootLength(b));
            const result = compareStringsCaseInsensitive(aRoot, bRoot);
            if (result !== 0 /* EqualTo */) {
                return result;
            }
            const aRest = a.substring(aRoot.length);
            const bRest = b.substring(bRoot.length);
            if (!relativePathSegmentRegExp.test(aRest) && !relativePathSegmentRegExp.test(bRest)) {
                return componentComparer(aRest, bRest);
            }
            const aComponents = reducePathComponents(getPathComponents(a));
            const bComponents = reducePathComponents(getPathComponents(b));
            const sharedLength = Math.min(aComponents.length, bComponents.length);
            for (let i = 1; i < sharedLength; i++) {
                const result2 = componentComparer(aComponents[i], bComponents[i]);
                if (result2 !== 0 /* EqualTo */) {
                    return result2;
                }
            }
            return compareValues(aComponents.length, bComponents.length);
        }
        function comparePathsCaseSensitive(a, b) {
            return comparePathsWorker(a, b, compareStringsCaseSensitive);
        }
        function comparePathsCaseInsensitive(a, b) {
            return comparePathsWorker(a, b, compareStringsCaseInsensitive);
        }
        function comparePaths(a, b, currentDirectory, ignoreCase) {
            if (typeof currentDirectory === "string") {
                a = combinePaths(currentDirectory, a);
                b = combinePaths(currentDirectory, b);
            }
            else if (typeof currentDirectory === "boolean") {
                ignoreCase = currentDirectory;
            }
            return comparePathsWorker(a, b, getStringComparer(ignoreCase));
        }
        function containsPath(parent2, child, currentDirectory, ignoreCase) {
            if (typeof currentDirectory === "string") {
                parent2 = combinePaths(currentDirectory, parent2);
                child = combinePaths(currentDirectory, child);
            }
            else if (typeof currentDirectory === "boolean") {
                ignoreCase = currentDirectory;
            }
            if (parent2 === void 0 || child === void 0)
                return false;
            if (parent2 === child)
                return true;
            const parentComponents = reducePathComponents(getPathComponents(parent2));
            const childComponents = reducePathComponents(getPathComponents(child));
            if (childComponents.length < parentComponents.length) {
                return false;
            }
            const componentEqualityComparer = ignoreCase ? equateStringsCaseInsensitive : equateStringsCaseSensitive;
            for (let i = 0; i < parentComponents.length; i++) {
                const equalityComparer = i === 0 ? equateStringsCaseInsensitive : componentEqualityComparer;
                if (!equalityComparer(parentComponents[i], childComponents[i])) {
                    return false;
                }
            }
            return true;
        }
        function startsWithDirectory(fileName, directoryName, getCanonicalFileName) {
            const canonicalFileName = getCanonicalFileName(fileName);
            const canonicalDirectoryName = getCanonicalFileName(directoryName);
            return startsWith(canonicalFileName, canonicalDirectoryName + "/") || startsWith(canonicalFileName, canonicalDirectoryName + "\\");
        }
        function getPathComponentsRelativeTo(from, to, stringEqualityComparer, getCanonicalFileName) {
            const fromComponents = reducePathComponents(getPathComponents(from));
            const toComponents = reducePathComponents(getPathComponents(to));
            let start;
            for (start = 0; start < fromComponents.length && start < toComponents.length; start++) {
                const fromComponent = getCanonicalFileName(fromComponents[start]);
                const toComponent = getCanonicalFileName(toComponents[start]);
                const comparer = start === 0 ? equateStringsCaseInsensitive : stringEqualityComparer;
                if (!comparer(fromComponent, toComponent))
                    break;
            }
            if (start === 0) {
                return toComponents;
            }
            const components = toComponents.slice(start);
            const relative = [];
            for (; start < fromComponents.length; start++) {
                relative.push("..");
            }
            return ["", ...relative, ...components];
        }
        function getRelativePathFromDirectory(fromDirectory, to, getCanonicalFileNameOrIgnoreCase) {
            Debug.assert(getRootLength(fromDirectory) > 0 === getRootLength(to) > 0, "Paths must either both be absolute or both be relative");
            const getCanonicalFileName = typeof getCanonicalFileNameOrIgnoreCase === "function" ? getCanonicalFileNameOrIgnoreCase : identity;
            const ignoreCase = typeof getCanonicalFileNameOrIgnoreCase === "boolean" ? getCanonicalFileNameOrIgnoreCase : false;
            const pathComponents2 = getPathComponentsRelativeTo(fromDirectory, to, ignoreCase ? equateStringsCaseInsensitive : equateStringsCaseSensitive, getCanonicalFileName);
            return getPathFromPathComponents(pathComponents2);
        }
        function convertToRelativePath(absoluteOrRelativePath, basePath, getCanonicalFileName) {
            return !isRootedDiskPath(absoluteOrRelativePath) ? absoluteOrRelativePath : getRelativePathToDirectoryOrUrl(basePath, absoluteOrRelativePath, basePath, getCanonicalFileName, 
            /*isAbsolutePathAnUrl*/
            false);
        }
        function getRelativePathFromFile(from, to, getCanonicalFileName) {
            return ensurePathIsNonModuleName(getRelativePathFromDirectory(getDirectoryPath(from), to, getCanonicalFileName));
        }
        function getRelativePathToDirectoryOrUrl(directoryPathOrUrl, relativeOrAbsolutePath, currentDirectory, getCanonicalFileName, isAbsolutePathAnUrl) {
            const pathComponents2 = getPathComponentsRelativeTo(resolvePath(currentDirectory, directoryPathOrUrl), resolvePath(currentDirectory, relativeOrAbsolutePath), equateStringsCaseSensitive, getCanonicalFileName);
            const firstComponent = pathComponents2[0];
            if (isAbsolutePathAnUrl && isRootedDiskPath(firstComponent)) {
                const prefix = firstComponent.charAt(0) === directorySeparator ? "file://" : "file:///";
                pathComponents2[0] = prefix + firstComponent;
            }
            return getPathFromPathComponents(pathComponents2);
        }
        function forEachAncestorDirectory(directory, callback) {
            while (true) {
                const result = callback(directory);
                if (result !== void 0) {
                    return result;
                }
                const parentPath = getDirectoryPath(directory);
                if (parentPath === directory) {
                    return void 0;
                }
                directory = parentPath;
            }
        }
        function isNodeModulesDirectory(dirPath) {
            return endsWith(dirPath, "/node_modules");
        }
        var directorySeparator, altDirectorySeparator, urlSchemeSeparator, backslashRegExp, relativePathSegmentRegExp;
        var init_path = __esm({
            "src/compiler/path.ts"() {
                "use strict";
                init_ts2();
                directorySeparator = "/";
                altDirectorySeparator = "\\";
                urlSchemeSeparator = "://";
                backslashRegExp = /\\/g;
                relativePathSegmentRegExp = /(?:\/\/)|(?:^|\/)\.\.?(?:$|\/)/;
            }
        });
        // src/compiler/diagnosticInformationMap.generated.ts
        function diag(code, category, key, message, reportsUnnecessary, elidedInCompatabilityPyramid, reportsDeprecated) {
            return { code, category, key, message, reportsUnnecessary, elidedInCompatabilityPyramid, reportsDeprecated };
        }
        var Diagnostics;
        var init_diagnosticInformationMap_generated = __esm({
            "src/compiler/diagnosticInformationMap.generated.ts"() {
                "use strict";
                init_types();
                Diagnostics = {
                    Unterminated_string_literal: diag(1002, 1 /* Error */, "Unterminated_string_literal_1002", "Unterminated string literal."),
                    Identifier_expected: diag(1003, 1 /* Error */, "Identifier_expected_1003", "Identifier expected."),
                    _0_expected: diag(1005, 1 /* Error */, "_0_expected_1005", "'{0}' expected."),
                    A_file_cannot_have_a_reference_to_itself: diag(1006, 1 /* Error */, "A_file_cannot_have_a_reference_to_itself_1006", "A file cannot have a reference to itself."),
                    The_parser_expected_to_find_a_1_to_match_the_0_token_here: diag(1007, 1 /* Error */, "The_parser_expected_to_find_a_1_to_match_the_0_token_here_1007", "The parser expected to find a '{1}' to match the '{0}' token here."),
                    Trailing_comma_not_allowed: diag(1009, 1 /* Error */, "Trailing_comma_not_allowed_1009", "Trailing comma not allowed."),
                    Asterisk_Slash_expected: diag(1010, 1 /* Error */, "Asterisk_Slash_expected_1010", "'*/' expected."),
                    An_element_access_expression_should_take_an_argument: diag(1011, 1 /* Error */, "An_element_access_expression_should_take_an_argument_1011", "An element access expression should take an argument."),
                    Unexpected_token: diag(1012, 1 /* Error */, "Unexpected_token_1012", "Unexpected token."),
                    A_rest_parameter_or_binding_pattern_may_not_have_a_trailing_comma: diag(1013, 1 /* Error */, "A_rest_parameter_or_binding_pattern_may_not_have_a_trailing_comma_1013", "A rest parameter or binding pattern may not have a trailing comma."),
                    A_rest_parameter_must_be_last_in_a_parameter_list: diag(1014, 1 /* Error */, "A_rest_parameter_must_be_last_in_a_parameter_list_1014", "A rest parameter must be last in a parameter list."),
                    Parameter_cannot_have_question_mark_and_initializer: diag(1015, 1 /* Error */, "Parameter_cannot_have_question_mark_and_initializer_1015", "Parameter cannot have question mark and initializer."),
                    A_required_parameter_cannot_follow_an_optional_parameter: diag(1016, 1 /* Error */, "A_required_parameter_cannot_follow_an_optional_parameter_1016", "A required parameter cannot follow an optional parameter."),
                    An_index_signature_cannot_have_a_rest_parameter: diag(1017, 1 /* Error */, "An_index_signature_cannot_have_a_rest_parameter_1017", "An index signature cannot have a rest parameter."),
                    An_index_signature_parameter_cannot_have_an_accessibility_modifier: diag(1018, 1 /* Error */, "An_index_signature_parameter_cannot_have_an_accessibility_modifier_1018", "An index signature parameter cannot have an accessibility modifier."),
                    An_index_signature_parameter_cannot_have_a_question_mark: diag(1019, 1 /* Error */, "An_index_signature_parameter_cannot_have_a_question_mark_1019", "An index signature parameter cannot have a question mark."),
                    An_index_signature_parameter_cannot_have_an_initializer: diag(1020, 1 /* Error */, "An_index_signature_parameter_cannot_have_an_initializer_1020", "An index signature parameter cannot have an initializer."),
                    An_index_signature_must_have_a_type_annotation: diag(1021, 1 /* Error */, "An_index_signature_must_have_a_type_annotation_1021", "An index signature must have a type annotation."),
                    An_index_signature_parameter_must_have_a_type_annotation: diag(1022, 1 /* Error */, "An_index_signature_parameter_must_have_a_type_annotation_1022", "An index signature parameter must have a type annotation."),
                    readonly_modifier_can_only_appear_on_a_property_declaration_or_index_signature: diag(1024, 1 /* Error */, "readonly_modifier_can_only_appear_on_a_property_declaration_or_index_signature_1024", "'readonly' modifier can only appear on a property declaration or index signature."),
                    An_index_signature_cannot_have_a_trailing_comma: diag(1025, 1 /* Error */, "An_index_signature_cannot_have_a_trailing_comma_1025", "An index signature cannot have a trailing comma."),
                    Accessibility_modifier_already_seen: diag(1028, 1 /* Error */, "Accessibility_modifier_already_seen_1028", "Accessibility modifier already seen."),
                    _0_modifier_must_precede_1_modifier: diag(1029, 1 /* Error */, "_0_modifier_must_precede_1_modifier_1029", "'{0}' modifier must precede '{1}' modifier."),
                    _0_modifier_already_seen: diag(1030, 1 /* Error */, "_0_modifier_already_seen_1030", "'{0}' modifier already seen."),
                    _0_modifier_cannot_appear_on_class_elements_of_this_kind: diag(1031, 1 /* Error */, "_0_modifier_cannot_appear_on_class_elements_of_this_kind_1031", "'{0}' modifier cannot appear on class elements of this kind."),
                    super_must_be_followed_by_an_argument_list_or_member_access: diag(1034, 1 /* Error */, "super_must_be_followed_by_an_argument_list_or_member_access_1034", "'super' must be followed by an argument list or member access."),
                    Only_ambient_modules_can_use_quoted_names: diag(1035, 1 /* Error */, "Only_ambient_modules_can_use_quoted_names_1035", "Only ambient modules can use quoted names."),
                    Statements_are_not_allowed_in_ambient_contexts: diag(1036, 1 /* Error */, "Statements_are_not_allowed_in_ambient_contexts_1036", "Statements are not allowed in ambient contexts."),
                    A_declare_modifier_cannot_be_used_in_an_already_ambient_context: diag(1038, 1 /* Error */, "A_declare_modifier_cannot_be_used_in_an_already_ambient_context_1038", "A 'declare' modifier cannot be used in an already ambient context."),
                    Initializers_are_not_allowed_in_ambient_contexts: diag(1039, 1 /* Error */, "Initializers_are_not_allowed_in_ambient_contexts_1039", "Initializers are not allowed in ambient contexts."),
                    _0_modifier_cannot_be_used_in_an_ambient_context: diag(1040, 1 /* Error */, "_0_modifier_cannot_be_used_in_an_ambient_context_1040", "'{0}' modifier cannot be used in an ambient context."),
                    _0_modifier_cannot_be_used_here: diag(1042, 1 /* Error */, "_0_modifier_cannot_be_used_here_1042", "'{0}' modifier cannot be used here."),
                    _0_modifier_cannot_appear_on_a_module_or_namespace_element: diag(1044, 1 /* Error */, "_0_modifier_cannot_appear_on_a_module_or_namespace_element_1044", "'{0}' modifier cannot appear on a module or namespace element."),
                    Top_level_declarations_in_d_ts_files_must_start_with_either_a_declare_or_export_modifier: diag(1046, 1 /* Error */, "Top_level_declarations_in_d_ts_files_must_start_with_either_a_declare_or_export_modifier_1046", "Top-level declarations in .d.ts files must start with either a 'declare' or 'export' modifier."),
                    A_rest_parameter_cannot_be_optional: diag(1047, 1 /* Error */, "A_rest_parameter_cannot_be_optional_1047", "A rest parameter cannot be optional."),
                    A_rest_parameter_cannot_have_an_initializer: diag(1048, 1 /* Error */, "A_rest_parameter_cannot_have_an_initializer_1048", "A rest parameter cannot have an initializer."),
                    A_set_accessor_must_have_exactly_one_parameter: diag(1049, 1 /* Error */, "A_set_accessor_must_have_exactly_one_parameter_1049", "A 'set' accessor must have exactly one parameter."),
                    A_set_accessor_cannot_have_an_optional_parameter: diag(1051, 1 /* Error */, "A_set_accessor_cannot_have_an_optional_parameter_1051", "A 'set' accessor cannot have an optional parameter."),
                    A_set_accessor_parameter_cannot_have_an_initializer: diag(1052, 1 /* Error */, "A_set_accessor_parameter_cannot_have_an_initializer_1052", "A 'set' accessor parameter cannot have an initializer."),
                    A_set_accessor_cannot_have_rest_parameter: diag(1053, 1 /* Error */, "A_set_accessor_cannot_have_rest_parameter_1053", "A 'set' accessor cannot have rest parameter."),
                    A_get_accessor_cannot_have_parameters: diag(1054, 1 /* Error */, "A_get_accessor_cannot_have_parameters_1054", "A 'get' accessor cannot have parameters."),
                    Type_0_is_not_a_valid_async_function_return_type_in_ES5_SlashES3_because_it_does_not_refer_to_a_Promise_compatible_constructor_value: diag(1055, 1 /* Error */, "Type_0_is_not_a_valid_async_function_return_type_in_ES5_SlashES3_because_it_does_not_refer_to_a_Prom_1055", "Type '{0}' is not a valid async function return type in ES5/ES3 because it does not refer to a Promise-compatible constructor value."),
                    Accessors_are_only_available_when_targeting_ECMAScript_5_and_higher: diag(1056, 1 /* Error */, "Accessors_are_only_available_when_targeting_ECMAScript_5_and_higher_1056", "Accessors are only available when targeting ECMAScript 5 and higher."),
                    The_return_type_of_an_async_function_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member: diag(1058, 1 /* Error */, "The_return_type_of_an_async_function_must_either_be_a_valid_promise_or_must_not_contain_a_callable_t_1058", "The return type of an async function must either be a valid promise or must not contain a callable 'then' member."),
                    A_promise_must_have_a_then_method: diag(1059, 1 /* Error */, "A_promise_must_have_a_then_method_1059", "A promise must have a 'then' method."),
                    The_first_parameter_of_the_then_method_of_a_promise_must_be_a_callback: diag(1060, 1 /* Error */, "The_first_parameter_of_the_then_method_of_a_promise_must_be_a_callback_1060", "The first parameter of the 'then' method of a promise must be a callback."),
                    Enum_member_must_have_initializer: diag(1061, 1 /* Error */, "Enum_member_must_have_initializer_1061", "Enum member must have initializer."),
                    Type_is_referenced_directly_or_indirectly_in_the_fulfillment_callback_of_its_own_then_method: diag(1062, 1 /* Error */, "Type_is_referenced_directly_or_indirectly_in_the_fulfillment_callback_of_its_own_then_method_1062", "Type is referenced directly or indirectly in the fulfillment callback of its own 'then' method."),
                    An_export_assignment_cannot_be_used_in_a_namespace: diag(1063, 1 /* Error */, "An_export_assignment_cannot_be_used_in_a_namespace_1063", "An export assignment cannot be used in a namespace."),
                    The_return_type_of_an_async_function_or_method_must_be_the_global_Promise_T_type_Did_you_mean_to_write_Promise_0: diag(1064, 1 /* Error */, "The_return_type_of_an_async_function_or_method_must_be_the_global_Promise_T_type_Did_you_mean_to_wri_1064", "The return type of an async function or method must be the global Promise<T> type. Did you mean to write 'Promise<{0}>'?"),
                    The_return_type_of_an_async_function_or_method_must_be_the_global_Promise_T_type: diag(1065, 1 /* Error */, "The_return_type_of_an_async_function_or_method_must_be_the_global_Promise_T_type_1065", "The return type of an async function or method must be the global Promise<T> type."),
                    In_ambient_enum_declarations_member_initializer_must_be_constant_expression: diag(1066, 1 /* Error */, "In_ambient_enum_declarations_member_initializer_must_be_constant_expression_1066", "In ambient enum declarations member initializer must be constant expression."),
                    Unexpected_token_A_constructor_method_accessor_or_property_was_expected: diag(1068, 1 /* Error */, "Unexpected_token_A_constructor_method_accessor_or_property_was_expected_1068", "Unexpected token. A constructor, method, accessor, or property was expected."),
                    Unexpected_token_A_type_parameter_name_was_expected_without_curly_braces: diag(1069, 1 /* Error */, "Unexpected_token_A_type_parameter_name_was_expected_without_curly_braces_1069", "Unexpected token. A type parameter name was expected without curly braces."),
                    _0_modifier_cannot_appear_on_a_type_member: diag(1070, 1 /* Error */, "_0_modifier_cannot_appear_on_a_type_member_1070", "'{0}' modifier cannot appear on a type member."),
                    _0_modifier_cannot_appear_on_an_index_signature: diag(1071, 1 /* Error */, "_0_modifier_cannot_appear_on_an_index_signature_1071", "'{0}' modifier cannot appear on an index signature."),
                    A_0_modifier_cannot_be_used_with_an_import_declaration: diag(1079, 1 /* Error */, "A_0_modifier_cannot_be_used_with_an_import_declaration_1079", "A '{0}' modifier cannot be used with an import declaration."),
                    Invalid_reference_directive_syntax: diag(1084, 1 /* Error */, "Invalid_reference_directive_syntax_1084", "Invalid 'reference' directive syntax."),
                    _0_modifier_cannot_appear_on_a_constructor_declaration: diag(1089, 1 /* Error */, "_0_modifier_cannot_appear_on_a_constructor_declaration_1089", "'{0}' modifier cannot appear on a constructor declaration."),
                    _0_modifier_cannot_appear_on_a_parameter: diag(1090, 1 /* Error */, "_0_modifier_cannot_appear_on_a_parameter_1090", "'{0}' modifier cannot appear on a parameter."),
                    Only_a_single_variable_declaration_is_allowed_in_a_for_in_statement: diag(1091, 1 /* Error */, "Only_a_single_variable_declaration_is_allowed_in_a_for_in_statement_1091", "Only a single variable declaration is allowed in a 'for...in' statement."),
                    Type_parameters_cannot_appear_on_a_constructor_declaration: diag(1092, 1 /* Error */, "Type_parameters_cannot_appear_on_a_constructor_declaration_1092", "Type parameters cannot appear on a constructor declaration."),
                    Type_annotation_cannot_appear_on_a_constructor_declaration: diag(1093, 1 /* Error */, "Type_annotation_cannot_appear_on_a_constructor_declaration_1093", "Type annotation cannot appear on a constructor declaration."),
                    An_accessor_cannot_have_type_parameters: diag(1094, 1 /* Error */, "An_accessor_cannot_have_type_parameters_1094", "An accessor cannot have type parameters."),
                    A_set_accessor_cannot_have_a_return_type_annotation: diag(1095, 1 /* Error */, "A_set_accessor_cannot_have_a_return_type_annotation_1095", "A 'set' accessor cannot have a return type annotation."),
                    An_index_signature_must_have_exactly_one_parameter: diag(1096, 1 /* Error */, "An_index_signature_must_have_exactly_one_parameter_1096", "An index signature must have exactly one parameter."),
                    _0_list_cannot_be_empty: diag(1097, 1 /* Error */, "_0_list_cannot_be_empty_1097", "'{0}' list cannot be empty."),
                    Type_parameter_list_cannot_be_empty: diag(1098, 1 /* Error */, "Type_parameter_list_cannot_be_empty_1098", "Type parameter list cannot be empty."),
                    Type_argument_list_cannot_be_empty: diag(1099, 1 /* Error */, "Type_argument_list_cannot_be_empty_1099", "Type argument list cannot be empty."),
                    Invalid_use_of_0_in_strict_mode: diag(1100, 1 /* Error */, "Invalid_use_of_0_in_strict_mode_1100", "Invalid use of '{0}' in strict mode."),
                    with_statements_are_not_allowed_in_strict_mode: diag(1101, 1 /* Error */, "with_statements_are_not_allowed_in_strict_mode_1101", "'with' statements are not allowed in strict mode."),
                    delete_cannot_be_called_on_an_identifier_in_strict_mode: diag(1102, 1 /* Error */, "delete_cannot_be_called_on_an_identifier_in_strict_mode_1102", "'delete' cannot be called on an identifier in strict mode."),
                    for_await_loops_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules: diag(1103, 1 /* Error */, "for_await_loops_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules_1103", "'for await' loops are only allowed within async functions and at the top levels of modules."),
                    A_continue_statement_can_only_be_used_within_an_enclosing_iteration_statement: diag(1104, 1 /* Error */, "A_continue_statement_can_only_be_used_within_an_enclosing_iteration_statement_1104", "A 'continue' statement can only be used within an enclosing iteration statement."),
                    A_break_statement_can_only_be_used_within_an_enclosing_iteration_or_switch_statement: diag(1105, 1 /* Error */, "A_break_statement_can_only_be_used_within_an_enclosing_iteration_or_switch_statement_1105", "A 'break' statement can only be used within an enclosing iteration or switch statement."),
                    The_left_hand_side_of_a_for_of_statement_may_not_be_async: diag(1106, 1 /* Error */, "The_left_hand_side_of_a_for_of_statement_may_not_be_async_1106", "The left-hand side of a 'for...of' statement may not be 'async'."),
                    Jump_target_cannot_cross_function_boundary: diag(1107, 1 /* Error */, "Jump_target_cannot_cross_function_boundary_1107", "Jump target cannot cross function boundary."),
                    A_return_statement_can_only_be_used_within_a_function_body: diag(1108, 1 /* Error */, "A_return_statement_can_only_be_used_within_a_function_body_1108", "A 'return' statement can only be used within a function body."),
                    Expression_expected: diag(1109, 1 /* Error */, "Expression_expected_1109", "Expression expected."),
                    Type_expected: diag(1110, 1 /* Error */, "Type_expected_1110", "Type expected."),
                    Private_field_0_must_be_declared_in_an_enclosing_class: diag(1111, 1 /* Error */, "Private_field_0_must_be_declared_in_an_enclosing_class_1111", "Private field '{0}' must be declared in an enclosing class."),
                    A_default_clause_cannot_appear_more_than_once_in_a_switch_statement: diag(1113, 1 /* Error */, "A_default_clause_cannot_appear_more_than_once_in_a_switch_statement_1113", "A 'default' clause cannot appear more than once in a 'switch' statement."),
                    Duplicate_label_0: diag(1114, 1 /* Error */, "Duplicate_label_0_1114", "Duplicate label '{0}'."),
                    A_continue_statement_can_only_jump_to_a_label_of_an_enclosing_iteration_statement: diag(1115, 1 /* Error */, "A_continue_statement_can_only_jump_to_a_label_of_an_enclosing_iteration_statement_1115", "A 'continue' statement can only jump to a label of an enclosing iteration statement."),
                    A_break_statement_can_only_jump_to_a_label_of_an_enclosing_statement: diag(1116, 1 /* Error */, "A_break_statement_can_only_jump_to_a_label_of_an_enclosing_statement_1116", "A 'break' statement can only jump to a label of an enclosing statement."),
                    An_object_literal_cannot_have_multiple_properties_with_the_same_name: diag(1117, 1 /* Error */, "An_object_literal_cannot_have_multiple_properties_with_the_same_name_1117", "An object literal cannot have multiple properties with the same name."),
                    An_object_literal_cannot_have_multiple_get_Slashset_accessors_with_the_same_name: diag(1118, 1 /* Error */, "An_object_literal_cannot_have_multiple_get_Slashset_accessors_with_the_same_name_1118", "An object literal cannot have multiple get/set accessors with the same name."),
                    An_object_literal_cannot_have_property_and_accessor_with_the_same_name: diag(1119, 1 /* Error */, "An_object_literal_cannot_have_property_and_accessor_with_the_same_name_1119", "An object literal cannot have property and accessor with the same name."),
                    An_export_assignment_cannot_have_modifiers: diag(1120, 1 /* Error */, "An_export_assignment_cannot_have_modifiers_1120", "An export assignment cannot have modifiers."),
                    Octal_literals_are_not_allowed_Use_the_syntax_0: diag(1121, 1 /* Error */, "Octal_literals_are_not_allowed_Use_the_syntax_0_1121", "Octal literals are not allowed. Use the syntax '{0}'."),
                    Variable_declaration_list_cannot_be_empty: diag(1123, 1 /* Error */, "Variable_declaration_list_cannot_be_empty_1123", "Variable declaration list cannot be empty."),
                    Digit_expected: diag(1124, 1 /* Error */, "Digit_expected_1124", "Digit expected."),
                    Hexadecimal_digit_expected: diag(1125, 1 /* Error */, "Hexadecimal_digit_expected_1125", "Hexadecimal digit expected."),
                    Unexpected_end_of_text: diag(1126, 1 /* Error */, "Unexpected_end_of_text_1126", "Unexpected end of text."),
                    Invalid_character: diag(1127, 1 /* Error */, "Invalid_character_1127", "Invalid character."),
                    Declaration_or_statement_expected: diag(1128, 1 /* Error */, "Declaration_or_statement_expected_1128", "Declaration or statement expected."),
                    Statement_expected: diag(1129, 1 /* Error */, "Statement_expected_1129", "Statement expected."),
                    case_or_default_expected: diag(1130, 1 /* Error */, "case_or_default_expected_1130", "'case' or 'default' expected."),
                    Property_or_signature_expected: diag(1131, 1 /* Error */, "Property_or_signature_expected_1131", "Property or signature expected."),
                    Enum_member_expected: diag(1132, 1 /* Error */, "Enum_member_expected_1132", "Enum member expected."),
                    Variable_declaration_expected: diag(1134, 1 /* Error */, "Variable_declaration_expected_1134", "Variable declaration expected."),
                    Argument_expression_expected: diag(1135, 1 /* Error */, "Argument_expression_expected_1135", "Argument expression expected."),
                    Property_assignment_expected: diag(1136, 1 /* Error */, "Property_assignment_expected_1136", "Property assignment expected."),
                    Expression_or_comma_expected: diag(1137, 1 /* Error */, "Expression_or_comma_expected_1137", "Expression or comma expected."),
                    Parameter_declaration_expected: diag(1138, 1 /* Error */, "Parameter_declaration_expected_1138", "Parameter declaration expected."),
                    Type_parameter_declaration_expected: diag(1139, 1 /* Error */, "Type_parameter_declaration_expected_1139", "Type parameter declaration expected."),
                    Type_argument_expected: diag(1140, 1 /* Error */, "Type_argument_expected_1140", "Type argument expected."),
                    String_literal_expected: diag(1141, 1 /* Error */, "String_literal_expected_1141", "String literal expected."),
                    Line_break_not_permitted_here: diag(1142, 1 /* Error */, "Line_break_not_permitted_here_1142", "Line break not permitted here."),
                    or_expected: diag(1144, 1 /* Error */, "or_expected_1144", "'{' or ';' expected."),
                    or_JSX_element_expected: diag(1145, 1 /* Error */, "or_JSX_element_expected_1145", "'{' or JSX element expected."),
                    Declaration_expected: diag(1146, 1 /* Error */, "Declaration_expected_1146", "Declaration expected."),
                    Import_declarations_in_a_namespace_cannot_reference_a_module: diag(1147, 1 /* Error */, "Import_declarations_in_a_namespace_cannot_reference_a_module_1147", "Import declarations in a namespace cannot reference a module."),
                    Cannot_use_imports_exports_or_module_augmentations_when_module_is_none: diag(1148, 1 /* Error */, "Cannot_use_imports_exports_or_module_augmentations_when_module_is_none_1148", "Cannot use imports, exports, or module augmentations when '--module' is 'none'."),
                    File_name_0_differs_from_already_included_file_name_1_only_in_casing: diag(1149, 1 /* Error */, "File_name_0_differs_from_already_included_file_name_1_only_in_casing_1149", "File name '{0}' differs from already included file name '{1}' only in casing."),
                    _0_declarations_must_be_initialized: diag(1155, 1 /* Error */, "_0_declarations_must_be_initialized_1155", "'{0}' declarations must be initialized."),
                    _0_declarations_can_only_be_declared_inside_a_block: diag(1156, 1 /* Error */, "_0_declarations_can_only_be_declared_inside_a_block_1156", "'{0}' declarations can only be declared inside a block."),
                    Unterminated_template_literal: diag(1160, 1 /* Error */, "Unterminated_template_literal_1160", "Unterminated template literal."),
                    Unterminated_regular_expression_literal: diag(1161, 1 /* Error */, "Unterminated_regular_expression_literal_1161", "Unterminated regular expression literal."),
                    An_object_member_cannot_be_declared_optional: diag(1162, 1 /* Error */, "An_object_member_cannot_be_declared_optional_1162", "An object member cannot be declared optional."),
                    A_yield_expression_is_only_allowed_in_a_generator_body: diag(1163, 1 /* Error */, "A_yield_expression_is_only_allowed_in_a_generator_body_1163", "A 'yield' expression is only allowed in a generator body."),
                    Computed_property_names_are_not_allowed_in_enums: diag(1164, 1 /* Error */, "Computed_property_names_are_not_allowed_in_enums_1164", "Computed property names are not allowed in enums."),
                    A_computed_property_name_in_an_ambient_context_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type: diag(1165, 1 /* Error */, "A_computed_property_name_in_an_ambient_context_must_refer_to_an_expression_whose_type_is_a_literal_t_1165", "A computed property name in an ambient context must refer to an expression whose type is a literal type or a 'unique symbol' type."),
                    A_computed_property_name_in_a_class_property_declaration_must_have_a_simple_literal_type_or_a_unique_symbol_type: diag(1166, 1 /* Error */, "A_computed_property_name_in_a_class_property_declaration_must_have_a_simple_literal_type_or_a_unique_1166", "A computed property name in a class property declaration must have a simple literal type or a 'unique symbol' type."),
                    A_computed_property_name_in_a_method_overload_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type: diag(1168, 1 /* Error */, "A_computed_property_name_in_a_method_overload_must_refer_to_an_expression_whose_type_is_a_literal_ty_1168", "A computed property name in a method overload must refer to an expression whose type is a literal type or a 'unique symbol' type."),
                    A_computed_property_name_in_an_interface_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type: diag(1169, 1 /* Error */, "A_computed_property_name_in_an_interface_must_refer_to_an_expression_whose_type_is_a_literal_type_or_1169", "A computed property name in an interface must refer to an expression whose type is a literal type or a 'unique symbol' type."),
                    A_computed_property_name_in_a_type_literal_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type: diag(1170, 1 /* Error */, "A_computed_property_name_in_a_type_literal_must_refer_to_an_expression_whose_type_is_a_literal_type__1170", "A computed property name in a type literal must refer to an expression whose type is a literal type or a 'unique symbol' type."),
                    A_comma_expression_is_not_allowed_in_a_computed_property_name: diag(1171, 1 /* Error */, "A_comma_expression_is_not_allowed_in_a_computed_property_name_1171", "A comma expression is not allowed in a computed property name."),
                    extends_clause_already_seen: diag(1172, 1 /* Error */, "extends_clause_already_seen_1172", "'extends' clause already seen."),
                    extends_clause_must_precede_implements_clause: diag(1173, 1 /* Error */, "extends_clause_must_precede_implements_clause_1173", "'extends' clause must precede 'implements' clause."),
                    Classes_can_only_extend_a_single_class: diag(1174, 1 /* Error */, "Classes_can_only_extend_a_single_class_1174", "Classes can only extend a single class."),
                    implements_clause_already_seen: diag(1175, 1 /* Error */, "implements_clause_already_seen_1175", "'implements' clause already seen."),
                    Interface_declaration_cannot_have_implements_clause: diag(1176, 1 /* Error */, "Interface_declaration_cannot_have_implements_clause_1176", "Interface declaration cannot have 'implements' clause."),
                    Binary_digit_expected: diag(1177, 1 /* Error */, "Binary_digit_expected_1177", "Binary digit expected."),
                    Octal_digit_expected: diag(1178, 1 /* Error */, "Octal_digit_expected_1178", "Octal digit expected."),
                    Unexpected_token_expected: diag(1179, 1 /* Error */, "Unexpected_token_expected_1179", "Unexpected token. '{' expected."),
                    Property_destructuring_pattern_expected: diag(1180, 1 /* Error */, "Property_destructuring_pattern_expected_1180", "Property destructuring pattern expected."),
                    Array_element_destructuring_pattern_expected: diag(1181, 1 /* Error */, "Array_element_destructuring_pattern_expected_1181", "Array element destructuring pattern expected."),
                    A_destructuring_declaration_must_have_an_initializer: diag(1182, 1 /* Error */, "A_destructuring_declaration_must_have_an_initializer_1182", "A destructuring declaration must have an initializer."),
                    An_implementation_cannot_be_declared_in_ambient_contexts: diag(1183, 1 /* Error */, "An_implementation_cannot_be_declared_in_ambient_contexts_1183", "An implementation cannot be declared in ambient contexts."),
                    Modifiers_cannot_appear_here: diag(1184, 1 /* Error */, "Modifiers_cannot_appear_here_1184", "Modifiers cannot appear here."),
                    Merge_conflict_marker_encountered: diag(1185, 1 /* Error */, "Merge_conflict_marker_encountered_1185", "Merge conflict marker encountered."),
                    A_rest_element_cannot_have_an_initializer: diag(1186, 1 /* Error */, "A_rest_element_cannot_have_an_initializer_1186", "A rest element cannot have an initializer."),
                    A_parameter_property_may_not_be_declared_using_a_binding_pattern: diag(1187, 1 /* Error */, "A_parameter_property_may_not_be_declared_using_a_binding_pattern_1187", "A parameter property may not be declared using a binding pattern."),
                    Only_a_single_variable_declaration_is_allowed_in_a_for_of_statement: diag(1188, 1 /* Error */, "Only_a_single_variable_declaration_is_allowed_in_a_for_of_statement_1188", "Only a single variable declaration is allowed in a 'for...of' statement."),
                    The_variable_declaration_of_a_for_in_statement_cannot_have_an_initializer: diag(1189, 1 /* Error */, "The_variable_declaration_of_a_for_in_statement_cannot_have_an_initializer_1189", "The variable declaration of a 'for...in' statement cannot have an initializer."),
                    The_variable_declaration_of_a_for_of_statement_cannot_have_an_initializer: diag(1190, 1 /* Error */, "The_variable_declaration_of_a_for_of_statement_cannot_have_an_initializer_1190", "The variable declaration of a 'for...of' statement cannot have an initializer."),
                    An_import_declaration_cannot_have_modifiers: diag(1191, 1 /* Error */, "An_import_declaration_cannot_have_modifiers_1191", "An import declaration cannot have modifiers."),
                    Module_0_has_no_default_export: diag(1192, 1 /* Error */, "Module_0_has_no_default_export_1192", "Module '{0}' has no default export."),
                    An_export_declaration_cannot_have_modifiers: diag(1193, 1 /* Error */, "An_export_declaration_cannot_have_modifiers_1193", "An export declaration cannot have modifiers."),
                    Export_declarations_are_not_permitted_in_a_namespace: diag(1194, 1 /* Error */, "Export_declarations_are_not_permitted_in_a_namespace_1194", "Export declarations are not permitted in a namespace."),
                    export_Asterisk_does_not_re_export_a_default: diag(1195, 1 /* Error */, "export_Asterisk_does_not_re_export_a_default_1195", "'export *' does not re-export a default."),
                    Catch_clause_variable_type_annotation_must_be_any_or_unknown_if_specified: diag(1196, 1 /* Error */, "Catch_clause_variable_type_annotation_must_be_any_or_unknown_if_specified_1196", "Catch clause variable type annotation must be 'any' or 'unknown' if specified."),
                    Catch_clause_variable_cannot_have_an_initializer: diag(1197, 1 /* Error */, "Catch_clause_variable_cannot_have_an_initializer_1197", "Catch clause variable cannot have an initializer."),
                    An_extended_Unicode_escape_value_must_be_between_0x0_and_0x10FFFF_inclusive: diag(1198, 1 /* Error */, "An_extended_Unicode_escape_value_must_be_between_0x0_and_0x10FFFF_inclusive_1198", "An extended Unicode escape value must be between 0x0 and 0x10FFFF inclusive."),
                    Unterminated_Unicode_escape_sequence: diag(1199, 1 /* Error */, "Unterminated_Unicode_escape_sequence_1199", "Unterminated Unicode escape sequence."),
                    Line_terminator_not_permitted_before_arrow: diag(1200, 1 /* Error */, "Line_terminator_not_permitted_before_arrow_1200", "Line terminator not permitted before arrow."),
                    Import_assignment_cannot_be_used_when_targeting_ECMAScript_modules_Consider_using_import_Asterisk_as_ns_from_mod_import_a_from_mod_import_d_from_mod_or_another_module_format_instead: diag(1202, 1 /* Error */, "Import_assignment_cannot_be_used_when_targeting_ECMAScript_modules_Consider_using_import_Asterisk_as_1202", `Import assignment cannot be used when targeting ECMAScript modules. Consider using 'import * as ns from "mod"', 'import {a} from "mod"', 'import d from "mod"', or another module format instead.`),
                    Export_assignment_cannot_be_used_when_targeting_ECMAScript_modules_Consider_using_export_default_or_another_module_format_instead: diag(1203, 1 /* Error */, "Export_assignment_cannot_be_used_when_targeting_ECMAScript_modules_Consider_using_export_default_or__1203", "Export assignment cannot be used when targeting ECMAScript modules. Consider using 'export default' or another module format instead."),
                    Re_exporting_a_type_when_0_is_enabled_requires_using_export_type: diag(1205, 1 /* Error */, "Re_exporting_a_type_when_0_is_enabled_requires_using_export_type_1205", "Re-exporting a type when '{0}' is enabled requires using 'export type'."),
                    Decorators_are_not_valid_here: diag(1206, 1 /* Error */, "Decorators_are_not_valid_here_1206", "Decorators are not valid here."),
                    Decorators_cannot_be_applied_to_multiple_get_Slashset_accessors_of_the_same_name: diag(1207, 1 /* Error */, "Decorators_cannot_be_applied_to_multiple_get_Slashset_accessors_of_the_same_name_1207", "Decorators cannot be applied to multiple get/set accessors of the same name."),
                    Invalid_optional_chain_from_new_expression_Did_you_mean_to_call_0: diag(1209, 1 /* Error */, "Invalid_optional_chain_from_new_expression_Did_you_mean_to_call_0_1209", "Invalid optional chain from new expression. Did you mean to call '{0}()'?"),
                    Code_contained_in_a_class_is_evaluated_in_JavaScript_s_strict_mode_which_does_not_allow_this_use_of_0_For_more_information_see_https_Colon_Slash_Slashdeveloper_mozilla_org_Slashen_US_Slashdocs_SlashWeb_SlashJavaScript_SlashReference_SlashStrict_mode: diag(1210, 1 /* Error */, "Code_contained_in_a_class_is_evaluated_in_JavaScript_s_strict_mode_which_does_not_allow_this_use_of__1210", "Code contained in a class is evaluated in JavaScript's strict mode which does not allow this use of '{0}'. For more information, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Strict_mode."),
                    A_class_declaration_without_the_default_modifier_must_have_a_name: diag(1211, 1 /* Error */, "A_class_declaration_without_the_default_modifier_must_have_a_name_1211", "A class declaration without the 'default' modifier must have a name."),
                    Identifier_expected_0_is_a_reserved_word_in_strict_mode: diag(1212, 1 /* Error */, "Identifier_expected_0_is_a_reserved_word_in_strict_mode_1212", "Identifier expected. '{0}' is a reserved word in strict mode."),
                    Identifier_expected_0_is_a_reserved_word_in_strict_mode_Class_definitions_are_automatically_in_strict_mode: diag(1213, 1 /* Error */, "Identifier_expected_0_is_a_reserved_word_in_strict_mode_Class_definitions_are_automatically_in_stric_1213", "Identifier expected. '{0}' is a reserved word in strict mode. Class definitions are automatically in strict mode."),
                    Identifier_expected_0_is_a_reserved_word_in_strict_mode_Modules_are_automatically_in_strict_mode: diag(1214, 1 /* Error */, "Identifier_expected_0_is_a_reserved_word_in_strict_mode_Modules_are_automatically_in_strict_mode_1214", "Identifier expected. '{0}' is a reserved word in strict mode. Modules are automatically in strict mode."),
                    Invalid_use_of_0_Modules_are_automatically_in_strict_mode: diag(1215, 1 /* Error */, "Invalid_use_of_0_Modules_are_automatically_in_strict_mode_1215", "Invalid use of '{0}'. Modules are automatically in strict mode."),
                    Identifier_expected_esModule_is_reserved_as_an_exported_marker_when_transforming_ECMAScript_modules: diag(1216, 1 /* Error */, "Identifier_expected_esModule_is_reserved_as_an_exported_marker_when_transforming_ECMAScript_modules_1216", "Identifier expected. '__esModule' is reserved as an exported marker when transforming ECMAScript modules."),
                    Export_assignment_is_not_supported_when_module_flag_is_system: diag(1218, 1 /* Error */, "Export_assignment_is_not_supported_when_module_flag_is_system_1218", "Export assignment is not supported when '--module' flag is 'system'."),
                    Generators_are_not_allowed_in_an_ambient_context: diag(1221, 1 /* Error */, "Generators_are_not_allowed_in_an_ambient_context_1221", "Generators are not allowed in an ambient context."),
                    An_overload_signature_cannot_be_declared_as_a_generator: diag(1222, 1 /* Error */, "An_overload_signature_cannot_be_declared_as_a_generator_1222", "An overload signature cannot be declared as a generator."),
                    _0_tag_already_specified: diag(1223, 1 /* Error */, "_0_tag_already_specified_1223", "'{0}' tag already specified."),
                    Signature_0_must_be_a_type_predicate: diag(1224, 1 /* Error */, "Signature_0_must_be_a_type_predicate_1224", "Signature '{0}' must be a type predicate."),
                    Cannot_find_parameter_0: diag(1225, 1 /* Error */, "Cannot_find_parameter_0_1225", "Cannot find parameter '{0}'."),
                    Type_predicate_0_is_not_assignable_to_1: diag(1226, 1 /* Error */, "Type_predicate_0_is_not_assignable_to_1_1226", "Type predicate '{0}' is not assignable to '{1}'."),
                    Parameter_0_is_not_in_the_same_position_as_parameter_1: diag(1227, 1 /* Error */, "Parameter_0_is_not_in_the_same_position_as_parameter_1_1227", "Parameter '{0}' is not in the same position as parameter '{1}'."),
                    A_type_predicate_is_only_allowed_in_return_type_position_for_functions_and_methods: diag(1228, 1 /* Error */, "A_type_predicate_is_only_allowed_in_return_type_position_for_functions_and_methods_1228", "A type predicate is only allowed in return type position for functions and methods."),
                    A_type_predicate_cannot_reference_a_rest_parameter: diag(1229, 1 /* Error */, "A_type_predicate_cannot_reference_a_rest_parameter_1229", "A type predicate cannot reference a rest parameter."),
                    A_type_predicate_cannot_reference_element_0_in_a_binding_pattern: diag(1230, 1 /* Error */, "A_type_predicate_cannot_reference_element_0_in_a_binding_pattern_1230", "A type predicate cannot reference element '{0}' in a binding pattern."),
                    An_export_assignment_must_be_at_the_top_level_of_a_file_or_module_declaration: diag(1231, 1 /* Error */, "An_export_assignment_must_be_at_the_top_level_of_a_file_or_module_declaration_1231", "An export assignment must be at the top level of a file or module declaration."),
                    An_import_declaration_can_only_be_used_at_the_top_level_of_a_namespace_or_module: diag(1232, 1 /* Error */, "An_import_declaration_can_only_be_used_at_the_top_level_of_a_namespace_or_module_1232", "An import declaration can only be used at the top level of a namespace or module."),
                    An_export_declaration_can_only_be_used_at_the_top_level_of_a_namespace_or_module: diag(1233, 1 /* Error */, "An_export_declaration_can_only_be_used_at_the_top_level_of_a_namespace_or_module_1233", "An export declaration can only be used at the top level of a namespace or module."),
                    An_ambient_module_declaration_is_only_allowed_at_the_top_level_in_a_file: diag(1234, 1 /* Error */, "An_ambient_module_declaration_is_only_allowed_at_the_top_level_in_a_file_1234", "An ambient module declaration is only allowed at the top level in a file."),
                    A_namespace_declaration_is_only_allowed_at_the_top_level_of_a_namespace_or_module: diag(1235, 1 /* Error */, "A_namespace_declaration_is_only_allowed_at_the_top_level_of_a_namespace_or_module_1235", "A namespace declaration is only allowed at the top level of a namespace or module."),
                    The_return_type_of_a_property_decorator_function_must_be_either_void_or_any: diag(1236, 1 /* Error */, "The_return_type_of_a_property_decorator_function_must_be_either_void_or_any_1236", "The return type of a property decorator function must be either 'void' or 'any'."),
                    The_return_type_of_a_parameter_decorator_function_must_be_either_void_or_any: diag(1237, 1 /* Error */, "The_return_type_of_a_parameter_decorator_function_must_be_either_void_or_any_1237", "The return type of a parameter decorator function must be either 'void' or 'any'."),
                    Unable_to_resolve_signature_of_class_decorator_when_called_as_an_expression: diag(1238, 1 /* Error */, "Unable_to_resolve_signature_of_class_decorator_when_called_as_an_expression_1238", "Unable to resolve signature of class decorator when called as an expression."),
                    Unable_to_resolve_signature_of_parameter_decorator_when_called_as_an_expression: diag(1239, 1 /* Error */, "Unable_to_resolve_signature_of_parameter_decorator_when_called_as_an_expression_1239", "Unable to resolve signature of parameter decorator when called as an expression."),
                    Unable_to_resolve_signature_of_property_decorator_when_called_as_an_expression: diag(1240, 1 /* Error */, "Unable_to_resolve_signature_of_property_decorator_when_called_as_an_expression_1240", "Unable to resolve signature of property decorator when called as an expression."),
                    Unable_to_resolve_signature_of_method_decorator_when_called_as_an_expression: diag(1241, 1 /* Error */, "Unable_to_resolve_signature_of_method_decorator_when_called_as_an_expression_1241", "Unable to resolve signature of method decorator when called as an expression."),
                    abstract_modifier_can_only_appear_on_a_class_method_or_property_declaration: diag(1242, 1 /* Error */, "abstract_modifier_can_only_appear_on_a_class_method_or_property_declaration_1242", "'abstract' modifier can only appear on a class, method, or property declaration."),
                    _0_modifier_cannot_be_used_with_1_modifier: diag(1243, 1 /* Error */, "_0_modifier_cannot_be_used_with_1_modifier_1243", "'{0}' modifier cannot be used with '{1}' modifier."),
                    Abstract_methods_can_only_appear_within_an_abstract_class: diag(1244, 1 /* Error */, "Abstract_methods_can_only_appear_within_an_abstract_class_1244", "Abstract methods can only appear within an abstract class."),
                    Method_0_cannot_have_an_implementation_because_it_is_marked_abstract: diag(1245, 1 /* Error */, "Method_0_cannot_have_an_implementation_because_it_is_marked_abstract_1245", "Method '{0}' cannot have an implementation because it is marked abstract."),
                    An_interface_property_cannot_have_an_initializer: diag(1246, 1 /* Error */, "An_interface_property_cannot_have_an_initializer_1246", "An interface property cannot have an initializer."),
                    A_type_literal_property_cannot_have_an_initializer: diag(1247, 1 /* Error */, "A_type_literal_property_cannot_have_an_initializer_1247", "A type literal property cannot have an initializer."),
                    A_class_member_cannot_have_the_0_keyword: diag(1248, 1 /* Error */, "A_class_member_cannot_have_the_0_keyword_1248", "A class member cannot have the '{0}' keyword."),
                    A_decorator_can_only_decorate_a_method_implementation_not_an_overload: diag(1249, 1 /* Error */, "A_decorator_can_only_decorate_a_method_implementation_not_an_overload_1249", "A decorator can only decorate a method implementation, not an overload."),
                    Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5: diag(1250, 1 /* Error */, "Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5_1250", "Function declarations are not allowed inside blocks in strict mode when targeting 'ES3' or 'ES5'."),
                    Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5_Class_definitions_are_automatically_in_strict_mode: diag(1251, 1 /* Error */, "Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5_Class_d_1251", "Function declarations are not allowed inside blocks in strict mode when targeting 'ES3' or 'ES5'. Class definitions are automatically in strict mode."),
                    Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5_Modules_are_automatically_in_strict_mode: diag(1252, 1 /* Error */, "Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5_Modules_1252", "Function declarations are not allowed inside blocks in strict mode when targeting 'ES3' or 'ES5'. Modules are automatically in strict mode."),
                    Abstract_properties_can_only_appear_within_an_abstract_class: diag(1253, 1 /* Error */, "Abstract_properties_can_only_appear_within_an_abstract_class_1253", "Abstract properties can only appear within an abstract class."),
                    A_const_initializer_in_an_ambient_context_must_be_a_string_or_numeric_literal_or_literal_enum_reference: diag(1254, 1 /* Error */, "A_const_initializer_in_an_ambient_context_must_be_a_string_or_numeric_literal_or_literal_enum_refere_1254", "A 'const' initializer in an ambient context must be a string or numeric literal or literal enum reference."),
                    A_definite_assignment_assertion_is_not_permitted_in_this_context: diag(1255, 1 /* Error */, "A_definite_assignment_assertion_is_not_permitted_in_this_context_1255", "A definite assignment assertion '!' is not permitted in this context."),
                    A_required_element_cannot_follow_an_optional_element: diag(1257, 1 /* Error */, "A_required_element_cannot_follow_an_optional_element_1257", "A required element cannot follow an optional element."),
                    A_default_export_must_be_at_the_top_level_of_a_file_or_module_declaration: diag(1258, 1 /* Error */, "A_default_export_must_be_at_the_top_level_of_a_file_or_module_declaration_1258", "A default export must be at the top level of a file or module declaration."),
                    Module_0_can_only_be_default_imported_using_the_1_flag: diag(1259, 1 /* Error */, "Module_0_can_only_be_default_imported_using_the_1_flag_1259", "Module '{0}' can only be default-imported using the '{1}' flag"),
                    Keywords_cannot_contain_escape_characters: diag(1260, 1 /* Error */, "Keywords_cannot_contain_escape_characters_1260", "Keywords cannot contain escape characters."),
                    Already_included_file_name_0_differs_from_file_name_1_only_in_casing: diag(1261, 1 /* Error */, "Already_included_file_name_0_differs_from_file_name_1_only_in_casing_1261", "Already included file name '{0}' differs from file name '{1}' only in casing."),
                    Identifier_expected_0_is_a_reserved_word_at_the_top_level_of_a_module: diag(1262, 1 /* Error */, "Identifier_expected_0_is_a_reserved_word_at_the_top_level_of_a_module_1262", "Identifier expected. '{0}' is a reserved word at the top-level of a module."),
                    Declarations_with_initializers_cannot_also_have_definite_assignment_assertions: diag(1263, 1 /* Error */, "Declarations_with_initializers_cannot_also_have_definite_assignment_assertions_1263", "Declarations with initializers cannot also have definite assignment assertions."),
                    Declarations_with_definite_assignment_assertions_must_also_have_type_annotations: diag(1264, 1 /* Error */, "Declarations_with_definite_assignment_assertions_must_also_have_type_annotations_1264", "Declarations with definite assignment assertions must also have type annotations."),
                    A_rest_element_cannot_follow_another_rest_element: diag(1265, 1 /* Error */, "A_rest_element_cannot_follow_another_rest_element_1265", "A rest element cannot follow another rest element."),
                    An_optional_element_cannot_follow_a_rest_element: diag(1266, 1 /* Error */, "An_optional_element_cannot_follow_a_rest_element_1266", "An optional element cannot follow a rest element."),
                    Property_0_cannot_have_an_initializer_because_it_is_marked_abstract: diag(1267, 1 /* Error */, "Property_0_cannot_have_an_initializer_because_it_is_marked_abstract_1267", "Property '{0}' cannot have an initializer because it is marked abstract."),
                    An_index_signature_parameter_type_must_be_string_number_symbol_or_a_template_literal_type: diag(1268, 1 /* Error */, "An_index_signature_parameter_type_must_be_string_number_symbol_or_a_template_literal_type_1268", "An index signature parameter type must be 'string', 'number', 'symbol', or a template literal type."),
                    Cannot_use_export_import_on_a_type_or_type_only_namespace_when_0_is_enabled: diag(1269, 1 /* Error */, "Cannot_use_export_import_on_a_type_or_type_only_namespace_when_0_is_enabled_1269", "Cannot use 'export import' on a type or type-only namespace when '{0}' is enabled."),
                    Decorator_function_return_type_0_is_not_assignable_to_type_1: diag(1270, 1 /* Error */, "Decorator_function_return_type_0_is_not_assignable_to_type_1_1270", "Decorator function return type '{0}' is not assignable to type '{1}'."),
                    Decorator_function_return_type_is_0_but_is_expected_to_be_void_or_any: diag(1271, 1 /* Error */, "Decorator_function_return_type_is_0_but_is_expected_to_be_void_or_any_1271", "Decorator function return type is '{0}' but is expected to be 'void' or 'any'."),
                    A_type_referenced_in_a_decorated_signature_must_be_imported_with_import_type_or_a_namespace_import_when_isolatedModules_and_emitDecoratorMetadata_are_enabled: diag(1272, 1 /* Error */, "A_type_referenced_in_a_decorated_signature_must_be_imported_with_import_type_or_a_namespace_import_w_1272", "A type referenced in a decorated signature must be imported with 'import type' or a namespace import when 'isolatedModules' and 'emitDecoratorMetadata' are enabled."),
                    _0_modifier_cannot_appear_on_a_type_parameter: diag(1273, 1 /* Error */, "_0_modifier_cannot_appear_on_a_type_parameter_1273", "'{0}' modifier cannot appear on a type parameter"),
                    _0_modifier_can_only_appear_on_a_type_parameter_of_a_class_interface_or_type_alias: diag(1274, 1 /* Error */, "_0_modifier_can_only_appear_on_a_type_parameter_of_a_class_interface_or_type_alias_1274", "'{0}' modifier can only appear on a type parameter of a class, interface or type alias"),
                    accessor_modifier_can_only_appear_on_a_property_declaration: diag(1275, 1 /* Error */, "accessor_modifier_can_only_appear_on_a_property_declaration_1275", "'accessor' modifier can only appear on a property declaration."),
                    An_accessor_property_cannot_be_declared_optional: diag(1276, 1 /* Error */, "An_accessor_property_cannot_be_declared_optional_1276", "An 'accessor' property cannot be declared optional."),
                    _0_modifier_can_only_appear_on_a_type_parameter_of_a_function_method_or_class: diag(1277, 1 /* Error */, "_0_modifier_can_only_appear_on_a_type_parameter_of_a_function_method_or_class_1277", "'{0}' modifier can only appear on a type parameter of a function, method or class"),
                    The_runtime_will_invoke_the_decorator_with_1_arguments_but_the_decorator_expects_0: diag(1278, 1 /* Error */, "The_runtime_will_invoke_the_decorator_with_1_arguments_but_the_decorator_expects_0_1278", "The runtime will invoke the decorator with {1} arguments, but the decorator expects {0}."),
                    The_runtime_will_invoke_the_decorator_with_1_arguments_but_the_decorator_expects_at_least_0: diag(1279, 1 /* Error */, "The_runtime_will_invoke_the_decorator_with_1_arguments_but_the_decorator_expects_at_least_0_1279", "The runtime will invoke the decorator with {1} arguments, but the decorator expects at least {0}."),
                    Namespaces_are_not_allowed_in_global_script_files_when_0_is_enabled_If_this_file_is_not_intended_to_be_a_global_script_set_moduleDetection_to_force_or_add_an_empty_export_statement: diag(1280, 1 /* Error */, "Namespaces_are_not_allowed_in_global_script_files_when_0_is_enabled_If_this_file_is_not_intended_to__1280", "Namespaces are not allowed in global script files when '{0}' is enabled. If this file is not intended to be a global script, set 'moduleDetection' to 'force' or add an empty 'export {}' statement."),
                    Cannot_access_0_from_another_file_without_qualification_when_1_is_enabled_Use_2_instead: diag(1281, 1 /* Error */, "Cannot_access_0_from_another_file_without_qualification_when_1_is_enabled_Use_2_instead_1281", "Cannot access '{0}' from another file without qualification when '{1}' is enabled. Use '{2}' instead."),
                    An_export_declaration_must_reference_a_value_when_verbatimModuleSyntax_is_enabled_but_0_only_refers_to_a_type: diag(1282, 1 /* Error */, "An_export_declaration_must_reference_a_value_when_verbatimModuleSyntax_is_enabled_but_0_only_refers__1282", "An 'export =' declaration must reference a value when 'verbatimModuleSyntax' is enabled, but '{0}' only refers to a type."),
                    An_export_declaration_must_reference_a_real_value_when_verbatimModuleSyntax_is_enabled_but_0_resolves_to_a_type_only_declaration: diag(1283, 1 /* Error */, "An_export_declaration_must_reference_a_real_value_when_verbatimModuleSyntax_is_enabled_but_0_resolve_1283", "An 'export =' declaration must reference a real value when 'verbatimModuleSyntax' is enabled, but '{0}' resolves to a type-only declaration."),
                    An_export_default_must_reference_a_value_when_verbatimModuleSyntax_is_enabled_but_0_only_refers_to_a_type: diag(1284, 1 /* Error */, "An_export_default_must_reference_a_value_when_verbatimModuleSyntax_is_enabled_but_0_only_refers_to_a_1284", "An 'export default' must reference a value when 'verbatimModuleSyntax' is enabled, but '{0}' only refers to a type."),
                    An_export_default_must_reference_a_real_value_when_verbatimModuleSyntax_is_enabled_but_0_resolves_to_a_type_only_declaration: diag(1285, 1 /* Error */, "An_export_default_must_reference_a_real_value_when_verbatimModuleSyntax_is_enabled_but_0_resolves_to_1285", "An 'export default' must reference a real value when 'verbatimModuleSyntax' is enabled, but '{0}' resolves to a type-only declaration."),
                    ESM_syntax_is_not_allowed_in_a_CommonJS_module_when_verbatimModuleSyntax_is_enabled: diag(1286, 1 /* Error */, "ESM_syntax_is_not_allowed_in_a_CommonJS_module_when_verbatimModuleSyntax_is_enabled_1286", "ESM syntax is not allowed in a CommonJS module when 'verbatimModuleSyntax' is enabled."),
                    A_top_level_export_modifier_cannot_be_used_on_value_declarations_in_a_CommonJS_module_when_verbatimModuleSyntax_is_enabled: diag(1287, 1 /* Error */, "A_top_level_export_modifier_cannot_be_used_on_value_declarations_in_a_CommonJS_module_when_verbatimM_1287", "A top-level 'export' modifier cannot be used on value declarations in a CommonJS module when 'verbatimModuleSyntax' is enabled."),
                    An_import_alias_cannot_resolve_to_a_type_or_type_only_declaration_when_verbatimModuleSyntax_is_enabled: diag(1288, 1 /* Error */, "An_import_alias_cannot_resolve_to_a_type_or_type_only_declaration_when_verbatimModuleSyntax_is_enabl_1288", "An import alias cannot resolve to a type or type-only declaration when 'verbatimModuleSyntax' is enabled."),
                    _0_resolves_to_a_type_only_declaration_and_must_be_marked_type_only_in_this_file_before_re_exporting_when_1_is_enabled_Consider_using_import_type_where_0_is_imported: diag(1289, 1 /* Error */, "_0_resolves_to_a_type_only_declaration_and_must_be_marked_type_only_in_this_file_before_re_exporting_1289", "'{0}' resolves to a type-only declaration and must be marked type-only in this file before re-exporting when '{1}' is enabled. Consider using 'import type' where '{0}' is imported."),
                    _0_resolves_to_a_type_only_declaration_and_must_be_marked_type_only_in_this_file_before_re_exporting_when_1_is_enabled_Consider_using_export_type_0_as_default: diag(1290, 1 /* Error */, "_0_resolves_to_a_type_only_declaration_and_must_be_marked_type_only_in_this_file_before_re_exporting_1290", "'{0}' resolves to a type-only declaration and must be marked type-only in this file before re-exporting when '{1}' is enabled. Consider using 'export type { {0} as default }'."),
                    _0_resolves_to_a_type_and_must_be_marked_type_only_in_this_file_before_re_exporting_when_1_is_enabled_Consider_using_import_type_where_0_is_imported: diag(1291, 1 /* Error */, "_0_resolves_to_a_type_and_must_be_marked_type_only_in_this_file_before_re_exporting_when_1_is_enable_1291", "'{0}' resolves to a type and must be marked type-only in this file before re-exporting when '{1}' is enabled. Consider using 'import type' where '{0}' is imported."),
                    _0_resolves_to_a_type_and_must_be_marked_type_only_in_this_file_before_re_exporting_when_1_is_enabled_Consider_using_export_type_0_as_default: diag(1292, 1 /* Error */, "_0_resolves_to_a_type_and_must_be_marked_type_only_in_this_file_before_re_exporting_when_1_is_enable_1292", "'{0}' resolves to a type and must be marked type-only in this file before re-exporting when '{1}' is enabled. Consider using 'export type { {0} as default }'."),
                    with_statements_are_not_allowed_in_an_async_function_block: diag(1300, 1 /* Error */, "with_statements_are_not_allowed_in_an_async_function_block_1300", "'with' statements are not allowed in an async function block."),
                    await_expressions_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules: diag(1308, 1 /* Error */, "await_expressions_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules_1308", "'await' expressions are only allowed within async functions and at the top levels of modules."),
                    The_current_file_is_a_CommonJS_module_and_cannot_use_await_at_the_top_level: diag(1309, 1 /* Error */, "The_current_file_is_a_CommonJS_module_and_cannot_use_await_at_the_top_level_1309", "The current file is a CommonJS module and cannot use 'await' at the top level."),
                    Did_you_mean_to_use_a_Colon_An_can_only_follow_a_property_name_when_the_containing_object_literal_is_part_of_a_destructuring_pattern: diag(1312, 1 /* Error */, "Did_you_mean_to_use_a_Colon_An_can_only_follow_a_property_name_when_the_containing_object_literal_is_1312", "Did you mean to use a ':'? An '=' can only follow a property name when the containing object literal is part of a destructuring pattern."),
                    The_body_of_an_if_statement_cannot_be_the_empty_statement: diag(1313, 1 /* Error */, "The_body_of_an_if_statement_cannot_be_the_empty_statement_1313", "The body of an 'if' statement cannot be the empty statement."),
                    Global_module_exports_may_only_appear_in_module_files: diag(1314, 1 /* Error */, "Global_module_exports_may_only_appear_in_module_files_1314", "Global module exports may only appear in module files."),
                    Global_module_exports_may_only_appear_in_declaration_files: diag(1315, 1 /* Error */, "Global_module_exports_may_only_appear_in_declaration_files_1315", "Global module exports may only appear in declaration files."),
                    Global_module_exports_may_only_appear_at_top_level: diag(1316, 1 /* Error */, "Global_module_exports_may_only_appear_at_top_level_1316", "Global module exports may only appear at top level."),
                    A_parameter_property_cannot_be_declared_using_a_rest_parameter: diag(1317, 1 /* Error */, "A_parameter_property_cannot_be_declared_using_a_rest_parameter_1317", "A parameter property cannot be declared using a rest parameter."),
                    An_abstract_accessor_cannot_have_an_implementation: diag(1318, 1 /* Error */, "An_abstract_accessor_cannot_have_an_implementation_1318", "An abstract accessor cannot have an implementation."),
                    A_default_export_can_only_be_used_in_an_ECMAScript_style_module: diag(1319, 1 /* Error */, "A_default_export_can_only_be_used_in_an_ECMAScript_style_module_1319", "A default export can only be used in an ECMAScript-style module."),
                    Type_of_await_operand_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member: diag(1320, 1 /* Error */, "Type_of_await_operand_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member_1320", "Type of 'await' operand must either be a valid promise or must not contain a callable 'then' member."),
                    Type_of_yield_operand_in_an_async_generator_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member: diag(1321, 1 /* Error */, "Type_of_yield_operand_in_an_async_generator_must_either_be_a_valid_promise_or_must_not_contain_a_cal_1321", "Type of 'yield' operand in an async generator must either be a valid promise or must not contain a callable 'then' member."),
                    Type_of_iterated_elements_of_a_yield_Asterisk_operand_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member: diag(1322, 1 /* Error */, "Type_of_iterated_elements_of_a_yield_Asterisk_operand_must_either_be_a_valid_promise_or_must_not_con_1322", "Type of iterated elements of a 'yield*' operand must either be a valid promise or must not contain a callable 'then' member."),
                    Dynamic_imports_are_only_supported_when_the_module_flag_is_set_to_es2020_es2022_esnext_commonjs_amd_system_umd_node16_or_nodenext: diag(1323, 1 /* Error */, "Dynamic_imports_are_only_supported_when_the_module_flag_is_set_to_es2020_es2022_esnext_commonjs_amd__1323", "Dynamic imports are only supported when the '--module' flag is set to 'es2020', 'es2022', 'esnext', 'commonjs', 'amd', 'system', 'umd', 'node16', or 'nodenext'."),
                    Dynamic_imports_only_support_a_second_argument_when_the_module_option_is_set_to_esnext_node16_or_nodenext: diag(1324, 1 /* Error */, "Dynamic_imports_only_support_a_second_argument_when_the_module_option_is_set_to_esnext_node16_or_nod_1324", "Dynamic imports only support a second argument when the '--module' option is set to 'esnext', 'node16', or 'nodenext'."),
                    Argument_of_dynamic_import_cannot_be_spread_element: diag(1325, 1 /* Error */, "Argument_of_dynamic_import_cannot_be_spread_element_1325", "Argument of dynamic import cannot be spread element."),
                    This_use_of_import_is_invalid_import_calls_can_be_written_but_they_must_have_parentheses_and_cannot_have_type_arguments: diag(1326, 1 /* Error */, "This_use_of_import_is_invalid_import_calls_can_be_written_but_they_must_have_parentheses_and_cannot__1326", "This use of 'import' is invalid. 'import()' calls can be written, but they must have parentheses and cannot have type arguments."),
                    String_literal_with_double_quotes_expected: diag(1327, 1 /* Error */, "String_literal_with_double_quotes_expected_1327", "String literal with double quotes expected."),
                    Property_value_can_only_be_string_literal_numeric_literal_true_false_null_object_literal_or_array_literal: diag(1328, 1 /* Error */, "Property_value_can_only_be_string_literal_numeric_literal_true_false_null_object_literal_or_array_li_1328", "Property value can only be string literal, numeric literal, 'true', 'false', 'null', object literal or array literal."),
                    _0_accepts_too_few_arguments_to_be_used_as_a_decorator_here_Did_you_mean_to_call_it_first_and_write_0: diag(1329, 1 /* Error */, "_0_accepts_too_few_arguments_to_be_used_as_a_decorator_here_Did_you_mean_to_call_it_first_and_write__1329", "'{0}' accepts too few arguments to be used as a decorator here. Did you mean to call it first and write '@{0}()'?"),
                    A_property_of_an_interface_or_type_literal_whose_type_is_a_unique_symbol_type_must_be_readonly: diag(1330, 1 /* Error */, "A_property_of_an_interface_or_type_literal_whose_type_is_a_unique_symbol_type_must_be_readonly_1330", "A property of an interface or type literal whose type is a 'unique symbol' type must be 'readonly'."),
                    A_property_of_a_class_whose_type_is_a_unique_symbol_type_must_be_both_static_and_readonly: diag(1331, 1 /* Error */, "A_property_of_a_class_whose_type_is_a_unique_symbol_type_must_be_both_static_and_readonly_1331", "A property of a class whose type is a 'unique symbol' type must be both 'static' and 'readonly'."),
                    A_variable_whose_type_is_a_unique_symbol_type_must_be_const: diag(1332, 1 /* Error */, "A_variable_whose_type_is_a_unique_symbol_type_must_be_const_1332", "A variable whose type is a 'unique symbol' type must be 'const'."),
                    unique_symbol_types_may_not_be_used_on_a_variable_declaration_with_a_binding_name: diag(1333, 1 /* Error */, "unique_symbol_types_may_not_be_used_on_a_variable_declaration_with_a_binding_name_1333", "'unique symbol' types may not be used on a variable declaration with a binding name."),
                    unique_symbol_types_are_only_allowed_on_variables_in_a_variable_statement: diag(1334, 1 /* Error */, "unique_symbol_types_are_only_allowed_on_variables_in_a_variable_statement_1334", "'unique symbol' types are only allowed on variables in a variable statement."),
                    unique_symbol_types_are_not_allowed_here: diag(1335, 1 /* Error */, "unique_symbol_types_are_not_allowed_here_1335", "'unique symbol' types are not allowed here."),
                    An_index_signature_parameter_type_cannot_be_a_literal_type_or_generic_type_Consider_using_a_mapped_object_type_instead: diag(1337, 1 /* Error */, "An_index_signature_parameter_type_cannot_be_a_literal_type_or_generic_type_Consider_using_a_mapped_o_1337", "An index signature parameter type cannot be a literal type or generic type. Consider using a mapped object type instead."),
                    infer_declarations_are_only_permitted_in_the_extends_clause_of_a_conditional_type: diag(1338, 1 /* Error */, "infer_declarations_are_only_permitted_in_the_extends_clause_of_a_conditional_type_1338", "'infer' declarations are only permitted in the 'extends' clause of a conditional type."),
                    Module_0_does_not_refer_to_a_value_but_is_used_as_a_value_here: diag(1339, 1 /* Error */, "Module_0_does_not_refer_to_a_value_but_is_used_as_a_value_here_1339", "Module '{0}' does not refer to a value, but is used as a value here."),
                    Module_0_does_not_refer_to_a_type_but_is_used_as_a_type_here_Did_you_mean_typeof_import_0: diag(1340, 1 /* Error */, "Module_0_does_not_refer_to_a_type_but_is_used_as_a_type_here_Did_you_mean_typeof_import_0_1340", "Module '{0}' does not refer to a type, but is used as a type here. Did you mean 'typeof import('{0}')'?"),
                    Class_constructor_may_not_be_an_accessor: diag(1341, 1 /* Error */, "Class_constructor_may_not_be_an_accessor_1341", "Class constructor may not be an accessor."),
                    The_import_meta_meta_property_is_only_allowed_when_the_module_option_is_es2020_es2022_esnext_system_node16_or_nodenext: diag(1343, 1 /* Error */, "The_import_meta_meta_property_is_only_allowed_when_the_module_option_is_es2020_es2022_esnext_system__1343", "The 'import.meta' meta-property is only allowed when the '--module' option is 'es2020', 'es2022', 'esnext', 'system', 'node16', or 'nodenext'."),
                    A_label_is_not_allowed_here: diag(1344, 1 /* Error */, "A_label_is_not_allowed_here_1344", "'A label is not allowed here."),
                    An_expression_of_type_void_cannot_be_tested_for_truthiness: diag(1345, 1 /* Error */, "An_expression_of_type_void_cannot_be_tested_for_truthiness_1345", "An expression of type 'void' cannot be tested for truthiness."),
                    This_parameter_is_not_allowed_with_use_strict_directive: diag(1346, 1 /* Error */, "This_parameter_is_not_allowed_with_use_strict_directive_1346", "This parameter is not allowed with 'use strict' directive."),
                    use_strict_directive_cannot_be_used_with_non_simple_parameter_list: diag(1347, 1 /* Error */, "use_strict_directive_cannot_be_used_with_non_simple_parameter_list_1347", "'use strict' directive cannot be used with non-simple parameter list."),
                    Non_simple_parameter_declared_here: diag(1348, 1 /* Error */, "Non_simple_parameter_declared_here_1348", "Non-simple parameter declared here."),
                    use_strict_directive_used_here: diag(1349, 1 /* Error */, "use_strict_directive_used_here_1349", "'use strict' directive used here."),
                    Print_the_final_configuration_instead_of_building: diag(1350, 3 /* Message */, "Print_the_final_configuration_instead_of_building_1350", "Print the final configuration instead of building."),
                    An_identifier_or_keyword_cannot_immediately_follow_a_numeric_literal: diag(1351, 1 /* Error */, "An_identifier_or_keyword_cannot_immediately_follow_a_numeric_literal_1351", "An identifier or keyword cannot immediately follow a numeric literal."),
                    A_bigint_literal_cannot_use_exponential_notation: diag(1352, 1 /* Error */, "A_bigint_literal_cannot_use_exponential_notation_1352", "A bigint literal cannot use exponential notation."),
                    A_bigint_literal_must_be_an_integer: diag(1353, 1 /* Error */, "A_bigint_literal_must_be_an_integer_1353", "A bigint literal must be an integer."),
                    readonly_type_modifier_is_only_permitted_on_array_and_tuple_literal_types: diag(1354, 1 /* Error */, "readonly_type_modifier_is_only_permitted_on_array_and_tuple_literal_types_1354", "'readonly' type modifier is only permitted on array and tuple literal types."),
                    A_const_assertions_can_only_be_applied_to_references_to_enum_members_or_string_number_boolean_array_or_object_literals: diag(1355, 1 /* Error */, "A_const_assertions_can_only_be_applied_to_references_to_enum_members_or_string_number_boolean_array__1355", "A 'const' assertions can only be applied to references to enum members, or string, number, boolean, array, or object literals."),
                    Did_you_mean_to_mark_this_function_as_async: diag(1356, 1 /* Error */, "Did_you_mean_to_mark_this_function_as_async_1356", "Did you mean to mark this function as 'async'?"),
                    An_enum_member_name_must_be_followed_by_a_or: diag(1357, 1 /* Error */, "An_enum_member_name_must_be_followed_by_a_or_1357", "An enum member name must be followed by a ',', '=', or '}'."),
                    Tagged_template_expressions_are_not_permitted_in_an_optional_chain: diag(1358, 1 /* Error */, "Tagged_template_expressions_are_not_permitted_in_an_optional_chain_1358", "Tagged template expressions are not permitted in an optional chain."),
                    Identifier_expected_0_is_a_reserved_word_that_cannot_be_used_here: diag(1359, 1 /* Error */, "Identifier_expected_0_is_a_reserved_word_that_cannot_be_used_here_1359", "Identifier expected. '{0}' is a reserved word that cannot be used here."),
                    Type_0_does_not_satisfy_the_expected_type_1: diag(1360, 1 /* Error */, "Type_0_does_not_satisfy_the_expected_type_1_1360", "Type '{0}' does not satisfy the expected type '{1}'."),
                    _0_cannot_be_used_as_a_value_because_it_was_imported_using_import_type: diag(1361, 1 /* Error */, "_0_cannot_be_used_as_a_value_because_it_was_imported_using_import_type_1361", "'{0}' cannot be used as a value because it was imported using 'import type'."),
                    _0_cannot_be_used_as_a_value_because_it_was_exported_using_export_type: diag(1362, 1 /* Error */, "_0_cannot_be_used_as_a_value_because_it_was_exported_using_export_type_1362", "'{0}' cannot be used as a value because it was exported using 'export type'."),
                    A_type_only_import_can_specify_a_default_import_or_named_bindings_but_not_both: diag(1363, 1 /* Error */, "A_type_only_import_can_specify_a_default_import_or_named_bindings_but_not_both_1363", "A type-only import can specify a default import or named bindings, but not both."),
                    Convert_to_type_only_export: diag(1364, 3 /* Message */, "Convert_to_type_only_export_1364", "Convert to type-only export"),
                    Convert_all_re_exported_types_to_type_only_exports: diag(1365, 3 /* Message */, "Convert_all_re_exported_types_to_type_only_exports_1365", "Convert all re-exported types to type-only exports"),
                    Split_into_two_separate_import_declarations: diag(1366, 3 /* Message */, "Split_into_two_separate_import_declarations_1366", "Split into two separate import declarations"),
                    Split_all_invalid_type_only_imports: diag(1367, 3 /* Message */, "Split_all_invalid_type_only_imports_1367", "Split all invalid type-only imports"),
                    Class_constructor_may_not_be_a_generator: diag(1368, 1 /* Error */, "Class_constructor_may_not_be_a_generator_1368", "Class constructor may not be a generator."),
                    Did_you_mean_0: diag(1369, 3 /* Message */, "Did_you_mean_0_1369", "Did you mean '{0}'?"),
                    This_import_is_never_used_as_a_value_and_must_use_import_type_because_importsNotUsedAsValues_is_set_to_error: diag(1371, 1 /* Error */, "This_import_is_never_used_as_a_value_and_must_use_import_type_because_importsNotUsedAsValues_is_set__1371", "This import is never used as a value and must use 'import type' because 'importsNotUsedAsValues' is set to 'error'."),
                    await_expressions_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_has_no_imports_or_exports_Consider_adding_an_empty_export_to_make_this_file_a_module: diag(1375, 1 /* Error */, "await_expressions_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_fi_1375", "'await' expressions are only allowed at the top level of a file when that file is a module, but this file has no imports or exports. Consider adding an empty 'export {}' to make this file a module."),
                    _0_was_imported_here: diag(1376, 3 /* Message */, "_0_was_imported_here_1376", "'{0}' was imported here."),
                    _0_was_exported_here: diag(1377, 3 /* Message */, "_0_was_exported_here_1377", "'{0}' was exported here."),
                    Top_level_await_expressions_are_only_allowed_when_the_module_option_is_set_to_es2022_esnext_system_node16_nodenext_or_preserve_and_the_target_option_is_set_to_es2017_or_higher: diag(1378, 1 /* Error */, "Top_level_await_expressions_are_only_allowed_when_the_module_option_is_set_to_es2022_esnext_system_n_1378", "Top-level 'await' expressions are only allowed when the 'module' option is set to 'es2022', 'esnext', 'system', 'node16', 'nodenext', or 'preserve', and the 'target' option is set to 'es2017' or higher."),
                    An_import_alias_cannot_reference_a_declaration_that_was_exported_using_export_type: diag(1379, 1 /* Error */, "An_import_alias_cannot_reference_a_declaration_that_was_exported_using_export_type_1379", "An import alias cannot reference a declaration that was exported using 'export type'."),
                    An_import_alias_cannot_reference_a_declaration_that_was_imported_using_import_type: diag(1380, 1 /* Error */, "An_import_alias_cannot_reference_a_declaration_that_was_imported_using_import_type_1380", "An import alias cannot reference a declaration that was imported using 'import type'."),
                    Unexpected_token_Did_you_mean_or_rbrace: diag(1381, 1 /* Error */, "Unexpected_token_Did_you_mean_or_rbrace_1381", "Unexpected token. Did you mean `{'}'}` or `&rbrace;`?"),
                    Unexpected_token_Did_you_mean_or_gt: diag(1382, 1 /* Error */, "Unexpected_token_Did_you_mean_or_gt_1382", "Unexpected token. Did you mean `{'>'}` or `&gt;`?"),
                    Function_type_notation_must_be_parenthesized_when_used_in_a_union_type: diag(1385, 1 /* Error */, "Function_type_notation_must_be_parenthesized_when_used_in_a_union_type_1385", "Function type notation must be parenthesized when used in a union type."),
                    Constructor_type_notation_must_be_parenthesized_when_used_in_a_union_type: diag(1386, 1 /* Error */, "Constructor_type_notation_must_be_parenthesized_when_used_in_a_union_type_1386", "Constructor type notation must be parenthesized when used in a union type."),
                    Function_type_notation_must_be_parenthesized_when_used_in_an_intersection_type: diag(1387, 1 /* Error */, "Function_type_notation_must_be_parenthesized_when_used_in_an_intersection_type_1387", "Function type notation must be parenthesized when used in an intersection type."),
                    Constructor_type_notation_must_be_parenthesized_when_used_in_an_intersection_type: diag(1388, 1 /* Error */, "Constructor_type_notation_must_be_parenthesized_when_used_in_an_intersection_type_1388", "Constructor type notation must be parenthesized when used in an intersection type."),
                    _0_is_not_allowed_as_a_variable_declaration_name: diag(1389, 1 /* Error */, "_0_is_not_allowed_as_a_variable_declaration_name_1389", "'{0}' is not allowed as a variable declaration name."),
                    _0_is_not_allowed_as_a_parameter_name: diag(1390, 1 /* Error */, "_0_is_not_allowed_as_a_parameter_name_1390", "'{0}' is not allowed as a parameter name."),
                    An_import_alias_cannot_use_import_type: diag(1392, 1 /* Error */, "An_import_alias_cannot_use_import_type_1392", "An import alias cannot use 'import type'"),
                    Imported_via_0_from_file_1: diag(1393, 3 /* Message */, "Imported_via_0_from_file_1_1393", "Imported via {0} from file '{1}'"),
                    Imported_via_0_from_file_1_with_packageId_2: diag(1394, 3 /* Message */, "Imported_via_0_from_file_1_with_packageId_2_1394", "Imported via {0} from file '{1}' with packageId '{2}'"),
                    Imported_via_0_from_file_1_to_import_importHelpers_as_specified_in_compilerOptions: diag(1395, 3 /* Message */, "Imported_via_0_from_file_1_to_import_importHelpers_as_specified_in_compilerOptions_1395", "Imported via {0} from file '{1}' to import 'importHelpers' as specified in compilerOptions"),
                    Imported_via_0_from_file_1_with_packageId_2_to_import_importHelpers_as_specified_in_compilerOptions: diag(1396, 3 /* Message */, "Imported_via_0_from_file_1_with_packageId_2_to_import_importHelpers_as_specified_in_compilerOptions_1396", "Imported via {0} from file '{1}' with packageId '{2}' to import 'importHelpers' as specified in compilerOptions"),
                    Imported_via_0_from_file_1_to_import_jsx_and_jsxs_factory_functions: diag(1397, 3 /* Message */, "Imported_via_0_from_file_1_to_import_jsx_and_jsxs_factory_functions_1397", "Imported via {0} from file '{1}' to import 'jsx' and 'jsxs' factory functions"),
                    Imported_via_0_from_file_1_with_packageId_2_to_import_jsx_and_jsxs_factory_functions: diag(1398, 3 /* Message */, "Imported_via_0_from_file_1_with_packageId_2_to_import_jsx_and_jsxs_factory_functions_1398", "Imported via {0} from file '{1}' with packageId '{2}' to import 'jsx' and 'jsxs' factory functions"),
                    File_is_included_via_import_here: diag(1399, 3 /* Message */, "File_is_included_via_import_here_1399", "File is included via import here."),
                    Referenced_via_0_from_file_1: diag(1400, 3 /* Message */, "Referenced_via_0_from_file_1_1400", "Referenced via '{0}' from file '{1}'"),
                    File_is_included_via_reference_here: diag(1401, 3 /* Message */, "File_is_included_via_reference_here_1401", "File is included via reference here."),
                    Type_library_referenced_via_0_from_file_1: diag(1402, 3 /* Message */, "Type_library_referenced_via_0_from_file_1_1402", "Type library referenced via '{0}' from file '{1}'"),
                    Type_library_referenced_via_0_from_file_1_with_packageId_2: diag(1403, 3 /* Message */, "Type_library_referenced_via_0_from_file_1_with_packageId_2_1403", "Type library referenced via '{0}' from file '{1}' with packageId '{2}'"),
                    File_is_included_via_type_library_reference_here: diag(1404, 3 /* Message */, "File_is_included_via_type_library_reference_here_1404", "File is included via type library reference here."),
                    Library_referenced_via_0_from_file_1: diag(1405, 3 /* Message */, "Library_referenced_via_0_from_file_1_1405", "Library referenced via '{0}' from file '{1}'"),
                    File_is_included_via_library_reference_here: diag(1406, 3 /* Message */, "File_is_included_via_library_reference_here_1406", "File is included via library reference here."),
                    Matched_by_include_pattern_0_in_1: diag(1407, 3 /* Message */, "Matched_by_include_pattern_0_in_1_1407", "Matched by include pattern '{0}' in '{1}'"),
                    File_is_matched_by_include_pattern_specified_here: diag(1408, 3 /* Message */, "File_is_matched_by_include_pattern_specified_here_1408", "File is matched by include pattern specified here."),
                    Part_of_files_list_in_tsconfig_json: diag(1409, 3 /* Message */, "Part_of_files_list_in_tsconfig_json_1409", "Part of 'files' list in tsconfig.json"),
                    File_is_matched_by_files_list_specified_here: diag(1410, 3 /* Message */, "File_is_matched_by_files_list_specified_here_1410", "File is matched by 'files' list specified here."),
                    Output_from_referenced_project_0_included_because_1_specified: diag(1411, 3 /* Message */, "Output_from_referenced_project_0_included_because_1_specified_1411", "Output from referenced project '{0}' included because '{1}' specified"),
                    Output_from_referenced_project_0_included_because_module_is_specified_as_none: diag(1412, 3 /* Message */, "Output_from_referenced_project_0_included_because_module_is_specified_as_none_1412", "Output from referenced project '{0}' included because '--module' is specified as 'none'"),
                    File_is_output_from_referenced_project_specified_here: diag(1413, 3 /* Message */, "File_is_output_from_referenced_project_specified_here_1413", "File is output from referenced project specified here."),
                    Source_from_referenced_project_0_included_because_1_specified: diag(1414, 3 /* Message */, "Source_from_referenced_project_0_included_because_1_specified_1414", "Source from referenced project '{0}' included because '{1}' specified"),
                    Source_from_referenced_project_0_included_because_module_is_specified_as_none: diag(1415, 3 /* Message */, "Source_from_referenced_project_0_included_because_module_is_specified_as_none_1415", "Source from referenced project '{0}' included because '--module' is specified as 'none'"),
                    File_is_source_from_referenced_project_specified_here: diag(1416, 3 /* Message */, "File_is_source_from_referenced_project_specified_here_1416", "File is source from referenced project specified here."),
                    Entry_point_of_type_library_0_specified_in_compilerOptions: diag(1417, 3 /* Message */, "Entry_point_of_type_library_0_specified_in_compilerOptions_1417", "Entry point of type library '{0}' specified in compilerOptions"),
                    Entry_point_of_type_library_0_specified_in_compilerOptions_with_packageId_1: diag(1418, 3 /* Message */, "Entry_point_of_type_library_0_specified_in_compilerOptions_with_packageId_1_1418", "Entry point of type library '{0}' specified in compilerOptions with packageId '{1}'"),
                    File_is_entry_point_of_type_library_specified_here: diag(1419, 3 /* Message */, "File_is_entry_point_of_type_library_specified_here_1419", "File is entry point of type library specified here."),
                    Entry_point_for_implicit_type_library_0: diag(1420, 3 /* Message */, "Entry_point_for_implicit_type_library_0_1420", "Entry point for implicit type library '{0}'"),
                    Entry_point_for_implicit_type_library_0_with_packageId_1: diag(1421, 3 /* Message */, "Entry_point_for_implicit_type_library_0_with_packageId_1_1421", "Entry point for implicit type library '{0}' with packageId '{1}'"),
                    Library_0_specified_in_compilerOptions: diag(1422, 3 /* Message */, "Library_0_specified_in_compilerOptions_1422", "Library '{0}' specified in compilerOptions"),
                    File_is_library_specified_here: diag(1423, 3 /* Message */, "File_is_library_specified_here_1423", "File is library specified here."),
                    Default_library: diag(1424, 3 /* Message */, "Default_library_1424", "Default library"),
                    Default_library_for_target_0: diag(1425, 3 /* Message */, "Default_library_for_target_0_1425", "Default library for target '{0}'"),
                    File_is_default_library_for_target_specified_here: diag(1426, 3 /* Message */, "File_is_default_library_for_target_specified_here_1426", "File is default library for target specified here."),
                    Root_file_specified_for_compilation: diag(1427, 3 /* Message */, "Root_file_specified_for_compilation_1427", "Root file specified for compilation"),
                    File_is_output_of_project_reference_source_0: diag(1428, 3 /* Message */, "File_is_output_of_project_reference_source_0_1428", "File is output of project reference source '{0}'"),
                    File_redirects_to_file_0: diag(1429, 3 /* Message */, "File_redirects_to_file_0_1429", "File redirects to file '{0}'"),
                    The_file_is_in_the_program_because_Colon: diag(1430, 3 /* Message */, "The_file_is_in_the_program_because_Colon_1430", "The file is in the program because:"),
                    for_await_loops_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_has_no_imports_or_exports_Consider_adding_an_empty_export_to_make_this_file_a_module: diag(1431, 1 /* Error */, "for_await_loops_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_1431", "'for await' loops are only allowed at the top level of a file when that file is a module, but this file has no imports or exports. Consider adding an empty 'export {}' to make this file a module."),
                    Top_level_for_await_loops_are_only_allowed_when_the_module_option_is_set_to_es2022_esnext_system_node16_nodenext_or_preserve_and_the_target_option_is_set_to_es2017_or_higher: diag(1432, 1 /* Error */, "Top_level_for_await_loops_are_only_allowed_when_the_module_option_is_set_to_es2022_esnext_system_nod_1432", "Top-level 'for await' loops are only allowed when the 'module' option is set to 'es2022', 'esnext', 'system', 'node16', 'nodenext', or 'preserve', and the 'target' option is set to 'es2017' or higher."),
                    Neither_decorators_nor_modifiers_may_be_applied_to_this_parameters: diag(1433, 1 /* Error */, "Neither_decorators_nor_modifiers_may_be_applied_to_this_parameters_1433", "Neither decorators nor modifiers may be applied to 'this' parameters."),
                    Unexpected_keyword_or_identifier: diag(1434, 1 /* Error */, "Unexpected_keyword_or_identifier_1434", "Unexpected keyword or identifier."),
                    Unknown_keyword_or_identifier_Did_you_mean_0: diag(1435, 1 /* Error */, "Unknown_keyword_or_identifier_Did_you_mean_0_1435", "Unknown keyword or identifier. Did you mean '{0}'?"),
                    Decorators_must_precede_the_name_and_all_keywords_of_property_declarations: diag(1436, 1 /* Error */, "Decorators_must_precede_the_name_and_all_keywords_of_property_declarations_1436", "Decorators must precede the name and all keywords of property declarations."),
                    Namespace_must_be_given_a_name: diag(1437, 1 /* Error */, "Namespace_must_be_given_a_name_1437", "Namespace must be given a name."),
                    Interface_must_be_given_a_name: diag(1438, 1 /* Error */, "Interface_must_be_given_a_name_1438", "Interface must be given a name."),
                    Type_alias_must_be_given_a_name: diag(1439, 1 /* Error */, "Type_alias_must_be_given_a_name_1439", "Type alias must be given a name."),
                    Variable_declaration_not_allowed_at_this_location: diag(1440, 1 /* Error */, "Variable_declaration_not_allowed_at_this_location_1440", "Variable declaration not allowed at this location."),
                    Cannot_start_a_function_call_in_a_type_annotation: diag(1441, 1 /* Error */, "Cannot_start_a_function_call_in_a_type_annotation_1441", "Cannot start a function call in a type annotation."),
                    Expected_for_property_initializer: diag(1442, 1 /* Error */, "Expected_for_property_initializer_1442", "Expected '=' for property initializer."),
                    Module_declaration_names_may_only_use_or_quoted_strings: diag(1443, 1 /* Error */, "Module_declaration_names_may_only_use_or_quoted_strings_1443", `Module declaration names may only use ' or " quoted strings.`),
                    _0_is_a_type_and_must_be_imported_using_a_type_only_import_when_preserveValueImports_and_isolatedModules_are_both_enabled: diag(1444, 1 /* Error */, "_0_is_a_type_and_must_be_imported_using_a_type_only_import_when_preserveValueImports_and_isolatedMod_1444", "'{0}' is a type and must be imported using a type-only import when 'preserveValueImports' and 'isolatedModules' are both enabled."),
                    _0_resolves_to_a_type_only_declaration_and_must_be_imported_using_a_type_only_import_when_preserveValueImports_and_isolatedModules_are_both_enabled: diag(1446, 1 /* Error */, "_0_resolves_to_a_type_only_declaration_and_must_be_imported_using_a_type_only_import_when_preserveVa_1446", "'{0}' resolves to a type-only declaration and must be imported using a type-only import when 'preserveValueImports' and 'isolatedModules' are both enabled."),
                    _0_resolves_to_a_type_only_declaration_and_must_be_re_exported_using_a_type_only_re_export_when_1_is_enabled: diag(1448, 1 /* Error */, "_0_resolves_to_a_type_only_declaration_and_must_be_re_exported_using_a_type_only_re_export_when_1_is_1448", "'{0}' resolves to a type-only declaration and must be re-exported using a type-only re-export when '{1}' is enabled."),
                    Preserve_unused_imported_values_in_the_JavaScript_output_that_would_otherwise_be_removed: diag(1449, 3 /* Message */, "Preserve_unused_imported_values_in_the_JavaScript_output_that_would_otherwise_be_removed_1449", "Preserve unused imported values in the JavaScript output that would otherwise be removed."),
                    Dynamic_imports_can_only_accept_a_module_specifier_and_an_optional_set_of_attributes_as_arguments: diag(1450, 3 /* Message */, "Dynamic_imports_can_only_accept_a_module_specifier_and_an_optional_set_of_attributes_as_arguments_1450", "Dynamic imports can only accept a module specifier and an optional set of attributes as arguments"),
                    Private_identifiers_are_only_allowed_in_class_bodies_and_may_only_be_used_as_part_of_a_class_member_declaration_property_access_or_on_the_left_hand_side_of_an_in_expression: diag(1451, 1 /* Error */, "Private_identifiers_are_only_allowed_in_class_bodies_and_may_only_be_used_as_part_of_a_class_member__1451", "Private identifiers are only allowed in class bodies and may only be used as part of a class member declaration, property access, or on the left-hand-side of an 'in' expression"),
                    resolution_mode_should_be_either_require_or_import: diag(1453, 1 /* Error */, "resolution_mode_should_be_either_require_or_import_1453", "`resolution-mode` should be either `require` or `import`."),
                    resolution_mode_can_only_be_set_for_type_only_imports: diag(1454, 1 /* Error */, "resolution_mode_can_only_be_set_for_type_only_imports_1454", "`resolution-mode` can only be set for type-only imports."),
                    resolution_mode_is_the_only_valid_key_for_type_import_assertions: diag(1455, 1 /* Error */, "resolution_mode_is_the_only_valid_key_for_type_import_assertions_1455", "`resolution-mode` is the only valid key for type import assertions."),
                    Type_import_assertions_should_have_exactly_one_key_resolution_mode_with_value_import_or_require: diag(1456, 1 /* Error */, "Type_import_assertions_should_have_exactly_one_key_resolution_mode_with_value_import_or_require_1456", "Type import assertions should have exactly one key - `resolution-mode` - with value `import` or `require`."),
                    Matched_by_default_include_pattern_Asterisk_Asterisk_Slash_Asterisk: diag(1457, 3 /* Message */, "Matched_by_default_include_pattern_Asterisk_Asterisk_Slash_Asterisk_1457", "Matched by default include pattern '**/*'"),
                    File_is_ECMAScript_module_because_0_has_field_type_with_value_module: diag(1458, 3 /* Message */, "File_is_ECMAScript_module_because_0_has_field_type_with_value_module_1458", `File is ECMAScript module because '{0}' has field "type" with value "module"`),
                    File_is_CommonJS_module_because_0_has_field_type_whose_value_is_not_module: diag(1459, 3 /* Message */, "File_is_CommonJS_module_because_0_has_field_type_whose_value_is_not_module_1459", `File is CommonJS module because '{0}' has field "type" whose value is not "module"`),
                    File_is_CommonJS_module_because_0_does_not_have_field_type: diag(1460, 3 /* Message */, "File_is_CommonJS_module_because_0_does_not_have_field_type_1460", `File is CommonJS module because '{0}' does not have field "type"`),
                    File_is_CommonJS_module_because_package_json_was_not_found: diag(1461, 3 /* Message */, "File_is_CommonJS_module_because_package_json_was_not_found_1461", "File is CommonJS module because 'package.json' was not found"),
                    resolution_mode_is_the_only_valid_key_for_type_import_attributes: diag(1463, 1 /* Error */, "resolution_mode_is_the_only_valid_key_for_type_import_attributes_1463", "'resolution-mode' is the only valid key for type import attributes."),
                    Type_import_attributes_should_have_exactly_one_key_resolution_mode_with_value_import_or_require: diag(1464, 1 /* Error */, "Type_import_attributes_should_have_exactly_one_key_resolution_mode_with_value_import_or_require_1464", "Type import attributes should have exactly one key - 'resolution-mode' - with value 'import' or 'require'."),
                    The_import_meta_meta_property_is_not_allowed_in_files_which_will_build_into_CommonJS_output: diag(1470, 1 /* Error */, "The_import_meta_meta_property_is_not_allowed_in_files_which_will_build_into_CommonJS_output_1470", "The 'import.meta' meta-property is not allowed in files which will build into CommonJS output."),
                    Module_0_cannot_be_imported_using_this_construct_The_specifier_only_resolves_to_an_ES_module_which_cannot_be_imported_with_require_Use_an_ECMAScript_import_instead: diag(1471, 1 /* Error */, "Module_0_cannot_be_imported_using_this_construct_The_specifier_only_resolves_to_an_ES_module_which_c_1471", "Module '{0}' cannot be imported using this construct. The specifier only resolves to an ES module, which cannot be imported with 'require'. Use an ECMAScript import instead."),
                    catch_or_finally_expected: diag(1472, 1 /* Error */, "catch_or_finally_expected_1472", "'catch' or 'finally' expected."),
                    An_import_declaration_can_only_be_used_at_the_top_level_of_a_module: diag(1473, 1 /* Error */, "An_import_declaration_can_only_be_used_at_the_top_level_of_a_module_1473", "An import declaration can only be used at the top level of a module."),
                    An_export_declaration_can_only_be_used_at_the_top_level_of_a_module: diag(1474, 1 /* Error */, "An_export_declaration_can_only_be_used_at_the_top_level_of_a_module_1474", "An export declaration can only be used at the top level of a module."),
                    Control_what_method_is_used_to_detect_module_format_JS_files: diag(1475, 3 /* Message */, "Control_what_method_is_used_to_detect_module_format_JS_files_1475", "Control what method is used to detect module-format JS files."),
                    auto_Colon_Treat_files_with_imports_exports_import_meta_jsx_with_jsx_Colon_react_jsx_or_esm_format_with_module_Colon_node16_as_modules: diag(1476, 3 /* Message */, "auto_Colon_Treat_files_with_imports_exports_import_meta_jsx_with_jsx_Colon_react_jsx_or_esm_format_w_1476", '"auto": Treat files with imports, exports, import.meta, jsx (with jsx: react-jsx), or esm format (with module: node16+) as modules.'),
                    An_instantiation_expression_cannot_be_followed_by_a_property_access: diag(1477, 1 /* Error */, "An_instantiation_expression_cannot_be_followed_by_a_property_access_1477", "An instantiation expression cannot be followed by a property access."),
                    Identifier_or_string_literal_expected: diag(1478, 1 /* Error */, "Identifier_or_string_literal_expected_1478", "Identifier or string literal expected."),
                    The_current_file_is_a_CommonJS_module_whose_imports_will_produce_require_calls_however_the_referenced_file_is_an_ECMAScript_module_and_cannot_be_imported_with_require_Consider_writing_a_dynamic_import_0_call_instead: diag(1479, 1 /* Error */, "The_current_file_is_a_CommonJS_module_whose_imports_will_produce_require_calls_however_the_reference_1479", `The current file is a CommonJS module whose imports will produce 'require' calls; however, the referenced file is an ECMAScript module and cannot be imported with 'require'. Consider writing a dynamic 'import("{0}")' call instead.`),
                    To_convert_this_file_to_an_ECMAScript_module_change_its_file_extension_to_0_or_create_a_local_package_json_file_with_type_Colon_module: diag(1480, 3 /* Message */, "To_convert_this_file_to_an_ECMAScript_module_change_its_file_extension_to_0_or_create_a_local_packag_1480", 'To convert this file to an ECMAScript module, change its file extension to \'{0}\' or create a local package.json file with `{ "type": "module" }`.'),
                    To_convert_this_file_to_an_ECMAScript_module_change_its_file_extension_to_0_or_add_the_field_type_Colon_module_to_1: diag(1481, 3 /* Message */, "To_convert_this_file_to_an_ECMAScript_module_change_its_file_extension_to_0_or_add_the_field_type_Co_1481", `To convert this file to an ECMAScript module, change its file extension to '{0}', or add the field \`"type": "module"\` to '{1}'.`),
                    To_convert_this_file_to_an_ECMAScript_module_add_the_field_type_Colon_module_to_0: diag(1482, 3 /* Message */, "To_convert_this_file_to_an_ECMAScript_module_add_the_field_type_Colon_module_to_0_1482", 'To convert this file to an ECMAScript module, add the field `"type": "module"` to \'{0}\'.'),
                    To_convert_this_file_to_an_ECMAScript_module_create_a_local_package_json_file_with_type_Colon_module: diag(1483, 3 /* Message */, "To_convert_this_file_to_an_ECMAScript_module_create_a_local_package_json_file_with_type_Colon_module_1483", 'To convert this file to an ECMAScript module, create a local package.json file with `{ "type": "module" }`.'),
                    _0_is_a_type_and_must_be_imported_using_a_type_only_import_when_verbatimModuleSyntax_is_enabled: diag(1484, 1 /* Error */, "_0_is_a_type_and_must_be_imported_using_a_type_only_import_when_verbatimModuleSyntax_is_enabled_1484", "'{0}' is a type and must be imported using a type-only import when 'verbatimModuleSyntax' is enabled."),
                    _0_resolves_to_a_type_only_declaration_and_must_be_imported_using_a_type_only_import_when_verbatimModuleSyntax_is_enabled: diag(1485, 1 /* Error */, "_0_resolves_to_a_type_only_declaration_and_must_be_imported_using_a_type_only_import_when_verbatimMo_1485", "'{0}' resolves to a type-only declaration and must be imported using a type-only import when 'verbatimModuleSyntax' is enabled."),
                    Decorator_used_before_export_here: diag(1486, 1 /* Error */, "Decorator_used_before_export_here_1486", "Decorator used before 'export' here."),
                    Octal_escape_sequences_are_not_allowed_Use_the_syntax_0: diag(1487, 1 /* Error */, "Octal_escape_sequences_are_not_allowed_Use_the_syntax_0_1487", "Octal escape sequences are not allowed. Use the syntax '{0}'."),
                    Escape_sequence_0_is_not_allowed: diag(1488, 1 /* Error */, "Escape_sequence_0_is_not_allowed_1488", "Escape sequence '{0}' is not allowed."),
                    Decimals_with_leading_zeros_are_not_allowed: diag(1489, 1 /* Error */, "Decimals_with_leading_zeros_are_not_allowed_1489", "Decimals with leading zeros are not allowed."),
                    File_appears_to_be_binary: diag(1490, 1 /* Error */, "File_appears_to_be_binary_1490", "File appears to be binary."),
                    _0_modifier_cannot_appear_on_a_using_declaration: diag(1491, 1 /* Error */, "_0_modifier_cannot_appear_on_a_using_declaration_1491", "'{0}' modifier cannot appear on a 'using' declaration."),
                    _0_declarations_may_not_have_binding_patterns: diag(1492, 1 /* Error */, "_0_declarations_may_not_have_binding_patterns_1492", "'{0}' declarations may not have binding patterns."),
                    The_left_hand_side_of_a_for_in_statement_cannot_be_a_using_declaration: diag(1493, 1 /* Error */, "The_left_hand_side_of_a_for_in_statement_cannot_be_a_using_declaration_1493", "The left-hand side of a 'for...in' statement cannot be a 'using' declaration."),
                    The_left_hand_side_of_a_for_in_statement_cannot_be_an_await_using_declaration: diag(1494, 1 /* Error */, "The_left_hand_side_of_a_for_in_statement_cannot_be_an_await_using_declaration_1494", "The left-hand side of a 'for...in' statement cannot be an 'await using' declaration."),
                    _0_modifier_cannot_appear_on_an_await_using_declaration: diag(1495, 1 /* Error */, "_0_modifier_cannot_appear_on_an_await_using_declaration_1495", "'{0}' modifier cannot appear on an 'await using' declaration."),
                    Identifier_string_literal_or_number_literal_expected: diag(1496, 1 /* Error */, "Identifier_string_literal_or_number_literal_expected_1496", "Identifier, string literal, or number literal expected."),
                    The_types_of_0_are_incompatible_between_these_types: diag(2200, 1 /* Error */, "The_types_of_0_are_incompatible_between_these_types_2200", "The types of '{0}' are incompatible between these types."),
                    The_types_returned_by_0_are_incompatible_between_these_types: diag(2201, 1 /* Error */, "The_types_returned_by_0_are_incompatible_between_these_types_2201", "The types returned by '{0}' are incompatible between these types."),
                    Call_signature_return_types_0_and_1_are_incompatible: diag(2202, 1 /* Error */, "Call_signature_return_types_0_and_1_are_incompatible_2202", "Call signature return types '{0}' and '{1}' are incompatible.", 
                    /*reportsUnnecessary*/
                    void 0, 
                    /*elidedInCompatabilityPyramid*/
                    true),
                    Construct_signature_return_types_0_and_1_are_incompatible: diag(2203, 1 /* Error */, "Construct_signature_return_types_0_and_1_are_incompatible_2203", "Construct signature return types '{0}' and '{1}' are incompatible.", 
                    /*reportsUnnecessary*/
                    void 0, 
                    /*elidedInCompatabilityPyramid*/
                    true),
                    Call_signatures_with_no_arguments_have_incompatible_return_types_0_and_1: diag(2204, 1 /* Error */, "Call_signatures_with_no_arguments_have_incompatible_return_types_0_and_1_2204", "Call signatures with no arguments have incompatible return types '{0}' and '{1}'.", 
                    /*reportsUnnecessary*/
                    void 0, 
                    /*elidedInCompatabilityPyramid*/
                    true),
                    Construct_signatures_with_no_arguments_have_incompatible_return_types_0_and_1: diag(2205, 1 /* Error */, "Construct_signatures_with_no_arguments_have_incompatible_return_types_0_and_1_2205", "Construct signatures with no arguments have incompatible return types '{0}' and '{1}'.", 
                    /*reportsUnnecessary*/
                    void 0, 
                    /*elidedInCompatabilityPyramid*/
                    true),
                    The_type_modifier_cannot_be_used_on_a_named_import_when_import_type_is_used_on_its_import_statement: diag(2206, 1 /* Error */, "The_type_modifier_cannot_be_used_on_a_named_import_when_import_type_is_used_on_its_import_statement_2206", "The 'type' modifier cannot be used on a named import when 'import type' is used on its import statement."),
                    The_type_modifier_cannot_be_used_on_a_named_export_when_export_type_is_used_on_its_export_statement: diag(2207, 1 /* Error */, "The_type_modifier_cannot_be_used_on_a_named_export_when_export_type_is_used_on_its_export_statement_2207", "The 'type' modifier cannot be used on a named export when 'export type' is used on its export statement."),
                    This_type_parameter_might_need_an_extends_0_constraint: diag(2208, 1 /* Error */, "This_type_parameter_might_need_an_extends_0_constraint_2208", "This type parameter might need an `extends {0}` constraint."),
                    The_project_root_is_ambiguous_but_is_required_to_resolve_export_map_entry_0_in_file_1_Supply_the_rootDir_compiler_option_to_disambiguate: diag(2209, 1 /* Error */, "The_project_root_is_ambiguous_but_is_required_to_resolve_export_map_entry_0_in_file_1_Supply_the_roo_2209", "The project root is ambiguous, but is required to resolve export map entry '{0}' in file '{1}'. Supply the `rootDir` compiler option to disambiguate."),
                    The_project_root_is_ambiguous_but_is_required_to_resolve_import_map_entry_0_in_file_1_Supply_the_rootDir_compiler_option_to_disambiguate: diag(2210, 1 /* Error */, "The_project_root_is_ambiguous_but_is_required_to_resolve_import_map_entry_0_in_file_1_Supply_the_roo_2210", "The project root is ambiguous, but is required to resolve import map entry '{0}' in file '{1}'. Supply the `rootDir` compiler option to disambiguate."),
                    Add_extends_constraint: diag(2211, 3 /* Message */, "Add_extends_constraint_2211", "Add `extends` constraint."),
                    Add_extends_constraint_to_all_type_parameters: diag(2212, 3 /* Message */, "Add_extends_constraint_to_all_type_parameters_2212", "Add `extends` constraint to all type parameters"),
                    Duplicate_identifier_0: diag(2300, 1 /* Error */, "Duplicate_identifier_0_2300", "Duplicate identifier '{0}'."),
                    Initializer_of_instance_member_variable_0_cannot_reference_identifier_1_declared_in_the_constructor: diag(2301, 1 /* Error */, "Initializer_of_instance_member_variable_0_cannot_reference_identifier_1_declared_in_the_constructor_2301", "Initializer of instance member variable '{0}' cannot reference identifier '{1}' declared in the constructor."),
                    Static_members_cannot_reference_class_type_parameters: diag(2302, 1 /* Error */, "Static_members_cannot_reference_class_type_parameters_2302", "Static members cannot reference class type parameters."),
                    Circular_definition_of_import_alias_0: diag(2303, 1 /* Error */, "Circular_definition_of_import_alias_0_2303", "Circular definition of import alias '{0}'."),
                    Cannot_find_name_0: diag(2304, 1 /* Error */, "Cannot_find_name_0_2304", "Cannot find name '{0}'."),
                    Module_0_has_no_exported_member_1: diag(2305, 1 /* Error */, "Module_0_has_no_exported_member_1_2305", "Module '{0}' has no exported member '{1}'."),
                    File_0_is_not_a_module: diag(2306, 1 /* Error */, "File_0_is_not_a_module_2306", "File '{0}' is not a module."),
                    Cannot_find_module_0_or_its_corresponding_type_declarations: diag(2307, 1 /* Error */, "Cannot_find_module_0_or_its_corresponding_type_declarations_2307", "Cannot find module '{0}' or its corresponding type declarations."),
                    Module_0_has_already_exported_a_member_named_1_Consider_explicitly_re_exporting_to_resolve_the_ambiguity: diag(2308, 1 /* Error */, "Module_0_has_already_exported_a_member_named_1_Consider_explicitly_re_exporting_to_resolve_the_ambig_2308", "Module {0} has already exported a member named '{1}'. Consider explicitly re-exporting to resolve the ambiguity."),
                    An_export_assignment_cannot_be_used_in_a_module_with_other_exported_elements: diag(2309, 1 /* Error */, "An_export_assignment_cannot_be_used_in_a_module_with_other_exported_elements_2309", "An export assignment cannot be used in a module with other exported elements."),
                    Type_0_recursively_references_itself_as_a_base_type: diag(2310, 1 /* Error */, "Type_0_recursively_references_itself_as_a_base_type_2310", "Type '{0}' recursively references itself as a base type."),
                    Cannot_find_name_0_Did_you_mean_to_write_this_in_an_async_function: diag(2311, 1 /* Error */, "Cannot_find_name_0_Did_you_mean_to_write_this_in_an_async_function_2311", "Cannot find name '{0}'. Did you mean to write this in an async function?"),
                    An_interface_can_only_extend_an_object_type_or_intersection_of_object_types_with_statically_known_members: diag(2312, 1 /* Error */, "An_interface_can_only_extend_an_object_type_or_intersection_of_object_types_with_statically_known_me_2312", "An interface can only extend an object type or intersection of object types with statically known members."),
                    Type_parameter_0_has_a_circular_constraint: diag(2313, 1 /* Error */, "Type_parameter_0_has_a_circular_constraint_2313", "Type parameter '{0}' has a circular constraint."),
                    Generic_type_0_requires_1_type_argument_s: diag(2314, 1 /* Error */, "Generic_type_0_requires_1_type_argument_s_2314", "Generic type '{0}' requires {1} type argument(s)."),
                    Type_0_is_not_generic: diag(2315, 1 /* Error */, "Type_0_is_not_generic_2315", "Type '{0}' is not generic."),
                    Global_type_0_must_be_a_class_or_interface_type: diag(2316, 1 /* Error */, "Global_type_0_must_be_a_class_or_interface_type_2316", "Global type '{0}' must be a class or interface type."),
                    Global_type_0_must_have_1_type_parameter_s: diag(2317, 1 /* Error */, "Global_type_0_must_have_1_type_parameter_s_2317", "Global type '{0}' must have {1} type parameter(s)."),
                    Cannot_find_global_type_0: diag(2318, 1 /* Error */, "Cannot_find_global_type_0_2318", "Cannot find global type '{0}'."),
                    Named_property_0_of_types_1_and_2_are_not_identical: diag(2319, 1 /* Error */, "Named_property_0_of_types_1_and_2_are_not_identical_2319", "Named property '{0}' of types '{1}' and '{2}' are not identical."),
                    Interface_0_cannot_simultaneously_extend_types_1_and_2: diag(2320, 1 /* Error */, "Interface_0_cannot_simultaneously_extend_types_1_and_2_2320", "Interface '{0}' cannot simultaneously extend types '{1}' and '{2}'."),
                    Excessive_stack_depth_comparing_types_0_and_1: diag(2321, 1 /* Error */, "Excessive_stack_depth_comparing_types_0_and_1_2321", "Excessive stack depth comparing types '{0}' and '{1}'."),
                    Type_0_is_not_assignable_to_type_1: diag(2322, 1 /* Error */, "Type_0_is_not_assignable_to_type_1_2322", "Type '{0}' is not assignable to type '{1}'."),
                    Cannot_redeclare_exported_variable_0: diag(2323, 1 /* Error */, "Cannot_redeclare_exported_variable_0_2323", "Cannot redeclare exported variable '{0}'."),
                    Property_0_is_missing_in_type_1: diag(2324, 1 /* Error */, "Property_0_is_missing_in_type_1_2324", "Property '{0}' is missing in type '{1}'."),
                    Property_0_is_private_in_type_1_but_not_in_type_2: diag(2325, 1 /* Error */, "Property_0_is_private_in_type_1_but_not_in_type_2_2325", "Property '{0}' is private in type '{1}' but not in type '{2}'."),
                    Types_of_property_0_are_incompatible: diag(2326, 1 /* Error */, "Types_of_property_0_are_incompatible_2326", "Types of property '{0}' are incompatible."),
                    Property_0_is_optional_in_type_1_but_required_in_type_2: diag(2327, 1 /* Error */, "Property_0_is_optional_in_type_1_but_required_in_type_2_2327", "Property '{0}' is optional in type '{1}' but required in type '{2}'."),
                    Types_of_parameters_0_and_1_are_incompatible: diag(2328, 1 /* Error */, "Types_of_parameters_0_and_1_are_incompatible_2328", "Types of parameters '{0}' and '{1}' are incompatible."),
                    Index_signature_for_type_0_is_missing_in_type_1: diag(2329, 1 /* Error */, "Index_signature_for_type_0_is_missing_in_type_1_2329", "Index signature for type '{0}' is missing in type '{1}'."),
                    _0_and_1_index_signatures_are_incompatible: diag(2330, 1 /* Error */, "_0_and_1_index_signatures_are_incompatible_2330", "'{0}' and '{1}' index signatures are incompatible."),
                    this_cannot_be_referenced_in_a_module_or_namespace_body: diag(2331, 1 /* Error */, "this_cannot_be_referenced_in_a_module_or_namespace_body_2331", "'this' cannot be referenced in a module or namespace body."),
                    this_cannot_be_referenced_in_current_location: diag(2332, 1 /* Error */, "this_cannot_be_referenced_in_current_location_2332", "'this' cannot be referenced in current location."),
                    this_cannot_be_referenced_in_constructor_arguments: diag(2333, 1 /* Error */, "this_cannot_be_referenced_in_constructor_arguments_2333", "'this' cannot be referenced in constructor arguments."),
                    this_cannot_be_referenced_in_a_static_property_initializer: diag(2334, 1 /* Error */, "this_cannot_be_referenced_in_a_static_property_initializer_2334", "'this' cannot be referenced in a static property initializer."),
                    super_can_only_be_referenced_in_a_derived_class: diag(2335, 1 /* Error */, "super_can_only_be_referenced_in_a_derived_class_2335", "'super' can only be referenced in a derived class."),
                    super_cannot_be_referenced_in_constructor_arguments: diag(2336, 1 /* Error */, "super_cannot_be_referenced_in_constructor_arguments_2336", "'super' cannot be referenced in constructor arguments."),
                    Super_calls_are_not_permitted_outside_constructors_or_in_nested_functions_inside_constructors: diag(2337, 1 /* Error */, "Super_calls_are_not_permitted_outside_constructors_or_in_nested_functions_inside_constructors_2337", "Super calls are not permitted outside constructors or in nested functions inside constructors."),
                    super_property_access_is_permitted_only_in_a_constructor_member_function_or_member_accessor_of_a_derived_class: diag(2338, 1 /* Error */, "super_property_access_is_permitted_only_in_a_constructor_member_function_or_member_accessor_of_a_der_2338", "'super' property access is permitted only in a constructor, member function, or member accessor of a derived class."),
                    Property_0_does_not_exist_on_type_1: diag(2339, 1 /* Error */, "Property_0_does_not_exist_on_type_1_2339", "Property '{0}' does not exist on type '{1}'."),
                    Only_public_and_protected_methods_of_the_base_class_are_accessible_via_the_super_keyword: diag(2340, 1 /* Error */, "Only_public_and_protected_methods_of_the_base_class_are_accessible_via_the_super_keyword_2340", "Only public and protected methods of the base class are accessible via the 'super' keyword."),
                    Property_0_is_private_and_only_accessible_within_class_1: diag(2341, 1 /* Error */, "Property_0_is_private_and_only_accessible_within_class_1_2341", "Property '{0}' is private and only accessible within class '{1}'."),
                    This_syntax_requires_an_imported_helper_named_1_which_does_not_exist_in_0_Consider_upgrading_your_version_of_0: diag(2343, 1 /* Error */, "This_syntax_requires_an_imported_helper_named_1_which_does_not_exist_in_0_Consider_upgrading_your_ve_2343", "This syntax requires an imported helper named '{1}' which does not exist in '{0}'. Consider upgrading your version of '{0}'."),
                    Type_0_does_not_satisfy_the_constraint_1: diag(2344, 1 /* Error */, "Type_0_does_not_satisfy_the_constraint_1_2344", "Type '{0}' does not satisfy the constraint '{1}'."),
                    Argument_of_type_0_is_not_assignable_to_parameter_of_type_1: diag(2345, 1 /* Error */, "Argument_of_type_0_is_not_assignable_to_parameter_of_type_1_2345", "Argument of type '{0}' is not assignable to parameter of type '{1}'."),
                    Untyped_function_calls_may_not_accept_type_arguments: diag(2347, 1 /* Error */, "Untyped_function_calls_may_not_accept_type_arguments_2347", "Untyped function calls may not accept type arguments."),
                    Value_of_type_0_is_not_callable_Did_you_mean_to_include_new: diag(2348, 1 /* Error */, "Value_of_type_0_is_not_callable_Did_you_mean_to_include_new_2348", "Value of type '{0}' is not callable. Did you mean to include 'new'?"),
                    This_expression_is_not_callable: diag(2349, 1 /* Error */, "This_expression_is_not_callable_2349", "This expression is not callable."),
                    Only_a_void_function_can_be_called_with_the_new_keyword: diag(2350, 1 /* Error */, "Only_a_void_function_can_be_called_with_the_new_keyword_2350", "Only a void function can be called with the 'new' keyword."),
                    This_expression_is_not_constructable: diag(2351, 1 /* Error */, "This_expression_is_not_constructable_2351", "This expression is not constructable."),
                    Conversion_of_type_0_to_type_1_may_be_a_mistake_because_neither_type_sufficiently_overlaps_with_the_other_If_this_was_intentional_convert_the_expression_to_unknown_first: diag(2352, 1 /* Error */, "Conversion_of_type_0_to_type_1_may_be_a_mistake_because_neither_type_sufficiently_overlaps_with_the__2352", "Conversion of type '{0}' to type '{1}' may be a mistake because neither type sufficiently overlaps with the other. If this was intentional, convert the expression to 'unknown' first."),
                    Object_literal_may_only_specify_known_properties_and_0_does_not_exist_in_type_1: diag(2353, 1 /* Error */, "Object_literal_may_only_specify_known_properties_and_0_does_not_exist_in_type_1_2353", "Object literal may only specify known properties, and '{0}' does not exist in type '{1}'."),
                    This_syntax_requires_an_imported_helper_but_module_0_cannot_be_found: diag(2354, 1 /* Error */, "This_syntax_requires_an_imported_helper_but_module_0_cannot_be_found_2354", "This syntax requires an imported helper but module '{0}' cannot be found."),
                    A_function_whose_declared_type_is_neither_undefined_void_nor_any_must_return_a_value: diag(2355, 1 /* Error */, "A_function_whose_declared_type_is_neither_undefined_void_nor_any_must_return_a_value_2355", "A function whose declared type is neither 'undefined', 'void', nor 'any' must return a value."),
                    An_arithmetic_operand_must_be_of_type_any_number_bigint_or_an_enum_type: diag(2356, 1 /* Error */, "An_arithmetic_operand_must_be_of_type_any_number_bigint_or_an_enum_type_2356", "An arithmetic operand must be of type 'any', 'number', 'bigint' or an enum type."),
                    The_operand_of_an_increment_or_decrement_operator_must_be_a_variable_or_a_property_access: diag(2357, 1 /* Error */, "The_operand_of_an_increment_or_decrement_operator_must_be_a_variable_or_a_property_access_2357", "The operand of an increment or decrement operator must be a variable or a property access."),
                    The_left_hand_side_of_an_instanceof_expression_must_be_of_type_any_an_object_type_or_a_type_parameter: diag(2358, 1 /* Error */, "The_left_hand_side_of_an_instanceof_expression_must_be_of_type_any_an_object_type_or_a_type_paramete_2358", "The left-hand side of an 'instanceof' expression must be of type 'any', an object type or a type parameter."),
                    The_right_hand_side_of_an_instanceof_expression_must_be_either_of_type_any_a_class_function_or_other_type_assignable_to_the_Function_interface_type_or_an_object_type_with_a_Symbol_hasInstance_method: diag(2359, 1 /* Error */, "The_right_hand_side_of_an_instanceof_expression_must_be_either_of_type_any_a_class_function_or_other_2359", "The right-hand side of an 'instanceof' expression must be either of type 'any', a class, function, or other type assignable to the 'Function' interface type, or an object type with a 'Symbol.hasInstance' method."),
                    The_left_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type: diag(2362, 1 /* Error */, "The_left_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type_2362", "The left-hand side of an arithmetic operation must be of type 'any', 'number', 'bigint' or an enum type."),
                    The_right_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type: diag(2363, 1 /* Error */, "The_right_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type_2363", "The right-hand side of an arithmetic operation must be of type 'any', 'number', 'bigint' or an enum type."),
                    The_left_hand_side_of_an_assignment_expression_must_be_a_variable_or_a_property_access: diag(2364, 1 /* Error */, "The_left_hand_side_of_an_assignment_expression_must_be_a_variable_or_a_property_access_2364", "The left-hand side of an assignment expression must be a variable or a property access."),
                    Operator_0_cannot_be_applied_to_types_1_and_2: diag(2365, 1 /* Error */, "Operator_0_cannot_be_applied_to_types_1_and_2_2365", "Operator '{0}' cannot be applied to types '{1}' and '{2}'."),
                    Function_lacks_ending_return_statement_and_return_type_does_not_include_undefined: diag(2366, 1 /* Error */, "Function_lacks_ending_return_statement_and_return_type_does_not_include_undefined_2366", "Function lacks ending return statement and return type does not include 'undefined'."),
                    This_comparison_appears_to_be_unintentional_because_the_types_0_and_1_have_no_overlap: diag(2367, 1 /* Error */, "This_comparison_appears_to_be_unintentional_because_the_types_0_and_1_have_no_overlap_2367", "This comparison appears to be unintentional because the types '{0}' and '{1}' have no overlap."),
                    Type_parameter_name_cannot_be_0: diag(2368, 1 /* Error */, "Type_parameter_name_cannot_be_0_2368", "Type parameter name cannot be '{0}'."),
                    A_parameter_property_is_only_allowed_in_a_constructor_implementation: diag(2369, 1 /* Error */, "A_parameter_property_is_only_allowed_in_a_constructor_implementation_2369", "A parameter property is only allowed in a constructor implementation."),
                    A_rest_parameter_must_be_of_an_array_type: diag(2370, 1 /* Error */, "A_rest_parameter_must_be_of_an_array_type_2370", "A rest parameter must be of an array type."),
                    A_parameter_initializer_is_only_allowed_in_a_function_or_constructor_implementation: diag(2371, 1 /* Error */, "A_parameter_initializer_is_only_allowed_in_a_function_or_constructor_implementation_2371", "A parameter initializer is only allowed in a function or constructor implementation."),
                    Parameter_0_cannot_reference_itself: diag(2372, 1 /* Error */, "Parameter_0_cannot_reference_itself_2372", "Parameter '{0}' cannot reference itself."),
                    Parameter_0_cannot_reference_identifier_1_declared_after_it: diag(2373, 1 /* Error */, "Parameter_0_cannot_reference_identifier_1_declared_after_it_2373", "Parameter '{0}' cannot reference identifier '{1}' declared after it."),
                    Duplicate_index_signature_for_type_0: diag(2374, 1 /* Error */, "Duplicate_index_signature_for_type_0_2374", "Duplicate index signature for type '{0}'."),
                    Type_0_is_not_assignable_to_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_types_of_the_target_s_properties: diag(2375, 1 /* Error */, "Type_0_is_not_assignable_to_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefi_2375", "Type '{0}' is not assignable to type '{1}' with 'exactOptionalPropertyTypes: true'. Consider adding 'undefined' to the types of the target's properties."),
                    A_super_call_must_be_the_first_statement_in_the_constructor_to_refer_to_super_or_this_when_a_derived_class_contains_initialized_properties_parameter_properties_or_private_identifiers: diag(2376, 1 /* Error */, "A_super_call_must_be_the_first_statement_in_the_constructor_to_refer_to_super_or_this_when_a_derived_2376", "A 'super' call must be the first statement in the constructor to refer to 'super' or 'this' when a derived class contains initialized properties, parameter properties, or private identifiers."),
                    Constructors_for_derived_classes_must_contain_a_super_call: diag(2377, 1 /* Error */, "Constructors_for_derived_classes_must_contain_a_super_call_2377", "Constructors for derived classes must contain a 'super' call."),
                    A_get_accessor_must_return_a_value: diag(2378, 1 /* Error */, "A_get_accessor_must_return_a_value_2378", "A 'get' accessor must return a value."),
                    Argument_of_type_0_is_not_assignable_to_parameter_of_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_types_of_the_target_s_properties: diag(2379, 1 /* Error */, "Argument_of_type_0_is_not_assignable_to_parameter_of_type_1_with_exactOptionalPropertyTypes_Colon_tr_2379", "Argument of type '{0}' is not assignable to parameter of type '{1}' with 'exactOptionalPropertyTypes: true'. Consider adding 'undefined' to the types of the target's properties."),
                    Overload_signatures_must_all_be_exported_or_non_exported: diag(2383, 1 /* Error */, "Overload_signatures_must_all_be_exported_or_non_exported_2383", "Overload signatures must all be exported or non-exported."),
                    Overload_signatures_must_all_be_ambient_or_non_ambient: diag(2384, 1 /* Error */, "Overload_signatures_must_all_be_ambient_or_non_ambient_2384", "Overload signatures must all be ambient or non-ambient."),
                    Overload_signatures_must_all_be_public_private_or_protected: diag(2385, 1 /* Error */, "Overload_signatures_must_all_be_public_private_or_protected_2385", "Overload signatures must all be public, private or protected."),
                    Overload_signatures_must_all_be_optional_or_required: diag(2386, 1 /* Error */, "Overload_signatures_must_all_be_optional_or_required_2386", "Overload signatures must all be optional or required."),
                    Function_overload_must_be_static: diag(2387, 1 /* Error */, "Function_overload_must_be_static_2387", "Function overload must be static."),
                    Function_overload_must_not_be_static: diag(2388, 1 /* Error */, "Function_overload_must_not_be_static_2388", "Function overload must not be static."),
                    Function_implementation_name_must_be_0: diag(2389, 1 /* Error */, "Function_implementation_name_must_be_0_2389", "Function implementation name must be '{0}'."),
                    Constructor_implementation_is_missing: diag(2390, 1 /* Error */, "Constructor_implementation_is_missing_2390", "Constructor implementation is missing."),
                    Function_implementation_is_missing_or_not_immediately_following_the_declaration: diag(2391, 1 /* Error */, "Function_implementation_is_missing_or_not_immediately_following_the_declaration_2391", "Function implementation is missing or not immediately following the declaration."),
                    Multiple_constructor_implementations_are_not_allowed: diag(2392, 1 /* Error */, "Multiple_constructor_implementations_are_not_allowed_2392", "Multiple constructor implementations are not allowed."),
                    Duplicate_function_implementation: diag(2393, 1 /* Error */, "Duplicate_function_implementation_2393", "Duplicate function implementation."),
                    This_overload_signature_is_not_compatible_with_its_implementation_signature: diag(2394, 1 /* Error */, "This_overload_signature_is_not_compatible_with_its_implementation_signature_2394", "This overload signature is not compatible with its implementation signature."),
                    Individual_declarations_in_merged_declaration_0_must_be_all_exported_or_all_local: diag(2395, 1 /* Error */, "Individual_declarations_in_merged_declaration_0_must_be_all_exported_or_all_local_2395", "Individual declarations in merged declaration '{0}' must be all exported or all local."),
                    Duplicate_identifier_arguments_Compiler_uses_arguments_to_initialize_rest_parameters: diag(2396, 1 /* Error */, "Duplicate_identifier_arguments_Compiler_uses_arguments_to_initialize_rest_parameters_2396", "Duplicate identifier 'arguments'. Compiler uses 'arguments' to initialize rest parameters."),
                    Declaration_name_conflicts_with_built_in_global_identifier_0: diag(2397, 1 /* Error */, "Declaration_name_conflicts_with_built_in_global_identifier_0_2397", "Declaration name conflicts with built-in global identifier '{0}'."),
                    constructor_cannot_be_used_as_a_parameter_property_name: diag(2398, 1 /* Error */, "constructor_cannot_be_used_as_a_parameter_property_name_2398", "'constructor' cannot be used as a parameter property name."),
                    Duplicate_identifier_this_Compiler_uses_variable_declaration_this_to_capture_this_reference: diag(2399, 1 /* Error */, "Duplicate_identifier_this_Compiler_uses_variable_declaration_this_to_capture_this_reference_2399", "Duplicate identifier '_this'. Compiler uses variable declaration '_this' to capture 'this' reference."),
                    Expression_resolves_to_variable_declaration_this_that_compiler_uses_to_capture_this_reference: diag(2400, 1 /* Error */, "Expression_resolves_to_variable_declaration_this_that_compiler_uses_to_capture_this_reference_2400", "Expression resolves to variable declaration '_this' that compiler uses to capture 'this' reference."),
                    A_super_call_must_be_a_root_level_statement_within_a_constructor_of_a_derived_class_that_contains_initialized_properties_parameter_properties_or_private_identifiers: diag(2401, 1 /* Error */, "A_super_call_must_be_a_root_level_statement_within_a_constructor_of_a_derived_class_that_contains_in_2401", "A 'super' call must be a root-level statement within a constructor of a derived class that contains initialized properties, parameter properties, or private identifiers."),
                    Expression_resolves_to_super_that_compiler_uses_to_capture_base_class_reference: diag(2402, 1 /* Error */, "Expression_resolves_to_super_that_compiler_uses_to_capture_base_class_reference_2402", "Expression resolves to '_super' that compiler uses to capture base class reference."),
                    Subsequent_variable_declarations_must_have_the_same_type_Variable_0_must_be_of_type_1_but_here_has_type_2: diag(2403, 1 /* Error */, "Subsequent_variable_declarations_must_have_the_same_type_Variable_0_must_be_of_type_1_but_here_has_t_2403", "Subsequent variable declarations must have the same type.  Variable '{0}' must be of type '{1}', but here has type '{2}'."),
                    The_left_hand_side_of_a_for_in_statement_cannot_use_a_type_annotation: diag(2404, 1 /* Error */, "The_left_hand_side_of_a_for_in_statement_cannot_use_a_type_annotation_2404", "The left-hand side of a 'for...in' statement cannot use a type annotation."),
                    The_left_hand_side_of_a_for_in_statement_must_be_of_type_string_or_any: diag(2405, 1 /* Error */, "The_left_hand_side_of_a_for_in_statement_must_be_of_type_string_or_any_2405", "The left-hand side of a 'for...in' statement must be of type 'string' or 'any'."),
                    The_left_hand_side_of_a_for_in_statement_must_be_a_variable_or_a_property_access: diag(2406, 1 /* Error */, "The_left_hand_side_of_a_for_in_statement_must_be_a_variable_or_a_property_access_2406", "The left-hand side of a 'for...in' statement must be a variable or a property access."),
                    The_right_hand_side_of_a_for_in_statement_must_be_of_type_any_an_object_type_or_a_type_parameter_but_here_has_type_0: diag(2407, 1 /* Error */, "The_right_hand_side_of_a_for_in_statement_must_be_of_type_any_an_object_type_or_a_type_parameter_but_2407", "The right-hand side of a 'for...in' statement must be of type 'any', an object type or a type parameter, but here has type '{0}'."),
                    Setters_cannot_return_a_value: diag(2408, 1 /* Error */, "Setters_cannot_return_a_value_2408", "Setters cannot return a value."),
                    Return_type_of_constructor_signature_must_be_assignable_to_the_instance_type_of_the_class: diag(2409, 1 /* Error */, "Return_type_of_constructor_signature_must_be_assignable_to_the_instance_type_of_the_class_2409", "Return type of constructor signature must be assignable to the instance type of the class."),
                    The_with_statement_is_not_supported_All_symbols_in_a_with_block_will_have_type_any: diag(2410, 1 /* Error */, "The_with_statement_is_not_supported_All_symbols_in_a_with_block_will_have_type_any_2410", "The 'with' statement is not supported. All symbols in a 'with' block will have type 'any'."),
                    Type_0_is_not_assignable_to_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_type_of_the_target: diag(2412, 1 /* Error */, "Type_0_is_not_assignable_to_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefi_2412", "Type '{0}' is not assignable to type '{1}' with 'exactOptionalPropertyTypes: true'. Consider adding 'undefined' to the type of the target."),
                    Property_0_of_type_1_is_not_assignable_to_2_index_type_3: diag(2411, 1 /* Error */, "Property_0_of_type_1_is_not_assignable_to_2_index_type_3_2411", "Property '{0}' of type '{1}' is not assignable to '{2}' index type '{3}'."),
                    _0_index_type_1_is_not_assignable_to_2_index_type_3: diag(2413, 1 /* Error */, "_0_index_type_1_is_not_assignable_to_2_index_type_3_2413", "'{0}' index type '{1}' is not assignable to '{2}' index type '{3}'."),
                    Class_name_cannot_be_0: diag(2414, 1 /* Error */, "Class_name_cannot_be_0_2414", "Class name cannot be '{0}'."),
                    Class_0_incorrectly_extends_base_class_1: diag(2415, 1 /* Error */, "Class_0_incorrectly_extends_base_class_1_2415", "Class '{0}' incorrectly extends base class '{1}'."),
                    Property_0_in_type_1_is_not_assignable_to_the_same_property_in_base_type_2: diag(2416, 1 /* Error */, "Property_0_in_type_1_is_not_assignable_to_the_same_property_in_base_type_2_2416", "Property '{0}' in type '{1}' is not assignable to the same property in base type '{2}'."),
                    Class_static_side_0_incorrectly_extends_base_class_static_side_1: diag(2417, 1 /* Error */, "Class_static_side_0_incorrectly_extends_base_class_static_side_1_2417", "Class static side '{0}' incorrectly extends base class static side '{1}'."),
                    Type_of_computed_property_s_value_is_0_which_is_not_assignable_to_type_1: diag(2418, 1 /* Error */, "Type_of_computed_property_s_value_is_0_which_is_not_assignable_to_type_1_2418", "Type of computed property's value is '{0}', which is not assignable to type '{1}'."),
                    Types_of_construct_signatures_are_incompatible: diag(2419, 1 /* Error */, "Types_of_construct_signatures_are_incompatible_2419", "Types of construct signatures are incompatible."),
                    Class_0_incorrectly_implements_interface_1: diag(2420, 1 /* Error */, "Class_0_incorrectly_implements_interface_1_2420", "Class '{0}' incorrectly implements interface '{1}'."),
                    A_class_can_only_implement_an_object_type_or_intersection_of_object_types_with_statically_known_members: diag(2422, 1 /* Error */, "A_class_can_only_implement_an_object_type_or_intersection_of_object_types_with_statically_known_memb_2422", "A class can only implement an object type or intersection of object types with statically known members."),
                    Class_0_defines_instance_member_function_1_but_extended_class_2_defines_it_as_instance_member_accessor: diag(2423, 1 /* Error */, "Class_0_defines_instance_member_function_1_but_extended_class_2_defines_it_as_instance_member_access_2423", "Class '{0}' defines instance member function '{1}', but extended class '{2}' defines it as instance member accessor."),
                    Class_0_defines_instance_member_property_1_but_extended_class_2_defines_it_as_instance_member_function: diag(2425, 1 /* Error */, "Class_0_defines_instance_member_property_1_but_extended_class_2_defines_it_as_instance_member_functi_2425", "Class '{0}' defines instance member property '{1}', but extended class '{2}' defines it as instance member function."),
                    Class_0_defines_instance_member_accessor_1_but_extended_class_2_defines_it_as_instance_member_function: diag(2426, 1 /* Error */, "Class_0_defines_instance_member_accessor_1_but_extended_class_2_defines_it_as_instance_member_functi_2426", "Class '{0}' defines instance member accessor '{1}', but extended class '{2}' defines it as instance member function."),
                    Interface_name_cannot_be_0: diag(2427, 1 /* Error */, "Interface_name_cannot_be_0_2427", "Interface name cannot be '{0}'."),
                    All_declarations_of_0_must_have_identical_type_parameters: diag(2428, 1 /* Error */, "All_declarations_of_0_must_have_identical_type_parameters_2428", "All declarations of '{0}' must have identical type parameters."),
                    Interface_0_incorrectly_extends_interface_1: diag(2430, 1 /* Error */, "Interface_0_incorrectly_extends_interface_1_2430", "Interface '{0}' incorrectly extends interface '{1}'."),
                    Enum_name_cannot_be_0: diag(2431, 1 /* Error */, "Enum_name_cannot_be_0_2431", "Enum name cannot be '{0}'."),
                    In_an_enum_with_multiple_declarations_only_one_declaration_can_omit_an_initializer_for_its_first_enum_element: diag(2432, 1 /* Error */, "In_an_enum_with_multiple_declarations_only_one_declaration_can_omit_an_initializer_for_its_first_enu_2432", "In an enum with multiple declarations, only one declaration can omit an initializer for its first enum element."),
                    A_namespace_declaration_cannot_be_in_a_different_file_from_a_class_or_function_with_which_it_is_merged: diag(2433, 1 /* Error */, "A_namespace_declaration_cannot_be_in_a_different_file_from_a_class_or_function_with_which_it_is_merg_2433", "A namespace declaration cannot be in a different file from a class or function with which it is merged."),
                    A_namespace_declaration_cannot_be_located_prior_to_a_class_or_function_with_which_it_is_merged: diag(2434, 1 /* Error */, "A_namespace_declaration_cannot_be_located_prior_to_a_class_or_function_with_which_it_is_merged_2434", "A namespace declaration cannot be located prior to a class or function with which it is merged."),
                    Ambient_modules_cannot_be_nested_in_other_modules_or_namespaces: diag(2435, 1 /* Error */, "Ambient_modules_cannot_be_nested_in_other_modules_or_namespaces_2435", "Ambient modules cannot be nested in other modules or namespaces."),
                    Ambient_module_declaration_cannot_specify_relative_module_name: diag(2436, 1 /* Error */, "Ambient_module_declaration_cannot_specify_relative_module_name_2436", "Ambient module declaration cannot specify relative module name."),
                    Module_0_is_hidden_by_a_local_declaration_with_the_same_name: diag(2437, 1 /* Error */, "Module_0_is_hidden_by_a_local_declaration_with_the_same_name_2437", "Module '{0}' is hidden by a local declaration with the same name."),
                    Import_name_cannot_be_0: diag(2438, 1 /* Error */, "Import_name_cannot_be_0_2438", "Import name cannot be '{0}'."),
                    Import_or_export_declaration_in_an_ambient_module_declaration_cannot_reference_module_through_relative_module_name: diag(2439, 1 /* Error */, "Import_or_export_declaration_in_an_ambient_module_declaration_cannot_reference_module_through_relati_2439", "Import or export declaration in an ambient module declaration cannot reference module through relative module name."),
                    Import_declaration_conflicts_with_local_declaration_of_0: diag(2440, 1 /* Error */, "Import_declaration_conflicts_with_local_declaration_of_0_2440", "Import declaration conflicts with local declaration of '{0}'."),
                    Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module: diag(2441, 1 /* Error */, "Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module_2441", "Duplicate identifier '{0}'. Compiler reserves name '{1}' in top level scope of a module."),
                    Types_have_separate_declarations_of_a_private_property_0: diag(2442, 1 /* Error */, "Types_have_separate_declarations_of_a_private_property_0_2442", "Types have separate declarations of a private property '{0}'."),
                    Property_0_is_protected_but_type_1_is_not_a_class_derived_from_2: diag(2443, 1 /* Error */, "Property_0_is_protected_but_type_1_is_not_a_class_derived_from_2_2443", "Property '{0}' is protected but type '{1}' is not a class derived from '{2}'."),
                    Property_0_is_protected_in_type_1_but_public_in_type_2: diag(2444, 1 /* Error */, "Property_0_is_protected_in_type_1_but_public_in_type_2_2444", "Property '{0}' is protected in type '{1}' but public in type '{2}'."),
                    Property_0_is_protected_and_only_accessible_within_class_1_and_its_subclasses: diag(2445, 1 /* Error */, "Property_0_is_protected_and_only_accessible_within_class_1_and_its_subclasses_2445", "Property '{0}' is protected and only accessible within class '{1}' and its subclasses."),
                    Property_0_is_protected_and_only_accessible_through_an_instance_of_class_1_This_is_an_instance_of_class_2: diag(2446, 1 /* Error */, "Property_0_is_protected_and_only_accessible_through_an_instance_of_class_1_This_is_an_instance_of_cl_2446", "Property '{0}' is protected and only accessible through an instance of class '{1}'. This is an instance of class '{2}'."),
                    The_0_operator_is_not_allowed_for_boolean_types_Consider_using_1_instead: diag(2447, 1 /* Error */, "The_0_operator_is_not_allowed_for_boolean_types_Consider_using_1_instead_2447", "The '{0}' operator is not allowed for boolean types. Consider using '{1}' instead."),
                    Block_scoped_variable_0_used_before_its_declaration: diag(2448, 1 /* Error */, "Block_scoped_variable_0_used_before_its_declaration_2448", "Block-scoped variable '{0}' used before its declaration."),
                    Class_0_used_before_its_declaration: diag(2449, 1 /* Error */, "Class_0_used_before_its_declaration_2449", "Class '{0}' used before its declaration."),
                    Enum_0_used_before_its_declaration: diag(2450, 1 /* Error */, "Enum_0_used_before_its_declaration_2450", "Enum '{0}' used before its declaration."),
                    Cannot_redeclare_block_scoped_variable_0: diag(2451, 1 /* Error */, "Cannot_redeclare_block_scoped_variable_0_2451", "Cannot redeclare block-scoped variable '{0}'."),
                    An_enum_member_cannot_have_a_numeric_name: diag(2452, 1 /* Error */, "An_enum_member_cannot_have_a_numeric_name_2452", "An enum member cannot have a numeric name."),
                    Variable_0_is_used_before_being_assigned: diag(2454, 1 /* Error */, "Variable_0_is_used_before_being_assigned_2454", "Variable '{0}' is used before being assigned."),
                    Type_alias_0_circularly_references_itself: diag(2456, 1 /* Error */, "Type_alias_0_circularly_references_itself_2456", "Type alias '{0}' circularly references itself."),
                    Type_alias_name_cannot_be_0: diag(2457, 1 /* Error */, "Type_alias_name_cannot_be_0_2457", "Type alias name cannot be '{0}'."),
                    An_AMD_module_cannot_have_multiple_name_assignments: diag(2458, 1 /* Error */, "An_AMD_module_cannot_have_multiple_name_assignments_2458", "An AMD module cannot have multiple name assignments."),
                    Module_0_declares_1_locally_but_it_is_not_exported: diag(2459, 1 /* Error */, "Module_0_declares_1_locally_but_it_is_not_exported_2459", "Module '{0}' declares '{1}' locally, but it is not exported."),
                    Module_0_declares_1_locally_but_it_is_exported_as_2: diag(2460, 1 /* Error */, "Module_0_declares_1_locally_but_it_is_exported_as_2_2460", "Module '{0}' declares '{1}' locally, but it is exported as '{2}'."),
                    Type_0_is_not_an_array_type: diag(2461, 1 /* Error */, "Type_0_is_not_an_array_type_2461", "Type '{0}' is not an array type."),
                    A_rest_element_must_be_last_in_a_destructuring_pattern: diag(2462, 1 /* Error */, "A_rest_element_must_be_last_in_a_destructuring_pattern_2462", "A rest element must be last in a destructuring pattern."),
                    A_binding_pattern_parameter_cannot_be_optional_in_an_implementation_signature: diag(2463, 1 /* Error */, "A_binding_pattern_parameter_cannot_be_optional_in_an_implementation_signature_2463", "A binding pattern parameter cannot be optional in an implementation signature."),
                    A_computed_property_name_must_be_of_type_string_number_symbol_or_any: diag(2464, 1 /* Error */, "A_computed_property_name_must_be_of_type_string_number_symbol_or_any_2464", "A computed property name must be of type 'string', 'number', 'symbol', or 'any'."),
                    this_cannot_be_referenced_in_a_computed_property_name: diag(2465, 1 /* Error */, "this_cannot_be_referenced_in_a_computed_property_name_2465", "'this' cannot be referenced in a computed property name."),
                    super_cannot_be_referenced_in_a_computed_property_name: diag(2466, 1 /* Error */, "super_cannot_be_referenced_in_a_computed_property_name_2466", "'super' cannot be referenced in a computed property name."),
                    A_computed_property_name_cannot_reference_a_type_parameter_from_its_containing_type: diag(2467, 1 /* Error */, "A_computed_property_name_cannot_reference_a_type_parameter_from_its_containing_type_2467", "A computed property name cannot reference a type parameter from its containing type."),
                    Cannot_find_global_value_0: diag(2468, 1 /* Error */, "Cannot_find_global_value_0_2468", "Cannot find global value '{0}'."),
                    The_0_operator_cannot_be_applied_to_type_symbol: diag(2469, 1 /* Error */, "The_0_operator_cannot_be_applied_to_type_symbol_2469", "The '{0}' operator cannot be applied to type 'symbol'."),
                    Spread_operator_in_new_expressions_is_only_available_when_targeting_ECMAScript_5_and_higher: diag(2472, 1 /* Error */, "Spread_operator_in_new_expressions_is_only_available_when_targeting_ECMAScript_5_and_higher_2472", "Spread operator in 'new' expressions is only available when targeting ECMAScript 5 and higher."),
                    Enum_declarations_must_all_be_const_or_non_const: diag(2473, 1 /* Error */, "Enum_declarations_must_all_be_const_or_non_const_2473", "Enum declarations must all be const or non-const."),
                    const_enum_member_initializers_must_be_constant_expressions: diag(2474, 1 /* Error */, "const_enum_member_initializers_must_be_constant_expressions_2474", "const enum member initializers must be constant expressions."),
                    const_enums_can_only_be_used_in_property_or_index_access_expressions_or_the_right_hand_side_of_an_import_declaration_or_export_assignment_or_type_query: diag(2475, 1 /* Error */, "const_enums_can_only_be_used_in_property_or_index_access_expressions_or_the_right_hand_side_of_an_im_2475", "'const' enums can only be used in property or index access expressions or the right hand side of an import declaration or export assignment or type query."),
                    A_const_enum_member_can_only_be_accessed_using_a_string_literal: diag(2476, 1 /* Error */, "A_const_enum_member_can_only_be_accessed_using_a_string_literal_2476", "A const enum member can only be accessed using a string literal."),
                    const_enum_member_initializer_was_evaluated_to_a_non_finite_value: diag(2477, 1 /* Error */, "const_enum_member_initializer_was_evaluated_to_a_non_finite_value_2477", "'const' enum member initializer was evaluated to a non-finite value."),
                    const_enum_member_initializer_was_evaluated_to_disallowed_value_NaN: diag(2478, 1 /* Error */, "const_enum_member_initializer_was_evaluated_to_disallowed_value_NaN_2478", "'const' enum member initializer was evaluated to disallowed value 'NaN'."),
                    let_is_not_allowed_to_be_used_as_a_name_in_let_or_const_declarations: diag(2480, 1 /* Error */, "let_is_not_allowed_to_be_used_as_a_name_in_let_or_const_declarations_2480", "'let' is not allowed to be used as a name in 'let' or 'const' declarations."),
                    Cannot_initialize_outer_scoped_variable_0_in_the_same_scope_as_block_scoped_declaration_1: diag(2481, 1 /* Error */, "Cannot_initialize_outer_scoped_variable_0_in_the_same_scope_as_block_scoped_declaration_1_2481", "Cannot initialize outer scoped variable '{0}' in the same scope as block scoped declaration '{1}'."),
                    The_left_hand_side_of_a_for_of_statement_cannot_use_a_type_annotation: diag(2483, 1 /* Error */, "The_left_hand_side_of_a_for_of_statement_cannot_use_a_type_annotation_2483", "The left-hand side of a 'for...of' statement cannot use a type annotation."),
                    Export_declaration_conflicts_with_exported_declaration_of_0: diag(2484, 1 /* Error */, "Export_declaration_conflicts_with_exported_declaration_of_0_2484", "Export declaration conflicts with exported declaration of '{0}'."),
                    The_left_hand_side_of_a_for_of_statement_must_be_a_variable_or_a_property_access: diag(2487, 1 /* Error */, "The_left_hand_side_of_a_for_of_statement_must_be_a_variable_or_a_property_access_2487", "The left-hand side of a 'for...of' statement must be a variable or a property access."),
                    Type_0_must_have_a_Symbol_iterator_method_that_returns_an_iterator: diag(2488, 1 /* Error */, "Type_0_must_have_a_Symbol_iterator_method_that_returns_an_iterator_2488", "Type '{0}' must have a '[Symbol.iterator]()' method that returns an iterator."),
                    An_iterator_must_have_a_next_method: diag(2489, 1 /* Error */, "An_iterator_must_have_a_next_method_2489", "An iterator must have a 'next()' method."),
                    The_type_returned_by_the_0_method_of_an_iterator_must_have_a_value_property: diag(2490, 1 /* Error */, "The_type_returned_by_the_0_method_of_an_iterator_must_have_a_value_property_2490", "The type returned by the '{0}()' method of an iterator must have a 'value' property."),
                    The_left_hand_side_of_a_for_in_statement_cannot_be_a_destructuring_pattern: diag(2491, 1 /* Error */, "The_left_hand_side_of_a_for_in_statement_cannot_be_a_destructuring_pattern_2491", "The left-hand side of a 'for...in' statement cannot be a destructuring pattern."),
                    Cannot_redeclare_identifier_0_in_catch_clause: diag(2492, 1 /* Error */, "Cannot_redeclare_identifier_0_in_catch_clause_2492", "Cannot redeclare identifier '{0}' in catch clause."),
                    Tuple_type_0_of_length_1_has_no_element_at_index_2: diag(2493, 1 /* Error */, "Tuple_type_0_of_length_1_has_no_element_at_index_2_2493", "Tuple type '{0}' of length '{1}' has no element at index '{2}'."),
                    Using_a_string_in_a_for_of_statement_is_only_supported_in_ECMAScript_5_and_higher: diag(2494, 1 /* Error */, "Using_a_string_in_a_for_of_statement_is_only_supported_in_ECMAScript_5_and_higher_2494", "Using a string in a 'for...of' statement is only supported in ECMAScript 5 and higher."),
                    Type_0_is_not_an_array_type_or_a_string_type: diag(2495, 1 /* Error */, "Type_0_is_not_an_array_type_or_a_string_type_2495", "Type '{0}' is not an array type or a string type."),
                    The_arguments_object_cannot_be_referenced_in_an_arrow_function_in_ES3_and_ES5_Consider_using_a_standard_function_expression: diag(2496, 1 /* Error */, "The_arguments_object_cannot_be_referenced_in_an_arrow_function_in_ES3_and_ES5_Consider_using_a_stand_2496", "The 'arguments' object cannot be referenced in an arrow function in ES3 and ES5. Consider using a standard function expression."),
                    This_module_can_only_be_referenced_with_ECMAScript_imports_Slashexports_by_turning_on_the_0_flag_and_referencing_its_default_export: diag(2497, 1 /* Error */, "This_module_can_only_be_referenced_with_ECMAScript_imports_Slashexports_by_turning_on_the_0_flag_and_2497", "This module can only be referenced with ECMAScript imports/exports by turning on the '{0}' flag and referencing its default export."),
                    Module_0_uses_export_and_cannot_be_used_with_export_Asterisk: diag(2498, 1 /* Error */, "Module_0_uses_export_and_cannot_be_used_with_export_Asterisk_2498", "Module '{0}' uses 'export =' and cannot be used with 'export *'."),
                    An_interface_can_only_extend_an_identifier_Slashqualified_name_with_optional_type_arguments: diag(2499, 1 /* Error */, "An_interface_can_only_extend_an_identifier_Slashqualified_name_with_optional_type_arguments_2499", "An interface can only extend an identifier/qualified-name with optional type arguments."),
                    A_class_can_only_implement_an_identifier_Slashqualified_name_with_optional_type_arguments: diag(2500, 1 /* Error */, "A_class_can_only_implement_an_identifier_Slashqualified_name_with_optional_type_arguments_2500", "A class can only implement an identifier/qualified-name with optional type arguments."),
                    A_rest_element_cannot_contain_a_binding_pattern: diag(2501, 1 /* Error */, "A_rest_element_cannot_contain_a_binding_pattern_2501", "A rest element cannot contain a binding pattern."),
                    _0_is_referenced_directly_or_indirectly_in_its_own_type_annotation: diag(2502, 1 /* Error */, "_0_is_referenced_directly_or_indirectly_in_its_own_type_annotation_2502", "'{0}' is referenced directly or indirectly in its own type annotation."),
                    Cannot_find_namespace_0: diag(2503, 1 /* Error */, "Cannot_find_namespace_0_2503", "Cannot find namespace '{0}'."),
                    Type_0_must_have_a_Symbol_asyncIterator_method_that_returns_an_async_iterator: diag(2504, 1 /* Error */, "Type_0_must_have_a_Symbol_asyncIterator_method_that_returns_an_async_iterator_2504", "Type '{0}' must have a '[Symbol.asyncIterator]()' method that returns an async iterator."),
                    A_generator_cannot_have_a_void_type_annotation: diag(2505, 1 /* Error */, "A_generator_cannot_have_a_void_type_annotation_2505", "A generator cannot have a 'void' type annotation."),
                    _0_is_referenced_directly_or_indirectly_in_its_own_base_expression: diag(2506, 1 /* Error */, "_0_is_referenced_directly_or_indirectly_in_its_own_base_expression_2506", "'{0}' is referenced directly or indirectly in its own base expression."),
                    Type_0_is_not_a_constructor_function_type: diag(2507, 1 /* Error */, "Type_0_is_not_a_constructor_function_type_2507", "Type '{0}' is not a constructor function type."),
                    No_base_constructor_has_the_specified_number_of_type_arguments: diag(2508, 1 /* Error */, "No_base_constructor_has_the_specified_number_of_type_arguments_2508", "No base constructor has the specified number of type arguments."),
                    Base_constructor_return_type_0_is_not_an_object_type_or_intersection_of_object_types_with_statically_known_members: diag(2509, 1 /* Error */, "Base_constructor_return_type_0_is_not_an_object_type_or_intersection_of_object_types_with_statically_2509", "Base constructor return type '{0}' is not an object type or intersection of object types with statically known members."),
                    Base_constructors_must_all_have_the_same_return_type: diag(2510, 1 /* Error */, "Base_constructors_must_all_have_the_same_return_type_2510", "Base constructors must all have the same return type."),
                    Cannot_create_an_instance_of_an_abstract_class: diag(2511, 1 /* Error */, "Cannot_create_an_instance_of_an_abstract_class_2511", "Cannot create an instance of an abstract class."),
                    Overload_signatures_must_all_be_abstract_or_non_abstract: diag(2512, 1 /* Error */, "Overload_signatures_must_all_be_abstract_or_non_abstract_2512", "Overload signatures must all be abstract or non-abstract."),
                    Abstract_method_0_in_class_1_cannot_be_accessed_via_super_expression: diag(2513, 1 /* Error */, "Abstract_method_0_in_class_1_cannot_be_accessed_via_super_expression_2513", "Abstract method '{0}' in class '{1}' cannot be accessed via super expression."),
                    A_tuple_type_cannot_be_indexed_with_a_negative_value: diag(2514, 1 /* Error */, "A_tuple_type_cannot_be_indexed_with_a_negative_value_2514", "A tuple type cannot be indexed with a negative value."),
                    Non_abstract_class_0_does_not_implement_inherited_abstract_member_1_from_class_2: diag(2515, 1 /* Error */, "Non_abstract_class_0_does_not_implement_inherited_abstract_member_1_from_class_2_2515", "Non-abstract class '{0}' does not implement inherited abstract member '{1}' from class '{2}'."),
                    All_declarations_of_an_abstract_method_must_be_consecutive: diag(2516, 1 /* Error */, "All_declarations_of_an_abstract_method_must_be_consecutive_2516", "All declarations of an abstract method must be consecutive."),
                    Cannot_assign_an_abstract_constructor_type_to_a_non_abstract_constructor_type: diag(2517, 1 /* Error */, "Cannot_assign_an_abstract_constructor_type_to_a_non_abstract_constructor_type_2517", "Cannot assign an abstract constructor type to a non-abstract constructor type."),
                    A_this_based_type_guard_is_not_compatible_with_a_parameter_based_type_guard: diag(2518, 1 /* Error */, "A_this_based_type_guard_is_not_compatible_with_a_parameter_based_type_guard_2518", "A 'this'-based type guard is not compatible with a parameter-based type guard."),
                    An_async_iterator_must_have_a_next_method: diag(2519, 1 /* Error */, "An_async_iterator_must_have_a_next_method_2519", "An async iterator must have a 'next()' method."),
                    Duplicate_identifier_0_Compiler_uses_declaration_1_to_support_async_functions: diag(2520, 1 /* Error */, "Duplicate_identifier_0_Compiler_uses_declaration_1_to_support_async_functions_2520", "Duplicate identifier '{0}'. Compiler uses declaration '{1}' to support async functions."),
                    The_arguments_object_cannot_be_referenced_in_an_async_function_or_method_in_ES3_and_ES5_Consider_using_a_standard_function_or_method: diag(2522, 1 /* Error */, "The_arguments_object_cannot_be_referenced_in_an_async_function_or_method_in_ES3_and_ES5_Consider_usi_2522", "The 'arguments' object cannot be referenced in an async function or method in ES3 and ES5. Consider using a standard function or method."),
                    yield_expressions_cannot_be_used_in_a_parameter_initializer: diag(2523, 1 /* Error */, "yield_expressions_cannot_be_used_in_a_parameter_initializer_2523", "'yield' expressions cannot be used in a parameter initializer."),
                    await_expressions_cannot_be_used_in_a_parameter_initializer: diag(2524, 1 /* Error */, "await_expressions_cannot_be_used_in_a_parameter_initializer_2524", "'await' expressions cannot be used in a parameter initializer."),
                    Initializer_provides_no_value_for_this_binding_element_and_the_binding_element_has_no_default_value: diag(2525, 1 /* Error */, "Initializer_provides_no_value_for_this_binding_element_and_the_binding_element_has_no_default_value_2525", "Initializer provides no value for this binding element and the binding element has no default value."),
                    A_this_type_is_available_only_in_a_non_static_member_of_a_class_or_interface: diag(2526, 1 /* Error */, "A_this_type_is_available_only_in_a_non_static_member_of_a_class_or_interface_2526", "A 'this' type is available only in a non-static member of a class or interface."),
                    The_inferred_type_of_0_references_an_inaccessible_1_type_A_type_annotation_is_necessary: diag(2527, 1 /* Error */, "The_inferred_type_of_0_references_an_inaccessible_1_type_A_type_annotation_is_necessary_2527", "The inferred type of '{0}' references an inaccessible '{1}' type. A type annotation is necessary."),
                    A_module_cannot_have_multiple_default_exports: diag(2528, 1 /* Error */, "A_module_cannot_have_multiple_default_exports_2528", "A module cannot have multiple default exports."),
                    Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module_containing_async_functions: diag(2529, 1 /* Error */, "Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module_containing_async_func_2529", "Duplicate identifier '{0}'. Compiler reserves name '{1}' in top level scope of a module containing async functions."),
                    Property_0_is_incompatible_with_index_signature: diag(2530, 1 /* Error */, "Property_0_is_incompatible_with_index_signature_2530", "Property '{0}' is incompatible with index signature."),
                    Object_is_possibly_null: diag(2531, 1 /* Error */, "Object_is_possibly_null_2531", "Object is possibly 'null'."),
                    Object_is_possibly_undefined: diag(2532, 1 /* Error */, "Object_is_possibly_undefined_2532", "Object is possibly 'undefined'."),
                    Object_is_possibly_null_or_undefined: diag(2533, 1 /* Error */, "Object_is_possibly_null_or_undefined_2533", "Object is possibly 'null' or 'undefined'."),
                    A_function_returning_never_cannot_have_a_reachable_end_point: diag(2534, 1 /* Error */, "A_function_returning_never_cannot_have_a_reachable_end_point_2534", "A function returning 'never' cannot have a reachable end point."),
                    Type_0_cannot_be_used_to_index_type_1: diag(2536, 1 /* Error */, "Type_0_cannot_be_used_to_index_type_1_2536", "Type '{0}' cannot be used to index type '{1}'."),
                    Type_0_has_no_matching_index_signature_for_type_1: diag(2537, 1 /* Error */, "Type_0_has_no_matching_index_signature_for_type_1_2537", "Type '{0}' has no matching index signature for type '{1}'."),
                    Type_0_cannot_be_used_as_an_index_type: diag(2538, 1 /* Error */, "Type_0_cannot_be_used_as_an_index_type_2538", "Type '{0}' cannot be used as an index type."),
                    Cannot_assign_to_0_because_it_is_not_a_variable: diag(2539, 1 /* Error */, "Cannot_assign_to_0_because_it_is_not_a_variable_2539", "Cannot assign to '{0}' because it is not a variable."),
                    Cannot_assign_to_0_because_it_is_a_read_only_property: diag(2540, 1 /* Error */, "Cannot_assign_to_0_because_it_is_a_read_only_property_2540", "Cannot assign to '{0}' because it is a read-only property."),
                    Index_signature_in_type_0_only_permits_reading: diag(2542, 1 /* Error */, "Index_signature_in_type_0_only_permits_reading_2542", "Index signature in type '{0}' only permits reading."),
                    Duplicate_identifier_newTarget_Compiler_uses_variable_declaration_newTarget_to_capture_new_target_meta_property_reference: diag(2543, 1 /* Error */, "Duplicate_identifier_newTarget_Compiler_uses_variable_declaration_newTarget_to_capture_new_target_me_2543", "Duplicate identifier '_newTarget'. Compiler uses variable declaration '_newTarget' to capture 'new.target' meta-property reference."),
                    Expression_resolves_to_variable_declaration_newTarget_that_compiler_uses_to_capture_new_target_meta_property_reference: diag(2544, 1 /* Error */, "Expression_resolves_to_variable_declaration_newTarget_that_compiler_uses_to_capture_new_target_meta__2544", "Expression resolves to variable declaration '_newTarget' that compiler uses to capture 'new.target' meta-property reference."),
                    A_mixin_class_must_have_a_constructor_with_a_single_rest_parameter_of_type_any: diag(2545, 1 /* Error */, "A_mixin_class_must_have_a_constructor_with_a_single_rest_parameter_of_type_any_2545", "A mixin class must have a constructor with a single rest parameter of type 'any[]'."),
                    The_type_returned_by_the_0_method_of_an_async_iterator_must_be_a_promise_for_a_type_with_a_value_property: diag(2547, 1 /* Error */, "The_type_returned_by_the_0_method_of_an_async_iterator_must_be_a_promise_for_a_type_with_a_value_pro_2547", "The type returned by the '{0}()' method of an async iterator must be a promise for a type with a 'value' property."),
                    Type_0_is_not_an_array_type_or_does_not_have_a_Symbol_iterator_method_that_returns_an_iterator: diag(2548, 1 /* Error */, "Type_0_is_not_an_array_type_or_does_not_have_a_Symbol_iterator_method_that_returns_an_iterator_2548", "Type '{0}' is not an array type or does not have a '[Symbol.iterator]()' method that returns an iterator."),
                    Type_0_is_not_an_array_type_or_a_string_type_or_does_not_have_a_Symbol_iterator_method_that_returns_an_iterator: diag(2549, 1 /* Error */, "Type_0_is_not_an_array_type_or_a_string_type_or_does_not_have_a_Symbol_iterator_method_that_returns__2549", "Type '{0}' is not an array type or a string type or does not have a '[Symbol.iterator]()' method that returns an iterator."),
                    Property_0_does_not_exist_on_type_1_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_2_or_later: diag(2550, 1 /* Error */, "Property_0_does_not_exist_on_type_1_Do_you_need_to_change_your_target_library_Try_changing_the_lib_c_2550", "Property '{0}' does not exist on type '{1}'. Do you need to change your target library? Try changing the 'lib' compiler option to '{2}' or later."),
                    Property_0_does_not_exist_on_type_1_Did_you_mean_2: diag(2551, 1 /* Error */, "Property_0_does_not_exist_on_type_1_Did_you_mean_2_2551", "Property '{0}' does not exist on type '{1}'. Did you mean '{2}'?"),
                    Cannot_find_name_0_Did_you_mean_1: diag(2552, 1 /* Error */, "Cannot_find_name_0_Did_you_mean_1_2552", "Cannot find name '{0}'. Did you mean '{1}'?"),
                    Computed_values_are_not_permitted_in_an_enum_with_string_valued_members: diag(2553, 1 /* Error */, "Computed_values_are_not_permitted_in_an_enum_with_string_valued_members_2553", "Computed values are not permitted in an enum with string valued members."),
                    Expected_0_arguments_but_got_1: diag(2554, 1 /* Error */, "Expected_0_arguments_but_got_1_2554", "Expected {0} arguments, but got {1}."),
                    Expected_at_least_0_arguments_but_got_1: diag(2555, 1 /* Error */, "Expected_at_least_0_arguments_but_got_1_2555", "Expected at least {0} arguments, but got {1}."),
                    A_spread_argument_must_either_have_a_tuple_type_or_be_passed_to_a_rest_parameter: diag(2556, 1 /* Error */, "A_spread_argument_must_either_have_a_tuple_type_or_be_passed_to_a_rest_parameter_2556", "A spread argument must either have a tuple type or be passed to a rest parameter."),
                    Expected_0_type_arguments_but_got_1: diag(2558, 1 /* Error */, "Expected_0_type_arguments_but_got_1_2558", "Expected {0} type arguments, but got {1}."),
                    Type_0_has_no_properties_in_common_with_type_1: diag(2559, 1 /* Error */, "Type_0_has_no_properties_in_common_with_type_1_2559", "Type '{0}' has no properties in common with type '{1}'."),
                    Value_of_type_0_has_no_properties_in_common_with_type_1_Did_you_mean_to_call_it: diag(2560, 1 /* Error */, "Value_of_type_0_has_no_properties_in_common_with_type_1_Did_you_mean_to_call_it_2560", "Value of type '{0}' has no properties in common with type '{1}'. Did you mean to call it?"),
                    Object_literal_may_only_specify_known_properties_but_0_does_not_exist_in_type_1_Did_you_mean_to_write_2: diag(2561, 1 /* Error */, "Object_literal_may_only_specify_known_properties_but_0_does_not_exist_in_type_1_Did_you_mean_to_writ_2561", "Object literal may only specify known properties, but '{0}' does not exist in type '{1}'. Did you mean to write '{2}'?"),
                    Base_class_expressions_cannot_reference_class_type_parameters: diag(2562, 1 /* Error */, "Base_class_expressions_cannot_reference_class_type_parameters_2562", "Base class expressions cannot reference class type parameters."),
                    The_containing_function_or_module_body_is_too_large_for_control_flow_analysis: diag(2563, 1 /* Error */, "The_containing_function_or_module_body_is_too_large_for_control_flow_analysis_2563", "The containing function or module body is too large for control flow analysis."),
                    Property_0_has_no_initializer_and_is_not_definitely_assigned_in_the_constructor: diag(2564, 1 /* Error */, "Property_0_has_no_initializer_and_is_not_definitely_assigned_in_the_constructor_2564", "Property '{0}' has no initializer and is not definitely assigned in the constructor."),
                    Property_0_is_used_before_being_assigned: diag(2565, 1 /* Error */, "Property_0_is_used_before_being_assigned_2565", "Property '{0}' is used before being assigned."),
                    A_rest_element_cannot_have_a_property_name: diag(2566, 1 /* Error */, "A_rest_element_cannot_have_a_property_name_2566", "A rest element cannot have a property name."),
                    Enum_declarations_can_only_merge_with_namespace_or_other_enum_declarations: diag(2567, 1 /* Error */, "Enum_declarations_can_only_merge_with_namespace_or_other_enum_declarations_2567", "Enum declarations can only merge with namespace or other enum declarations."),
                    Property_0_may_not_exist_on_type_1_Did_you_mean_2: diag(2568, 1 /* Error */, "Property_0_may_not_exist_on_type_1_Did_you_mean_2_2568", "Property '{0}' may not exist on type '{1}'. Did you mean '{2}'?"),
                    Could_not_find_name_0_Did_you_mean_1: diag(2570, 1 /* Error */, "Could_not_find_name_0_Did_you_mean_1_2570", "Could not find name '{0}'. Did you mean '{1}'?"),
                    Object_is_of_type_unknown: diag(2571, 1 /* Error */, "Object_is_of_type_unknown_2571", "Object is of type 'unknown'."),
                    A_rest_element_type_must_be_an_array_type: diag(2574, 1 /* Error */, "A_rest_element_type_must_be_an_array_type_2574", "A rest element type must be an array type."),
                    No_overload_expects_0_arguments_but_overloads_do_exist_that_expect_either_1_or_2_arguments: diag(2575, 1 /* Error */, "No_overload_expects_0_arguments_but_overloads_do_exist_that_expect_either_1_or_2_arguments_2575", "No overload expects {0} arguments, but overloads do exist that expect either {1} or {2} arguments."),
                    Property_0_does_not_exist_on_type_1_Did_you_mean_to_access_the_static_member_2_instead: diag(2576, 1 /* Error */, "Property_0_does_not_exist_on_type_1_Did_you_mean_to_access_the_static_member_2_instead_2576", "Property '{0}' does not exist on type '{1}'. Did you mean to access the static member '{2}' instead?"),
                    Return_type_annotation_circularly_references_itself: diag(2577, 1 /* Error */, "Return_type_annotation_circularly_references_itself_2577", "Return type annotation circularly references itself."),
                    Unused_ts_expect_error_directive: diag(2578, 1 /* Error */, "Unused_ts_expect_error_directive_2578", "Unused '@ts-expect-error' directive."),
                    Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_node_Try_npm_i_save_dev_types_Slashnode: diag(2580, 1 /* Error */, "Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_node_Try_npm_i_save_dev_types_Slashno_2580", "Cannot find name '{0}'. Do you need to install type definitions for node? Try `npm i --save-dev @types/node`."),
                    Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_jQuery_Try_npm_i_save_dev_types_Slashjquery: diag(2581, 1 /* Error */, "Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_jQuery_Try_npm_i_save_dev_types_Slash_2581", "Cannot find name '{0}'. Do you need to install type definitions for jQuery? Try `npm i --save-dev @types/jquery`."),
                    Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_a_test_runner_Try_npm_i_save_dev_types_Slashjest_or_npm_i_save_dev_types_Slashmocha: diag(2582, 1 /* Error */, "Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_a_test_runner_Try_npm_i_save_dev_type_2582", "Cannot find name '{0}'. Do you need to install type definitions for a test runner? Try `npm i --save-dev @types/jest` or `npm i --save-dev @types/mocha`."),
                    Cannot_find_name_0_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_1_or_later: diag(2583, 1 /* Error */, "Cannot_find_name_0_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_2583", "Cannot find name '{0}'. Do you need to change your target library? Try changing the 'lib' compiler option to '{1}' or later."),
                    Cannot_find_name_0_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_include_dom: diag(2584, 1 /* Error */, "Cannot_find_name_0_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_2584", "Cannot find name '{0}'. Do you need to change your target library? Try changing the 'lib' compiler option to include 'dom'."),
                    _0_only_refers_to_a_type_but_is_being_used_as_a_value_here_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_es2015_or_later: diag(2585, 1 /* Error */, "_0_only_refers_to_a_type_but_is_being_used_as_a_value_here_Do_you_need_to_change_your_target_library_2585", "'{0}' only refers to a type, but is being used as a value here. Do you need to change your target library? Try changing the 'lib' compiler option to es2015 or later."),
                    Cannot_assign_to_0_because_it_is_a_constant: diag(2588, 1 /* Error */, "Cannot_assign_to_0_because_it_is_a_constant_2588", "Cannot assign to '{0}' because it is a constant."),
                    Type_instantiation_is_excessively_deep_and_possibly_infinite: diag(2589, 1 /* Error */, "Type_instantiation_is_excessively_deep_and_possibly_infinite_2589", "Type instantiation is excessively deep and possibly infinite."),
                    Expression_produces_a_union_type_that_is_too_complex_to_represent: diag(2590, 1 /* Error */, "Expression_produces_a_union_type_that_is_too_complex_to_represent_2590", "Expression produces a union type that is too complex to represent."),
                    Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_node_Try_npm_i_save_dev_types_Slashnode_and_then_add_node_to_the_types_field_in_your_tsconfig: diag(2591, 1 /* Error */, "Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_node_Try_npm_i_save_dev_types_Slashno_2591", "Cannot find name '{0}'. Do you need to install type definitions for node? Try `npm i --save-dev @types/node` and then add 'node' to the types field in your tsconfig."),
                    Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_jQuery_Try_npm_i_save_dev_types_Slashjquery_and_then_add_jquery_to_the_types_field_in_your_tsconfig: diag(2592, 1 /* Error */, "Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_jQuery_Try_npm_i_save_dev_types_Slash_2592", "Cannot find name '{0}'. Do you need to install type definitions for jQuery? Try `npm i --save-dev @types/jquery` and then add 'jquery' to the types field in your tsconfig."),
                    Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_a_test_runner_Try_npm_i_save_dev_types_Slashjest_or_npm_i_save_dev_types_Slashmocha_and_then_add_jest_or_mocha_to_the_types_field_in_your_tsconfig: diag(2593, 1 /* Error */, "Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_a_test_runner_Try_npm_i_save_dev_type_2593", "Cannot find name '{0}'. Do you need to install type definitions for a test runner? Try `npm i --save-dev @types/jest` or `npm i --save-dev @types/mocha` and then add 'jest' or 'mocha' to the types field in your tsconfig."),
                    This_module_is_declared_with_export_and_can_only_be_used_with_a_default_import_when_using_the_0_flag: diag(2594, 1 /* Error */, "This_module_is_declared_with_export_and_can_only_be_used_with_a_default_import_when_using_the_0_flag_2594", "This module is declared with 'export =', and can only be used with a default import when using the '{0}' flag."),
                    _0_can_only_be_imported_by_using_a_default_import: diag(2595, 1 /* Error */, "_0_can_only_be_imported_by_using_a_default_import_2595", "'{0}' can only be imported by using a default import."),
                    _0_can_only_be_imported_by_turning_on_the_esModuleInterop_flag_and_using_a_default_import: diag(2596, 1 /* Error */, "_0_can_only_be_imported_by_turning_on_the_esModuleInterop_flag_and_using_a_default_import_2596", "'{0}' can only be imported by turning on the 'esModuleInterop' flag and using a default import."),
                    _0_can_only_be_imported_by_using_a_require_call_or_by_using_a_default_import: diag(2597, 1 /* Error */, "_0_can_only_be_imported_by_using_a_require_call_or_by_using_a_default_import_2597", "'{0}' can only be imported by using a 'require' call or by using a default import."),
                    _0_can_only_be_imported_by_using_a_require_call_or_by_turning_on_the_esModuleInterop_flag_and_using_a_default_import: diag(2598, 1 /* Error */, "_0_can_only_be_imported_by_using_a_require_call_or_by_turning_on_the_esModuleInterop_flag_and_using__2598", "'{0}' can only be imported by using a 'require' call or by turning on the 'esModuleInterop' flag and using a default import."),
                    JSX_element_implicitly_has_type_any_because_the_global_type_JSX_Element_does_not_exist: diag(2602, 1 /* Error */, "JSX_element_implicitly_has_type_any_because_the_global_type_JSX_Element_does_not_exist_2602", "JSX element implicitly has type 'any' because the global type 'JSX.Element' does not exist."),
                    Property_0_in_type_1_is_not_assignable_to_type_2: diag(2603, 1 /* Error */, "Property_0_in_type_1_is_not_assignable_to_type_2_2603", "Property '{0}' in type '{1}' is not assignable to type '{2}'."),
                    JSX_element_type_0_does_not_have_any_construct_or_call_signatures: diag(2604, 1 /* Error */, "JSX_element_type_0_does_not_have_any_construct_or_call_signatures_2604", "JSX element type '{0}' does not have any construct or call signatures."),
                    Property_0_of_JSX_spread_attribute_is_not_assignable_to_target_property: diag(2606, 1 /* Error */, "Property_0_of_JSX_spread_attribute_is_not_assignable_to_target_property_2606", "Property '{0}' of JSX spread attribute is not assignable to target property."),
                    JSX_element_class_does_not_support_attributes_because_it_does_not_have_a_0_property: diag(2607, 1 /* Error */, "JSX_element_class_does_not_support_attributes_because_it_does_not_have_a_0_property_2607", "JSX element class does not support attributes because it does not have a '{0}' property."),
                    The_global_type_JSX_0_may_not_have_more_than_one_property: diag(2608, 1 /* Error */, "The_global_type_JSX_0_may_not_have_more_than_one_property_2608", "The global type 'JSX.{0}' may not have more than one property."),
                    JSX_spread_child_must_be_an_array_type: diag(2609, 1 /* Error */, "JSX_spread_child_must_be_an_array_type_2609", "JSX spread child must be an array type."),
                    _0_is_defined_as_an_accessor_in_class_1_but_is_overridden_here_in_2_as_an_instance_property: diag(2610, 1 /* Error */, "_0_is_defined_as_an_accessor_in_class_1_but_is_overridden_here_in_2_as_an_instance_property_2610", "'{0}' is defined as an accessor in class '{1}', but is overridden here in '{2}' as an instance property."),
                    _0_is_defined_as_a_property_in_class_1_but_is_overridden_here_in_2_as_an_accessor: diag(2611, 1 /* Error */, "_0_is_defined_as_a_property_in_class_1_but_is_overridden_here_in_2_as_an_accessor_2611", "'{0}' is defined as a property in class '{1}', but is overridden here in '{2}' as an accessor."),
                    Property_0_will_overwrite_the_base_property_in_1_If_this_is_intentional_add_an_initializer_Otherwise_add_a_declare_modifier_or_remove_the_redundant_declaration: diag(2612, 1 /* Error */, "Property_0_will_overwrite_the_base_property_in_1_If_this_is_intentional_add_an_initializer_Otherwise_2612", "Property '{0}' will overwrite the base property in '{1}'. If this is intentional, add an initializer. Otherwise, add a 'declare' modifier or remove the redundant declaration."),
                    Module_0_has_no_default_export_Did_you_mean_to_use_import_1_from_0_instead: diag(2613, 1 /* Error */, "Module_0_has_no_default_export_Did_you_mean_to_use_import_1_from_0_instead_2613", "Module '{0}' has no default export. Did you mean to use 'import { {1} } from {0}' instead?"),
                    Module_0_has_no_exported_member_1_Did_you_mean_to_use_import_1_from_0_instead: diag(2614, 1 /* Error */, "Module_0_has_no_exported_member_1_Did_you_mean_to_use_import_1_from_0_instead_2614", "Module '{0}' has no exported member '{1}'. Did you mean to use 'import {1} from {0}' instead?"),
                    Type_of_property_0_circularly_references_itself_in_mapped_type_1: diag(2615, 1 /* Error */, "Type_of_property_0_circularly_references_itself_in_mapped_type_1_2615", "Type of property '{0}' circularly references itself in mapped type '{1}'."),
                    _0_can_only_be_imported_by_using_import_1_require_2_or_a_default_import: diag(2616, 1 /* Error */, "_0_can_only_be_imported_by_using_import_1_require_2_or_a_default_import_2616", "'{0}' can only be imported by using 'import {1} = require({2})' or a default import."),
                    _0_can_only_be_imported_by_using_import_1_require_2_or_by_turning_on_the_esModuleInterop_flag_and_using_a_default_import: diag(2617, 1 /* Error */, "_0_can_only_be_imported_by_using_import_1_require_2_or_by_turning_on_the_esModuleInterop_flag_and_us_2617", "'{0}' can only be imported by using 'import {1} = require({2})' or by turning on the 'esModuleInterop' flag and using a default import."),
                    Source_has_0_element_s_but_target_requires_1: diag(2618, 1 /* Error */, "Source_has_0_element_s_but_target_requires_1_2618", "Source has {0} element(s) but target requires {1}."),
                    Source_has_0_element_s_but_target_allows_only_1: diag(2619, 1 /* Error */, "Source_has_0_element_s_but_target_allows_only_1_2619", "Source has {0} element(s) but target allows only {1}."),
                    Target_requires_0_element_s_but_source_may_have_fewer: diag(2620, 1 /* Error */, "Target_requires_0_element_s_but_source_may_have_fewer_2620", "Target requires {0} element(s) but source may have fewer."),
                    Target_allows_only_0_element_s_but_source_may_have_more: diag(2621, 1 /* Error */, "Target_allows_only_0_element_s_but_source_may_have_more_2621", "Target allows only {0} element(s) but source may have more."),
                    Source_provides_no_match_for_required_element_at_position_0_in_target: diag(2623, 1 /* Error */, "Source_provides_no_match_for_required_element_at_position_0_in_target_2623", "Source provides no match for required element at position {0} in target."),
                    Source_provides_no_match_for_variadic_element_at_position_0_in_target: diag(2624, 1 /* Error */, "Source_provides_no_match_for_variadic_element_at_position_0_in_target_2624", "Source provides no match for variadic element at position {0} in target."),
                    Variadic_element_at_position_0_in_source_does_not_match_element_at_position_1_in_target: diag(2625, 1 /* Error */, "Variadic_element_at_position_0_in_source_does_not_match_element_at_position_1_in_target_2625", "Variadic element at position {0} in source does not match element at position {1} in target."),
                    Type_at_position_0_in_source_is_not_compatible_with_type_at_position_1_in_target: diag(2626, 1 /* Error */, "Type_at_position_0_in_source_is_not_compatible_with_type_at_position_1_in_target_2626", "Type at position {0} in source is not compatible with type at position {1} in target."),
                    Type_at_positions_0_through_1_in_source_is_not_compatible_with_type_at_position_2_in_target: diag(2627, 1 /* Error */, "Type_at_positions_0_through_1_in_source_is_not_compatible_with_type_at_position_2_in_target_2627", "Type at positions {0} through {1} in source is not compatible with type at position {2} in target."),
                    Cannot_assign_to_0_because_it_is_an_enum: diag(2628, 1 /* Error */, "Cannot_assign_to_0_because_it_is_an_enum_2628", "Cannot assign to '{0}' because it is an enum."),
                    Cannot_assign_to_0_because_it_is_a_class: diag(2629, 1 /* Error */, "Cannot_assign_to_0_because_it_is_a_class_2629", "Cannot assign to '{0}' because it is a class."),
                    Cannot_assign_to_0_because_it_is_a_function: diag(2630, 1 /* Error */, "Cannot_assign_to_0_because_it_is_a_function_2630", "Cannot assign to '{0}' because it is a function."),
                    Cannot_assign_to_0_because_it_is_a_namespace: diag(2631, 1 /* Error */, "Cannot_assign_to_0_because_it_is_a_namespace_2631", "Cannot assign to '{0}' because it is a namespace."),
                    Cannot_assign_to_0_because_it_is_an_import: diag(2632, 1 /* Error */, "Cannot_assign_to_0_because_it_is_an_import_2632", "Cannot assign to '{0}' because it is an import."),
                    JSX_property_access_expressions_cannot_include_JSX_namespace_names: diag(2633, 1 /* Error */, "JSX_property_access_expressions_cannot_include_JSX_namespace_names_2633", "JSX property access expressions cannot include JSX namespace names"),
                    _0_index_signatures_are_incompatible: diag(2634, 1 /* Error */, "_0_index_signatures_are_incompatible_2634", "'{0}' index signatures are incompatible."),
                    Type_0_has_no_signatures_for_which_the_type_argument_list_is_applicable: diag(2635, 1 /* Error */, "Type_0_has_no_signatures_for_which_the_type_argument_list_is_applicable_2635", "Type '{0}' has no signatures for which the type argument list is applicable."),
                    Type_0_is_not_assignable_to_type_1_as_implied_by_variance_annotation: diag(2636, 1 /* Error */, "Type_0_is_not_assignable_to_type_1_as_implied_by_variance_annotation_2636", "Type '{0}' is not assignable to type '{1}' as implied by variance annotation."),
                    Variance_annotations_are_only_supported_in_type_aliases_for_object_function_constructor_and_mapped_types: diag(2637, 1 /* Error */, "Variance_annotations_are_only_supported_in_type_aliases_for_object_function_constructor_and_mapped_t_2637", "Variance annotations are only supported in type aliases for object, function, constructor, and mapped types."),
                    Type_0_may_represent_a_primitive_value_which_is_not_permitted_as_the_right_operand_of_the_in_operator: diag(2638, 1 /* Error */, "Type_0_may_represent_a_primitive_value_which_is_not_permitted_as_the_right_operand_of_the_in_operato_2638", "Type '{0}' may represent a primitive value, which is not permitted as the right operand of the 'in' operator."),
                    React_components_cannot_include_JSX_namespace_names: diag(2639, 1 /* Error */, "React_components_cannot_include_JSX_namespace_names_2639", "React components cannot include JSX namespace names"),
                    Cannot_augment_module_0_with_value_exports_because_it_resolves_to_a_non_module_entity: diag(2649, 1 /* Error */, "Cannot_augment_module_0_with_value_exports_because_it_resolves_to_a_non_module_entity_2649", "Cannot augment module '{0}' with value exports because it resolves to a non-module entity."),
                    A_member_initializer_in_a_enum_declaration_cannot_reference_members_declared_after_it_including_members_defined_in_other_enums: diag(2651, 1 /* Error */, "A_member_initializer_in_a_enum_declaration_cannot_reference_members_declared_after_it_including_memb_2651", "A member initializer in a enum declaration cannot reference members declared after it, including members defined in other enums."),
                    Merged_declaration_0_cannot_include_a_default_export_declaration_Consider_adding_a_separate_export_default_0_declaration_instead: diag(2652, 1 /* Error */, "Merged_declaration_0_cannot_include_a_default_export_declaration_Consider_adding_a_separate_export_d_2652", "Merged declaration '{0}' cannot include a default export declaration. Consider adding a separate 'export default {0}' declaration instead."),
                    Non_abstract_class_expression_does_not_implement_inherited_abstract_member_0_from_class_1: diag(2653, 1 /* Error */, "Non_abstract_class_expression_does_not_implement_inherited_abstract_member_0_from_class_1_2653", "Non-abstract class expression does not implement inherited abstract member '{0}' from class '{1}'."),
                    JSX_expressions_must_have_one_parent_element: diag(2657, 1 /* Error */, "JSX_expressions_must_have_one_parent_element_2657", "JSX expressions must have one parent element."),
                    Type_0_provides_no_match_for_the_signature_1: diag(2658, 1 /* Error */, "Type_0_provides_no_match_for_the_signature_1_2658", "Type '{0}' provides no match for the signature '{1}'."),
                    super_is_only_allowed_in_members_of_object_literal_expressions_when_option_target_is_ES2015_or_higher: diag(2659, 1 /* Error */, "super_is_only_allowed_in_members_of_object_literal_expressions_when_option_target_is_ES2015_or_highe_2659", "'super' is only allowed in members of object literal expressions when option 'target' is 'ES2015' or higher."),
                    super_can_only_be_referenced_in_members_of_derived_classes_or_object_literal_expressions: diag(2660, 1 /* Error */, "super_can_only_be_referenced_in_members_of_derived_classes_or_object_literal_expressions_2660", "'super' can only be referenced in members of derived classes or object literal expressions."),
                    Cannot_export_0_Only_local_declarations_can_be_exported_from_a_module: diag(2661, 1 /* Error */, "Cannot_export_0_Only_local_declarations_can_be_exported_from_a_module_2661", "Cannot export '{0}'. Only local declarations can be exported from a module."),
                    Cannot_find_name_0_Did_you_mean_the_static_member_1_0: diag(2662, 1 /* Error */, "Cannot_find_name_0_Did_you_mean_the_static_member_1_0_2662", "Cannot find name '{0}'. Did you mean the static member '{1}.{0}'?"),
                    Cannot_find_name_0_Did_you_mean_the_instance_member_this_0: diag(2663, 1 /* Error */, "Cannot_find_name_0_Did_you_mean_the_instance_member_this_0_2663", "Cannot find name '{0}'. Did you mean the instance member 'this.{0}'?"),
                    Invalid_module_name_in_augmentation_module_0_cannot_be_found: diag(2664, 1 /* Error */, "Invalid_module_name_in_augmentation_module_0_cannot_be_found_2664", "Invalid module name in augmentation, module '{0}' cannot be found."),
                    Invalid_module_name_in_augmentation_Module_0_resolves_to_an_untyped_module_at_1_which_cannot_be_augmented: diag(2665, 1 /* Error */, "Invalid_module_name_in_augmentation_Module_0_resolves_to_an_untyped_module_at_1_which_cannot_be_augm_2665", "Invalid module name in augmentation. Module '{0}' resolves to an untyped module at '{1}', which cannot be augmented."),
                    Exports_and_export_assignments_are_not_permitted_in_module_augmentations: diag(2666, 1 /* Error */, "Exports_and_export_assignments_are_not_permitted_in_module_augmentations_2666", "Exports and export assignments are not permitted in module augmentations."),
                    Imports_are_not_permitted_in_module_augmentations_Consider_moving_them_to_the_enclosing_external_module: diag(2667, 1 /* Error */, "Imports_are_not_permitted_in_module_augmentations_Consider_moving_them_to_the_enclosing_external_mod_2667", "Imports are not permitted in module augmentations. Consider moving them to the enclosing external module."),
                    export_modifier_cannot_be_applied_to_ambient_modules_and_module_augmentations_since_they_are_always_visible: diag(2668, 1 /* Error */, "export_modifier_cannot_be_applied_to_ambient_modules_and_module_augmentations_since_they_are_always__2668", "'export' modifier cannot be applied to ambient modules and module augmentations since they are always visible."),
                    Augmentations_for_the_global_scope_can_only_be_directly_nested_in_external_modules_or_ambient_module_declarations: diag(2669, 1 /* Error */, "Augmentations_for_the_global_scope_can_only_be_directly_nested_in_external_modules_or_ambient_module_2669", "Augmentations for the global scope can only be directly nested in external modules or ambient module declarations."),
                    Augmentations_for_the_global_scope_should_have_declare_modifier_unless_they_appear_in_already_ambient_context: diag(2670, 1 /* Error */, "Augmentations_for_the_global_scope_should_have_declare_modifier_unless_they_appear_in_already_ambien_2670", "Augmentations for the global scope should have 'declare' modifier unless they appear in already ambient context."),
                    Cannot_augment_module_0_because_it_resolves_to_a_non_module_entity: diag(2671, 1 /* Error */, "Cannot_augment_module_0_because_it_resolves_to_a_non_module_entity_2671", "Cannot augment module '{0}' because it resolves to a non-module entity."),
                    Cannot_assign_a_0_constructor_type_to_a_1_constructor_type: diag(2672, 1 /* Error */, "Cannot_assign_a_0_constructor_type_to_a_1_constructor_type_2672", "Cannot assign a '{0}' constructor type to a '{1}' constructor type."),
                    Constructor_of_class_0_is_private_and_only_accessible_within_the_class_declaration: diag(2673, 1 /* Error */, "Constructor_of_class_0_is_private_and_only_accessible_within_the_class_declaration_2673", "Constructor of class '{0}' is private and only accessible within the class declaration."),
                    Constructor_of_class_0_is_protected_and_only_accessible_within_the_class_declaration: diag(2674, 1 /* Error */, "Constructor_of_class_0_is_protected_and_only_accessible_within_the_class_declaration_2674", "Constructor of class '{0}' is protected and only accessible within the class declaration."),
                    Cannot_extend_a_class_0_Class_constructor_is_marked_as_private: diag(2675, 1 /* Error */, "Cannot_extend_a_class_0_Class_constructor_is_marked_as_private_2675", "Cannot extend a class '{0}'. Class constructor is marked as private."),
                    Accessors_must_both_be_abstract_or_non_abstract: diag(2676, 1 /* Error */, "Accessors_must_both_be_abstract_or_non_abstract_2676", "Accessors must both be abstract or non-abstract."),
                    A_type_predicate_s_type_must_be_assignable_to_its_parameter_s_type: diag(2677, 1 /* Error */, "A_type_predicate_s_type_must_be_assignable_to_its_parameter_s_type_2677", "A type predicate's type must be assignable to its parameter's type."),
                    Type_0_is_not_comparable_to_type_1: diag(2678, 1 /* Error */, "Type_0_is_not_comparable_to_type_1_2678", "Type '{0}' is not comparable to type '{1}'."),
                    A_function_that_is_called_with_the_new_keyword_cannot_have_a_this_type_that_is_void: diag(2679, 1 /* Error */, "A_function_that_is_called_with_the_new_keyword_cannot_have_a_this_type_that_is_void_2679", "A function that is called with the 'new' keyword cannot have a 'this' type that is 'void'."),
                    A_0_parameter_must_be_the_first_parameter: diag(2680, 1 /* Error */, "A_0_parameter_must_be_the_first_parameter_2680", "A '{0}' parameter must be the first parameter."),
                    A_constructor_cannot_have_a_this_parameter: diag(2681, 1 /* Error */, "A_constructor_cannot_have_a_this_parameter_2681", "A constructor cannot have a 'this' parameter."),
                    this_implicitly_has_type_any_because_it_does_not_have_a_type_annotation: diag(2683, 1 /* Error */, "this_implicitly_has_type_any_because_it_does_not_have_a_type_annotation_2683", "'this' implicitly has type 'any' because it does not have a type annotation."),
                    The_this_context_of_type_0_is_not_assignable_to_method_s_this_of_type_1: diag(2684, 1 /* Error */, "The_this_context_of_type_0_is_not_assignable_to_method_s_this_of_type_1_2684", "The 'this' context of type '{0}' is not assignable to method's 'this' of type '{1}'."),
                    The_this_types_of_each_signature_are_incompatible: diag(2685, 1 /* Error */, "The_this_types_of_each_signature_are_incompatible_2685", "The 'this' types of each signature are incompatible."),
                    _0_refers_to_a_UMD_global_but_the_current_file_is_a_module_Consider_adding_an_import_instead: diag(2686, 1 /* Error */, "_0_refers_to_a_UMD_global_but_the_current_file_is_a_module_Consider_adding_an_import_instead_2686", "'{0}' refers to a UMD global, but the current file is a module. Consider adding an import instead."),
                    All_declarations_of_0_must_have_identical_modifiers: diag(2687, 1 /* Error */, "All_declarations_of_0_must_have_identical_modifiers_2687", "All declarations of '{0}' must have identical modifiers."),
                    Cannot_find_type_definition_file_for_0: diag(2688, 1 /* Error */, "Cannot_find_type_definition_file_for_0_2688", "Cannot find type definition file for '{0}'."),
                    Cannot_extend_an_interface_0_Did_you_mean_implements: diag(2689, 1 /* Error */, "Cannot_extend_an_interface_0_Did_you_mean_implements_2689", "Cannot extend an interface '{0}'. Did you mean 'implements'?"),
                    _0_only_refers_to_a_type_but_is_being_used_as_a_value_here_Did_you_mean_to_use_1_in_0: diag(2690, 1 /* Error */, "_0_only_refers_to_a_type_but_is_being_used_as_a_value_here_Did_you_mean_to_use_1_in_0_2690", "'{0}' only refers to a type, but is being used as a value here. Did you mean to use '{1} in {0}'?"),
                    _0_is_a_primitive_but_1_is_a_wrapper_object_Prefer_using_0_when_possible: diag(2692, 1 /* Error */, "_0_is_a_primitive_but_1_is_a_wrapper_object_Prefer_using_0_when_possible_2692", "'{0}' is a primitive, but '{1}' is a wrapper object. Prefer using '{0}' when possible."),
                    _0_only_refers_to_a_type_but_is_being_used_as_a_value_here: diag(2693, 1 /* Error */, "_0_only_refers_to_a_type_but_is_being_used_as_a_value_here_2693", "'{0}' only refers to a type, but is being used as a value here."),
                    Namespace_0_has_no_exported_member_1: diag(2694, 1 /* Error */, "Namespace_0_has_no_exported_member_1_2694", "Namespace '{0}' has no exported member '{1}'."),
                    Left_side_of_comma_operator_is_unused_and_has_no_side_effects: diag(2695, 1 /* Error */, "Left_side_of_comma_operator_is_unused_and_has_no_side_effects_2695", "Left side of comma operator is unused and has no side effects.", 
                    /*reportsUnnecessary*/
                    true),
                    The_Object_type_is_assignable_to_very_few_other_types_Did_you_mean_to_use_the_any_type_instead: diag(2696, 1 /* Error */, "The_Object_type_is_assignable_to_very_few_other_types_Did_you_mean_to_use_the_any_type_instead_2696", "The 'Object' type is assignable to very few other types. Did you mean to use the 'any' type instead?"),
                    An_async_function_or_method_must_return_a_Promise_Make_sure_you_have_a_declaration_for_Promise_or_include_ES2015_in_your_lib_option: diag(2697, 1 /* Error */, "An_async_function_or_method_must_return_a_Promise_Make_sure_you_have_a_declaration_for_Promise_or_in_2697", "An async function or method must return a 'Promise'. Make sure you have a declaration for 'Promise' or include 'ES2015' in your '--lib' option."),
                    Spread_types_may_only_be_created_from_object_types: diag(2698, 1 /* Error */, "Spread_types_may_only_be_created_from_object_types_2698", "Spread types may only be created from object types."),
                    Static_property_0_conflicts_with_built_in_property_Function_0_of_constructor_function_1: diag(2699, 1 /* Error */, "Static_property_0_conflicts_with_built_in_property_Function_0_of_constructor_function_1_2699", "Static property '{0}' conflicts with built-in property 'Function.{0}' of constructor function '{1}'."),
                    Rest_types_may_only_be_created_from_object_types: diag(2700, 1 /* Error */, "Rest_types_may_only_be_created_from_object_types_2700", "Rest types may only be created from object types."),
                    The_target_of_an_object_rest_assignment_must_be_a_variable_or_a_property_access: diag(2701, 1 /* Error */, "The_target_of_an_object_rest_assignment_must_be_a_variable_or_a_property_access_2701", "The target of an object rest assignment must be a variable or a property access."),
                    _0_only_refers_to_a_type_but_is_being_used_as_a_namespace_here: diag(2702, 1 /* Error */, "_0_only_refers_to_a_type_but_is_being_used_as_a_namespace_here_2702", "'{0}' only refers to a type, but is being used as a namespace here."),
                    The_operand_of_a_delete_operator_must_be_a_property_reference: diag(2703, 1 /* Error */, "The_operand_of_a_delete_operator_must_be_a_property_reference_2703", "The operand of a 'delete' operator must be a property reference."),
                    The_operand_of_a_delete_operator_cannot_be_a_read_only_property: diag(2704, 1 /* Error */, "The_operand_of_a_delete_operator_cannot_be_a_read_only_property_2704", "The operand of a 'delete' operator cannot be a read-only property."),
                    An_async_function_or_method_in_ES5_SlashES3_requires_the_Promise_constructor_Make_sure_you_have_a_declaration_for_the_Promise_constructor_or_include_ES2015_in_your_lib_option: diag(2705, 1 /* Error */, "An_async_function_or_method_in_ES5_SlashES3_requires_the_Promise_constructor_Make_sure_you_have_a_de_2705", "An async function or method in ES5/ES3 requires the 'Promise' constructor.  Make sure you have a declaration for the 'Promise' constructor or include 'ES2015' in your '--lib' option."),
                    Required_type_parameters_may_not_follow_optional_type_parameters: diag(2706, 1 /* Error */, "Required_type_parameters_may_not_follow_optional_type_parameters_2706", "Required type parameters may not follow optional type parameters."),
                    Generic_type_0_requires_between_1_and_2_type_arguments: diag(2707, 1 /* Error */, "Generic_type_0_requires_between_1_and_2_type_arguments_2707", "Generic type '{0}' requires between {1} and {2} type arguments."),
                    Cannot_use_namespace_0_as_a_value: diag(2708, 1 /* Error */, "Cannot_use_namespace_0_as_a_value_2708", "Cannot use namespace '{0}' as a value."),
                    Cannot_use_namespace_0_as_a_type: diag(2709, 1 /* Error */, "Cannot_use_namespace_0_as_a_type_2709", "Cannot use namespace '{0}' as a type."),
                    _0_are_specified_twice_The_attribute_named_0_will_be_overwritten: diag(2710, 1 /* Error */, "_0_are_specified_twice_The_attribute_named_0_will_be_overwritten_2710", "'{0}' are specified twice. The attribute named '{0}' will be overwritten."),
                    A_dynamic_import_call_returns_a_Promise_Make_sure_you_have_a_declaration_for_Promise_or_include_ES2015_in_your_lib_option: diag(2711, 1 /* Error */, "A_dynamic_import_call_returns_a_Promise_Make_sure_you_have_a_declaration_for_Promise_or_include_ES20_2711", "A dynamic import call returns a 'Promise'. Make sure you have a declaration for 'Promise' or include 'ES2015' in your '--lib' option."),
                    A_dynamic_import_call_in_ES5_SlashES3_requires_the_Promise_constructor_Make_sure_you_have_a_declaration_for_the_Promise_constructor_or_include_ES2015_in_your_lib_option: diag(2712, 1 /* Error */, "A_dynamic_import_call_in_ES5_SlashES3_requires_the_Promise_constructor_Make_sure_you_have_a_declarat_2712", "A dynamic import call in ES5/ES3 requires the 'Promise' constructor.  Make sure you have a declaration for the 'Promise' constructor or include 'ES2015' in your '--lib' option."),
                    Cannot_access_0_1_because_0_is_a_type_but_not_a_namespace_Did_you_mean_to_retrieve_the_type_of_the_property_1_in_0_with_0_1: diag(2713, 1 /* Error */, "Cannot_access_0_1_because_0_is_a_type_but_not_a_namespace_Did_you_mean_to_retrieve_the_type_of_the_p_2713", `Cannot access '{0}.{1}' because '{0}' is a type, but not a namespace. Did you mean to retrieve the type of the property '{1}' in '{0}' with '{0}["{1}"]'?`),
                    The_expression_of_an_export_assignment_must_be_an_identifier_or_qualified_name_in_an_ambient_context: diag(2714, 1 /* Error */, "The_expression_of_an_export_assignment_must_be_an_identifier_or_qualified_name_in_an_ambient_context_2714", "The expression of an export assignment must be an identifier or qualified name in an ambient context."),
                    Abstract_property_0_in_class_1_cannot_be_accessed_in_the_constructor: diag(2715, 1 /* Error */, "Abstract_property_0_in_class_1_cannot_be_accessed_in_the_constructor_2715", "Abstract property '{0}' in class '{1}' cannot be accessed in the constructor."),
                    Type_parameter_0_has_a_circular_default: diag(2716, 1 /* Error */, "Type_parameter_0_has_a_circular_default_2716", "Type parameter '{0}' has a circular default."),
                    Subsequent_property_declarations_must_have_the_same_type_Property_0_must_be_of_type_1_but_here_has_type_2: diag(2717, 1 /* Error */, "Subsequent_property_declarations_must_have_the_same_type_Property_0_must_be_of_type_1_but_here_has_t_2717", "Subsequent property declarations must have the same type.  Property '{0}' must be of type '{1}', but here has type '{2}'."),
                    Duplicate_property_0: diag(2718, 1 /* Error */, "Duplicate_property_0_2718", "Duplicate property '{0}'."),
                    Type_0_is_not_assignable_to_type_1_Two_different_types_with_this_name_exist_but_they_are_unrelated: diag(2719, 1 /* Error */, "Type_0_is_not_assignable_to_type_1_Two_different_types_with_this_name_exist_but_they_are_unrelated_2719", "Type '{0}' is not assignable to type '{1}'. Two different types with this name exist, but they are unrelated."),
                    Class_0_incorrectly_implements_class_1_Did_you_mean_to_extend_1_and_inherit_its_members_as_a_subclass: diag(2720, 1 /* Error */, "Class_0_incorrectly_implements_class_1_Did_you_mean_to_extend_1_and_inherit_its_members_as_a_subclas_2720", "Class '{0}' incorrectly implements class '{1}'. Did you mean to extend '{1}' and inherit its members as a subclass?"),
                    Cannot_invoke_an_object_which_is_possibly_null: diag(2721, 1 /* Error */, "Cannot_invoke_an_object_which_is_possibly_null_2721", "Cannot invoke an object which is possibly 'null'."),
                    Cannot_invoke_an_object_which_is_possibly_undefined: diag(2722, 1 /* Error */, "Cannot_invoke_an_object_which_is_possibly_undefined_2722", "Cannot invoke an object which is possibly 'undefined'."),
                    Cannot_invoke_an_object_which_is_possibly_null_or_undefined: diag(2723, 1 /* Error */, "Cannot_invoke_an_object_which_is_possibly_null_or_undefined_2723", "Cannot invoke an object which is possibly 'null' or 'undefined'."),
                    _0_has_no_exported_member_named_1_Did_you_mean_2: diag(2724, 1 /* Error */, "_0_has_no_exported_member_named_1_Did_you_mean_2_2724", "'{0}' has no exported member named '{1}'. Did you mean '{2}'?"),
                    Class_name_cannot_be_Object_when_targeting_ES5_with_module_0: diag(2725, 1 /* Error */, "Class_name_cannot_be_Object_when_targeting_ES5_with_module_0_2725", "Class name cannot be 'Object' when targeting ES5 with module {0}."),
                    Cannot_find_lib_definition_for_0: diag(2726, 1 /* Error */, "Cannot_find_lib_definition_for_0_2726", "Cannot find lib definition for '{0}'."),
                    Cannot_find_lib_definition_for_0_Did_you_mean_1: diag(2727, 1 /* Error */, "Cannot_find_lib_definition_for_0_Did_you_mean_1_2727", "Cannot find lib definition for '{0}'. Did you mean '{1}'?"),
                    _0_is_declared_here: diag(2728, 3 /* Message */, "_0_is_declared_here_2728", "'{0}' is declared here."),
                    Property_0_is_used_before_its_initialization: diag(2729, 1 /* Error */, "Property_0_is_used_before_its_initialization_2729", "Property '{0}' is used before its initialization."),
                    An_arrow_function_cannot_have_a_this_parameter: diag(2730, 1 /* Error */, "An_arrow_function_cannot_have_a_this_parameter_2730", "An arrow function cannot have a 'this' parameter."),
                    Implicit_conversion_of_a_symbol_to_a_string_will_fail_at_runtime_Consider_wrapping_this_expression_in_String: diag(2731, 1 /* Error */, "Implicit_conversion_of_a_symbol_to_a_string_will_fail_at_runtime_Consider_wrapping_this_expression_i_2731", "Implicit conversion of a 'symbol' to a 'string' will fail at runtime. Consider wrapping this expression in 'String(...)'."),
                    Cannot_find_module_0_Consider_using_resolveJsonModule_to_import_module_with_json_extension: diag(2732, 1 /* Error */, "Cannot_find_module_0_Consider_using_resolveJsonModule_to_import_module_with_json_extension_2732", "Cannot find module '{0}'. Consider using '--resolveJsonModule' to import module with '.json' extension."),
                    Property_0_was_also_declared_here: diag(2733, 1 /* Error */, "Property_0_was_also_declared_here_2733", "Property '{0}' was also declared here."),
                    Are_you_missing_a_semicolon: diag(2734, 1 /* Error */, "Are_you_missing_a_semicolon_2734", "Are you missing a semicolon?"),
                    Did_you_mean_for_0_to_be_constrained_to_type_new_args_Colon_any_1: diag(2735, 1 /* Error */, "Did_you_mean_for_0_to_be_constrained_to_type_new_args_Colon_any_1_2735", "Did you mean for '{0}' to be constrained to type 'new (...args: any[]) => {1}'?"),
                    Operator_0_cannot_be_applied_to_type_1: diag(2736, 1 /* Error */, "Operator_0_cannot_be_applied_to_type_1_2736", "Operator '{0}' cannot be applied to type '{1}'."),
                    BigInt_literals_are_not_available_when_targeting_lower_than_ES2020: diag(2737, 1 /* Error */, "BigInt_literals_are_not_available_when_targeting_lower_than_ES2020_2737", "BigInt literals are not available when targeting lower than ES2020."),
                    An_outer_value_of_this_is_shadowed_by_this_container: diag(2738, 3 /* Message */, "An_outer_value_of_this_is_shadowed_by_this_container_2738", "An outer value of 'this' is shadowed by this container."),
                    Type_0_is_missing_the_following_properties_from_type_1_Colon_2: diag(2739, 1 /* Error */, "Type_0_is_missing_the_following_properties_from_type_1_Colon_2_2739", "Type '{0}' is missing the following properties from type '{1}': {2}"),
                    Type_0_is_missing_the_following_properties_from_type_1_Colon_2_and_3_more: diag(2740, 1 /* Error */, "Type_0_is_missing_the_following_properties_from_type_1_Colon_2_and_3_more_2740", "Type '{0}' is missing the following properties from type '{1}': {2}, and {3} more."),
                    Property_0_is_missing_in_type_1_but_required_in_type_2: diag(2741, 1 /* Error */, "Property_0_is_missing_in_type_1_but_required_in_type_2_2741", "Property '{0}' is missing in type '{1}' but required in type '{2}'."),
                    The_inferred_type_of_0_cannot_be_named_without_a_reference_to_1_This_is_likely_not_portable_A_type_annotation_is_necessary: diag(2742, 1 /* Error */, "The_inferred_type_of_0_cannot_be_named_without_a_reference_to_1_This_is_likely_not_portable_A_type_a_2742", "The inferred type of '{0}' cannot be named without a reference to '{1}'. This is likely not portable. A type annotation is necessary."),
                    No_overload_expects_0_type_arguments_but_overloads_do_exist_that_expect_either_1_or_2_type_arguments: diag(2743, 1 /* Error */, "No_overload_expects_0_type_arguments_but_overloads_do_exist_that_expect_either_1_or_2_type_arguments_2743", "No overload expects {0} type arguments, but overloads do exist that expect either {1} or {2} type arguments."),
                    Type_parameter_defaults_can_only_reference_previously_declared_type_parameters: diag(2744, 1 /* Error */, "Type_parameter_defaults_can_only_reference_previously_declared_type_parameters_2744", "Type parameter defaults can only reference previously declared type parameters."),
                    This_JSX_tag_s_0_prop_expects_type_1_which_requires_multiple_children_but_only_a_single_child_was_provided: diag(2745, 1 /* Error */, "This_JSX_tag_s_0_prop_expects_type_1_which_requires_multiple_children_but_only_a_single_child_was_pr_2745", "This JSX tag's '{0}' prop expects type '{1}' which requires multiple children, but only a single child was provided."),
                    This_JSX_tag_s_0_prop_expects_a_single_child_of_type_1_but_multiple_children_were_provided: diag(2746, 1 /* Error */, "This_JSX_tag_s_0_prop_expects_a_single_child_of_type_1_but_multiple_children_were_provided_2746", "This JSX tag's '{0}' prop expects a single child of type '{1}', but multiple children were provided."),
                    _0_components_don_t_accept_text_as_child_elements_Text_in_JSX_has_the_type_string_but_the_expected_type_of_1_is_2: diag(2747, 1 /* Error */, "_0_components_don_t_accept_text_as_child_elements_Text_in_JSX_has_the_type_string_but_the_expected_t_2747", "'{0}' components don't accept text as child elements. Text in JSX has the type 'string', but the expected type of '{1}' is '{2}'."),
                    Cannot_access_ambient_const_enums_when_0_is_enabled: diag(2748, 1 /* Error */, "Cannot_access_ambient_const_enums_when_0_is_enabled_2748", "Cannot access ambient const enums when '{0}' is enabled."),
                    _0_refers_to_a_value_but_is_being_used_as_a_type_here_Did_you_mean_typeof_0: diag(2749, 1 /* Error */, "_0_refers_to_a_value_but_is_being_used_as_a_type_here_Did_you_mean_typeof_0_2749", "'{0}' refers to a value, but is being used as a type here. Did you mean 'typeof {0}'?"),
                    The_implementation_signature_is_declared_here: diag(2750, 1 /* Error */, "The_implementation_signature_is_declared_here_2750", "The implementation signature is declared here."),
                    Circularity_originates_in_type_at_this_location: diag(2751, 1 /* Error */, "Circularity_originates_in_type_at_this_location_2751", "Circularity originates in type at this location."),
                    The_first_export_default_is_here: diag(2752, 1 /* Error */, "The_first_export_default_is_here_2752", "The first export default is here."),
                    Another_export_default_is_here: diag(2753, 1 /* Error */, "Another_export_default_is_here_2753", "Another export default is here."),
                    super_may_not_use_type_arguments: diag(2754, 1 /* Error */, "super_may_not_use_type_arguments_2754", "'super' may not use type arguments."),
                    No_constituent_of_type_0_is_callable: diag(2755, 1 /* Error */, "No_constituent_of_type_0_is_callable_2755", "No constituent of type '{0}' is callable."),
                    Not_all_constituents_of_type_0_are_callable: diag(2756, 1 /* Error */, "Not_all_constituents_of_type_0_are_callable_2756", "Not all constituents of type '{0}' are callable."),
                    Type_0_has_no_call_signatures: diag(2757, 1 /* Error */, "Type_0_has_no_call_signatures_2757", "Type '{0}' has no call signatures."),
                    Each_member_of_the_union_type_0_has_signatures_but_none_of_those_signatures_are_compatible_with_each_other: diag(2758, 1 /* Error */, "Each_member_of_the_union_type_0_has_signatures_but_none_of_those_signatures_are_compatible_with_each_2758", "Each member of the union type '{0}' has signatures, but none of those signatures are compatible with each other."),
                    No_constituent_of_type_0_is_constructable: diag(2759, 1 /* Error */, "No_constituent_of_type_0_is_constructable_2759", "No constituent of type '{0}' is constructable."),
                    Not_all_constituents_of_type_0_are_constructable: diag(2760, 1 /* Error */, "Not_all_constituents_of_type_0_are_constructable_2760", "Not all constituents of type '{0}' are constructable."),
                    Type_0_has_no_construct_signatures: diag(2761, 1 /* Error */, "Type_0_has_no_construct_signatures_2761", "Type '{0}' has no construct signatures."),
                    Each_member_of_the_union_type_0_has_construct_signatures_but_none_of_those_signatures_are_compatible_with_each_other: diag(2762, 1 /* Error */, "Each_member_of_the_union_type_0_has_construct_signatures_but_none_of_those_signatures_are_compatible_2762", "Each member of the union type '{0}' has construct signatures, but none of those signatures are compatible with each other."),
                    Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_for_of_will_always_send_0: diag(2763, 1 /* Error */, "Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_for_of_will_always_s_2763", "Cannot iterate value because the 'next' method of its iterator expects type '{1}', but for-of will always send '{0}'."),
                    Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_array_spread_will_always_send_0: diag(2764, 1 /* Error */, "Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_array_spread_will_al_2764", "Cannot iterate value because the 'next' method of its iterator expects type '{1}', but array spread will always send '{0}'."),
                    Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_array_destructuring_will_always_send_0: diag(2765, 1 /* Error */, "Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_array_destructuring__2765", "Cannot iterate value because the 'next' method of its iterator expects type '{1}', but array destructuring will always send '{0}'."),
                    Cannot_delegate_iteration_to_value_because_the_next_method_of_its_iterator_expects_type_1_but_the_containing_generator_will_always_send_0: diag(2766, 1 /* Error */, "Cannot_delegate_iteration_to_value_because_the_next_method_of_its_iterator_expects_type_1_but_the_co_2766", "Cannot delegate iteration to value because the 'next' method of its iterator expects type '{1}', but the containing generator will always send '{0}'."),
                    The_0_property_of_an_iterator_must_be_a_method: diag(2767, 1 /* Error */, "The_0_property_of_an_iterator_must_be_a_method_2767", "The '{0}' property of an iterator must be a method."),
                    The_0_property_of_an_async_iterator_must_be_a_method: diag(2768, 1 /* Error */, "The_0_property_of_an_async_iterator_must_be_a_method_2768", "The '{0}' property of an async iterator must be a method."),
                    No_overload_matches_this_call: diag(2769, 1 /* Error */, "No_overload_matches_this_call_2769", "No overload matches this call."),
                    The_last_overload_gave_the_following_error: diag(2770, 1 /* Error */, "The_last_overload_gave_the_following_error_2770", "The last overload gave the following error."),
                    The_last_overload_is_declared_here: diag(2771, 1 /* Error */, "The_last_overload_is_declared_here_2771", "The last overload is declared here."),
                    Overload_0_of_1_2_gave_the_following_error: diag(2772, 1 /* Error */, "Overload_0_of_1_2_gave_the_following_error_2772", "Overload {0} of {1}, '{2}', gave the following error."),
                    Did_you_forget_to_use_await: diag(2773, 1 /* Error */, "Did_you_forget_to_use_await_2773", "Did you forget to use 'await'?"),
                    This_condition_will_always_return_true_since_this_function_is_always_defined_Did_you_mean_to_call_it_instead: diag(2774, 1 /* Error */, "This_condition_will_always_return_true_since_this_function_is_always_defined_Did_you_mean_to_call_it_2774", "This condition will always return true since this function is always defined. Did you mean to call it instead?"),
                    Assertions_require_every_name_in_the_call_target_to_be_declared_with_an_explicit_type_annotation: diag(2775, 1 /* Error */, "Assertions_require_every_name_in_the_call_target_to_be_declared_with_an_explicit_type_annotation_2775", "Assertions require every name in the call target to be declared with an explicit type annotation."),
                    Assertions_require_the_call_target_to_be_an_identifier_or_qualified_name: diag(2776, 1 /* Error */, "Assertions_require_the_call_target_to_be_an_identifier_or_qualified_name_2776", "Assertions require the call target to be an identifier or qualified name."),
                    The_operand_of_an_increment_or_decrement_operator_may_not_be_an_optional_property_access: diag(2777, 1 /* Error */, "The_operand_of_an_increment_or_decrement_operator_may_not_be_an_optional_property_access_2777", "The operand of an increment or decrement operator may not be an optional property access."),
                    The_target_of_an_object_rest_assignment_may_not_be_an_optional_property_access: diag(2778, 1 /* Error */, "The_target_of_an_object_rest_assignment_may_not_be_an_optional_property_access_2778", "The target of an object rest assignment may not be an optional property access."),
                    The_left_hand_side_of_an_assignment_expression_may_not_be_an_optional_property_access: diag(2779, 1 /* Error */, "The_left_hand_side_of_an_assignment_expression_may_not_be_an_optional_property_access_2779", "The left-hand side of an assignment expression may not be an optional property access."),
                    The_left_hand_side_of_a_for_in_statement_may_not_be_an_optional_property_access: diag(2780, 1 /* Error */, "The_left_hand_side_of_a_for_in_statement_may_not_be_an_optional_property_access_2780", "The left-hand side of a 'for...in' statement may not be an optional property access."),
                    The_left_hand_side_of_a_for_of_statement_may_not_be_an_optional_property_access: diag(2781, 1 /* Error */, "The_left_hand_side_of_a_for_of_statement_may_not_be_an_optional_property_access_2781", "The left-hand side of a 'for...of' statement may not be an optional property access."),
                    _0_needs_an_explicit_type_annotation: diag(2782, 3 /* Message */, "_0_needs_an_explicit_type_annotation_2782", "'{0}' needs an explicit type annotation."),
                    _0_is_specified_more_than_once_so_this_usage_will_be_overwritten: diag(2783, 1 /* Error */, "_0_is_specified_more_than_once_so_this_usage_will_be_overwritten_2783", "'{0}' is specified more than once, so this usage will be overwritten."),
                    get_and_set_accessors_cannot_declare_this_parameters: diag(2784, 1 /* Error */, "get_and_set_accessors_cannot_declare_this_parameters_2784", "'get' and 'set' accessors cannot declare 'this' parameters."),
                    This_spread_always_overwrites_this_property: diag(2785, 1 /* Error */, "This_spread_always_overwrites_this_property_2785", "This spread always overwrites this property."),
                    _0_cannot_be_used_as_a_JSX_component: diag(2786, 1 /* Error */, "_0_cannot_be_used_as_a_JSX_component_2786", "'{0}' cannot be used as a JSX component."),
                    Its_return_type_0_is_not_a_valid_JSX_element: diag(2787, 1 /* Error */, "Its_return_type_0_is_not_a_valid_JSX_element_2787", "Its return type '{0}' is not a valid JSX element."),
                    Its_instance_type_0_is_not_a_valid_JSX_element: diag(2788, 1 /* Error */, "Its_instance_type_0_is_not_a_valid_JSX_element_2788", "Its instance type '{0}' is not a valid JSX element."),
                    Its_element_type_0_is_not_a_valid_JSX_element: diag(2789, 1 /* Error */, "Its_element_type_0_is_not_a_valid_JSX_element_2789", "Its element type '{0}' is not a valid JSX element."),
                    The_operand_of_a_delete_operator_must_be_optional: diag(2790, 1 /* Error */, "The_operand_of_a_delete_operator_must_be_optional_2790", "The operand of a 'delete' operator must be optional."),
                    Exponentiation_cannot_be_performed_on_bigint_values_unless_the_target_option_is_set_to_es2016_or_later: diag(2791, 1 /* Error */, "Exponentiation_cannot_be_performed_on_bigint_values_unless_the_target_option_is_set_to_es2016_or_lat_2791", "Exponentiation cannot be performed on 'bigint' values unless the 'target' option is set to 'es2016' or later."),
                    Cannot_find_module_0_Did_you_mean_to_set_the_moduleResolution_option_to_nodenext_or_to_add_aliases_to_the_paths_option: diag(2792, 1 /* Error */, "Cannot_find_module_0_Did_you_mean_to_set_the_moduleResolution_option_to_nodenext_or_to_add_aliases_t_2792", "Cannot find module '{0}'. Did you mean to set the 'moduleResolution' option to 'nodenext', or to add aliases to the 'paths' option?"),
                    The_call_would_have_succeeded_against_this_implementation_but_implementation_signatures_of_overloads_are_not_externally_visible: diag(2793, 1 /* Error */, "The_call_would_have_succeeded_against_this_implementation_but_implementation_signatures_of_overloads_2793", "The call would have succeeded against this implementation, but implementation signatures of overloads are not externally visible."),
                    Expected_0_arguments_but_got_1_Did_you_forget_to_include_void_in_your_type_argument_to_Promise: diag(2794, 1 /* Error */, "Expected_0_arguments_but_got_1_Did_you_forget_to_include_void_in_your_type_argument_to_Promise_2794", "Expected {0} arguments, but got {1}. Did you forget to include 'void' in your type argument to 'Promise'?"),
                    The_intrinsic_keyword_can_only_be_used_to_declare_compiler_provided_intrinsic_types: diag(2795, 1 /* Error */, "The_intrinsic_keyword_can_only_be_used_to_declare_compiler_provided_intrinsic_types_2795", "The 'intrinsic' keyword can only be used to declare compiler provided intrinsic types."),
                    It_is_likely_that_you_are_missing_a_comma_to_separate_these_two_template_expressions_They_form_a_tagged_template_expression_which_cannot_be_invoked: diag(2796, 1 /* Error */, "It_is_likely_that_you_are_missing_a_comma_to_separate_these_two_template_expressions_They_form_a_tag_2796", "It is likely that you are missing a comma to separate these two template expressions. They form a tagged template expression which cannot be invoked."),
                    A_mixin_class_that_extends_from_a_type_variable_containing_an_abstract_construct_signature_must_also_be_declared_abstract: diag(2797, 1 /* Error */, "A_mixin_class_that_extends_from_a_type_variable_containing_an_abstract_construct_signature_must_also_2797", "A mixin class that extends from a type variable containing an abstract construct signature must also be declared 'abstract'."),
                    The_declaration_was_marked_as_deprecated_here: diag(2798, 1 /* Error */, "The_declaration_was_marked_as_deprecated_here_2798", "The declaration was marked as deprecated here."),
                    Type_produces_a_tuple_type_that_is_too_large_to_represent: diag(2799, 1 /* Error */, "Type_produces_a_tuple_type_that_is_too_large_to_represent_2799", "Type produces a tuple type that is too large to represent."),
                    Expression_produces_a_tuple_type_that_is_too_large_to_represent: diag(2800, 1 /* Error */, "Expression_produces_a_tuple_type_that_is_too_large_to_represent_2800", "Expression produces a tuple type that is too large to represent."),
                    This_condition_will_always_return_true_since_this_0_is_always_defined: diag(2801, 1 /* Error */, "This_condition_will_always_return_true_since_this_0_is_always_defined_2801", "This condition will always return true since this '{0}' is always defined."),
                    Type_0_can_only_be_iterated_through_when_using_the_downlevelIteration_flag_or_with_a_target_of_es2015_or_higher: diag(2802, 1 /* Error */, "Type_0_can_only_be_iterated_through_when_using_the_downlevelIteration_flag_or_with_a_target_of_es201_2802", "Type '{0}' can only be iterated through when using the '--downlevelIteration' flag or with a '--target' of 'es2015' or higher."),
                    Cannot_assign_to_private_method_0_Private_methods_are_not_writable: diag(2803, 1 /* Error */, "Cannot_assign_to_private_method_0_Private_methods_are_not_writable_2803", "Cannot assign to private method '{0}'. Private methods are not writable."),
                    Duplicate_identifier_0_Static_and_instance_elements_cannot_share_the_same_private_name: diag(2804, 1 /* Error */, "Duplicate_identifier_0_Static_and_instance_elements_cannot_share_the_same_private_name_2804", "Duplicate identifier '{0}'. Static and instance elements cannot share the same private name."),
                    Private_accessor_was_defined_without_a_getter: diag(2806, 1 /* Error */, "Private_accessor_was_defined_without_a_getter_2806", "Private accessor was defined without a getter."),
                    This_syntax_requires_an_imported_helper_named_1_with_2_parameters_which_is_not_compatible_with_the_one_in_0_Consider_upgrading_your_version_of_0: diag(2807, 1 /* Error */, "This_syntax_requires_an_imported_helper_named_1_with_2_parameters_which_is_not_compatible_with_the_o_2807", "This syntax requires an imported helper named '{1}' with {2} parameters, which is not compatible with the one in '{0}'. Consider upgrading your version of '{0}'."),
                    A_get_accessor_must_be_at_least_as_accessible_as_the_setter: diag(2808, 1 /* Error */, "A_get_accessor_must_be_at_least_as_accessible_as_the_setter_2808", "A get accessor must be at least as accessible as the setter"),
                    Declaration_or_statement_expected_This_follows_a_block_of_statements_so_if_you_intended_to_write_a_destructuring_assignment_you_might_need_to_wrap_the_whole_assignment_in_parentheses: diag(2809, 1 /* Error */, "Declaration_or_statement_expected_This_follows_a_block_of_statements_so_if_you_intended_to_write_a_d_2809", "Declaration or statement expected. This '=' follows a block of statements, so if you intended to write a destructuring assignment, you might need to wrap the whole assignment in parentheses."),
                    Expected_1_argument_but_got_0_new_Promise_needs_a_JSDoc_hint_to_produce_a_resolve_that_can_be_called_without_arguments: diag(2810, 1 /* Error */, "Expected_1_argument_but_got_0_new_Promise_needs_a_JSDoc_hint_to_produce_a_resolve_that_can_be_called_2810", "Expected 1 argument, but got 0. 'new Promise()' needs a JSDoc hint to produce a 'resolve' that can be called without arguments."),
                    Initializer_for_property_0: diag(2811, 1 /* Error */, "Initializer_for_property_0_2811", "Initializer for property '{0}'"),
                    Property_0_does_not_exist_on_type_1_Try_changing_the_lib_compiler_option_to_include_dom: diag(2812, 1 /* Error */, "Property_0_does_not_exist_on_type_1_Try_changing_the_lib_compiler_option_to_include_dom_2812", "Property '{0}' does not exist on type '{1}'. Try changing the 'lib' compiler option to include 'dom'."),
                    Class_declaration_cannot_implement_overload_list_for_0: diag(2813, 1 /* Error */, "Class_declaration_cannot_implement_overload_list_for_0_2813", "Class declaration cannot implement overload list for '{0}'."),
                    Function_with_bodies_can_only_merge_with_classes_that_are_ambient: diag(2814, 1 /* Error */, "Function_with_bodies_can_only_merge_with_classes_that_are_ambient_2814", "Function with bodies can only merge with classes that are ambient."),
                    arguments_cannot_be_referenced_in_property_initializers: diag(2815, 1 /* Error */, "arguments_cannot_be_referenced_in_property_initializers_2815", "'arguments' cannot be referenced in property initializers."),
                    Cannot_use_this_in_a_static_property_initializer_of_a_decorated_class: diag(2816, 1 /* Error */, "Cannot_use_this_in_a_static_property_initializer_of_a_decorated_class_2816", "Cannot use 'this' in a static property initializer of a decorated class."),
                    Property_0_has_no_initializer_and_is_not_definitely_assigned_in_a_class_static_block: diag(2817, 1 /* Error */, "Property_0_has_no_initializer_and_is_not_definitely_assigned_in_a_class_static_block_2817", "Property '{0}' has no initializer and is not definitely assigned in a class static block."),
                    Duplicate_identifier_0_Compiler_reserves_name_1_when_emitting_super_references_in_static_initializers: diag(2818, 1 /* Error */, "Duplicate_identifier_0_Compiler_reserves_name_1_when_emitting_super_references_in_static_initializer_2818", "Duplicate identifier '{0}'. Compiler reserves name '{1}' when emitting 'super' references in static initializers."),
                    Namespace_name_cannot_be_0: diag(2819, 1 /* Error */, "Namespace_name_cannot_be_0_2819", "Namespace name cannot be '{0}'."),
                    Type_0_is_not_assignable_to_type_1_Did_you_mean_2: diag(2820, 1 /* Error */, "Type_0_is_not_assignable_to_type_1_Did_you_mean_2_2820", "Type '{0}' is not assignable to type '{1}'. Did you mean '{2}'?"),
                    Import_assertions_are_only_supported_when_the_module_option_is_set_to_esnext_nodenext_or_preserve: diag(2821, 1 /* Error */, "Import_assertions_are_only_supported_when_the_module_option_is_set_to_esnext_nodenext_or_preserve_2821", "Import assertions are only supported when the '--module' option is set to 'esnext', 'nodenext', or 'preserve'."),
                    Import_assertions_cannot_be_used_with_type_only_imports_or_exports: diag(2822, 1 /* Error */, "Import_assertions_cannot_be_used_with_type_only_imports_or_exports_2822", "Import assertions cannot be used with type-only imports or exports."),
                    Import_attributes_are_only_supported_when_the_module_option_is_set_to_esnext_nodenext_or_preserve: diag(2823, 1 /* Error */, "Import_attributes_are_only_supported_when_the_module_option_is_set_to_esnext_nodenext_or_preserve_2823", "Import attributes are only supported when the '--module' option is set to 'esnext', 'nodenext', or 'preserve'."),
                    Cannot_find_namespace_0_Did_you_mean_1: diag(2833, 1 /* Error */, "Cannot_find_namespace_0_Did_you_mean_1_2833", "Cannot find namespace '{0}'. Did you mean '{1}'?"),
                    Relative_import_paths_need_explicit_file_extensions_in_ECMAScript_imports_when_moduleResolution_is_node16_or_nodenext_Consider_adding_an_extension_to_the_import_path: diag(2834, 1 /* Error */, "Relative_import_paths_need_explicit_file_extensions_in_ECMAScript_imports_when_moduleResolution_is_n_2834", "Relative import paths need explicit file extensions in ECMAScript imports when '--moduleResolution' is 'node16' or 'nodenext'. Consider adding an extension to the import path."),
                    Relative_import_paths_need_explicit_file_extensions_in_ECMAScript_imports_when_moduleResolution_is_node16_or_nodenext_Did_you_mean_0: diag(2835, 1 /* Error */, "Relative_import_paths_need_explicit_file_extensions_in_ECMAScript_imports_when_moduleResolution_is_n_2835", "Relative import paths need explicit file extensions in ECMAScript imports when '--moduleResolution' is 'node16' or 'nodenext'. Did you mean '{0}'?"),
                    Import_assertions_are_not_allowed_on_statements_that_compile_to_CommonJS_require_calls: diag(2836, 1 /* Error */, "Import_assertions_are_not_allowed_on_statements_that_compile_to_CommonJS_require_calls_2836", "Import assertions are not allowed on statements that compile to CommonJS 'require' calls."),
                    Import_assertion_values_must_be_string_literal_expressions: diag(2837, 1 /* Error */, "Import_assertion_values_must_be_string_literal_expressions_2837", "Import assertion values must be string literal expressions."),
                    All_declarations_of_0_must_have_identical_constraints: diag(2838, 1 /* Error */, "All_declarations_of_0_must_have_identical_constraints_2838", "All declarations of '{0}' must have identical constraints."),
                    This_condition_will_always_return_0_since_JavaScript_compares_objects_by_reference_not_value: diag(2839, 1 /* Error */, "This_condition_will_always_return_0_since_JavaScript_compares_objects_by_reference_not_value_2839", "This condition will always return '{0}' since JavaScript compares objects by reference, not value."),
                    An_interface_cannot_extend_a_primitive_type_like_0_It_can_only_extend_other_named_object_types: diag(2840, 1 /* Error */, "An_interface_cannot_extend_a_primitive_type_like_0_It_can_only_extend_other_named_object_types_2840", "An interface cannot extend a primitive type like '{0}'. It can only extend other named object types."),
                    _0_is_an_unused_renaming_of_1_Did_you_intend_to_use_it_as_a_type_annotation: diag(2842, 1 /* Error */, "_0_is_an_unused_renaming_of_1_Did_you_intend_to_use_it_as_a_type_annotation_2842", "'{0}' is an unused renaming of '{1}'. Did you intend to use it as a type annotation?"),
                    We_can_only_write_a_type_for_0_by_adding_a_type_for_the_entire_parameter_here: diag(2843, 1 /* Error */, "We_can_only_write_a_type_for_0_by_adding_a_type_for_the_entire_parameter_here_2843", "We can only write a type for '{0}' by adding a type for the entire parameter here."),
                    Type_of_instance_member_variable_0_cannot_reference_identifier_1_declared_in_the_constructor: diag(2844, 1 /* Error */, "Type_of_instance_member_variable_0_cannot_reference_identifier_1_declared_in_the_constructor_2844", "Type of instance member variable '{0}' cannot reference identifier '{1}' declared in the constructor."),
                    This_condition_will_always_return_0: diag(2845, 1 /* Error */, "This_condition_will_always_return_0_2845", "This condition will always return '{0}'."),
                    A_declaration_file_cannot_be_imported_without_import_type_Did_you_mean_to_import_an_implementation_file_0_instead: diag(2846, 1 /* Error */, "A_declaration_file_cannot_be_imported_without_import_type_Did_you_mean_to_import_an_implementation_f_2846", "A declaration file cannot be imported without 'import type'. Did you mean to import an implementation file '{0}' instead?"),
                    The_right_hand_side_of_an_instanceof_expression_must_not_be_an_instantiation_expression: diag(2848, 1 /* Error */, "The_right_hand_side_of_an_instanceof_expression_must_not_be_an_instantiation_expression_2848", "The right-hand side of an 'instanceof' expression must not be an instantiation expression."),
                    Target_signature_provides_too_few_arguments_Expected_0_or_more_but_got_1: diag(2849, 1 /* Error */, "Target_signature_provides_too_few_arguments_Expected_0_or_more_but_got_1_2849", "Target signature provides too few arguments. Expected {0} or more, but got {1}."),
                    The_initializer_of_a_using_declaration_must_be_either_an_object_with_a_Symbol_dispose_method_or_be_null_or_undefined: diag(2850, 1 /* Error */, "The_initializer_of_a_using_declaration_must_be_either_an_object_with_a_Symbol_dispose_method_or_be_n_2850", "The initializer of a 'using' declaration must be either an object with a '[Symbol.dispose]()' method, or be 'null' or 'undefined'."),
                    The_initializer_of_an_await_using_declaration_must_be_either_an_object_with_a_Symbol_asyncDispose_or_Symbol_dispose_method_or_be_null_or_undefined: diag(2851, 1 /* Error */, "The_initializer_of_an_await_using_declaration_must_be_either_an_object_with_a_Symbol_asyncDispose_or_2851", "The initializer of an 'await using' declaration must be either an object with a '[Symbol.asyncDispose]()' or '[Symbol.dispose]()' method, or be 'null' or 'undefined'."),
                    await_using_statements_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules: diag(2852, 1 /* Error */, "await_using_statements_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules_2852", "'await using' statements are only allowed within async functions and at the top levels of modules."),
                    await_using_statements_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_has_no_imports_or_exports_Consider_adding_an_empty_export_to_make_this_file_a_module: diag(2853, 1 /* Error */, "await_using_statements_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_th_2853", "'await using' statements are only allowed at the top level of a file when that file is a module, but this file has no imports or exports. Consider adding an empty 'export {}' to make this file a module."),
                    Top_level_await_using_statements_are_only_allowed_when_the_module_option_is_set_to_es2022_esnext_system_node16_nodenext_or_preserve_and_the_target_option_is_set_to_es2017_or_higher: diag(2854, 1 /* Error */, "Top_level_await_using_statements_are_only_allowed_when_the_module_option_is_set_to_es2022_esnext_sys_2854", "Top-level 'await using' statements are only allowed when the 'module' option is set to 'es2022', 'esnext', 'system', 'node16', 'nodenext', or 'preserve', and the 'target' option is set to 'es2017' or higher."),
                    Class_field_0_defined_by_the_parent_class_is_not_accessible_in_the_child_class_via_super: diag(2855, 1 /* Error */, "Class_field_0_defined_by_the_parent_class_is_not_accessible_in_the_child_class_via_super_2855", "Class field '{0}' defined by the parent class is not accessible in the child class via super."),
                    Import_attributes_are_not_allowed_on_statements_that_compile_to_CommonJS_require_calls: diag(2856, 1 /* Error */, "Import_attributes_are_not_allowed_on_statements_that_compile_to_CommonJS_require_calls_2856", "Import attributes are not allowed on statements that compile to CommonJS 'require' calls."),
                    Import_attributes_cannot_be_used_with_type_only_imports_or_exports: diag(2857, 1 /* Error */, "Import_attributes_cannot_be_used_with_type_only_imports_or_exports_2857", "Import attributes cannot be used with type-only imports or exports."),
                    Import_attribute_values_must_be_string_literal_expressions: diag(2858, 1 /* Error */, "Import_attribute_values_must_be_string_literal_expressions_2858", "Import attribute values must be string literal expressions."),
                    Excessive_complexity_comparing_types_0_and_1: diag(2859, 1 /* Error */, "Excessive_complexity_comparing_types_0_and_1_2859", "Excessive complexity comparing types '{0}' and '{1}'."),
                    The_left_hand_side_of_an_instanceof_expression_must_be_assignable_to_the_first_argument_of_the_right_hand_side_s_Symbol_hasInstance_method: diag(2860, 1 /* Error */, "The_left_hand_side_of_an_instanceof_expression_must_be_assignable_to_the_first_argument_of_the_right_2860", "The left-hand side of an 'instanceof' expression must be assignable to the first argument of the right-hand side's '[Symbol.hasInstance]' method."),
                    An_object_s_Symbol_hasInstance_method_must_return_a_boolean_value_for_it_to_be_used_on_the_right_hand_side_of_an_instanceof_expression: diag(2861, 1 /* Error */, "An_object_s_Symbol_hasInstance_method_must_return_a_boolean_value_for_it_to_be_used_on_the_right_han_2861", "An object's '[Symbol.hasInstance]' method must return a boolean value for it to be used on the right-hand side of an 'instanceof' expression."),
                    Type_0_is_generic_and_can_only_be_indexed_for_reading: diag(2862, 1 /* Error */, "Type_0_is_generic_and_can_only_be_indexed_for_reading_2862", "Type '{0}' is generic and can only be indexed for reading."),
                    A_class_cannot_extend_a_primitive_type_like_0_Classes_can_only_extend_constructable_values: diag(2863, 1 /* Error */, "A_class_cannot_extend_a_primitive_type_like_0_Classes_can_only_extend_constructable_values_2863", "A class cannot extend a primitive type like '{0}'. Classes can only extend constructable values."),
                    A_class_cannot_implement_a_primitive_type_like_0_It_can_only_implement_other_named_object_types: diag(2864, 1 /* Error */, "A_class_cannot_implement_a_primitive_type_like_0_It_can_only_implement_other_named_object_types_2864", "A class cannot implement a primitive type like '{0}'. It can only implement other named object types."),
                    Import_0_conflicts_with_local_value_so_must_be_declared_with_a_type_only_import_when_isolatedModules_is_enabled: diag(2865, 1 /* Error */, "Import_0_conflicts_with_local_value_so_must_be_declared_with_a_type_only_import_when_isolatedModules_2865", "Import '{0}' conflicts with local value, so must be declared with a type-only import when 'isolatedModules' is enabled."),
                    Import_0_conflicts_with_global_value_used_in_this_file_so_must_be_declared_with_a_type_only_import_when_isolatedModules_is_enabled: diag(2866, 1 /* Error */, "Import_0_conflicts_with_global_value_used_in_this_file_so_must_be_declared_with_a_type_only_import_w_2866", "Import '{0}' conflicts with global value used in this file, so must be declared with a type-only import when 'isolatedModules' is enabled."),
                    Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_Bun_Try_npm_i_save_dev_types_Slashbun: diag(2867, 1 /* Error */, "Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_Bun_Try_npm_i_save_dev_types_Slashbun_2867", "Cannot find name '{0}'. Do you need to install type definitions for Bun? Try `npm i --save-dev @types/bun`."),
                    Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_Bun_Try_npm_i_save_dev_types_Slashbun_and_then_add_bun_to_the_types_field_in_your_tsconfig: diag(2868, 1 /* Error */, "Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_Bun_Try_npm_i_save_dev_types_Slashbun_2868", "Cannot find name '{0}'. Do you need to install type definitions for Bun? Try `npm i --save-dev @types/bun` and then add 'bun' to the types field in your tsconfig."),
                    Import_declaration_0_is_using_private_name_1: diag(4e3, 1 /* Error */, "Import_declaration_0_is_using_private_name_1_4000", "Import declaration '{0}' is using private name '{1}'."),
                    Type_parameter_0_of_exported_class_has_or_is_using_private_name_1: diag(4002, 1 /* Error */, "Type_parameter_0_of_exported_class_has_or_is_using_private_name_1_4002", "Type parameter '{0}' of exported class has or is using private name '{1}'."),
                    Type_parameter_0_of_exported_interface_has_or_is_using_private_name_1: diag(4004, 1 /* Error */, "Type_parameter_0_of_exported_interface_has_or_is_using_private_name_1_4004", "Type parameter '{0}' of exported interface has or is using private name '{1}'."),
                    Type_parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1: diag(4006, 1 /* Error */, "Type_parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1_4006", "Type parameter '{0}' of constructor signature from exported interface has or is using private name '{1}'."),
                    Type_parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1: diag(4008, 1 /* Error */, "Type_parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1_4008", "Type parameter '{0}' of call signature from exported interface has or is using private name '{1}'."),
                    Type_parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1: diag(4010, 1 /* Error */, "Type_parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1_4010", "Type parameter '{0}' of public static method from exported class has or is using private name '{1}'."),
                    Type_parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1: diag(4012, 1 /* Error */, "Type_parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1_4012", "Type parameter '{0}' of public method from exported class has or is using private name '{1}'."),
                    Type_parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1: diag(4014, 1 /* Error */, "Type_parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1_4014", "Type parameter '{0}' of method from exported interface has or is using private name '{1}'."),
                    Type_parameter_0_of_exported_function_has_or_is_using_private_name_1: diag(4016, 1 /* Error */, "Type_parameter_0_of_exported_function_has_or_is_using_private_name_1_4016", "Type parameter '{0}' of exported function has or is using private name '{1}'."),
                    Implements_clause_of_exported_class_0_has_or_is_using_private_name_1: diag(4019, 1 /* Error */, "Implements_clause_of_exported_class_0_has_or_is_using_private_name_1_4019", "Implements clause of exported class '{0}' has or is using private name '{1}'."),
                    extends_clause_of_exported_class_0_has_or_is_using_private_name_1: diag(4020, 1 /* Error */, "extends_clause_of_exported_class_0_has_or_is_using_private_name_1_4020", "'extends' clause of exported class '{0}' has or is using private name '{1}'."),
                    extends_clause_of_exported_class_has_or_is_using_private_name_0: diag(4021, 1 /* Error */, "extends_clause_of_exported_class_has_or_is_using_private_name_0_4021", "'extends' clause of exported class has or is using private name '{0}'."),
                    extends_clause_of_exported_interface_0_has_or_is_using_private_name_1: diag(4022, 1 /* Error */, "extends_clause_of_exported_interface_0_has_or_is_using_private_name_1_4022", "'extends' clause of exported interface '{0}' has or is using private name '{1}'."),
                    Exported_variable_0_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: diag(4023, 1 /* Error */, "Exported_variable_0_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named_4023", "Exported variable '{0}' has or is using name '{1}' from external module {2} but cannot be named."),
                    Exported_variable_0_has_or_is_using_name_1_from_private_module_2: diag(4024, 1 /* Error */, "Exported_variable_0_has_or_is_using_name_1_from_private_module_2_4024", "Exported variable '{0}' has or is using name '{1}' from private module '{2}'."),
                    Exported_variable_0_has_or_is_using_private_name_1: diag(4025, 1 /* Error */, "Exported_variable_0_has_or_is_using_private_name_1_4025", "Exported variable '{0}' has or is using private name '{1}'."),
                    Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: diag(4026, 1 /* Error */, "Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot__4026", "Public static property '{0}' of exported class has or is using name '{1}' from external module {2} but cannot be named."),
                    Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2: diag(4027, 1 /* Error */, "Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2_4027", "Public static property '{0}' of exported class has or is using name '{1}' from private module '{2}'."),
                    Public_static_property_0_of_exported_class_has_or_is_using_private_name_1: diag(4028, 1 /* Error */, "Public_static_property_0_of_exported_class_has_or_is_using_private_name_1_4028", "Public static property '{0}' of exported class has or is using private name '{1}'."),
                    Public_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: diag(4029, 1 /* Error */, "Public_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_name_4029", "Public property '{0}' of exported class has or is using name '{1}' from external module {2} but cannot be named."),
                    Public_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2: diag(4030, 1 /* Error */, "Public_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2_4030", "Public property '{0}' of exported class has or is using name '{1}' from private module '{2}'."),
                    Public_property_0_of_exported_class_has_or_is_using_private_name_1: diag(4031, 1 /* Error */, "Public_property_0_of_exported_class_has_or_is_using_private_name_1_4031", "Public property '{0}' of exported class has or is using private name '{1}'."),
                    Property_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2: diag(4032, 1 /* Error */, "Property_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2_4032", "Property '{0}' of exported interface has or is using name '{1}' from private module '{2}'."),
                    Property_0_of_exported_interface_has_or_is_using_private_name_1: diag(4033, 1 /* Error */, "Property_0_of_exported_interface_has_or_is_using_private_name_1_4033", "Property '{0}' of exported interface has or is using private name '{1}'."),
                    Parameter_type_of_public_static_setter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2: diag(4034, 1 /* Error */, "Parameter_type_of_public_static_setter_0_from_exported_class_has_or_is_using_name_1_from_private_mod_4034", "Parameter type of public static setter '{0}' from exported class has or is using name '{1}' from private module '{2}'."),
                    Parameter_type_of_public_static_setter_0_from_exported_class_has_or_is_using_private_name_1: diag(4035, 1 /* Error */, "Parameter_type_of_public_static_setter_0_from_exported_class_has_or_is_using_private_name_1_4035", "Parameter type of public static setter '{0}' from exported class has or is using private name '{1}'."),
                    Parameter_type_of_public_setter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2: diag(4036, 1 /* Error */, "Parameter_type_of_public_setter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2_4036", "Parameter type of public setter '{0}' from exported class has or is using name '{1}' from private module '{2}'."),
                    Parameter_type_of_public_setter_0_from_exported_class_has_or_is_using_private_name_1: diag(4037, 1 /* Error */, "Parameter_type_of_public_setter_0_from_exported_class_has_or_is_using_private_name_1_4037", "Parameter type of public setter '{0}' from exported class has or is using private name '{1}'."),
                    Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: diag(4038, 1 /* Error */, "Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_name_1_from_external_modul_4038", "Return type of public static getter '{0}' from exported class has or is using name '{1}' from external module {2} but cannot be named."),
                    Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2: diag(4039, 1 /* Error */, "Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_name_1_from_private_module_4039", "Return type of public static getter '{0}' from exported class has or is using name '{1}' from private module '{2}'."),
                    Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_private_name_1: diag(4040, 1 /* Error */, "Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_private_name_1_4040", "Return type of public static getter '{0}' from exported class has or is using private name '{1}'."),
                    Return_type_of_public_getter_0_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: diag(4041, 1 /* Error */, "Return_type_of_public_getter_0_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_4041", "Return type of public getter '{0}' from exported class has or is using name '{1}' from external module {2} but cannot be named."),
                    Return_type_of_public_getter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2: diag(4042, 1 /* Error */, "Return_type_of_public_getter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2_4042", "Return type of public getter '{0}' from exported class has or is using name '{1}' from private module '{2}'."),
                    Return_type_of_public_getter_0_from_exported_class_has_or_is_using_private_name_1: diag(4043, 1 /* Error */, "Return_type_of_public_getter_0_from_exported_class_has_or_is_using_private_name_1_4043", "Return type of public getter '{0}' from exported class has or is using private name '{1}'."),
                    Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1: diag(4044, 1 /* Error */, "Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_name_0_from_private_mod_4044", "Return type of constructor signature from exported interface has or is using name '{0}' from private module '{1}'."),
                    Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_0: diag(4045, 1 /* Error */, "Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_0_4045", "Return type of constructor signature from exported interface has or is using private name '{0}'."),
                    Return_type_of_call_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1: diag(4046, 1 /* Error */, "Return_type_of_call_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1_4046", "Return type of call signature from exported interface has or is using name '{0}' from private module '{1}'."),
                    Return_type_of_call_signature_from_exported_interface_has_or_is_using_private_name_0: diag(4047, 1 /* Error */, "Return_type_of_call_signature_from_exported_interface_has_or_is_using_private_name_0_4047", "Return type of call signature from exported interface has or is using private name '{0}'."),
                    Return_type_of_index_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1: diag(4048, 1 /* Error */, "Return_type_of_index_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1_4048", "Return type of index signature from exported interface has or is using name '{0}' from private module '{1}'."),
                    Return_type_of_index_signature_from_exported_interface_has_or_is_using_private_name_0: diag(4049, 1 /* Error */, "Return_type_of_index_signature_from_exported_interface_has_or_is_using_private_name_0_4049", "Return type of index signature from exported interface has or is using private name '{0}'."),
                    Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named: diag(4050, 1 /* Error */, "Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_external_module__4050", "Return type of public static method from exported class has or is using name '{0}' from external module {1} but cannot be named."),
                    Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_private_module_1: diag(4051, 1 /* Error */, "Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_private_module_1_4051", "Return type of public static method from exported class has or is using name '{0}' from private module '{1}'."),
                    Return_type_of_public_static_method_from_exported_class_has_or_is_using_private_name_0: diag(4052, 1 /* Error */, "Return_type_of_public_static_method_from_exported_class_has_or_is_using_private_name_0_4052", "Return type of public static method from exported class has or is using private name '{0}'."),
                    Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named: diag(4053, 1 /* Error */, "Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_external_module_1_but_c_4053", "Return type of public method from exported class has or is using name '{0}' from external module {1} but cannot be named."),
                    Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_private_module_1: diag(4054, 1 /* Error */, "Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_private_module_1_4054", "Return type of public method from exported class has or is using name '{0}' from private module '{1}'."),
                    Return_type_of_public_method_from_exported_class_has_or_is_using_private_name_0: diag(4055, 1 /* Error */, "Return_type_of_public_method_from_exported_class_has_or_is_using_private_name_0_4055", "Return type of public method from exported class has or is using private name '{0}'."),
                    Return_type_of_method_from_exported_interface_has_or_is_using_name_0_from_private_module_1: diag(4056, 1 /* Error */, "Return_type_of_method_from_exported_interface_has_or_is_using_name_0_from_private_module_1_4056", "Return type of method from exported interface has or is using name '{0}' from private module '{1}'."),
                    Return_type_of_method_from_exported_interface_has_or_is_using_private_name_0: diag(4057, 1 /* Error */, "Return_type_of_method_from_exported_interface_has_or_is_using_private_name_0_4057", "Return type of method from exported interface has or is using private name '{0}'."),
                    Return_type_of_exported_function_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named: diag(4058, 1 /* Error */, "Return_type_of_exported_function_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named_4058", "Return type of exported function has or is using name '{0}' from external module {1} but cannot be named."),
                    Return_type_of_exported_function_has_or_is_using_name_0_from_private_module_1: diag(4059, 1 /* Error */, "Return_type_of_exported_function_has_or_is_using_name_0_from_private_module_1_4059", "Return type of exported function has or is using name '{0}' from private module '{1}'."),
                    Return_type_of_exported_function_has_or_is_using_private_name_0: diag(4060, 1 /* Error */, "Return_type_of_exported_function_has_or_is_using_private_name_0_4060", "Return type of exported function has or is using private name '{0}'."),
                    Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: diag(4061, 1 /* Error */, "Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_can_4061", "Parameter '{0}' of constructor from exported class has or is using name '{1}' from external module {2} but cannot be named."),
                    Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_private_module_2: diag(4062, 1 /* Error */, "Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_private_module_2_4062", "Parameter '{0}' of constructor from exported class has or is using name '{1}' from private module '{2}'."),
                    Parameter_0_of_constructor_from_exported_class_has_or_is_using_private_name_1: diag(4063, 1 /* Error */, "Parameter_0_of_constructor_from_exported_class_has_or_is_using_private_name_1_4063", "Parameter '{0}' of constructor from exported class has or is using private name '{1}'."),
                    Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2: diag(4064, 1 /* Error */, "Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_name_1_from_private_mod_4064", "Parameter '{0}' of constructor signature from exported interface has or is using name '{1}' from private module '{2}'."),
                    Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1: diag(4065, 1 /* Error */, "Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1_4065", "Parameter '{0}' of constructor signature from exported interface has or is using private name '{1}'."),
                    Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2: diag(4066, 1 /* Error */, "Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2_4066", "Parameter '{0}' of call signature from exported interface has or is using name '{1}' from private module '{2}'."),
                    Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1: diag(4067, 1 /* Error */, "Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1_4067", "Parameter '{0}' of call signature from exported interface has or is using private name '{1}'."),
                    Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: diag(4068, 1 /* Error */, "Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_external_module__4068", "Parameter '{0}' of public static method from exported class has or is using name '{1}' from external module {2} but cannot be named."),
                    Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_private_module_2: diag(4069, 1 /* Error */, "Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_private_module_2_4069", "Parameter '{0}' of public static method from exported class has or is using name '{1}' from private module '{2}'."),
                    Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1: diag(4070, 1 /* Error */, "Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1_4070", "Parameter '{0}' of public static method from exported class has or is using private name '{1}'."),
                    Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: diag(4071, 1 /* Error */, "Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_c_4071", "Parameter '{0}' of public method from exported class has or is using name '{1}' from external module {2} but cannot be named."),
                    Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_private_module_2: diag(4072, 1 /* Error */, "Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_private_module_2_4072", "Parameter '{0}' of public method from exported class has or is using name '{1}' from private module '{2}'."),
                    Parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1: diag(4073, 1 /* Error */, "Parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1_4073", "Parameter '{0}' of public method from exported class has or is using private name '{1}'."),
                    Parameter_0_of_method_from_exported_interface_has_or_is_using_name_1_from_private_module_2: diag(4074, 1 /* Error */, "Parameter_0_of_method_from_exported_interface_has_or_is_using_name_1_from_private_module_2_4074", "Parameter '{0}' of method from exported interface has or is using name '{1}' from private module '{2}'."),
                    Parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1: diag(4075, 1 /* Error */, "Parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1_4075", "Parameter '{0}' of method from exported interface has or is using private name '{1}'."),
                    Parameter_0_of_exported_function_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: diag(4076, 1 /* Error */, "Parameter_0_of_exported_function_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named_4076", "Parameter '{0}' of exported function has or is using name '{1}' from external module {2} but cannot be named."),
                    Parameter_0_of_exported_function_has_or_is_using_name_1_from_private_module_2: diag(4077, 1 /* Error */, "Parameter_0_of_exported_function_has_or_is_using_name_1_from_private_module_2_4077", "Parameter '{0}' of exported function has or is using name '{1}' from private module '{2}'."),
                    Parameter_0_of_exported_function_has_or_is_using_private_name_1: diag(4078, 1 /* Error */, "Parameter_0_of_exported_function_has_or_is_using_private_name_1_4078", "Parameter '{0}' of exported function has or is using private name '{1}'."),
                    Exported_type_alias_0_has_or_is_using_private_name_1: diag(4081, 1 /* Error */, "Exported_type_alias_0_has_or_is_using_private_name_1_4081", "Exported type alias '{0}' has or is using private name '{1}'."),
                    Default_export_of_the_module_has_or_is_using_private_name_0: diag(4082, 1 /* Error */, "Default_export_of_the_module_has_or_is_using_private_name_0_4082", "Default export of the module has or is using private name '{0}'."),
                    Type_parameter_0_of_exported_type_alias_has_or_is_using_private_name_1: diag(4083, 1 /* Error */, "Type_parameter_0_of_exported_type_alias_has_or_is_using_private_name_1_4083", "Type parameter '{0}' of exported type alias has or is using private name '{1}'."),
                    Exported_type_alias_0_has_or_is_using_private_name_1_from_module_2: diag(4084, 1 /* Error */, "Exported_type_alias_0_has_or_is_using_private_name_1_from_module_2_4084", "Exported type alias '{0}' has or is using private name '{1}' from module {2}."),
                    Extends_clause_for_inferred_type_0_has_or_is_using_private_name_1: diag(4085, 1 /* Error */, "Extends_clause_for_inferred_type_0_has_or_is_using_private_name_1_4085", "Extends clause for inferred type '{0}' has or is using private name '{1}'."),
                    Conflicting_definitions_for_0_found_at_1_and_2_Consider_installing_a_specific_version_of_this_library_to_resolve_the_conflict: diag(4090, 1 /* Error */, "Conflicting_definitions_for_0_found_at_1_and_2_Consider_installing_a_specific_version_of_this_librar_4090", "Conflicting definitions for '{0}' found at '{1}' and '{2}'. Consider installing a specific version of this library to resolve the conflict."),
                    Parameter_0_of_index_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2: diag(4091, 1 /* Error */, "Parameter_0_of_index_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2_4091", "Parameter '{0}' of index signature from exported interface has or is using name '{1}' from private module '{2}'."),
                    Parameter_0_of_index_signature_from_exported_interface_has_or_is_using_private_name_1: diag(4092, 1 /* Error */, "Parameter_0_of_index_signature_from_exported_interface_has_or_is_using_private_name_1_4092", "Parameter '{0}' of index signature from exported interface has or is using private name '{1}'."),
                    Property_0_of_exported_class_expression_may_not_be_private_or_protected: diag(4094, 1 /* Error */, "Property_0_of_exported_class_expression_may_not_be_private_or_protected_4094", "Property '{0}' of exported class expression may not be private or protected."),
                    Public_static_method_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: diag(4095, 1 /* Error */, "Public_static_method_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_4095", "Public static method '{0}' of exported class has or is using name '{1}' from external module {2} but cannot be named."),
                    Public_static_method_0_of_exported_class_has_or_is_using_name_1_from_private_module_2: diag(4096, 1 /* Error */, "Public_static_method_0_of_exported_class_has_or_is_using_name_1_from_private_module_2_4096", "Public static method '{0}' of exported class has or is using name '{1}' from private module '{2}'."),
                    Public_static_method_0_of_exported_class_has_or_is_using_private_name_1: diag(4097, 1 /* Error */, "Public_static_method_0_of_exported_class_has_or_is_using_private_name_1_4097", "Public static method '{0}' of exported class has or is using private name '{1}'."),
                    Public_method_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: diag(4098, 1 /* Error */, "Public_method_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named_4098", "Public method '{0}' of exported class has or is using name '{1}' from external module {2} but cannot be named."),
                    Public_method_0_of_exported_class_has_or_is_using_name_1_from_private_module_2: diag(4099, 1 /* Error */, "Public_method_0_of_exported_class_has_or_is_using_name_1_from_private_module_2_4099", "Public method '{0}' of exported class has or is using name '{1}' from private module '{2}'."),
                    Public_method_0_of_exported_class_has_or_is_using_private_name_1: diag(4100, 1 /* Error */, "Public_method_0_of_exported_class_has_or_is_using_private_name_1_4100", "Public method '{0}' of exported class has or is using private name '{1}'."),
                    Method_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2: diag(4101, 1 /* Error */, "Method_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2_4101", "Method '{0}' of exported interface has or is using name '{1}' from private module '{2}'."),
                    Method_0_of_exported_interface_has_or_is_using_private_name_1: diag(4102, 1 /* Error */, "Method_0_of_exported_interface_has_or_is_using_private_name_1_4102", "Method '{0}' of exported interface has or is using private name '{1}'."),
                    Type_parameter_0_of_exported_mapped_object_type_is_using_private_name_1: diag(4103, 1 /* Error */, "Type_parameter_0_of_exported_mapped_object_type_is_using_private_name_1_4103", "Type parameter '{0}' of exported mapped object type is using private name '{1}'."),
                    The_type_0_is_readonly_and_cannot_be_assigned_to_the_mutable_type_1: diag(4104, 1 /* Error */, "The_type_0_is_readonly_and_cannot_be_assigned_to_the_mutable_type_1_4104", "The type '{0}' is 'readonly' and cannot be assigned to the mutable type '{1}'."),
                    Private_or_protected_member_0_cannot_be_accessed_on_a_type_parameter: diag(4105, 1 /* Error */, "Private_or_protected_member_0_cannot_be_accessed_on_a_type_parameter_4105", "Private or protected member '{0}' cannot be accessed on a type parameter."),
                    Parameter_0_of_accessor_has_or_is_using_private_name_1: diag(4106, 1 /* Error */, "Parameter_0_of_accessor_has_or_is_using_private_name_1_4106", "Parameter '{0}' of accessor has or is using private name '{1}'."),
                    Parameter_0_of_accessor_has_or_is_using_name_1_from_private_module_2: diag(4107, 1 /* Error */, "Parameter_0_of_accessor_has_or_is_using_name_1_from_private_module_2_4107", "Parameter '{0}' of accessor has or is using name '{1}' from private module '{2}'."),
                    Parameter_0_of_accessor_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: diag(4108, 1 /* Error */, "Parameter_0_of_accessor_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named_4108", "Parameter '{0}' of accessor has or is using name '{1}' from external module '{2}' but cannot be named."),
                    Type_arguments_for_0_circularly_reference_themselves: diag(4109, 1 /* Error */, "Type_arguments_for_0_circularly_reference_themselves_4109", "Type arguments for '{0}' circularly reference themselves."),
                    Tuple_type_arguments_circularly_reference_themselves: diag(4110, 1 /* Error */, "Tuple_type_arguments_circularly_reference_themselves_4110", "Tuple type arguments circularly reference themselves."),
                    Property_0_comes_from_an_index_signature_so_it_must_be_accessed_with_0: diag(4111, 1 /* Error */, "Property_0_comes_from_an_index_signature_so_it_must_be_accessed_with_0_4111", "Property '{0}' comes from an index signature, so it must be accessed with ['{0}']."),
                    This_member_cannot_have_an_override_modifier_because_its_containing_class_0_does_not_extend_another_class: diag(4112, 1 /* Error */, "This_member_cannot_have_an_override_modifier_because_its_containing_class_0_does_not_extend_another__4112", "This member cannot have an 'override' modifier because its containing class '{0}' does not extend another class."),
                    This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0: diag(4113, 1 /* Error */, "This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0_4113", "This member cannot have an 'override' modifier because it is not declared in the base class '{0}'."),
                    This_member_must_have_an_override_modifier_because_it_overrides_a_member_in_the_base_class_0: diag(4114, 1 /* Error */, "This_member_must_have_an_override_modifier_because_it_overrides_a_member_in_the_base_class_0_4114", "This member must have an 'override' modifier because it overrides a member in the base class '{0}'."),
                    This_parameter_property_must_have_an_override_modifier_because_it_overrides_a_member_in_base_class_0: diag(4115, 1 /* Error */, "This_parameter_property_must_have_an_override_modifier_because_it_overrides_a_member_in_base_class_0_4115", "This parameter property must have an 'override' modifier because it overrides a member in base class '{0}'."),
                    This_member_must_have_an_override_modifier_because_it_overrides_an_abstract_method_that_is_declared_in_the_base_class_0: diag(4116, 1 /* Error */, "This_member_must_have_an_override_modifier_because_it_overrides_an_abstract_method_that_is_declared__4116", "This member must have an 'override' modifier because it overrides an abstract method that is declared in the base class '{0}'."),
                    This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0_Did_you_mean_1: diag(4117, 1 /* Error */, "This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0_Did_you__4117", "This member cannot have an 'override' modifier because it is not declared in the base class '{0}'. Did you mean '{1}'?"),
                    The_type_of_this_node_cannot_be_serialized_because_its_property_0_cannot_be_serialized: diag(4118, 1 /* Error */, "The_type_of_this_node_cannot_be_serialized_because_its_property_0_cannot_be_serialized_4118", "The type of this node cannot be serialized because its property '{0}' cannot be serialized."),
                    This_member_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_in_the_base_class_0: diag(4119, 1 /* Error */, "This_member_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_in_the_base_4119", "This member must have a JSDoc comment with an '@override' tag because it overrides a member in the base class '{0}'."),
                    This_parameter_property_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_in_the_base_class_0: diag(4120, 1 /* Error */, "This_parameter_property_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_4120", "This parameter property must have a JSDoc comment with an '@override' tag because it overrides a member in the base class '{0}'."),
                    This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_its_containing_class_0_does_not_extend_another_class: diag(4121, 1 /* Error */, "This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_its_containing_class_0_does_not_4121", "This member cannot have a JSDoc comment with an '@override' tag because its containing class '{0}' does not extend another class."),
                    This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_it_is_not_declared_in_the_base_class_0: diag(4122, 1 /* Error */, "This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_it_is_not_declared_in_the_base__4122", "This member cannot have a JSDoc comment with an '@override' tag because it is not declared in the base class '{0}'."),
                    This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_it_is_not_declared_in_the_base_class_0_Did_you_mean_1: diag(4123, 1 /* Error */, "This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_it_is_not_declared_in_the_base__4123", "This member cannot have a JSDoc comment with an 'override' tag because it is not declared in the base class '{0}'. Did you mean '{1}'?"),
                    Compiler_option_0_of_value_1_is_unstable_Use_nightly_TypeScript_to_silence_this_error_Try_updating_with_npm_install_D_typescript_next: diag(4124, 1 /* Error */, "Compiler_option_0_of_value_1_is_unstable_Use_nightly_TypeScript_to_silence_this_error_Try_updating_w_4124", "Compiler option '{0}' of value '{1}' is unstable. Use nightly TypeScript to silence this error. Try updating with 'npm install -D typescript@next'."),
                    Each_declaration_of_0_1_differs_in_its_value_where_2_was_expected_but_3_was_given: diag(4125, 1 /* Error */, "Each_declaration_of_0_1_differs_in_its_value_where_2_was_expected_but_3_was_given_4125", "Each declaration of '{0}.{1}' differs in its value, where '{2}' was expected but '{3}' was given."),
                    One_value_of_0_1_is_the_string_2_and_the_other_is_assumed_to_be_an_unknown_numeric_value: diag(4126, 1 /* Error */, "One_value_of_0_1_is_the_string_2_and_the_other_is_assumed_to_be_an_unknown_numeric_value_4126", "One value of '{0}.{1}' is the string '{2}', and the other is assumed to be an unknown numeric value."),
                    The_current_host_does_not_support_the_0_option: diag(5001, 1 /* Error */, "The_current_host_does_not_support_the_0_option_5001", "The current host does not support the '{0}' option."),
                    Cannot_find_the_common_subdirectory_path_for_the_input_files: diag(5009, 1 /* Error */, "Cannot_find_the_common_subdirectory_path_for_the_input_files_5009", "Cannot find the common subdirectory path for the input files."),
                    File_specification_cannot_end_in_a_recursive_directory_wildcard_Asterisk_Asterisk_Colon_0: diag(5010, 1 /* Error */, "File_specification_cannot_end_in_a_recursive_directory_wildcard_Asterisk_Asterisk_Colon_0_5010", "File specification cannot end in a recursive directory wildcard ('**'): '{0}'."),
                    Cannot_read_file_0_Colon_1: diag(5012, 1 /* Error */, "Cannot_read_file_0_Colon_1_5012", "Cannot read file '{0}': {1}."),
                    Failed_to_parse_file_0_Colon_1: diag(5014, 1 /* Error */, "Failed_to_parse_file_0_Colon_1_5014", "Failed to parse file '{0}': {1}."),
                    Unknown_compiler_option_0: diag(5023, 1 /* Error */, "Unknown_compiler_option_0_5023", "Unknown compiler option '{0}'."),
                    Compiler_option_0_requires_a_value_of_type_1: diag(5024, 1 /* Error */, "Compiler_option_0_requires_a_value_of_type_1_5024", "Compiler option '{0}' requires a value of type {1}."),
                    Unknown_compiler_option_0_Did_you_mean_1: diag(5025, 1 /* Error */, "Unknown_compiler_option_0_Did_you_mean_1_5025", "Unknown compiler option '{0}'. Did you mean '{1}'?"),
                    Could_not_write_file_0_Colon_1: diag(5033, 1 /* Error */, "Could_not_write_file_0_Colon_1_5033", "Could not write file '{0}': {1}."),
                    Option_project_cannot_be_mixed_with_source_files_on_a_command_line: diag(5042, 1 /* Error */, "Option_project_cannot_be_mixed_with_source_files_on_a_command_line_5042", "Option 'project' cannot be mixed with source files on a command line."),
                    Option_isolatedModules_can_only_be_used_when_either_option_module_is_provided_or_option_target_is_ES2015_or_higher: diag(5047, 1 /* Error */, "Option_isolatedModules_can_only_be_used_when_either_option_module_is_provided_or_option_target_is_ES_5047", "Option 'isolatedModules' can only be used when either option '--module' is provided or option 'target' is 'ES2015' or higher."),
                    Option_0_cannot_be_specified_when_option_target_is_ES3: diag(5048, 1 /* Error */, "Option_0_cannot_be_specified_when_option_target_is_ES3_5048", "Option '{0}' cannot be specified when option 'target' is 'ES3'."),
                    Option_0_can_only_be_used_when_either_option_inlineSourceMap_or_option_sourceMap_is_provided: diag(5051, 1 /* Error */, "Option_0_can_only_be_used_when_either_option_inlineSourceMap_or_option_sourceMap_is_provided_5051", "Option '{0} can only be used when either option '--inlineSourceMap' or option '--sourceMap' is provided."),
                    Option_0_cannot_be_specified_without_specifying_option_1: diag(5052, 1 /* Error */, "Option_0_cannot_be_specified_without_specifying_option_1_5052", "Option '{0}' cannot be specified without specifying option '{1}'."),
                    Option_0_cannot_be_specified_with_option_1: diag(5053, 1 /* Error */, "Option_0_cannot_be_specified_with_option_1_5053", "Option '{0}' cannot be specified with option '{1}'."),
                    A_tsconfig_json_file_is_already_defined_at_Colon_0: diag(5054, 1 /* Error */, "A_tsconfig_json_file_is_already_defined_at_Colon_0_5054", "A 'tsconfig.json' file is already defined at: '{0}'."),
                    Cannot_write_file_0_because_it_would_overwrite_input_file: diag(5055, 1 /* Error */, "Cannot_write_file_0_because_it_would_overwrite_input_file_5055", "Cannot write file '{0}' because it would overwrite input file."),
                    Cannot_write_file_0_because_it_would_be_overwritten_by_multiple_input_files: diag(5056, 1 /* Error */, "Cannot_write_file_0_because_it_would_be_overwritten_by_multiple_input_files_5056", "Cannot write file '{0}' because it would be overwritten by multiple input files."),
                    Cannot_find_a_tsconfig_json_file_at_the_specified_directory_Colon_0: diag(5057, 1 /* Error */, "Cannot_find_a_tsconfig_json_file_at_the_specified_directory_Colon_0_5057", "Cannot find a tsconfig.json file at the specified directory: '{0}'."),
                    The_specified_path_does_not_exist_Colon_0: diag(5058, 1 /* Error */, "The_specified_path_does_not_exist_Colon_0_5058", "The specified path does not exist: '{0}'."),
                    Invalid_value_for_reactNamespace_0_is_not_a_valid_identifier: diag(5059, 1 /* Error */, "Invalid_value_for_reactNamespace_0_is_not_a_valid_identifier_5059", "Invalid value for '--reactNamespace'. '{0}' is not a valid identifier."),
                    Pattern_0_can_have_at_most_one_Asterisk_character: diag(5061, 1 /* Error */, "Pattern_0_can_have_at_most_one_Asterisk_character_5061", "Pattern '{0}' can have at most one '*' character."),
                    Substitution_0_in_pattern_1_can_have_at_most_one_Asterisk_character: diag(5062, 1 /* Error */, "Substitution_0_in_pattern_1_can_have_at_most_one_Asterisk_character_5062", "Substitution '{0}' in pattern '{1}' can have at most one '*' character."),
                    Substitutions_for_pattern_0_should_be_an_array: diag(5063, 1 /* Error */, "Substitutions_for_pattern_0_should_be_an_array_5063", "Substitutions for pattern '{0}' should be an array."),
                    Substitution_0_for_pattern_1_has_incorrect_type_expected_string_got_2: diag(5064, 1 /* Error */, "Substitution_0_for_pattern_1_has_incorrect_type_expected_string_got_2_5064", "Substitution '{0}' for pattern '{1}' has incorrect type, expected 'string', got '{2}'."),
                    File_specification_cannot_contain_a_parent_directory_that_appears_after_a_recursive_directory_wildcard_Asterisk_Asterisk_Colon_0: diag(5065, 1 /* Error */, "File_specification_cannot_contain_a_parent_directory_that_appears_after_a_recursive_directory_wildca_5065", "File specification cannot contain a parent directory ('..') that appears after a recursive directory wildcard ('**'): '{0}'."),
                    Substitutions_for_pattern_0_shouldn_t_be_an_empty_array: diag(5066, 1 /* Error */, "Substitutions_for_pattern_0_shouldn_t_be_an_empty_array_5066", "Substitutions for pattern '{0}' shouldn't be an empty array."),
                    Invalid_value_for_jsxFactory_0_is_not_a_valid_identifier_or_qualified_name: diag(5067, 1 /* Error */, "Invalid_value_for_jsxFactory_0_is_not_a_valid_identifier_or_qualified_name_5067", "Invalid value for 'jsxFactory'. '{0}' is not a valid identifier or qualified-name."),
                    Adding_a_tsconfig_json_file_will_help_organize_projects_that_contain_both_TypeScript_and_JavaScript_files_Learn_more_at_https_Colon_Slash_Slashaka_ms_Slashtsconfig: diag(5068, 1 /* Error */, "Adding_a_tsconfig_json_file_will_help_organize_projects_that_contain_both_TypeScript_and_JavaScript__5068", "Adding a tsconfig.json file will help organize projects that contain both TypeScript and JavaScript files. Learn more at https://aka.ms/tsconfig."),
                    Option_0_cannot_be_specified_without_specifying_option_1_or_option_2: diag(5069, 1 /* Error */, "Option_0_cannot_be_specified_without_specifying_option_1_or_option_2_5069", "Option '{0}' cannot be specified without specifying option '{1}' or option '{2}'."),
                    Option_resolveJsonModule_cannot_be_specified_when_moduleResolution_is_set_to_classic: diag(5070, 1 /* Error */, "Option_resolveJsonModule_cannot_be_specified_when_moduleResolution_is_set_to_classic_5070", "Option '--resolveJsonModule' cannot be specified when 'moduleResolution' is set to 'classic'."),
                    Option_resolveJsonModule_cannot_be_specified_when_module_is_set_to_none_system_or_umd: diag(5071, 1 /* Error */, "Option_resolveJsonModule_cannot_be_specified_when_module_is_set_to_none_system_or_umd_5071", "Option '--resolveJsonModule' cannot be specified when 'module' is set to 'none', 'system', or 'umd'."),
                    Unknown_build_option_0: diag(5072, 1 /* Error */, "Unknown_build_option_0_5072", "Unknown build option '{0}'."),
                    Build_option_0_requires_a_value_of_type_1: diag(5073, 1 /* Error */, "Build_option_0_requires_a_value_of_type_1_5073", "Build option '{0}' requires a value of type {1}."),
                    Option_incremental_can_only_be_specified_using_tsconfig_emitting_to_single_file_or_when_option_tsBuildInfoFile_is_specified: diag(5074, 1 /* Error */, "Option_incremental_can_only_be_specified_using_tsconfig_emitting_to_single_file_or_when_option_tsBui_5074", "Option '--incremental' can only be specified using tsconfig, emitting to single file or when option '--tsBuildInfoFile' is specified."),
                    _0_is_assignable_to_the_constraint_of_type_1_but_1_could_be_instantiated_with_a_different_subtype_of_constraint_2: diag(5075, 1 /* Error */, "_0_is_assignable_to_the_constraint_of_type_1_but_1_could_be_instantiated_with_a_different_subtype_of_5075", "'{0}' is assignable to the constraint of type '{1}', but '{1}' could be instantiated with a different subtype of constraint '{2}'."),
                    _0_and_1_operations_cannot_be_mixed_without_parentheses: diag(5076, 1 /* Error */, "_0_and_1_operations_cannot_be_mixed_without_parentheses_5076", "'{0}' and '{1}' operations cannot be mixed without parentheses."),
                    Unknown_build_option_0_Did_you_mean_1: diag(5077, 1 /* Error */, "Unknown_build_option_0_Did_you_mean_1_5077", "Unknown build option '{0}'. Did you mean '{1}'?"),
                    Unknown_watch_option_0: diag(5078, 1 /* Error */, "Unknown_watch_option_0_5078", "Unknown watch option '{0}'."),
                    Unknown_watch_option_0_Did_you_mean_1: diag(5079, 1 /* Error */, "Unknown_watch_option_0_Did_you_mean_1_5079", "Unknown watch option '{0}'. Did you mean '{1}'?"),
                    Watch_option_0_requires_a_value_of_type_1: diag(5080, 1 /* Error */, "Watch_option_0_requires_a_value_of_type_1_5080", "Watch option '{0}' requires a value of type {1}."),
                    Cannot_find_a_tsconfig_json_file_at_the_current_directory_Colon_0: diag(5081, 1 /* Error */, "Cannot_find_a_tsconfig_json_file_at_the_current_directory_Colon_0_5081", "Cannot find a tsconfig.json file at the current directory: {0}."),
                    _0_could_be_instantiated_with_an_arbitrary_type_which_could_be_unrelated_to_1: diag(5082, 1 /* Error */, "_0_could_be_instantiated_with_an_arbitrary_type_which_could_be_unrelated_to_1_5082", "'{0}' could be instantiated with an arbitrary type which could be unrelated to '{1}'."),
                    Cannot_read_file_0: diag(5083, 1 /* Error */, "Cannot_read_file_0_5083", "Cannot read file '{0}'."),
                    A_tuple_member_cannot_be_both_optional_and_rest: diag(5085, 1 /* Error */, "A_tuple_member_cannot_be_both_optional_and_rest_5085", "A tuple member cannot be both optional and rest."),
                    A_labeled_tuple_element_is_declared_as_optional_with_a_question_mark_after_the_name_and_before_the_colon_rather_than_after_the_type: diag(5086, 1 /* Error */, "A_labeled_tuple_element_is_declared_as_optional_with_a_question_mark_after_the_name_and_before_the_c_5086", "A labeled tuple element is declared as optional with a question mark after the name and before the colon, rather than after the type."),
                    A_labeled_tuple_element_is_declared_as_rest_with_a_before_the_name_rather_than_before_the_type: diag(5087, 1 /* Error */, "A_labeled_tuple_element_is_declared_as_rest_with_a_before_the_name_rather_than_before_the_type_5087", "A labeled tuple element is declared as rest with a '...' before the name, rather than before the type."),
                    The_inferred_type_of_0_references_a_type_with_a_cyclic_structure_which_cannot_be_trivially_serialized_A_type_annotation_is_necessary: diag(5088, 1 /* Error */, "The_inferred_type_of_0_references_a_type_with_a_cyclic_structure_which_cannot_be_trivially_serialize_5088", "The inferred type of '{0}' references a type with a cyclic structure which cannot be trivially serialized. A type annotation is necessary."),
                    Option_0_cannot_be_specified_when_option_jsx_is_1: diag(5089, 1 /* Error */, "Option_0_cannot_be_specified_when_option_jsx_is_1_5089", "Option '{0}' cannot be specified when option 'jsx' is '{1}'."),
                    Non_relative_paths_are_not_allowed_when_baseUrl_is_not_set_Did_you_forget_a_leading_Slash: diag(5090, 1 /* Error */, "Non_relative_paths_are_not_allowed_when_baseUrl_is_not_set_Did_you_forget_a_leading_Slash_5090", "Non-relative paths are not allowed when 'baseUrl' is not set. Did you forget a leading './'?"),
                    Option_preserveConstEnums_cannot_be_disabled_when_0_is_enabled: diag(5091, 1 /* Error */, "Option_preserveConstEnums_cannot_be_disabled_when_0_is_enabled_5091", "Option 'preserveConstEnums' cannot be disabled when '{0}' is enabled."),
                    The_root_value_of_a_0_file_must_be_an_object: diag(5092, 1 /* Error */, "The_root_value_of_a_0_file_must_be_an_object_5092", "The root value of a '{0}' file must be an object."),
                    Compiler_option_0_may_only_be_used_with_build: diag(5093, 1 /* Error */, "Compiler_option_0_may_only_be_used_with_build_5093", "Compiler option '--{0}' may only be used with '--build'."),
                    Compiler_option_0_may_not_be_used_with_build: diag(5094, 1 /* Error */, "Compiler_option_0_may_not_be_used_with_build_5094", "Compiler option '--{0}' may not be used with '--build'."),
                    Option_0_can_only_be_used_when_module_is_set_to_preserve_or_to_es2015_or_later: diag(5095, 1 /* Error */, "Option_0_can_only_be_used_when_module_is_set_to_preserve_or_to_es2015_or_later_5095", "Option '{0}' can only be used when 'module' is set to 'preserve' or to 'es2015' or later."),
                    Option_allowImportingTsExtensions_can_only_be_used_when_either_noEmit_or_emitDeclarationOnly_is_set: diag(5096, 1 /* Error */, "Option_allowImportingTsExtensions_can_only_be_used_when_either_noEmit_or_emitDeclarationOnly_is_set_5096", "Option 'allowImportingTsExtensions' can only be used when either 'noEmit' or 'emitDeclarationOnly' is set."),
                    An_import_path_can_only_end_with_a_0_extension_when_allowImportingTsExtensions_is_enabled: diag(5097, 1 /* Error */, "An_import_path_can_only_end_with_a_0_extension_when_allowImportingTsExtensions_is_enabled_5097", "An import path can only end with a '{0}' extension when 'allowImportingTsExtensions' is enabled."),
                    Option_0_can_only_be_used_when_moduleResolution_is_set_to_node16_nodenext_or_bundler: diag(5098, 1 /* Error */, "Option_0_can_only_be_used_when_moduleResolution_is_set_to_node16_nodenext_or_bundler_5098", "Option '{0}' can only be used when 'moduleResolution' is set to 'node16', 'nodenext', or 'bundler'."),
                    Option_0_is_deprecated_and_will_stop_functioning_in_TypeScript_1_Specify_compilerOption_ignoreDeprecations_Colon_2_to_silence_this_error: diag(5101, 1 /* Error */, "Option_0_is_deprecated_and_will_stop_functioning_in_TypeScript_1_Specify_compilerOption_ignoreDeprec_5101", `Option '{0}' is deprecated and will stop functioning in TypeScript {1}. Specify compilerOption '"ignoreDeprecations": "{2}"' to silence this error.`),
                    Option_0_has_been_removed_Please_remove_it_from_your_configuration: diag(5102, 1 /* Error */, "Option_0_has_been_removed_Please_remove_it_from_your_configuration_5102", "Option '{0}' has been removed. Please remove it from your configuration."),
                    Invalid_value_for_ignoreDeprecations: diag(5103, 1 /* Error */, "Invalid_value_for_ignoreDeprecations_5103", "Invalid value for '--ignoreDeprecations'."),
                    Option_0_is_redundant_and_cannot_be_specified_with_option_1: diag(5104, 1 /* Error */, "Option_0_is_redundant_and_cannot_be_specified_with_option_1_5104", "Option '{0}' is redundant and cannot be specified with option '{1}'."),
                    Option_verbatimModuleSyntax_cannot_be_used_when_module_is_set_to_UMD_AMD_or_System: diag(5105, 1 /* Error */, "Option_verbatimModuleSyntax_cannot_be_used_when_module_is_set_to_UMD_AMD_or_System_5105", "Option 'verbatimModuleSyntax' cannot be used when 'module' is set to 'UMD', 'AMD', or 'System'."),
                    Use_0_instead: diag(5106, 3 /* Message */, "Use_0_instead_5106", "Use '{0}' instead."),
                    Option_0_1_is_deprecated_and_will_stop_functioning_in_TypeScript_2_Specify_compilerOption_ignoreDeprecations_Colon_3_to_silence_this_error: diag(5107, 1 /* Error */, "Option_0_1_is_deprecated_and_will_stop_functioning_in_TypeScript_2_Specify_compilerOption_ignoreDepr_5107", `Option '{0}={1}' is deprecated and will stop functioning in TypeScript {2}. Specify compilerOption '"ignoreDeprecations": "{3}"' to silence this error.`),
                    Option_0_1_has_been_removed_Please_remove_it_from_your_configuration: diag(5108, 1 /* Error */, "Option_0_1_has_been_removed_Please_remove_it_from_your_configuration_5108", "Option '{0}={1}' has been removed. Please remove it from your configuration."),
                    Option_moduleResolution_must_be_set_to_0_or_left_unspecified_when_option_module_is_set_to_1: diag(5109, 1 /* Error */, "Option_moduleResolution_must_be_set_to_0_or_left_unspecified_when_option_module_is_set_to_1_5109", "Option 'moduleResolution' must be set to '{0}' (or left unspecified) when option 'module' is set to '{1}'."),
                    Option_module_must_be_set_to_0_when_option_moduleResolution_is_set_to_1: diag(5110, 1 /* Error */, "Option_module_must_be_set_to_0_when_option_moduleResolution_is_set_to_1_5110", "Option 'module' must be set to '{0}' when option 'moduleResolution' is set to '{1}'."),
                    Generates_a_sourcemap_for_each_corresponding_d_ts_file: diag(6e3, 3 /* Message */, "Generates_a_sourcemap_for_each_corresponding_d_ts_file_6000", "Generates a sourcemap for each corresponding '.d.ts' file."),
                    Concatenate_and_emit_output_to_single_file: diag(6001, 3 /* Message */, "Concatenate_and_emit_output_to_single_file_6001", "Concatenate and emit output to single file."),
                    Generates_corresponding_d_ts_file: diag(6002, 3 /* Message */, "Generates_corresponding_d_ts_file_6002", "Generates corresponding '.d.ts' file."),
                    Specify_the_location_where_debugger_should_locate_TypeScript_files_instead_of_source_locations: diag(6004, 3 /* Message */, "Specify_the_location_where_debugger_should_locate_TypeScript_files_instead_of_source_locations_6004", "Specify the location where debugger should locate TypeScript files instead of source locations."),
                    Watch_input_files: diag(6005, 3 /* Message */, "Watch_input_files_6005", "Watch input files."),
                    Redirect_output_structure_to_the_directory: diag(6006, 3 /* Message */, "Redirect_output_structure_to_the_directory_6006", "Redirect output structure to the directory."),
                    Do_not_erase_const_enum_declarations_in_generated_code: diag(6007, 3 /* Message */, "Do_not_erase_const_enum_declarations_in_generated_code_6007", "Do not erase const enum declarations in generated code."),
                    Do_not_emit_outputs_if_any_errors_were_reported: diag(6008, 3 /* Message */, "Do_not_emit_outputs_if_any_errors_were_reported_6008", "Do not emit outputs if any errors were reported."),
                    Do_not_emit_comments_to_output: diag(6009, 3 /* Message */, "Do_not_emit_comments_to_output_6009", "Do not emit comments to output."),
                    Do_not_emit_outputs: diag(6010, 3 /* Message */, "Do_not_emit_outputs_6010", "Do not emit outputs."),
                    Allow_default_imports_from_modules_with_no_default_export_This_does_not_affect_code_emit_just_typechecking: diag(6011, 3 /* Message */, "Allow_default_imports_from_modules_with_no_default_export_This_does_not_affect_code_emit_just_typech_6011", "Allow default imports from modules with no default export. This does not affect code emit, just typechecking."),
                    Skip_type_checking_of_declaration_files: diag(6012, 3 /* Message */, "Skip_type_checking_of_declaration_files_6012", "Skip type checking of declaration files."),
                    Do_not_resolve_the_real_path_of_symlinks: diag(6013, 3 /* Message */, "Do_not_resolve_the_real_path_of_symlinks_6013", "Do not resolve the real path of symlinks."),
                    Only_emit_d_ts_declaration_files: diag(6014, 3 /* Message */, "Only_emit_d_ts_declaration_files_6014", "Only emit '.d.ts' declaration files."),
                    Specify_ECMAScript_target_version: diag(6015, 3 /* Message */, "Specify_ECMAScript_target_version_6015", "Specify ECMAScript target version."),
                    Specify_module_code_generation: diag(6016, 3 /* Message */, "Specify_module_code_generation_6016", "Specify module code generation."),
                    Print_this_message: diag(6017, 3 /* Message */, "Print_this_message_6017", "Print this message."),
                    Print_the_compiler_s_version: diag(6019, 3 /* Message */, "Print_the_compiler_s_version_6019", "Print the compiler's version."),
                    Compile_the_project_given_the_path_to_its_configuration_file_or_to_a_folder_with_a_tsconfig_json: diag(6020, 3 /* Message */, "Compile_the_project_given_the_path_to_its_configuration_file_or_to_a_folder_with_a_tsconfig_json_6020", "Compile the project given the path to its configuration file, or to a folder with a 'tsconfig.json'."),
                    Syntax_Colon_0: diag(6023, 3 /* Message */, "Syntax_Colon_0_6023", "Syntax: {0}"),
                    options: diag(6024, 3 /* Message */, "options_6024", "options"),
                    file: diag(6025, 3 /* Message */, "file_6025", "file"),
                    Examples_Colon_0: diag(6026, 3 /* Message */, "Examples_Colon_0_6026", "Examples: {0}"),
                    Options_Colon: diag(6027, 3 /* Message */, "Options_Colon_6027", "Options:"),
                    Version_0: diag(6029, 3 /* Message */, "Version_0_6029", "Version {0}"),
                    Insert_command_line_options_and_files_from_a_file: diag(6030, 3 /* Message */, "Insert_command_line_options_and_files_from_a_file_6030", "Insert command line options and files from a file."),
                    Starting_compilation_in_watch_mode: diag(6031, 3 /* Message */, "Starting_compilation_in_watch_mode_6031", "Starting compilation in watch mode..."),
                    File_change_detected_Starting_incremental_compilation: diag(6032, 3 /* Message */, "File_change_detected_Starting_incremental_compilation_6032", "File change detected. Starting incremental compilation..."),
                    KIND: diag(6034, 3 /* Message */, "KIND_6034", "KIND"),
                    FILE: diag(6035, 3 /* Message */, "FILE_6035", "FILE"),
                    VERSION: diag(6036, 3 /* Message */, "VERSION_6036", "VERSION"),
                    LOCATION: diag(6037, 3 /* Message */, "LOCATION_6037", "LOCATION"),
                    DIRECTORY: diag(6038, 3 /* Message */, "DIRECTORY_6038", "DIRECTORY"),
                    STRATEGY: diag(6039, 3 /* Message */, "STRATEGY_6039", "STRATEGY"),
                    FILE_OR_DIRECTORY: diag(6040, 3 /* Message */, "FILE_OR_DIRECTORY_6040", "FILE OR DIRECTORY"),
                    Errors_Files: diag(6041, 3 /* Message */, "Errors_Files_6041", "Errors  Files"),
                    Generates_corresponding_map_file: diag(6043, 3 /* Message */, "Generates_corresponding_map_file_6043", "Generates corresponding '.map' file."),
                    Compiler_option_0_expects_an_argument: diag(6044, 1 /* Error */, "Compiler_option_0_expects_an_argument_6044", "Compiler option '{0}' expects an argument."),
                    Unterminated_quoted_string_in_response_file_0: diag(6045, 1 /* Error */, "Unterminated_quoted_string_in_response_file_0_6045", "Unterminated quoted string in response file '{0}'."),
                    Argument_for_0_option_must_be_Colon_1: diag(6046, 1 /* Error */, "Argument_for_0_option_must_be_Colon_1_6046", "Argument for '{0}' option must be: {1}."),
                    Locale_must_be_of_the_form_language_or_language_territory_For_example_0_or_1: diag(6048, 1 /* Error */, "Locale_must_be_of_the_form_language_or_language_territory_For_example_0_or_1_6048", "Locale must be of the form <language> or <language>-<territory>. For example '{0}' or '{1}'."),
                    Unable_to_open_file_0: diag(6050, 1 /* Error */, "Unable_to_open_file_0_6050", "Unable to open file '{0}'."),
                    Corrupted_locale_file_0: diag(6051, 1 /* Error */, "Corrupted_locale_file_0_6051", "Corrupted locale file {0}."),
                    Raise_error_on_expressions_and_declarations_with_an_implied_any_type: diag(6052, 3 /* Message */, "Raise_error_on_expressions_and_declarations_with_an_implied_any_type_6052", "Raise error on expressions and declarations with an implied 'any' type."),
                    File_0_not_found: diag(6053, 1 /* Error */, "File_0_not_found_6053", "File '{0}' not found."),
                    File_0_has_an_unsupported_extension_The_only_supported_extensions_are_1: diag(6054, 1 /* Error */, "File_0_has_an_unsupported_extension_The_only_supported_extensions_are_1_6054", "File '{0}' has an unsupported extension. The only supported extensions are {1}."),
                    Suppress_noImplicitAny_errors_for_indexing_objects_lacking_index_signatures: diag(6055, 3 /* Message */, "Suppress_noImplicitAny_errors_for_indexing_objects_lacking_index_signatures_6055", "Suppress noImplicitAny errors for indexing objects lacking index signatures."),
                    Do_not_emit_declarations_for_code_that_has_an_internal_annotation: diag(6056, 3 /* Message */, "Do_not_emit_declarations_for_code_that_has_an_internal_annotation_6056", "Do not emit declarations for code that has an '@internal' annotation."),
                    Specify_the_root_directory_of_input_files_Use_to_control_the_output_directory_structure_with_outDir: diag(6058, 3 /* Message */, "Specify_the_root_directory_of_input_files_Use_to_control_the_output_directory_structure_with_outDir_6058", "Specify the root directory of input files. Use to control the output directory structure with --outDir."),
                    File_0_is_not_under_rootDir_1_rootDir_is_expected_to_contain_all_source_files: diag(6059, 1 /* Error */, "File_0_is_not_under_rootDir_1_rootDir_is_expected_to_contain_all_source_files_6059", "File '{0}' is not under 'rootDir' '{1}'. 'rootDir' is expected to contain all source files."),
                    Specify_the_end_of_line_sequence_to_be_used_when_emitting_files_Colon_CRLF_dos_or_LF_unix: diag(6060, 3 /* Message */, "Specify_the_end_of_line_sequence_to_be_used_when_emitting_files_Colon_CRLF_dos_or_LF_unix_6060", "Specify the end of line sequence to be used when emitting files: 'CRLF' (dos) or 'LF' (unix)."),
                    NEWLINE: diag(6061, 3 /* Message */, "NEWLINE_6061", "NEWLINE"),
                    Option_0_can_only_be_specified_in_tsconfig_json_file_or_set_to_null_on_command_line: diag(6064, 1 /* Error */, "Option_0_can_only_be_specified_in_tsconfig_json_file_or_set_to_null_on_command_line_6064", "Option '{0}' can only be specified in 'tsconfig.json' file or set to 'null' on command line."),
                    Enables_experimental_support_for_ES7_decorators: diag(6065, 3 /* Message */, "Enables_experimental_support_for_ES7_decorators_6065", "Enables experimental support for ES7 decorators."),
                    Enables_experimental_support_for_emitting_type_metadata_for_decorators: diag(6066, 3 /* Message */, "Enables_experimental_support_for_emitting_type_metadata_for_decorators_6066", "Enables experimental support for emitting type metadata for decorators."),
                    Initializes_a_TypeScript_project_and_creates_a_tsconfig_json_file: diag(6070, 3 /* Message */, "Initializes_a_TypeScript_project_and_creates_a_tsconfig_json_file_6070", "Initializes a TypeScript project and creates a tsconfig.json file."),
                    Successfully_created_a_tsconfig_json_file: diag(6071, 3 /* Message */, "Successfully_created_a_tsconfig_json_file_6071", "Successfully created a tsconfig.json file."),
                    Suppress_excess_property_checks_for_object_literals: diag(6072, 3 /* Message */, "Suppress_excess_property_checks_for_object_literals_6072", "Suppress excess property checks for object literals."),
                    Stylize_errors_and_messages_using_color_and_context_experimental: diag(6073, 3 /* Message */, "Stylize_errors_and_messages_using_color_and_context_experimental_6073", "Stylize errors and messages using color and context (experimental)."),
                    Do_not_report_errors_on_unused_labels: diag(6074, 3 /* Message */, "Do_not_report_errors_on_unused_labels_6074", "Do not report errors on unused labels."),
                    Report_error_when_not_all_code_paths_in_function_return_a_value: diag(6075, 3 /* Message */, "Report_error_when_not_all_code_paths_in_function_return_a_value_6075", "Report error when not all code paths in function return a value."),
                    Report_errors_for_fallthrough_cases_in_switch_statement: diag(6076, 3 /* Message */, "Report_errors_for_fallthrough_cases_in_switch_statement_6076", "Report errors for fallthrough cases in switch statement."),
                    Do_not_report_errors_on_unreachable_code: diag(6077, 3 /* Message */, "Do_not_report_errors_on_unreachable_code_6077", "Do not report errors on unreachable code."),
                    Disallow_inconsistently_cased_references_to_the_same_file: diag(6078, 3 /* Message */, "Disallow_inconsistently_cased_references_to_the_same_file_6078", "Disallow inconsistently-cased references to the same file."),
                    Specify_library_files_to_be_included_in_the_compilation: diag(6079, 3 /* Message */, "Specify_library_files_to_be_included_in_the_compilation_6079", "Specify library files to be included in the compilation."),
                    Specify_JSX_code_generation: diag(6080, 3 /* Message */, "Specify_JSX_code_generation_6080", "Specify JSX code generation."),
                    Only_amd_and_system_modules_are_supported_alongside_0: diag(6082, 1 /* Error */, "Only_amd_and_system_modules_are_supported_alongside_0_6082", "Only 'amd' and 'system' modules are supported alongside --{0}."),
                    Base_directory_to_resolve_non_absolute_module_names: diag(6083, 3 /* Message */, "Base_directory_to_resolve_non_absolute_module_names_6083", "Base directory to resolve non-absolute module names."),
                    Deprecated_Use_jsxFactory_instead_Specify_the_object_invoked_for_createElement_when_targeting_react_JSX_emit: diag(6084, 3 /* Message */, "Deprecated_Use_jsxFactory_instead_Specify_the_object_invoked_for_createElement_when_targeting_react__6084", "[Deprecated] Use '--jsxFactory' instead. Specify the object invoked for createElement when targeting 'react' JSX emit"),
                    Enable_tracing_of_the_name_resolution_process: diag(6085, 3 /* Message */, "Enable_tracing_of_the_name_resolution_process_6085", "Enable tracing of the name resolution process."),
                    Resolving_module_0_from_1: diag(6086, 3 /* Message */, "Resolving_module_0_from_1_6086", "======== Resolving module '{0}' from '{1}'. ========"),
                    Explicitly_specified_module_resolution_kind_Colon_0: diag(6087, 3 /* Message */, "Explicitly_specified_module_resolution_kind_Colon_0_6087", "Explicitly specified module resolution kind: '{0}'."),
                    Module_resolution_kind_is_not_specified_using_0: diag(6088, 3 /* Message */, "Module_resolution_kind_is_not_specified_using_0_6088", "Module resolution kind is not specified, using '{0}'."),
                    Module_name_0_was_successfully_resolved_to_1: diag(6089, 3 /* Message */, "Module_name_0_was_successfully_resolved_to_1_6089", "======== Module name '{0}' was successfully resolved to '{1}'. ========"),
                    Module_name_0_was_not_resolved: diag(6090, 3 /* Message */, "Module_name_0_was_not_resolved_6090", "======== Module name '{0}' was not resolved. ========"),
                    paths_option_is_specified_looking_for_a_pattern_to_match_module_name_0: diag(6091, 3 /* Message */, "paths_option_is_specified_looking_for_a_pattern_to_match_module_name_0_6091", "'paths' option is specified, looking for a pattern to match module name '{0}'."),
                    Module_name_0_matched_pattern_1: diag(6092, 3 /* Message */, "Module_name_0_matched_pattern_1_6092", "Module name '{0}', matched pattern '{1}'."),
                    Trying_substitution_0_candidate_module_location_Colon_1: diag(6093, 3 /* Message */, "Trying_substitution_0_candidate_module_location_Colon_1_6093", "Trying substitution '{0}', candidate module location: '{1}'."),
                    Resolving_module_name_0_relative_to_base_url_1_2: diag(6094, 3 /* Message */, "Resolving_module_name_0_relative_to_base_url_1_2_6094", "Resolving module name '{0}' relative to base url '{1}' - '{2}'."),
                    Loading_module_as_file_Slash_folder_candidate_module_location_0_target_file_types_Colon_1: diag(6095, 3 /* Message */, "Loading_module_as_file_Slash_folder_candidate_module_location_0_target_file_types_Colon_1_6095", "Loading module as file / folder, candidate module location '{0}', target file types: {1}."),
                    File_0_does_not_exist: diag(6096, 3 /* Message */, "File_0_does_not_exist_6096", "File '{0}' does not exist."),
                    File_0_exists_use_it_as_a_name_resolution_result: diag(6097, 3 /* Message */, "File_0_exists_use_it_as_a_name_resolution_result_6097", "File '{0}' exists - use it as a name resolution result."),
                    Loading_module_0_from_node_modules_folder_target_file_types_Colon_1: diag(6098, 3 /* Message */, "Loading_module_0_from_node_modules_folder_target_file_types_Colon_1_6098", "Loading module '{0}' from 'node_modules' folder, target file types: {1}."),
                    Found_package_json_at_0: diag(6099, 3 /* Message */, "Found_package_json_at_0_6099", "Found 'package.json' at '{0}'."),
                    package_json_does_not_have_a_0_field: diag(6100, 3 /* Message */, "package_json_does_not_have_a_0_field_6100", "'package.json' does not have a '{0}' field."),
                    package_json_has_0_field_1_that_references_2: diag(6101, 3 /* Message */, "package_json_has_0_field_1_that_references_2_6101", "'package.json' has '{0}' field '{1}' that references '{2}'."),
                    Allow_javascript_files_to_be_compiled: diag(6102, 3 /* Message */, "Allow_javascript_files_to_be_compiled_6102", "Allow javascript files to be compiled."),
                    Checking_if_0_is_the_longest_matching_prefix_for_1_2: diag(6104, 3 /* Message */, "Checking_if_0_is_the_longest_matching_prefix_for_1_2_6104", "Checking if '{0}' is the longest matching prefix for '{1}' - '{2}'."),
                    Expected_type_of_0_field_in_package_json_to_be_1_got_2: diag(6105, 3 /* Message */, "Expected_type_of_0_field_in_package_json_to_be_1_got_2_6105", "Expected type of '{0}' field in 'package.json' to be '{1}', got '{2}'."),
                    baseUrl_option_is_set_to_0_using_this_value_to_resolve_non_relative_module_name_1: diag(6106, 3 /* Message */, "baseUrl_option_is_set_to_0_using_this_value_to_resolve_non_relative_module_name_1_6106", "'baseUrl' option is set to '{0}', using this value to resolve non-relative module name '{1}'."),
                    rootDirs_option_is_set_using_it_to_resolve_relative_module_name_0: diag(6107, 3 /* Message */, "rootDirs_option_is_set_using_it_to_resolve_relative_module_name_0_6107", "'rootDirs' option is set, using it to resolve relative module name '{0}'."),
                    Longest_matching_prefix_for_0_is_1: diag(6108, 3 /* Message */, "Longest_matching_prefix_for_0_is_1_6108", "Longest matching prefix for '{0}' is '{1}'."),
                    Loading_0_from_the_root_dir_1_candidate_location_2: diag(6109, 3 /* Message */, "Loading_0_from_the_root_dir_1_candidate_location_2_6109", "Loading '{0}' from the root dir '{1}', candidate location '{2}'."),
                    Trying_other_entries_in_rootDirs: diag(6110, 3 /* Message */, "Trying_other_entries_in_rootDirs_6110", "Trying other entries in 'rootDirs'."),
                    Module_resolution_using_rootDirs_has_failed: diag(6111, 3 /* Message */, "Module_resolution_using_rootDirs_has_failed_6111", "Module resolution using 'rootDirs' has failed."),
                    Do_not_emit_use_strict_directives_in_module_output: diag(6112, 3 /* Message */, "Do_not_emit_use_strict_directives_in_module_output_6112", "Do not emit 'use strict' directives in module output."),
                    Enable_strict_null_checks: diag(6113, 3 /* Message */, "Enable_strict_null_checks_6113", "Enable strict null checks."),
                    Unknown_option_excludes_Did_you_mean_exclude: diag(6114, 1 /* Error */, "Unknown_option_excludes_Did_you_mean_exclude_6114", "Unknown option 'excludes'. Did you mean 'exclude'?"),
                    Raise_error_on_this_expressions_with_an_implied_any_type: diag(6115, 3 /* Message */, "Raise_error_on_this_expressions_with_an_implied_any_type_6115", "Raise error on 'this' expressions with an implied 'any' type."),
                    Resolving_type_reference_directive_0_containing_file_1_root_directory_2: diag(6116, 3 /* Message */, "Resolving_type_reference_directive_0_containing_file_1_root_directory_2_6116", "======== Resolving type reference directive '{0}', containing file '{1}', root directory '{2}'. ========"),
                    Type_reference_directive_0_was_successfully_resolved_to_1_primary_Colon_2: diag(6119, 3 /* Message */, "Type_reference_directive_0_was_successfully_resolved_to_1_primary_Colon_2_6119", "======== Type reference directive '{0}' was successfully resolved to '{1}', primary: {2}. ========"),
                    Type_reference_directive_0_was_not_resolved: diag(6120, 3 /* Message */, "Type_reference_directive_0_was_not_resolved_6120", "======== Type reference directive '{0}' was not resolved. ========"),
                    Resolving_with_primary_search_path_0: diag(6121, 3 /* Message */, "Resolving_with_primary_search_path_0_6121", "Resolving with primary search path '{0}'."),
                    Root_directory_cannot_be_determined_skipping_primary_search_paths: diag(6122, 3 /* Message */, "Root_directory_cannot_be_determined_skipping_primary_search_paths_6122", "Root directory cannot be determined, skipping primary search paths."),
                    Resolving_type_reference_directive_0_containing_file_1_root_directory_not_set: diag(6123, 3 /* Message */, "Resolving_type_reference_directive_0_containing_file_1_root_directory_not_set_6123", "======== Resolving type reference directive '{0}', containing file '{1}', root directory not set. ========"),
                    Type_declaration_files_to_be_included_in_compilation: diag(6124, 3 /* Message */, "Type_declaration_files_to_be_included_in_compilation_6124", "Type declaration files to be included in compilation."),
                    Looking_up_in_node_modules_folder_initial_location_0: diag(6125, 3 /* Message */, "Looking_up_in_node_modules_folder_initial_location_0_6125", "Looking up in 'node_modules' folder, initial location '{0}'."),
                    Containing_file_is_not_specified_and_root_directory_cannot_be_determined_skipping_lookup_in_node_modules_folder: diag(6126, 3 /* Message */, "Containing_file_is_not_specified_and_root_directory_cannot_be_determined_skipping_lookup_in_node_mod_6126", "Containing file is not specified and root directory cannot be determined, skipping lookup in 'node_modules' folder."),
                    Resolving_type_reference_directive_0_containing_file_not_set_root_directory_1: diag(6127, 3 /* Message */, "Resolving_type_reference_directive_0_containing_file_not_set_root_directory_1_6127", "======== Resolving type reference directive '{0}', containing file not set, root directory '{1}'. ========"),
                    Resolving_type_reference_directive_0_containing_file_not_set_root_directory_not_set: diag(6128, 3 /* Message */, "Resolving_type_reference_directive_0_containing_file_not_set_root_directory_not_set_6128", "======== Resolving type reference directive '{0}', containing file not set, root directory not set. ========"),
                    Resolving_real_path_for_0_result_1: diag(6130, 3 /* Message */, "Resolving_real_path_for_0_result_1_6130", "Resolving real path for '{0}', result '{1}'."),
                    Cannot_compile_modules_using_option_0_unless_the_module_flag_is_amd_or_system: diag(6131, 1 /* Error */, "Cannot_compile_modules_using_option_0_unless_the_module_flag_is_amd_or_system_6131", "Cannot compile modules using option '{0}' unless the '--module' flag is 'amd' or 'system'."),
                    File_name_0_has_a_1_extension_stripping_it: diag(6132, 3 /* Message */, "File_name_0_has_a_1_extension_stripping_it_6132", "File name '{0}' has a '{1}' extension - stripping it."),
                    _0_is_declared_but_its_value_is_never_read: diag(6133, 1 /* Error */, "_0_is_declared_but_its_value_is_never_read_6133", "'{0}' is declared but its value is never read.", 
                    /*reportsUnnecessary*/
                    true),
                    Report_errors_on_unused_locals: diag(6134, 3 /* Message */, "Report_errors_on_unused_locals_6134", "Report errors on unused locals."),
                    Report_errors_on_unused_parameters: diag(6135, 3 /* Message */, "Report_errors_on_unused_parameters_6135", "Report errors on unused parameters."),
                    The_maximum_dependency_depth_to_search_under_node_modules_and_load_JavaScript_files: diag(6136, 3 /* Message */, "The_maximum_dependency_depth_to_search_under_node_modules_and_load_JavaScript_files_6136", "The maximum dependency depth to search under node_modules and load JavaScript files."),
                    Cannot_import_type_declaration_files_Consider_importing_0_instead_of_1: diag(6137, 1 /* Error */, "Cannot_import_type_declaration_files_Consider_importing_0_instead_of_1_6137", "Cannot import type declaration files. Consider importing '{0}' instead of '{1}'."),
                    Property_0_is_declared_but_its_value_is_never_read: diag(6138, 1 /* Error */, "Property_0_is_declared_but_its_value_is_never_read_6138", "Property '{0}' is declared but its value is never read.", 
                    /*reportsUnnecessary*/
                    true),
                    Import_emit_helpers_from_tslib: diag(6139, 3 /* Message */, "Import_emit_helpers_from_tslib_6139", "Import emit helpers from 'tslib'."),
                    Auto_discovery_for_typings_is_enabled_in_project_0_Running_extra_resolution_pass_for_module_1_using_cache_location_2: diag(6140, 1 /* Error */, "Auto_discovery_for_typings_is_enabled_in_project_0_Running_extra_resolution_pass_for_module_1_using__6140", "Auto discovery for typings is enabled in project '{0}'. Running extra resolution pass for module '{1}' using cache location '{2}'."),
                    Parse_in_strict_mode_and_emit_use_strict_for_each_source_file: diag(6141, 3 /* Message */, "Parse_in_strict_mode_and_emit_use_strict_for_each_source_file_6141", 'Parse in strict mode and emit "use strict" for each source file.'),
                    Module_0_was_resolved_to_1_but_jsx_is_not_set: diag(6142, 1 /* Error */, "Module_0_was_resolved_to_1_but_jsx_is_not_set_6142", "Module '{0}' was resolved to '{1}', but '--jsx' is not set."),
                    Module_0_was_resolved_as_locally_declared_ambient_module_in_file_1: diag(6144, 3 /* Message */, "Module_0_was_resolved_as_locally_declared_ambient_module_in_file_1_6144", "Module '{0}' was resolved as locally declared ambient module in file '{1}'."),
                    Module_0_was_resolved_as_ambient_module_declared_in_1_since_this_file_was_not_modified: diag(6145, 3 /* Message */, "Module_0_was_resolved_as_ambient_module_declared_in_1_since_this_file_was_not_modified_6145", "Module '{0}' was resolved as ambient module declared in '{1}' since this file was not modified."),
                    Specify_the_JSX_factory_function_to_use_when_targeting_react_JSX_emit_e_g_React_createElement_or_h: diag(6146, 3 /* Message */, "Specify_the_JSX_factory_function_to_use_when_targeting_react_JSX_emit_e_g_React_createElement_or_h_6146", "Specify the JSX factory function to use when targeting 'react' JSX emit, e.g. 'React.createElement' or 'h'."),
                    Resolution_for_module_0_was_found_in_cache_from_location_1: diag(6147, 3 /* Message */, "Resolution_for_module_0_was_found_in_cache_from_location_1_6147", "Resolution for module '{0}' was found in cache from location '{1}'."),
                    Directory_0_does_not_exist_skipping_all_lookups_in_it: diag(6148, 3 /* Message */, "Directory_0_does_not_exist_skipping_all_lookups_in_it_6148", "Directory '{0}' does not exist, skipping all lookups in it."),
                    Show_diagnostic_information: diag(6149, 3 /* Message */, "Show_diagnostic_information_6149", "Show diagnostic information."),
                    Show_verbose_diagnostic_information: diag(6150, 3 /* Message */, "Show_verbose_diagnostic_information_6150", "Show verbose diagnostic information."),
                    Emit_a_single_file_with_source_maps_instead_of_having_a_separate_file: diag(6151, 3 /* Message */, "Emit_a_single_file_with_source_maps_instead_of_having_a_separate_file_6151", "Emit a single file with source maps instead of having a separate file."),
                    Emit_the_source_alongside_the_sourcemaps_within_a_single_file_requires_inlineSourceMap_or_sourceMap_to_be_set: diag(6152, 3 /* Message */, "Emit_the_source_alongside_the_sourcemaps_within_a_single_file_requires_inlineSourceMap_or_sourceMap__6152", "Emit the source alongside the sourcemaps within a single file; requires '--inlineSourceMap' or '--sourceMap' to be set."),
                    Transpile_each_file_as_a_separate_module_similar_to_ts_transpileModule: diag(6153, 3 /* Message */, "Transpile_each_file_as_a_separate_module_similar_to_ts_transpileModule_6153", "Transpile each file as a separate module (similar to 'ts.transpileModule')."),
                    Print_names_of_generated_files_part_of_the_compilation: diag(6154, 3 /* Message */, "Print_names_of_generated_files_part_of_the_compilation_6154", "Print names of generated files part of the compilation."),
                    Print_names_of_files_part_of_the_compilation: diag(6155, 3 /* Message */, "Print_names_of_files_part_of_the_compilation_6155", "Print names of files part of the compilation."),
                    The_locale_used_when_displaying_messages_to_the_user_e_g_en_us: diag(6156, 3 /* Message */, "The_locale_used_when_displaying_messages_to_the_user_e_g_en_us_6156", "The locale used when displaying messages to the user (e.g. 'en-us')"),
                    Do_not_generate_custom_helper_functions_like_extends_in_compiled_output: diag(6157, 3 /* Message */, "Do_not_generate_custom_helper_functions_like_extends_in_compiled_output_6157", "Do not generate custom helper functions like '__extends' in compiled output."),
                    Do_not_include_the_default_library_file_lib_d_ts: diag(6158, 3 /* Message */, "Do_not_include_the_default_library_file_lib_d_ts_6158", "Do not include the default library file (lib.d.ts)."),
                    Do_not_add_triple_slash_references_or_imported_modules_to_the_list_of_compiled_files: diag(6159, 3 /* Message */, "Do_not_add_triple_slash_references_or_imported_modules_to_the_list_of_compiled_files_6159", "Do not add triple-slash references or imported modules to the list of compiled files."),
                    Deprecated_Use_skipLibCheck_instead_Skip_type_checking_of_default_library_declaration_files: diag(6160, 3 /* Message */, "Deprecated_Use_skipLibCheck_instead_Skip_type_checking_of_default_library_declaration_files_6160", "[Deprecated] Use '--skipLibCheck' instead. Skip type checking of default library declaration files."),
                    List_of_folders_to_include_type_definitions_from: diag(6161, 3 /* Message */, "List_of_folders_to_include_type_definitions_from_6161", "List of folders to include type definitions from."),
                    Disable_size_limitations_on_JavaScript_projects: diag(6162, 3 /* Message */, "Disable_size_limitations_on_JavaScript_projects_6162", "Disable size limitations on JavaScript projects."),
                    The_character_set_of_the_input_files: diag(6163, 3 /* Message */, "The_character_set_of_the_input_files_6163", "The character set of the input files."),
                    Skipping_module_0_that_looks_like_an_absolute_URI_target_file_types_Colon_1: diag(6164, 3 /* Message */, "Skipping_module_0_that_looks_like_an_absolute_URI_target_file_types_Colon_1_6164", "Skipping module '{0}' that looks like an absolute URI, target file types: {1}."),
                    Do_not_truncate_error_messages: diag(6165, 3 /* Message */, "Do_not_truncate_error_messages_6165", "Do not truncate error messages."),
                    Output_directory_for_generated_declaration_files: diag(6166, 3 /* Message */, "Output_directory_for_generated_declaration_files_6166", "Output directory for generated declaration files."),
                    A_series_of_entries_which_re_map_imports_to_lookup_locations_relative_to_the_baseUrl: diag(6167, 3 /* Message */, "A_series_of_entries_which_re_map_imports_to_lookup_locations_relative_to_the_baseUrl_6167", "A series of entries which re-map imports to lookup locations relative to the 'baseUrl'."),
                    List_of_root_folders_whose_combined_content_represents_the_structure_of_the_project_at_runtime: diag(6168, 3 /* Message */, "List_of_root_folders_whose_combined_content_represents_the_structure_of_the_project_at_runtime_6168", "List of root folders whose combined content represents the structure of the project at runtime."),
                    Show_all_compiler_options: diag(6169, 3 /* Message */, "Show_all_compiler_options_6169", "Show all compiler options."),
                    Deprecated_Use_outFile_instead_Concatenate_and_emit_output_to_single_file: diag(6170, 3 /* Message */, "Deprecated_Use_outFile_instead_Concatenate_and_emit_output_to_single_file_6170", "[Deprecated] Use '--outFile' instead. Concatenate and emit output to single file"),
                    Command_line_Options: diag(6171, 3 /* Message */, "Command_line_Options_6171", "Command-line Options"),
                    Provide_full_support_for_iterables_in_for_of_spread_and_destructuring_when_targeting_ES5_or_ES3: diag(6179, 3 /* Message */, "Provide_full_support_for_iterables_in_for_of_spread_and_destructuring_when_targeting_ES5_or_ES3_6179", "Provide full support for iterables in 'for-of', spread, and destructuring when targeting 'ES5' or 'ES3'."),
                    Enable_all_strict_type_checking_options: diag(6180, 3 /* Message */, "Enable_all_strict_type_checking_options_6180", "Enable all strict type-checking options."),
                    Scoped_package_detected_looking_in_0: diag(6182, 3 /* Message */, "Scoped_package_detected_looking_in_0_6182", "Scoped package detected, looking in '{0}'"),
                    Reusing_resolution_of_module_0_from_1_of_old_program_it_was_successfully_resolved_to_2: diag(6183, 3 /* Message */, "Reusing_resolution_of_module_0_from_1_of_old_program_it_was_successfully_resolved_to_2_6183", "Reusing resolution of module '{0}' from '{1}' of old program, it was successfully resolved to '{2}'."),
                    Reusing_resolution_of_module_0_from_1_of_old_program_it_was_successfully_resolved_to_2_with_Package_ID_3: diag(6184, 3 /* Message */, "Reusing_resolution_of_module_0_from_1_of_old_program_it_was_successfully_resolved_to_2_with_Package__6184", "Reusing resolution of module '{0}' from '{1}' of old program, it was successfully resolved to '{2}' with Package ID '{3}'."),
                    Enable_strict_checking_of_function_types: diag(6186, 3 /* Message */, "Enable_strict_checking_of_function_types_6186", "Enable strict checking of function types."),
                    Enable_strict_checking_of_property_initialization_in_classes: diag(6187, 3 /* Message */, "Enable_strict_checking_of_property_initialization_in_classes_6187", "Enable strict checking of property initialization in classes."),
                    Numeric_separators_are_not_allowed_here: diag(6188, 1 /* Error */, "Numeric_separators_are_not_allowed_here_6188", "Numeric separators are not allowed here."),
                    Multiple_consecutive_numeric_separators_are_not_permitted: diag(6189, 1 /* Error */, "Multiple_consecutive_numeric_separators_are_not_permitted_6189", "Multiple consecutive numeric separators are not permitted."),
                    Whether_to_keep_outdated_console_output_in_watch_mode_instead_of_clearing_the_screen: diag(6191, 3 /* Message */, "Whether_to_keep_outdated_console_output_in_watch_mode_instead_of_clearing_the_screen_6191", "Whether to keep outdated console output in watch mode instead of clearing the screen."),
                    All_imports_in_import_declaration_are_unused: diag(6192, 1 /* Error */, "All_imports_in_import_declaration_are_unused_6192", "All imports in import declaration are unused.", 
                    /*reportsUnnecessary*/
                    true),
                    Found_1_error_Watching_for_file_changes: diag(6193, 3 /* Message */, "Found_1_error_Watching_for_file_changes_6193", "Found 1 error. Watching for file changes."),
                    Found_0_errors_Watching_for_file_changes: diag(6194, 3 /* Message */, "Found_0_errors_Watching_for_file_changes_6194", "Found {0} errors. Watching for file changes."),
                    Resolve_keyof_to_string_valued_property_names_only_no_numbers_or_symbols: diag(6195, 3 /* Message */, "Resolve_keyof_to_string_valued_property_names_only_no_numbers_or_symbols_6195", "Resolve 'keyof' to string valued property names only (no numbers or symbols)."),
                    _0_is_declared_but_never_used: diag(6196, 1 /* Error */, "_0_is_declared_but_never_used_6196", "'{0}' is declared but never used.", 
                    /*reportsUnnecessary*/
                    true),
                    Include_modules_imported_with_json_extension: diag(6197, 3 /* Message */, "Include_modules_imported_with_json_extension_6197", "Include modules imported with '.json' extension"),
                    All_destructured_elements_are_unused: diag(6198, 1 /* Error */, "All_destructured_elements_are_unused_6198", "All destructured elements are unused.", 
                    /*reportsUnnecessary*/
                    true),
                    All_variables_are_unused: diag(6199, 1 /* Error */, "All_variables_are_unused_6199", "All variables are unused.", 
                    /*reportsUnnecessary*/
                    true),
                    Definitions_of_the_following_identifiers_conflict_with_those_in_another_file_Colon_0: diag(6200, 1 /* Error */, "Definitions_of_the_following_identifiers_conflict_with_those_in_another_file_Colon_0_6200", "Definitions of the following identifiers conflict with those in another file: {0}"),
                    Conflicts_are_in_this_file: diag(6201, 3 /* Message */, "Conflicts_are_in_this_file_6201", "Conflicts are in this file."),
                    Project_references_may_not_form_a_circular_graph_Cycle_detected_Colon_0: diag(6202, 1 /* Error */, "Project_references_may_not_form_a_circular_graph_Cycle_detected_Colon_0_6202", "Project references may not form a circular graph. Cycle detected: {0}"),
                    _0_was_also_declared_here: diag(6203, 3 /* Message */, "_0_was_also_declared_here_6203", "'{0}' was also declared here."),
                    and_here: diag(6204, 3 /* Message */, "and_here_6204", "and here."),
                    All_type_parameters_are_unused: diag(6205, 1 /* Error */, "All_type_parameters_are_unused_6205", "All type parameters are unused."),
                    package_json_has_a_typesVersions_field_with_version_specific_path_mappings: diag(6206, 3 /* Message */, "package_json_has_a_typesVersions_field_with_version_specific_path_mappings_6206", "'package.json' has a 'typesVersions' field with version-specific path mappings."),
                    package_json_does_not_have_a_typesVersions_entry_that_matches_version_0: diag(6207, 3 /* Message */, "package_json_does_not_have_a_typesVersions_entry_that_matches_version_0_6207", "'package.json' does not have a 'typesVersions' entry that matches version '{0}'."),
                    package_json_has_a_typesVersions_entry_0_that_matches_compiler_version_1_looking_for_a_pattern_to_match_module_name_2: diag(6208, 3 /* Message */, "package_json_has_a_typesVersions_entry_0_that_matches_compiler_version_1_looking_for_a_pattern_to_ma_6208", "'package.json' has a 'typesVersions' entry '{0}' that matches compiler version '{1}', looking for a pattern to match module name '{2}'."),
                    package_json_has_a_typesVersions_entry_0_that_is_not_a_valid_semver_range: diag(6209, 3 /* Message */, "package_json_has_a_typesVersions_entry_0_that_is_not_a_valid_semver_range_6209", "'package.json' has a 'typesVersions' entry '{0}' that is not a valid semver range."),
                    An_argument_for_0_was_not_provided: diag(6210, 3 /* Message */, "An_argument_for_0_was_not_provided_6210", "An argument for '{0}' was not provided."),
                    An_argument_matching_this_binding_pattern_was_not_provided: diag(6211, 3 /* Message */, "An_argument_matching_this_binding_pattern_was_not_provided_6211", "An argument matching this binding pattern was not provided."),
                    Did_you_mean_to_call_this_expression: diag(6212, 3 /* Message */, "Did_you_mean_to_call_this_expression_6212", "Did you mean to call this expression?"),
                    Did_you_mean_to_use_new_with_this_expression: diag(6213, 3 /* Message */, "Did_you_mean_to_use_new_with_this_expression_6213", "Did you mean to use 'new' with this expression?"),
                    Enable_strict_bind_call_and_apply_methods_on_functions: diag(6214, 3 /* Message */, "Enable_strict_bind_call_and_apply_methods_on_functions_6214", "Enable strict 'bind', 'call', and 'apply' methods on functions."),
                    Using_compiler_options_of_project_reference_redirect_0: diag(6215, 3 /* Message */, "Using_compiler_options_of_project_reference_redirect_0_6215", "Using compiler options of project reference redirect '{0}'."),
                    Found_1_error: diag(6216, 3 /* Message */, "Found_1_error_6216", "Found 1 error."),
                    Found_0_errors: diag(6217, 3 /* Message */, "Found_0_errors_6217", "Found {0} errors."),
                    Module_name_0_was_successfully_resolved_to_1_with_Package_ID_2: diag(6218, 3 /* Message */, "Module_name_0_was_successfully_resolved_to_1_with_Package_ID_2_6218", "======== Module name '{0}' was successfully resolved to '{1}' with Package ID '{2}'. ========"),
                    Type_reference_directive_0_was_successfully_resolved_to_1_with_Package_ID_2_primary_Colon_3: diag(6219, 3 /* Message */, "Type_reference_directive_0_was_successfully_resolved_to_1_with_Package_ID_2_primary_Colon_3_6219", "======== Type reference directive '{0}' was successfully resolved to '{1}' with Package ID '{2}', primary: {3}. ========"),
                    package_json_had_a_falsy_0_field: diag(6220, 3 /* Message */, "package_json_had_a_falsy_0_field_6220", "'package.json' had a falsy '{0}' field."),
                    Disable_use_of_source_files_instead_of_declaration_files_from_referenced_projects: diag(6221, 3 /* Message */, "Disable_use_of_source_files_instead_of_declaration_files_from_referenced_projects_6221", "Disable use of source files instead of declaration files from referenced projects."),
                    Emit_class_fields_with_Define_instead_of_Set: diag(6222, 3 /* Message */, "Emit_class_fields_with_Define_instead_of_Set_6222", "Emit class fields with Define instead of Set."),
                    Generates_a_CPU_profile: diag(6223, 3 /* Message */, "Generates_a_CPU_profile_6223", "Generates a CPU profile."),
                    Disable_solution_searching_for_this_project: diag(6224, 3 /* Message */, "Disable_solution_searching_for_this_project_6224", "Disable solution searching for this project."),
                    Specify_strategy_for_watching_file_Colon_FixedPollingInterval_default_PriorityPollingInterval_DynamicPriorityPolling_FixedChunkSizePolling_UseFsEvents_UseFsEventsOnParentDirectory: diag(6225, 3 /* Message */, "Specify_strategy_for_watching_file_Colon_FixedPollingInterval_default_PriorityPollingInterval_Dynami_6225", "Specify strategy for watching file: 'FixedPollingInterval' (default), 'PriorityPollingInterval', 'DynamicPriorityPolling', 'FixedChunkSizePolling', 'UseFsEvents', 'UseFsEventsOnParentDirectory'."),
                    Specify_strategy_for_watching_directory_on_platforms_that_don_t_support_recursive_watching_natively_Colon_UseFsEvents_default_FixedPollingInterval_DynamicPriorityPolling_FixedChunkSizePolling: diag(6226, 3 /* Message */, "Specify_strategy_for_watching_directory_on_platforms_that_don_t_support_recursive_watching_natively__6226", "Specify strategy for watching directory on platforms that don't support recursive watching natively: 'UseFsEvents' (default), 'FixedPollingInterval', 'DynamicPriorityPolling', 'FixedChunkSizePolling'."),
                    Specify_strategy_for_creating_a_polling_watch_when_it_fails_to_create_using_file_system_events_Colon_FixedInterval_default_PriorityInterval_DynamicPriority_FixedChunkSize: diag(6227, 3 /* Message */, "Specify_strategy_for_creating_a_polling_watch_when_it_fails_to_create_using_file_system_events_Colon_6227", "Specify strategy for creating a polling watch when it fails to create using file system events: 'FixedInterval' (default), 'PriorityInterval', 'DynamicPriority', 'FixedChunkSize'."),
                    Tag_0_expects_at_least_1_arguments_but_the_JSX_factory_2_provides_at_most_3: diag(6229, 1 /* Error */, "Tag_0_expects_at_least_1_arguments_but_the_JSX_factory_2_provides_at_most_3_6229", "Tag '{0}' expects at least '{1}' arguments, but the JSX factory '{2}' provides at most '{3}'."),
                    Option_0_can_only_be_specified_in_tsconfig_json_file_or_set_to_false_or_null_on_command_line: diag(6230, 1 /* Error */, "Option_0_can_only_be_specified_in_tsconfig_json_file_or_set_to_false_or_null_on_command_line_6230", "Option '{0}' can only be specified in 'tsconfig.json' file or set to 'false' or 'null' on command line."),
                    Could_not_resolve_the_path_0_with_the_extensions_Colon_1: diag(6231, 1 /* Error */, "Could_not_resolve_the_path_0_with_the_extensions_Colon_1_6231", "Could not resolve the path '{0}' with the extensions: {1}."),
                    Declaration_augments_declaration_in_another_file_This_cannot_be_serialized: diag(6232, 1 /* Error */, "Declaration_augments_declaration_in_another_file_This_cannot_be_serialized_6232", "Declaration augments declaration in another file. This cannot be serialized."),
                    This_is_the_declaration_being_augmented_Consider_moving_the_augmenting_declaration_into_the_same_file: diag(6233, 1 /* Error */, "This_is_the_declaration_being_augmented_Consider_moving_the_augmenting_declaration_into_the_same_fil_6233", "This is the declaration being augmented. Consider moving the augmenting declaration into the same file."),
                    This_expression_is_not_callable_because_it_is_a_get_accessor_Did_you_mean_to_use_it_without: diag(6234, 1 /* Error */, "This_expression_is_not_callable_because_it_is_a_get_accessor_Did_you_mean_to_use_it_without_6234", "This expression is not callable because it is a 'get' accessor. Did you mean to use it without '()'?"),
                    Disable_loading_referenced_projects: diag(6235, 3 /* Message */, "Disable_loading_referenced_projects_6235", "Disable loading referenced projects."),
                    Arguments_for_the_rest_parameter_0_were_not_provided: diag(6236, 1 /* Error */, "Arguments_for_the_rest_parameter_0_were_not_provided_6236", "Arguments for the rest parameter '{0}' were not provided."),
                    Generates_an_event_trace_and_a_list_of_types: diag(6237, 3 /* Message */, "Generates_an_event_trace_and_a_list_of_types_6237", "Generates an event trace and a list of types."),
                    Specify_the_module_specifier_to_be_used_to_import_the_jsx_and_jsxs_factory_functions_from_eg_react: diag(6238, 1 /* Error */, "Specify_the_module_specifier_to_be_used_to_import_the_jsx_and_jsxs_factory_functions_from_eg_react_6238", "Specify the module specifier to be used to import the 'jsx' and 'jsxs' factory functions from. eg, react"),
                    File_0_exists_according_to_earlier_cached_lookups: diag(6239, 3 /* Message */, "File_0_exists_according_to_earlier_cached_lookups_6239", "File '{0}' exists according to earlier cached lookups."),
                    File_0_does_not_exist_according_to_earlier_cached_lookups: diag(6240, 3 /* Message */, "File_0_does_not_exist_according_to_earlier_cached_lookups_6240", "File '{0}' does not exist according to earlier cached lookups."),
                    Resolution_for_type_reference_directive_0_was_found_in_cache_from_location_1: diag(6241, 3 /* Message */, "Resolution_for_type_reference_directive_0_was_found_in_cache_from_location_1_6241", "Resolution for type reference directive '{0}' was found in cache from location '{1}'."),
                    Resolving_type_reference_directive_0_containing_file_1: diag(6242, 3 /* Message */, "Resolving_type_reference_directive_0_containing_file_1_6242", "======== Resolving type reference directive '{0}', containing file '{1}'. ========"),
                    Interpret_optional_property_types_as_written_rather_than_adding_undefined: diag(6243, 3 /* Message */, "Interpret_optional_property_types_as_written_rather_than_adding_undefined_6243", "Interpret optional property types as written, rather than adding 'undefined'."),
                    Modules: diag(6244, 3 /* Message */, "Modules_6244", "Modules"),
                    File_Management: diag(6245, 3 /* Message */, "File_Management_6245", "File Management"),
                    Emit: diag(6246, 3 /* Message */, "Emit_6246", "Emit"),
                    JavaScript_Support: diag(6247, 3 /* Message */, "JavaScript_Support_6247", "JavaScript Support"),
                    Type_Checking: diag(6248, 3 /* Message */, "Type_Checking_6248", "Type Checking"),
                    Editor_Support: diag(6249, 3 /* Message */, "Editor_Support_6249", "Editor Support"),
                    Watch_and_Build_Modes: diag(6250, 3 /* Message */, "Watch_and_Build_Modes_6250", "Watch and Build Modes"),
                    Compiler_Diagnostics: diag(6251, 3 /* Message */, "Compiler_Diagnostics_6251", "Compiler Diagnostics"),
                    Interop_Constraints: diag(6252, 3 /* Message */, "Interop_Constraints_6252", "Interop Constraints"),
                    Backwards_Compatibility: diag(6253, 3 /* Message */, "Backwards_Compatibility_6253", "Backwards Compatibility"),
                    Language_and_Environment: diag(6254, 3 /* Message */, "Language_and_Environment_6254", "Language and Environment"),
                    Projects: diag(6255, 3 /* Message */, "Projects_6255", "Projects"),
                    Output_Formatting: diag(6256, 3 /* Message */, "Output_Formatting_6256", "Output Formatting"),
                    Completeness: diag(6257, 3 /* Message */, "Completeness_6257", "Completeness"),
                    _0_should_be_set_inside_the_compilerOptions_object_of_the_config_json_file: diag(6258, 1 /* Error */, "_0_should_be_set_inside_the_compilerOptions_object_of_the_config_json_file_6258", "'{0}' should be set inside the 'compilerOptions' object of the config json file"),
                    Found_1_error_in_0: diag(6259, 3 /* Message */, "Found_1_error_in_0_6259", "Found 1 error in {0}"),
                    Found_0_errors_in_the_same_file_starting_at_Colon_1: diag(6260, 3 /* Message */, "Found_0_errors_in_the_same_file_starting_at_Colon_1_6260", "Found {0} errors in the same file, starting at: {1}"),
                    Found_0_errors_in_1_files: diag(6261, 3 /* Message */, "Found_0_errors_in_1_files_6261", "Found {0} errors in {1} files."),
                    File_name_0_has_a_1_extension_looking_up_2_instead: diag(6262, 3 /* Message */, "File_name_0_has_a_1_extension_looking_up_2_instead_6262", "File name '{0}' has a '{1}' extension - looking up '{2}' instead."),
                    Module_0_was_resolved_to_1_but_allowArbitraryExtensions_is_not_set: diag(6263, 1 /* Error */, "Module_0_was_resolved_to_1_but_allowArbitraryExtensions_is_not_set_6263", "Module '{0}' was resolved to '{1}', but '--allowArbitraryExtensions' is not set."),
                    Enable_importing_files_with_any_extension_provided_a_declaration_file_is_present: diag(6264, 3 /* Message */, "Enable_importing_files_with_any_extension_provided_a_declaration_file_is_present_6264", "Enable importing files with any extension, provided a declaration file is present."),
                    Resolving_type_reference_directive_for_program_that_specifies_custom_typeRoots_skipping_lookup_in_node_modules_folder: diag(6265, 3 /* Message */, "Resolving_type_reference_directive_for_program_that_specifies_custom_typeRoots_skipping_lookup_in_no_6265", "Resolving type reference directive for program that specifies custom typeRoots, skipping lookup in 'node_modules' folder."),
                    Option_0_can_only_be_specified_on_command_line: diag(6266, 1 /* Error */, "Option_0_can_only_be_specified_on_command_line_6266", "Option '{0}' can only be specified on command line."),
                    Directory_0_has_no_containing_package_json_scope_Imports_will_not_resolve: diag(6270, 3 /* Message */, "Directory_0_has_no_containing_package_json_scope_Imports_will_not_resolve_6270", "Directory '{0}' has no containing package.json scope. Imports will not resolve."),
                    Import_specifier_0_does_not_exist_in_package_json_scope_at_path_1: diag(6271, 3 /* Message */, "Import_specifier_0_does_not_exist_in_package_json_scope_at_path_1_6271", "Import specifier '{0}' does not exist in package.json scope at path '{1}'."),
                    Invalid_import_specifier_0_has_no_possible_resolutions: diag(6272, 3 /* Message */, "Invalid_import_specifier_0_has_no_possible_resolutions_6272", "Invalid import specifier '{0}' has no possible resolutions."),
                    package_json_scope_0_has_no_imports_defined: diag(6273, 3 /* Message */, "package_json_scope_0_has_no_imports_defined_6273", "package.json scope '{0}' has no imports defined."),
                    package_json_scope_0_explicitly_maps_specifier_1_to_null: diag(6274, 3 /* Message */, "package_json_scope_0_explicitly_maps_specifier_1_to_null_6274", "package.json scope '{0}' explicitly maps specifier '{1}' to null."),
                    package_json_scope_0_has_invalid_type_for_target_of_specifier_1: diag(6275, 3 /* Message */, "package_json_scope_0_has_invalid_type_for_target_of_specifier_1_6275", "package.json scope '{0}' has invalid type for target of specifier '{1}'"),
                    Export_specifier_0_does_not_exist_in_package_json_scope_at_path_1: diag(6276, 3 /* Message */, "Export_specifier_0_does_not_exist_in_package_json_scope_at_path_1_6276", "Export specifier '{0}' does not exist in package.json scope at path '{1}'."),
                    Resolution_of_non_relative_name_failed_trying_with_modern_Node_resolution_features_disabled_to_see_if_npm_library_needs_configuration_update: diag(6277, 3 /* Message */, "Resolution_of_non_relative_name_failed_trying_with_modern_Node_resolution_features_disabled_to_see_i_6277", "Resolution of non-relative name failed; trying with modern Node resolution features disabled to see if npm library needs configuration update."),
                    There_are_types_at_0_but_this_result_could_not_be_resolved_when_respecting_package_json_exports_The_1_library_may_need_to_update_its_package_json_or_typings: diag(6278, 3 /* Message */, "There_are_types_at_0_but_this_result_could_not_be_resolved_when_respecting_package_json_exports_The__6278", `There are types at '{0}', but this result could not be resolved when respecting package.json "exports". The '{1}' library may need to update its package.json or typings.`),
                    Resolution_of_non_relative_name_failed_trying_with_moduleResolution_bundler_to_see_if_project_may_need_configuration_update: diag(6279, 3 /* Message */, "Resolution_of_non_relative_name_failed_trying_with_moduleResolution_bundler_to_see_if_project_may_ne_6279", "Resolution of non-relative name failed; trying with '--moduleResolution bundler' to see if project may need configuration update."),
                    There_are_types_at_0_but_this_result_could_not_be_resolved_under_your_current_moduleResolution_setting_Consider_updating_to_node16_nodenext_or_bundler: diag(6280, 3 /* Message */, "There_are_types_at_0_but_this_result_could_not_be_resolved_under_your_current_moduleResolution_setti_6280", "There are types at '{0}', but this result could not be resolved under your current 'moduleResolution' setting. Consider updating to 'node16', 'nodenext', or 'bundler'."),
                    Enable_project_compilation: diag(6302, 3 /* Message */, "Enable_project_compilation_6302", "Enable project compilation"),
                    Composite_projects_may_not_disable_declaration_emit: diag(6304, 1 /* Error */, "Composite_projects_may_not_disable_declaration_emit_6304", "Composite projects may not disable declaration emit."),
                    Output_file_0_has_not_been_built_from_source_file_1: diag(6305, 1 /* Error */, "Output_file_0_has_not_been_built_from_source_file_1_6305", "Output file '{0}' has not been built from source file '{1}'."),
                    Referenced_project_0_must_have_setting_composite_Colon_true: diag(6306, 1 /* Error */, "Referenced_project_0_must_have_setting_composite_Colon_true_6306", `Referenced project '{0}' must have setting "composite": true.`),
                    File_0_is_not_listed_within_the_file_list_of_project_1_Projects_must_list_all_files_or_use_an_include_pattern: diag(6307, 1 /* Error */, "File_0_is_not_listed_within_the_file_list_of_project_1_Projects_must_list_all_files_or_use_an_includ_6307", "File '{0}' is not listed within the file list of project '{1}'. Projects must list all files or use an 'include' pattern."),
                    Cannot_prepend_project_0_because_it_does_not_have_outFile_set: diag(6308, 1 /* Error */, "Cannot_prepend_project_0_because_it_does_not_have_outFile_set_6308", "Cannot prepend project '{0}' because it does not have 'outFile' set"),
                    Output_file_0_from_project_1_does_not_exist: diag(6309, 1 /* Error */, "Output_file_0_from_project_1_does_not_exist_6309", "Output file '{0}' from project '{1}' does not exist"),
                    Referenced_project_0_may_not_disable_emit: diag(6310, 1 /* Error */, "Referenced_project_0_may_not_disable_emit_6310", "Referenced project '{0}' may not disable emit."),
                    Project_0_is_out_of_date_because_output_1_is_older_than_input_2: diag(6350, 3 /* Message */, "Project_0_is_out_of_date_because_output_1_is_older_than_input_2_6350", "Project '{0}' is out of date because output '{1}' is older than input '{2}'"),
                    Project_0_is_up_to_date_because_newest_input_1_is_older_than_output_2: diag(6351, 3 /* Message */, "Project_0_is_up_to_date_because_newest_input_1_is_older_than_output_2_6351", "Project '{0}' is up to date because newest input '{1}' is older than output '{2}'"),
                    Project_0_is_out_of_date_because_output_file_1_does_not_exist: diag(6352, 3 /* Message */, "Project_0_is_out_of_date_because_output_file_1_does_not_exist_6352", "Project '{0}' is out of date because output file '{1}' does not exist"),
                    Project_0_is_out_of_date_because_its_dependency_1_is_out_of_date: diag(6353, 3 /* Message */, "Project_0_is_out_of_date_because_its_dependency_1_is_out_of_date_6353", "Project '{0}' is out of date because its dependency '{1}' is out of date"),
                    Project_0_is_up_to_date_with_d_ts_files_from_its_dependencies: diag(6354, 3 /* Message */, "Project_0_is_up_to_date_with_d_ts_files_from_its_dependencies_6354", "Project '{0}' is up to date with .d.ts files from its dependencies"),
                    Projects_in_this_build_Colon_0: diag(6355, 3 /* Message */, "Projects_in_this_build_Colon_0_6355", "Projects in this build: {0}"),
                    A_non_dry_build_would_delete_the_following_files_Colon_0: diag(6356, 3 /* Message */, "A_non_dry_build_would_delete_the_following_files_Colon_0_6356", "A non-dry build would delete the following files: {0}"),
                    A_non_dry_build_would_build_project_0: diag(6357, 3 /* Message */, "A_non_dry_build_would_build_project_0_6357", "A non-dry build would build project '{0}'"),
                    Building_project_0: diag(6358, 3 /* Message */, "Building_project_0_6358", "Building project '{0}'..."),
                    Updating_output_timestamps_of_project_0: diag(6359, 3 /* Message */, "Updating_output_timestamps_of_project_0_6359", "Updating output timestamps of project '{0}'..."),
                    Project_0_is_up_to_date: diag(6361, 3 /* Message */, "Project_0_is_up_to_date_6361", "Project '{0}' is up to date"),
                    Skipping_build_of_project_0_because_its_dependency_1_has_errors: diag(6362, 3 /* Message */, "Skipping_build_of_project_0_because_its_dependency_1_has_errors_6362", "Skipping build of project '{0}' because its dependency '{1}' has errors"),
                    Project_0_can_t_be_built_because_its_dependency_1_has_errors: diag(6363, 3 /* Message */, "Project_0_can_t_be_built_because_its_dependency_1_has_errors_6363", "Project '{0}' can't be built because its dependency '{1}' has errors"),
                    Build_one_or_more_projects_and_their_dependencies_if_out_of_date: diag(6364, 3 /* Message */, "Build_one_or_more_projects_and_their_dependencies_if_out_of_date_6364", "Build one or more projects and their dependencies, if out of date"),
                    Delete_the_outputs_of_all_projects: diag(6365, 3 /* Message */, "Delete_the_outputs_of_all_projects_6365", "Delete the outputs of all projects."),
                    Show_what_would_be_built_or_deleted_if_specified_with_clean: diag(6367, 3 /* Message */, "Show_what_would_be_built_or_deleted_if_specified_with_clean_6367", "Show what would be built (or deleted, if specified with '--clean')"),
                    Option_build_must_be_the_first_command_line_argument: diag(6369, 1 /* Error */, "Option_build_must_be_the_first_command_line_argument_6369", "Option '--build' must be the first command line argument."),
                    Options_0_and_1_cannot_be_combined: diag(6370, 1 /* Error */, "Options_0_and_1_cannot_be_combined_6370", "Options '{0}' and '{1}' cannot be combined."),
                    Updating_unchanged_output_timestamps_of_project_0: diag(6371, 3 /* Message */, "Updating_unchanged_output_timestamps_of_project_0_6371", "Updating unchanged output timestamps of project '{0}'..."),
                    Project_0_is_out_of_date_because_output_of_its_dependency_1_has_changed: diag(6372, 3 /* Message */, "Project_0_is_out_of_date_because_output_of_its_dependency_1_has_changed_6372", "Project '{0}' is out of date because output of its dependency '{1}' has changed"),
                    Updating_output_of_project_0: diag(6373, 3 /* Message */, "Updating_output_of_project_0_6373", "Updating output of project '{0}'..."),
                    A_non_dry_build_would_update_timestamps_for_output_of_project_0: diag(6374, 3 /* Message */, "A_non_dry_build_would_update_timestamps_for_output_of_project_0_6374", "A non-dry build would update timestamps for output of project '{0}'"),
                    A_non_dry_build_would_update_output_of_project_0: diag(6375, 3 /* Message */, "A_non_dry_build_would_update_output_of_project_0_6375", "A non-dry build would update output of project '{0}'"),
                    Cannot_update_output_of_project_0_because_there_was_error_reading_file_1: diag(6376, 3 /* Message */, "Cannot_update_output_of_project_0_because_there_was_error_reading_file_1_6376", "Cannot update output of project '{0}' because there was error reading file '{1}'"),
                    Cannot_write_file_0_because_it_will_overwrite_tsbuildinfo_file_generated_by_referenced_project_1: diag(6377, 1 /* Error */, "Cannot_write_file_0_because_it_will_overwrite_tsbuildinfo_file_generated_by_referenced_project_1_6377", "Cannot write file '{0}' because it will overwrite '.tsbuildinfo' file generated by referenced project '{1}'"),
                    Composite_projects_may_not_disable_incremental_compilation: diag(6379, 1 /* Error */, "Composite_projects_may_not_disable_incremental_compilation_6379", "Composite projects may not disable incremental compilation."),
                    Specify_file_to_store_incremental_compilation_information: diag(6380, 3 /* Message */, "Specify_file_to_store_incremental_compilation_information_6380", "Specify file to store incremental compilation information"),
                    Project_0_is_out_of_date_because_output_for_it_was_generated_with_version_1_that_differs_with_current_version_2: diag(6381, 3 /* Message */, "Project_0_is_out_of_date_because_output_for_it_was_generated_with_version_1_that_differs_with_curren_6381", "Project '{0}' is out of date because output for it was generated with version '{1}' that differs with current version '{2}'"),
                    Skipping_build_of_project_0_because_its_dependency_1_was_not_built: diag(6382, 3 /* Message */, "Skipping_build_of_project_0_because_its_dependency_1_was_not_built_6382", "Skipping build of project '{0}' because its dependency '{1}' was not built"),
                    Project_0_can_t_be_built_because_its_dependency_1_was_not_built: diag(6383, 3 /* Message */, "Project_0_can_t_be_built_because_its_dependency_1_was_not_built_6383", "Project '{0}' can't be built because its dependency '{1}' was not built"),
                    Have_recompiles_in_incremental_and_watch_assume_that_changes_within_a_file_will_only_affect_files_directly_depending_on_it: diag(6384, 3 /* Message */, "Have_recompiles_in_incremental_and_watch_assume_that_changes_within_a_file_will_only_affect_files_di_6384", "Have recompiles in '--incremental' and '--watch' assume that changes within a file will only affect files directly depending on it."),
                    _0_is_deprecated: diag(6385, 2 /* Suggestion */, "_0_is_deprecated_6385", "'{0}' is deprecated.", 
                    /*reportsUnnecessary*/
                    void 0, 
                    /*elidedInCompatabilityPyramid*/
                    void 0, 
                    /*reportsDeprecated*/
                    true),
                    Performance_timings_for_diagnostics_or_extendedDiagnostics_are_not_available_in_this_session_A_native_implementation_of_the_Web_Performance_API_could_not_be_found: diag(6386, 3 /* Message */, "Performance_timings_for_diagnostics_or_extendedDiagnostics_are_not_available_in_this_session_A_nativ_6386", "Performance timings for '--diagnostics' or '--extendedDiagnostics' are not available in this session. A native implementation of the Web Performance API could not be found."),
                    The_signature_0_of_1_is_deprecated: diag(6387, 2 /* Suggestion */, "The_signature_0_of_1_is_deprecated_6387", "The signature '{0}' of '{1}' is deprecated.", 
                    /*reportsUnnecessary*/
                    void 0, 
                    /*elidedInCompatabilityPyramid*/
                    void 0, 
                    /*reportsDeprecated*/
                    true),
                    Project_0_is_being_forcibly_rebuilt: diag(6388, 3 /* Message */, "Project_0_is_being_forcibly_rebuilt_6388", "Project '{0}' is being forcibly rebuilt"),
                    Reusing_resolution_of_module_0_from_1_of_old_program_it_was_not_resolved: diag(6389, 3 /* Message */, "Reusing_resolution_of_module_0_from_1_of_old_program_it_was_not_resolved_6389", "Reusing resolution of module '{0}' from '{1}' of old program, it was not resolved."),
                    Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_successfully_resolved_to_2: diag(6390, 3 /* Message */, "Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_successfully_resolved__6390", "Reusing resolution of type reference directive '{0}' from '{1}' of old program, it was successfully resolved to '{2}'."),
                    Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_successfully_resolved_to_2_with_Package_ID_3: diag(6391, 3 /* Message */, "Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_successfully_resolved__6391", "Reusing resolution of type reference directive '{0}' from '{1}' of old program, it was successfully resolved to '{2}' with Package ID '{3}'."),
                    Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_not_resolved: diag(6392, 3 /* Message */, "Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_not_resolved_6392", "Reusing resolution of type reference directive '{0}' from '{1}' of old program, it was not resolved."),
                    Reusing_resolution_of_module_0_from_1_found_in_cache_from_location_2_it_was_successfully_resolved_to_3: diag(6393, 3 /* Message */, "Reusing_resolution_of_module_0_from_1_found_in_cache_from_location_2_it_was_successfully_resolved_to_6393", "Reusing resolution of module '{0}' from '{1}' found in cache from location '{2}', it was successfully resolved to '{3}'."),
                    Reusing_resolution_of_module_0_from_1_found_in_cache_from_location_2_it_was_successfully_resolved_to_3_with_Package_ID_4: diag(6394, 3 /* Message */, "Reusing_resolution_of_module_0_from_1_found_in_cache_from_location_2_it_was_successfully_resolved_to_6394", "Reusing resolution of module '{0}' from '{1}' found in cache from location '{2}', it was successfully resolved to '{3}' with Package ID '{4}'."),
                    Reusing_resolution_of_module_0_from_1_found_in_cache_from_location_2_it_was_not_resolved: diag(6395, 3 /* Message */, "Reusing_resolution_of_module_0_from_1_found_in_cache_from_location_2_it_was_not_resolved_6395", "Reusing resolution of module '{0}' from '{1}' found in cache from location '{2}', it was not resolved."),
                    Reusing_resolution_of_type_reference_directive_0_from_1_found_in_cache_from_location_2_it_was_successfully_resolved_to_3: diag(6396, 3 /* Message */, "Reusing_resolution_of_type_reference_directive_0_from_1_found_in_cache_from_location_2_it_was_succes_6396", "Reusing resolution of type reference directive '{0}' from '{1}' found in cache from location '{2}', it was successfully resolved to '{3}'."),
                    Reusing_resolution_of_type_reference_directive_0_from_1_found_in_cache_from_location_2_it_was_successfully_resolved_to_3_with_Package_ID_4: diag(6397, 3 /* Message */, "Reusing_resolution_of_type_reference_directive_0_from_1_found_in_cache_from_location_2_it_was_succes_6397", "Reusing resolution of type reference directive '{0}' from '{1}' found in cache from location '{2}', it was successfully resolved to '{3}' with Package ID '{4}'."),
                    Reusing_resolution_of_type_reference_directive_0_from_1_found_in_cache_from_location_2_it_was_not_resolved: diag(6398, 3 /* Message */, "Reusing_resolution_of_type_reference_directive_0_from_1_found_in_cache_from_location_2_it_was_not_re_6398", "Reusing resolution of type reference directive '{0}' from '{1}' found in cache from location '{2}', it was not resolved."),
                    Project_0_is_out_of_date_because_buildinfo_file_1_indicates_that_some_of_the_changes_were_not_emitted: diag(6399, 3 /* Message */, "Project_0_is_out_of_date_because_buildinfo_file_1_indicates_that_some_of_the_changes_were_not_emitte_6399", "Project '{0}' is out of date because buildinfo file '{1}' indicates that some of the changes were not emitted"),
                    Project_0_is_up_to_date_but_needs_to_update_timestamps_of_output_files_that_are_older_than_input_files: diag(6400, 3 /* Message */, "Project_0_is_up_to_date_but_needs_to_update_timestamps_of_output_files_that_are_older_than_input_fil_6400", "Project '{0}' is up to date but needs to update timestamps of output files that are older than input files"),
                    Project_0_is_out_of_date_because_there_was_error_reading_file_1: diag(6401, 3 /* Message */, "Project_0_is_out_of_date_because_there_was_error_reading_file_1_6401", "Project '{0}' is out of date because there was error reading file '{1}'"),
                    Resolving_in_0_mode_with_conditions_1: diag(6402, 3 /* Message */, "Resolving_in_0_mode_with_conditions_1_6402", "Resolving in {0} mode with conditions {1}."),
                    Matched_0_condition_1: diag(6403, 3 /* Message */, "Matched_0_condition_1_6403", "Matched '{0}' condition '{1}'."),
                    Using_0_subpath_1_with_target_2: diag(6404, 3 /* Message */, "Using_0_subpath_1_with_target_2_6404", "Using '{0}' subpath '{1}' with target '{2}'."),
                    Saw_non_matching_condition_0: diag(6405, 3 /* Message */, "Saw_non_matching_condition_0_6405", "Saw non-matching condition '{0}'."),
                    Project_0_is_out_of_date_because_buildinfo_file_1_indicates_there_is_change_in_compilerOptions: diag(6406, 3 /* Message */, "Project_0_is_out_of_date_because_buildinfo_file_1_indicates_there_is_change_in_compilerOptions_6406", "Project '{0}' is out of date because buildinfo file '{1}' indicates there is change in compilerOptions"),
                    Allow_imports_to_include_TypeScript_file_extensions_Requires_moduleResolution_bundler_and_either_noEmit_or_emitDeclarationOnly_to_be_set: diag(6407, 3 /* Message */, "Allow_imports_to_include_TypeScript_file_extensions_Requires_moduleResolution_bundler_and_either_noE_6407", "Allow imports to include TypeScript file extensions. Requires '--moduleResolution bundler' and either '--noEmit' or '--emitDeclarationOnly' to be set."),
                    Use_the_package_json_exports_field_when_resolving_package_imports: diag(6408, 3 /* Message */, "Use_the_package_json_exports_field_when_resolving_package_imports_6408", "Use the package.json 'exports' field when resolving package imports."),
                    Use_the_package_json_imports_field_when_resolving_imports: diag(6409, 3 /* Message */, "Use_the_package_json_imports_field_when_resolving_imports_6409", "Use the package.json 'imports' field when resolving imports."),
                    Conditions_to_set_in_addition_to_the_resolver_specific_defaults_when_resolving_imports: diag(6410, 3 /* Message */, "Conditions_to_set_in_addition_to_the_resolver_specific_defaults_when_resolving_imports_6410", "Conditions to set in addition to the resolver-specific defaults when resolving imports."),
                    true_when_moduleResolution_is_node16_nodenext_or_bundler_otherwise_false: diag(6411, 3 /* Message */, "true_when_moduleResolution_is_node16_nodenext_or_bundler_otherwise_false_6411", "`true` when 'moduleResolution' is 'node16', 'nodenext', or 'bundler'; otherwise `false`."),
                    Project_0_is_out_of_date_because_buildinfo_file_1_indicates_that_file_2_was_root_file_of_compilation_but_not_any_more: diag(6412, 3 /* Message */, "Project_0_is_out_of_date_because_buildinfo_file_1_indicates_that_file_2_was_root_file_of_compilation_6412", "Project '{0}' is out of date because buildinfo file '{1}' indicates that file '{2}' was root file of compilation but not any more."),
                    Entering_conditional_exports: diag(6413, 3 /* Message */, "Entering_conditional_exports_6413", "Entering conditional exports."),
                    Resolved_under_condition_0: diag(6414, 3 /* Message */, "Resolved_under_condition_0_6414", "Resolved under condition '{0}'."),
                    Failed_to_resolve_under_condition_0: diag(6415, 3 /* Message */, "Failed_to_resolve_under_condition_0_6415", "Failed to resolve under condition '{0}'."),
                    Exiting_conditional_exports: diag(6416, 3 /* Message */, "Exiting_conditional_exports_6416", "Exiting conditional exports."),
                    Searching_all_ancestor_node_modules_directories_for_preferred_extensions_Colon_0: diag(6417, 3 /* Message */, "Searching_all_ancestor_node_modules_directories_for_preferred_extensions_Colon_0_6417", "Searching all ancestor node_modules directories for preferred extensions: {0}."),
                    Searching_all_ancestor_node_modules_directories_for_fallback_extensions_Colon_0: diag(6418, 3 /* Message */, "Searching_all_ancestor_node_modules_directories_for_fallback_extensions_Colon_0_6418", "Searching all ancestor node_modules directories for fallback extensions: {0}."),
                    The_expected_type_comes_from_property_0_which_is_declared_here_on_type_1: diag(6500, 3 /* Message */, "The_expected_type_comes_from_property_0_which_is_declared_here_on_type_1_6500", "The expected type comes from property '{0}' which is declared here on type '{1}'"),
                    The_expected_type_comes_from_this_index_signature: diag(6501, 3 /* Message */, "The_expected_type_comes_from_this_index_signature_6501", "The expected type comes from this index signature."),
                    The_expected_type_comes_from_the_return_type_of_this_signature: diag(6502, 3 /* Message */, "The_expected_type_comes_from_the_return_type_of_this_signature_6502", "The expected type comes from the return type of this signature."),
                    Print_names_of_files_that_are_part_of_the_compilation_and_then_stop_processing: diag(6503, 3 /* Message */, "Print_names_of_files_that_are_part_of_the_compilation_and_then_stop_processing_6503", "Print names of files that are part of the compilation and then stop processing."),
                    File_0_is_a_JavaScript_file_Did_you_mean_to_enable_the_allowJs_option: diag(6504, 1 /* Error */, "File_0_is_a_JavaScript_file_Did_you_mean_to_enable_the_allowJs_option_6504", "File '{0}' is a JavaScript file. Did you mean to enable the 'allowJs' option?"),
                    Print_names_of_files_and_the_reason_they_are_part_of_the_compilation: diag(6505, 3 /* Message */, "Print_names_of_files_and_the_reason_they_are_part_of_the_compilation_6505", "Print names of files and the reason they are part of the compilation."),
                    Consider_adding_a_declare_modifier_to_this_class: diag(6506, 3 /* Message */, "Consider_adding_a_declare_modifier_to_this_class_6506", "Consider adding a 'declare' modifier to this class."),
                    Allow_JavaScript_files_to_be_a_part_of_your_program_Use_the_checkJS_option_to_get_errors_from_these_files: diag(6600, 3 /* Message */, "Allow_JavaScript_files_to_be_a_part_of_your_program_Use_the_checkJS_option_to_get_errors_from_these__6600", "Allow JavaScript files to be a part of your program. Use the 'checkJS' option to get errors from these files."),
                    Allow_import_x_from_y_when_a_module_doesn_t_have_a_default_export: diag(6601, 3 /* Message */, "Allow_import_x_from_y_when_a_module_doesn_t_have_a_default_export_6601", "Allow 'import x from y' when a module doesn't have a default export."),
                    Allow_accessing_UMD_globals_from_modules: diag(6602, 3 /* Message */, "Allow_accessing_UMD_globals_from_modules_6602", "Allow accessing UMD globals from modules."),
                    Disable_error_reporting_for_unreachable_code: diag(6603, 3 /* Message */, "Disable_error_reporting_for_unreachable_code_6603", "Disable error reporting for unreachable code."),
                    Disable_error_reporting_for_unused_labels: diag(6604, 3 /* Message */, "Disable_error_reporting_for_unused_labels_6604", "Disable error reporting for unused labels."),
                    Ensure_use_strict_is_always_emitted: diag(6605, 3 /* Message */, "Ensure_use_strict_is_always_emitted_6605", "Ensure 'use strict' is always emitted."),
                    Have_recompiles_in_projects_that_use_incremental_and_watch_mode_assume_that_changes_within_a_file_will_only_affect_files_directly_depending_on_it: diag(6606, 3 /* Message */, "Have_recompiles_in_projects_that_use_incremental_and_watch_mode_assume_that_changes_within_a_file_wi_6606", "Have recompiles in projects that use 'incremental' and 'watch' mode assume that changes within a file will only affect files directly depending on it."),
                    Specify_the_base_directory_to_resolve_non_relative_module_names: diag(6607, 3 /* Message */, "Specify_the_base_directory_to_resolve_non_relative_module_names_6607", "Specify the base directory to resolve non-relative module names."),
                    No_longer_supported_In_early_versions_manually_set_the_text_encoding_for_reading_files: diag(6608, 3 /* Message */, "No_longer_supported_In_early_versions_manually_set_the_text_encoding_for_reading_files_6608", "No longer supported. In early versions, manually set the text encoding for reading files."),
                    Enable_error_reporting_in_type_checked_JavaScript_files: diag(6609, 3 /* Message */, "Enable_error_reporting_in_type_checked_JavaScript_files_6609", "Enable error reporting in type-checked JavaScript files."),
                    Enable_constraints_that_allow_a_TypeScript_project_to_be_used_with_project_references: diag(6611, 3 /* Message */, "Enable_constraints_that_allow_a_TypeScript_project_to_be_used_with_project_references_6611", "Enable constraints that allow a TypeScript project to be used with project references."),
                    Generate_d_ts_files_from_TypeScript_and_JavaScript_files_in_your_project: diag(6612, 3 /* Message */, "Generate_d_ts_files_from_TypeScript_and_JavaScript_files_in_your_project_6612", "Generate .d.ts files from TypeScript and JavaScript files in your project."),
                    Specify_the_output_directory_for_generated_declaration_files: diag(6613, 3 /* Message */, "Specify_the_output_directory_for_generated_declaration_files_6613", "Specify the output directory for generated declaration files."),
                    Create_sourcemaps_for_d_ts_files: diag(6614, 3 /* Message */, "Create_sourcemaps_for_d_ts_files_6614", "Create sourcemaps for d.ts files."),
                    Output_compiler_performance_information_after_building: diag(6615, 3 /* Message */, "Output_compiler_performance_information_after_building_6615", "Output compiler performance information after building."),
                    Disables_inference_for_type_acquisition_by_looking_at_filenames_in_a_project: diag(6616, 3 /* Message */, "Disables_inference_for_type_acquisition_by_looking_at_filenames_in_a_project_6616", "Disables inference for type acquisition by looking at filenames in a project."),
                    Reduce_the_number_of_projects_loaded_automatically_by_TypeScript: diag(6617, 3 /* Message */, "Reduce_the_number_of_projects_loaded_automatically_by_TypeScript_6617", "Reduce the number of projects loaded automatically by TypeScript."),
                    Remove_the_20mb_cap_on_total_source_code_size_for_JavaScript_files_in_the_TypeScript_language_server: diag(6618, 3 /* Message */, "Remove_the_20mb_cap_on_total_source_code_size_for_JavaScript_files_in_the_TypeScript_language_server_6618", "Remove the 20mb cap on total source code size for JavaScript files in the TypeScript language server."),
                    Opt_a_project_out_of_multi_project_reference_checking_when_editing: diag(6619, 3 /* Message */, "Opt_a_project_out_of_multi_project_reference_checking_when_editing_6619", "Opt a project out of multi-project reference checking when editing."),
                    Disable_preferring_source_files_instead_of_declaration_files_when_referencing_composite_projects: diag(6620, 3 /* Message */, "Disable_preferring_source_files_instead_of_declaration_files_when_referencing_composite_projects_6620", "Disable preferring source files instead of declaration files when referencing composite projects."),
                    Emit_more_compliant_but_verbose_and_less_performant_JavaScript_for_iteration: diag(6621, 3 /* Message */, "Emit_more_compliant_but_verbose_and_less_performant_JavaScript_for_iteration_6621", "Emit more compliant, but verbose and less performant JavaScript for iteration."),
                    Emit_a_UTF_8_Byte_Order_Mark_BOM_in_the_beginning_of_output_files: diag(6622, 3 /* Message */, "Emit_a_UTF_8_Byte_Order_Mark_BOM_in_the_beginning_of_output_files_6622", "Emit a UTF-8 Byte Order Mark (BOM) in the beginning of output files."),
                    Only_output_d_ts_files_and_not_JavaScript_files: diag(6623, 3 /* Message */, "Only_output_d_ts_files_and_not_JavaScript_files_6623", "Only output d.ts files and not JavaScript files."),
                    Emit_design_type_metadata_for_decorated_declarations_in_source_files: diag(6624, 3 /* Message */, "Emit_design_type_metadata_for_decorated_declarations_in_source_files_6624", "Emit design-type metadata for decorated declarations in source files."),
                    Disable_the_type_acquisition_for_JavaScript_projects: diag(6625, 3 /* Message */, "Disable_the_type_acquisition_for_JavaScript_projects_6625", "Disable the type acquisition for JavaScript projects"),
                    Emit_additional_JavaScript_to_ease_support_for_importing_CommonJS_modules_This_enables_allowSyntheticDefaultImports_for_type_compatibility: diag(6626, 3 /* Message */, "Emit_additional_JavaScript_to_ease_support_for_importing_CommonJS_modules_This_enables_allowSyntheti_6626", "Emit additional JavaScript to ease support for importing CommonJS modules. This enables 'allowSyntheticDefaultImports' for type compatibility."),
                    Filters_results_from_the_include_option: diag(6627, 3 /* Message */, "Filters_results_from_the_include_option_6627", "Filters results from the `include` option."),
                    Remove_a_list_of_directories_from_the_watch_process: diag(6628, 3 /* Message */, "Remove_a_list_of_directories_from_the_watch_process_6628", "Remove a list of directories from the watch process."),
                    Remove_a_list_of_files_from_the_watch_mode_s_processing: diag(6629, 3 /* Message */, "Remove_a_list_of_files_from_the_watch_mode_s_processing_6629", "Remove a list of files from the watch mode's processing."),
                    Enable_experimental_support_for_legacy_experimental_decorators: diag(6630, 3 /* Message */, "Enable_experimental_support_for_legacy_experimental_decorators_6630", "Enable experimental support for legacy experimental decorators."),
                    Print_files_read_during_the_compilation_including_why_it_was_included: diag(6631, 3 /* Message */, "Print_files_read_during_the_compilation_including_why_it_was_included_6631", "Print files read during the compilation including why it was included."),
                    Output_more_detailed_compiler_performance_information_after_building: diag(6632, 3 /* Message */, "Output_more_detailed_compiler_performance_information_after_building_6632", "Output more detailed compiler performance information after building."),
                    Specify_one_or_more_path_or_node_module_references_to_base_configuration_files_from_which_settings_are_inherited: diag(6633, 3 /* Message */, "Specify_one_or_more_path_or_node_module_references_to_base_configuration_files_from_which_settings_a_6633", "Specify one or more path or node module references to base configuration files from which settings are inherited."),
                    Specify_what_approach_the_watcher_should_use_if_the_system_runs_out_of_native_file_watchers: diag(6634, 3 /* Message */, "Specify_what_approach_the_watcher_should_use_if_the_system_runs_out_of_native_file_watchers_6634", "Specify what approach the watcher should use if the system runs out of native file watchers."),
                    Include_a_list_of_files_This_does_not_support_glob_patterns_as_opposed_to_include: diag(6635, 3 /* Message */, "Include_a_list_of_files_This_does_not_support_glob_patterns_as_opposed_to_include_6635", "Include a list of files. This does not support glob patterns, as opposed to `include`."),
                    Build_all_projects_including_those_that_appear_to_be_up_to_date: diag(6636, 3 /* Message */, "Build_all_projects_including_those_that_appear_to_be_up_to_date_6636", "Build all projects, including those that appear to be up to date."),
                    Ensure_that_casing_is_correct_in_imports: diag(6637, 3 /* Message */, "Ensure_that_casing_is_correct_in_imports_6637", "Ensure that casing is correct in imports."),
                    Emit_a_v8_CPU_profile_of_the_compiler_run_for_debugging: diag(6638, 3 /* Message */, "Emit_a_v8_CPU_profile_of_the_compiler_run_for_debugging_6638", "Emit a v8 CPU profile of the compiler run for debugging."),
                    Allow_importing_helper_functions_from_tslib_once_per_project_instead_of_including_them_per_file: diag(6639, 3 /* Message */, "Allow_importing_helper_functions_from_tslib_once_per_project_instead_of_including_them_per_file_6639", "Allow importing helper functions from tslib once per project, instead of including them per-file."),
                    Specify_a_list_of_glob_patterns_that_match_files_to_be_included_in_compilation: diag(6641, 3 /* Message */, "Specify_a_list_of_glob_patterns_that_match_files_to_be_included_in_compilation_6641", "Specify a list of glob patterns that match files to be included in compilation."),
                    Save_tsbuildinfo_files_to_allow_for_incremental_compilation_of_projects: diag(6642, 3 /* Message */, "Save_tsbuildinfo_files_to_allow_for_incremental_compilation_of_projects_6642", "Save .tsbuildinfo files to allow for incremental compilation of projects."),
                    Include_sourcemap_files_inside_the_emitted_JavaScript: diag(6643, 3 /* Message */, "Include_sourcemap_files_inside_the_emitted_JavaScript_6643", "Include sourcemap files inside the emitted JavaScript."),
                    Include_source_code_in_the_sourcemaps_inside_the_emitted_JavaScript: diag(6644, 3 /* Message */, "Include_source_code_in_the_sourcemaps_inside_the_emitted_JavaScript_6644", "Include source code in the sourcemaps inside the emitted JavaScript."),
                    Ensure_that_each_file_can_be_safely_transpiled_without_relying_on_other_imports: diag(6645, 3 /* Message */, "Ensure_that_each_file_can_be_safely_transpiled_without_relying_on_other_imports_6645", "Ensure that each file can be safely transpiled without relying on other imports."),
                    Specify_what_JSX_code_is_generated: diag(6646, 3 /* Message */, "Specify_what_JSX_code_is_generated_6646", "Specify what JSX code is generated."),
                    Specify_the_JSX_factory_function_used_when_targeting_React_JSX_emit_e_g_React_createElement_or_h: diag(6647, 3 /* Message */, "Specify_the_JSX_factory_function_used_when_targeting_React_JSX_emit_e_g_React_createElement_or_h_6647", "Specify the JSX factory function used when targeting React JSX emit, e.g. 'React.createElement' or 'h'."),
                    Specify_the_JSX_Fragment_reference_used_for_fragments_when_targeting_React_JSX_emit_e_g_React_Fragment_or_Fragment: diag(6648, 3 /* Message */, "Specify_the_JSX_Fragment_reference_used_for_fragments_when_targeting_React_JSX_emit_e_g_React_Fragme_6648", "Specify the JSX Fragment reference used for fragments when targeting React JSX emit e.g. 'React.Fragment' or 'Fragment'."),
                    Specify_module_specifier_used_to_import_the_JSX_factory_functions_when_using_jsx_Colon_react_jsx_Asterisk: diag(6649, 3 /* Message */, "Specify_module_specifier_used_to_import_the_JSX_factory_functions_when_using_jsx_Colon_react_jsx_Ast_6649", "Specify module specifier used to import the JSX factory functions when using 'jsx: react-jsx*'."),
                    Make_keyof_only_return_strings_instead_of_string_numbers_or_symbols_Legacy_option: diag(6650, 3 /* Message */, "Make_keyof_only_return_strings_instead_of_string_numbers_or_symbols_Legacy_option_6650", "Make keyof only return strings instead of string, numbers or symbols. Legacy option."),
                    Specify_a_set_of_bundled_library_declaration_files_that_describe_the_target_runtime_environment: diag(6651, 3 /* Message */, "Specify_a_set_of_bundled_library_declaration_files_that_describe_the_target_runtime_environment_6651", "Specify a set of bundled library declaration files that describe the target runtime environment."),
                    Print_the_names_of_emitted_files_after_a_compilation: diag(6652, 3 /* Message */, "Print_the_names_of_emitted_files_after_a_compilation_6652", "Print the names of emitted files after a compilation."),
                    Print_all_of_the_files_read_during_the_compilation: diag(6653, 3 /* Message */, "Print_all_of_the_files_read_during_the_compilation_6653", "Print all of the files read during the compilation."),
                    Set_the_language_of_the_messaging_from_TypeScript_This_does_not_affect_emit: diag(6654, 3 /* Message */, "Set_the_language_of_the_messaging_from_TypeScript_This_does_not_affect_emit_6654", "Set the language of the messaging from TypeScript. This does not affect emit."),
                    Specify_the_location_where_debugger_should_locate_map_files_instead_of_generated_locations: diag(6655, 3 /* Message */, "Specify_the_location_where_debugger_should_locate_map_files_instead_of_generated_locations_6655", "Specify the location where debugger should locate map files instead of generated locations."),
                    Specify_the_maximum_folder_depth_used_for_checking_JavaScript_files_from_node_modules_Only_applicable_with_allowJs: diag(6656, 3 /* Message */, "Specify_the_maximum_folder_depth_used_for_checking_JavaScript_files_from_node_modules_Only_applicabl_6656", "Specify the maximum folder depth used for checking JavaScript files from 'node_modules'. Only applicable with 'allowJs'."),
                    Specify_what_module_code_is_generated: diag(6657, 3 /* Message */, "Specify_what_module_code_is_generated_6657", "Specify what module code is generated."),
                    Specify_how_TypeScript_looks_up_a_file_from_a_given_module_specifier: diag(6658, 3 /* Message */, "Specify_how_TypeScript_looks_up_a_file_from_a_given_module_specifier_6658", "Specify how TypeScript looks up a file from a given module specifier."),
                    Set_the_newline_character_for_emitting_files: diag(6659, 3 /* Message */, "Set_the_newline_character_for_emitting_files_6659", "Set the newline character for emitting files."),
                    Disable_emitting_files_from_a_compilation: diag(6660, 3 /* Message */, "Disable_emitting_files_from_a_compilation_6660", "Disable emitting files from a compilation."),
                    Disable_generating_custom_helper_functions_like_extends_in_compiled_output: diag(6661, 3 /* Message */, "Disable_generating_custom_helper_functions_like_extends_in_compiled_output_6661", "Disable generating custom helper functions like '__extends' in compiled output."),
                    Disable_emitting_files_if_any_type_checking_errors_are_reported: diag(6662, 3 /* Message */, "Disable_emitting_files_if_any_type_checking_errors_are_reported_6662", "Disable emitting files if any type checking errors are reported."),
                    Disable_truncating_types_in_error_messages: diag(6663, 3 /* Message */, "Disable_truncating_types_in_error_messages_6663", "Disable truncating types in error messages."),
                    Enable_error_reporting_for_fallthrough_cases_in_switch_statements: diag(6664, 3 /* Message */, "Enable_error_reporting_for_fallthrough_cases_in_switch_statements_6664", "Enable error reporting for fallthrough cases in switch statements."),
                    Enable_error_reporting_for_expressions_and_declarations_with_an_implied_any_type: diag(6665, 3 /* Message */, "Enable_error_reporting_for_expressions_and_declarations_with_an_implied_any_type_6665", "Enable error reporting for expressions and declarations with an implied 'any' type."),
                    Ensure_overriding_members_in_derived_classes_are_marked_with_an_override_modifier: diag(6666, 3 /* Message */, "Ensure_overriding_members_in_derived_classes_are_marked_with_an_override_modifier_6666", "Ensure overriding members in derived classes are marked with an override modifier."),
                    Enable_error_reporting_for_codepaths_that_do_not_explicitly_return_in_a_function: diag(6667, 3 /* Message */, "Enable_error_reporting_for_codepaths_that_do_not_explicitly_return_in_a_function_6667", "Enable error reporting for codepaths that do not explicitly return in a function."),
                    Enable_error_reporting_when_this_is_given_the_type_any: diag(6668, 3 /* Message */, "Enable_error_reporting_when_this_is_given_the_type_any_6668", "Enable error reporting when 'this' is given the type 'any'."),
                    Disable_adding_use_strict_directives_in_emitted_JavaScript_files: diag(6669, 3 /* Message */, "Disable_adding_use_strict_directives_in_emitted_JavaScript_files_6669", "Disable adding 'use strict' directives in emitted JavaScript files."),
                    Disable_including_any_library_files_including_the_default_lib_d_ts: diag(6670, 3 /* Message */, "Disable_including_any_library_files_including_the_default_lib_d_ts_6670", "Disable including any library files, including the default lib.d.ts."),
                    Enforces_using_indexed_accessors_for_keys_declared_using_an_indexed_type: diag(6671, 3 /* Message */, "Enforces_using_indexed_accessors_for_keys_declared_using_an_indexed_type_6671", "Enforces using indexed accessors for keys declared using an indexed type."),
                    Disallow_import_s_require_s_or_reference_s_from_expanding_the_number_of_files_TypeScript_should_add_to_a_project: diag(6672, 3 /* Message */, "Disallow_import_s_require_s_or_reference_s_from_expanding_the_number_of_files_TypeScript_should_add__6672", "Disallow 'import's, 'require's or '<reference>'s from expanding the number of files TypeScript should add to a project."),
                    Disable_strict_checking_of_generic_signatures_in_function_types: diag(6673, 3 /* Message */, "Disable_strict_checking_of_generic_signatures_in_function_types_6673", "Disable strict checking of generic signatures in function types."),
                    Add_undefined_to_a_type_when_accessed_using_an_index: diag(6674, 3 /* Message */, "Add_undefined_to_a_type_when_accessed_using_an_index_6674", "Add 'undefined' to a type when accessed using an index."),
                    Enable_error_reporting_when_local_variables_aren_t_read: diag(6675, 3 /* Message */, "Enable_error_reporting_when_local_variables_aren_t_read_6675", "Enable error reporting when local variables aren't read."),
                    Raise_an_error_when_a_function_parameter_isn_t_read: diag(6676, 3 /* Message */, "Raise_an_error_when_a_function_parameter_isn_t_read_6676", "Raise an error when a function parameter isn't read."),
                    Deprecated_setting_Use_outFile_instead: diag(6677, 3 /* Message */, "Deprecated_setting_Use_outFile_instead_6677", "Deprecated setting. Use 'outFile' instead."),
                    Specify_an_output_folder_for_all_emitted_files: diag(6678, 3 /* Message */, "Specify_an_output_folder_for_all_emitted_files_6678", "Specify an output folder for all emitted files."),
                    Specify_a_file_that_bundles_all_outputs_into_one_JavaScript_file_If_declaration_is_true_also_designates_a_file_that_bundles_all_d_ts_output: diag(6679, 3 /* Message */, "Specify_a_file_that_bundles_all_outputs_into_one_JavaScript_file_If_declaration_is_true_also_designa_6679", "Specify a file that bundles all outputs into one JavaScript file. If 'declaration' is true, also designates a file that bundles all .d.ts output."),
                    Specify_a_set_of_entries_that_re_map_imports_to_additional_lookup_locations: diag(6680, 3 /* Message */, "Specify_a_set_of_entries_that_re_map_imports_to_additional_lookup_locations_6680", "Specify a set of entries that re-map imports to additional lookup locations."),
                    Specify_a_list_of_language_service_plugins_to_include: diag(6681, 3 /* Message */, "Specify_a_list_of_language_service_plugins_to_include_6681", "Specify a list of language service plugins to include."),
                    Disable_erasing_const_enum_declarations_in_generated_code: diag(6682, 3 /* Message */, "Disable_erasing_const_enum_declarations_in_generated_code_6682", "Disable erasing 'const enum' declarations in generated code."),
                    Disable_resolving_symlinks_to_their_realpath_This_correlates_to_the_same_flag_in_node: diag(6683, 3 /* Message */, "Disable_resolving_symlinks_to_their_realpath_This_correlates_to_the_same_flag_in_node_6683", "Disable resolving symlinks to their realpath. This correlates to the same flag in node."),
                    Disable_wiping_the_console_in_watch_mode: diag(6684, 3 /* Message */, "Disable_wiping_the_console_in_watch_mode_6684", "Disable wiping the console in watch mode."),
                    Enable_color_and_formatting_in_TypeScript_s_output_to_make_compiler_errors_easier_to_read: diag(6685, 3 /* Message */, "Enable_color_and_formatting_in_TypeScript_s_output_to_make_compiler_errors_easier_to_read_6685", "Enable color and formatting in TypeScript's output to make compiler errors easier to read."),
                    Specify_the_object_invoked_for_createElement_This_only_applies_when_targeting_react_JSX_emit: diag(6686, 3 /* Message */, "Specify_the_object_invoked_for_createElement_This_only_applies_when_targeting_react_JSX_emit_6686", "Specify the object invoked for 'createElement'. This only applies when targeting 'react' JSX emit."),
                    Specify_an_array_of_objects_that_specify_paths_for_projects_Used_in_project_references: diag(6687, 3 /* Message */, "Specify_an_array_of_objects_that_specify_paths_for_projects_Used_in_project_references_6687", "Specify an array of objects that specify paths for projects. Used in project references."),
                    Disable_emitting_comments: diag(6688, 3 /* Message */, "Disable_emitting_comments_6688", "Disable emitting comments."),
                    Enable_importing_json_files: diag(6689, 3 /* Message */, "Enable_importing_json_files_6689", "Enable importing .json files."),
                    Specify_the_root_folder_within_your_source_files: diag(6690, 3 /* Message */, "Specify_the_root_folder_within_your_source_files_6690", "Specify the root folder within your source files."),
                    Allow_multiple_folders_to_be_treated_as_one_when_resolving_modules: diag(6691, 3 /* Message */, "Allow_multiple_folders_to_be_treated_as_one_when_resolving_modules_6691", "Allow multiple folders to be treated as one when resolving modules."),
                    Skip_type_checking_d_ts_files_that_are_included_with_TypeScript: diag(6692, 3 /* Message */, "Skip_type_checking_d_ts_files_that_are_included_with_TypeScript_6692", "Skip type checking .d.ts files that are included with TypeScript."),
                    Skip_type_checking_all_d_ts_files: diag(6693, 3 /* Message */, "Skip_type_checking_all_d_ts_files_6693", "Skip type checking all .d.ts files."),
                    Create_source_map_files_for_emitted_JavaScript_files: diag(6694, 3 /* Message */, "Create_source_map_files_for_emitted_JavaScript_files_6694", "Create source map files for emitted JavaScript files."),
                    Specify_the_root_path_for_debuggers_to_find_the_reference_source_code: diag(6695, 3 /* Message */, "Specify_the_root_path_for_debuggers_to_find_the_reference_source_code_6695", "Specify the root path for debuggers to find the reference source code."),
                    Check_that_the_arguments_for_bind_call_and_apply_methods_match_the_original_function: diag(6697, 3 /* Message */, "Check_that_the_arguments_for_bind_call_and_apply_methods_match_the_original_function_6697", "Check that the arguments for 'bind', 'call', and 'apply' methods match the original function."),
                    When_assigning_functions_check_to_ensure_parameters_and_the_return_values_are_subtype_compatible: diag(6698, 3 /* Message */, "When_assigning_functions_check_to_ensure_parameters_and_the_return_values_are_subtype_compatible_6698", "When assigning functions, check to ensure parameters and the return values are subtype-compatible."),
                    When_type_checking_take_into_account_null_and_undefined: diag(6699, 3 /* Message */, "When_type_checking_take_into_account_null_and_undefined_6699", "When type checking, take into account 'null' and 'undefined'."),
                    Check_for_class_properties_that_are_declared_but_not_set_in_the_constructor: diag(6700, 3 /* Message */, "Check_for_class_properties_that_are_declared_but_not_set_in_the_constructor_6700", "Check for class properties that are declared but not set in the constructor."),
                    Disable_emitting_declarations_that_have_internal_in_their_JSDoc_comments: diag(6701, 3 /* Message */, "Disable_emitting_declarations_that_have_internal_in_their_JSDoc_comments_6701", "Disable emitting declarations that have '@internal' in their JSDoc comments."),
                    Disable_reporting_of_excess_property_errors_during_the_creation_of_object_literals: diag(6702, 3 /* Message */, "Disable_reporting_of_excess_property_errors_during_the_creation_of_object_literals_6702", "Disable reporting of excess property errors during the creation of object literals."),
                    Suppress_noImplicitAny_errors_when_indexing_objects_that_lack_index_signatures: diag(6703, 3 /* Message */, "Suppress_noImplicitAny_errors_when_indexing_objects_that_lack_index_signatures_6703", "Suppress 'noImplicitAny' errors when indexing objects that lack index signatures."),
                    Synchronously_call_callbacks_and_update_the_state_of_directory_watchers_on_platforms_that_don_t_support_recursive_watching_natively: diag(6704, 3 /* Message */, "Synchronously_call_callbacks_and_update_the_state_of_directory_watchers_on_platforms_that_don_t_supp_6704", "Synchronously call callbacks and update the state of directory watchers on platforms that don`t support recursive watching natively."),
                    Set_the_JavaScript_language_version_for_emitted_JavaScript_and_include_compatible_library_declarations: diag(6705, 3 /* Message */, "Set_the_JavaScript_language_version_for_emitted_JavaScript_and_include_compatible_library_declaratio_6705", "Set the JavaScript language version for emitted JavaScript and include compatible library declarations."),
                    Log_paths_used_during_the_moduleResolution_process: diag(6706, 3 /* Message */, "Log_paths_used_during_the_moduleResolution_process_6706", "Log paths used during the 'moduleResolution' process."),
                    Specify_the_path_to_tsbuildinfo_incremental_compilation_file: diag(6707, 3 /* Message */, "Specify_the_path_to_tsbuildinfo_incremental_compilation_file_6707", "Specify the path to .tsbuildinfo incremental compilation file."),
                    Specify_options_for_automatic_acquisition_of_declaration_files: diag(6709, 3 /* Message */, "Specify_options_for_automatic_acquisition_of_declaration_files_6709", "Specify options for automatic acquisition of declaration files."),
                    Specify_multiple_folders_that_act_like_Slashnode_modules_Slash_types: diag(6710, 3 /* Message */, "Specify_multiple_folders_that_act_like_Slashnode_modules_Slash_types_6710", "Specify multiple folders that act like './node_modules/@types'."),
                    Specify_type_package_names_to_be_included_without_being_referenced_in_a_source_file: diag(6711, 3 /* Message */, "Specify_type_package_names_to_be_included_without_being_referenced_in_a_source_file_6711", "Specify type package names to be included without being referenced in a source file."),
                    Emit_ECMAScript_standard_compliant_class_fields: diag(6712, 3 /* Message */, "Emit_ECMAScript_standard_compliant_class_fields_6712", "Emit ECMAScript-standard-compliant class fields."),
                    Enable_verbose_logging: diag(6713, 3 /* Message */, "Enable_verbose_logging_6713", "Enable verbose logging."),
                    Specify_how_directories_are_watched_on_systems_that_lack_recursive_file_watching_functionality: diag(6714, 3 /* Message */, "Specify_how_directories_are_watched_on_systems_that_lack_recursive_file_watching_functionality_6714", "Specify how directories are watched on systems that lack recursive file-watching functionality."),
                    Specify_how_the_TypeScript_watch_mode_works: diag(6715, 3 /* Message */, "Specify_how_the_TypeScript_watch_mode_works_6715", "Specify how the TypeScript watch mode works."),
                    Require_undeclared_properties_from_index_signatures_to_use_element_accesses: diag(6717, 3 /* Message */, "Require_undeclared_properties_from_index_signatures_to_use_element_accesses_6717", "Require undeclared properties from index signatures to use element accesses."),
                    Specify_emit_Slashchecking_behavior_for_imports_that_are_only_used_for_types: diag(6718, 3 /* Message */, "Specify_emit_Slashchecking_behavior_for_imports_that_are_only_used_for_types_6718", "Specify emit/checking behavior for imports that are only used for types."),
                    Default_catch_clause_variables_as_unknown_instead_of_any: diag(6803, 3 /* Message */, "Default_catch_clause_variables_as_unknown_instead_of_any_6803", "Default catch clause variables as 'unknown' instead of 'any'."),
                    Do_not_transform_or_elide_any_imports_or_exports_not_marked_as_type_only_ensuring_they_are_written_in_the_output_file_s_format_based_on_the_module_setting: diag(6804, 3 /* Message */, "Do_not_transform_or_elide_any_imports_or_exports_not_marked_as_type_only_ensuring_they_are_written_i_6804", "Do not transform or elide any imports or exports not marked as type-only, ensuring they are written in the output file's format based on the 'module' setting."),
                    one_of_Colon: diag(6900, 3 /* Message */, "one_of_Colon_6900", "one of:"),
                    one_or_more_Colon: diag(6901, 3 /* Message */, "one_or_more_Colon_6901", "one or more:"),
                    type_Colon: diag(6902, 3 /* Message */, "type_Colon_6902", "type:"),
                    default_Colon: diag(6903, 3 /* Message */, "default_Colon_6903", "default:"),
                    module_system_or_esModuleInterop: diag(6904, 3 /* Message */, "module_system_or_esModuleInterop_6904", 'module === "system" or esModuleInterop'),
                    false_unless_strict_is_set: diag(6905, 3 /* Message */, "false_unless_strict_is_set_6905", "`false`, unless `strict` is set"),
                    false_unless_composite_is_set: diag(6906, 3 /* Message */, "false_unless_composite_is_set_6906", "`false`, unless `composite` is set"),
                    node_modules_bower_components_jspm_packages_plus_the_value_of_outDir_if_one_is_specified: diag(6907, 3 /* Message */, "node_modules_bower_components_jspm_packages_plus_the_value_of_outDir_if_one_is_specified_6907", '`["node_modules", "bower_components", "jspm_packages"]`, plus the value of `outDir` if one is specified.'),
                    if_files_is_specified_otherwise_Asterisk_Asterisk_Slash_Asterisk: diag(6908, 3 /* Message */, "if_files_is_specified_otherwise_Asterisk_Asterisk_Slash_Asterisk_6908", '`[]` if `files` is specified, otherwise `["**/*"]`'),
                    true_if_composite_false_otherwise: diag(6909, 3 /* Message */, "true_if_composite_false_otherwise_6909", "`true` if `composite`, `false` otherwise"),
                    module_AMD_or_UMD_or_System_or_ES6_then_Classic_Otherwise_Node: diag(69010, 3 /* Message */, "module_AMD_or_UMD_or_System_or_ES6_then_Classic_Otherwise_Node_69010", "module === `AMD` or `UMD` or `System` or `ES6`, then `Classic`, Otherwise `Node`"),
                    Computed_from_the_list_of_input_files: diag(6911, 3 /* Message */, "Computed_from_the_list_of_input_files_6911", "Computed from the list of input files"),
                    Platform_specific: diag(6912, 3 /* Message */, "Platform_specific_6912", "Platform specific"),
                    You_can_learn_about_all_of_the_compiler_options_at_0: diag(6913, 3 /* Message */, "You_can_learn_about_all_of_the_compiler_options_at_0_6913", "You can learn about all of the compiler options at {0}"),
                    Including_watch_w_will_start_watching_the_current_project_for_the_file_changes_Once_set_you_can_config_watch_mode_with_Colon: diag(6914, 3 /* Message */, "Including_watch_w_will_start_watching_the_current_project_for_the_file_changes_Once_set_you_can_conf_6914", "Including --watch, -w will start watching the current project for the file changes. Once set, you can config watch mode with:"),
                    Using_build_b_will_make_tsc_behave_more_like_a_build_orchestrator_than_a_compiler_This_is_used_to_trigger_building_composite_projects_which_you_can_learn_more_about_at_0: diag(6915, 3 /* Message */, "Using_build_b_will_make_tsc_behave_more_like_a_build_orchestrator_than_a_compiler_This_is_used_to_tr_6915", "Using --build, -b will make tsc behave more like a build orchestrator than a compiler. This is used to trigger building composite projects which you can learn more about at {0}"),
                    COMMON_COMMANDS: diag(6916, 3 /* Message */, "COMMON_COMMANDS_6916", "COMMON COMMANDS"),
                    ALL_COMPILER_OPTIONS: diag(6917, 3 /* Message */, "ALL_COMPILER_OPTIONS_6917", "ALL COMPILER OPTIONS"),
                    WATCH_OPTIONS: diag(6918, 3 /* Message */, "WATCH_OPTIONS_6918", "WATCH OPTIONS"),
                    BUILD_OPTIONS: diag(6919, 3 /* Message */, "BUILD_OPTIONS_6919", "BUILD OPTIONS"),
                    COMMON_COMPILER_OPTIONS: diag(6920, 3 /* Message */, "COMMON_COMPILER_OPTIONS_6920", "COMMON COMPILER OPTIONS"),
                    COMMAND_LINE_FLAGS: diag(6921, 3 /* Message */, "COMMAND_LINE_FLAGS_6921", "COMMAND LINE FLAGS"),
                    tsc_Colon_The_TypeScript_Compiler: diag(6922, 3 /* Message */, "tsc_Colon_The_TypeScript_Compiler_6922", "tsc: The TypeScript Compiler"),
                    Compiles_the_current_project_tsconfig_json_in_the_working_directory: diag(6923, 3 /* Message */, "Compiles_the_current_project_tsconfig_json_in_the_working_directory_6923", "Compiles the current project (tsconfig.json in the working directory.)"),
                    Ignoring_tsconfig_json_compiles_the_specified_files_with_default_compiler_options: diag(6924, 3 /* Message */, "Ignoring_tsconfig_json_compiles_the_specified_files_with_default_compiler_options_6924", "Ignoring tsconfig.json, compiles the specified files with default compiler options."),
                    Build_a_composite_project_in_the_working_directory: diag(6925, 3 /* Message */, "Build_a_composite_project_in_the_working_directory_6925", "Build a composite project in the working directory."),
                    Creates_a_tsconfig_json_with_the_recommended_settings_in_the_working_directory: diag(6926, 3 /* Message */, "Creates_a_tsconfig_json_with_the_recommended_settings_in_the_working_directory_6926", "Creates a tsconfig.json with the recommended settings in the working directory."),
                    Compiles_the_TypeScript_project_located_at_the_specified_path: diag(6927, 3 /* Message */, "Compiles_the_TypeScript_project_located_at_the_specified_path_6927", "Compiles the TypeScript project located at the specified path."),
                    An_expanded_version_of_this_information_showing_all_possible_compiler_options: diag(6928, 3 /* Message */, "An_expanded_version_of_this_information_showing_all_possible_compiler_options_6928", "An expanded version of this information, showing all possible compiler options"),
                    Compiles_the_current_project_with_additional_settings: diag(6929, 3 /* Message */, "Compiles_the_current_project_with_additional_settings_6929", "Compiles the current project, with additional settings."),
                    true_for_ES2022_and_above_including_ESNext: diag(6930, 3 /* Message */, "true_for_ES2022_and_above_including_ESNext_6930", "`true` for ES2022 and above, including ESNext."),
                    List_of_file_name_suffixes_to_search_when_resolving_a_module: diag(6931, 1 /* Error */, "List_of_file_name_suffixes_to_search_when_resolving_a_module_6931", "List of file name suffixes to search when resolving a module."),
                    Variable_0_implicitly_has_an_1_type: diag(7005, 1 /* Error */, "Variable_0_implicitly_has_an_1_type_7005", "Variable '{0}' implicitly has an '{1}' type."),
                    Parameter_0_implicitly_has_an_1_type: diag(7006, 1 /* Error */, "Parameter_0_implicitly_has_an_1_type_7006", "Parameter '{0}' implicitly has an '{1}' type."),
                    Member_0_implicitly_has_an_1_type: diag(7008, 1 /* Error */, "Member_0_implicitly_has_an_1_type_7008", "Member '{0}' implicitly has an '{1}' type."),
                    new_expression_whose_target_lacks_a_construct_signature_implicitly_has_an_any_type: diag(7009, 1 /* Error */, "new_expression_whose_target_lacks_a_construct_signature_implicitly_has_an_any_type_7009", "'new' expression, whose target lacks a construct signature, implicitly has an 'any' type."),
                    _0_which_lacks_return_type_annotation_implicitly_has_an_1_return_type: diag(7010, 1 /* Error */, "_0_which_lacks_return_type_annotation_implicitly_has_an_1_return_type_7010", "'{0}', which lacks return-type annotation, implicitly has an '{1}' return type."),
                    Function_expression_which_lacks_return_type_annotation_implicitly_has_an_0_return_type: diag(7011, 1 /* Error */, "Function_expression_which_lacks_return_type_annotation_implicitly_has_an_0_return_type_7011", "Function expression, which lacks return-type annotation, implicitly has an '{0}' return type."),
                    This_overload_implicitly_returns_the_type_0_because_it_lacks_a_return_type_annotation: diag(7012, 1 /* Error */, "This_overload_implicitly_returns_the_type_0_because_it_lacks_a_return_type_annotation_7012", "This overload implicitly returns the type '{0}' because it lacks a return type annotation."),
                    Construct_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type: diag(7013, 1 /* Error */, "Construct_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type_7013", "Construct signature, which lacks return-type annotation, implicitly has an 'any' return type."),
                    Function_type_which_lacks_return_type_annotation_implicitly_has_an_0_return_type: diag(7014, 1 /* Error */, "Function_type_which_lacks_return_type_annotation_implicitly_has_an_0_return_type_7014", "Function type, which lacks return-type annotation, implicitly has an '{0}' return type."),
                    Element_implicitly_has_an_any_type_because_index_expression_is_not_of_type_number: diag(7015, 1 /* Error */, "Element_implicitly_has_an_any_type_because_index_expression_is_not_of_type_number_7015", "Element implicitly has an 'any' type because index expression is not of type 'number'."),
                    Could_not_find_a_declaration_file_for_module_0_1_implicitly_has_an_any_type: diag(7016, 1 /* Error */, "Could_not_find_a_declaration_file_for_module_0_1_implicitly_has_an_any_type_7016", "Could not find a declaration file for module '{0}'. '{1}' implicitly has an 'any' type."),
                    Element_implicitly_has_an_any_type_because_type_0_has_no_index_signature: diag(7017, 1 /* Error */, "Element_implicitly_has_an_any_type_because_type_0_has_no_index_signature_7017", "Element implicitly has an 'any' type because type '{0}' has no index signature."),
                    Object_literal_s_property_0_implicitly_has_an_1_type: diag(7018, 1 /* Error */, "Object_literal_s_property_0_implicitly_has_an_1_type_7018", "Object literal's property '{0}' implicitly has an '{1}' type."),
                    Rest_parameter_0_implicitly_has_an_any_type: diag(7019, 1 /* Error */, "Rest_parameter_0_implicitly_has_an_any_type_7019", "Rest parameter '{0}' implicitly has an 'any[]' type."),
                    Call_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type: diag(7020, 1 /* Error */, "Call_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type_7020", "Call signature, which lacks return-type annotation, implicitly has an 'any' return type."),
                    _0_implicitly_has_type_any_because_it_does_not_have_a_type_annotation_and_is_referenced_directly_or_indirectly_in_its_own_initializer: diag(7022, 1 /* Error */, "_0_implicitly_has_type_any_because_it_does_not_have_a_type_annotation_and_is_referenced_directly_or__7022", "'{0}' implicitly has type 'any' because it does not have a type annotation and is referenced directly or indirectly in its own initializer."),
                    _0_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_referenced_directly_or_indirectly_in_one_of_its_return_expressions: diag(7023, 1 /* Error */, "_0_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_reference_7023", "'{0}' implicitly has return type 'any' because it does not have a return type annotation and is referenced directly or indirectly in one of its return expressions."),
                    Function_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_referenced_directly_or_indirectly_in_one_of_its_return_expressions: diag(7024, 1 /* Error */, "Function_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_ref_7024", "Function implicitly has return type 'any' because it does not have a return type annotation and is referenced directly or indirectly in one of its return expressions."),
                    Generator_implicitly_has_yield_type_0_because_it_does_not_yield_any_values_Consider_supplying_a_return_type_annotation: diag(7025, 1 /* Error */, "Generator_implicitly_has_yield_type_0_because_it_does_not_yield_any_values_Consider_supplying_a_retu_7025", "Generator implicitly has yield type '{0}' because it does not yield any values. Consider supplying a return type annotation."),
                    JSX_element_implicitly_has_type_any_because_no_interface_JSX_0_exists: diag(7026, 1 /* Error */, "JSX_element_implicitly_has_type_any_because_no_interface_JSX_0_exists_7026", "JSX element implicitly has type 'any' because no interface 'JSX.{0}' exists."),
                    Unreachable_code_detected: diag(7027, 1 /* Error */, "Unreachable_code_detected_7027", "Unreachable code detected.", 
                    /*reportsUnnecessary*/
                    true),
                    Unused_label: diag(7028, 1 /* Error */, "Unused_label_7028", "Unused label.", 
                    /*reportsUnnecessary*/
                    true),
                    Fallthrough_case_in_switch: diag(7029, 1 /* Error */, "Fallthrough_case_in_switch_7029", "Fallthrough case in switch."),
                    Not_all_code_paths_return_a_value: diag(7030, 1 /* Error */, "Not_all_code_paths_return_a_value_7030", "Not all code paths return a value."),
                    Binding_element_0_implicitly_has_an_1_type: diag(7031, 1 /* Error */, "Binding_element_0_implicitly_has_an_1_type_7031", "Binding element '{0}' implicitly has an '{1}' type."),
                    Property_0_implicitly_has_type_any_because_its_set_accessor_lacks_a_parameter_type_annotation: diag(7032, 1 /* Error */, "Property_0_implicitly_has_type_any_because_its_set_accessor_lacks_a_parameter_type_annotation_7032", "Property '{0}' implicitly has type 'any', because its set accessor lacks a parameter type annotation."),
                    Property_0_implicitly_has_type_any_because_its_get_accessor_lacks_a_return_type_annotation: diag(7033, 1 /* Error */, "Property_0_implicitly_has_type_any_because_its_get_accessor_lacks_a_return_type_annotation_7033", "Property '{0}' implicitly has type 'any', because its get accessor lacks a return type annotation."),
                    Variable_0_implicitly_has_type_1_in_some_locations_where_its_type_cannot_be_determined: diag(7034, 1 /* Error */, "Variable_0_implicitly_has_type_1_in_some_locations_where_its_type_cannot_be_determined_7034", "Variable '{0}' implicitly has type '{1}' in some locations where its type cannot be determined."),
                    Try_npm_i_save_dev_types_Slash_1_if_it_exists_or_add_a_new_declaration_d_ts_file_containing_declare_module_0: diag(7035, 1 /* Error */, "Try_npm_i_save_dev_types_Slash_1_if_it_exists_or_add_a_new_declaration_d_ts_file_containing_declare__7035", "Try `npm i --save-dev @types/{1}` if it exists or add a new declaration (.d.ts) file containing `declare module '{0}';`"),
                    Dynamic_import_s_specifier_must_be_of_type_string_but_here_has_type_0: diag(7036, 1 /* Error */, "Dynamic_import_s_specifier_must_be_of_type_string_but_here_has_type_0_7036", "Dynamic import's specifier must be of type 'string', but here has type '{0}'."),
                    Enables_emit_interoperability_between_CommonJS_and_ES_Modules_via_creation_of_namespace_objects_for_all_imports_Implies_allowSyntheticDefaultImports: diag(7037, 3 /* Message */, "Enables_emit_interoperability_between_CommonJS_and_ES_Modules_via_creation_of_namespace_objects_for__7037", "Enables emit interoperability between CommonJS and ES Modules via creation of namespace objects for all imports. Implies 'allowSyntheticDefaultImports'."),
                    Type_originates_at_this_import_A_namespace_style_import_cannot_be_called_or_constructed_and_will_cause_a_failure_at_runtime_Consider_using_a_default_import_or_import_require_here_instead: diag(7038, 3 /* Message */, "Type_originates_at_this_import_A_namespace_style_import_cannot_be_called_or_constructed_and_will_cau_7038", "Type originates at this import. A namespace-style import cannot be called or constructed, and will cause a failure at runtime. Consider using a default import or import require here instead."),
                    Mapped_object_type_implicitly_has_an_any_template_type: diag(7039, 1 /* Error */, "Mapped_object_type_implicitly_has_an_any_template_type_7039", "Mapped object type implicitly has an 'any' template type."),
                    If_the_0_package_actually_exposes_this_module_consider_sending_a_pull_request_to_amend_https_Colon_Slash_Slashgithub_com_SlashDefinitelyTyped_SlashDefinitelyTyped_Slashtree_Slashmaster_Slashtypes_Slash_1: diag(7040, 1 /* Error */, "If_the_0_package_actually_exposes_this_module_consider_sending_a_pull_request_to_amend_https_Colon_S_7040", "If the '{0}' package actually exposes this module, consider sending a pull request to amend 'https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/{1}'"),
                    The_containing_arrow_function_captures_the_global_value_of_this: diag(7041, 1 /* Error */, "The_containing_arrow_function_captures_the_global_value_of_this_7041", "The containing arrow function captures the global value of 'this'."),
                    Module_0_was_resolved_to_1_but_resolveJsonModule_is_not_used: diag(7042, 1 /* Error */, "Module_0_was_resolved_to_1_but_resolveJsonModule_is_not_used_7042", "Module '{0}' was resolved to '{1}', but '--resolveJsonModule' is not used."),
                    Variable_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage: diag(7043, 2 /* Suggestion */, "Variable_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage_7043", "Variable '{0}' implicitly has an '{1}' type, but a better type may be inferred from usage."),
                    Parameter_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage: diag(7044, 2 /* Suggestion */, "Parameter_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage_7044", "Parameter '{0}' implicitly has an '{1}' type, but a better type may be inferred from usage."),
                    Member_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage: diag(7045, 2 /* Suggestion */, "Member_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage_7045", "Member '{0}' implicitly has an '{1}' type, but a better type may be inferred from usage."),
                    Variable_0_implicitly_has_type_1_in_some_locations_but_a_better_type_may_be_inferred_from_usage: diag(7046, 2 /* Suggestion */, "Variable_0_implicitly_has_type_1_in_some_locations_but_a_better_type_may_be_inferred_from_usage_7046", "Variable '{0}' implicitly has type '{1}' in some locations, but a better type may be inferred from usage."),
                    Rest_parameter_0_implicitly_has_an_any_type_but_a_better_type_may_be_inferred_from_usage: diag(7047, 2 /* Suggestion */, "Rest_parameter_0_implicitly_has_an_any_type_but_a_better_type_may_be_inferred_from_usage_7047", "Rest parameter '{0}' implicitly has an 'any[]' type, but a better type may be inferred from usage."),
                    Property_0_implicitly_has_type_any_but_a_better_type_for_its_get_accessor_may_be_inferred_from_usage: diag(7048, 2 /* Suggestion */, "Property_0_implicitly_has_type_any_but_a_better_type_for_its_get_accessor_may_be_inferred_from_usage_7048", "Property '{0}' implicitly has type 'any', but a better type for its get accessor may be inferred from usage."),
                    Property_0_implicitly_has_type_any_but_a_better_type_for_its_set_accessor_may_be_inferred_from_usage: diag(7049, 2 /* Suggestion */, "Property_0_implicitly_has_type_any_but_a_better_type_for_its_set_accessor_may_be_inferred_from_usage_7049", "Property '{0}' implicitly has type 'any', but a better type for its set accessor may be inferred from usage."),
                    _0_implicitly_has_an_1_return_type_but_a_better_type_may_be_inferred_from_usage: diag(7050, 2 /* Suggestion */, "_0_implicitly_has_an_1_return_type_but_a_better_type_may_be_inferred_from_usage_7050", "'{0}' implicitly has an '{1}' return type, but a better type may be inferred from usage."),
                    Parameter_has_a_name_but_no_type_Did_you_mean_0_Colon_1: diag(7051, 1 /* Error */, "Parameter_has_a_name_but_no_type_Did_you_mean_0_Colon_1_7051", "Parameter has a name but no type. Did you mean '{0}: {1}'?"),
                    Element_implicitly_has_an_any_type_because_type_0_has_no_index_signature_Did_you_mean_to_call_1: diag(7052, 1 /* Error */, "Element_implicitly_has_an_any_type_because_type_0_has_no_index_signature_Did_you_mean_to_call_1_7052", "Element implicitly has an 'any' type because type '{0}' has no index signature. Did you mean to call '{1}'?"),
                    Element_implicitly_has_an_any_type_because_expression_of_type_0_can_t_be_used_to_index_type_1: diag(7053, 1 /* Error */, "Element_implicitly_has_an_any_type_because_expression_of_type_0_can_t_be_used_to_index_type_1_7053", "Element implicitly has an 'any' type because expression of type '{0}' can't be used to index type '{1}'."),
                    No_index_signature_with_a_parameter_of_type_0_was_found_on_type_1: diag(7054, 1 /* Error */, "No_index_signature_with_a_parameter_of_type_0_was_found_on_type_1_7054", "No index signature with a parameter of type '{0}' was found on type '{1}'."),
                    _0_which_lacks_return_type_annotation_implicitly_has_an_1_yield_type: diag(7055, 1 /* Error */, "_0_which_lacks_return_type_annotation_implicitly_has_an_1_yield_type_7055", "'{0}', which lacks return-type annotation, implicitly has an '{1}' yield type."),
                    The_inferred_type_of_this_node_exceeds_the_maximum_length_the_compiler_will_serialize_An_explicit_type_annotation_is_needed: diag(7056, 1 /* Error */, "The_inferred_type_of_this_node_exceeds_the_maximum_length_the_compiler_will_serialize_An_explicit_ty_7056", "The inferred type of this node exceeds the maximum length the compiler will serialize. An explicit type annotation is needed."),
                    yield_expression_implicitly_results_in_an_any_type_because_its_containing_generator_lacks_a_return_type_annotation: diag(7057, 1 /* Error */, "yield_expression_implicitly_results_in_an_any_type_because_its_containing_generator_lacks_a_return_t_7057", "'yield' expression implicitly results in an 'any' type because its containing generator lacks a return-type annotation."),
                    If_the_0_package_actually_exposes_this_module_try_adding_a_new_declaration_d_ts_file_containing_declare_module_1: diag(7058, 1 /* Error */, "If_the_0_package_actually_exposes_this_module_try_adding_a_new_declaration_d_ts_file_containing_decl_7058", "If the '{0}' package actually exposes this module, try adding a new declaration (.d.ts) file containing `declare module '{1}';`"),
                    This_syntax_is_reserved_in_files_with_the_mts_or_cts_extension_Use_an_as_expression_instead: diag(7059, 1 /* Error */, "This_syntax_is_reserved_in_files_with_the_mts_or_cts_extension_Use_an_as_expression_instead_7059", "This syntax is reserved in files with the .mts or .cts extension. Use an `as` expression instead."),
                    This_syntax_is_reserved_in_files_with_the_mts_or_cts_extension_Add_a_trailing_comma_or_explicit_constraint: diag(7060, 1 /* Error */, "This_syntax_is_reserved_in_files_with_the_mts_or_cts_extension_Add_a_trailing_comma_or_explicit_cons_7060", "This syntax is reserved in files with the .mts or .cts extension. Add a trailing comma or explicit constraint."),
                    A_mapped_type_may_not_declare_properties_or_methods: diag(7061, 1 /* Error */, "A_mapped_type_may_not_declare_properties_or_methods_7061", "A mapped type may not declare properties or methods."),
                    You_cannot_rename_this_element: diag(8e3, 1 /* Error */, "You_cannot_rename_this_element_8000", "You cannot rename this element."),
                    You_cannot_rename_elements_that_are_defined_in_the_standard_TypeScript_library: diag(8001, 1 /* Error */, "You_cannot_rename_elements_that_are_defined_in_the_standard_TypeScript_library_8001", "You cannot rename elements that are defined in the standard TypeScript library."),
                    import_can_only_be_used_in_TypeScript_files: diag(8002, 1 /* Error */, "import_can_only_be_used_in_TypeScript_files_8002", "'import ... =' can only be used in TypeScript files."),
                    export_can_only_be_used_in_TypeScript_files: diag(8003, 1 /* Error */, "export_can_only_be_used_in_TypeScript_files_8003", "'export =' can only be used in TypeScript files."),
                    Type_parameter_declarations_can_only_be_used_in_TypeScript_files: diag(8004, 1 /* Error */, "Type_parameter_declarations_can_only_be_used_in_TypeScript_files_8004", "Type parameter declarations can only be used in TypeScript files."),
                    implements_clauses_can_only_be_used_in_TypeScript_files: diag(8005, 1 /* Error */, "implements_clauses_can_only_be_used_in_TypeScript_files_8005", "'implements' clauses can only be used in TypeScript files."),
                    _0_declarations_can_only_be_used_in_TypeScript_files: diag(8006, 1 /* Error */, "_0_declarations_can_only_be_used_in_TypeScript_files_8006", "'{0}' declarations can only be used in TypeScript files."),
                    Type_aliases_can_only_be_used_in_TypeScript_files: diag(8008, 1 /* Error */, "Type_aliases_can_only_be_used_in_TypeScript_files_8008", "Type aliases can only be used in TypeScript files."),
                    The_0_modifier_can_only_be_used_in_TypeScript_files: diag(8009, 1 /* Error */, "The_0_modifier_can_only_be_used_in_TypeScript_files_8009", "The '{0}' modifier can only be used in TypeScript files."),
                    Type_annotations_can_only_be_used_in_TypeScript_files: diag(8010, 1 /* Error */, "Type_annotations_can_only_be_used_in_TypeScript_files_8010", "Type annotations can only be used in TypeScript files."),
                    Type_arguments_can_only_be_used_in_TypeScript_files: diag(8011, 1 /* Error */, "Type_arguments_can_only_be_used_in_TypeScript_files_8011", "Type arguments can only be used in TypeScript files."),
                    Parameter_modifiers_can_only_be_used_in_TypeScript_files: diag(8012, 1 /* Error */, "Parameter_modifiers_can_only_be_used_in_TypeScript_files_8012", "Parameter modifiers can only be used in TypeScript files."),
                    Non_null_assertions_can_only_be_used_in_TypeScript_files: diag(8013, 1 /* Error */, "Non_null_assertions_can_only_be_used_in_TypeScript_files_8013", "Non-null assertions can only be used in TypeScript files."),
                    Type_assertion_expressions_can_only_be_used_in_TypeScript_files: diag(8016, 1 /* Error */, "Type_assertion_expressions_can_only_be_used_in_TypeScript_files_8016", "Type assertion expressions can only be used in TypeScript files."),
                    Signature_declarations_can_only_be_used_in_TypeScript_files: diag(8017, 1 /* Error */, "Signature_declarations_can_only_be_used_in_TypeScript_files_8017", "Signature declarations can only be used in TypeScript files."),
                    Report_errors_in_js_files: diag(8019, 3 /* Message */, "Report_errors_in_js_files_8019", "Report errors in .js files."),
                    JSDoc_types_can_only_be_used_inside_documentation_comments: diag(8020, 1 /* Error */, "JSDoc_types_can_only_be_used_inside_documentation_comments_8020", "JSDoc types can only be used inside documentation comments."),
                    JSDoc_typedef_tag_should_either_have_a_type_annotation_or_be_followed_by_property_or_member_tags: diag(8021, 1 /* Error */, "JSDoc_typedef_tag_should_either_have_a_type_annotation_or_be_followed_by_property_or_member_tags_8021", "JSDoc '@typedef' tag should either have a type annotation or be followed by '@property' or '@member' tags."),
                    JSDoc_0_is_not_attached_to_a_class: diag(8022, 1 /* Error */, "JSDoc_0_is_not_attached_to_a_class_8022", "JSDoc '@{0}' is not attached to a class."),
                    JSDoc_0_1_does_not_match_the_extends_2_clause: diag(8023, 1 /* Error */, "JSDoc_0_1_does_not_match_the_extends_2_clause_8023", "JSDoc '@{0} {1}' does not match the 'extends {2}' clause."),
                    JSDoc_param_tag_has_name_0_but_there_is_no_parameter_with_that_name: diag(8024, 1 /* Error */, "JSDoc_param_tag_has_name_0_but_there_is_no_parameter_with_that_name_8024", "JSDoc '@param' tag has name '{0}', but there is no parameter with that name."),
                    Class_declarations_cannot_have_more_than_one_augments_or_extends_tag: diag(8025, 1 /* Error */, "Class_declarations_cannot_have_more_than_one_augments_or_extends_tag_8025", "Class declarations cannot have more than one '@augments' or '@extends' tag."),
                    Expected_0_type_arguments_provide_these_with_an_extends_tag: diag(8026, 1 /* Error */, "Expected_0_type_arguments_provide_these_with_an_extends_tag_8026", "Expected {0} type arguments; provide these with an '@extends' tag."),
                    Expected_0_1_type_arguments_provide_these_with_an_extends_tag: diag(8027, 1 /* Error */, "Expected_0_1_type_arguments_provide_these_with_an_extends_tag_8027", "Expected {0}-{1} type arguments; provide these with an '@extends' tag."),
                    JSDoc_may_only_appear_in_the_last_parameter_of_a_signature: diag(8028, 1 /* Error */, "JSDoc_may_only_appear_in_the_last_parameter_of_a_signature_8028", "JSDoc '...' may only appear in the last parameter of a signature."),
                    JSDoc_param_tag_has_name_0_but_there_is_no_parameter_with_that_name_It_would_match_arguments_if_it_had_an_array_type: diag(8029, 1 /* Error */, "JSDoc_param_tag_has_name_0_but_there_is_no_parameter_with_that_name_It_would_match_arguments_if_it_h_8029", "JSDoc '@param' tag has name '{0}', but there is no parameter with that name. It would match 'arguments' if it had an array type."),
                    The_type_of_a_function_declaration_must_match_the_function_s_signature: diag(8030, 1 /* Error */, "The_type_of_a_function_declaration_must_match_the_function_s_signature_8030", "The type of a function declaration must match the function's signature."),
                    You_cannot_rename_a_module_via_a_global_import: diag(8031, 1 /* Error */, "You_cannot_rename_a_module_via_a_global_import_8031", "You cannot rename a module via a global import."),
                    Qualified_name_0_is_not_allowed_without_a_leading_param_object_1: diag(8032, 1 /* Error */, "Qualified_name_0_is_not_allowed_without_a_leading_param_object_1_8032", "Qualified name '{0}' is not allowed without a leading '@param {object} {1}'."),
                    A_JSDoc_typedef_comment_may_not_contain_multiple_type_tags: diag(8033, 1 /* Error */, "A_JSDoc_typedef_comment_may_not_contain_multiple_type_tags_8033", "A JSDoc '@typedef' comment may not contain multiple '@type' tags."),
                    The_tag_was_first_specified_here: diag(8034, 1 /* Error */, "The_tag_was_first_specified_here_8034", "The tag was first specified here."),
                    You_cannot_rename_elements_that_are_defined_in_a_node_modules_folder: diag(8035, 1 /* Error */, "You_cannot_rename_elements_that_are_defined_in_a_node_modules_folder_8035", "You cannot rename elements that are defined in a 'node_modules' folder."),
                    You_cannot_rename_elements_that_are_defined_in_another_node_modules_folder: diag(8036, 1 /* Error */, "You_cannot_rename_elements_that_are_defined_in_another_node_modules_folder_8036", "You cannot rename elements that are defined in another 'node_modules' folder."),
                    Type_satisfaction_expressions_can_only_be_used_in_TypeScript_files: diag(8037, 1 /* Error */, "Type_satisfaction_expressions_can_only_be_used_in_TypeScript_files_8037", "Type satisfaction expressions can only be used in TypeScript files."),
                    Decorators_may_not_appear_after_export_or_export_default_if_they_also_appear_before_export: diag(8038, 1 /* Error */, "Decorators_may_not_appear_after_export_or_export_default_if_they_also_appear_before_export_8038", "Decorators may not appear after 'export' or 'export default' if they also appear before 'export'."),
                    A_JSDoc_template_tag_may_not_follow_a_typedef_callback_or_overload_tag: diag(8039, 1 /* Error */, "A_JSDoc_template_tag_may_not_follow_a_typedef_callback_or_overload_tag_8039", "A JSDoc '@template' tag may not follow a '@typedef', '@callback', or '@overload' tag"),
                    Declaration_emit_for_this_file_requires_using_private_name_0_An_explicit_type_annotation_may_unblock_declaration_emit: diag(9005, 1 /* Error */, "Declaration_emit_for_this_file_requires_using_private_name_0_An_explicit_type_annotation_may_unblock_9005", "Declaration emit for this file requires using private name '{0}'. An explicit type annotation may unblock declaration emit."),
                    Declaration_emit_for_this_file_requires_using_private_name_0_from_module_1_An_explicit_type_annotation_may_unblock_declaration_emit: diag(9006, 1 /* Error */, "Declaration_emit_for_this_file_requires_using_private_name_0_from_module_1_An_explicit_type_annotati_9006", "Declaration emit for this file requires using private name '{0}' from module '{1}'. An explicit type annotation may unblock declaration emit."),
                    JSX_attributes_must_only_be_assigned_a_non_empty_expression: diag(17e3, 1 /* Error */, "JSX_attributes_must_only_be_assigned_a_non_empty_expression_17000", "JSX attributes must only be assigned a non-empty 'expression'."),
                    JSX_elements_cannot_have_multiple_attributes_with_the_same_name: diag(17001, 1 /* Error */, "JSX_elements_cannot_have_multiple_attributes_with_the_same_name_17001", "JSX elements cannot have multiple attributes with the same name."),
                    Expected_corresponding_JSX_closing_tag_for_0: diag(17002, 1 /* Error */, "Expected_corresponding_JSX_closing_tag_for_0_17002", "Expected corresponding JSX closing tag for '{0}'."),
                    Cannot_use_JSX_unless_the_jsx_flag_is_provided: diag(17004, 1 /* Error */, "Cannot_use_JSX_unless_the_jsx_flag_is_provided_17004", "Cannot use JSX unless the '--jsx' flag is provided."),
                    A_constructor_cannot_contain_a_super_call_when_its_class_extends_null: diag(17005, 1 /* Error */, "A_constructor_cannot_contain_a_super_call_when_its_class_extends_null_17005", "A constructor cannot contain a 'super' call when its class extends 'null'."),
                    An_unary_expression_with_the_0_operator_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_expression_Consider_enclosing_the_expression_in_parentheses: diag(17006, 1 /* Error */, "An_unary_expression_with_the_0_operator_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_ex_17006", "An unary expression with the '{0}' operator is not allowed in the left-hand side of an exponentiation expression. Consider enclosing the expression in parentheses."),
                    A_type_assertion_expression_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_expression_Consider_enclosing_the_expression_in_parentheses: diag(17007, 1 /* Error */, "A_type_assertion_expression_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_expression_Con_17007", "A type assertion expression is not allowed in the left-hand side of an exponentiation expression. Consider enclosing the expression in parentheses."),
                    JSX_element_0_has_no_corresponding_closing_tag: diag(17008, 1 /* Error */, "JSX_element_0_has_no_corresponding_closing_tag_17008", "JSX element '{0}' has no corresponding closing tag."),
                    super_must_be_called_before_accessing_this_in_the_constructor_of_a_derived_class: diag(17009, 1 /* Error */, "super_must_be_called_before_accessing_this_in_the_constructor_of_a_derived_class_17009", "'super' must be called before accessing 'this' in the constructor of a derived class."),
                    Unknown_type_acquisition_option_0: diag(17010, 1 /* Error */, "Unknown_type_acquisition_option_0_17010", "Unknown type acquisition option '{0}'."),
                    super_must_be_called_before_accessing_a_property_of_super_in_the_constructor_of_a_derived_class: diag(17011, 1 /* Error */, "super_must_be_called_before_accessing_a_property_of_super_in_the_constructor_of_a_derived_class_17011", "'super' must be called before accessing a property of 'super' in the constructor of a derived class."),
                    _0_is_not_a_valid_meta_property_for_keyword_1_Did_you_mean_2: diag(17012, 1 /* Error */, "_0_is_not_a_valid_meta_property_for_keyword_1_Did_you_mean_2_17012", "'{0}' is not a valid meta-property for keyword '{1}'. Did you mean '{2}'?"),
                    Meta_property_0_is_only_allowed_in_the_body_of_a_function_declaration_function_expression_or_constructor: diag(17013, 1 /* Error */, "Meta_property_0_is_only_allowed_in_the_body_of_a_function_declaration_function_expression_or_constru_17013", "Meta-property '{0}' is only allowed in the body of a function declaration, function expression, or constructor."),
                    JSX_fragment_has_no_corresponding_closing_tag: diag(17014, 1 /* Error */, "JSX_fragment_has_no_corresponding_closing_tag_17014", "JSX fragment has no corresponding closing tag."),
                    Expected_corresponding_closing_tag_for_JSX_fragment: diag(17015, 1 /* Error */, "Expected_corresponding_closing_tag_for_JSX_fragment_17015", "Expected corresponding closing tag for JSX fragment."),
                    The_jsxFragmentFactory_compiler_option_must_be_provided_to_use_JSX_fragments_with_the_jsxFactory_compiler_option: diag(17016, 1 /* Error */, "The_jsxFragmentFactory_compiler_option_must_be_provided_to_use_JSX_fragments_with_the_jsxFactory_com_17016", "The 'jsxFragmentFactory' compiler option must be provided to use JSX fragments with the 'jsxFactory' compiler option."),
                    An_jsxFrag_pragma_is_required_when_using_an_jsx_pragma_with_JSX_fragments: diag(17017, 1 /* Error */, "An_jsxFrag_pragma_is_required_when_using_an_jsx_pragma_with_JSX_fragments_17017", "An @jsxFrag pragma is required when using an @jsx pragma with JSX fragments."),
                    Unknown_type_acquisition_option_0_Did_you_mean_1: diag(17018, 1 /* Error */, "Unknown_type_acquisition_option_0_Did_you_mean_1_17018", "Unknown type acquisition option '{0}'. Did you mean '{1}'?"),
                    _0_at_the_end_of_a_type_is_not_valid_TypeScript_syntax_Did_you_mean_to_write_1: diag(17019, 1 /* Error */, "_0_at_the_end_of_a_type_is_not_valid_TypeScript_syntax_Did_you_mean_to_write_1_17019", "'{0}' at the end of a type is not valid TypeScript syntax. Did you mean to write '{1}'?"),
                    _0_at_the_start_of_a_type_is_not_valid_TypeScript_syntax_Did_you_mean_to_write_1: diag(17020, 1 /* Error */, "_0_at_the_start_of_a_type_is_not_valid_TypeScript_syntax_Did_you_mean_to_write_1_17020", "'{0}' at the start of a type is not valid TypeScript syntax. Did you mean to write '{1}'?"),
                    Unicode_escape_sequence_cannot_appear_here: diag(17021, 1 /* Error */, "Unicode_escape_sequence_cannot_appear_here_17021", "Unicode escape sequence cannot appear here."),
                    Circularity_detected_while_resolving_configuration_Colon_0: diag(18e3, 1 /* Error */, "Circularity_detected_while_resolving_configuration_Colon_0_18000", "Circularity detected while resolving configuration: {0}"),
                    The_files_list_in_config_file_0_is_empty: diag(18002, 1 /* Error */, "The_files_list_in_config_file_0_is_empty_18002", "The 'files' list in config file '{0}' is empty."),
                    No_inputs_were_found_in_config_file_0_Specified_include_paths_were_1_and_exclude_paths_were_2: diag(18003, 1 /* Error */, "No_inputs_were_found_in_config_file_0_Specified_include_paths_were_1_and_exclude_paths_were_2_18003", "No inputs were found in config file '{0}'. Specified 'include' paths were '{1}' and 'exclude' paths were '{2}'."),
                    File_is_a_CommonJS_module_it_may_be_converted_to_an_ES_module: diag(80001, 2 /* Suggestion */, "File_is_a_CommonJS_module_it_may_be_converted_to_an_ES_module_80001", "File is a CommonJS module; it may be converted to an ES module."),
                    This_constructor_function_may_be_converted_to_a_class_declaration: diag(80002, 2 /* Suggestion */, "This_constructor_function_may_be_converted_to_a_class_declaration_80002", "This constructor function may be converted to a class declaration."),
                    Import_may_be_converted_to_a_default_import: diag(80003, 2 /* Suggestion */, "Import_may_be_converted_to_a_default_import_80003", "Import may be converted to a default import."),
                    JSDoc_types_may_be_moved_to_TypeScript_types: diag(80004, 2 /* Suggestion */, "JSDoc_types_may_be_moved_to_TypeScript_types_80004", "JSDoc types may be moved to TypeScript types."),
                    require_call_may_be_converted_to_an_import: diag(80005, 2 /* Suggestion */, "require_call_may_be_converted_to_an_import_80005", "'require' call may be converted to an import."),
                    This_may_be_converted_to_an_async_function: diag(80006, 2 /* Suggestion */, "This_may_be_converted_to_an_async_function_80006", "This may be converted to an async function."),
                    await_has_no_effect_on_the_type_of_this_expression: diag(80007, 2 /* Suggestion */, "await_has_no_effect_on_the_type_of_this_expression_80007", "'await' has no effect on the type of this expression."),
                    Numeric_literals_with_absolute_values_equal_to_2_53_or_greater_are_too_large_to_be_represented_accurately_as_integers: diag(80008, 2 /* Suggestion */, "Numeric_literals_with_absolute_values_equal_to_2_53_or_greater_are_too_large_to_be_represented_accur_80008", "Numeric literals with absolute values equal to 2^53 or greater are too large to be represented accurately as integers."),
                    JSDoc_typedef_may_be_converted_to_TypeScript_type: diag(80009, 2 /* Suggestion */, "JSDoc_typedef_may_be_converted_to_TypeScript_type_80009", "JSDoc typedef may be converted to TypeScript type."),
                    JSDoc_typedefs_may_be_converted_to_TypeScript_types: diag(80010, 2 /* Suggestion */, "JSDoc_typedefs_may_be_converted_to_TypeScript_types_80010", "JSDoc typedefs may be converted to TypeScript types."),
                    Add_missing_super_call: diag(90001, 3 /* Message */, "Add_missing_super_call_90001", "Add missing 'super()' call"),
                    Make_super_call_the_first_statement_in_the_constructor: diag(90002, 3 /* Message */, "Make_super_call_the_first_statement_in_the_constructor_90002", "Make 'super()' call the first statement in the constructor"),
                    Change_extends_to_implements: diag(90003, 3 /* Message */, "Change_extends_to_implements_90003", "Change 'extends' to 'implements'"),
                    Remove_unused_declaration_for_Colon_0: diag(90004, 3 /* Message */, "Remove_unused_declaration_for_Colon_0_90004", "Remove unused declaration for: '{0}'"),
                    Remove_import_from_0: diag(90005, 3 /* Message */, "Remove_import_from_0_90005", "Remove import from '{0}'"),
                    Implement_interface_0: diag(90006, 3 /* Message */, "Implement_interface_0_90006", "Implement interface '{0}'"),
                    Implement_inherited_abstract_class: diag(90007, 3 /* Message */, "Implement_inherited_abstract_class_90007", "Implement inherited abstract class"),
                    Add_0_to_unresolved_variable: diag(90008, 3 /* Message */, "Add_0_to_unresolved_variable_90008", "Add '{0}.' to unresolved variable"),
                    Remove_variable_statement: diag(90010, 3 /* Message */, "Remove_variable_statement_90010", "Remove variable statement"),
                    Remove_template_tag: diag(90011, 3 /* Message */, "Remove_template_tag_90011", "Remove template tag"),
                    Remove_type_parameters: diag(90012, 3 /* Message */, "Remove_type_parameters_90012", "Remove type parameters"),
                    Import_0_from_1: diag(90013, 3 /* Message */, "Import_0_from_1_90013", `Import '{0}' from "{1}"`),
                    Change_0_to_1: diag(90014, 3 /* Message */, "Change_0_to_1_90014", "Change '{0}' to '{1}'"),
                    Declare_property_0: diag(90016, 3 /* Message */, "Declare_property_0_90016", "Declare property '{0}'"),
                    Add_index_signature_for_property_0: diag(90017, 3 /* Message */, "Add_index_signature_for_property_0_90017", "Add index signature for property '{0}'"),
                    Disable_checking_for_this_file: diag(90018, 3 /* Message */, "Disable_checking_for_this_file_90018", "Disable checking for this file"),
                    Ignore_this_error_message: diag(90019, 3 /* Message */, "Ignore_this_error_message_90019", "Ignore this error message"),
                    Initialize_property_0_in_the_constructor: diag(90020, 3 /* Message */, "Initialize_property_0_in_the_constructor_90020", "Initialize property '{0}' in the constructor"),
                    Initialize_static_property_0: diag(90021, 3 /* Message */, "Initialize_static_property_0_90021", "Initialize static property '{0}'"),
                    Change_spelling_to_0: diag(90022, 3 /* Message */, "Change_spelling_to_0_90022", "Change spelling to '{0}'"),
                    Declare_method_0: diag(90023, 3 /* Message */, "Declare_method_0_90023", "Declare method '{0}'"),
                    Declare_static_method_0: diag(90024, 3 /* Message */, "Declare_static_method_0_90024", "Declare static method '{0}'"),
                    Prefix_0_with_an_underscore: diag(90025, 3 /* Message */, "Prefix_0_with_an_underscore_90025", "Prefix '{0}' with an underscore"),
                    Rewrite_as_the_indexed_access_type_0: diag(90026, 3 /* Message */, "Rewrite_as_the_indexed_access_type_0_90026", "Rewrite as the indexed access type '{0}'"),
                    Declare_static_property_0: diag(90027, 3 /* Message */, "Declare_static_property_0_90027", "Declare static property '{0}'"),
                    Call_decorator_expression: diag(90028, 3 /* Message */, "Call_decorator_expression_90028", "Call decorator expression"),
                    Add_async_modifier_to_containing_function: diag(90029, 3 /* Message */, "Add_async_modifier_to_containing_function_90029", "Add async modifier to containing function"),
                    Replace_infer_0_with_unknown: diag(90030, 3 /* Message */, "Replace_infer_0_with_unknown_90030", "Replace 'infer {0}' with 'unknown'"),
                    Replace_all_unused_infer_with_unknown: diag(90031, 3 /* Message */, "Replace_all_unused_infer_with_unknown_90031", "Replace all unused 'infer' with 'unknown'"),
                    Add_parameter_name: diag(90034, 3 /* Message */, "Add_parameter_name_90034", "Add parameter name"),
                    Declare_private_property_0: diag(90035, 3 /* Message */, "Declare_private_property_0_90035", "Declare private property '{0}'"),
                    Replace_0_with_Promise_1: diag(90036, 3 /* Message */, "Replace_0_with_Promise_1_90036", "Replace '{0}' with 'Promise<{1}>'"),
                    Fix_all_incorrect_return_type_of_an_async_functions: diag(90037, 3 /* Message */, "Fix_all_incorrect_return_type_of_an_async_functions_90037", "Fix all incorrect return type of an async functions"),
                    Declare_private_method_0: diag(90038, 3 /* Message */, "Declare_private_method_0_90038", "Declare private method '{0}'"),
                    Remove_unused_destructuring_declaration: diag(90039, 3 /* Message */, "Remove_unused_destructuring_declaration_90039", "Remove unused destructuring declaration"),
                    Remove_unused_declarations_for_Colon_0: diag(90041, 3 /* Message */, "Remove_unused_declarations_for_Colon_0_90041", "Remove unused declarations for: '{0}'"),
                    Declare_a_private_field_named_0: diag(90053, 3 /* Message */, "Declare_a_private_field_named_0_90053", "Declare a private field named '{0}'."),
                    Includes_imports_of_types_referenced_by_0: diag(90054, 3 /* Message */, "Includes_imports_of_types_referenced_by_0_90054", "Includes imports of types referenced by '{0}'"),
                    Remove_type_from_import_declaration_from_0: diag(90055, 3 /* Message */, "Remove_type_from_import_declaration_from_0_90055", `Remove 'type' from import declaration from "{0}"`),
                    Remove_type_from_import_of_0_from_1: diag(90056, 3 /* Message */, "Remove_type_from_import_of_0_from_1_90056", `Remove 'type' from import of '{0}' from "{1}"`),
                    Add_import_from_0: diag(90057, 3 /* Message */, "Add_import_from_0_90057", 'Add import from "{0}"'),
                    Update_import_from_0: diag(90058, 3 /* Message */, "Update_import_from_0_90058", 'Update import from "{0}"'),
                    Export_0_from_module_1: diag(90059, 3 /* Message */, "Export_0_from_module_1_90059", "Export '{0}' from module '{1}'"),
                    Export_all_referenced_locals: diag(90060, 3 /* Message */, "Export_all_referenced_locals_90060", "Export all referenced locals"),
                    Convert_function_to_an_ES2015_class: diag(95001, 3 /* Message */, "Convert_function_to_an_ES2015_class_95001", "Convert function to an ES2015 class"),
                    Convert_0_to_1_in_0: diag(95003, 3 /* Message */, "Convert_0_to_1_in_0_95003", "Convert '{0}' to '{1} in {0}'"),
                    Extract_to_0_in_1: diag(95004, 3 /* Message */, "Extract_to_0_in_1_95004", "Extract to {0} in {1}"),
                    Extract_function: diag(95005, 3 /* Message */, "Extract_function_95005", "Extract function"),
                    Extract_constant: diag(95006, 3 /* Message */, "Extract_constant_95006", "Extract constant"),
                    Extract_to_0_in_enclosing_scope: diag(95007, 3 /* Message */, "Extract_to_0_in_enclosing_scope_95007", "Extract to {0} in enclosing scope"),
                    Extract_to_0_in_1_scope: diag(95008, 3 /* Message */, "Extract_to_0_in_1_scope_95008", "Extract to {0} in {1} scope"),
                    Annotate_with_type_from_JSDoc: diag(95009, 3 /* Message */, "Annotate_with_type_from_JSDoc_95009", "Annotate with type from JSDoc"),
                    Infer_type_of_0_from_usage: diag(95011, 3 /* Message */, "Infer_type_of_0_from_usage_95011", "Infer type of '{0}' from usage"),
                    Infer_parameter_types_from_usage: diag(95012, 3 /* Message */, "Infer_parameter_types_from_usage_95012", "Infer parameter types from usage"),
                    Convert_to_default_import: diag(95013, 3 /* Message */, "Convert_to_default_import_95013", "Convert to default import"),
                    Install_0: diag(95014, 3 /* Message */, "Install_0_95014", "Install '{0}'"),
                    Replace_import_with_0: diag(95015, 3 /* Message */, "Replace_import_with_0_95015", "Replace import with '{0}'."),
                    Use_synthetic_default_member: diag(95016, 3 /* Message */, "Use_synthetic_default_member_95016", "Use synthetic 'default' member."),
                    Convert_to_ES_module: diag(95017, 3 /* Message */, "Convert_to_ES_module_95017", "Convert to ES module"),
                    Add_undefined_type_to_property_0: diag(95018, 3 /* Message */, "Add_undefined_type_to_property_0_95018", "Add 'undefined' type to property '{0}'"),
                    Add_initializer_to_property_0: diag(95019, 3 /* Message */, "Add_initializer_to_property_0_95019", "Add initializer to property '{0}'"),
                    Add_definite_assignment_assertion_to_property_0: diag(95020, 3 /* Message */, "Add_definite_assignment_assertion_to_property_0_95020", "Add definite assignment assertion to property '{0}'"),
                    Convert_all_type_literals_to_mapped_type: diag(95021, 3 /* Message */, "Convert_all_type_literals_to_mapped_type_95021", "Convert all type literals to mapped type"),
                    Add_all_missing_members: diag(95022, 3 /* Message */, "Add_all_missing_members_95022", "Add all missing members"),
                    Infer_all_types_from_usage: diag(95023, 3 /* Message */, "Infer_all_types_from_usage_95023", "Infer all types from usage"),
                    Delete_all_unused_declarations: diag(95024, 3 /* Message */, "Delete_all_unused_declarations_95024", "Delete all unused declarations"),
                    Prefix_all_unused_declarations_with_where_possible: diag(95025, 3 /* Message */, "Prefix_all_unused_declarations_with_where_possible_95025", "Prefix all unused declarations with '_' where possible"),
                    Fix_all_detected_spelling_errors: diag(95026, 3 /* Message */, "Fix_all_detected_spelling_errors_95026", "Fix all detected spelling errors"),
                    Add_initializers_to_all_uninitialized_properties: diag(95027, 3 /* Message */, "Add_initializers_to_all_uninitialized_properties_95027", "Add initializers to all uninitialized properties"),
                    Add_definite_assignment_assertions_to_all_uninitialized_properties: diag(95028, 3 /* Message */, "Add_definite_assignment_assertions_to_all_uninitialized_properties_95028", "Add definite assignment assertions to all uninitialized properties"),
                    Add_undefined_type_to_all_uninitialized_properties: diag(95029, 3 /* Message */, "Add_undefined_type_to_all_uninitialized_properties_95029", "Add undefined type to all uninitialized properties"),
                    Change_all_jsdoc_style_types_to_TypeScript: diag(95030, 3 /* Message */, "Change_all_jsdoc_style_types_to_TypeScript_95030", "Change all jsdoc-style types to TypeScript"),
                    Change_all_jsdoc_style_types_to_TypeScript_and_add_undefined_to_nullable_types: diag(95031, 3 /* Message */, "Change_all_jsdoc_style_types_to_TypeScript_and_add_undefined_to_nullable_types_95031", "Change all jsdoc-style types to TypeScript (and add '| undefined' to nullable types)"),
                    Implement_all_unimplemented_interfaces: diag(95032, 3 /* Message */, "Implement_all_unimplemented_interfaces_95032", "Implement all unimplemented interfaces"),
                    Install_all_missing_types_packages: diag(95033, 3 /* Message */, "Install_all_missing_types_packages_95033", "Install all missing types packages"),
                    Rewrite_all_as_indexed_access_types: diag(95034, 3 /* Message */, "Rewrite_all_as_indexed_access_types_95034", "Rewrite all as indexed access types"),
                    Convert_all_to_default_imports: diag(95035, 3 /* Message */, "Convert_all_to_default_imports_95035", "Convert all to default imports"),
                    Make_all_super_calls_the_first_statement_in_their_constructor: diag(95036, 3 /* Message */, "Make_all_super_calls_the_first_statement_in_their_constructor_95036", "Make all 'super()' calls the first statement in their constructor"),
                    Add_qualifier_to_all_unresolved_variables_matching_a_member_name: diag(95037, 3 /* Message */, "Add_qualifier_to_all_unresolved_variables_matching_a_member_name_95037", "Add qualifier to all unresolved variables matching a member name"),
                    Change_all_extended_interfaces_to_implements: diag(95038, 3 /* Message */, "Change_all_extended_interfaces_to_implements_95038", "Change all extended interfaces to 'implements'"),
                    Add_all_missing_super_calls: diag(95039, 3 /* Message */, "Add_all_missing_super_calls_95039", "Add all missing super calls"),
                    Implement_all_inherited_abstract_classes: diag(95040, 3 /* Message */, "Implement_all_inherited_abstract_classes_95040", "Implement all inherited abstract classes"),
                    Add_all_missing_async_modifiers: diag(95041, 3 /* Message */, "Add_all_missing_async_modifiers_95041", "Add all missing 'async' modifiers"),
                    Add_ts_ignore_to_all_error_messages: diag(95042, 3 /* Message */, "Add_ts_ignore_to_all_error_messages_95042", "Add '@ts-ignore' to all error messages"),
                    Annotate_everything_with_types_from_JSDoc: diag(95043, 3 /* Message */, "Annotate_everything_with_types_from_JSDoc_95043", "Annotate everything with types from JSDoc"),
                    Add_to_all_uncalled_decorators: diag(95044, 3 /* Message */, "Add_to_all_uncalled_decorators_95044", "Add '()' to all uncalled decorators"),
                    Convert_all_constructor_functions_to_classes: diag(95045, 3 /* Message */, "Convert_all_constructor_functions_to_classes_95045", "Convert all constructor functions to classes"),
                    Generate_get_and_set_accessors: diag(95046, 3 /* Message */, "Generate_get_and_set_accessors_95046", "Generate 'get' and 'set' accessors"),
                    Convert_require_to_import: diag(95047, 3 /* Message */, "Convert_require_to_import_95047", "Convert 'require' to 'import'"),
                    Convert_all_require_to_import: diag(95048, 3 /* Message */, "Convert_all_require_to_import_95048", "Convert all 'require' to 'import'"),
                    Move_to_a_new_file: diag(95049, 3 /* Message */, "Move_to_a_new_file_95049", "Move to a new file"),
                    Remove_unreachable_code: diag(95050, 3 /* Message */, "Remove_unreachable_code_95050", "Remove unreachable code"),
                    Remove_all_unreachable_code: diag(95051, 3 /* Message */, "Remove_all_unreachable_code_95051", "Remove all unreachable code"),
                    Add_missing_typeof: diag(95052, 3 /* Message */, "Add_missing_typeof_95052", "Add missing 'typeof'"),
                    Remove_unused_label: diag(95053, 3 /* Message */, "Remove_unused_label_95053", "Remove unused label"),
                    Remove_all_unused_labels: diag(95054, 3 /* Message */, "Remove_all_unused_labels_95054", "Remove all unused labels"),
                    Convert_0_to_mapped_object_type: diag(95055, 3 /* Message */, "Convert_0_to_mapped_object_type_95055", "Convert '{0}' to mapped object type"),
                    Convert_namespace_import_to_named_imports: diag(95056, 3 /* Message */, "Convert_namespace_import_to_named_imports_95056", "Convert namespace import to named imports"),
                    Convert_named_imports_to_namespace_import: diag(95057, 3 /* Message */, "Convert_named_imports_to_namespace_import_95057", "Convert named imports to namespace import"),
                    Add_or_remove_braces_in_an_arrow_function: diag(95058, 3 /* Message */, "Add_or_remove_braces_in_an_arrow_function_95058", "Add or remove braces in an arrow function"),
                    Add_braces_to_arrow_function: diag(95059, 3 /* Message */, "Add_braces_to_arrow_function_95059", "Add braces to arrow function"),
                    Remove_braces_from_arrow_function: diag(95060, 3 /* Message */, "Remove_braces_from_arrow_function_95060", "Remove braces from arrow function"),
                    Convert_default_export_to_named_export: diag(95061, 3 /* Message */, "Convert_default_export_to_named_export_95061", "Convert default export to named export"),
                    Convert_named_export_to_default_export: diag(95062, 3 /* Message */, "Convert_named_export_to_default_export_95062", "Convert named export to default export"),
                    Add_missing_enum_member_0: diag(95063, 3 /* Message */, "Add_missing_enum_member_0_95063", "Add missing enum member '{0}'"),
                    Add_all_missing_imports: diag(95064, 3 /* Message */, "Add_all_missing_imports_95064", "Add all missing imports"),
                    Convert_to_async_function: diag(95065, 3 /* Message */, "Convert_to_async_function_95065", "Convert to async function"),
                    Convert_all_to_async_functions: diag(95066, 3 /* Message */, "Convert_all_to_async_functions_95066", "Convert all to async functions"),
                    Add_missing_call_parentheses: diag(95067, 3 /* Message */, "Add_missing_call_parentheses_95067", "Add missing call parentheses"),
                    Add_all_missing_call_parentheses: diag(95068, 3 /* Message */, "Add_all_missing_call_parentheses_95068", "Add all missing call parentheses"),
                    Add_unknown_conversion_for_non_overlapping_types: diag(95069, 3 /* Message */, "Add_unknown_conversion_for_non_overlapping_types_95069", "Add 'unknown' conversion for non-overlapping types"),
                    Add_unknown_to_all_conversions_of_non_overlapping_types: diag(95070, 3 /* Message */, "Add_unknown_to_all_conversions_of_non_overlapping_types_95070", "Add 'unknown' to all conversions of non-overlapping types"),
                    Add_missing_new_operator_to_call: diag(95071, 3 /* Message */, "Add_missing_new_operator_to_call_95071", "Add missing 'new' operator to call"),
                    Add_missing_new_operator_to_all_calls: diag(95072, 3 /* Message */, "Add_missing_new_operator_to_all_calls_95072", "Add missing 'new' operator to all calls"),
                    Add_names_to_all_parameters_without_names: diag(95073, 3 /* Message */, "Add_names_to_all_parameters_without_names_95073", "Add names to all parameters without names"),
                    Enable_the_experimentalDecorators_option_in_your_configuration_file: diag(95074, 3 /* Message */, "Enable_the_experimentalDecorators_option_in_your_configuration_file_95074", "Enable the 'experimentalDecorators' option in your configuration file"),
                    Convert_parameters_to_destructured_object: diag(95075, 3 /* Message */, "Convert_parameters_to_destructured_object_95075", "Convert parameters to destructured object"),
                    Extract_type: diag(95077, 3 /* Message */, "Extract_type_95077", "Extract type"),
                    Extract_to_type_alias: diag(95078, 3 /* Message */, "Extract_to_type_alias_95078", "Extract to type alias"),
                    Extract_to_typedef: diag(95079, 3 /* Message */, "Extract_to_typedef_95079", "Extract to typedef"),
                    Infer_this_type_of_0_from_usage: diag(95080, 3 /* Message */, "Infer_this_type_of_0_from_usage_95080", "Infer 'this' type of '{0}' from usage"),
                    Add_const_to_unresolved_variable: diag(95081, 3 /* Message */, "Add_const_to_unresolved_variable_95081", "Add 'const' to unresolved variable"),
                    Add_const_to_all_unresolved_variables: diag(95082, 3 /* Message */, "Add_const_to_all_unresolved_variables_95082", "Add 'const' to all unresolved variables"),
                    Add_await: diag(95083, 3 /* Message */, "Add_await_95083", "Add 'await'"),
                    Add_await_to_initializer_for_0: diag(95084, 3 /* Message */, "Add_await_to_initializer_for_0_95084", "Add 'await' to initializer for '{0}'"),
                    Fix_all_expressions_possibly_missing_await: diag(95085, 3 /* Message */, "Fix_all_expressions_possibly_missing_await_95085", "Fix all expressions possibly missing 'await'"),
                    Remove_unnecessary_await: diag(95086, 3 /* Message */, "Remove_unnecessary_await_95086", "Remove unnecessary 'await'"),
                    Remove_all_unnecessary_uses_of_await: diag(95087, 3 /* Message */, "Remove_all_unnecessary_uses_of_await_95087", "Remove all unnecessary uses of 'await'"),
                    Enable_the_jsx_flag_in_your_configuration_file: diag(95088, 3 /* Message */, "Enable_the_jsx_flag_in_your_configuration_file_95088", "Enable the '--jsx' flag in your configuration file"),
                    Add_await_to_initializers: diag(95089, 3 /* Message */, "Add_await_to_initializers_95089", "Add 'await' to initializers"),
                    Extract_to_interface: diag(95090, 3 /* Message */, "Extract_to_interface_95090", "Extract to interface"),
                    Convert_to_a_bigint_numeric_literal: diag(95091, 3 /* Message */, "Convert_to_a_bigint_numeric_literal_95091", "Convert to a bigint numeric literal"),
                    Convert_all_to_bigint_numeric_literals: diag(95092, 3 /* Message */, "Convert_all_to_bigint_numeric_literals_95092", "Convert all to bigint numeric literals"),
                    Convert_const_to_let: diag(95093, 3 /* Message */, "Convert_const_to_let_95093", "Convert 'const' to 'let'"),
                    Prefix_with_declare: diag(95094, 3 /* Message */, "Prefix_with_declare_95094", "Prefix with 'declare'"),
                    Prefix_all_incorrect_property_declarations_with_declare: diag(95095, 3 /* Message */, "Prefix_all_incorrect_property_declarations_with_declare_95095", "Prefix all incorrect property declarations with 'declare'"),
                    Convert_to_template_string: diag(95096, 3 /* Message */, "Convert_to_template_string_95096", "Convert to template string"),
                    Add_export_to_make_this_file_into_a_module: diag(95097, 3 /* Message */, "Add_export_to_make_this_file_into_a_module_95097", "Add 'export {}' to make this file into a module"),
                    Set_the_target_option_in_your_configuration_file_to_0: diag(95098, 3 /* Message */, "Set_the_target_option_in_your_configuration_file_to_0_95098", "Set the 'target' option in your configuration file to '{0}'"),
                    Set_the_module_option_in_your_configuration_file_to_0: diag(95099, 3 /* Message */, "Set_the_module_option_in_your_configuration_file_to_0_95099", "Set the 'module' option in your configuration file to '{0}'"),
                    Convert_invalid_character_to_its_html_entity_code: diag(95100, 3 /* Message */, "Convert_invalid_character_to_its_html_entity_code_95100", "Convert invalid character to its html entity code"),
                    Convert_all_invalid_characters_to_HTML_entity_code: diag(95101, 3 /* Message */, "Convert_all_invalid_characters_to_HTML_entity_code_95101", "Convert all invalid characters to HTML entity code"),
                    Convert_all_const_to_let: diag(95102, 3 /* Message */, "Convert_all_const_to_let_95102", "Convert all 'const' to 'let'"),
                    Convert_function_expression_0_to_arrow_function: diag(95105, 3 /* Message */, "Convert_function_expression_0_to_arrow_function_95105", "Convert function expression '{0}' to arrow function"),
                    Convert_function_declaration_0_to_arrow_function: diag(95106, 3 /* Message */, "Convert_function_declaration_0_to_arrow_function_95106", "Convert function declaration '{0}' to arrow function"),
                    Fix_all_implicit_this_errors: diag(95107, 3 /* Message */, "Fix_all_implicit_this_errors_95107", "Fix all implicit-'this' errors"),
                    Wrap_invalid_character_in_an_expression_container: diag(95108, 3 /* Message */, "Wrap_invalid_character_in_an_expression_container_95108", "Wrap invalid character in an expression container"),
                    Wrap_all_invalid_characters_in_an_expression_container: diag(95109, 3 /* Message */, "Wrap_all_invalid_characters_in_an_expression_container_95109", "Wrap all invalid characters in an expression container"),
                    Visit_https_Colon_Slash_Slashaka_ms_Slashtsconfig_to_read_more_about_this_file: diag(95110, 3 /* Message */, "Visit_https_Colon_Slash_Slashaka_ms_Slashtsconfig_to_read_more_about_this_file_95110", "Visit https://aka.ms/tsconfig to read more about this file"),
                    Add_a_return_statement: diag(95111, 3 /* Message */, "Add_a_return_statement_95111", "Add a return statement"),
                    Remove_braces_from_arrow_function_body: diag(95112, 3 /* Message */, "Remove_braces_from_arrow_function_body_95112", "Remove braces from arrow function body"),
                    Wrap_the_following_body_with_parentheses_which_should_be_an_object_literal: diag(95113, 3 /* Message */, "Wrap_the_following_body_with_parentheses_which_should_be_an_object_literal_95113", "Wrap the following body with parentheses which should be an object literal"),
                    Add_all_missing_return_statement: diag(95114, 3 /* Message */, "Add_all_missing_return_statement_95114", "Add all missing return statement"),
                    Remove_braces_from_all_arrow_function_bodies_with_relevant_issues: diag(95115, 3 /* Message */, "Remove_braces_from_all_arrow_function_bodies_with_relevant_issues_95115", "Remove braces from all arrow function bodies with relevant issues"),
                    Wrap_all_object_literal_with_parentheses: diag(95116, 3 /* Message */, "Wrap_all_object_literal_with_parentheses_95116", "Wrap all object literal with parentheses"),
                    Move_labeled_tuple_element_modifiers_to_labels: diag(95117, 3 /* Message */, "Move_labeled_tuple_element_modifiers_to_labels_95117", "Move labeled tuple element modifiers to labels"),
                    Convert_overload_list_to_single_signature: diag(95118, 3 /* Message */, "Convert_overload_list_to_single_signature_95118", "Convert overload list to single signature"),
                    Generate_get_and_set_accessors_for_all_overriding_properties: diag(95119, 3 /* Message */, "Generate_get_and_set_accessors_for_all_overriding_properties_95119", "Generate 'get' and 'set' accessors for all overriding properties"),
                    Wrap_in_JSX_fragment: diag(95120, 3 /* Message */, "Wrap_in_JSX_fragment_95120", "Wrap in JSX fragment"),
                    Wrap_all_unparented_JSX_in_JSX_fragment: diag(95121, 3 /* Message */, "Wrap_all_unparented_JSX_in_JSX_fragment_95121", "Wrap all unparented JSX in JSX fragment"),
                    Convert_arrow_function_or_function_expression: diag(95122, 3 /* Message */, "Convert_arrow_function_or_function_expression_95122", "Convert arrow function or function expression"),
                    Convert_to_anonymous_function: diag(95123, 3 /* Message */, "Convert_to_anonymous_function_95123", "Convert to anonymous function"),
                    Convert_to_named_function: diag(95124, 3 /* Message */, "Convert_to_named_function_95124", "Convert to named function"),
                    Convert_to_arrow_function: diag(95125, 3 /* Message */, "Convert_to_arrow_function_95125", "Convert to arrow function"),
                    Remove_parentheses: diag(95126, 3 /* Message */, "Remove_parentheses_95126", "Remove parentheses"),
                    Could_not_find_a_containing_arrow_function: diag(95127, 3 /* Message */, "Could_not_find_a_containing_arrow_function_95127", "Could not find a containing arrow function"),
                    Containing_function_is_not_an_arrow_function: diag(95128, 3 /* Message */, "Containing_function_is_not_an_arrow_function_95128", "Containing function is not an arrow function"),
                    Could_not_find_export_statement: diag(95129, 3 /* Message */, "Could_not_find_export_statement_95129", "Could not find export statement"),
                    This_file_already_has_a_default_export: diag(95130, 3 /* Message */, "This_file_already_has_a_default_export_95130", "This file already has a default export"),
                    Could_not_find_import_clause: diag(95131, 3 /* Message */, "Could_not_find_import_clause_95131", "Could not find import clause"),
                    Could_not_find_namespace_import_or_named_imports: diag(95132, 3 /* Message */, "Could_not_find_namespace_import_or_named_imports_95132", "Could not find namespace import or named imports"),
                    Selection_is_not_a_valid_type_node: diag(95133, 3 /* Message */, "Selection_is_not_a_valid_type_node_95133", "Selection is not a valid type node"),
                    No_type_could_be_extracted_from_this_type_node: diag(95134, 3 /* Message */, "No_type_could_be_extracted_from_this_type_node_95134", "No type could be extracted from this type node"),
                    Could_not_find_property_for_which_to_generate_accessor: diag(95135, 3 /* Message */, "Could_not_find_property_for_which_to_generate_accessor_95135", "Could not find property for which to generate accessor"),
                    Name_is_not_valid: diag(95136, 3 /* Message */, "Name_is_not_valid_95136", "Name is not valid"),
                    Can_only_convert_property_with_modifier: diag(95137, 3 /* Message */, "Can_only_convert_property_with_modifier_95137", "Can only convert property with modifier"),
                    Switch_each_misused_0_to_1: diag(95138, 3 /* Message */, "Switch_each_misused_0_to_1_95138", "Switch each misused '{0}' to '{1}'"),
                    Convert_to_optional_chain_expression: diag(95139, 3 /* Message */, "Convert_to_optional_chain_expression_95139", "Convert to optional chain expression"),
                    Could_not_find_convertible_access_expression: diag(95140, 3 /* Message */, "Could_not_find_convertible_access_expression_95140", "Could not find convertible access expression"),
                    Could_not_find_matching_access_expressions: diag(95141, 3 /* Message */, "Could_not_find_matching_access_expressions_95141", "Could not find matching access expressions"),
                    Can_only_convert_logical_AND_access_chains: diag(95142, 3 /* Message */, "Can_only_convert_logical_AND_access_chains_95142", "Can only convert logical AND access chains"),
                    Add_void_to_Promise_resolved_without_a_value: diag(95143, 3 /* Message */, "Add_void_to_Promise_resolved_without_a_value_95143", "Add 'void' to Promise resolved without a value"),
                    Add_void_to_all_Promises_resolved_without_a_value: diag(95144, 3 /* Message */, "Add_void_to_all_Promises_resolved_without_a_value_95144", "Add 'void' to all Promises resolved without a value"),
                    Use_element_access_for_0: diag(95145, 3 /* Message */, "Use_element_access_for_0_95145", "Use element access for '{0}'"),
                    Use_element_access_for_all_undeclared_properties: diag(95146, 3 /* Message */, "Use_element_access_for_all_undeclared_properties_95146", "Use element access for all undeclared properties."),
                    Delete_all_unused_imports: diag(95147, 3 /* Message */, "Delete_all_unused_imports_95147", "Delete all unused imports"),
                    Infer_function_return_type: diag(95148, 3 /* Message */, "Infer_function_return_type_95148", "Infer function return type"),
                    Return_type_must_be_inferred_from_a_function: diag(95149, 3 /* Message */, "Return_type_must_be_inferred_from_a_function_95149", "Return type must be inferred from a function"),
                    Could_not_determine_function_return_type: diag(95150, 3 /* Message */, "Could_not_determine_function_return_type_95150", "Could not determine function return type"),
                    Could_not_convert_to_arrow_function: diag(95151, 3 /* Message */, "Could_not_convert_to_arrow_function_95151", "Could not convert to arrow function"),
                    Could_not_convert_to_named_function: diag(95152, 3 /* Message */, "Could_not_convert_to_named_function_95152", "Could not convert to named function"),
                    Could_not_convert_to_anonymous_function: diag(95153, 3 /* Message */, "Could_not_convert_to_anonymous_function_95153", "Could not convert to anonymous function"),
                    Can_only_convert_string_concatenations_and_string_literals: diag(95154, 3 /* Message */, "Can_only_convert_string_concatenations_and_string_literals_95154", "Can only convert string concatenations and string literals"),
                    Selection_is_not_a_valid_statement_or_statements: diag(95155, 3 /* Message */, "Selection_is_not_a_valid_statement_or_statements_95155", "Selection is not a valid statement or statements"),
                    Add_missing_function_declaration_0: diag(95156, 3 /* Message */, "Add_missing_function_declaration_0_95156", "Add missing function declaration '{0}'"),
                    Add_all_missing_function_declarations: diag(95157, 3 /* Message */, "Add_all_missing_function_declarations_95157", "Add all missing function declarations"),
                    Method_not_implemented: diag(95158, 3 /* Message */, "Method_not_implemented_95158", "Method not implemented."),
                    Function_not_implemented: diag(95159, 3 /* Message */, "Function_not_implemented_95159", "Function not implemented."),
                    Add_override_modifier: diag(95160, 3 /* Message */, "Add_override_modifier_95160", "Add 'override' modifier"),
                    Remove_override_modifier: diag(95161, 3 /* Message */, "Remove_override_modifier_95161", "Remove 'override' modifier"),
                    Add_all_missing_override_modifiers: diag(95162, 3 /* Message */, "Add_all_missing_override_modifiers_95162", "Add all missing 'override' modifiers"),
                    Remove_all_unnecessary_override_modifiers: diag(95163, 3 /* Message */, "Remove_all_unnecessary_override_modifiers_95163", "Remove all unnecessary 'override' modifiers"),
                    Can_only_convert_named_export: diag(95164, 3 /* Message */, "Can_only_convert_named_export_95164", "Can only convert named export"),
                    Add_missing_properties: diag(95165, 3 /* Message */, "Add_missing_properties_95165", "Add missing properties"),
                    Add_all_missing_properties: diag(95166, 3 /* Message */, "Add_all_missing_properties_95166", "Add all missing properties"),
                    Add_missing_attributes: diag(95167, 3 /* Message */, "Add_missing_attributes_95167", "Add missing attributes"),
                    Add_all_missing_attributes: diag(95168, 3 /* Message */, "Add_all_missing_attributes_95168", "Add all missing attributes"),
                    Add_undefined_to_optional_property_type: diag(95169, 3 /* Message */, "Add_undefined_to_optional_property_type_95169", "Add 'undefined' to optional property type"),
                    Convert_named_imports_to_default_import: diag(95170, 3 /* Message */, "Convert_named_imports_to_default_import_95170", "Convert named imports to default import"),
                    Delete_unused_param_tag_0: diag(95171, 3 /* Message */, "Delete_unused_param_tag_0_95171", "Delete unused '@param' tag '{0}'"),
                    Delete_all_unused_param_tags: diag(95172, 3 /* Message */, "Delete_all_unused_param_tags_95172", "Delete all unused '@param' tags"),
                    Rename_param_tag_name_0_to_1: diag(95173, 3 /* Message */, "Rename_param_tag_name_0_to_1_95173", "Rename '@param' tag name '{0}' to '{1}'"),
                    Use_0: diag(95174, 3 /* Message */, "Use_0_95174", "Use `{0}`."),
                    Use_Number_isNaN_in_all_conditions: diag(95175, 3 /* Message */, "Use_Number_isNaN_in_all_conditions_95175", "Use `Number.isNaN` in all conditions."),
                    Convert_typedef_to_TypeScript_type: diag(95176, 3 /* Message */, "Convert_typedef_to_TypeScript_type_95176", "Convert typedef to TypeScript type."),
                    Convert_all_typedef_to_TypeScript_types: diag(95177, 3 /* Message */, "Convert_all_typedef_to_TypeScript_types_95177", "Convert all typedef to TypeScript types."),
                    Move_to_file: diag(95178, 3 /* Message */, "Move_to_file_95178", "Move to file"),
                    Cannot_move_to_file_selected_file_is_invalid: diag(95179, 3 /* Message */, "Cannot_move_to_file_selected_file_is_invalid_95179", "Cannot move to file, selected file is invalid"),
                    Use_import_type: diag(95180, 3 /* Message */, "Use_import_type_95180", "Use 'import type'"),
                    Use_type_0: diag(95181, 3 /* Message */, "Use_type_0_95181", "Use 'type {0}'"),
                    Fix_all_with_type_only_imports: diag(95182, 3 /* Message */, "Fix_all_with_type_only_imports_95182", "Fix all with type-only imports"),
                    Cannot_move_statements_to_the_selected_file: diag(95183, 3 /* Message */, "Cannot_move_statements_to_the_selected_file_95183", "Cannot move statements to the selected file"),
                    Inline_variable: diag(95184, 3 /* Message */, "Inline_variable_95184", "Inline variable"),
                    Could_not_find_variable_to_inline: diag(95185, 3 /* Message */, "Could_not_find_variable_to_inline_95185", "Could not find variable to inline."),
                    Variables_with_multiple_declarations_cannot_be_inlined: diag(95186, 3 /* Message */, "Variables_with_multiple_declarations_cannot_be_inlined_95186", "Variables with multiple declarations cannot be inlined."),
                    Add_missing_comma_for_object_member_completion_0: diag(95187, 3 /* Message */, "Add_missing_comma_for_object_member_completion_0_95187", "Add missing comma for object member completion '{0}'."),
                    Add_missing_parameter_to_0: diag(95188, 3 /* Message */, "Add_missing_parameter_to_0_95188", "Add missing parameter to '{0}'"),
                    Add_missing_parameters_to_0: diag(95189, 3 /* Message */, "Add_missing_parameters_to_0_95189", "Add missing parameters to '{0}'"),
                    Add_all_missing_parameters: diag(95190, 3 /* Message */, "Add_all_missing_parameters_95190", "Add all missing parameters"),
                    Add_optional_parameter_to_0: diag(95191, 3 /* Message */, "Add_optional_parameter_to_0_95191", "Add optional parameter to '{0}'"),
                    Add_optional_parameters_to_0: diag(95192, 3 /* Message */, "Add_optional_parameters_to_0_95192", "Add optional parameters to '{0}'"),
                    Add_all_optional_parameters: diag(95193, 3 /* Message */, "Add_all_optional_parameters_95193", "Add all optional parameters"),
                    No_value_exists_in_scope_for_the_shorthand_property_0_Either_declare_one_or_provide_an_initializer: diag(18004, 1 /* Error */, "No_value_exists_in_scope_for_the_shorthand_property_0_Either_declare_one_or_provide_an_initializer_18004", "No value exists in scope for the shorthand property '{0}'. Either declare one or provide an initializer."),
                    Classes_may_not_have_a_field_named_constructor: diag(18006, 1 /* Error */, "Classes_may_not_have_a_field_named_constructor_18006", "Classes may not have a field named 'constructor'."),
                    JSX_expressions_may_not_use_the_comma_operator_Did_you_mean_to_write_an_array: diag(18007, 1 /* Error */, "JSX_expressions_may_not_use_the_comma_operator_Did_you_mean_to_write_an_array_18007", "JSX expressions may not use the comma operator. Did you mean to write an array?"),
                    Private_identifiers_cannot_be_used_as_parameters: diag(18009, 1 /* Error */, "Private_identifiers_cannot_be_used_as_parameters_18009", "Private identifiers cannot be used as parameters."),
                    An_accessibility_modifier_cannot_be_used_with_a_private_identifier: diag(18010, 1 /* Error */, "An_accessibility_modifier_cannot_be_used_with_a_private_identifier_18010", "An accessibility modifier cannot be used with a private identifier."),
                    The_operand_of_a_delete_operator_cannot_be_a_private_identifier: diag(18011, 1 /* Error */, "The_operand_of_a_delete_operator_cannot_be_a_private_identifier_18011", "The operand of a 'delete' operator cannot be a private identifier."),
                    constructor_is_a_reserved_word: diag(18012, 1 /* Error */, "constructor_is_a_reserved_word_18012", "'#constructor' is a reserved word."),
                    Property_0_is_not_accessible_outside_class_1_because_it_has_a_private_identifier: diag(18013, 1 /* Error */, "Property_0_is_not_accessible_outside_class_1_because_it_has_a_private_identifier_18013", "Property '{0}' is not accessible outside class '{1}' because it has a private identifier."),
                    The_property_0_cannot_be_accessed_on_type_1_within_this_class_because_it_is_shadowed_by_another_private_identifier_with_the_same_spelling: diag(18014, 1 /* Error */, "The_property_0_cannot_be_accessed_on_type_1_within_this_class_because_it_is_shadowed_by_another_priv_18014", "The property '{0}' cannot be accessed on type '{1}' within this class because it is shadowed by another private identifier with the same spelling."),
                    Property_0_in_type_1_refers_to_a_different_member_that_cannot_be_accessed_from_within_type_2: diag(18015, 1 /* Error */, "Property_0_in_type_1_refers_to_a_different_member_that_cannot_be_accessed_from_within_type_2_18015", "Property '{0}' in type '{1}' refers to a different member that cannot be accessed from within type '{2}'."),
                    Private_identifiers_are_not_allowed_outside_class_bodies: diag(18016, 1 /* Error */, "Private_identifiers_are_not_allowed_outside_class_bodies_18016", "Private identifiers are not allowed outside class bodies."),
                    The_shadowing_declaration_of_0_is_defined_here: diag(18017, 1 /* Error */, "The_shadowing_declaration_of_0_is_defined_here_18017", "The shadowing declaration of '{0}' is defined here"),
                    The_declaration_of_0_that_you_probably_intended_to_use_is_defined_here: diag(18018, 1 /* Error */, "The_declaration_of_0_that_you_probably_intended_to_use_is_defined_here_18018", "The declaration of '{0}' that you probably intended to use is defined here"),
                    _0_modifier_cannot_be_used_with_a_private_identifier: diag(18019, 1 /* Error */, "_0_modifier_cannot_be_used_with_a_private_identifier_18019", "'{0}' modifier cannot be used with a private identifier."),
                    An_enum_member_cannot_be_named_with_a_private_identifier: diag(18024, 1 /* Error */, "An_enum_member_cannot_be_named_with_a_private_identifier_18024", "An enum member cannot be named with a private identifier."),
                    can_only_be_used_at_the_start_of_a_file: diag(18026, 1 /* Error */, "can_only_be_used_at_the_start_of_a_file_18026", "'#!' can only be used at the start of a file."),
                    Compiler_reserves_name_0_when_emitting_private_identifier_downlevel: diag(18027, 1 /* Error */, "Compiler_reserves_name_0_when_emitting_private_identifier_downlevel_18027", "Compiler reserves name '{0}' when emitting private identifier downlevel."),
                    Private_identifiers_are_only_available_when_targeting_ECMAScript_2015_and_higher: diag(18028, 1 /* Error */, "Private_identifiers_are_only_available_when_targeting_ECMAScript_2015_and_higher_18028", "Private identifiers are only available when targeting ECMAScript 2015 and higher."),
                    Private_identifiers_are_not_allowed_in_variable_declarations: diag(18029, 1 /* Error */, "Private_identifiers_are_not_allowed_in_variable_declarations_18029", "Private identifiers are not allowed in variable declarations."),
                    An_optional_chain_cannot_contain_private_identifiers: diag(18030, 1 /* Error */, "An_optional_chain_cannot_contain_private_identifiers_18030", "An optional chain cannot contain private identifiers."),
                    The_intersection_0_was_reduced_to_never_because_property_1_has_conflicting_types_in_some_constituents: diag(18031, 1 /* Error */, "The_intersection_0_was_reduced_to_never_because_property_1_has_conflicting_types_in_some_constituent_18031", "The intersection '{0}' was reduced to 'never' because property '{1}' has conflicting types in some constituents."),
                    The_intersection_0_was_reduced_to_never_because_property_1_exists_in_multiple_constituents_and_is_private_in_some: diag(18032, 1 /* Error */, "The_intersection_0_was_reduced_to_never_because_property_1_exists_in_multiple_constituents_and_is_pr_18032", "The intersection '{0}' was reduced to 'never' because property '{1}' exists in multiple constituents and is private in some."),
                    Type_0_is_not_assignable_to_type_1_as_required_for_computed_enum_member_values: diag(18033, 1 /* Error */, "Type_0_is_not_assignable_to_type_1_as_required_for_computed_enum_member_values_18033", "Type '{0}' is not assignable to type '{1}' as required for computed enum member values."),
                    Specify_the_JSX_fragment_factory_function_to_use_when_targeting_react_JSX_emit_with_jsxFactory_compiler_option_is_specified_e_g_Fragment: diag(18034, 3 /* Message */, "Specify_the_JSX_fragment_factory_function_to_use_when_targeting_react_JSX_emit_with_jsxFactory_compi_18034", "Specify the JSX fragment factory function to use when targeting 'react' JSX emit with 'jsxFactory' compiler option is specified, e.g. 'Fragment'."),
                    Invalid_value_for_jsxFragmentFactory_0_is_not_a_valid_identifier_or_qualified_name: diag(18035, 1 /* Error */, "Invalid_value_for_jsxFragmentFactory_0_is_not_a_valid_identifier_or_qualified_name_18035", "Invalid value for 'jsxFragmentFactory'. '{0}' is not a valid identifier or qualified-name."),
                    Class_decorators_can_t_be_used_with_static_private_identifier_Consider_removing_the_experimental_decorator: diag(18036, 1 /* Error */, "Class_decorators_can_t_be_used_with_static_private_identifier_Consider_removing_the_experimental_dec_18036", "Class decorators can't be used with static private identifier. Consider removing the experimental decorator."),
                    await_expression_cannot_be_used_inside_a_class_static_block: diag(18037, 1 /* Error */, "await_expression_cannot_be_used_inside_a_class_static_block_18037", "'await' expression cannot be used inside a class static block."),
                    for_await_loops_cannot_be_used_inside_a_class_static_block: diag(18038, 1 /* Error */, "for_await_loops_cannot_be_used_inside_a_class_static_block_18038", "'for await' loops cannot be used inside a class static block."),
                    Invalid_use_of_0_It_cannot_be_used_inside_a_class_static_block: diag(18039, 1 /* Error */, "Invalid_use_of_0_It_cannot_be_used_inside_a_class_static_block_18039", "Invalid use of '{0}'. It cannot be used inside a class static block."),
                    A_return_statement_cannot_be_used_inside_a_class_static_block: diag(18041, 1 /* Error */, "A_return_statement_cannot_be_used_inside_a_class_static_block_18041", "A 'return' statement cannot be used inside a class static block."),
                    _0_is_a_type_and_cannot_be_imported_in_JavaScript_files_Use_1_in_a_JSDoc_type_annotation: diag(18042, 1 /* Error */, "_0_is_a_type_and_cannot_be_imported_in_JavaScript_files_Use_1_in_a_JSDoc_type_annotation_18042", "'{0}' is a type and cannot be imported in JavaScript files. Use '{1}' in a JSDoc type annotation."),
                    Types_cannot_appear_in_export_declarations_in_JavaScript_files: diag(18043, 1 /* Error */, "Types_cannot_appear_in_export_declarations_in_JavaScript_files_18043", "Types cannot appear in export declarations in JavaScript files."),
                    _0_is_automatically_exported_here: diag(18044, 3 /* Message */, "_0_is_automatically_exported_here_18044", "'{0}' is automatically exported here."),
                    Properties_with_the_accessor_modifier_are_only_available_when_targeting_ECMAScript_2015_and_higher: diag(18045, 1 /* Error */, "Properties_with_the_accessor_modifier_are_only_available_when_targeting_ECMAScript_2015_and_higher_18045", "Properties with the 'accessor' modifier are only available when targeting ECMAScript 2015 and higher."),
                    _0_is_of_type_unknown: diag(18046, 1 /* Error */, "_0_is_of_type_unknown_18046", "'{0}' is of type 'unknown'."),
                    _0_is_possibly_null: diag(18047, 1 /* Error */, "_0_is_possibly_null_18047", "'{0}' is possibly 'null'."),
                    _0_is_possibly_undefined: diag(18048, 1 /* Error */, "_0_is_possibly_undefined_18048", "'{0}' is possibly 'undefined'."),
                    _0_is_possibly_null_or_undefined: diag(18049, 1 /* Error */, "_0_is_possibly_null_or_undefined_18049", "'{0}' is possibly 'null' or 'undefined'."),
                    The_value_0_cannot_be_used_here: diag(18050, 1 /* Error */, "The_value_0_cannot_be_used_here_18050", "The value '{0}' cannot be used here."),
                    Compiler_option_0_cannot_be_given_an_empty_string: diag(18051, 1 /* Error */, "Compiler_option_0_cannot_be_given_an_empty_string_18051", "Compiler option '{0}' cannot be given an empty string."),
                    Non_abstract_class_0_does_not_implement_all_abstract_members_of_1: diag(18052, 1 /* Error */, "Non_abstract_class_0_does_not_implement_all_abstract_members_of_1_18052", "Non-abstract class '{0}' does not implement all abstract members of '{1}'"),
                    Its_type_0_is_not_a_valid_JSX_element_type: diag(18053, 1 /* Error */, "Its_type_0_is_not_a_valid_JSX_element_type_18053", "Its type '{0}' is not a valid JSX element type."),
                    await_using_statements_cannot_be_used_inside_a_class_static_block: diag(18054, 1 /* Error */, "await_using_statements_cannot_be_used_inside_a_class_static_block_18054", "'await using' statements cannot be used inside a class static block.")
                };
            }
        });
        // src/compiler/scanner.ts
        function tokenIsIdentifierOrKeyword(token) {
            return token >= 80 /* Identifier */;
        }
        function tokenIsIdentifierOrKeywordOrGreaterThan(token) {
            return token === 32 /* GreaterThanToken */ || tokenIsIdentifierOrKeyword(token);
        }
        function lookupInUnicodeMap(code, map2) {
            if (code < map2[0]) {
                return false;
            }
            let lo = 0;
            let hi = map2.length;
            let mid;
            while (lo + 1 < hi) {
                mid = lo + (hi - lo) / 2;
                mid -= mid % 2;
                if (map2[mid] <= code && code <= map2[mid + 1]) {
                    return true;
                }
                if (code < map2[mid]) {
                    hi = mid;
                }
                else {
                    lo = mid + 2;
                }
            }
            return false;
        }
        function isUnicodeIdentifierStart(code, languageVersion) {
            return languageVersion >= 2 /* ES2015 */ ? lookupInUnicodeMap(code, unicodeESNextIdentifierStart) : languageVersion === 1 /* ES5 */ ? lookupInUnicodeMap(code, unicodeES5IdentifierStart) : lookupInUnicodeMap(code, unicodeES3IdentifierStart);
        }
        function isUnicodeIdentifierPart(code, languageVersion) {
            return languageVersion >= 2 /* ES2015 */ ? lookupInUnicodeMap(code, unicodeESNextIdentifierPart) : languageVersion === 1 /* ES5 */ ? lookupInUnicodeMap(code, unicodeES5IdentifierPart) : lookupInUnicodeMap(code, unicodeES3IdentifierPart);
        }
        function makeReverseMap(source) {
            const result = [];
            source.forEach((value, name) => {
                result[value] = name;
            });
            return result;
        }
        function tokenToString(t) {
            return tokenStrings[t];
        }
        function stringToToken(s) {
            return textToToken.get(s);
        }
        function computeLineStarts(text) {
            const result = [];
            let pos = 0;
            let lineStart = 0;
            while (pos < text.length) {
                const ch = text.charCodeAt(pos);
                pos++;
                switch (ch) {
                    case 13 /* carriageReturn */:
                        if (text.charCodeAt(pos) === 10 /* lineFeed */) {
                            pos++;
                        }
                    case 10 /* lineFeed */:
                        result.push(lineStart);
                        lineStart = pos;
                        break;
                    default:
                        if (ch > 127 /* maxAsciiCharacter */ && isLineBreak(ch)) {
                            result.push(lineStart);
                            lineStart = pos;
                        }
                        break;
                }
            }
            result.push(lineStart);
            return result;
        }
        function getPositionOfLineAndCharacter(sourceFile, line, character, allowEdits) {
            return sourceFile.getPositionOfLineAndCharacter ? sourceFile.getPositionOfLineAndCharacter(line, character, allowEdits) : computePositionOfLineAndCharacter(getLineStarts(sourceFile), line, character, sourceFile.text, allowEdits);
        }
        function computePositionOfLineAndCharacter(lineStarts, line, character, debugText, allowEdits) {
            if (line < 0 || line >= lineStarts.length) {
                if (allowEdits) {
                    line = line < 0 ? 0 : line >= lineStarts.length ? lineStarts.length - 1 : line;
                }
                else {
                    Debug.fail(`Bad line number. Line: ${line}, lineStarts.length: ${lineStarts.length} , line map is correct? ${debugText !== void 0 ? arraysEqual(lineStarts, computeLineStarts(debugText)) : "unknown"}`);
                }
            }
            const res = lineStarts[line] + character;
            if (allowEdits) {
                return res > lineStarts[line + 1] ? lineStarts[line + 1] : typeof debugText === "string" && res > debugText.length ? debugText.length : res;
            }
            if (line < lineStarts.length - 1) {
                Debug.assert(res < lineStarts[line + 1]);
            }
            else if (debugText !== void 0) {
                Debug.assert(res <= debugText.length);
            }
            return res;
        }
        function getLineStarts(sourceFile) {
            return sourceFile.lineMap || (sourceFile.lineMap = computeLineStarts(sourceFile.text));
        }
        function computeLineAndCharacterOfPosition(lineStarts, position) {
            const lineNumber = computeLineOfPosition(lineStarts, position);
            return {
                line: lineNumber,
                character: position - lineStarts[lineNumber]
            };
        }
        function computeLineOfPosition(lineStarts, position, lowerBound) {
            let lineNumber = binarySearch(lineStarts, position, identity, compareValues, lowerBound);
            if (lineNumber < 0) {
                lineNumber = ~lineNumber - 1;
                Debug.assert(lineNumber !== -1, "position cannot precede the beginning of the file");
            }
            return lineNumber;
        }
        function getLinesBetweenPositions(sourceFile, pos1, pos2) {
            if (pos1 === pos2)
                return 0;
            const lineStarts = getLineStarts(sourceFile);
            const lower = Math.min(pos1, pos2);
            const isNegative = lower === pos2;
            const upper = isNegative ? pos1 : pos2;
            const lowerLine = computeLineOfPosition(lineStarts, lower);
            const upperLine = computeLineOfPosition(lineStarts, upper, lowerLine);
            return isNegative ? lowerLine - upperLine : upperLine - lowerLine;
        }
        function getLineAndCharacterOfPosition(sourceFile, position) {
            return computeLineAndCharacterOfPosition(getLineStarts(sourceFile), position);
        }
        function isWhiteSpaceLike(ch) {
            return isWhiteSpaceSingleLine(ch) || isLineBreak(ch);
        }
        function isWhiteSpaceSingleLine(ch) {
            return ch === 32 /* space */ || ch === 9 /* tab */ || ch === 11 /* verticalTab */ || ch === 12 /* formFeed */ || ch === 160 /* nonBreakingSpace */ || ch === 133 /* nextLine */ || ch === 5760 /* ogham */ || ch >= 8192 /* enQuad */ && ch <= 8203 /* zeroWidthSpace */ || ch === 8239 /* narrowNoBreakSpace */ || ch === 8287 /* mathematicalSpace */ || ch === 12288 /* ideographicSpace */ || ch === 65279 /* byteOrderMark */;
        }
        function isLineBreak(ch) {
            return ch === 10 /* lineFeed */ || ch === 13 /* carriageReturn */ || ch === 8232 /* lineSeparator */ || ch === 8233 /* paragraphSeparator */;
        }
        function isDigit(ch) {
            return ch >= 48 /* _0 */ && ch <= 57 /* _9 */;
        }
        function isHexDigit(ch) {
            return isDigit(ch) || ch >= 65 /* A */ && ch <= 70 /* F */ || ch >= 97 /* a */ && ch <= 102 /* f */;
        }
        function isCodePoint(code) {
            return code <= 1114111;
        }
        function isOctalDigit(ch) {
            return ch >= 48 /* _0 */ && ch <= 55 /* _7 */;
        }
        function couldStartTrivia(text, pos) {
            const ch = text.charCodeAt(pos);
            switch (ch) {
                case 13 /* carriageReturn */:
                case 10 /* lineFeed */:
                case 9 /* tab */:
                case 11 /* verticalTab */:
                case 12 /* formFeed */:
                case 32 /* space */:
                case 47 /* slash */:
                case 60 /* lessThan */:
                case 124 /* bar */:
                case 61 /* equals */:
                case 62 /* greaterThan */:
                    return true;
                case 35 /* hash */:
                    return pos === 0;
                default:
                    return ch > 127 /* maxAsciiCharacter */;
            }
        }
        function skipTrivia(text, pos, stopAfterLineBreak, stopAtComments, inJSDoc) {
            if (positionIsSynthesized(pos)) {
                return pos;
            }
            let canConsumeStar = false;
            while (true) {
                const ch = text.charCodeAt(pos);
                switch (ch) {
                    case 13 /* carriageReturn */:
                        if (text.charCodeAt(pos + 1) === 10 /* lineFeed */) {
                            pos++;
                        }
                    case 10 /* lineFeed */:
                        pos++;
                        if (stopAfterLineBreak) {
                            return pos;
                        }
                        canConsumeStar = !!inJSDoc;
                        continue;
                    case 9 /* tab */:
                    case 11 /* verticalTab */:
                    case 12 /* formFeed */:
                    case 32 /* space */:
                        pos++;
                        continue;
                    case 47 /* slash */:
                        if (stopAtComments) {
                            break;
                        }
                        if (text.charCodeAt(pos + 1) === 47 /* slash */) {
                            pos += 2;
                            while (pos < text.length) {
                                if (isLineBreak(text.charCodeAt(pos))) {
                                    break;
                                }
                                pos++;
                            }
                            canConsumeStar = false;
                            continue;
                        }
                        if (text.charCodeAt(pos + 1) === 42 /* asterisk */) {
                            pos += 2;
                            while (pos < text.length) {
                                if (text.charCodeAt(pos) === 42 /* asterisk */ && text.charCodeAt(pos + 1) === 47 /* slash */) {
                                    pos += 2;
                                    break;
                                }
                                pos++;
                            }
                            canConsumeStar = false;
                            continue;
                        }
                        break;
                    case 60 /* lessThan */:
                    case 124 /* bar */:
                    case 61 /* equals */:
                    case 62 /* greaterThan */:
                        if (isConflictMarkerTrivia(text, pos)) {
                            pos = scanConflictMarkerTrivia(text, pos);
                            canConsumeStar = false;
                            continue;
                        }
                        break;
                    case 35 /* hash */:
                        if (pos === 0 && isShebangTrivia(text, pos)) {
                            pos = scanShebangTrivia(text, pos);
                            canConsumeStar = false;
                            continue;
                        }
                        break;
                    case 42 /* asterisk */:
                        if (canConsumeStar) {
                            pos++;
                            canConsumeStar = false;
                            continue;
                        }
                        break;
                    default:
                        if (ch > 127 /* maxAsciiCharacter */ && isWhiteSpaceLike(ch)) {
                            pos++;
                            continue;
                        }
                        break;
                }
                return pos;
            }
        }
        function isConflictMarkerTrivia(text, pos) {
            Debug.assert(pos >= 0);
            if (pos === 0 || isLineBreak(text.charCodeAt(pos - 1))) {
                const ch = text.charCodeAt(pos);
                if (pos + mergeConflictMarkerLength < text.length) {
                    for (let i = 0; i < mergeConflictMarkerLength; i++) {
                        if (text.charCodeAt(pos + i) !== ch) {
                            return false;
                        }
                    }
                    return ch === 61 /* equals */ || text.charCodeAt(pos + mergeConflictMarkerLength) === 32 /* space */;
                }
            }
            return false;
        }
        function scanConflictMarkerTrivia(text, pos, error2) {
            if (error2) {
                error2(Diagnostics.Merge_conflict_marker_encountered, pos, mergeConflictMarkerLength);
            }
            const ch = text.charCodeAt(pos);
            const len = text.length;
            if (ch === 60 /* lessThan */ || ch === 62 /* greaterThan */) {
                while (pos < len && !isLineBreak(text.charCodeAt(pos))) {
                    pos++;
                }
            }
            else {
                Debug.assert(ch === 124 /* bar */ || ch === 61 /* equals */);
                while (pos < len) {
                    const currentChar = text.charCodeAt(pos);
                    if ((currentChar === 61 /* equals */ || currentChar === 62 /* greaterThan */) && currentChar !== ch && isConflictMarkerTrivia(text, pos)) {
                        break;
                    }
                    pos++;
                }
            }
            return pos;
        }
        function isShebangTrivia(text, pos) {
            Debug.assert(pos === 0);
            return shebangTriviaRegex.test(text);
        }
        function scanShebangTrivia(text, pos) {
            const shebang = shebangTriviaRegex.exec(text)[0];
            pos = pos + shebang.length;
            return pos;
        }
        function iterateCommentRanges(reduce, text, pos, trailing, cb, state, initial) {
            let pendingPos;
            let pendingEnd;
            let pendingKind;
            let pendingHasTrailingNewLine;
            let hasPendingCommentRange = false;
            let collecting = trailing;
            let accumulator = initial;
            if (pos === 0) {
                collecting = true;
                const shebang = getShebang(text);
                if (shebang) {
                    pos = shebang.length;
                }
            }
            scan: while (pos >= 0 && pos < text.length) {
                const ch = text.charCodeAt(pos);
                switch (ch) {
                    case 13 /* carriageReturn */:
                        if (text.charCodeAt(pos + 1) === 10 /* lineFeed */) {
                            pos++;
                        }
                    case 10 /* lineFeed */:
                        pos++;
                        if (trailing) {
                            break scan;
                        }
                        collecting = true;
                        if (hasPendingCommentRange) {
                            pendingHasTrailingNewLine = true;
                        }
                        continue;
                    case 9 /* tab */:
                    case 11 /* verticalTab */:
                    case 12 /* formFeed */:
                    case 32 /* space */:
                        pos++;
                        continue;
                    case 47 /* slash */:
                        const nextChar = text.charCodeAt(pos + 1);
                        let hasTrailingNewLine = false;
                        if (nextChar === 47 /* slash */ || nextChar === 42 /* asterisk */) {
                            const kind = nextChar === 47 /* slash */ ? 2 /* SingleLineCommentTrivia */ : 3 /* MultiLineCommentTrivia */;
                            const startPos = pos;
                            pos += 2;
                            if (nextChar === 47 /* slash */) {
                                while (pos < text.length) {
                                    if (isLineBreak(text.charCodeAt(pos))) {
                                        hasTrailingNewLine = true;
                                        break;
                                    }
                                    pos++;
                                }
                            }
                            else {
                                while (pos < text.length) {
                                    if (text.charCodeAt(pos) === 42 /* asterisk */ && text.charCodeAt(pos + 1) === 47 /* slash */) {
                                        pos += 2;
                                        break;
                                    }
                                    pos++;
                                }
                            }
                            if (collecting) {
                                if (hasPendingCommentRange) {
                                    accumulator = cb(pendingPos, pendingEnd, pendingKind, pendingHasTrailingNewLine, state, accumulator);
                                    if (!reduce && accumulator) {
                                        return accumulator;
                                    }
                                }
                                pendingPos = startPos;
                                pendingEnd = pos;
                                pendingKind = kind;
                                pendingHasTrailingNewLine = hasTrailingNewLine;
                                hasPendingCommentRange = true;
                            }
                            continue;
                        }
                        break scan;
                    default:
                        if (ch > 127 /* maxAsciiCharacter */ && isWhiteSpaceLike(ch)) {
                            if (hasPendingCommentRange && isLineBreak(ch)) {
                                pendingHasTrailingNewLine = true;
                            }
                            pos++;
                            continue;
                        }
                        break scan;
                }
            }
            if (hasPendingCommentRange) {
                accumulator = cb(pendingPos, pendingEnd, pendingKind, pendingHasTrailingNewLine, state, accumulator);
            }
            return accumulator;
        }
        function forEachLeadingCommentRange(text, pos, cb, state) {
            return iterateCommentRanges(
            /*reduce*/
            false, text, pos, 
            /*trailing*/
            false, cb, state);
        }
        function forEachTrailingCommentRange(text, pos, cb, state) {
            return iterateCommentRanges(
            /*reduce*/
            false, text, pos, 
            /*trailing*/
            true, cb, state);
        }
        function reduceEachLeadingCommentRange(text, pos, cb, state, initial) {
            return iterateCommentRanges(
            /*reduce*/
            true, text, pos, 
            /*trailing*/
            false, cb, state, initial);
        }
        function reduceEachTrailingCommentRange(text, pos, cb, state, initial) {
            return iterateCommentRanges(
            /*reduce*/
            true, text, pos, 
            /*trailing*/
            true, cb, state, initial);
        }
        function appendCommentRange(pos, end, kind, hasTrailingNewLine, _state, comments = []) {
            comments.push({ kind, pos, end, hasTrailingNewLine });
            return comments;
        }
        function getLeadingCommentRanges(text, pos) {
            return reduceEachLeadingCommentRange(text, pos, appendCommentRange, 
            /*state*/
            void 0, 
            /*initial*/
            void 0);
        }
        function getTrailingCommentRanges(text, pos) {
            return reduceEachTrailingCommentRange(text, pos, appendCommentRange, 
            /*state*/
            void 0, 
            /*initial*/
            void 0);
        }
        function getShebang(text) {
            const match = shebangTriviaRegex.exec(text);
            if (match) {
                return match[0];
            }
        }
        function isIdentifierStart(ch, languageVersion) {
            return ch >= 65 /* A */ && ch <= 90 /* Z */ || ch >= 97 /* a */ && ch <= 122 /* z */ || ch === 36 /* $ */ || ch === 95 /* _ */ || ch > 127 /* maxAsciiCharacter */ && isUnicodeIdentifierStart(ch, languageVersion);
        }
        function isIdentifierPart(ch, languageVersion, identifierVariant) {
            return ch >= 65 /* A */ && ch <= 90 /* Z */ || ch >= 97 /* a */ && ch <= 122 /* z */ || ch >= 48 /* _0 */ && ch <= 57 /* _9 */ || ch === 36 /* $ */ || ch === 95 /* _ */ || // "-" and ":" are valid in JSX Identifiers
                (identifierVariant === 1 /* JSX */ ? ch === 45 /* minus */ || ch === 58 /* colon */ : false) || ch > 127 /* maxAsciiCharacter */ && isUnicodeIdentifierPart(ch, languageVersion);
        }
        function isIdentifierText(name, languageVersion, identifierVariant) {
            let ch = codePointAt(name, 0);
            if (!isIdentifierStart(ch, languageVersion)) {
                return false;
            }
            for (let i = charSize(ch); i < name.length; i += charSize(ch)) {
                if (!isIdentifierPart(ch = codePointAt(name, i), languageVersion, identifierVariant)) {
                    return false;
                }
            }
            return true;
        }
        function createScanner(languageVersion, skipTrivia2, languageVariant = 0 /* Standard */, textInitial, onError, start, length2) {
            var text = textInitial;
            var pos;
            var end;
            var fullStartPos;
            var tokenStart;
            var token;
            var tokenValue;
            var tokenFlags;
            var commentDirectives;
            var inJSDocType = 0;
            var scriptKind = 0 /* Unknown */;
            var jsDocParsingMode = 0 /* ParseAll */;
            setText(text, start, length2);
            var scanner2 = {
                getTokenFullStart: () => fullStartPos,
                getStartPos: () => fullStartPos,
                getTokenEnd: () => pos,
                getTextPos: () => pos,
                getToken: () => token,
                getTokenStart: () => tokenStart,
                getTokenPos: () => tokenStart,
                getTokenText: () => text.substring(tokenStart, pos),
                getTokenValue: () => tokenValue,
                hasUnicodeEscape: () => (tokenFlags & 1024 /* UnicodeEscape */) !== 0,
                hasExtendedUnicodeEscape: () => (tokenFlags & 8 /* ExtendedUnicodeEscape */) !== 0,
                hasPrecedingLineBreak: () => (tokenFlags & 1 /* PrecedingLineBreak */) !== 0,
                hasPrecedingJSDocComment: () => (tokenFlags & 2 /* PrecedingJSDocComment */) !== 0,
                isIdentifier: () => token === 80 /* Identifier */ || token > 118 /* LastReservedWord */,
                isReservedWord: () => token >= 83 /* FirstReservedWord */ && token <= 118 /* LastReservedWord */,
                isUnterminated: () => (tokenFlags & 4 /* Unterminated */) !== 0,
                getCommentDirectives: () => commentDirectives,
                getNumericLiteralFlags: () => tokenFlags & 25584 /* NumericLiteralFlags */,
                getTokenFlags: () => tokenFlags,
                reScanGreaterToken,
                reScanAsteriskEqualsToken,
                reScanSlashToken,
                reScanTemplateToken,
                reScanTemplateHeadOrNoSubstitutionTemplate,
                scanJsxIdentifier,
                scanJsxAttributeValue,
                reScanJsxAttributeValue,
                reScanJsxToken,
                reScanLessThanToken,
                reScanHashToken,
                reScanQuestionToken,
                reScanInvalidIdentifier,
                scanJsxToken,
                scanJsDocToken,
                scanJSDocCommentTextToken,
                scan,
                getText,
                clearCommentDirectives,
                setText,
                setScriptTarget,
                setLanguageVariant,
                setScriptKind,
                setJSDocParsingMode,
                setOnError,
                resetTokenState,
                setTextPos: resetTokenState,
                setInJSDocType,
                tryScan,
                lookAhead,
                scanRange
            };
            if (Debug.isDebugging) {
                Object.defineProperty(scanner2, "__debugShowCurrentPositionInText", {
                    get: () => {
                        const text2 = scanner2.getText();
                        return text2.slice(0, scanner2.getTokenFullStart()) + "\u2551" + text2.slice(scanner2.getTokenFullStart());
                    }
                });
            }
            return scanner2;
            function error2(message, errPos = pos, length3, arg0) {
                if (onError) {
                    const oldPos = pos;
                    pos = errPos;
                    onError(message, length3 || 0, arg0);
                    pos = oldPos;
                }
            }
            function scanNumberFragment() {
                let start2 = pos;
                let allowSeparator = false;
                let isPreviousTokenSeparator = false;
                let result = "";
                while (true) {
                    const ch = text.charCodeAt(pos);
                    if (ch === 95 /* _ */) {
                        tokenFlags |= 512 /* ContainsSeparator */;
                        if (allowSeparator) {
                            allowSeparator = false;
                            isPreviousTokenSeparator = true;
                            result += text.substring(start2, pos);
                        }
                        else {
                            tokenFlags |= 16384 /* ContainsInvalidSeparator */;
                            if (isPreviousTokenSeparator) {
                                error2(Diagnostics.Multiple_consecutive_numeric_separators_are_not_permitted, pos, 1);
                            }
                            else {
                                error2(Diagnostics.Numeric_separators_are_not_allowed_here, pos, 1);
                            }
                        }
                        pos++;
                        start2 = pos;
                        continue;
                    }
                    if (isDigit(ch)) {
                        allowSeparator = true;
                        isPreviousTokenSeparator = false;
                        pos++;
                        continue;
                    }
                    break;
                }
                if (text.charCodeAt(pos - 1) === 95 /* _ */) {
                    tokenFlags |= 16384 /* ContainsInvalidSeparator */;
                    error2(Diagnostics.Numeric_separators_are_not_allowed_here, pos - 1, 1);
                }
                return result + text.substring(start2, pos);
            }
            function scanNumber() {
                let start2 = pos;
                let mainFragment;
                if (text.charCodeAt(pos) === 48 /* _0 */) {
                    pos++;
                    if (text.charCodeAt(pos) === 95 /* _ */) {
                        tokenFlags |= 512 /* ContainsSeparator */ | 16384 /* ContainsInvalidSeparator */;
                        error2(Diagnostics.Numeric_separators_are_not_allowed_here, pos, 1);
                        pos--;
                        mainFragment = scanNumberFragment();
                    }
                    else if (!scanDigits()) {
                        tokenFlags |= 8192 /* ContainsLeadingZero */;
                        mainFragment = "" + +tokenValue;
                    }
                    else if (!tokenValue) {
                        mainFragment = "0";
                    }
                    else {
                        tokenValue = "" + parseInt(tokenValue, 8);
                        tokenFlags |= 32 /* Octal */;
                        const withMinus = token === 41 /* MinusToken */;
                        const literal = (withMinus ? "-" : "") + "0o" + (+tokenValue).toString(8);
                        if (withMinus)
                            start2--;
                        error2(Diagnostics.Octal_literals_are_not_allowed_Use_the_syntax_0, start2, pos - start2, literal);
                        return 9 /* NumericLiteral */;
                    }
                }
                else {
                    mainFragment = scanNumberFragment();
                }
                let decimalFragment;
                let scientificFragment;
                if (text.charCodeAt(pos) === 46 /* dot */) {
                    pos++;
                    decimalFragment = scanNumberFragment();
                }
                let end2 = pos;
                if (text.charCodeAt(pos) === 69 /* E */ || text.charCodeAt(pos) === 101 /* e */) {
                    pos++;
                    tokenFlags |= 16 /* Scientific */;
                    if (text.charCodeAt(pos) === 43 /* plus */ || text.charCodeAt(pos) === 45 /* minus */)
                        pos++;
                    const preNumericPart = pos;
                    const finalFragment = scanNumberFragment();
                    if (!finalFragment) {
                        error2(Diagnostics.Digit_expected);
                    }
                    else {
                        scientificFragment = text.substring(end2, preNumericPart) + finalFragment;
                        end2 = pos;
                    }
                }
                let result;
                if (tokenFlags & 512 /* ContainsSeparator */) {
                    result = mainFragment;
                    if (decimalFragment) {
                        result += "." + decimalFragment;
                    }
                    if (scientificFragment) {
                        result += scientificFragment;
                    }
                }
                else {
                    result = text.substring(start2, end2);
                }
                if (tokenFlags & 8192 /* ContainsLeadingZero */) {
                    error2(Diagnostics.Decimals_with_leading_zeros_are_not_allowed, start2, end2 - start2);
                    tokenValue = "" + +result;
                    return 9 /* NumericLiteral */;
                }
                if (decimalFragment !== void 0 || tokenFlags & 16 /* Scientific */) {
                    checkForIdentifierStartAfterNumericLiteral(start2, decimalFragment === void 0 && !!(tokenFlags & 16 /* Scientific */));
                    tokenValue = "" + +result;
                    return 9 /* NumericLiteral */;
                }
                else {
                    tokenValue = result;
                    const type = checkBigIntSuffix();
                    checkForIdentifierStartAfterNumericLiteral(start2);
                    return type;
                }
            }
            function checkForIdentifierStartAfterNumericLiteral(numericStart, isScientific) {
                if (!isIdentifierStart(codePointAt(text, pos), languageVersion)) {
                    return;
                }
                const identifierStart = pos;
                const { length: length3 } = scanIdentifierParts();
                if (length3 === 1 && text[identifierStart] === "n") {
                    if (isScientific) {
                        error2(Diagnostics.A_bigint_literal_cannot_use_exponential_notation, numericStart, identifierStart - numericStart + 1);
                    }
                    else {
                        error2(Diagnostics.A_bigint_literal_must_be_an_integer, numericStart, identifierStart - numericStart + 1);
                    }
                }
                else {
                    error2(Diagnostics.An_identifier_or_keyword_cannot_immediately_follow_a_numeric_literal, identifierStart, length3);
                    pos = identifierStart;
                }
            }
            function scanDigits() {
                const start2 = pos;
                let isOctal = true;
                while (isDigit(text.charCodeAt(pos))) {
                    if (!isOctalDigit(text.charCodeAt(pos))) {
                        isOctal = false;
                    }
                    pos++;
                }
                tokenValue = text.substring(start2, pos);
                return isOctal;
            }
            function scanExactNumberOfHexDigits(count, canHaveSeparators) {
                const valueString = scanHexDigits(
                /*minCount*/
                count, 
                /*scanAsManyAsPossible*/
                false, canHaveSeparators);
                return valueString ? parseInt(valueString, 16) : -1;
            }
            function scanMinimumNumberOfHexDigits(count, canHaveSeparators) {
                return scanHexDigits(
                /*minCount*/
                count, 
                /*scanAsManyAsPossible*/
                true, canHaveSeparators);
            }
            function scanHexDigits(minCount, scanAsManyAsPossible, canHaveSeparators) {
                let valueChars = [];
                let allowSeparator = false;
                let isPreviousTokenSeparator = false;
                while (valueChars.length < minCount || scanAsManyAsPossible) {
                    let ch = text.charCodeAt(pos);
                    if (canHaveSeparators && ch === 95 /* _ */) {
                        tokenFlags |= 512 /* ContainsSeparator */;
                        if (allowSeparator) {
                            allowSeparator = false;
                            isPreviousTokenSeparator = true;
                        }
                        else if (isPreviousTokenSeparator) {
                            error2(Diagnostics.Multiple_consecutive_numeric_separators_are_not_permitted, pos, 1);
                        }
                        else {
                            error2(Diagnostics.Numeric_separators_are_not_allowed_here, pos, 1);
                        }
                        pos++;
                        continue;
                    }
                    allowSeparator = canHaveSeparators;
                    if (ch >= 65 /* A */ && ch <= 70 /* F */) {
                        ch += 97 /* a */ - 65 /* A */;
                    }
                    else if (!(ch >= 48 /* _0 */ && ch <= 57 /* _9 */ || ch >= 97 /* a */ && ch <= 102 /* f */)) {
                        break;
                    }
                    valueChars.push(ch);
                    pos++;
                    isPreviousTokenSeparator = false;
                }
                if (valueChars.length < minCount) {
                    valueChars = [];
                }
                if (text.charCodeAt(pos - 1) === 95 /* _ */) {
                    error2(Diagnostics.Numeric_separators_are_not_allowed_here, pos - 1, 1);
                }
                return String.fromCharCode(...valueChars);
            }
            function scanString(jsxAttributeString = false) {
                const quote2 = text.charCodeAt(pos);
                pos++;
                let result = "";
                let start2 = pos;
                while (true) {
                    if (pos >= end) {
                        result += text.substring(start2, pos);
                        tokenFlags |= 4 /* Unterminated */;
                        error2(Diagnostics.Unterminated_string_literal);
                        break;
                    }
                    const ch = text.charCodeAt(pos);
                    if (ch === quote2) {
                        result += text.substring(start2, pos);
                        pos++;
                        break;
                    }
                    if (ch === 92 /* backslash */ && !jsxAttributeString) {
                        result += text.substring(start2, pos);
                        result += scanEscapeSequence(
                        /*shouldEmitInvalidEscapeError*/
                        true);
                        start2 = pos;
                        continue;
                    }
                    if ((ch === 10 /* lineFeed */ || ch === 13 /* carriageReturn */) && !jsxAttributeString) {
                        result += text.substring(start2, pos);
                        tokenFlags |= 4 /* Unterminated */;
                        error2(Diagnostics.Unterminated_string_literal);
                        break;
                    }
                    pos++;
                }
                return result;
            }
            function scanTemplateAndSetTokenValue(shouldEmitInvalidEscapeError) {
                const startedWithBacktick = text.charCodeAt(pos) === 96 /* backtick */;
                pos++;
                let start2 = pos;
                let contents = "";
                let resultingToken;
                while (true) {
                    if (pos >= end) {
                        contents += text.substring(start2, pos);
                        tokenFlags |= 4 /* Unterminated */;
                        error2(Diagnostics.Unterminated_template_literal);
                        resultingToken = startedWithBacktick ? 15 /* NoSubstitutionTemplateLiteral */ : 18 /* TemplateTail */;
                        break;
                    }
                    const currChar = text.charCodeAt(pos);
                    if (currChar === 96 /* backtick */) {
                        contents += text.substring(start2, pos);
                        pos++;
                        resultingToken = startedWithBacktick ? 15 /* NoSubstitutionTemplateLiteral */ : 18 /* TemplateTail */;
                        break;
                    }
                    if (currChar === 36 /* $ */ && pos + 1 < end && text.charCodeAt(pos + 1) === 123 /* openBrace */) {
                        contents += text.substring(start2, pos);
                        pos += 2;
                        resultingToken = startedWithBacktick ? 16 /* TemplateHead */ : 17 /* TemplateMiddle */;
                        break;
                    }
                    if (currChar === 92 /* backslash */) {
                        contents += text.substring(start2, pos);
                        contents += scanEscapeSequence(shouldEmitInvalidEscapeError);
                        start2 = pos;
                        continue;
                    }
                    if (currChar === 13 /* carriageReturn */) {
                        contents += text.substring(start2, pos);
                        pos++;
                        if (pos < end && text.charCodeAt(pos) === 10 /* lineFeed */) {
                            pos++;
                        }
                        contents += "\n";
                        start2 = pos;
                        continue;
                    }
                    pos++;
                }
                Debug.assert(resultingToken !== void 0);
                tokenValue = contents;
                return resultingToken;
            }
            function scanEscapeSequence(shouldEmitInvalidEscapeError) {
                const start2 = pos;
                pos++;
                if (pos >= end) {
                    error2(Diagnostics.Unexpected_end_of_text);
                    return "";
                }
                const ch = text.charCodeAt(pos);
                pos++;
                switch (ch) {
                    case 48 /* _0 */:
                        if (pos >= end || !isDigit(text.charCodeAt(pos))) {
                            return "\0";
                        }
                    case 49 /* _1 */:
                    case 50 /* _2 */:
                    case 51 /* _3 */:
                        if (pos < end && isOctalDigit(text.charCodeAt(pos))) {
                            pos++;
                        }
                    case 52 /* _4 */:
                    case 53 /* _5 */:
                    case 54 /* _6 */:
                    case 55 /* _7 */:
                        if (pos < end && isOctalDigit(text.charCodeAt(pos))) {
                            pos++;
                        }
                        tokenFlags |= 2048 /* ContainsInvalidEscape */;
                        if (shouldEmitInvalidEscapeError) {
                            const code = parseInt(text.substring(start2 + 1, pos), 8);
                            error2(Diagnostics.Octal_escape_sequences_are_not_allowed_Use_the_syntax_0, start2, pos - start2, "\\x" + code.toString(16).padStart(2, "0"));
                            return String.fromCharCode(code);
                        }
                        return text.substring(start2, pos);
                    case 56 /* _8 */:
                    case 57 /* _9 */:
                        tokenFlags |= 2048 /* ContainsInvalidEscape */;
                        if (shouldEmitInvalidEscapeError) {
                            error2(Diagnostics.Escape_sequence_0_is_not_allowed, start2, pos - start2, text.substring(start2, pos));
                            return String.fromCharCode(ch);
                        }
                        return text.substring(start2, pos);
                    case 98 /* b */:
                        return "\b";
                    case 116 /* t */:
                        return "	";
                    case 110 /* n */:
                        return "\n";
                    case 118 /* v */:
                        return "\v";
                    case 102 /* f */:
                        return "\f";
                    case 114 /* r */:
                        return "\r";
                    case 39 /* singleQuote */:
                        return "'";
                    case 34 /* doubleQuote */:
                        return '"';
                    case 117 /* u */:
                        if (pos < end && text.charCodeAt(pos) === 123 /* openBrace */) {
                            pos++;
                            const escapedValueString = scanMinimumNumberOfHexDigits(1, 
                            /*canHaveSeparators*/
                            false);
                            const escapedValue = escapedValueString ? parseInt(escapedValueString, 16) : -1;
                            if (escapedValue < 0) {
                                tokenFlags |= 2048 /* ContainsInvalidEscape */;
                                if (shouldEmitInvalidEscapeError) {
                                    error2(Diagnostics.Hexadecimal_digit_expected);
                                }
                                return text.substring(start2, pos);
                            }
                            if (!isCodePoint(escapedValue)) {
                                tokenFlags |= 2048 /* ContainsInvalidEscape */;
                                if (shouldEmitInvalidEscapeError) {
                                    error2(Diagnostics.An_extended_Unicode_escape_value_must_be_between_0x0_and_0x10FFFF_inclusive);
                                }
                                return text.substring(start2, pos);
                            }
                            if (pos >= end) {
                                tokenFlags |= 2048 /* ContainsInvalidEscape */;
                                if (shouldEmitInvalidEscapeError) {
                                    error2(Diagnostics.Unexpected_end_of_text);
                                }
                                return text.substring(start2, pos);
                            }
                            if (text.charCodeAt(pos) !== 125 /* closeBrace */) {
                                tokenFlags |= 2048 /* ContainsInvalidEscape */;
                                if (shouldEmitInvalidEscapeError) {
                                    error2(Diagnostics.Unterminated_Unicode_escape_sequence);
                                }
                                return text.substring(start2, pos);
                            }
                            pos++;
                            tokenFlags |= 8 /* ExtendedUnicodeEscape */;
                            return utf16EncodeAsString(escapedValue);
                        }
                        for (; pos < start2 + 6; pos++) {
                            if (!(pos < end && isHexDigit(text.charCodeAt(pos)))) {
                                tokenFlags |= 2048 /* ContainsInvalidEscape */;
                                if (shouldEmitInvalidEscapeError) {
                                    error2(Diagnostics.Hexadecimal_digit_expected);
                                }
                                return text.substring(start2, pos);
                            }
                        }
                        tokenFlags |= 1024 /* UnicodeEscape */;
                        return String.fromCharCode(parseInt(text.substring(start2 + 2, pos), 16));
                    case 120 /* x */:
                        for (; pos < start2 + 4; pos++) {
                            if (!(pos < end && isHexDigit(text.charCodeAt(pos)))) {
                                tokenFlags |= 2048 /* ContainsInvalidEscape */;
                                if (shouldEmitInvalidEscapeError) {
                                    error2(Diagnostics.Hexadecimal_digit_expected);
                                }
                                return text.substring(start2, pos);
                            }
                        }
                        tokenFlags |= 4096 /* HexEscape */;
                        return String.fromCharCode(parseInt(text.substring(start2 + 2, pos), 16));
                    case 13 /* carriageReturn */:
                        if (pos < end && text.charCodeAt(pos) === 10 /* lineFeed */) {
                            pos++;
                        }
                    case 10 /* lineFeed */:
                    case 8232 /* lineSeparator */:
                    case 8233 /* paragraphSeparator */:
                        return "";
                    default:
                        return String.fromCharCode(ch);
                }
            }
            function scanExtendedUnicodeEscape() {
                const escapedValueString = scanMinimumNumberOfHexDigits(1, 
                /*canHaveSeparators*/
                false);
                const escapedValue = escapedValueString ? parseInt(escapedValueString, 16) : -1;
                let isInvalidExtendedEscape = false;
                if (escapedValue < 0) {
                    error2(Diagnostics.Hexadecimal_digit_expected);
                    isInvalidExtendedEscape = true;
                }
                else if (escapedValue > 1114111) {
                    error2(Diagnostics.An_extended_Unicode_escape_value_must_be_between_0x0_and_0x10FFFF_inclusive);
                    isInvalidExtendedEscape = true;
                }
                if (pos >= end) {
                    error2(Diagnostics.Unexpected_end_of_text);
                    isInvalidExtendedEscape = true;
                }
                else if (text.charCodeAt(pos) === 125 /* closeBrace */) {
                    pos++;
                }
                else {
                    error2(Diagnostics.Unterminated_Unicode_escape_sequence);
                    isInvalidExtendedEscape = true;
                }
                if (isInvalidExtendedEscape) {
                    return "";
                }
                return utf16EncodeAsString(escapedValue);
            }
            function peekUnicodeEscape() {
                if (pos + 5 < end && text.charCodeAt(pos + 1) === 117 /* u */) {
                    const start2 = pos;
                    pos += 2;
                    const value = scanExactNumberOfHexDigits(4, 
                    /*canHaveSeparators*/
                    false);
                    pos = start2;
                    return value;
                }
                return -1;
            }
            function peekExtendedUnicodeEscape() {
                if (codePointAt(text, pos + 1) === 117 /* u */ && codePointAt(text, pos + 2) === 123 /* openBrace */) {
                    const start2 = pos;
                    pos += 3;
                    const escapedValueString = scanMinimumNumberOfHexDigits(1, 
                    /*canHaveSeparators*/
                    false);
                    const escapedValue = escapedValueString ? parseInt(escapedValueString, 16) : -1;
                    pos = start2;
                    return escapedValue;
                }
                return -1;
            }
            function scanIdentifierParts() {
                let result = "";
                let start2 = pos;
                while (pos < end) {
                    let ch = codePointAt(text, pos);
                    if (isIdentifierPart(ch, languageVersion)) {
                        pos += charSize(ch);
                    }
                    else if (ch === 92 /* backslash */) {
                        ch = peekExtendedUnicodeEscape();
                        if (ch >= 0 && isIdentifierPart(ch, languageVersion)) {
                            pos += 3;
                            tokenFlags |= 8 /* ExtendedUnicodeEscape */;
                            result += scanExtendedUnicodeEscape();
                            start2 = pos;
                            continue;
                        }
                        ch = peekUnicodeEscape();
                        if (!(ch >= 0 && isIdentifierPart(ch, languageVersion))) {
                            break;
                        }
                        tokenFlags |= 1024 /* UnicodeEscape */;
                        result += text.substring(start2, pos);
                        result += utf16EncodeAsString(ch);
                        pos += 6;
                        start2 = pos;
                    }
                    else {
                        break;
                    }
                }
                result += text.substring(start2, pos);
                return result;
            }
            function getIdentifierToken() {
                const len = tokenValue.length;
                if (len >= 2 && len <= 12) {
                    const ch = tokenValue.charCodeAt(0);
                    if (ch >= 97 /* a */ && ch <= 122 /* z */) {
                        const keyword = textToKeyword.get(tokenValue);
                        if (keyword !== void 0) {
                            return token = keyword;
                        }
                    }
                }
                return token = 80 /* Identifier */;
            }
            function scanBinaryOrOctalDigits(base) {
                let value = "";
                let separatorAllowed = false;
                let isPreviousTokenSeparator = false;
                while (true) {
                    const ch = text.charCodeAt(pos);
                    if (ch === 95 /* _ */) {
                        tokenFlags |= 512 /* ContainsSeparator */;
                        if (separatorAllowed) {
                            separatorAllowed = false;
                            isPreviousTokenSeparator = true;
                        }
                        else if (isPreviousTokenSeparator) {
                            error2(Diagnostics.Multiple_consecutive_numeric_separators_are_not_permitted, pos, 1);
                        }
                        else {
                            error2(Diagnostics.Numeric_separators_are_not_allowed_here, pos, 1);
                        }
                        pos++;
                        continue;
                    }
                    separatorAllowed = true;
                    if (!isDigit(ch) || ch - 48 /* _0 */ >= base) {
                        break;
                    }
                    value += text[pos];
                    pos++;
                    isPreviousTokenSeparator = false;
                }
                if (text.charCodeAt(pos - 1) === 95 /* _ */) {
                    error2(Diagnostics.Numeric_separators_are_not_allowed_here, pos - 1, 1);
                }
                return value;
            }
            function checkBigIntSuffix() {
                if (text.charCodeAt(pos) === 110 /* n */) {
                    tokenValue += "n";
                    if (tokenFlags & 384 /* BinaryOrOctalSpecifier */) {
                        tokenValue = parsePseudoBigInt(tokenValue) + "n";
                    }
                    pos++;
                    return 10 /* BigIntLiteral */;
                }
                else {
                    const numericValue = tokenFlags & 128 /* BinarySpecifier */ ? parseInt(tokenValue.slice(2), 2) : tokenFlags & 256 /* OctalSpecifier */ ? parseInt(tokenValue.slice(2), 8) : +tokenValue;
                    tokenValue = "" + numericValue;
                    return 9 /* NumericLiteral */;
                }
            }
            function scan() {
                fullStartPos = pos;
                tokenFlags = 0 /* None */;
                let asteriskSeen = false;
                while (true) {
                    tokenStart = pos;
                    if (pos >= end) {
                        return token = 1 /* EndOfFileToken */;
                    }
                    const ch = codePointAt(text, pos);
                    if (pos === 0) {
                        if (text.slice(0, 256).includes("\uFFFD")) {
                            error2(Diagnostics.File_appears_to_be_binary);
                            pos = end;
                            return token = 8 /* NonTextFileMarkerTrivia */;
                        }
                        if (ch === 35 /* hash */ && isShebangTrivia(text, pos)) {
                            pos = scanShebangTrivia(text, pos);
                            if (skipTrivia2) {
                                continue;
                            }
                            else {
                                return token = 6 /* ShebangTrivia */;
                            }
                        }
                    }
                    switch (ch) {
                        case 10 /* lineFeed */:
                        case 13 /* carriageReturn */:
                            tokenFlags |= 1 /* PrecedingLineBreak */;
                            if (skipTrivia2) {
                                pos++;
                                continue;
                            }
                            else {
                                if (ch === 13 /* carriageReturn */ && pos + 1 < end && text.charCodeAt(pos + 1) === 10 /* lineFeed */) {
                                    pos += 2;
                                }
                                else {
                                    pos++;
                                }
                                return token = 4 /* NewLineTrivia */;
                            }
                        case 9 /* tab */:
                        case 11 /* verticalTab */:
                        case 12 /* formFeed */:
                        case 32 /* space */:
                        case 160 /* nonBreakingSpace */:
                        case 5760 /* ogham */:
                        case 8192 /* enQuad */:
                        case 8193 /* emQuad */:
                        case 8194 /* enSpace */:
                        case 8195 /* emSpace */:
                        case 8196 /* threePerEmSpace */:
                        case 8197 /* fourPerEmSpace */:
                        case 8198 /* sixPerEmSpace */:
                        case 8199 /* figureSpace */:
                        case 8200 /* punctuationSpace */:
                        case 8201 /* thinSpace */:
                        case 8202 /* hairSpace */:
                        case 8203 /* zeroWidthSpace */:
                        case 8239 /* narrowNoBreakSpace */:
                        case 8287 /* mathematicalSpace */:
                        case 12288 /* ideographicSpace */:
                        case 65279 /* byteOrderMark */:
                            if (skipTrivia2) {
                                pos++;
                                continue;
                            }
                            else {
                                while (pos < end && isWhiteSpaceSingleLine(text.charCodeAt(pos))) {
                                    pos++;
                                }
                                return token = 5 /* WhitespaceTrivia */;
                            }
                        case 33 /* exclamation */:
                            if (text.charCodeAt(pos + 1) === 61 /* equals */) {
                                if (text.charCodeAt(pos + 2) === 61 /* equals */) {
                                    return pos += 3, token = 38 /* ExclamationEqualsEqualsToken */;
                                }
                                return pos += 2, token = 36 /* ExclamationEqualsToken */;
                            }
                            pos++;
                            return token = 54 /* ExclamationToken */;
                        case 34 /* doubleQuote */:
                        case 39 /* singleQuote */:
                            tokenValue = scanString();
                            return token = 11 /* StringLiteral */;
                        case 96 /* backtick */:
                            return token = scanTemplateAndSetTokenValue(
                            /*shouldEmitInvalidEscapeError*/
                            false);
                        case 37 /* percent */:
                            if (text.charCodeAt(pos + 1) === 61 /* equals */) {
                                return pos += 2, token = 70 /* PercentEqualsToken */;
                            }
                            pos++;
                            return token = 45 /* PercentToken */;
                        case 38 /* ampersand */:
                            if (text.charCodeAt(pos + 1) === 38 /* ampersand */) {
                                if (text.charCodeAt(pos + 2) === 61 /* equals */) {
                                    return pos += 3, token = 77 /* AmpersandAmpersandEqualsToken */;
                                }
                                return pos += 2, token = 56 /* AmpersandAmpersandToken */;
                            }
                            if (text.charCodeAt(pos + 1) === 61 /* equals */) {
                                return pos += 2, token = 74 /* AmpersandEqualsToken */;
                            }
                            pos++;
                            return token = 51 /* AmpersandToken */;
                        case 40 /* openParen */:
                            pos++;
                            return token = 21 /* OpenParenToken */;
                        case 41 /* closeParen */:
                            pos++;
                            return token = 22 /* CloseParenToken */;
                        case 42 /* asterisk */:
                            if (text.charCodeAt(pos + 1) === 61 /* equals */) {
                                return pos += 2, token = 67 /* AsteriskEqualsToken */;
                            }
                            if (text.charCodeAt(pos + 1) === 42 /* asterisk */) {
                                if (text.charCodeAt(pos + 2) === 61 /* equals */) {
                                    return pos += 3, token = 68 /* AsteriskAsteriskEqualsToken */;
                                }
                                return pos += 2, token = 43 /* AsteriskAsteriskToken */;
                            }
                            pos++;
                            if (inJSDocType && !asteriskSeen && tokenFlags & 1 /* PrecedingLineBreak */) {
                                asteriskSeen = true;
                                continue;
                            }
                            return token = 42 /* AsteriskToken */;
                        case 43 /* plus */:
                            if (text.charCodeAt(pos + 1) === 43 /* plus */) {
                                return pos += 2, token = 46 /* PlusPlusToken */;
                            }
                            if (text.charCodeAt(pos + 1) === 61 /* equals */) {
                                return pos += 2, token = 65 /* PlusEqualsToken */;
                            }
                            pos++;
                            return token = 40 /* PlusToken */;
                        case 44 /* comma */:
                            pos++;
                            return token = 28 /* CommaToken */;
                        case 45 /* minus */:
                            if (text.charCodeAt(pos + 1) === 45 /* minus */) {
                                return pos += 2, token = 47 /* MinusMinusToken */;
                            }
                            if (text.charCodeAt(pos + 1) === 61 /* equals */) {
                                return pos += 2, token = 66 /* MinusEqualsToken */;
                            }
                            pos++;
                            return token = 41 /* MinusToken */;
                        case 46 /* dot */:
                            if (isDigit(text.charCodeAt(pos + 1))) {
                                scanNumber();
                                return token = 9 /* NumericLiteral */;
                            }
                            if (text.charCodeAt(pos + 1) === 46 /* dot */ && text.charCodeAt(pos + 2) === 46 /* dot */) {
                                return pos += 3, token = 26 /* DotDotDotToken */;
                            }
                            pos++;
                            return token = 25 /* DotToken */;
                        case 47 /* slash */:
                            if (text.charCodeAt(pos + 1) === 47 /* slash */) {
                                pos += 2;
                                while (pos < end) {
                                    if (isLineBreak(text.charCodeAt(pos))) {
                                        break;
                                    }
                                    pos++;
                                }
                                commentDirectives = appendIfCommentDirective(commentDirectives, text.slice(tokenStart, pos), commentDirectiveRegExSingleLine, tokenStart);
                                if (skipTrivia2) {
                                    continue;
                                }
                                else {
                                    return token = 2 /* SingleLineCommentTrivia */;
                                }
                            }
                            if (text.charCodeAt(pos + 1) === 42 /* asterisk */) {
                                pos += 2;
                                const isJSDoc2 = text.charCodeAt(pos) === 42 /* asterisk */ && text.charCodeAt(pos + 1) !== 47 /* slash */;
                                let commentClosed = false;
                                let lastLineStart = tokenStart;
                                while (pos < end) {
                                    const ch2 = text.charCodeAt(pos);
                                    if (ch2 === 42 /* asterisk */ && text.charCodeAt(pos + 1) === 47 /* slash */) {
                                        pos += 2;
                                        commentClosed = true;
                                        break;
                                    }
                                    pos++;
                                    if (isLineBreak(ch2)) {
                                        lastLineStart = pos;
                                        tokenFlags |= 1 /* PrecedingLineBreak */;
                                    }
                                }
                                if (isJSDoc2 && shouldParseJSDoc()) {
                                    tokenFlags |= 2 /* PrecedingJSDocComment */;
                                }
                                commentDirectives = appendIfCommentDirective(commentDirectives, text.slice(lastLineStart, pos), commentDirectiveRegExMultiLine, lastLineStart);
                                if (!commentClosed) {
                                    error2(Diagnostics.Asterisk_Slash_expected);
                                }
                                if (skipTrivia2) {
                                    continue;
                                }
                                else {
                                    if (!commentClosed) {
                                        tokenFlags |= 4 /* Unterminated */;
                                    }
                                    return token = 3 /* MultiLineCommentTrivia */;
                                }
                            }
                            if (text.charCodeAt(pos + 1) === 61 /* equals */) {
                                return pos += 2, token = 69 /* SlashEqualsToken */;
                            }
                            pos++;
                            return token = 44 /* SlashToken */;
                        case 48 /* _0 */:
                            if (pos + 2 < end && (text.charCodeAt(pos + 1) === 88 /* X */ || text.charCodeAt(pos + 1) === 120 /* x */)) {
                                pos += 2;
                                tokenValue = scanMinimumNumberOfHexDigits(1, 
                                /*canHaveSeparators*/
                                true);
                                if (!tokenValue) {
                                    error2(Diagnostics.Hexadecimal_digit_expected);
                                    tokenValue = "0";
                                }
                                tokenValue = "0x" + tokenValue;
                                tokenFlags |= 64 /* HexSpecifier */;
                                return token = checkBigIntSuffix();
                            }
                            else if (pos + 2 < end && (text.charCodeAt(pos + 1) === 66 /* B */ || text.charCodeAt(pos + 1) === 98 /* b */)) {
                                pos += 2;
                                tokenValue = scanBinaryOrOctalDigits(
                                /* base */
                                2);
                                if (!tokenValue) {
                                    error2(Diagnostics.Binary_digit_expected);
                                    tokenValue = "0";
                                }
                                tokenValue = "0b" + tokenValue;
                                tokenFlags |= 128 /* BinarySpecifier */;
                                return token = checkBigIntSuffix();
                            }
                            else if (pos + 2 < end && (text.charCodeAt(pos + 1) === 79 /* O */ || text.charCodeAt(pos + 1) === 111 /* o */)) {
                                pos += 2;
                                tokenValue = scanBinaryOrOctalDigits(
                                /* base */
                                8);
                                if (!tokenValue) {
                                    error2(Diagnostics.Octal_digit_expected);
                                    tokenValue = "0";
                                }
                                tokenValue = "0o" + tokenValue;
                                tokenFlags |= 256 /* OctalSpecifier */;
                                return token = checkBigIntSuffix();
                            }
                        case 49 /* _1 */:
                        case 50 /* _2 */:
                        case 51 /* _3 */:
                        case 52 /* _4 */:
                        case 53 /* _5 */:
                        case 54 /* _6 */:
                        case 55 /* _7 */:
                        case 56 /* _8 */:
                        case 57 /* _9 */:
                            return token = scanNumber();
                        case 58 /* colon */:
                            pos++;
                            return token = 59 /* ColonToken */;
                        case 59 /* semicolon */:
                            pos++;
                            return token = 27 /* SemicolonToken */;
                        case 60 /* lessThan */:
                            if (isConflictMarkerTrivia(text, pos)) {
                                pos = scanConflictMarkerTrivia(text, pos, error2);
                                if (skipTrivia2) {
                                    continue;
                                }
                                else {
                                    return token = 7 /* ConflictMarkerTrivia */;
                                }
                            }
                            if (text.charCodeAt(pos + 1) === 60 /* lessThan */) {
                                if (text.charCodeAt(pos + 2) === 61 /* equals */) {
                                    return pos += 3, token = 71 /* LessThanLessThanEqualsToken */;
                                }
                                return pos += 2, token = 48 /* LessThanLessThanToken */;
                            }
                            if (text.charCodeAt(pos + 1) === 61 /* equals */) {
                                return pos += 2, token = 33 /* LessThanEqualsToken */;
                            }
                            if (languageVariant === 1 /* JSX */ && text.charCodeAt(pos + 1) === 47 /* slash */ && text.charCodeAt(pos + 2) !== 42 /* asterisk */) {
                                return pos += 2, token = 31 /* LessThanSlashToken */;
                            }
                            pos++;
                            return token = 30 /* LessThanToken */;
                        case 61 /* equals */:
                            if (isConflictMarkerTrivia(text, pos)) {
                                pos = scanConflictMarkerTrivia(text, pos, error2);
                                if (skipTrivia2) {
                                    continue;
                                }
                                else {
                                    return token = 7 /* ConflictMarkerTrivia */;
                                }
                            }
                            if (text.charCodeAt(pos + 1) === 61 /* equals */) {
                                if (text.charCodeAt(pos + 2) === 61 /* equals */) {
                                    return pos += 3, token = 37 /* EqualsEqualsEqualsToken */;
                                }
                                return pos += 2, token = 35 /* EqualsEqualsToken */;
                            }
                            if (text.charCodeAt(pos + 1) === 62 /* greaterThan */) {
                                return pos += 2, token = 39 /* EqualsGreaterThanToken */;
                            }
                            pos++;
                            return token = 64 /* EqualsToken */;
                        case 62 /* greaterThan */:
                            if (isConflictMarkerTrivia(text, pos)) {
                                pos = scanConflictMarkerTrivia(text, pos, error2);
                                if (skipTrivia2) {
                                    continue;
                                }
                                else {
                                    return token = 7 /* ConflictMarkerTrivia */;
                                }
                            }
                            pos++;
                            return token = 32 /* GreaterThanToken */;
                        case 63 /* question */:
                            if (text.charCodeAt(pos + 1) === 46 /* dot */ && !isDigit(text.charCodeAt(pos + 2))) {
                                return pos += 2, token = 29 /* QuestionDotToken */;
                            }
                            if (text.charCodeAt(pos + 1) === 63 /* question */) {
                                if (text.charCodeAt(pos + 2) === 61 /* equals */) {
                                    return pos += 3, token = 78 /* QuestionQuestionEqualsToken */;
                                }
                                return pos += 2, token = 61 /* QuestionQuestionToken */;
                            }
                            pos++;
                            return token = 58 /* QuestionToken */;
                        case 91 /* openBracket */:
                            pos++;
                            return token = 23 /* OpenBracketToken */;
                        case 93 /* closeBracket */:
                            pos++;
                            return token = 24 /* CloseBracketToken */;
                        case 94 /* caret */:
                            if (text.charCodeAt(pos + 1) === 61 /* equals */) {
                                return pos += 2, token = 79 /* CaretEqualsToken */;
                            }
                            pos++;
                            return token = 53 /* CaretToken */;
                        case 123 /* openBrace */:
                            pos++;
                            return token = 19 /* OpenBraceToken */;
                        case 124 /* bar */:
                            if (isConflictMarkerTrivia(text, pos)) {
                                pos = scanConflictMarkerTrivia(text, pos, error2);
                                if (skipTrivia2) {
                                    continue;
                                }
                                else {
                                    return token = 7 /* ConflictMarkerTrivia */;
                                }
                            }
                            if (text.charCodeAt(pos + 1) === 124 /* bar */) {
                                if (text.charCodeAt(pos + 2) === 61 /* equals */) {
                                    return pos += 3, token = 76 /* BarBarEqualsToken */;
                                }
                                return pos += 2, token = 57 /* BarBarToken */;
                            }
                            if (text.charCodeAt(pos + 1) === 61 /* equals */) {
                                return pos += 2, token = 75 /* BarEqualsToken */;
                            }
                            pos++;
                            return token = 52 /* BarToken */;
                        case 125 /* closeBrace */:
                            pos++;
                            return token = 20 /* CloseBraceToken */;
                        case 126 /* tilde */:
                            pos++;
                            return token = 55 /* TildeToken */;
                        case 64 /* at */:
                            pos++;
                            return token = 60 /* AtToken */;
                        case 92 /* backslash */:
                            const extendedCookedChar = peekExtendedUnicodeEscape();
                            if (extendedCookedChar >= 0 && isIdentifierStart(extendedCookedChar, languageVersion)) {
                                pos += 3;
                                tokenFlags |= 8 /* ExtendedUnicodeEscape */;
                                tokenValue = scanExtendedUnicodeEscape() + scanIdentifierParts();
                                return token = getIdentifierToken();
                            }
                            const cookedChar = peekUnicodeEscape();
                            if (cookedChar >= 0 && isIdentifierStart(cookedChar, languageVersion)) {
                                pos += 6;
                                tokenFlags |= 1024 /* UnicodeEscape */;
                                tokenValue = String.fromCharCode(cookedChar) + scanIdentifierParts();
                                return token = getIdentifierToken();
                            }
                            error2(Diagnostics.Invalid_character);
                            pos++;
                            return token = 0 /* Unknown */;
                        case 35 /* hash */:
                            if (pos !== 0 && text[pos + 1] === "!") {
                                error2(Diagnostics.can_only_be_used_at_the_start_of_a_file);
                                pos++;
                                return token = 0 /* Unknown */;
                            }
                            const charAfterHash = codePointAt(text, pos + 1);
                            if (charAfterHash === 92 /* backslash */) {
                                pos++;
                                const extendedCookedChar2 = peekExtendedUnicodeEscape();
                                if (extendedCookedChar2 >= 0 && isIdentifierStart(extendedCookedChar2, languageVersion)) {
                                    pos += 3;
                                    tokenFlags |= 8 /* ExtendedUnicodeEscape */;
                                    tokenValue = "#" + scanExtendedUnicodeEscape() + scanIdentifierParts();
                                    return token = 81 /* PrivateIdentifier */;
                                }
                                const cookedChar2 = peekUnicodeEscape();
                                if (cookedChar2 >= 0 && isIdentifierStart(cookedChar2, languageVersion)) {
                                    pos += 6;
                                    tokenFlags |= 1024 /* UnicodeEscape */;
                                    tokenValue = "#" + String.fromCharCode(cookedChar2) + scanIdentifierParts();
                                    return token = 81 /* PrivateIdentifier */;
                                }
                                pos--;
                            }
                            if (isIdentifierStart(charAfterHash, languageVersion)) {
                                pos++;
                                scanIdentifier(charAfterHash, languageVersion);
                            }
                            else {
                                tokenValue = "#";
                                error2(Diagnostics.Invalid_character, pos++, charSize(ch));
                            }
                            return token = 81 /* PrivateIdentifier */;
                        default:
                            const identifierKind = scanIdentifier(ch, languageVersion);
                            if (identifierKind) {
                                return token = identifierKind;
                            }
                            else if (isWhiteSpaceSingleLine(ch)) {
                                pos += charSize(ch);
                                continue;
                            }
                            else if (isLineBreak(ch)) {
                                tokenFlags |= 1 /* PrecedingLineBreak */;
                                pos += charSize(ch);
                                continue;
                            }
                            const size = charSize(ch);
                            error2(Diagnostics.Invalid_character, pos, size);
                            pos += size;
                            return token = 0 /* Unknown */;
                    }
                }
            }
            function shouldParseJSDoc() {
                switch (jsDocParsingMode) {
                    case 0 /* ParseAll */:
                        return true;
                    case 1 /* ParseNone */:
                        return false;
                }
                if (scriptKind !== 3 /* TS */ && scriptKind !== 4 /* TSX */) {
                    return true;
                }
                if (jsDocParsingMode === 3 /* ParseForTypeInfo */) {
                    return false;
                }
                return jsDocSeeOrLink.test(text.slice(fullStartPos, pos));
            }
            function reScanInvalidIdentifier() {
                Debug.assert(token === 0 /* Unknown */, "'reScanInvalidIdentifier' should only be called when the current token is 'SyntaxKind.Unknown'.");
                pos = tokenStart = fullStartPos;
                tokenFlags = 0;
                const ch = codePointAt(text, pos);
                const identifierKind = scanIdentifier(ch, 99 /* ESNext */);
                if (identifierKind) {
                    return token = identifierKind;
                }
                pos += charSize(ch);
                return token;
            }
            function scanIdentifier(startCharacter, languageVersion2) {
                let ch = startCharacter;
                if (isIdentifierStart(ch, languageVersion2)) {
                    pos += charSize(ch);
                    while (pos < end && isIdentifierPart(ch = codePointAt(text, pos), languageVersion2))
                        pos += charSize(ch);
                    tokenValue = text.substring(tokenStart, pos);
                    if (ch === 92 /* backslash */) {
                        tokenValue += scanIdentifierParts();
                    }
                    return getIdentifierToken();
                }
            }
            function reScanGreaterToken() {
                if (token === 32 /* GreaterThanToken */) {
                    if (text.charCodeAt(pos) === 62 /* greaterThan */) {
                        if (text.charCodeAt(pos + 1) === 62 /* greaterThan */) {
                            if (text.charCodeAt(pos + 2) === 61 /* equals */) {
                                return pos += 3, token = 73 /* GreaterThanGreaterThanGreaterThanEqualsToken */;
                            }
                            return pos += 2, token = 50 /* GreaterThanGreaterThanGreaterThanToken */;
                        }
                        if (text.charCodeAt(pos + 1) === 61 /* equals */) {
                            return pos += 2, token = 72 /* GreaterThanGreaterThanEqualsToken */;
                        }
                        pos++;
                        return token = 49 /* GreaterThanGreaterThanToken */;
                    }
                    if (text.charCodeAt(pos) === 61 /* equals */) {
                        pos++;
                        return token = 34 /* GreaterThanEqualsToken */;
                    }
                }
                return token;
            }
            function reScanAsteriskEqualsToken() {
                Debug.assert(token === 67 /* AsteriskEqualsToken */, "'reScanAsteriskEqualsToken' should only be called on a '*='");
                pos = tokenStart + 1;
                return token = 64 /* EqualsToken */;
            }
            function reScanSlashToken() {
                if (token === 44 /* SlashToken */ || token === 69 /* SlashEqualsToken */) {
                    let p = tokenStart + 1;
                    let inEscape = false;
                    let inCharacterClass = false;
                    while (true) {
                        if (p >= end) {
                            tokenFlags |= 4 /* Unterminated */;
                            error2(Diagnostics.Unterminated_regular_expression_literal);
                            break;
                        }
                        const ch = text.charCodeAt(p);
                        if (isLineBreak(ch)) {
                            tokenFlags |= 4 /* Unterminated */;
                            error2(Diagnostics.Unterminated_regular_expression_literal);
                            break;
                        }
                        if (inEscape) {
                            inEscape = false;
                        }
                        else if (ch === 47 /* slash */ && !inCharacterClass) {
                            p++;
                            break;
                        }
                        else if (ch === 91 /* openBracket */) {
                            inCharacterClass = true;
                        }
                        else if (ch === 92 /* backslash */) {
                            inEscape = true;
                        }
                        else if (ch === 93 /* closeBracket */) {
                            inCharacterClass = false;
                        }
                        p++;
                    }
                    while (p < end && isIdentifierPart(text.charCodeAt(p), languageVersion)) {
                        p++;
                    }
                    pos = p;
                    tokenValue = text.substring(tokenStart, pos);
                    token = 14 /* RegularExpressionLiteral */;
                }
                return token;
            }
            function appendIfCommentDirective(commentDirectives2, text2, commentDirectiveRegEx, lineStart) {
                const type = getDirectiveFromComment(text2.trimStart(), commentDirectiveRegEx);
                if (type === void 0) {
                    return commentDirectives2;
                }
                return append(commentDirectives2, {
                    range: { pos: lineStart, end: pos },
                    type
                });
            }
            function getDirectiveFromComment(text2, commentDirectiveRegEx) {
                const match = commentDirectiveRegEx.exec(text2);
                if (!match) {
                    return void 0;
                }
                switch (match[1]) {
                    case "ts-expect-error":
                        return 0 /* ExpectError */;
                    case "ts-ignore":
                        return 1 /* Ignore */;
                }
                return void 0;
            }
            function reScanTemplateToken(isTaggedTemplate) {
                pos = tokenStart;
                return token = scanTemplateAndSetTokenValue(!isTaggedTemplate);
            }
            function reScanTemplateHeadOrNoSubstitutionTemplate() {
                pos = tokenStart;
                return token = scanTemplateAndSetTokenValue(
                /*shouldEmitInvalidEscapeError*/
                true);
            }
            function reScanJsxToken(allowMultilineJsxText = true) {
                pos = tokenStart = fullStartPos;
                return token = scanJsxToken(allowMultilineJsxText);
            }
            function reScanLessThanToken() {
                if (token === 48 /* LessThanLessThanToken */) {
                    pos = tokenStart + 1;
                    return token = 30 /* LessThanToken */;
                }
                return token;
            }
            function reScanHashToken() {
                if (token === 81 /* PrivateIdentifier */) {
                    pos = tokenStart + 1;
                    return token = 63 /* HashToken */;
                }
                return token;
            }
            function reScanQuestionToken() {
                Debug.assert(token === 61 /* QuestionQuestionToken */, "'reScanQuestionToken' should only be called on a '??'");
                pos = tokenStart + 1;
                return token = 58 /* QuestionToken */;
            }
            function scanJsxToken(allowMultilineJsxText = true) {
                fullStartPos = tokenStart = pos;
                if (pos >= end) {
                    return token = 1 /* EndOfFileToken */;
                }
                let char = text.charCodeAt(pos);
                if (char === 60 /* lessThan */) {
                    if (text.charCodeAt(pos + 1) === 47 /* slash */) {
                        pos += 2;
                        return token = 31 /* LessThanSlashToken */;
                    }
                    pos++;
                    return token = 30 /* LessThanToken */;
                }
                if (char === 123 /* openBrace */) {
                    pos++;
                    return token = 19 /* OpenBraceToken */;
                }
                let firstNonWhitespace = 0;
                while (pos < end) {
                    char = text.charCodeAt(pos);
                    if (char === 123 /* openBrace */) {
                        break;
                    }
                    if (char === 60 /* lessThan */) {
                        if (isConflictMarkerTrivia(text, pos)) {
                            pos = scanConflictMarkerTrivia(text, pos, error2);
                            return token = 7 /* ConflictMarkerTrivia */;
                        }
                        break;
                    }
                    if (char === 62 /* greaterThan */) {
                        error2(Diagnostics.Unexpected_token_Did_you_mean_or_gt, pos, 1);
                    }
                    if (char === 125 /* closeBrace */) {
                        error2(Diagnostics.Unexpected_token_Did_you_mean_or_rbrace, pos, 1);
                    }
                    if (isLineBreak(char) && firstNonWhitespace === 0) {
                        firstNonWhitespace = -1;
                    }
                    else if (!allowMultilineJsxText && isLineBreak(char) && firstNonWhitespace > 0) {
                        break;
                    }
                    else if (!isWhiteSpaceLike(char)) {
                        firstNonWhitespace = pos;
                    }
                    pos++;
                }
                tokenValue = text.substring(fullStartPos, pos);
                return firstNonWhitespace === -1 ? 13 /* JsxTextAllWhiteSpaces */ : 12 /* JsxText */;
            }
            function scanJsxIdentifier() {
                if (tokenIsIdentifierOrKeyword(token)) {
                    while (pos < end) {
                        const ch = text.charCodeAt(pos);
                        if (ch === 45 /* minus */) {
                            tokenValue += "-";
                            pos++;
                            continue;
                        }
                        const oldPos = pos;
                        tokenValue += scanIdentifierParts();
                        if (pos === oldPos) {
                            break;
                        }
                    }
                    return getIdentifierToken();
                }
                return token;
            }
            function scanJsxAttributeValue() {
                fullStartPos = pos;
                switch (text.charCodeAt(pos)) {
                    case 34 /* doubleQuote */:
                    case 39 /* singleQuote */:
                        tokenValue = scanString(
                        /*jsxAttributeString*/
                        true);
                        return token = 11 /* StringLiteral */;
                    default:
                        return scan();
                }
            }
            function reScanJsxAttributeValue() {
                pos = tokenStart = fullStartPos;
                return scanJsxAttributeValue();
            }
            function scanJSDocCommentTextToken(inBackticks) {
                fullStartPos = tokenStart = pos;
                tokenFlags = 0 /* None */;
                if (pos >= end) {
                    return token = 1 /* EndOfFileToken */;
                }
                for (let ch = text.charCodeAt(pos); pos < end && (!isLineBreak(ch) && ch !== 96 /* backtick */); ch = codePointAt(text, ++pos)) {
                    if (!inBackticks) {
                        if (ch === 123 /* openBrace */) {
                            break;
                        }
                        else if (ch === 64 /* at */ && pos - 1 >= 0 && isWhiteSpaceSingleLine(text.charCodeAt(pos - 1)) && !(pos + 1 < end && isWhiteSpaceLike(text.charCodeAt(pos + 1)))) {
                            break;
                        }
                    }
                }
                if (pos === tokenStart) {
                    return scanJsDocToken();
                }
                tokenValue = text.substring(tokenStart, pos);
                return token = 82 /* JSDocCommentTextToken */;
            }
            function scanJsDocToken() {
                fullStartPos = tokenStart = pos;
                tokenFlags = 0 /* None */;
                if (pos >= end) {
                    return token = 1 /* EndOfFileToken */;
                }
                const ch = codePointAt(text, pos);
                pos += charSize(ch);
                switch (ch) {
                    case 9 /* tab */:
                    case 11 /* verticalTab */:
                    case 12 /* formFeed */:
                    case 32 /* space */:
                        while (pos < end && isWhiteSpaceSingleLine(text.charCodeAt(pos))) {
                            pos++;
                        }
                        return token = 5 /* WhitespaceTrivia */;
                    case 64 /* at */:
                        return token = 60 /* AtToken */;
                    case 13 /* carriageReturn */:
                        if (text.charCodeAt(pos) === 10 /* lineFeed */) {
                            pos++;
                        }
                    case 10 /* lineFeed */:
                        tokenFlags |= 1 /* PrecedingLineBreak */;
                        return token = 4 /* NewLineTrivia */;
                    case 42 /* asterisk */:
                        return token = 42 /* AsteriskToken */;
                    case 123 /* openBrace */:
                        return token = 19 /* OpenBraceToken */;
                    case 125 /* closeBrace */:
                        return token = 20 /* CloseBraceToken */;
                    case 91 /* openBracket */:
                        return token = 23 /* OpenBracketToken */;
                    case 93 /* closeBracket */:
                        return token = 24 /* CloseBracketToken */;
                    case 60 /* lessThan */:
                        return token = 30 /* LessThanToken */;
                    case 62 /* greaterThan */:
                        return token = 32 /* GreaterThanToken */;
                    case 61 /* equals */:
                        return token = 64 /* EqualsToken */;
                    case 44 /* comma */:
                        return token = 28 /* CommaToken */;
                    case 46 /* dot */:
                        return token = 25 /* DotToken */;
                    case 96 /* backtick */:
                        return token = 62 /* BacktickToken */;
                    case 35 /* hash */:
                        return token = 63 /* HashToken */;
                    case 92 /* backslash */:
                        pos--;
                        const extendedCookedChar = peekExtendedUnicodeEscape();
                        if (extendedCookedChar >= 0 && isIdentifierStart(extendedCookedChar, languageVersion)) {
                            pos += 3;
                            tokenFlags |= 8 /* ExtendedUnicodeEscape */;
                            tokenValue = scanExtendedUnicodeEscape() + scanIdentifierParts();
                            return token = getIdentifierToken();
                        }
                        const cookedChar = peekUnicodeEscape();
                        if (cookedChar >= 0 && isIdentifierStart(cookedChar, languageVersion)) {
                            pos += 6;
                            tokenFlags |= 1024 /* UnicodeEscape */;
                            tokenValue = String.fromCharCode(cookedChar) + scanIdentifierParts();
                            return token = getIdentifierToken();
                        }
                        pos++;
                        return token = 0 /* Unknown */;
                }
                if (isIdentifierStart(ch, languageVersion)) {
                    let char = ch;
                    while (pos < end && isIdentifierPart(char = codePointAt(text, pos), languageVersion) || text.charCodeAt(pos) === 45 /* minus */)
                        pos += charSize(char);
                    tokenValue = text.substring(tokenStart, pos);
                    if (char === 92 /* backslash */) {
                        tokenValue += scanIdentifierParts();
                    }
                    return token = getIdentifierToken();
                }
                else {
                    return token = 0 /* Unknown */;
                }
            }
            function speculationHelper(callback, isLookahead) {
                const savePos = pos;
                const saveStartPos = fullStartPos;
                const saveTokenPos = tokenStart;
                const saveToken = token;
                const saveTokenValue = tokenValue;
                const saveTokenFlags = tokenFlags;
                const result = callback();
                if (!result || isLookahead) {
                    pos = savePos;
                    fullStartPos = saveStartPos;
                    tokenStart = saveTokenPos;
                    token = saveToken;
                    tokenValue = saveTokenValue;
                    tokenFlags = saveTokenFlags;
                }
                return result;
            }
            function scanRange(start2, length3, callback) {
                const saveEnd = end;
                const savePos = pos;
                const saveStartPos = fullStartPos;
                const saveTokenPos = tokenStart;
                const saveToken = token;
                const saveTokenValue = tokenValue;
                const saveTokenFlags = tokenFlags;
                const saveErrorExpectations = commentDirectives;
                setText(text, start2, length3);
                const result = callback();
                end = saveEnd;
                pos = savePos;
                fullStartPos = saveStartPos;
                tokenStart = saveTokenPos;
                token = saveToken;
                tokenValue = saveTokenValue;
                tokenFlags = saveTokenFlags;
                commentDirectives = saveErrorExpectations;
                return result;
            }
            function lookAhead(callback) {
                return speculationHelper(callback, 
                /*isLookahead*/
                true);
            }
            function tryScan(callback) {
                return speculationHelper(callback, 
                /*isLookahead*/
                false);
            }
            function getText() {
                return text;
            }
            function clearCommentDirectives() {
                commentDirectives = void 0;
            }
            function setText(newText, start2, length3) {
                text = newText || "";
                end = length3 === void 0 ? text.length : start2 + length3;
                resetTokenState(start2 || 0);
            }
            function setOnError(errorCallback) {
                onError = errorCallback;
            }
            function setScriptTarget(scriptTarget) {
                languageVersion = scriptTarget;
            }
            function setLanguageVariant(variant) {
                languageVariant = variant;
            }
            function setScriptKind(kind) {
                scriptKind = kind;
            }
            function setJSDocParsingMode(kind) {
                jsDocParsingMode = kind;
            }
            function resetTokenState(position) {
                Debug.assert(position >= 0);
                pos = position;
                fullStartPos = position;
                tokenStart = position;
                token = 0 /* Unknown */;
                tokenValue = void 0;
                tokenFlags = 0 /* None */;
            }
            function setInJSDocType(inType) {
                inJSDocType += inType ? 1 : -1;
            }
        }
        function codePointAt(s, i) {
            return s.codePointAt(i);
        }
        function charSize(ch) {
            if (ch >= 65536) {
                return 2;
            }
            return 1;
        }
        function utf16EncodeAsStringFallback(codePoint) {
            Debug.assert(0 <= codePoint && codePoint <= 1114111);
            if (codePoint <= 65535) {
                return String.fromCharCode(codePoint);
            }
            const codeUnit1 = Math.floor((codePoint - 65536) / 1024) + 55296;
            const codeUnit2 = (codePoint - 65536) % 1024 + 56320;
            return String.fromCharCode(codeUnit1, codeUnit2);
        }
        function utf16EncodeAsString(codePoint) {
            return utf16EncodeAsStringWorker(codePoint);
        }
        var textToKeywordObj, textToKeyword, textToToken, unicodeES3IdentifierStart, unicodeES3IdentifierPart, unicodeES5IdentifierStart, unicodeES5IdentifierPart, unicodeESNextIdentifierStart, unicodeESNextIdentifierPart, commentDirectiveRegExSingleLine, commentDirectiveRegExMultiLine, jsDocSeeOrLink, tokenStrings, mergeConflictMarkerLength, shebangTriviaRegex, utf16EncodeAsStringWorker;
        var init_scanner = __esm({
            "src/compiler/scanner.ts"() {
                "use strict";
                init_ts2();
                textToKeywordObj = {
                    abstract: 128 /* AbstractKeyword */,
                    accessor: 129 /* AccessorKeyword */,
                    any: 133 /* AnyKeyword */,
                    as: 130 /* AsKeyword */,
                    asserts: 131 /* AssertsKeyword */,
                    assert: 132 /* AssertKeyword */,
                    bigint: 163 /* BigIntKeyword */,
                    boolean: 136 /* BooleanKeyword */,
                    break: 83 /* BreakKeyword */,
                    case: 84 /* CaseKeyword */,
                    catch: 85 /* CatchKeyword */,
                    class: 86 /* ClassKeyword */,
                    continue: 88 /* ContinueKeyword */,
                    const: 87 /* ConstKeyword */,
                    ["constructor"]: 137 /* ConstructorKeyword */,
                    debugger: 89 /* DebuggerKeyword */,
                    declare: 138 /* DeclareKeyword */,
                    default: 90 /* DefaultKeyword */,
                    delete: 91 /* DeleteKeyword */,
                    do: 92 /* DoKeyword */,
                    else: 93 /* ElseKeyword */,
                    enum: 94 /* EnumKeyword */,
                    export: 95 /* ExportKeyword */,
                    extends: 96 /* ExtendsKeyword */,
                    false: 97 /* FalseKeyword */,
                    finally: 98 /* FinallyKeyword */,
                    for: 99 /* ForKeyword */,
                    from: 161 /* FromKeyword */,
                    function: 100 /* FunctionKeyword */,
                    get: 139 /* GetKeyword */,
                    if: 101 /* IfKeyword */,
                    implements: 119 /* ImplementsKeyword */,
                    import: 102 /* ImportKeyword */,
                    in: 103 /* InKeyword */,
                    infer: 140 /* InferKeyword */,
                    instanceof: 104 /* InstanceOfKeyword */,
                    interface: 120 /* InterfaceKeyword */,
                    intrinsic: 141 /* IntrinsicKeyword */,
                    is: 142 /* IsKeyword */,
                    keyof: 143 /* KeyOfKeyword */,
                    let: 121 /* LetKeyword */,
                    module: 144 /* ModuleKeyword */,
                    namespace: 145 /* NamespaceKeyword */,
                    never: 146 /* NeverKeyword */,
                    new: 105 /* NewKeyword */,
                    null: 106 /* NullKeyword */,
                    number: 150 /* NumberKeyword */,
                    object: 151 /* ObjectKeyword */,
                    package: 122 /* PackageKeyword */,
                    private: 123 /* PrivateKeyword */,
                    protected: 124 /* ProtectedKeyword */,
                    public: 125 /* PublicKeyword */,
                    override: 164 /* OverrideKeyword */,
                    out: 147 /* OutKeyword */,
                    readonly: 148 /* ReadonlyKeyword */,
                    require: 149 /* RequireKeyword */,
                    global: 162 /* GlobalKeyword */,
                    return: 107 /* ReturnKeyword */,
                    satisfies: 152 /* SatisfiesKeyword */,
                    set: 153 /* SetKeyword */,
                    static: 126 /* StaticKeyword */,
                    string: 154 /* StringKeyword */,
                    super: 108 /* SuperKeyword */,
                    switch: 109 /* SwitchKeyword */,
                    symbol: 155 /* SymbolKeyword */,
                    this: 110 /* ThisKeyword */,
                    throw: 111 /* ThrowKeyword */,
                    true: 112 /* TrueKeyword */,
                    try: 113 /* TryKeyword */,
                    type: 156 /* TypeKeyword */,
                    typeof: 114 /* TypeOfKeyword */,
                    undefined: 157 /* UndefinedKeyword */,
                    unique: 158 /* UniqueKeyword */,
                    unknown: 159 /* UnknownKeyword */,
                    using: 160 /* UsingKeyword */,
                    var: 115 /* VarKeyword */,
                    void: 116 /* VoidKeyword */,
                    while: 117 /* WhileKeyword */,
                    with: 118 /* WithKeyword */,
                    yield: 127 /* YieldKeyword */,
                    async: 134 /* AsyncKeyword */,
                    await: 135 /* AwaitKeyword */,
                    of: 165 /* OfKeyword */
                };
                textToKeyword = new Map(Object.entries(textToKeywordObj));
                textToToken = new Map(Object.entries({
                    ...textToKeywordObj,
                    "{": 19 /* OpenBraceToken */,
                    "}": 20 /* CloseBraceToken */,
                    "(": 21 /* OpenParenToken */,
                    ")": 22 /* CloseParenToken */,
                    "[": 23 /* OpenBracketToken */,
                    "]": 24 /* CloseBracketToken */,
                    ".": 25 /* DotToken */,
                    "...": 26 /* DotDotDotToken */,
                    ";": 27 /* SemicolonToken */,
                    ",": 28 /* CommaToken */,
                    "<": 30 /* LessThanToken */,
                    ">": 32 /* GreaterThanToken */,
                    "<=": 33 /* LessThanEqualsToken */,
                    ">=": 34 /* GreaterThanEqualsToken */,
                    "==": 35 /* EqualsEqualsToken */,
                    "!=": 36 /* ExclamationEqualsToken */,
                    "===": 37 /* EqualsEqualsEqualsToken */,
                    "!==": 38 /* ExclamationEqualsEqualsToken */,
                    "=>": 39 /* EqualsGreaterThanToken */,
                    "+": 40 /* PlusToken */,
                    "-": 41 /* MinusToken */,
                    "**": 43 /* AsteriskAsteriskToken */,
                    "*": 42 /* AsteriskToken */,
                    "/": 44 /* SlashToken */,
                    "%": 45 /* PercentToken */,
                    "++": 46 /* PlusPlusToken */,
                    "--": 47 /* MinusMinusToken */,
                    "<<": 48 /* LessThanLessThanToken */,
                    "</": 31 /* LessThanSlashToken */,
                    ">>": 49 /* GreaterThanGreaterThanToken */,
                    ">>>": 50 /* GreaterThanGreaterThanGreaterThanToken */,
                    "&": 51 /* AmpersandToken */,
                    "|": 52 /* BarToken */,
                    "^": 53 /* CaretToken */,
                    "!": 54 /* ExclamationToken */,
                    "~": 55 /* TildeToken */,
                    "&&": 56 /* AmpersandAmpersandToken */,
                    "||": 57 /* BarBarToken */,
                    "?": 58 /* QuestionToken */,
                    "??": 61 /* QuestionQuestionToken */,
                    "?.": 29 /* QuestionDotToken */,
                    ":": 59 /* ColonToken */,
                    "=": 64 /* EqualsToken */,
                    "+=": 65 /* PlusEqualsToken */,
                    "-=": 66 /* MinusEqualsToken */,
                    "*=": 67 /* AsteriskEqualsToken */,
                    "**=": 68 /* AsteriskAsteriskEqualsToken */,
                    "/=": 69 /* SlashEqualsToken */,
                    "%=": 70 /* PercentEqualsToken */,
                    "<<=": 71 /* LessThanLessThanEqualsToken */,
                    ">>=": 72 /* GreaterThanGreaterThanEqualsToken */,
                    ">>>=": 73 /* GreaterThanGreaterThanGreaterThanEqualsToken */,
                    "&=": 74 /* AmpersandEqualsToken */,
                    "|=": 75 /* BarEqualsToken */,
                    "^=": 79 /* CaretEqualsToken */,
                    "||=": 76 /* BarBarEqualsToken */,
                    "&&=": 77 /* AmpersandAmpersandEqualsToken */,
                    "??=": 78 /* QuestionQuestionEqualsToken */,
                    "@": 60 /* AtToken */,
                    "#": 63 /* HashToken */,
                    "`": 62 /* BacktickToken */
                }));
                unicodeES3IdentifierStart = [170, 170, 181, 181, 186, 186, 192, 214, 216, 246, 248, 543, 546, 563, 592, 685, 688, 696, 699, 705, 720, 721, 736, 740, 750, 750, 890, 890, 902, 902, 904, 906, 908, 908, 910, 929, 931, 974, 976, 983, 986, 1011, 1024, 1153, 1164, 1220, 1223, 1224, 1227, 1228, 1232, 1269, 1272, 1273, 1329, 1366, 1369, 1369, 1377, 1415, 1488, 1514, 1520, 1522, 1569, 1594, 1600, 1610, 1649, 1747, 1749, 1749, 1765, 1766, 1786, 1788, 1808, 1808, 1810, 1836, 1920, 1957, 2309, 2361, 2365, 2365, 2384, 2384, 2392, 2401, 2437, 2444, 2447, 2448, 2451, 2472, 2474, 2480, 2482, 2482, 2486, 2489, 2524, 2525, 2527, 2529, 2544, 2545, 2565, 2570, 2575, 2576, 2579, 2600, 2602, 2608, 2610, 2611, 2613, 2614, 2616, 2617, 2649, 2652, 2654, 2654, 2674, 2676, 2693, 2699, 2701, 2701, 2703, 2705, 2707, 2728, 2730, 2736, 2738, 2739, 2741, 2745, 2749, 2749, 2768, 2768, 2784, 2784, 2821, 2828, 2831, 2832, 2835, 2856, 2858, 2864, 2866, 2867, 2870, 2873, 2877, 2877, 2908, 2909, 2911, 2913, 2949, 2954, 2958, 2960, 2962, 2965, 2969, 2970, 2972, 2972, 2974, 2975, 2979, 2980, 2984, 2986, 2990, 2997, 2999, 3001, 3077, 3084, 3086, 3088, 3090, 3112, 3114, 3123, 3125, 3129, 3168, 3169, 3205, 3212, 3214, 3216, 3218, 3240, 3242, 3251, 3253, 3257, 3294, 3294, 3296, 3297, 3333, 3340, 3342, 3344, 3346, 3368, 3370, 3385, 3424, 3425, 3461, 3478, 3482, 3505, 3507, 3515, 3517, 3517, 3520, 3526, 3585, 3632, 3634, 3635, 3648, 3654, 3713, 3714, 3716, 3716, 3719, 3720, 3722, 3722, 3725, 3725, 3732, 3735, 3737, 3743, 3745, 3747, 3749, 3749, 3751, 3751, 3754, 3755, 3757, 3760, 3762, 3763, 3773, 3773, 3776, 3780, 3782, 3782, 3804, 3805, 3840, 3840, 3904, 3911, 3913, 3946, 3976, 3979, 4096, 4129, 4131, 4135, 4137, 4138, 4176, 4181, 4256, 4293, 4304, 4342, 4352, 4441, 4447, 4514, 4520, 4601, 4608, 4614, 4616, 4678, 4680, 4680, 4682, 4685, 4688, 4694, 4696, 4696, 4698, 4701, 4704, 4742, 4744, 4744, 4746, 4749, 4752, 4782, 4784, 4784, 4786, 4789, 4792, 4798, 4800, 4800, 4802, 4805, 4808, 4814, 4816, 4822, 4824, 4846, 4848, 4878, 4880, 4880, 4882, 4885, 4888, 4894, 4896, 4934, 4936, 4954, 5024, 5108, 5121, 5740, 5743, 5750, 5761, 5786, 5792, 5866, 6016, 6067, 6176, 6263, 6272, 6312, 7680, 7835, 7840, 7929, 7936, 7957, 7960, 7965, 7968, 8005, 8008, 8013, 8016, 8023, 8025, 8025, 8027, 8027, 8029, 8029, 8031, 8061, 8064, 8116, 8118, 8124, 8126, 8126, 8130, 8132, 8134, 8140, 8144, 8147, 8150, 8155, 8160, 8172, 8178, 8180, 8182, 8188, 8319, 8319, 8450, 8450, 8455, 8455, 8458, 8467, 8469, 8469, 8473, 8477, 8484, 8484, 8486, 8486, 8488, 8488, 8490, 8493, 8495, 8497, 8499, 8505, 8544, 8579, 12293, 12295, 12321, 12329, 12337, 12341, 12344, 12346, 12353, 12436, 12445, 12446, 12449, 12538, 12540, 12542, 12549, 12588, 12593, 12686, 12704, 12727, 13312, 19893, 19968, 40869, 40960, 42124, 44032, 55203, 63744, 64045, 64256, 64262, 64275, 64279, 64285, 64285, 64287, 64296, 64298, 64310, 64312, 64316, 64318, 64318, 64320, 64321, 64323, 64324, 64326, 64433, 64467, 64829, 64848, 64911, 64914, 64967, 65008, 65019, 65136, 65138, 65140, 65140, 65142, 65276, 65313, 65338, 65345, 65370, 65382, 65470, 65474, 65479, 65482, 65487, 65490, 65495, 65498, 65500];
                unicodeES3IdentifierPart = [170, 170, 181, 181, 186, 186, 192, 214, 216, 246, 248, 543, 546, 563, 592, 685, 688, 696, 699, 705, 720, 721, 736, 740, 750, 750, 768, 846, 864, 866, 890, 890, 902, 902, 904, 906, 908, 908, 910, 929, 931, 974, 976, 983, 986, 1011, 1024, 1153, 1155, 1158, 1164, 1220, 1223, 1224, 1227, 1228, 1232, 1269, 1272, 1273, 1329, 1366, 1369, 1369, 1377, 1415, 1425, 1441, 1443, 1465, 1467, 1469, 1471, 1471, 1473, 1474, 1476, 1476, 1488, 1514, 1520, 1522, 1569, 1594, 1600, 1621, 1632, 1641, 1648, 1747, 1749, 1756, 1759, 1768, 1770, 1773, 1776, 1788, 1808, 1836, 1840, 1866, 1920, 1968, 2305, 2307, 2309, 2361, 2364, 2381, 2384, 2388, 2392, 2403, 2406, 2415, 2433, 2435, 2437, 2444, 2447, 2448, 2451, 2472, 2474, 2480, 2482, 2482, 2486, 2489, 2492, 2492, 2494, 2500, 2503, 2504, 2507, 2509, 2519, 2519, 2524, 2525, 2527, 2531, 2534, 2545, 2562, 2562, 2565, 2570, 2575, 2576, 2579, 2600, 2602, 2608, 2610, 2611, 2613, 2614, 2616, 2617, 2620, 2620, 2622, 2626, 2631, 2632, 2635, 2637, 2649, 2652, 2654, 2654, 2662, 2676, 2689, 2691, 2693, 2699, 2701, 2701, 2703, 2705, 2707, 2728, 2730, 2736, 2738, 2739, 2741, 2745, 2748, 2757, 2759, 2761, 2763, 2765, 2768, 2768, 2784, 2784, 2790, 2799, 2817, 2819, 2821, 2828, 2831, 2832, 2835, 2856, 2858, 2864, 2866, 2867, 2870, 2873, 2876, 2883, 2887, 2888, 2891, 2893, 2902, 2903, 2908, 2909, 2911, 2913, 2918, 2927, 2946, 2947, 2949, 2954, 2958, 2960, 2962, 2965, 2969, 2970, 2972, 2972, 2974, 2975, 2979, 2980, 2984, 2986, 2990, 2997, 2999, 3001, 3006, 3010, 3014, 3016, 3018, 3021, 3031, 3031, 3047, 3055, 3073, 3075, 3077, 3084, 3086, 3088, 3090, 3112, 3114, 3123, 3125, 3129, 3134, 3140, 3142, 3144, 3146, 3149, 3157, 3158, 3168, 3169, 3174, 3183, 3202, 3203, 3205, 3212, 3214, 3216, 3218, 3240, 3242, 3251, 3253, 3257, 3262, 3268, 3270, 3272, 3274, 3277, 3285, 3286, 3294, 3294, 3296, 3297, 3302, 3311, 3330, 3331, 3333, 3340, 3342, 3344, 3346, 3368, 3370, 3385, 3390, 3395, 3398, 3400, 3402, 3405, 3415, 3415, 3424, 3425, 3430, 3439, 3458, 3459, 3461, 3478, 3482, 3505, 3507, 3515, 3517, 3517, 3520, 3526, 3530, 3530, 3535, 3540, 3542, 3542, 3544, 3551, 3570, 3571, 3585, 3642, 3648, 3662, 3664, 3673, 3713, 3714, 3716, 3716, 3719, 3720, 3722, 3722, 3725, 3725, 3732, 3735, 3737, 3743, 3745, 3747, 3749, 3749, 3751, 3751, 3754, 3755, 3757, 3769, 3771, 3773, 3776, 3780, 3782, 3782, 3784, 3789, 3792, 3801, 3804, 3805, 3840, 3840, 3864, 3865, 3872, 3881, 3893, 3893, 3895, 3895, 3897, 3897, 3902, 3911, 3913, 3946, 3953, 3972, 3974, 3979, 3984, 3991, 3993, 4028, 4038, 4038, 4096, 4129, 4131, 4135, 4137, 4138, 4140, 4146, 4150, 4153, 4160, 4169, 4176, 4185, 4256, 4293, 4304, 4342, 4352, 4441, 4447, 4514, 4520, 4601, 4608, 4614, 4616, 4678, 4680, 4680, 4682, 4685, 4688, 4694, 4696, 4696, 4698, 4701, 4704, 4742, 4744, 4744, 4746, 4749, 4752, 4782, 4784, 4784, 4786, 4789, 4792, 4798, 4800, 4800, 4802, 4805, 4808, 4814, 4816, 4822, 4824, 4846, 4848, 4878, 4880, 4880, 4882, 4885, 4888, 4894, 4896, 4934, 4936, 4954, 4969, 4977, 5024, 5108, 5121, 5740, 5743, 5750, 5761, 5786, 5792, 5866, 6016, 6099, 6112, 6121, 6160, 6169, 6176, 6263, 6272, 6313, 7680, 7835, 7840, 7929, 7936, 7957, 7960, 7965, 7968, 8005, 8008, 8013, 8016, 8023, 8025, 8025, 8027, 8027, 8029, 8029, 8031, 8061, 8064, 8116, 8118, 8124, 8126, 8126, 8130, 8132, 8134, 8140, 8144, 8147, 8150, 8155, 8160, 8172, 8178, 8180, 8182, 8188, 8255, 8256, 8319, 8319, 8400, 8412, 8417, 8417, 8450, 8450, 8455, 8455, 8458, 8467, 8469, 8469, 8473, 8477, 8484, 8484, 8486, 8486, 8488, 8488, 8490, 8493, 8495, 8497, 8499, 8505, 8544, 8579, 12293, 12295, 12321, 12335, 12337, 12341, 12344, 12346, 12353, 12436, 12441, 12442, 12445, 12446, 12449, 12542, 12549, 12588, 12593, 12686, 12704, 12727, 13312, 19893, 19968, 40869, 40960, 42124, 44032, 55203, 63744, 64045, 64256, 64262, 64275, 64279, 64285, 64296, 64298, 64310, 64312, 64316, 64318, 64318, 64320, 64321, 64323, 64324, 64326, 64433, 64467, 64829, 64848, 64911, 64914, 64967, 65008, 65019, 65056, 65059, 65075, 65076, 65101, 65103, 65136, 65138, 65140, 65140, 65142, 65276, 65296, 65305, 65313, 65338, 65343, 65343, 65345, 65370, 65381, 65470, 65474, 65479, 65482, 65487, 65490, 65495, 65498, 65500];
                unicodeES5IdentifierStart = [170, 170, 181, 181, 186, 186, 192, 214, 216, 246, 248, 705, 710, 721, 736, 740, 748, 748, 750, 750, 880, 884, 886, 887, 890, 893, 902, 902, 904, 906, 908, 908, 910, 929, 931, 1013, 1015, 1153, 1162, 1319, 1329, 1366, 1369, 1369, 1377, 1415, 1488, 1514, 1520, 1522, 1568, 1610, 1646, 1647, 1649, 1747, 1749, 1749, 1765, 1766, 1774, 1775, 1786, 1788, 1791, 1791, 1808, 1808, 1810, 1839, 1869, 1957, 1969, 1969, 1994, 2026, 2036, 2037, 2042, 2042, 2048, 2069, 2074, 2074, 2084, 2084, 2088, 2088, 2112, 2136, 2208, 2208, 2210, 2220, 2308, 2361, 2365, 2365, 2384, 2384, 2392, 2401, 2417, 2423, 2425, 2431, 2437, 2444, 2447, 2448, 2451, 2472, 2474, 2480, 2482, 2482, 2486, 2489, 2493, 2493, 2510, 2510, 2524, 2525, 2527, 2529, 2544, 2545, 2565, 2570, 2575, 2576, 2579, 2600, 2602, 2608, 2610, 2611, 2613, 2614, 2616, 2617, 2649, 2652, 2654, 2654, 2674, 2676, 2693, 2701, 2703, 2705, 2707, 2728, 2730, 2736, 2738, 2739, 2741, 2745, 2749, 2749, 2768, 2768, 2784, 2785, 2821, 2828, 2831, 2832, 2835, 2856, 2858, 2864, 2866, 2867, 2869, 2873, 2877, 2877, 2908, 2909, 2911, 2913, 2929, 2929, 2947, 2947, 2949, 2954, 2958, 2960, 2962, 2965, 2969, 2970, 2972, 2972, 2974, 2975, 2979, 2980, 2984, 2986, 2990, 3001, 3024, 3024, 3077, 3084, 3086, 3088, 3090, 3112, 3114, 3123, 3125, 3129, 3133, 3133, 3160, 3161, 3168, 3169, 3205, 3212, 3214, 3216, 3218, 3240, 3242, 3251, 3253, 3257, 3261, 3261, 3294, 3294, 3296, 3297, 3313, 3314, 3333, 3340, 3342, 3344, 3346, 3386, 3389, 3389, 3406, 3406, 3424, 3425, 3450, 3455, 3461, 3478, 3482, 3505, 3507, 3515, 3517, 3517, 3520, 3526, 3585, 3632, 3634, 3635, 3648, 3654, 3713, 3714, 3716, 3716, 3719, 3720, 3722, 3722, 3725, 3725, 3732, 3735, 3737, 3743, 3745, 3747, 3749, 3749, 3751, 3751, 3754, 3755, 3757, 3760, 3762, 3763, 3773, 3773, 3776, 3780, 3782, 3782, 3804, 3807, 3840, 3840, 3904, 3911, 3913, 3948, 3976, 3980, 4096, 4138, 4159, 4159, 4176, 4181, 4186, 4189, 4193, 4193, 4197, 4198, 4206, 4208, 4213, 4225, 4238, 4238, 4256, 4293, 4295, 4295, 4301, 4301, 4304, 4346, 4348, 4680, 4682, 4685, 4688, 4694, 4696, 4696, 4698, 4701, 4704, 4744, 4746, 4749, 4752, 4784, 4786, 4789, 4792, 4798, 4800, 4800, 4802, 4805, 4808, 4822, 4824, 4880, 4882, 4885, 4888, 4954, 4992, 5007, 5024, 5108, 5121, 5740, 5743, 5759, 5761, 5786, 5792, 5866, 5870, 5872, 5888, 5900, 5902, 5905, 5920, 5937, 5952, 5969, 5984, 5996, 5998, 6e3, 6016, 6067, 6103, 6103, 6108, 6108, 6176, 6263, 6272, 6312, 6314, 6314, 6320, 6389, 6400, 6428, 6480, 6509, 6512, 6516, 6528, 6571, 6593, 6599, 6656, 6678, 6688, 6740, 6823, 6823, 6917, 6963, 6981, 6987, 7043, 7072, 7086, 7087, 7098, 7141, 7168, 7203, 7245, 7247, 7258, 7293, 7401, 7404, 7406, 7409, 7413, 7414, 7424, 7615, 7680, 7957, 7960, 7965, 7968, 8005, 8008, 8013, 8016, 8023, 8025, 8025, 8027, 8027, 8029, 8029, 8031, 8061, 8064, 8116, 8118, 8124, 8126, 8126, 8130, 8132, 8134, 8140, 8144, 8147, 8150, 8155, 8160, 8172, 8178, 8180, 8182, 8188, 8305, 8305, 8319, 8319, 8336, 8348, 8450, 8450, 8455, 8455, 8458, 8467, 8469, 8469, 8473, 8477, 8484, 8484, 8486, 8486, 8488, 8488, 8490, 8493, 8495, 8505, 8508, 8511, 8517, 8521, 8526, 8526, 8544, 8584, 11264, 11310, 11312, 11358, 11360, 11492, 11499, 11502, 11506, 11507, 11520, 11557, 11559, 11559, 11565, 11565, 11568, 11623, 11631, 11631, 11648, 11670, 11680, 11686, 11688, 11694, 11696, 11702, 11704, 11710, 11712, 11718, 11720, 11726, 11728, 11734, 11736, 11742, 11823, 11823, 12293, 12295, 12321, 12329, 12337, 12341, 12344, 12348, 12353, 12438, 12445, 12447, 12449, 12538, 12540, 12543, 12549, 12589, 12593, 12686, 12704, 12730, 12784, 12799, 13312, 19893, 19968, 40908, 40960, 42124, 42192, 42237, 42240, 42508, 42512, 42527, 42538, 42539, 42560, 42606, 42623, 42647, 42656, 42735, 42775, 42783, 42786, 42888, 42891, 42894, 42896, 42899, 42912, 42922, 43e3, 43009, 43011, 43013, 43015, 43018, 43020, 43042, 43072, 43123, 43138, 43187, 43250, 43255, 43259, 43259, 43274, 43301, 43312, 43334, 43360, 43388, 43396, 43442, 43471, 43471, 43520, 43560, 43584, 43586, 43588, 43595, 43616, 43638, 43642, 43642, 43648, 43695, 43697, 43697, 43701, 43702, 43705, 43709, 43712, 43712, 43714, 43714, 43739, 43741, 43744, 43754, 43762, 43764, 43777, 43782, 43785, 43790, 43793, 43798, 43808, 43814, 43816, 43822, 43968, 44002, 44032, 55203, 55216, 55238, 55243, 55291, 63744, 64109, 64112, 64217, 64256, 64262, 64275, 64279, 64285, 64285, 64287, 64296, 64298, 64310, 64312, 64316, 64318, 64318, 64320, 64321, 64323, 64324, 64326, 64433, 64467, 64829, 64848, 64911, 64914, 64967, 65008, 65019, 65136, 65140, 65142, 65276, 65313, 65338, 65345, 65370, 65382, 65470, 65474, 65479, 65482, 65487, 65490, 65495, 65498, 65500];
                unicodeES5IdentifierPart = [170, 170, 181, 181, 186, 186, 192, 214, 216, 246, 248, 705, 710, 721, 736, 740, 748, 748, 750, 750, 768, 884, 886, 887, 890, 893, 902, 902, 904, 906, 908, 908, 910, 929, 931, 1013, 1015, 1153, 1155, 1159, 1162, 1319, 1329, 1366, 1369, 1369, 1377, 1415, 1425, 1469, 1471, 1471, 1473, 1474, 1476, 1477, 1479, 1479, 1488, 1514, 1520, 1522, 1552, 1562, 1568, 1641, 1646, 1747, 1749, 1756, 1759, 1768, 1770, 1788, 1791, 1791, 1808, 1866, 1869, 1969, 1984, 2037, 2042, 2042, 2048, 2093, 2112, 2139, 2208, 2208, 2210, 2220, 2276, 2302, 2304, 2403, 2406, 2415, 2417, 2423, 2425, 2431, 2433, 2435, 2437, 2444, 2447, 2448, 2451, 2472, 2474, 2480, 2482, 2482, 2486, 2489, 2492, 2500, 2503, 2504, 2507, 2510, 2519, 2519, 2524, 2525, 2527, 2531, 2534, 2545, 2561, 2563, 2565, 2570, 2575, 2576, 2579, 2600, 2602, 2608, 2610, 2611, 2613, 2614, 2616, 2617, 2620, 2620, 2622, 2626, 2631, 2632, 2635, 2637, 2641, 2641, 2649, 2652, 2654, 2654, 2662, 2677, 2689, 2691, 2693, 2701, 2703, 2705, 2707, 2728, 2730, 2736, 2738, 2739, 2741, 2745, 2748, 2757, 2759, 2761, 2763, 2765, 2768, 2768, 2784, 2787, 2790, 2799, 2817, 2819, 2821, 2828, 2831, 2832, 2835, 2856, 2858, 2864, 2866, 2867, 2869, 2873, 2876, 2884, 2887, 2888, 2891, 2893, 2902, 2903, 2908, 2909, 2911, 2915, 2918, 2927, 2929, 2929, 2946, 2947, 2949, 2954, 2958, 2960, 2962, 2965, 2969, 2970, 2972, 2972, 2974, 2975, 2979, 2980, 2984, 2986, 2990, 3001, 3006, 3010, 3014, 3016, 3018, 3021, 3024, 3024, 3031, 3031, 3046, 3055, 3073, 3075, 3077, 3084, 3086, 3088, 3090, 3112, 3114, 3123, 3125, 3129, 3133, 3140, 3142, 3144, 3146, 3149, 3157, 3158, 3160, 3161, 3168, 3171, 3174, 3183, 3202, 3203, 3205, 3212, 3214, 3216, 3218, 3240, 3242, 3251, 3253, 3257, 3260, 3268, 3270, 3272, 3274, 3277, 3285, 3286, 3294, 3294, 3296, 3299, 3302, 3311, 3313, 3314, 3330, 3331, 3333, 3340, 3342, 3344, 3346, 3386, 3389, 3396, 3398, 3400, 3402, 3406, 3415, 3415, 3424, 3427, 3430, 3439, 3450, 3455, 3458, 3459, 3461, 3478, 3482, 3505, 3507, 3515, 3517, 3517, 3520, 3526, 3530, 3530, 3535, 3540, 3542, 3542, 3544, 3551, 3570, 3571, 3585, 3642, 3648, 3662, 3664, 3673, 3713, 3714, 3716, 3716, 3719, 3720, 3722, 3722, 3725, 3725, 3732, 3735, 3737, 3743, 3745, 3747, 3749, 3749, 3751, 3751, 3754, 3755, 3757, 3769, 3771, 3773, 3776, 3780, 3782, 3782, 3784, 3789, 3792, 3801, 3804, 3807, 3840, 3840, 3864, 3865, 3872, 3881, 3893, 3893, 3895, 3895, 3897, 3897, 3902, 3911, 3913, 3948, 3953, 3972, 3974, 3991, 3993, 4028, 4038, 4038, 4096, 4169, 4176, 4253, 4256, 4293, 4295, 4295, 4301, 4301, 4304, 4346, 4348, 4680, 4682, 4685, 4688, 4694, 4696, 4696, 4698, 4701, 4704, 4744, 4746, 4749, 4752, 4784, 4786, 4789, 4792, 4798, 4800, 4800, 4802, 4805, 4808, 4822, 4824, 4880, 4882, 4885, 4888, 4954, 4957, 4959, 4992, 5007, 5024, 5108, 5121, 5740, 5743, 5759, 5761, 5786, 5792, 5866, 5870, 5872, 5888, 5900, 5902, 5908, 5920, 5940, 5952, 5971, 5984, 5996, 5998, 6e3, 6002, 6003, 6016, 6099, 6103, 6103, 6108, 6109, 6112, 6121, 6155, 6157, 6160, 6169, 6176, 6263, 6272, 6314, 6320, 6389, 6400, 6428, 6432, 6443, 6448, 6459, 6470, 6509, 6512, 6516, 6528, 6571, 6576, 6601, 6608, 6617, 6656, 6683, 6688, 6750, 6752, 6780, 6783, 6793, 6800, 6809, 6823, 6823, 6912, 6987, 6992, 7001, 7019, 7027, 7040, 7155, 7168, 7223, 7232, 7241, 7245, 7293, 7376, 7378, 7380, 7414, 7424, 7654, 7676, 7957, 7960, 7965, 7968, 8005, 8008, 8013, 8016, 8023, 8025, 8025, 8027, 8027, 8029, 8029, 8031, 8061, 8064, 8116, 8118, 8124, 8126, 8126, 8130, 8132, 8134, 8140, 8144, 8147, 8150, 8155, 8160, 8172, 8178, 8180, 8182, 8188, 8204, 8205, 8255, 8256, 8276, 8276, 8305, 8305, 8319, 8319, 8336, 8348, 8400, 8412, 8417, 8417, 8421, 8432, 8450, 8450, 8455, 8455, 8458, 8467, 8469, 8469, 8473, 8477, 8484, 8484, 8486, 8486, 8488, 8488, 8490, 8493, 8495, 8505, 8508, 8511, 8517, 8521, 8526, 8526, 8544, 8584, 11264, 11310, 11312, 11358, 11360, 11492, 11499, 11507, 11520, 11557, 11559, 11559, 11565, 11565, 11568, 11623, 11631, 11631, 11647, 11670, 11680, 11686, 11688, 11694, 11696, 11702, 11704, 11710, 11712, 11718, 11720, 11726, 11728, 11734, 11736, 11742, 11744, 11775, 11823, 11823, 12293, 12295, 12321, 12335, 12337, 12341, 12344, 12348, 12353, 12438, 12441, 12442, 12445, 12447, 12449, 12538, 12540, 12543, 12549, 12589, 12593, 12686, 12704, 12730, 12784, 12799, 13312, 19893, 19968, 40908, 40960, 42124, 42192, 42237, 42240, 42508, 42512, 42539, 42560, 42607, 42612, 42621, 42623, 42647, 42655, 42737, 42775, 42783, 42786, 42888, 42891, 42894, 42896, 42899, 42912, 42922, 43e3, 43047, 43072, 43123, 43136, 43204, 43216, 43225, 43232, 43255, 43259, 43259, 43264, 43309, 43312, 43347, 43360, 43388, 43392, 43456, 43471, 43481, 43520, 43574, 43584, 43597, 43600, 43609, 43616, 43638, 43642, 43643, 43648, 43714, 43739, 43741, 43744, 43759, 43762, 43766, 43777, 43782, 43785, 43790, 43793, 43798, 43808, 43814, 43816, 43822, 43968, 44010, 44012, 44013, 44016, 44025, 44032, 55203, 55216, 55238, 55243, 55291, 63744, 64109, 64112, 64217, 64256, 64262, 64275, 64279, 64285, 64296, 64298, 64310, 64312, 64316, 64318, 64318, 64320, 64321, 64323, 64324, 64326, 64433, 64467, 64829, 64848, 64911, 64914, 64967, 65008, 65019, 65024, 65039, 65056, 65062, 65075, 65076, 65101, 65103, 65136, 65140, 65142, 65276, 65296, 65305, 65313, 65338, 65343, 65343, 65345, 65370, 65382, 65470, 65474, 65479, 65482, 65487, 65490, 65495, 65498, 65500];
                unicodeESNextIdentifierStart = [65, 90, 97, 122, 170, 170, 181, 181, 186, 186, 192, 214, 216, 246, 248, 705, 710, 721, 736, 740, 748, 748, 750, 750, 880, 884, 886, 887, 890, 893, 895, 895, 902, 902, 904, 906, 908, 908, 910, 929, 931, 1013, 1015, 1153, 1162, 1327, 1329, 1366, 1369, 1369, 1376, 1416, 1488, 1514, 1519, 1522, 1568, 1610, 1646, 1647, 1649, 1747, 1749, 1749, 1765, 1766, 1774, 1775, 1786, 1788, 1791, 1791, 1808, 1808, 1810, 1839, 1869, 1957, 1969, 1969, 1994, 2026, 2036, 2037, 2042, 2042, 2048, 2069, 2074, 2074, 2084, 2084, 2088, 2088, 2112, 2136, 2144, 2154, 2208, 2228, 2230, 2237, 2308, 2361, 2365, 2365, 2384, 2384, 2392, 2401, 2417, 2432, 2437, 2444, 2447, 2448, 2451, 2472, 2474, 2480, 2482, 2482, 2486, 2489, 2493, 2493, 2510, 2510, 2524, 2525, 2527, 2529, 2544, 2545, 2556, 2556, 2565, 2570, 2575, 2576, 2579, 2600, 2602, 2608, 2610, 2611, 2613, 2614, 2616, 2617, 2649, 2652, 2654, 2654, 2674, 2676, 2693, 2701, 2703, 2705, 2707, 2728, 2730, 2736, 2738, 2739, 2741, 2745, 2749, 2749, 2768, 2768, 2784, 2785, 2809, 2809, 2821, 2828, 2831, 2832, 2835, 2856, 2858, 2864, 2866, 2867, 2869, 2873, 2877, 2877, 2908, 2909, 2911, 2913, 2929, 2929, 2947, 2947, 2949, 2954, 2958, 2960, 2962, 2965, 2969, 2970, 2972, 2972, 2974, 2975, 2979, 2980, 2984, 2986, 2990, 3001, 3024, 3024, 3077, 3084, 3086, 3088, 3090, 3112, 3114, 3129, 3133, 3133, 3160, 3162, 3168, 3169, 3200, 3200, 3205, 3212, 3214, 3216, 3218, 3240, 3242, 3251, 3253, 3257, 3261, 3261, 3294, 3294, 3296, 3297, 3313, 3314, 3333, 3340, 3342, 3344, 3346, 3386, 3389, 3389, 3406, 3406, 3412, 3414, 3423, 3425, 3450, 3455, 3461, 3478, 3482, 3505, 3507, 3515, 3517, 3517, 3520, 3526, 3585, 3632, 3634, 3635, 3648, 3654, 3713, 3714, 3716, 3716, 3718, 3722, 3724, 3747, 3749, 3749, 3751, 3760, 3762, 3763, 3773, 3773, 3776, 3780, 3782, 3782, 3804, 3807, 3840, 3840, 3904, 3911, 3913, 3948, 3976, 3980, 4096, 4138, 4159, 4159, 4176, 4181, 4186, 4189, 4193, 4193, 4197, 4198, 4206, 4208, 4213, 4225, 4238, 4238, 4256, 4293, 4295, 4295, 4301, 4301, 4304, 4346, 4348, 4680, 4682, 4685, 4688, 4694, 4696, 4696, 4698, 4701, 4704, 4744, 4746, 4749, 4752, 4784, 4786, 4789, 4792, 4798, 4800, 4800, 4802, 4805, 4808, 4822, 4824, 4880, 4882, 4885, 4888, 4954, 4992, 5007, 5024, 5109, 5112, 5117, 5121, 5740, 5743, 5759, 5761, 5786, 5792, 5866, 5870, 5880, 5888, 5900, 5902, 5905, 5920, 5937, 5952, 5969, 5984, 5996, 5998, 6e3, 6016, 6067, 6103, 6103, 6108, 6108, 6176, 6264, 6272, 6312, 6314, 6314, 6320, 6389, 6400, 6430, 6480, 6509, 6512, 6516, 6528, 6571, 6576, 6601, 6656, 6678, 6688, 6740, 6823, 6823, 6917, 6963, 6981, 6987, 7043, 7072, 7086, 7087, 7098, 7141, 7168, 7203, 7245, 7247, 7258, 7293, 7296, 7304, 7312, 7354, 7357, 7359, 7401, 7404, 7406, 7411, 7413, 7414, 7418, 7418, 7424, 7615, 7680, 7957, 7960, 7965, 7968, 8005, 8008, 8013, 8016, 8023, 8025, 8025, 8027, 8027, 8029, 8029, 8031, 8061, 8064, 8116, 8118, 8124, 8126, 8126, 8130, 8132, 8134, 8140, 8144, 8147, 8150, 8155, 8160, 8172, 8178, 8180, 8182, 8188, 8305, 8305, 8319, 8319, 8336, 8348, 8450, 8450, 8455, 8455, 8458, 8467, 8469, 8469, 8472, 8477, 8484, 8484, 8486, 8486, 8488, 8488, 8490, 8505, 8508, 8511, 8517, 8521, 8526, 8526, 8544, 8584, 11264, 11310, 11312, 11358, 11360, 11492, 11499, 11502, 11506, 11507, 11520, 11557, 11559, 11559, 11565, 11565, 11568, 11623, 11631, 11631, 11648, 11670, 11680, 11686, 11688, 11694, 11696, 11702, 11704, 11710, 11712, 11718, 11720, 11726, 11728, 11734, 11736, 11742, 12293, 12295, 12321, 12329, 12337, 12341, 12344, 12348, 12353, 12438, 12443, 12447, 12449, 12538, 12540, 12543, 12549, 12591, 12593, 12686, 12704, 12730, 12784, 12799, 13312, 19893, 19968, 40943, 40960, 42124, 42192, 42237, 42240, 42508, 42512, 42527, 42538, 42539, 42560, 42606, 42623, 42653, 42656, 42735, 42775, 42783, 42786, 42888, 42891, 42943, 42946, 42950, 42999, 43009, 43011, 43013, 43015, 43018, 43020, 43042, 43072, 43123, 43138, 43187, 43250, 43255, 43259, 43259, 43261, 43262, 43274, 43301, 43312, 43334, 43360, 43388, 43396, 43442, 43471, 43471, 43488, 43492, 43494, 43503, 43514, 43518, 43520, 43560, 43584, 43586, 43588, 43595, 43616, 43638, 43642, 43642, 43646, 43695, 43697, 43697, 43701, 43702, 43705, 43709, 43712, 43712, 43714, 43714, 43739, 43741, 43744, 43754, 43762, 43764, 43777, 43782, 43785, 43790, 43793, 43798, 43808, 43814, 43816, 43822, 43824, 43866, 43868, 43879, 43888, 44002, 44032, 55203, 55216, 55238, 55243, 55291, 63744, 64109, 64112, 64217, 64256, 64262, 64275, 64279, 64285, 64285, 64287, 64296, 64298, 64310, 64312, 64316, 64318, 64318, 64320, 64321, 64323, 64324, 64326, 64433, 64467, 64829, 64848, 64911, 64914, 64967, 65008, 65019, 65136, 65140, 65142, 65276, 65313, 65338, 65345, 65370, 65382, 65470, 65474, 65479, 65482, 65487, 65490, 65495, 65498, 65500, 65536, 65547, 65549, 65574, 65576, 65594, 65596, 65597, 65599, 65613, 65616, 65629, 65664, 65786, 65856, 65908, 66176, 66204, 66208, 66256, 66304, 66335, 66349, 66378, 66384, 66421, 66432, 66461, 66464, 66499, 66504, 66511, 66513, 66517, 66560, 66717, 66736, 66771, 66776, 66811, 66816, 66855, 66864, 66915, 67072, 67382, 67392, 67413, 67424, 67431, 67584, 67589, 67592, 67592, 67594, 67637, 67639, 67640, 67644, 67644, 67647, 67669, 67680, 67702, 67712, 67742, 67808, 67826, 67828, 67829, 67840, 67861, 67872, 67897, 67968, 68023, 68030, 68031, 68096, 68096, 68112, 68115, 68117, 68119, 68121, 68149, 68192, 68220, 68224, 68252, 68288, 68295, 68297, 68324, 68352, 68405, 68416, 68437, 68448, 68466, 68480, 68497, 68608, 68680, 68736, 68786, 68800, 68850, 68864, 68899, 69376, 69404, 69415, 69415, 69424, 69445, 69600, 69622, 69635, 69687, 69763, 69807, 69840, 69864, 69891, 69926, 69956, 69956, 69968, 70002, 70006, 70006, 70019, 70066, 70081, 70084, 70106, 70106, 70108, 70108, 70144, 70161, 70163, 70187, 70272, 70278, 70280, 70280, 70282, 70285, 70287, 70301, 70303, 70312, 70320, 70366, 70405, 70412, 70415, 70416, 70419, 70440, 70442, 70448, 70450, 70451, 70453, 70457, 70461, 70461, 70480, 70480, 70493, 70497, 70656, 70708, 70727, 70730, 70751, 70751, 70784, 70831, 70852, 70853, 70855, 70855, 71040, 71086, 71128, 71131, 71168, 71215, 71236, 71236, 71296, 71338, 71352, 71352, 71424, 71450, 71680, 71723, 71840, 71903, 71935, 71935, 72096, 72103, 72106, 72144, 72161, 72161, 72163, 72163, 72192, 72192, 72203, 72242, 72250, 72250, 72272, 72272, 72284, 72329, 72349, 72349, 72384, 72440, 72704, 72712, 72714, 72750, 72768, 72768, 72818, 72847, 72960, 72966, 72968, 72969, 72971, 73008, 73030, 73030, 73056, 73061, 73063, 73064, 73066, 73097, 73112, 73112, 73440, 73458, 73728, 74649, 74752, 74862, 74880, 75075, 77824, 78894, 82944, 83526, 92160, 92728, 92736, 92766, 92880, 92909, 92928, 92975, 92992, 92995, 93027, 93047, 93053, 93071, 93760, 93823, 93952, 94026, 94032, 94032, 94099, 94111, 94176, 94177, 94179, 94179, 94208, 100343, 100352, 101106, 110592, 110878, 110928, 110930, 110948, 110951, 110960, 111355, 113664, 113770, 113776, 113788, 113792, 113800, 113808, 113817, 119808, 119892, 119894, 119964, 119966, 119967, 119970, 119970, 119973, 119974, 119977, 119980, 119982, 119993, 119995, 119995, 119997, 120003, 120005, 120069, 120071, 120074, 120077, 120084, 120086, 120092, 120094, 120121, 120123, 120126, 120128, 120132, 120134, 120134, 120138, 120144, 120146, 120485, 120488, 120512, 120514, 120538, 120540, 120570, 120572, 120596, 120598, 120628, 120630, 120654, 120656, 120686, 120688, 120712, 120714, 120744, 120746, 120770, 120772, 120779, 123136, 123180, 123191, 123197, 123214, 123214, 123584, 123627, 124928, 125124, 125184, 125251, 125259, 125259, 126464, 126467, 126469, 126495, 126497, 126498, 126500, 126500, 126503, 126503, 126505, 126514, 126516, 126519, 126521, 126521, 126523, 126523, 126530, 126530, 126535, 126535, 126537, 126537, 126539, 126539, 126541, 126543, 126545, 126546, 126548, 126548, 126551, 126551, 126553, 126553, 126555, 126555, 126557, 126557, 126559, 126559, 126561, 126562, 126564, 126564, 126567, 126570, 126572, 126578, 126580, 126583, 126585, 126588, 126590, 126590, 126592, 126601, 126603, 126619, 126625, 126627, 126629, 126633, 126635, 126651, 131072, 173782, 173824, 177972, 177984, 178205, 178208, 183969, 183984, 191456, 194560, 195101];
                unicodeESNextIdentifierPart = [48, 57, 65, 90, 95, 95, 97, 122, 170, 170, 181, 181, 183, 183, 186, 186, 192, 214, 216, 246, 248, 705, 710, 721, 736, 740, 748, 748, 750, 750, 768, 884, 886, 887, 890, 893, 895, 895, 902, 906, 908, 908, 910, 929, 931, 1013, 1015, 1153, 1155, 1159, 1162, 1327, 1329, 1366, 1369, 1369, 1376, 1416, 1425, 1469, 1471, 1471, 1473, 1474, 1476, 1477, 1479, 1479, 1488, 1514, 1519, 1522, 1552, 1562, 1568, 1641, 1646, 1747, 1749, 1756, 1759, 1768, 1770, 1788, 1791, 1791, 1808, 1866, 1869, 1969, 1984, 2037, 2042, 2042, 2045, 2045, 2048, 2093, 2112, 2139, 2144, 2154, 2208, 2228, 2230, 2237, 2259, 2273, 2275, 2403, 2406, 2415, 2417, 2435, 2437, 2444, 2447, 2448, 2451, 2472, 2474, 2480, 2482, 2482, 2486, 2489, 2492, 2500, 2503, 2504, 2507, 2510, 2519, 2519, 2524, 2525, 2527, 2531, 2534, 2545, 2556, 2556, 2558, 2558, 2561, 2563, 2565, 2570, 2575, 2576, 2579, 2600, 2602, 2608, 2610, 2611, 2613, 2614, 2616, 2617, 2620, 2620, 2622, 2626, 2631, 2632, 2635, 2637, 2641, 2641, 2649, 2652, 2654, 2654, 2662, 2677, 2689, 2691, 2693, 2701, 2703, 2705, 2707, 2728, 2730, 2736, 2738, 2739, 2741, 2745, 2748, 2757, 2759, 2761, 2763, 2765, 2768, 2768, 2784, 2787, 2790, 2799, 2809, 2815, 2817, 2819, 2821, 2828, 2831, 2832, 2835, 2856, 2858, 2864, 2866, 2867, 2869, 2873, 2876, 2884, 2887, 2888, 2891, 2893, 2902, 2903, 2908, 2909, 2911, 2915, 2918, 2927, 2929, 2929, 2946, 2947, 2949, 2954, 2958, 2960, 2962, 2965, 2969, 2970, 2972, 2972, 2974, 2975, 2979, 2980, 2984, 2986, 2990, 3001, 3006, 3010, 3014, 3016, 3018, 3021, 3024, 3024, 3031, 3031, 3046, 3055, 3072, 3084, 3086, 3088, 3090, 3112, 3114, 3129, 3133, 3140, 3142, 3144, 3146, 3149, 3157, 3158, 3160, 3162, 3168, 3171, 3174, 3183, 3200, 3203, 3205, 3212, 3214, 3216, 3218, 3240, 3242, 3251, 3253, 3257, 3260, 3268, 3270, 3272, 3274, 3277, 3285, 3286, 3294, 3294, 3296, 3299, 3302, 3311, 3313, 3314, 3328, 3331, 3333, 3340, 3342, 3344, 3346, 3396, 3398, 3400, 3402, 3406, 3412, 3415, 3423, 3427, 3430, 3439, 3450, 3455, 3458, 3459, 3461, 3478, 3482, 3505, 3507, 3515, 3517, 3517, 3520, 3526, 3530, 3530, 3535, 3540, 3542, 3542, 3544, 3551, 3558, 3567, 3570, 3571, 3585, 3642, 3648, 3662, 3664, 3673, 3713, 3714, 3716, 3716, 3718, 3722, 3724, 3747, 3749, 3749, 3751, 3773, 3776, 3780, 3782, 3782, 3784, 3789, 3792, 3801, 3804, 3807, 3840, 3840, 3864, 3865, 3872, 3881, 3893, 3893, 3895, 3895, 3897, 3897, 3902, 3911, 3913, 3948, 3953, 3972, 3974, 3991, 3993, 4028, 4038, 4038, 4096, 4169, 4176, 4253, 4256, 4293, 4295, 4295, 4301, 4301, 4304, 4346, 4348, 4680, 4682, 4685, 4688, 4694, 4696, 4696, 4698, 4701, 4704, 4744, 4746, 4749, 4752, 4784, 4786, 4789, 4792, 4798, 4800, 4800, 4802, 4805, 4808, 4822, 4824, 4880, 4882, 4885, 4888, 4954, 4957, 4959, 4969, 4977, 4992, 5007, 5024, 5109, 5112, 5117, 5121, 5740, 5743, 5759, 5761, 5786, 5792, 5866, 5870, 5880, 5888, 5900, 5902, 5908, 5920, 5940, 5952, 5971, 5984, 5996, 5998, 6e3, 6002, 6003, 6016, 6099, 6103, 6103, 6108, 6109, 6112, 6121, 6155, 6157, 6160, 6169, 6176, 6264, 6272, 6314, 6320, 6389, 6400, 6430, 6432, 6443, 6448, 6459, 6470, 6509, 6512, 6516, 6528, 6571, 6576, 6601, 6608, 6618, 6656, 6683, 6688, 6750, 6752, 6780, 6783, 6793, 6800, 6809, 6823, 6823, 6832, 6845, 6912, 6987, 6992, 7001, 7019, 7027, 7040, 7155, 7168, 7223, 7232, 7241, 7245, 7293, 7296, 7304, 7312, 7354, 7357, 7359, 7376, 7378, 7380, 7418, 7424, 7673, 7675, 7957, 7960, 7965, 7968, 8005, 8008, 8013, 8016, 8023, 8025, 8025, 8027, 8027, 8029, 8029, 8031, 8061, 8064, 8116, 8118, 8124, 8126, 8126, 8130, 8132, 8134, 8140, 8144, 8147, 8150, 8155, 8160, 8172, 8178, 8180, 8182, 8188, 8255, 8256, 8276, 8276, 8305, 8305, 8319, 8319, 8336, 8348, 8400, 8412, 8417, 8417, 8421, 8432, 8450, 8450, 8455, 8455, 8458, 8467, 8469, 8469, 8472, 8477, 8484, 8484, 8486, 8486, 8488, 8488, 8490, 8505, 8508, 8511, 8517, 8521, 8526, 8526, 8544, 8584, 11264, 11310, 11312, 11358, 11360, 11492, 11499, 11507, 11520, 11557, 11559, 11559, 11565, 11565, 11568, 11623, 11631, 11631, 11647, 11670, 11680, 11686, 11688, 11694, 11696, 11702, 11704, 11710, 11712, 11718, 11720, 11726, 11728, 11734, 11736, 11742, 11744, 11775, 12293, 12295, 12321, 12335, 12337, 12341, 12344, 12348, 12353, 12438, 12441, 12447, 12449, 12538, 12540, 12543, 12549, 12591, 12593, 12686, 12704, 12730, 12784, 12799, 13312, 19893, 19968, 40943, 40960, 42124, 42192, 42237, 42240, 42508, 42512, 42539, 42560, 42607, 42612, 42621, 42623, 42737, 42775, 42783, 42786, 42888, 42891, 42943, 42946, 42950, 42999, 43047, 43072, 43123, 43136, 43205, 43216, 43225, 43232, 43255, 43259, 43259, 43261, 43309, 43312, 43347, 43360, 43388, 43392, 43456, 43471, 43481, 43488, 43518, 43520, 43574, 43584, 43597, 43600, 43609, 43616, 43638, 43642, 43714, 43739, 43741, 43744, 43759, 43762, 43766, 43777, 43782, 43785, 43790, 43793, 43798, 43808, 43814, 43816, 43822, 43824, 43866, 43868, 43879, 43888, 44010, 44012, 44013, 44016, 44025, 44032, 55203, 55216, 55238, 55243, 55291, 63744, 64109, 64112, 64217, 64256, 64262, 64275, 64279, 64285, 64296, 64298, 64310, 64312, 64316, 64318, 64318, 64320, 64321, 64323, 64324, 64326, 64433, 64467, 64829, 64848, 64911, 64914, 64967, 65008, 65019, 65024, 65039, 65056, 65071, 65075, 65076, 65101, 65103, 65136, 65140, 65142, 65276, 65296, 65305, 65313, 65338, 65343, 65343, 65345, 65370, 65382, 65470, 65474, 65479, 65482, 65487, 65490, 65495, 65498, 65500, 65536, 65547, 65549, 65574, 65576, 65594, 65596, 65597, 65599, 65613, 65616, 65629, 65664, 65786, 65856, 65908, 66045, 66045, 66176, 66204, 66208, 66256, 66272, 66272, 66304, 66335, 66349, 66378, 66384, 66426, 66432, 66461, 66464, 66499, 66504, 66511, 66513, 66517, 66560, 66717, 66720, 66729, 66736, 66771, 66776, 66811, 66816, 66855, 66864, 66915, 67072, 67382, 67392, 67413, 67424, 67431, 67584, 67589, 67592, 67592, 67594, 67637, 67639, 67640, 67644, 67644, 67647, 67669, 67680, 67702, 67712, 67742, 67808, 67826, 67828, 67829, 67840, 67861, 67872, 67897, 67968, 68023, 68030, 68031, 68096, 68099, 68101, 68102, 68108, 68115, 68117, 68119, 68121, 68149, 68152, 68154, 68159, 68159, 68192, 68220, 68224, 68252, 68288, 68295, 68297, 68326, 68352, 68405, 68416, 68437, 68448, 68466, 68480, 68497, 68608, 68680, 68736, 68786, 68800, 68850, 68864, 68903, 68912, 68921, 69376, 69404, 69415, 69415, 69424, 69456, 69600, 69622, 69632, 69702, 69734, 69743, 69759, 69818, 69840, 69864, 69872, 69881, 69888, 69940, 69942, 69951, 69956, 69958, 69968, 70003, 70006, 70006, 70016, 70084, 70089, 70092, 70096, 70106, 70108, 70108, 70144, 70161, 70163, 70199, 70206, 70206, 70272, 70278, 70280, 70280, 70282, 70285, 70287, 70301, 70303, 70312, 70320, 70378, 70384, 70393, 70400, 70403, 70405, 70412, 70415, 70416, 70419, 70440, 70442, 70448, 70450, 70451, 70453, 70457, 70459, 70468, 70471, 70472, 70475, 70477, 70480, 70480, 70487, 70487, 70493, 70499, 70502, 70508, 70512, 70516, 70656, 70730, 70736, 70745, 70750, 70751, 70784, 70853, 70855, 70855, 70864, 70873, 71040, 71093, 71096, 71104, 71128, 71133, 71168, 71232, 71236, 71236, 71248, 71257, 71296, 71352, 71360, 71369, 71424, 71450, 71453, 71467, 71472, 71481, 71680, 71738, 71840, 71913, 71935, 71935, 72096, 72103, 72106, 72151, 72154, 72161, 72163, 72164, 72192, 72254, 72263, 72263, 72272, 72345, 72349, 72349, 72384, 72440, 72704, 72712, 72714, 72758, 72760, 72768, 72784, 72793, 72818, 72847, 72850, 72871, 72873, 72886, 72960, 72966, 72968, 72969, 72971, 73014, 73018, 73018, 73020, 73021, 73023, 73031, 73040, 73049, 73056, 73061, 73063, 73064, 73066, 73102, 73104, 73105, 73107, 73112, 73120, 73129, 73440, 73462, 73728, 74649, 74752, 74862, 74880, 75075, 77824, 78894, 82944, 83526, 92160, 92728, 92736, 92766, 92768, 92777, 92880, 92909, 92912, 92916, 92928, 92982, 92992, 92995, 93008, 93017, 93027, 93047, 93053, 93071, 93760, 93823, 93952, 94026, 94031, 94087, 94095, 94111, 94176, 94177, 94179, 94179, 94208, 100343, 100352, 101106, 110592, 110878, 110928, 110930, 110948, 110951, 110960, 111355, 113664, 113770, 113776, 113788, 113792, 113800, 113808, 113817, 113821, 113822, 119141, 119145, 119149, 119154, 119163, 119170, 119173, 119179, 119210, 119213, 119362, 119364, 119808, 119892, 119894, 119964, 119966, 119967, 119970, 119970, 119973, 119974, 119977, 119980, 119982, 119993, 119995, 119995, 119997, 120003, 120005, 120069, 120071, 120074, 120077, 120084, 120086, 120092, 120094, 120121, 120123, 120126, 120128, 120132, 120134, 120134, 120138, 120144, 120146, 120485, 120488, 120512, 120514, 120538, 120540, 120570, 120572, 120596, 120598, 120628, 120630, 120654, 120656, 120686, 120688, 120712, 120714, 120744, 120746, 120770, 120772, 120779, 120782, 120831, 121344, 121398, 121403, 121452, 121461, 121461, 121476, 121476, 121499, 121503, 121505, 121519, 122880, 122886, 122888, 122904, 122907, 122913, 122915, 122916, 122918, 122922, 123136, 123180, 123184, 123197, 123200, 123209, 123214, 123214, 123584, 123641, 124928, 125124, 125136, 125142, 125184, 125259, 125264, 125273, 126464, 126467, 126469, 126495, 126497, 126498, 126500, 126500, 126503, 126503, 126505, 126514, 126516, 126519, 126521, 126521, 126523, 126523, 126530, 126530, 126535, 126535, 126537, 126537, 126539, 126539, 126541, 126543, 126545, 126546, 126548, 126548, 126551, 126551, 126553, 126553, 126555, 126555, 126557, 126557, 126559, 126559, 126561, 126562, 126564, 126564, 126567, 126570, 126572, 126578, 126580, 126583, 126585, 126588, 126590, 126590, 126592, 126601, 126603, 126619, 126625, 126627, 126629, 126633, 126635, 126651, 131072, 173782, 173824, 177972, 177984, 178205, 178208, 183969, 183984, 191456, 194560, 195101, 917760, 917999];
                commentDirectiveRegExSingleLine = /^\/\/\/?\s*@(ts-expect-error|ts-ignore)/;
                commentDirectiveRegExMultiLine = /^(?:\/|\*)*\s*@(ts-expect-error|ts-ignore)/;
                jsDocSeeOrLink = /@(?:see|link)/i;
                tokenStrings = makeReverseMap(textToToken);
                mergeConflictMarkerLength = "<<<<<<<".length;
                shebangTriviaRegex = /^#!.*/;
                utf16EncodeAsStringWorker = String.fromCodePoint ? (codePoint) => String.fromCodePoint(codePoint) : utf16EncodeAsStringFallback;
            }
        });
        // src/compiler/utilitiesPublic.ts
        function isExternalModuleNameRelative(moduleName) {
            return pathIsRelative(moduleName) || isRootedDiskPath(moduleName);
        }
        function sortAndDeduplicateDiagnostics(diagnostics) {
            return sortAndDeduplicate(diagnostics, compareDiagnostics);
        }
        function getDefaultLibFileName(options) {
            switch (getEmitScriptTarget(options)) {
                case 99 /* ESNext */:
                    return "lib.esnext.full.d.ts";
                case 9 /* ES2022 */:
                    return "lib.es2022.full.d.ts";
                case 8 /* ES2021 */:
                    return "lib.es2021.full.d.ts";
                case 7 /* ES2020 */:
                    return "lib.es2020.full.d.ts";
                case 6 /* ES2019 */:
                    return "lib.es2019.full.d.ts";
                case 5 /* ES2018 */:
                    return "lib.es2018.full.d.ts";
                case 4 /* ES2017 */:
                    return "lib.es2017.full.d.ts";
                case 3 /* ES2016 */:
                    return "lib.es2016.full.d.ts";
                case 2 /* ES2015 */:
                    return "lib.es6.d.ts";
                default:
                    return "lib.d.ts";
            }
        }
        function textSpanEnd(span) {
            return span.start + span.length;
        }
        function textSpanIsEmpty(span) {
            return span.length === 0;
        }
        function textSpanContainsPosition(span, position) {
            return position >= span.start && position < textSpanEnd(span);
        }
        function textRangeContainsPositionInclusive(span, position) {
            return position >= span.pos && position <= span.end;
        }
        function textSpanContainsTextSpan(span, other) {
            return other.start >= span.start && textSpanEnd(other) <= textSpanEnd(span);
        }
        function textSpanOverlapsWith(span, other) {
            return textSpanOverlap(span, other) !== void 0;
        }
        function textSpanOverlap(span1, span2) {
            const overlap = textSpanIntersection(span1, span2);
            return overlap && overlap.length === 0 ? void 0 : overlap;
        }
        function textSpanIntersectsWithTextSpan(span, other) {
            return decodedTextSpanIntersectsWith(span.start, span.length, other.start, other.length);
        }
        function textSpanIntersectsWith(span, start, length2) {
            return decodedTextSpanIntersectsWith(span.start, span.length, start, length2);
        }
        function decodedTextSpanIntersectsWith(start1, length1, start2, length2) {
            const end1 = start1 + length1;
            const end2 = start2 + length2;
            return start2 <= end1 && end2 >= start1;
        }
        function textSpanIntersectsWithPosition(span, position) {
            return position <= textSpanEnd(span) && position >= span.start;
        }
        function textSpanIntersection(span1, span2) {
            const start = Math.max(span1.start, span2.start);
            const end = Math.min(textSpanEnd(span1), textSpanEnd(span2));
            return start <= end ? createTextSpanFromBounds(start, end) : void 0;
        }
        function createTextSpan(start, length2) {
            if (start < 0) {
                throw new Error("start < 0");
            }
            if (length2 < 0) {
                throw new Error("length < 0");
            }
            return { start, length: length2 };
        }
        function createTextSpanFromBounds(start, end) {
            return createTextSpan(start, end - start);
        }
        function textChangeRangeNewSpan(range) {
            return createTextSpan(range.span.start, range.newLength);
        }
        function textChangeRangeIsUnchanged(range) {
            return textSpanIsEmpty(range.span) && range.newLength === 0;
        }
        function createTextChangeRange(span, newLength) {
            if (newLength < 0) {
                throw new Error("newLength < 0");
            }
            return { span, newLength };
        }
        function collapseTextChangeRangesAcrossMultipleVersions(changes) {
            if (changes.length === 0) {
                return unchangedTextChangeRange;
            }
            if (changes.length === 1) {
                return changes[0];
            }
            const change0 = changes[0];
            let oldStartN = change0.span.start;
            let oldEndN = textSpanEnd(change0.span);
            let newEndN = oldStartN + change0.newLength;
            for (let i = 1; i < changes.length; i++) {
                const nextChange = changes[i];
                const oldStart1 = oldStartN;
                const oldEnd1 = oldEndN;
                const newEnd1 = newEndN;
                const oldStart2 = nextChange.span.start;
                const oldEnd2 = textSpanEnd(nextChange.span);
                const newEnd2 = oldStart2 + nextChange.newLength;
                oldStartN = Math.min(oldStart1, oldStart2);
                oldEndN = Math.max(oldEnd1, oldEnd1 + (oldEnd2 - newEnd1));
                newEndN = Math.max(newEnd2, newEnd2 + (newEnd1 - oldEnd2));
            }
            return createTextChangeRange(createTextSpanFromBounds(oldStartN, oldEndN), 
            /*newLength*/
            newEndN - oldStartN);
        }
        function getTypeParameterOwner(d) {
            if (d && d.kind === 168 /* TypeParameter */) {
                for (let current = d; current; current = current.parent) {
                    if (isFunctionLike(current) || isClassLike(current) || current.kind === 264 /* InterfaceDeclaration */) {
                        return current;
                    }
                }
            }
        }
        function isParameterPropertyDeclaration(node, parent2) {
            return isParameter(node) && hasSyntacticModifier(node, 31 /* ParameterPropertyModifier */) && parent2.kind === 176 /* Constructor */;
        }
        function isEmptyBindingPattern(node) {
            if (isBindingPattern(node)) {
                return every(node.elements, isEmptyBindingElement);
            }
            return false;
        }
        function isEmptyBindingElement(node) {
            if (isOmittedExpression(node)) {
                return true;
            }
            return isEmptyBindingPattern(node.name);
        }
        function walkUpBindingElementsAndPatterns(binding) {
            let node = binding.parent;
            while (isBindingElement(node.parent)) {
                node = node.parent.parent;
            }
            return node.parent;
        }
        function getCombinedFlags(node, getFlags) {
            if (isBindingElement(node)) {
                node = walkUpBindingElementsAndPatterns(node);
            }
            let flags = getFlags(node);
            if (node.kind === 260 /* VariableDeclaration */) {
                node = node.parent;
            }
            if (node && node.kind === 261 /* VariableDeclarationList */) {
                flags |= getFlags(node);
                node = node.parent;
            }
            if (node && node.kind === 243 /* VariableStatement */) {
                flags |= getFlags(node);
            }
            return flags;
        }
        function getCombinedModifierFlags(node) {
            return getCombinedFlags(node, getEffectiveModifierFlags);
        }
        function getCombinedNodeFlagsAlwaysIncludeJSDoc(node) {
            return getCombinedFlags(node, getEffectiveModifierFlagsAlwaysIncludeJSDoc);
        }
        function getCombinedNodeFlags(node) {
            return getCombinedFlags(node, getNodeFlags);
        }
        function getNodeFlags(node) {
            return node.flags;
        }
        function validateLocaleAndSetLanguage(locale, sys2, errors) {
            const lowerCaseLocale = locale.toLowerCase();
            const matchResult = /^([a-z]+)([_-]([a-z]+))?$/.exec(lowerCaseLocale);
            if (!matchResult) {
                if (errors) {
                    errors.push(createCompilerDiagnostic(Diagnostics.Locale_must_be_of_the_form_language_or_language_territory_For_example_0_or_1, "en", "ja-jp"));
                }
                return;
            }
            const language = matchResult[1];
            const territory = matchResult[3];
            if (contains(supportedLocaleDirectories, lowerCaseLocale) && !trySetLanguageAndTerritory(language, territory, errors)) {
                trySetLanguageAndTerritory(language, 
                /*territory*/
                void 0, errors);
            }
            setUILocale(locale);
            function trySetLanguageAndTerritory(language2, territory2, errors2) {
                const compilerFilePath = normalizePath(sys2.getExecutingFilePath());
                const containingDirectoryPath = getDirectoryPath(compilerFilePath);
                let filePath = combinePaths(containingDirectoryPath, language2);
                if (territory2) {
                    filePath = filePath + "-" + territory2;
                }
                filePath = sys2.resolvePath(combinePaths(filePath, "diagnosticMessages.generated.json"));
                if (!sys2.fileExists(filePath)) {
                    return false;
                }
                let fileContents = "";
                try {
                    fileContents = sys2.readFile(filePath);
                }
                catch (e) {
                    if (errors2) {
                        errors2.push(createCompilerDiagnostic(Diagnostics.Unable_to_open_file_0, filePath));
                    }
                    return false;
                }
                try {
                    setLocalizedDiagnosticMessages(JSON.parse(fileContents));
                }
                catch {
                    if (errors2) {
                        errors2.push(createCompilerDiagnostic(Diagnostics.Corrupted_locale_file_0, filePath));
                    }
                    return false;
                }
                return true;
            }
        }
        function getOriginalNode(node, nodeTest) {
            if (node) {
                while (node.original !== void 0) {
                    node = node.original;
                }
            }
            if (!node || !nodeTest) {
                return node;
            }
            return nodeTest(node) ? node : void 0;
        }
        function findAncestor(node, callback) {
            while (node) {
                const result = callback(node);
                if (result === "quit") {
                    return void 0;
                }
                else if (result) {
                    return node;
                }
                node = node.parent;
            }
            return void 0;
        }
        function isParseTreeNode(node) {
            return (node.flags & 16 /* Synthesized */) === 0;
        }
        function getParseTreeNode(node, nodeTest) {
            if (node === void 0 || isParseTreeNode(node)) {
                return node;
            }
            node = node.original;
            while (node) {
                if (isParseTreeNode(node)) {
                    return !nodeTest || nodeTest(node) ? node : void 0;
                }
                node = node.original;
            }
        }
        function escapeLeadingUnderscores(identifier) {
            return identifier.length >= 2 && identifier.charCodeAt(0) === 95 /* _ */ && identifier.charCodeAt(1) === 95 /* _ */ ? "_" + identifier : identifier;
        }
        function unescapeLeadingUnderscores(identifier) {
            const id = identifier;
            return id.length >= 3 && id.charCodeAt(0) === 95 /* _ */ && id.charCodeAt(1) === 95 /* _ */ && id.charCodeAt(2) === 95 /* _ */ ? id.substr(1) : id;
        }
        function idText(identifierOrPrivateName) {
            return unescapeLeadingUnderscores(identifierOrPrivateName.escapedText);
        }
        function identifierToKeywordKind(node) {
            const token = stringToToken(node.escapedText);
            return token ? tryCast(token, isKeyword) : void 0;
        }
        function symbolName(symbol) {
            if (symbol.valueDeclaration && isPrivateIdentifierClassElementDeclaration(symbol.valueDeclaration)) {
                return idText(symbol.valueDeclaration.name);
            }
            return unescapeLeadingUnderscores(symbol.escapedName);
        }
        function nameForNamelessJSDocTypedef(declaration) {
            const hostNode = declaration.parent.parent;
            if (!hostNode) {
                return void 0;
            }
            if (isDeclaration(hostNode)) {
                return getDeclarationIdentifier(hostNode);
            }
            switch (hostNode.kind) {
                case 243 /* VariableStatement */:
                    if (hostNode.declarationList && hostNode.declarationList.declarations[0]) {
                        return getDeclarationIdentifier(hostNode.declarationList.declarations[0]);
                    }
                    break;
                case 244 /* ExpressionStatement */:
                    let expr = hostNode.expression;
                    if (expr.kind === 226 /* BinaryExpression */ && expr.operatorToken.kind === 64 /* EqualsToken */) {
                        expr = expr.left;
                    }
                    switch (expr.kind) {
                        case 211 /* PropertyAccessExpression */:
                            return expr.name;
                        case 212 /* ElementAccessExpression */:
                            const arg = expr.argumentExpression;
                            if (isIdentifier(arg)) {
                                return arg;
                            }
                    }
                    break;
                case 217 /* ParenthesizedExpression */: {
                    return getDeclarationIdentifier(hostNode.expression);
                }
                case 256 /* LabeledStatement */: {
                    if (isDeclaration(hostNode.statement) || isExpression(hostNode.statement)) {
                        return getDeclarationIdentifier(hostNode.statement);
                    }
                    break;
                }
            }
        }
        function getDeclarationIdentifier(node) {
            const name = getNameOfDeclaration(node);
            return name && isIdentifier(name) ? name : void 0;
        }
        function nodeHasName(statement, name) {
            if (isNamedDeclaration(statement) && isIdentifier(statement.name) && idText(statement.name) === idText(name)) {
                return true;
            }
            if (isVariableStatement(statement) && some(statement.declarationList.declarations, (d) => nodeHasName(d, name))) {
                return true;
            }
            return false;
        }
        function getNameOfJSDocTypedef(declaration) {
            return declaration.name || nameForNamelessJSDocTypedef(declaration);
        }
        function isNamedDeclaration(node) {
            return !!node.name;
        }
        function getNonAssignedNameOfDeclaration(declaration) {
            switch (declaration.kind) {
                case 80 /* Identifier */:
                    return declaration;
                case 355 /* JSDocPropertyTag */:
                case 348 /* JSDocParameterTag */: {
                    const { name } = declaration;
                    if (name.kind === 166 /* QualifiedName */) {
                        return name.right;
                    }
                    break;
                }
                case 213 /* CallExpression */:
                case 226 /* BinaryExpression */: {
                    const expr2 = declaration;
                    switch (getAssignmentDeclarationKind(expr2)) {
                        case 1 /* ExportsProperty */:
                        case 4 /* ThisProperty */:
                        case 5 /* Property */:
                        case 3 /* PrototypeProperty */:
                            return getElementOrPropertyAccessArgumentExpressionOrName(expr2.left);
                        case 7 /* ObjectDefinePropertyValue */:
                        case 8 /* ObjectDefinePropertyExports */:
                        case 9 /* ObjectDefinePrototypeProperty */:
                            return expr2.arguments[1];
                        default:
                            return void 0;
                    }
                }
                case 353 /* JSDocTypedefTag */:
                    return getNameOfJSDocTypedef(declaration);
                case 347 /* JSDocEnumTag */:
                    return nameForNamelessJSDocTypedef(declaration);
                case 277 /* ExportAssignment */: {
                    const { expression } = declaration;
                    return isIdentifier(expression) ? expression : void 0;
                }
                case 212 /* ElementAccessExpression */:
                    const expr = declaration;
                    if (isBindableStaticElementAccessExpression(expr)) {
                        return expr.argumentExpression;
                    }
            }
            return declaration.name;
        }
        function getNameOfDeclaration(declaration) {
            if (declaration === void 0)
                return void 0;
            return getNonAssignedNameOfDeclaration(declaration) || (isFunctionExpression(declaration) || isArrowFunction(declaration) || isClassExpression(declaration) ? getAssignedName(declaration) : void 0);
        }
        function getAssignedName(node) {
            if (!node.parent) {
                return void 0;
            }
            else if (isPropertyAssignment(node.parent) || isBindingElement(node.parent)) {
                return node.parent.name;
            }
            else if (isBinaryExpression(node.parent) && node === node.parent.right) {
                if (isIdentifier(node.parent.left)) {
                    return node.parent.left;
                }
                else if (isAccessExpression(node.parent.left)) {
                    return getElementOrPropertyAccessArgumentExpressionOrName(node.parent.left);
                }
            }
            else if (isVariableDeclaration(node.parent) && isIdentifier(node.parent.name)) {
                return node.parent.name;
            }
        }
        function getDecorators(node) {
            if (hasDecorators(node)) {
                return filter(node.modifiers, isDecorator);
            }
        }
        function getModifiers(node) {
            if (hasSyntacticModifier(node, 98303 /* Modifier */)) {
                return filter(node.modifiers, isModifier);
            }
        }
        function getJSDocParameterTagsWorker(param, noCache) {
            if (param.name) {
                if (isIdentifier(param.name)) {
                    const name = param.name.escapedText;
                    return getJSDocTagsWorker(param.parent, noCache).filter((tag) => isJSDocParameterTag(tag) && isIdentifier(tag.name) && tag.name.escapedText === name);
                }
                else {
                    const i = param.parent.parameters.indexOf(param);
                    Debug.assert(i > -1, "Parameters should always be in their parents' parameter list");
                    const paramTags = getJSDocTagsWorker(param.parent, noCache).filter(isJSDocParameterTag);
                    if (i < paramTags.length) {
                        return [paramTags[i]];
                    }
                }
            }
            return emptyArray;
        }
        function getJSDocParameterTags(param) {
            return getJSDocParameterTagsWorker(param, 
            /*noCache*/
            false);
        }
        function getJSDocParameterTagsNoCache(param) {
            return getJSDocParameterTagsWorker(param, 
            /*noCache*/
            true);
        }
        function getJSDocTypeParameterTagsWorker(param, noCache) {
            const name = param.name.escapedText;
            return getJSDocTagsWorker(param.parent, noCache).filter((tag) => isJSDocTemplateTag(tag) && tag.typeParameters.some((tp) => tp.name.escapedText === name));
        }
        function getJSDocTypeParameterTags(param) {
            return getJSDocTypeParameterTagsWorker(param, 
            /*noCache*/
            false);
        }
        function getJSDocTypeParameterTagsNoCache(param) {
            return getJSDocTypeParameterTagsWorker(param, 
            /*noCache*/
            true);
        }
        function hasJSDocParameterTags(node) {
            return !!getFirstJSDocTag(node, isJSDocParameterTag);
        }
        function getJSDocAugmentsTag(node) {
            return getFirstJSDocTag(node, isJSDocAugmentsTag);
        }
        function getJSDocImplementsTags(node) {
            return getAllJSDocTags(node, isJSDocImplementsTag);
        }
        function getJSDocClassTag(node) {
            return getFirstJSDocTag(node, isJSDocClassTag);
        }
        function getJSDocPublicTag(node) {
            return getFirstJSDocTag(node, isJSDocPublicTag);
        }
        function getJSDocPublicTagNoCache(node) {
            return getFirstJSDocTag(node, isJSDocPublicTag, 
            /*noCache*/
            true);
        }
        function getJSDocPrivateTag(node) {
            return getFirstJSDocTag(node, isJSDocPrivateTag);
        }
        function getJSDocPrivateTagNoCache(node) {
            return getFirstJSDocTag(node, isJSDocPrivateTag, 
            /*noCache*/
            true);
        }
        function getJSDocProtectedTag(node) {
            return getFirstJSDocTag(node, isJSDocProtectedTag);
        }
        function getJSDocProtectedTagNoCache(node) {
            return getFirstJSDocTag(node, isJSDocProtectedTag, 
            /*noCache*/
            true);
        }
        function getJSDocReadonlyTag(node) {
            return getFirstJSDocTag(node, isJSDocReadonlyTag);
        }
        function getJSDocReadonlyTagNoCache(node) {
            return getFirstJSDocTag(node, isJSDocReadonlyTag, 
            /*noCache*/
            true);
        }
        function getJSDocOverrideTagNoCache(node) {
            return getFirstJSDocTag(node, isJSDocOverrideTag, 
            /*noCache*/
            true);
        }
        function getJSDocDeprecatedTag(node) {
            return getFirstJSDocTag(node, isJSDocDeprecatedTag);
        }
        function getJSDocDeprecatedTagNoCache(node) {
            return getFirstJSDocTag(node, isJSDocDeprecatedTag, 
            /*noCache*/
            true);
        }
        function getJSDocEnumTag(node) {
            return getFirstJSDocTag(node, isJSDocEnumTag);
        }
        function getJSDocThisTag(node) {
            return getFirstJSDocTag(node, isJSDocThisTag);
        }
        function getJSDocReturnTag(node) {
            return getFirstJSDocTag(node, isJSDocReturnTag);
        }
        function getJSDocTemplateTag(node) {
            return getFirstJSDocTag(node, isJSDocTemplateTag);
        }
        function getJSDocSatisfiesTag(node) {
            return getFirstJSDocTag(node, isJSDocSatisfiesTag);
        }
        function getJSDocTypeTag(node) {
            const tag = getFirstJSDocTag(node, isJSDocTypeTag);
            if (tag && tag.typeExpression && tag.typeExpression.type) {
                return tag;
            }
            return void 0;
        }
        function getJSDocType(node) {
            let tag = getFirstJSDocTag(node, isJSDocTypeTag);
            if (!tag && isParameter(node)) {
                tag = find(getJSDocParameterTags(node), (tag2) => !!tag2.typeExpression);
            }
            return tag && tag.typeExpression && tag.typeExpression.type;
        }
        function getJSDocReturnType(node) {
            const returnTag = getJSDocReturnTag(node);
            if (returnTag && returnTag.typeExpression) {
                return returnTag.typeExpression.type;
            }
            const typeTag = getJSDocTypeTag(node);
            if (typeTag && typeTag.typeExpression) {
                const type = typeTag.typeExpression.type;
                if (isTypeLiteralNode(type)) {
                    const sig = find(type.members, isCallSignatureDeclaration);
                    return sig && sig.type;
                }
                if (isFunctionTypeNode(type) || isJSDocFunctionType(type)) {
                    return type.type;
                }
            }
        }
        function getJSDocTagsWorker(node, noCache) {
            var _a;
            if (!canHaveJSDoc(node))
                return emptyArray;
            let tags = (_a = node.jsDoc) == null ? void 0 : _a.jsDocCache;
            if (tags === void 0 || noCache) {
                const comments = getJSDocCommentsAndTags(node, noCache);
                Debug.assert(comments.length < 2 || comments[0] !== comments[1]);
                tags = flatMap(comments, (j) => isJSDoc(j) ? j.tags : j);
                if (!noCache) {
                    node.jsDoc ?? (node.jsDoc = []);
                    node.jsDoc.jsDocCache = tags;
                }
            }
            return tags;
        }
        function getJSDocTags(node) {
            return getJSDocTagsWorker(node, 
            /*noCache*/
            false);
        }
        function getJSDocTagsNoCache(node) {
            return getJSDocTagsWorker(node, 
            /*noCache*/
            true);
        }
        function getFirstJSDocTag(node, predicate, noCache) {
            return find(getJSDocTagsWorker(node, noCache), predicate);
        }
        function getAllJSDocTags(node, predicate) {
            return getJSDocTags(node).filter(predicate);
        }
        function getAllJSDocTagsOfKind(node, kind) {
            return getJSDocTags(node).filter((doc) => doc.kind === kind);
        }
        function getTextOfJSDocComment(comment) {
            return typeof comment === "string" ? comment : comment == null ? void 0 : comment.map((c) => c.kind === 328 /* JSDocText */ ? c.text : formatJSDocLink(c)).join("");
        }
        function formatJSDocLink(link) {
            const kind = link.kind === 331 /* JSDocLink */ ? "link" : link.kind === 332 /* JSDocLinkCode */ ? "linkcode" : "linkplain";
            const name = link.name ? entityNameToString(link.name) : "";
            const space = link.name && link.text.startsWith("://") ? "" : " ";
            return `{@${kind} ${name}${space}${link.text}}`;
        }
        function getEffectiveTypeParameterDeclarations(node) {
            if (isJSDocSignature(node)) {
                if (isJSDocOverloadTag(node.parent)) {
                    const jsDoc = getJSDocRoot(node.parent);
                    if (jsDoc && length(jsDoc.tags)) {
                        return flatMap(jsDoc.tags, (tag) => isJSDocTemplateTag(tag) ? tag.typeParameters : void 0);
                    }
                }
                return emptyArray;
            }
            if (isJSDocTypeAlias(node)) {
                Debug.assert(node.parent.kind === 327 /* JSDoc */);
                return flatMap(node.parent.tags, (tag) => isJSDocTemplateTag(tag) ? tag.typeParameters : void 0);
            }
            if (node.typeParameters) {
                return node.typeParameters;
            }
            if (canHaveIllegalTypeParameters(node) && node.typeParameters) {
                return node.typeParameters;
            }
            if (isInJSFile(node)) {
                const decls = getJSDocTypeParameterDeclarations(node);
                if (decls.length) {
                    return decls;
                }
                const typeTag = getJSDocType(node);
                if (typeTag && isFunctionTypeNode(typeTag) && typeTag.typeParameters) {
                    return typeTag.typeParameters;
                }
            }
            return emptyArray;
        }
        function getEffectiveConstraintOfTypeParameter(node) {
            return node.constraint ? node.constraint : isJSDocTemplateTag(node.parent) && node === node.parent.typeParameters[0] ? node.parent.constraint : void 0;
        }
        function isMemberName(node) {
            return node.kind === 80 /* Identifier */ || node.kind === 81 /* PrivateIdentifier */;
        }
        function isGetOrSetAccessorDeclaration(node) {
            return node.kind === 178 /* SetAccessor */ || node.kind === 177 /* GetAccessor */;
        }
        function isPropertyAccessChain(node) {
            return isPropertyAccessExpression(node) && !!(node.flags & 64 /* OptionalChain */);
        }
        function isElementAccessChain(node) {
            return isElementAccessExpression(node) && !!(node.flags & 64 /* OptionalChain */);
        }
        function isCallChain(node) {
            return isCallExpression(node) && !!(node.flags & 64 /* OptionalChain */);
        }
        function isOptionalChain(node) {
            const kind = node.kind;
            return !!(node.flags & 64 /* OptionalChain */) && (kind === 211 /* PropertyAccessExpression */ || kind === 212 /* ElementAccessExpression */ || kind === 213 /* CallExpression */ || kind === 235 /* NonNullExpression */);
        }
        function isOptionalChainRoot(node) {
            return isOptionalChain(node) && !isNonNullExpression(node) && !!node.questionDotToken;
        }
        function isExpressionOfOptionalChainRoot(node) {
            return isOptionalChainRoot(node.parent) && node.parent.expression === node;
        }
        function isOutermostOptionalChain(node) {
            return !isOptionalChain(node.parent) || isOptionalChainRoot(node.parent) || node !== node.parent.expression;
        }
        function isNullishCoalesce(node) {
            return node.kind === 226 /* BinaryExpression */ && node.operatorToken.kind === 61 /* QuestionQuestionToken */;
        }
        function isConstTypeReference(node) {
            return isTypeReferenceNode(node) && isIdentifier(node.typeName) && node.typeName.escapedText === "const" && !node.typeArguments;
        }
        function skipPartiallyEmittedExpressions(node) {
            return skipOuterExpressions(node, 8 /* PartiallyEmittedExpressions */);
        }
        function isNonNullChain(node) {
            return isNonNullExpression(node) && !!(node.flags & 64 /* OptionalChain */);
        }
        function isBreakOrContinueStatement(node) {
            return node.kind === 252 /* BreakStatement */ || node.kind === 251 /* ContinueStatement */;
        }
        function isNamedExportBindings(node) {
            return node.kind === 280 /* NamespaceExport */ || node.kind === 279 /* NamedExports */;
        }
        function isUnparsedTextLike(node) {
            switch (node.kind) {
                case 309 /* UnparsedText */:
                case 310 /* UnparsedInternalText */:
                    return true;
                default:
                    return false;
            }
        }
        function isUnparsedNode(node) {
            return isUnparsedTextLike(node) || node.kind === 307 /* UnparsedPrologue */ || node.kind === 311 /* UnparsedSyntheticReference */;
        }
        function isJSDocPropertyLikeTag(node) {
            return node.kind === 355 /* JSDocPropertyTag */ || node.kind === 348 /* JSDocParameterTag */;
        }
        function isNode(node) {
            return isNodeKind(node.kind);
        }
        function isNodeKind(kind) {
            return kind >= 166 /* FirstNode */;
        }
        function isTokenKind(kind) {
            return kind >= 0 /* FirstToken */ && kind <= 165 /* LastToken */;
        }
        function isToken(n) {
            return isTokenKind(n.kind);
        }
        function isNodeArray(array) {
            return hasProperty(array, "pos") && hasProperty(array, "end");
        }
        function isLiteralKind(kind) {
            return 9 /* FirstLiteralToken */ <= kind && kind <= 15 /* LastLiteralToken */;
        }
        function isLiteralExpression(node) {
            return isLiteralKind(node.kind);
        }
        function isLiteralExpressionOfObject(node) {
            switch (node.kind) {
                case 210 /* ObjectLiteralExpression */:
                case 209 /* ArrayLiteralExpression */:
                case 14 /* RegularExpressionLiteral */:
                case 218 /* FunctionExpression */:
                case 231 /* ClassExpression */:
                    return true;
            }
            return false;
        }
        function isTemplateLiteralKind(kind) {
            return 15 /* FirstTemplateToken */ <= kind && kind <= 18 /* LastTemplateToken */;
        }
        function isTemplateLiteralToken(node) {
            return isTemplateLiteralKind(node.kind);
        }
        function isTemplateMiddleOrTemplateTail(node) {
            const kind = node.kind;
            return kind === 17 /* TemplateMiddle */ || kind === 18 /* TemplateTail */;
        }
        function isImportOrExportSpecifier(node) {
            return isImportSpecifier(node) || isExportSpecifier(node);
        }
        function isTypeOnlyImportDeclaration(node) {
            switch (node.kind) {
                case 276 /* ImportSpecifier */:
                    return node.isTypeOnly || node.parent.parent.isTypeOnly;
                case 274 /* NamespaceImport */:
                    return node.parent.isTypeOnly;
                case 273 /* ImportClause */:
                case 271 /* ImportEqualsDeclaration */:
                    return node.isTypeOnly;
            }
            return false;
        }
        function isTypeOnlyExportDeclaration(node) {
            switch (node.kind) {
                case 281 /* ExportSpecifier */:
                    return node.isTypeOnly || node.parent.parent.isTypeOnly;
                case 278 /* ExportDeclaration */:
                    return node.isTypeOnly && !!node.moduleSpecifier && !node.exportClause;
                case 280 /* NamespaceExport */:
                    return node.parent.isTypeOnly;
            }
            return false;
        }
        function isTypeOnlyImportOrExportDeclaration(node) {
            return isTypeOnlyImportDeclaration(node) || isTypeOnlyExportDeclaration(node);
        }
        function isStringTextContainingNode(node) {
            return node.kind === 11 /* StringLiteral */ || isTemplateLiteralKind(node.kind);
        }
        function isImportAttributeName(node) {
            return isStringLiteral(node) || isIdentifier(node);
        }
        function isGeneratedIdentifier(node) {
            var _a;
            return isIdentifier(node) && ((_a = node.emitNode) == null ? void 0 : _a.autoGenerate) !== void 0;
        }
        function isGeneratedPrivateIdentifier(node) {
            var _a;
            return isPrivateIdentifier(node) && ((_a = node.emitNode) == null ? void 0 : _a.autoGenerate) !== void 0;
        }
        function isFileLevelReservedGeneratedIdentifier(node) {
            const flags = node.emitNode.autoGenerate.flags;
            return !!(flags & 32 /* FileLevel */) && !!(flags & 16 /* Optimistic */) && !!(flags & 8 /* ReservedInNestedScopes */);
        }
        function isPrivateIdentifierClassElementDeclaration(node) {
            return (isPropertyDeclaration(node) || isMethodOrAccessor(node)) && isPrivateIdentifier(node.name);
        }
        function isPrivateIdentifierPropertyAccessExpression(node) {
            return isPropertyAccessExpression(node) && isPrivateIdentifier(node.name);
        }
        function isModifierKind(token) {
            switch (token) {
                case 128 /* AbstractKeyword */:
                case 129 /* AccessorKeyword */:
                case 134 /* AsyncKeyword */:
                case 87 /* ConstKeyword */:
                case 138 /* DeclareKeyword */:
                case 90 /* DefaultKeyword */:
                case 95 /* ExportKeyword */:
                case 103 /* InKeyword */:
                case 125 /* PublicKeyword */:
                case 123 /* PrivateKeyword */:
                case 124 /* ProtectedKeyword */:
                case 148 /* ReadonlyKeyword */:
                case 126 /* StaticKeyword */:
                case 147 /* OutKeyword */:
                case 164 /* OverrideKeyword */:
                    return true;
            }
            return false;
        }
        function isParameterPropertyModifier(kind) {
            return !!(modifierToFlag(kind) & 31 /* ParameterPropertyModifier */);
        }
        function isClassMemberModifier(idToken) {
            return isParameterPropertyModifier(idToken) || idToken === 126 /* StaticKeyword */ || idToken === 164 /* OverrideKeyword */ || idToken === 129 /* AccessorKeyword */;
        }
        function isModifier(node) {
            return isModifierKind(node.kind);
        }
        function isEntityName(node) {
            const kind = node.kind;
            return kind === 166 /* QualifiedName */ || kind === 80 /* Identifier */;
        }
        function isPropertyName(node) {
            const kind = node.kind;
            return kind === 80 /* Identifier */ || kind === 81 /* PrivateIdentifier */ || kind === 11 /* StringLiteral */ || kind === 9 /* NumericLiteral */ || kind === 167 /* ComputedPropertyName */;
        }
        function isBindingName(node) {
            const kind = node.kind;
            return kind === 80 /* Identifier */ || kind === 206 /* ObjectBindingPattern */ || kind === 207 /* ArrayBindingPattern */;
        }
        function isFunctionLike(node) {
            return !!node && isFunctionLikeKind(node.kind);
        }
        function isFunctionLikeOrClassStaticBlockDeclaration(node) {
            return !!node && (isFunctionLikeKind(node.kind) || isClassStaticBlockDeclaration(node));
        }
        function isFunctionLikeDeclaration(node) {
            return node && isFunctionLikeDeclarationKind(node.kind);
        }
        function isBooleanLiteral(node) {
            return node.kind === 112 /* TrueKeyword */ || node.kind === 97 /* FalseKeyword */;
        }
        function isFunctionLikeDeclarationKind(kind) {
            switch (kind) {
                case 262 /* FunctionDeclaration */:
                case 174 /* MethodDeclaration */:
                case 176 /* Constructor */:
                case 177 /* GetAccessor */:
                case 178 /* SetAccessor */:
                case 218 /* FunctionExpression */:
                case 219 /* ArrowFunction */:
                    return true;
                default:
                    return false;
            }
        }
        function isFunctionLikeKind(kind) {
            switch (kind) {
                case 173 /* MethodSignature */:
                case 179 /* CallSignature */:
                case 330 /* JSDocSignature */:
                case 180 /* ConstructSignature */:
                case 181 /* IndexSignature */:
                case 184 /* FunctionType */:
                case 324 /* JSDocFunctionType */:
                case 185 /* ConstructorType */:
                    return true;
                default:
                    return isFunctionLikeDeclarationKind(kind);
            }
        }
        function isFunctionOrModuleBlock(node) {
            return isSourceFile(node) || isModuleBlock(node) || isBlock(node) && isFunctionLike(node.parent);
        }
        function isClassElement(node) {
            const kind = node.kind;
            return kind === 176 /* Constructor */ || kind === 172 /* PropertyDeclaration */ || kind === 174 /* MethodDeclaration */ || kind === 177 /* GetAccessor */ || kind === 178 /* SetAccessor */ || kind === 181 /* IndexSignature */ || kind === 175 /* ClassStaticBlockDeclaration */ || kind === 240 /* SemicolonClassElement */;
        }
        function isClassLike(node) {
            return node && (node.kind === 263 /* ClassDeclaration */ || node.kind === 231 /* ClassExpression */);
        }
        function isAccessor(node) {
            return node && (node.kind === 177 /* GetAccessor */ || node.kind === 178 /* SetAccessor */);
        }
        function isAutoAccessorPropertyDeclaration(node) {
            return isPropertyDeclaration(node) && hasAccessorModifier(node);
        }
        function isClassInstanceProperty(node) {
            if (isInJSFile(node) && isExpandoPropertyDeclaration(node)) {
                return (!isBindableStaticAccessExpression(node) || !isPrototypeAccess(node.expression)) && !isBindableStaticNameExpression(node, 
                /*excludeThisKeyword*/
                true);
            }
            return node.parent && isClassLike(node.parent) && isPropertyDeclaration(node) && !hasAccessorModifier(node);
        }
        function isMethodOrAccessor(node) {
            switch (node.kind) {
                case 174 /* MethodDeclaration */:
                case 177 /* GetAccessor */:
                case 178 /* SetAccessor */:
                    return true;
                default:
                    return false;
            }
        }
        function isNamedClassElement(node) {
            switch (node.kind) {
                case 174 /* MethodDeclaration */:
                case 177 /* GetAccessor */:
                case 178 /* SetAccessor */:
                case 172 /* PropertyDeclaration */:
                    return true;
                default:
                    return false;
            }
        }
        function isModifierLike(node) {
            return isModifier(node) || isDecorator(node);
        }
        function isTypeElement(node) {
            const kind = node.kind;
            return kind === 180 /* ConstructSignature */ || kind === 179 /* CallSignature */ || kind === 171 /* PropertySignature */ || kind === 173 /* MethodSignature */ || kind === 181 /* IndexSignature */ || kind === 177 /* GetAccessor */ || kind === 178 /* SetAccessor */;
        }
        function isClassOrTypeElement(node) {
            return isTypeElement(node) || isClassElement(node);
        }
        function isObjectLiteralElementLike(node) {
            const kind = node.kind;
            return kind === 303 /* PropertyAssignment */ || kind === 304 /* ShorthandPropertyAssignment */ || kind === 305 /* SpreadAssignment */ || kind === 174 /* MethodDeclaration */ || kind === 177 /* GetAccessor */ || kind === 178 /* SetAccessor */;
        }
        function isTypeNode(node) {
            return isTypeNodeKind(node.kind);
        }
        function isFunctionOrConstructorTypeNode(node) {
            switch (node.kind) {
                case 184 /* FunctionType */:
                case 185 /* ConstructorType */:
                    return true;
            }
            return false;
        }
        function isBindingPattern(node) {
            if (node) {
                const kind = node.kind;
                return kind === 207 /* ArrayBindingPattern */ || kind === 206 /* ObjectBindingPattern */;
            }
            return false;
        }
        function isAssignmentPattern(node) {
            const kind = node.kind;
            return kind === 209 /* ArrayLiteralExpression */ || kind === 210 /* ObjectLiteralExpression */;
        }
        function isArrayBindingElement(node) {
            const kind = node.kind;
            return kind === 208 /* BindingElement */ || kind === 232 /* OmittedExpression */;
        }
        function isDeclarationBindingElement(bindingElement) {
            switch (bindingElement.kind) {
                case 260 /* VariableDeclaration */:
                case 169 /* Parameter */:
                case 208 /* BindingElement */:
                    return true;
            }
            return false;
        }
        function isBindingOrAssignmentElement(node) {
            return isVariableDeclaration(node) || isParameter(node) || isObjectBindingOrAssignmentElement(node) || isArrayBindingOrAssignmentElement(node);
        }
        function isBindingOrAssignmentPattern(node) {
            return isObjectBindingOrAssignmentPattern(node) || isArrayBindingOrAssignmentPattern(node);
        }
        function isObjectBindingOrAssignmentPattern(node) {
            switch (node.kind) {
                case 206 /* ObjectBindingPattern */:
                case 210 /* ObjectLiteralExpression */:
                    return true;
            }
            return false;
        }
        function isObjectBindingOrAssignmentElement(node) {
            switch (node.kind) {
                case 208 /* BindingElement */:
                case 303 /* PropertyAssignment */:
                case 304 /* ShorthandPropertyAssignment */:
                case 305 /* SpreadAssignment */:
                    return true;
            }
            return false;
        }
        function isArrayBindingOrAssignmentPattern(node) {
            switch (node.kind) {
                case 207 /* ArrayBindingPattern */:
                case 209 /* ArrayLiteralExpression */:
                    return true;
            }
            return false;
        }
        function isArrayBindingOrAssignmentElement(node) {
            switch (node.kind) {
                case 208 /* BindingElement */:
                case 232 /* OmittedExpression */:
                case 230 /* SpreadElement */:
                case 209 /* ArrayLiteralExpression */:
                case 210 /* ObjectLiteralExpression */:
                case 80 /* Identifier */:
                case 211 /* PropertyAccessExpression */:
                case 212 /* ElementAccessExpression */:
                    return true;
            }
            return isAssignmentExpression(node, 
            /*excludeCompoundAssignment*/
            true);
        }
        function isPropertyAccessOrQualifiedNameOrImportTypeNode(node) {
            const kind = node.kind;
            return kind === 211 /* PropertyAccessExpression */ || kind === 166 /* QualifiedName */ || kind === 205 /* ImportType */;
        }
        function isPropertyAccessOrQualifiedName(node) {
            const kind = node.kind;
            return kind === 211 /* PropertyAccessExpression */ || kind === 166 /* QualifiedName */;
        }
        function isCallLikeOrFunctionLikeExpression(node) {
            return isCallLikeExpression(node) || isFunctionExpressionOrArrowFunction(node);
        }
        function isCallLikeExpression(node) {
            switch (node.kind) {
                case 286 /* JsxOpeningElement */:
                case 285 /* JsxSelfClosingElement */:
                case 213 /* CallExpression */:
                case 214 /* NewExpression */:
                case 215 /* TaggedTemplateExpression */:
                case 170 /* Decorator */:
                    return true;
                default:
                    return false;
            }
        }
        function isCallOrNewExpression(node) {
            return node.kind === 213 /* CallExpression */ || node.kind === 214 /* NewExpression */;
        }
        function isTemplateLiteral(node) {
            const kind = node.kind;
            return kind === 228 /* TemplateExpression */ || kind === 15 /* NoSubstitutionTemplateLiteral */;
        }
        function isLeftHandSideExpression(node) {
            return isLeftHandSideExpressionKind(skipPartiallyEmittedExpressions(node).kind);
        }
        function isLeftHandSideExpressionKind(kind) {
            switch (kind) {
                case 211 /* PropertyAccessExpression */:
                case 212 /* ElementAccessExpression */:
                case 214 /* NewExpression */:
                case 213 /* CallExpression */:
                case 284 /* JsxElement */:
                case 285 /* JsxSelfClosingElement */:
                case 288 /* JsxFragment */:
                case 215 /* TaggedTemplateExpression */:
                case 209 /* ArrayLiteralExpression */:
                case 217 /* ParenthesizedExpression */:
                case 210 /* ObjectLiteralExpression */:
                case 231 /* ClassExpression */:
                case 218 /* FunctionExpression */:
                case 80 /* Identifier */:
                case 81 /* PrivateIdentifier */:
                case 14 /* RegularExpressionLiteral */:
                case 9 /* NumericLiteral */:
                case 10 /* BigIntLiteral */:
                case 11 /* StringLiteral */:
                case 15 /* NoSubstitutionTemplateLiteral */:
                case 228 /* TemplateExpression */:
                case 97 /* FalseKeyword */:
                case 106 /* NullKeyword */:
                case 110 /* ThisKeyword */:
                case 112 /* TrueKeyword */:
                case 108 /* SuperKeyword */:
                case 235 /* NonNullExpression */:
                case 233 /* ExpressionWithTypeArguments */:
                case 236 /* MetaProperty */:
                case 102 /* ImportKeyword */:
                case 282 /* MissingDeclaration */:
                    return true;
                default:
                    return false;
            }
        }
        function isUnaryExpression(node) {
            return isUnaryExpressionKind(skipPartiallyEmittedExpressions(node).kind);
        }
        function isUnaryExpressionKind(kind) {
            switch (kind) {
                case 224 /* PrefixUnaryExpression */:
                case 225 /* PostfixUnaryExpression */:
                case 220 /* DeleteExpression */:
                case 221 /* TypeOfExpression */:
                case 222 /* VoidExpression */:
                case 223 /* AwaitExpression */:
                case 216 /* TypeAssertionExpression */:
                    return true;
                default:
                    return isLeftHandSideExpressionKind(kind);
            }
        }
        function isUnaryExpressionWithWrite(expr) {
            switch (expr.kind) {
                case 225 /* PostfixUnaryExpression */:
                    return true;
                case 224 /* PrefixUnaryExpression */:
                    return expr.operator === 46 /* PlusPlusToken */ || expr.operator === 47 /* MinusMinusToken */;
                default:
                    return false;
            }
        }
        function isLiteralTypeLiteral(node) {
            switch (node.kind) {
                case 106 /* NullKeyword */:
                case 112 /* TrueKeyword */:
                case 97 /* FalseKeyword */:
                case 224 /* PrefixUnaryExpression */:
                    return true;
                default:
                    return isLiteralExpression(node);
            }
        }
        function isExpression(node) {
            return isExpressionKind(skipPartiallyEmittedExpressions(node).kind);
        }
        function isExpressionKind(kind) {
            switch (kind) {
                case 227 /* ConditionalExpression */:
                case 229 /* YieldExpression */:
                case 219 /* ArrowFunction */:
                case 226 /* BinaryExpression */:
                case 230 /* SpreadElement */:
                case 234 /* AsExpression */:
                case 232 /* OmittedExpression */:
                case 361 /* CommaListExpression */:
                case 360 /* PartiallyEmittedExpression */:
                case 238 /* SatisfiesExpression */:
                    return true;
                default:
                    return isUnaryExpressionKind(kind);
            }
        }
        function isAssertionExpression(node) {
            const kind = node.kind;
            return kind === 216 /* TypeAssertionExpression */ || kind === 234 /* AsExpression */;
        }
        function isNotEmittedOrPartiallyEmittedNode(node) {
            return isNotEmittedStatement(node) || isPartiallyEmittedExpression(node);
        }
        function isIterationStatement(node, lookInLabeledStatements) {
            switch (node.kind) {
                case 248 /* ForStatement */:
                case 249 /* ForInStatement */:
                case 250 /* ForOfStatement */:
                case 246 /* DoStatement */:
                case 247 /* WhileStatement */:
                    return true;
                case 256 /* LabeledStatement */:
                    return lookInLabeledStatements && isIterationStatement(node.statement, lookInLabeledStatements);
            }
            return false;
        }
        function isScopeMarker(node) {
            return isExportAssignment(node) || isExportDeclaration(node);
        }
        function hasScopeMarker(statements) {
            return some(statements, isScopeMarker);
        }
        function needsScopeMarker(result) {
            return !isAnyImportOrReExport(result) && !isExportAssignment(result) && !hasSyntacticModifier(result, 32 /* Export */) && !isAmbientModule(result);
        }
        function isExternalModuleIndicator(result) {
            return isAnyImportOrReExport(result) || isExportAssignment(result) || hasSyntacticModifier(result, 32 /* Export */);
        }
        function isForInOrOfStatement(node) {
            return node.kind === 249 /* ForInStatement */ || node.kind === 250 /* ForOfStatement */;
        }
        function isConciseBody(node) {
            return isBlock(node) || isExpression(node);
        }
        function isFunctionBody(node) {
            return isBlock(node);
        }
        function isForInitializer(node) {
            return isVariableDeclarationList(node) || isExpression(node);
        }
        function isModuleBody(node) {
            const kind = node.kind;
            return kind === 268 /* ModuleBlock */ || kind === 267 /* ModuleDeclaration */ || kind === 80 /* Identifier */;
        }
        function isNamespaceBody(node) {
            const kind = node.kind;
            return kind === 268 /* ModuleBlock */ || kind === 267 /* ModuleDeclaration */;
        }
        function isJSDocNamespaceBody(node) {
            const kind = node.kind;
            return kind === 80 /* Identifier */ || kind === 267 /* ModuleDeclaration */;
        }
        function isNamedImportBindings(node) {
            const kind = node.kind;
            return kind === 275 /* NamedImports */ || kind === 274 /* NamespaceImport */;
        }
        function isModuleOrEnumDeclaration(node) {
            return node.kind === 267 /* ModuleDeclaration */ || node.kind === 266 /* EnumDeclaration */;
        }
        function canHaveSymbol(node) {
            switch (node.kind) {
                case 219 /* ArrowFunction */:
                case 226 /* BinaryExpression */:
                case 208 /* BindingElement */:
                case 213 /* CallExpression */:
                case 179 /* CallSignature */:
                case 263 /* ClassDeclaration */:
                case 231 /* ClassExpression */:
                case 175 /* ClassStaticBlockDeclaration */:
                case 176 /* Constructor */:
                case 185 /* ConstructorType */:
                case 180 /* ConstructSignature */:
                case 212 /* ElementAccessExpression */:
                case 266 /* EnumDeclaration */:
                case 306 /* EnumMember */:
                case 277 /* ExportAssignment */:
                case 278 /* ExportDeclaration */:
                case 281 /* ExportSpecifier */:
                case 262 /* FunctionDeclaration */:
                case 218 /* FunctionExpression */:
                case 184 /* FunctionType */:
                case 177 /* GetAccessor */:
                case 80 /* Identifier */:
                case 273 /* ImportClause */:
                case 271 /* ImportEqualsDeclaration */:
                case 276 /* ImportSpecifier */:
                case 181 /* IndexSignature */:
                case 264 /* InterfaceDeclaration */:
                case 345 /* JSDocCallbackTag */:
                case 347 /* JSDocEnumTag */:
                case 324 /* JSDocFunctionType */:
                case 348 /* JSDocParameterTag */:
                case 355 /* JSDocPropertyTag */:
                case 330 /* JSDocSignature */:
                case 353 /* JSDocTypedefTag */:
                case 329 /* JSDocTypeLiteral */:
                case 291 /* JsxAttribute */:
                case 292 /* JsxAttributes */:
                case 293 /* JsxSpreadAttribute */:
                case 200 /* MappedType */:
                case 174 /* MethodDeclaration */:
                case 173 /* MethodSignature */:
                case 267 /* ModuleDeclaration */:
                case 202 /* NamedTupleMember */:
                case 280 /* NamespaceExport */:
                case 270 /* NamespaceExportDeclaration */:
                case 274 /* NamespaceImport */:
                case 214 /* NewExpression */:
                case 15 /* NoSubstitutionTemplateLiteral */:
                case 9 /* NumericLiteral */:
                case 210 /* ObjectLiteralExpression */:
                case 169 /* Parameter */:
                case 211 /* PropertyAccessExpression */:
                case 303 /* PropertyAssignment */:
                case 172 /* PropertyDeclaration */:
                case 171 /* PropertySignature */:
                case 178 /* SetAccessor */:
                case 304 /* ShorthandPropertyAssignment */:
                case 312 /* SourceFile */:
                case 305 /* SpreadAssignment */:
                case 11 /* StringLiteral */:
                case 265 /* TypeAliasDeclaration */:
                case 187 /* TypeLiteral */:
                case 168 /* TypeParameter */:
                case 260 /* VariableDeclaration */:
                    return true;
                default:
                    return false;
            }
        }
        function canHaveLocals(node) {
            switch (node.kind) {
                case 219 /* ArrowFunction */:
                case 241 /* Block */:
                case 179 /* CallSignature */:
                case 269 /* CaseBlock */:
                case 299 /* CatchClause */:
                case 175 /* ClassStaticBlockDeclaration */:
                case 194 /* ConditionalType */:
                case 176 /* Constructor */:
                case 185 /* ConstructorType */:
                case 180 /* ConstructSignature */:
                case 248 /* ForStatement */:
                case 249 /* ForInStatement */:
                case 250 /* ForOfStatement */:
                case 262 /* FunctionDeclaration */:
                case 218 /* FunctionExpression */:
                case 184 /* FunctionType */:
                case 177 /* GetAccessor */:
                case 181 /* IndexSignature */:
                case 345 /* JSDocCallbackTag */:
                case 347 /* JSDocEnumTag */:
                case 324 /* JSDocFunctionType */:
                case 330 /* JSDocSignature */:
                case 353 /* JSDocTypedefTag */:
                case 200 /* MappedType */:
                case 174 /* MethodDeclaration */:
                case 173 /* MethodSignature */:
                case 267 /* ModuleDeclaration */:
                case 178 /* SetAccessor */:
                case 312 /* SourceFile */:
                case 265 /* TypeAliasDeclaration */:
                    return true;
                default:
                    return false;
            }
        }
        function isDeclarationKind(kind) {
            return kind === 219 /* ArrowFunction */ || kind === 208 /* BindingElement */ || kind === 263 /* ClassDeclaration */ || kind === 231 /* ClassExpression */ || kind === 175 /* ClassStaticBlockDeclaration */ || kind === 176 /* Constructor */ || kind === 266 /* EnumDeclaration */ || kind === 306 /* EnumMember */ || kind === 281 /* ExportSpecifier */ || kind === 262 /* FunctionDeclaration */ || kind === 218 /* FunctionExpression */ || kind === 177 /* GetAccessor */ || kind === 273 /* ImportClause */ || kind === 271 /* ImportEqualsDeclaration */ || kind === 276 /* ImportSpecifier */ || kind === 264 /* InterfaceDeclaration */ || kind === 291 /* JsxAttribute */ || kind === 174 /* MethodDeclaration */ || kind === 173 /* MethodSignature */ || kind === 267 /* ModuleDeclaration */ || kind === 270 /* NamespaceExportDeclaration */ || kind === 274 /* NamespaceImport */ || kind === 280 /* NamespaceExport */ || kind === 169 /* Parameter */ || kind === 303 /* PropertyAssignment */ || kind === 172 /* PropertyDeclaration */ || kind === 171 /* PropertySignature */ || kind === 178 /* SetAccessor */ || kind === 304 /* ShorthandPropertyAssignment */ || kind === 265 /* TypeAliasDeclaration */ || kind === 168 /* TypeParameter */ || kind === 260 /* VariableDeclaration */ || kind === 353 /* JSDocTypedefTag */ || kind === 345 /* JSDocCallbackTag */ || kind === 355 /* JSDocPropertyTag */;
        }
        function isDeclarationStatementKind(kind) {
            return kind === 262 /* FunctionDeclaration */ || kind === 282 /* MissingDeclaration */ || kind === 263 /* ClassDeclaration */ || kind === 264 /* InterfaceDeclaration */ || kind === 265 /* TypeAliasDeclaration */ || kind === 266 /* EnumDeclaration */ || kind === 267 /* ModuleDeclaration */ || kind === 272 /* ImportDeclaration */ || kind === 271 /* ImportEqualsDeclaration */ || kind === 278 /* ExportDeclaration */ || kind === 277 /* ExportAssignment */ || kind === 270 /* NamespaceExportDeclaration */;
        }
        function isStatementKindButNotDeclarationKind(kind) {
            return kind === 252 /* BreakStatement */ || kind === 251 /* ContinueStatement */ || kind === 259 /* DebuggerStatement */ || kind === 246 /* DoStatement */ || kind === 244 /* ExpressionStatement */ || kind === 242 /* EmptyStatement */ || kind === 249 /* ForInStatement */ || kind === 250 /* ForOfStatement */ || kind === 248 /* ForStatement */ || kind === 245 /* IfStatement */ || kind === 256 /* LabeledStatement */ || kind === 253 /* ReturnStatement */ || kind === 255 /* SwitchStatement */ || kind === 257 /* ThrowStatement */ || kind === 258 /* TryStatement */ || kind === 243 /* VariableStatement */ || kind === 247 /* WhileStatement */ || kind === 254 /* WithStatement */ || kind === 359 /* NotEmittedStatement */;
        }
        function isDeclaration(node) {
            if (node.kind === 168 /* TypeParameter */) {
                return node.parent && node.parent.kind !== 352 /* JSDocTemplateTag */ || isInJSFile(node);
            }
            return isDeclarationKind(node.kind);
        }
        function isDeclarationStatement(node) {
            return isDeclarationStatementKind(node.kind);
        }
        function isStatementButNotDeclaration(node) {
            return isStatementKindButNotDeclarationKind(node.kind);
        }
        function isStatement(node) {
            const kind = node.kind;
            return isStatementKindButNotDeclarationKind(kind) || isDeclarationStatementKind(kind) || isBlockStatement(node);
        }
        function isBlockStatement(node) {
            if (node.kind !== 241 /* Block */)
                return false;
            if (node.parent !== void 0) {
                if (node.parent.kind === 258 /* TryStatement */ || node.parent.kind === 299 /* CatchClause */) {
                    return false;
                }
            }
            return !isFunctionBlock(node);
        }
        function isStatementOrBlock(node) {
            const kind = node.kind;
            return isStatementKindButNotDeclarationKind(kind) || isDeclarationStatementKind(kind) || kind === 241 /* Block */;
        }
        function isModuleReference(node) {
            const kind = node.kind;
            return kind === 283 /* ExternalModuleReference */ || kind === 166 /* QualifiedName */ || kind === 80 /* Identifier */;
        }
        function isJsxTagNameExpression(node) {
            const kind = node.kind;
            return kind === 110 /* ThisKeyword */ || kind === 80 /* Identifier */ || kind === 211 /* PropertyAccessExpression */ || kind === 295 /* JsxNamespacedName */;
        }
        function isJsxChild(node) {
            const kind = node.kind;
            return kind === 284 /* JsxElement */ || kind === 294 /* JsxExpression */ || kind === 285 /* JsxSelfClosingElement */ || kind === 12 /* JsxText */ || kind === 288 /* JsxFragment */;
        }
        function isJsxAttributeLike(node) {
            const kind = node.kind;
            return kind === 291 /* JsxAttribute */ || kind === 293 /* JsxSpreadAttribute */;
        }
        function isStringLiteralOrJsxExpression(node) {
            const kind = node.kind;
            return kind === 11 /* StringLiteral */ || kind === 294 /* JsxExpression */;
        }
        function isJsxOpeningLikeElement(node) {
            const kind = node.kind;
            return kind === 286 /* JsxOpeningElement */ || kind === 285 /* JsxSelfClosingElement */;
        }
        function isCaseOrDefaultClause(node) {
            const kind = node.kind;
            return kind === 296 /* CaseClause */ || kind === 297 /* DefaultClause */;
        }
        function isJSDocNode(node) {
            return node.kind >= 316 /* FirstJSDocNode */ && node.kind <= 357 /* LastJSDocNode */;
        }
        function isJSDocCommentContainingNode(node) {
            return node.kind === 327 /* JSDoc */ || node.kind === 326 /* JSDocNamepathType */ || node.kind === 328 /* JSDocText */ || isJSDocLinkLike(node) || isJSDocTag(node) || isJSDocTypeLiteral(node) || isJSDocSignature(node);
        }
        function isJSDocTag(node) {
            return node.kind >= 334 /* FirstJSDocTagNode */ && node.kind <= 357 /* LastJSDocTagNode */;
        }
        function isSetAccessor(node) {
            return node.kind === 178 /* SetAccessor */;
        }
        function isGetAccessor(node) {
            return node.kind === 177 /* GetAccessor */;
        }
        function hasJSDocNodes(node) {
            if (!canHaveJSDoc(node))
                return false;
            const { jsDoc } = node;
            return !!jsDoc && jsDoc.length > 0;
        }
        function hasType(node) {
            return !!node.type;
        }
        function hasInitializer(node) {
            return !!node.initializer;
        }
        function hasOnlyExpressionInitializer(node) {
            switch (node.kind) {
                case 260 /* VariableDeclaration */:
                case 169 /* Parameter */:
                case 208 /* BindingElement */:
                case 172 /* PropertyDeclaration */:
                case 303 /* PropertyAssignment */:
                case 306 /* EnumMember */:
                    return true;
                default:
                    return false;
            }
        }
        function isObjectLiteralElement(node) {
            return node.kind === 291 /* JsxAttribute */ || node.kind === 293 /* JsxSpreadAttribute */ || isObjectLiteralElementLike(node);
        }
        function isTypeReferenceType(node) {
            return node.kind === 183 /* TypeReference */ || node.kind === 233 /* ExpressionWithTypeArguments */;
        }
        function guessIndentation(lines) {
            let indentation = MAX_SMI_X86;
            for (const line of lines) {
                if (!line.length) {
                    continue;
                }
                let i = 0;
                for (; i < line.length && i < indentation; i++) {
                    if (!isWhiteSpaceLike(line.charCodeAt(i))) {
                        break;
                    }
                }
                if (i < indentation) {
                    indentation = i;
                }
                if (indentation === 0) {
                    return 0;
                }
            }
            return indentation === MAX_SMI_X86 ? void 0 : indentation;
        }
        function isStringLiteralLike(node) {
            return node.kind === 11 /* StringLiteral */ || node.kind === 15 /* NoSubstitutionTemplateLiteral */;
        }
        function isJSDocLinkLike(node) {
            return node.kind === 331 /* JSDocLink */ || node.kind === 332 /* JSDocLinkCode */ || node.kind === 333 /* JSDocLinkPlain */;
        }
        function hasRestParameter(s) {
            const last2 = lastOrUndefined(s.parameters);
            return !!last2 && isRestParameter(last2);
        }
        function isRestParameter(node) {
            const type = isJSDocParameterTag(node) ? node.typeExpression && node.typeExpression.type : node.type;
            return node.dotDotDotToken !== void 0 || !!type && type.kind === 325 /* JSDocVariadicType */;
        }
        function hasInternalAnnotation(range, sourceFile) {
            const comment = sourceFile.text.substring(range.pos, range.end);
            return comment.includes("@internal");
        }
        function isInternalDeclaration(node, sourceFile) {
            sourceFile ?? (sourceFile = getSourceFileOfNode(node));
            const parseTreeNode = getParseTreeNode(node);
            if (parseTreeNode && parseTreeNode.kind === 169 /* Parameter */) {
                const paramIdx = parseTreeNode.parent.parameters.indexOf(parseTreeNode);
                const previousSibling = paramIdx > 0 ? parseTreeNode.parent.parameters[paramIdx - 1] : void 0;
                const text = sourceFile.text;
                const commentRanges = previousSibling ? concatenate(
                // to handle
                // ... parameters, /** @internal */
                // public param: string
                getTrailingCommentRanges(text, skipTrivia(text, previousSibling.end + 1, 
                /*stopAfterLineBreak*/
                false, 
                /*stopAtComments*/
                true)), getLeadingCommentRanges(text, node.pos)) : getTrailingCommentRanges(text, skipTrivia(text, node.pos, 
                /*stopAfterLineBreak*/
                false, 
                /*stopAtComments*/
                true));
                return some(commentRanges) && hasInternalAnnotation(last(commentRanges), sourceFile);
            }
            const leadingCommentRanges = parseTreeNode && getLeadingCommentRangesOfNode(parseTreeNode, sourceFile);
            return !!forEach(leadingCommentRanges, (range) => {
                return hasInternalAnnotation(range, sourceFile);
            });
        }
        var unchangedTextChangeRange, supportedLocaleDirectories, MAX_SMI_X86;
        var init_utilitiesPublic = __esm({
            "src/compiler/utilitiesPublic.ts"() {
                "use strict";
                init_ts2();
                unchangedTextChangeRange = createTextChangeRange(createTextSpan(0, 0), 0);
                supportedLocaleDirectories = ["cs", "de", "es", "fr", "it", "ja", "ko", "pl", "pt-br", "ru", "tr", "zh-cn", "zh-tw"];
                MAX_SMI_X86 = 1073741823;
            }
        });
        // src/compiler/utilities.ts
        function getDeclarationOfKind(symbol, kind) {
            const declarations = symbol.declarations;
            if (declarations) {
                for (const declaration of declarations) {
                    if (declaration.kind === kind) {
                        return declaration;
                    }
                }
            }
            return void 0;
        }
        function getDeclarationsOfKind(symbol, kind) {
            return filter(symbol.declarations || emptyArray, (d) => d.kind === kind);
        }
        function createSymbolTable(symbols) {
            const result = /* @__PURE__ */ new Map();
            if (symbols) {
                for (const symbol of symbols) {
                    result.set(symbol.escapedName, symbol);
                }
            }
            return result;
        }
        function isTransientSymbol(symbol) {
            return (symbol.flags & 33554432 /* Transient */) !== 0;
        }
        function createSingleLineStringWriter() {
            var str = "";
            const writeText = (text) => str += text;
            return {
                getText: () => str,
                write: writeText,
                rawWrite: writeText,
                writeKeyword: writeText,
                writeOperator: writeText,
                writePunctuation: writeText,
                writeSpace: writeText,
                writeStringLiteral: writeText,
                writeLiteral: writeText,
                writeParameter: writeText,
                writeProperty: writeText,
                writeSymbol: (s, _) => writeText(s),
                writeTrailingSemicolon: writeText,
                writeComment: writeText,
                getTextPos: () => str.length,
                getLine: () => 0,
                getColumn: () => 0,
                getIndent: () => 0,
                isAtStartOfLine: () => false,
                hasTrailingComment: () => false,
                hasTrailingWhitespace: () => !!str.length && isWhiteSpaceLike(str.charCodeAt(str.length - 1)),
                // Completely ignore indentation for string writers.  And map newlines to
                // a single space.
                writeLine: () => str += " ",
                increaseIndent: noop,
                decreaseIndent: noop,
                clear: () => str = ""
            };
        }
        function changesAffectModuleResolution(oldOptions, newOptions) {
            return oldOptions.configFilePath !== newOptions.configFilePath || optionsHaveModuleResolutionChanges(oldOptions, newOptions);
        }
        function optionsHaveModuleResolutionChanges(oldOptions, newOptions) {
            return optionsHaveChanges(oldOptions, newOptions, moduleResolutionOptionDeclarations);
        }
        function changesAffectingProgramStructure(oldOptions, newOptions) {
            return optionsHaveChanges(oldOptions, newOptions, optionsAffectingProgramStructure);
        }
        function optionsHaveChanges(oldOptions, newOptions, optionDeclarations2) {
            return oldOptions !== newOptions && optionDeclarations2.some((o) => !isJsonEqual(getCompilerOptionValue(oldOptions, o), getCompilerOptionValue(newOptions, o)));
        }
        function forEachAncestor(node, callback) {
            while (true) {
                const res = callback(node);
                if (res === "quit")
                    return void 0;
                if (res !== void 0)
                    return res;
                if (isSourceFile(node))
                    return void 0;
                node = node.parent;
            }
        }
        function forEachEntry(map2, callback) {
            const iterator = map2.entries();
            for (const [key, value] of iterator) {
                const result = callback(value, key);
                if (result) {
                    return result;
                }
            }
            return void 0;
        }
        function forEachKey(map2, callback) {
            const iterator = map2.keys();
            for (const key of iterator) {
                const result = callback(key);
                if (result) {
                    return result;
                }
            }
            return void 0;
        }
        function copyEntries(source, target) {
            source.forEach((value, key) => {
                target.set(key, value);
            });
        }
        function usingSingleLineStringWriter(action) {
            const oldString = stringWriter.getText();
            try {
                action(stringWriter);
                return stringWriter.getText();
            }
            finally {
                stringWriter.clear();
                stringWriter.writeKeyword(oldString);
            }
        }
        function getFullWidth(node) {
            return node.end - node.pos;
        }
        function projectReferenceIsEqualTo(oldRef, newRef) {
            return oldRef.path === newRef.path && !oldRef.prepend === !newRef.prepend && !oldRef.circular === !newRef.circular;
        }
        function moduleResolutionIsEqualTo(oldResolution, newResolution) {
            return oldResolution === newResolution || oldResolution.resolvedModule === newResolution.resolvedModule || !!oldResolution.resolvedModule && !!newResolution.resolvedModule && oldResolution.resolvedModule.isExternalLibraryImport === newResolution.resolvedModule.isExternalLibraryImport && oldResolution.resolvedModule.extension === newResolution.resolvedModule.extension && oldResolution.resolvedModule.resolvedFileName === newResolution.resolvedModule.resolvedFileName && oldResolution.resolvedModule.originalPath === newResolution.resolvedModule.originalPath && packageIdIsEqual(oldResolution.resolvedModule.packageId, newResolution.resolvedModule.packageId) && oldResolution.alternateResult === newResolution.alternateResult;
        }
        function createModuleNotFoundChain(sourceFile, host, moduleReference, mode, packageName) {
            var _a;
            const alternateResult = (_a = host.getResolvedModule(sourceFile, moduleReference, mode)) == null ? void 0 : _a.alternateResult;
            const alternateResultMessage = alternateResult && (getEmitModuleResolutionKind(host.getCompilerOptions()) === 2 /* Node10 */ ? [Diagnostics.There_are_types_at_0_but_this_result_could_not_be_resolved_under_your_current_moduleResolution_setting_Consider_updating_to_node16_nodenext_or_bundler, [alternateResult]] : [
                Diagnostics.There_are_types_at_0_but_this_result_could_not_be_resolved_when_respecting_package_json_exports_The_1_library_may_need_to_update_its_package_json_or_typings,
                [alternateResult, alternateResult.includes(nodeModulesPathPart + "@types/") ? `@types/${mangleScopedPackageName(packageName)}` : packageName]
            ]);
            const result = alternateResultMessage ? chainDiagnosticMessages(
            /*details*/
            void 0, alternateResultMessage[0], ...alternateResultMessage[1]) : host.typesPackageExists(packageName) ? chainDiagnosticMessages(
            /*details*/
            void 0, Diagnostics.If_the_0_package_actually_exposes_this_module_consider_sending_a_pull_request_to_amend_https_Colon_Slash_Slashgithub_com_SlashDefinitelyTyped_SlashDefinitelyTyped_Slashtree_Slashmaster_Slashtypes_Slash_1, packageName, mangleScopedPackageName(packageName)) : host.packageBundlesTypes(packageName) ? chainDiagnosticMessages(
            /*details*/
            void 0, Diagnostics.If_the_0_package_actually_exposes_this_module_try_adding_a_new_declaration_d_ts_file_containing_declare_module_1, packageName, moduleReference) : chainDiagnosticMessages(
            /*details*/
            void 0, Diagnostics.Try_npm_i_save_dev_types_Slash_1_if_it_exists_or_add_a_new_declaration_d_ts_file_containing_declare_module_0, moduleReference, mangleScopedPackageName(packageName));
            if (result)
                result.repopulateInfo = () => ({ moduleReference, mode, packageName: packageName === moduleReference ? void 0 : packageName });
            return result;
        }
        function packageIdIsEqual(a, b) {
            return a === b || !!a && !!b && a.name === b.name && a.subModuleName === b.subModuleName && a.version === b.version;
        }
        function packageIdToPackageName({ name, subModuleName }) {
            return subModuleName ? `${name}/${subModuleName}` : name;
        }
        function packageIdToString(packageId) {
            return `${packageIdToPackageName(packageId)}@${packageId.version}`;
        }
        function typeDirectiveIsEqualTo(oldResolution, newResolution) {
            return oldResolution === newResolution || oldResolution.resolvedTypeReferenceDirective === newResolution.resolvedTypeReferenceDirective || !!oldResolution.resolvedTypeReferenceDirective && !!newResolution.resolvedTypeReferenceDirective && oldResolution.resolvedTypeReferenceDirective.resolvedFileName === newResolution.resolvedTypeReferenceDirective.resolvedFileName && !!oldResolution.resolvedTypeReferenceDirective.primary === !!newResolution.resolvedTypeReferenceDirective.primary && oldResolution.resolvedTypeReferenceDirective.originalPath === newResolution.resolvedTypeReferenceDirective.originalPath;
        }
        function hasChangesInResolutions(names, newResolutions, getOldResolution, comparer) {
            Debug.assert(names.length === newResolutions.length);
            for (let i = 0; i < names.length; i++) {
                const newResolution = newResolutions[i];
                const entry = names[i];
                const oldResolution = getOldResolution(entry);
                const changed = oldResolution ? !newResolution || !comparer(oldResolution, newResolution) : newResolution;
                if (changed) {
                    return true;
                }
            }
            return false;
        }
        function containsParseError(node) {
            aggregateChildData(node);
            return (node.flags & 1048576 /* ThisNodeOrAnySubNodesHasError */) !== 0;
        }
        function aggregateChildData(node) {
            if (!(node.flags & 2097152 /* HasAggregatedChildData */)) {
                const thisNodeOrAnySubNodesHasError = (node.flags & 262144 /* ThisNodeHasError */) !== 0 || forEachChild(node, containsParseError);
                if (thisNodeOrAnySubNodesHasError) {
                    node.flags |= 1048576 /* ThisNodeOrAnySubNodesHasError */;
                }
                node.flags |= 2097152 /* HasAggregatedChildData */;
            }
        }
        function getSourceFileOfNode(node) {
            while (node && node.kind !== 312 /* SourceFile */) {
                node = node.parent;
            }
            return node;
        }
        function getSourceFileOfModule(module2) {
            return getSourceFileOfNode(module2.valueDeclaration || getNonAugmentationDeclaration(module2));
        }
        function isPlainJsFile(file, checkJs) {
            return !!file && (file.scriptKind === 1 /* JS */ || file.scriptKind === 2 /* JSX */) && !file.checkJsDirective && checkJs === void 0;
        }
        function isStatementWithLocals(node) {
            switch (node.kind) {
                case 241 /* Block */:
                case 269 /* CaseBlock */:
                case 248 /* ForStatement */:
                case 249 /* ForInStatement */:
                case 250 /* ForOfStatement */:
                    return true;
            }
            return false;
        }
        function getStartPositionOfLine(line, sourceFile) {
            Debug.assert(line >= 0);
            return getLineStarts(sourceFile)[line];
        }
        function nodePosToString(node) {
            const file = getSourceFileOfNode(node);
            const loc = getLineAndCharacterOfPosition(file, node.pos);
            return `${file.fileName}(${loc.line + 1},${loc.character + 1})`;
        }
        function getEndLinePosition(line, sourceFile) {
            Debug.assert(line >= 0);
            const lineStarts = getLineStarts(sourceFile);
            const lineIndex = line;
            const sourceText = sourceFile.text;
            if (lineIndex + 1 === lineStarts.length) {
                return sourceText.length - 1;
            }
            else {
                const start = lineStarts[lineIndex];
                let pos = lineStarts[lineIndex + 1] - 1;
                Debug.assert(isLineBreak(sourceText.charCodeAt(pos)));
                while (start <= pos && isLineBreak(sourceText.charCodeAt(pos))) {
                    pos--;
                }
                return pos;
            }
        }
        function isFileLevelUniqueName(sourceFile, name, hasGlobalName) {
            return !(hasGlobalName && hasGlobalName(name)) && !sourceFile.identifiers.has(name);
        }
        function nodeIsMissing(node) {
            if (node === void 0) {
                return true;
            }
            return node.pos === node.end && node.pos >= 0 && node.kind !== 1 /* EndOfFileToken */;
        }
        function nodeIsPresent(node) {
            return !nodeIsMissing(node);
        }
        function isGrammarError(parent2, child) {
            if (isTypeParameterDeclaration(parent2))
                return child === parent2.expression;
            if (isClassStaticBlockDeclaration(parent2))
                return child === parent2.modifiers;
            if (isPropertySignature(parent2))
                return child === parent2.initializer;
            if (isPropertyDeclaration(parent2))
                return child === parent2.questionToken && isAutoAccessorPropertyDeclaration(parent2);
            if (isPropertyAssignment(parent2))
                return child === parent2.modifiers || child === parent2.questionToken || child === parent2.exclamationToken || isGrammarErrorElement(parent2.modifiers, child, isModifierLike);
            if (isShorthandPropertyAssignment(parent2))
                return child === parent2.equalsToken || child === parent2.modifiers || child === parent2.questionToken || child === parent2.exclamationToken || isGrammarErrorElement(parent2.modifiers, child, isModifierLike);
            if (isMethodDeclaration(parent2))
                return child === parent2.exclamationToken;
            if (isConstructorDeclaration(parent2))
                return child === parent2.typeParameters || child === parent2.type || isGrammarErrorElement(parent2.typeParameters, child, isTypeParameterDeclaration);
            if (isGetAccessorDeclaration(parent2))
                return child === parent2.typeParameters || isGrammarErrorElement(parent2.typeParameters, child, isTypeParameterDeclaration);
            if (isSetAccessorDeclaration(parent2))
                return child === parent2.typeParameters || child === parent2.type || isGrammarErrorElement(parent2.typeParameters, child, isTypeParameterDeclaration);
            if (isNamespaceExportDeclaration(parent2))
                return child === parent2.modifiers || isGrammarErrorElement(parent2.modifiers, child, isModifierLike);
            return false;
        }
        function isGrammarErrorElement(nodeArray, child, isElement) {
            if (!nodeArray || isArray(child) || !isElement(child))
                return false;
            return contains(nodeArray, child);
        }
        function insertStatementsAfterPrologue(to, from, isPrologueDirective2) {
            if (from === void 0 || from.length === 0)
                return to;
            let statementIndex = 0;
            for (; statementIndex < to.length; ++statementIndex) {
                if (!isPrologueDirective2(to[statementIndex])) {
                    break;
                }
            }
            to.splice(statementIndex, 0, ...from);
            return to;
        }
        function insertStatementAfterPrologue(to, statement, isPrologueDirective2) {
            if (statement === void 0)
                return to;
            let statementIndex = 0;
            for (; statementIndex < to.length; ++statementIndex) {
                if (!isPrologueDirective2(to[statementIndex])) {
                    break;
                }
            }
            to.splice(statementIndex, 0, statement);
            return to;
        }
        function isAnyPrologueDirective(node) {
            return isPrologueDirective(node) || !!(getEmitFlags(node) & 2097152 /* CustomPrologue */);
        }
        function insertStatementsAfterStandardPrologue(to, from) {
            return insertStatementsAfterPrologue(to, from, isPrologueDirective);
        }
        function insertStatementsAfterCustomPrologue(to, from) {
            return insertStatementsAfterPrologue(to, from, isAnyPrologueDirective);
        }
        function insertStatementAfterStandardPrologue(to, statement) {
            return insertStatementAfterPrologue(to, statement, isPrologueDirective);
        }
        function insertStatementAfterCustomPrologue(to, statement) {
            return insertStatementAfterPrologue(to, statement, isAnyPrologueDirective);
        }
        function isRecognizedTripleSlashComment(text, commentPos, commentEnd) {
            if (text.charCodeAt(commentPos + 1) === 47 /* slash */ && commentPos + 2 < commentEnd && text.charCodeAt(commentPos + 2) === 47 /* slash */) {
                const textSubStr = text.substring(commentPos, commentEnd);
                return fullTripleSlashReferencePathRegEx.test(textSubStr) || fullTripleSlashAMDReferencePathRegEx.test(textSubStr) || fullTripleSlashAMDModuleRegEx.test(textSubStr) || fullTripleSlashReferenceTypeReferenceDirectiveRegEx.test(textSubStr) || fullTripleSlashLibReferenceRegEx.test(textSubStr) || defaultLibReferenceRegEx.test(textSubStr) ? true : false;
            }
            return false;
        }
        function isPinnedComment(text, start) {
            return text.charCodeAt(start + 1) === 42 /* asterisk */ && text.charCodeAt(start + 2) === 33 /* exclamation */;
        }
        function createCommentDirectivesMap(sourceFile, commentDirectives) {
            const directivesByLine = new Map(commentDirectives.map((commentDirective) => [
                `${getLineAndCharacterOfPosition(sourceFile, commentDirective.range.end).line}`,
                commentDirective
            ]));
            const usedLines = /* @__PURE__ */ new Map();
            return { getUnusedExpectations, markUsed };
            function getUnusedExpectations() {
                return arrayFrom(directivesByLine.entries()).filter(([line, directive]) => directive.type === 0 /* ExpectError */ && !usedLines.get(line)).map(([_, directive]) => directive);
            }
            function markUsed(line) {
                if (!directivesByLine.has(`${line}`)) {
                    return false;
                }
                usedLines.set(`${line}`, true);
                return true;
            }
        }
        function getTokenPosOfNode(node, sourceFile, includeJsDoc) {
            if (nodeIsMissing(node)) {
                return node.pos;
            }
            if (isJSDocNode(node) || node.kind === 12 /* JsxText */) {
                return skipTrivia((sourceFile || getSourceFileOfNode(node)).text, node.pos, 
                /*stopAfterLineBreak*/
                false, 
                /*stopAtComments*/
                true);
            }
            if (includeJsDoc && hasJSDocNodes(node)) {
                return getTokenPosOfNode(node.jsDoc[0], sourceFile);
            }
            if (node.kind === 358 /* SyntaxList */ && node._children.length > 0) {
                return getTokenPosOfNode(node._children[0], sourceFile, includeJsDoc);
            }
            return skipTrivia((sourceFile || getSourceFileOfNode(node)).text, node.pos, 
            /*stopAfterLineBreak*/
            false, 
            /*stopAtComments*/
            false, isInJSDoc(node));
        }
        function getNonDecoratorTokenPosOfNode(node, sourceFile) {
            const lastDecorator = !nodeIsMissing(node) && canHaveModifiers(node) ? findLast(node.modifiers, isDecorator) : void 0;
            if (!lastDecorator) {
                return getTokenPosOfNode(node, sourceFile);
            }
            return skipTrivia((sourceFile || getSourceFileOfNode(node)).text, lastDecorator.end);
        }
        function getSourceTextOfNodeFromSourceFile(sourceFile, node, includeTrivia = false) {
            return getTextOfNodeFromSourceText(sourceFile.text, node, includeTrivia);
        }
        function isJSDocTypeExpressionOrChild(node) {
            return !!findAncestor(node, isJSDocTypeExpression);
        }
        function isExportNamespaceAsDefaultDeclaration(node) {
            return !!(isExportDeclaration(node) && node.exportClause && isNamespaceExport(node.exportClause) && node.exportClause.name.escapedText === "default");
        }
        function getTextOfNodeFromSourceText(sourceText, node, includeTrivia = false) {
            if (nodeIsMissing(node)) {
                return "";
            }
            let text = sourceText.substring(includeTrivia ? node.pos : skipTrivia(sourceText, node.pos), node.end);
            if (isJSDocTypeExpressionOrChild(node)) {
                text = text.split(/\r\n|\n|\r/).map((line) => line.replace(/^\s*\*/, "").trimStart()).join("\n");
            }
            return text;
        }
        function getTextOfNode(node, includeTrivia = false) {
            return getSourceTextOfNodeFromSourceFile(getSourceFileOfNode(node), node, includeTrivia);
        }
        function getPos(range) {
            return range.pos;
        }
        function indexOfNode(nodeArray, node) {
            return binarySearch(nodeArray, node, getPos, compareValues);
        }
        function getEmitFlags(node) {
            const emitNode = node.emitNode;
            return emitNode && emitNode.flags || 0;
        }
        function getInternalEmitFlags(node) {
            const emitNode = node.emitNode;
            return emitNode && emitNode.internalFlags || 0;
        }
        function getLiteralText(node, sourceFile, flags) {
            if (sourceFile && canUseOriginalText(node, flags)) {
                return getSourceTextOfNodeFromSourceFile(sourceFile, node);
            }
            switch (node.kind) {
                case 11 /* StringLiteral */: {
                    const escapeText = flags & 2 /* JsxAttributeEscape */ ? escapeJsxAttributeString : flags & 1 /* NeverAsciiEscape */ || getEmitFlags(node) & 16777216 /* NoAsciiEscaping */ ? escapeString : escapeNonAsciiString;
                    if (node.singleQuote) {
                        return "'" + escapeText(node.text, 39 /* singleQuote */) + "'";
                    }
                    else {
                        return '"' + escapeText(node.text, 34 /* doubleQuote */) + '"';
                    }
                }
                case 15 /* NoSubstitutionTemplateLiteral */:
                case 16 /* TemplateHead */:
                case 17 /* TemplateMiddle */:
                case 18 /* TemplateTail */: {
                    const escapeText = flags & 1 /* NeverAsciiEscape */ || getEmitFlags(node) & 16777216 /* NoAsciiEscaping */ ? escapeString : escapeNonAsciiString;
                    const rawText = node.rawText ?? escapeTemplateSubstitution(escapeText(node.text, 96 /* backtick */));
                    switch (node.kind) {
                        case 15 /* NoSubstitutionTemplateLiteral */:
                            return "`" + rawText + "`";
                        case 16 /* TemplateHead */:
                            return "`" + rawText + "${";
                        case 17 /* TemplateMiddle */:
                            return "}" + rawText + "${";
                        case 18 /* TemplateTail */:
                            return "}" + rawText + "`";
                    }
                    break;
                }
                case 9 /* NumericLiteral */:
                case 10 /* BigIntLiteral */:
                    return node.text;
                case 14 /* RegularExpressionLiteral */:
                    if (flags & 4 /* TerminateUnterminatedLiterals */ && node.isUnterminated) {
                        return node.text + (node.text.charCodeAt(node.text.length - 1) === 92 /* backslash */ ? " /" : "/");
                    }
                    return node.text;
            }
            return Debug.fail(`Literal kind '${node.kind}' not accounted for.`);
        }
        function canUseOriginalText(node, flags) {
            if (nodeIsSynthesized(node) || !node.parent || flags & 4 /* TerminateUnterminatedLiterals */ && node.isUnterminated) {
                return false;
            }
            if (isNumericLiteral(node)) {
                if (node.numericLiteralFlags & 26656 /* IsInvalid */) {
                    return false;
                }
                if (node.numericLiteralFlags & 512 /* ContainsSeparator */) {
                    return !!(flags & 8 /* AllowNumericSeparator */);
                }
            }
            return !isBigIntLiteral(node);
        }
        function getTextOfConstantValue(value) {
            return isString(value) ? '"' + escapeNonAsciiString(value) + '"' : "" + value;
        }
        function makeIdentifierFromModuleName(moduleName) {
            return getBaseFileName(moduleName).replace(/^(\d)/, "_$1").replace(/\W/g, "_");
        }
        function isBlockOrCatchScoped(declaration) {
            return (getCombinedNodeFlags(declaration) & 7 /* BlockScoped */) !== 0 || isCatchClauseVariableDeclarationOrBindingElement(declaration);
        }
        function isCatchClauseVariableDeclarationOrBindingElement(declaration) {
            const node = getRootDeclaration(declaration);
            return node.kind === 260 /* VariableDeclaration */ && node.parent.kind === 299 /* CatchClause */;
        }
        function isAmbientModule(node) {
            return isModuleDeclaration(node) && (node.name.kind === 11 /* StringLiteral */ || isGlobalScopeAugmentation(node));
        }
        function isModuleWithStringLiteralName(node) {
            return isModuleDeclaration(node) && node.name.kind === 11 /* StringLiteral */;
        }
        function isNonGlobalAmbientModule(node) {
            return isModuleDeclaration(node) && isStringLiteral(node.name);
        }
        function isEffectiveModuleDeclaration(node) {
            return isModuleDeclaration(node) || isIdentifier(node);
        }
        function isShorthandAmbientModuleSymbol(moduleSymbol) {
            return isShorthandAmbientModule(moduleSymbol.valueDeclaration);
        }
        function isShorthandAmbientModule(node) {
            return !!node && node.kind === 267 /* ModuleDeclaration */ && !node.body;
        }
        function isBlockScopedContainerTopLevel(node) {
            return node.kind === 312 /* SourceFile */ || node.kind === 267 /* ModuleDeclaration */ || isFunctionLikeOrClassStaticBlockDeclaration(node);
        }
        function isGlobalScopeAugmentation(module2) {
            return !!(module2.flags & 2048 /* GlobalAugmentation */);
        }
        function isExternalModuleAugmentation(node) {
            return isAmbientModule(node) && isModuleAugmentationExternal(node);
        }
        function isModuleAugmentationExternal(node) {
            switch (node.parent.kind) {
                case 312 /* SourceFile */:
                    return isExternalModule(node.parent);
                case 268 /* ModuleBlock */:
                    return isAmbientModule(node.parent.parent) && isSourceFile(node.parent.parent.parent) && !isExternalModule(node.parent.parent.parent);
            }
            return false;
        }
        function getNonAugmentationDeclaration(symbol) {
            var _a;
            return (_a = symbol.declarations) == null ? void 0 : _a.find((d) => !isExternalModuleAugmentation(d) && !(isModuleDeclaration(d) && isGlobalScopeAugmentation(d)));
        }
        function isCommonJSContainingModuleKind(kind) {
            return kind === 1 /* CommonJS */ || kind === 100 /* Node16 */ || kind === 199 /* NodeNext */;
        }
        function isEffectiveExternalModule(node, compilerOptions) {
            return isExternalModule(node) || isCommonJSContainingModuleKind(getEmitModuleKind(compilerOptions)) && !!node.commonJsModuleIndicator;
        }
        function isEffectiveStrictModeSourceFile(node, compilerOptions) {
            switch (node.scriptKind) {
                case 1 /* JS */:
                case 3 /* TS */:
                case 2 /* JSX */:
                case 4 /* TSX */:
                    break;
                default:
                    return false;
            }
            if (node.isDeclarationFile) {
                return false;
            }
            if (getStrictOptionValue(compilerOptions, "alwaysStrict")) {
                return true;
            }
            if (startsWithUseStrict(node.statements)) {
                return true;
            }
            if (isExternalModule(node) || getIsolatedModules(compilerOptions)) {
                if (getEmitModuleKind(compilerOptions) >= 5 /* ES2015 */) {
                    return true;
                }
                return !compilerOptions.noImplicitUseStrict;
            }
            return false;
        }
        function isAmbientPropertyDeclaration(node) {
            return !!(node.flags & 33554432 /* Ambient */) || hasSyntacticModifier(node, 128 /* Ambient */);
        }
        function isBlockScope(node, parentNode) {
            switch (node.kind) {
                case 312 /* SourceFile */:
                case 269 /* CaseBlock */:
                case 299 /* CatchClause */:
                case 267 /* ModuleDeclaration */:
                case 248 /* ForStatement */:
                case 249 /* ForInStatement */:
                case 250 /* ForOfStatement */:
                case 176 /* Constructor */:
                case 174 /* MethodDeclaration */:
                case 177 /* GetAccessor */:
                case 178 /* SetAccessor */:
                case 262 /* FunctionDeclaration */:
                case 218 /* FunctionExpression */:
                case 219 /* ArrowFunction */:
                case 172 /* PropertyDeclaration */:
                case 175 /* ClassStaticBlockDeclaration */:
                    return true;
                case 241 /* Block */:
                    return !isFunctionLikeOrClassStaticBlockDeclaration(parentNode);
            }
            return false;
        }
        function isDeclarationWithTypeParameters(node) {
            Debug.type(node);
            switch (node.kind) {
                case 345 /* JSDocCallbackTag */:
                case 353 /* JSDocTypedefTag */:
                case 330 /* JSDocSignature */:
                    return true;
                default:
                    assertType(node);
                    return isDeclarationWithTypeParameterChildren(node);
            }
        }
        function isDeclarationWithTypeParameterChildren(node) {
            Debug.type(node);
            switch (node.kind) {
                case 179 /* CallSignature */:
                case 180 /* ConstructSignature */:
                case 173 /* MethodSignature */:
                case 181 /* IndexSignature */:
                case 184 /* FunctionType */:
                case 185 /* ConstructorType */:
                case 324 /* JSDocFunctionType */:
                case 263 /* ClassDeclaration */:
                case 231 /* ClassExpression */:
                case 264 /* InterfaceDeclaration */:
                case 265 /* TypeAliasDeclaration */:
                case 352 /* JSDocTemplateTag */:
                case 262 /* FunctionDeclaration */:
                case 174 /* MethodDeclaration */:
                case 176 /* Constructor */:
                case 177 /* GetAccessor */:
                case 178 /* SetAccessor */:
                case 218 /* FunctionExpression */:
                case 219 /* ArrowFunction */:
                    return true;
                default:
                    assertType(node);
                    return false;
            }
        }
        function isAnyImportSyntax(node) {
            switch (node.kind) {
                case 272 /* ImportDeclaration */:
                case 271 /* ImportEqualsDeclaration */:
                    return true;
                default:
                    return false;
            }
        }
        function isAnyImportOrBareOrAccessedRequire(node) {
            return isAnyImportSyntax(node) || isVariableDeclarationInitializedToBareOrAccessedRequire(node);
        }
        function isLateVisibilityPaintedStatement(node) {
            switch (node.kind) {
                case 272 /* ImportDeclaration */:
                case 271 /* ImportEqualsDeclaration */:
                case 243 /* VariableStatement */:
                case 263 /* ClassDeclaration */:
                case 262 /* FunctionDeclaration */:
                case 267 /* ModuleDeclaration */:
                case 265 /* TypeAliasDeclaration */:
                case 264 /* InterfaceDeclaration */:
                case 266 /* EnumDeclaration */:
                    return true;
                default:
                    return false;
            }
        }
        function hasPossibleExternalModuleReference(node) {
            return isAnyImportOrReExport(node) || isModuleDeclaration(node) || isImportTypeNode(node) || isImportCall(node);
        }
        function isAnyImportOrReExport(node) {
            return isAnyImportSyntax(node) || isExportDeclaration(node);
        }
        function getEnclosingContainer(node) {
            return findAncestor(node.parent, (n) => !!(getContainerFlags(n) & 1 /* IsContainer */));
        }
        function getEnclosingBlockScopeContainer(node) {
            return findAncestor(node.parent, (current) => isBlockScope(current, current.parent));
        }
        function forEachEnclosingBlockScopeContainer(node, cb) {
            let container = getEnclosingBlockScopeContainer(node);
            while (container) {
                cb(container);
                container = getEnclosingBlockScopeContainer(container);
            }
        }
        function declarationNameToString(name) {
            return !name || getFullWidth(name) === 0 ? "(Missing)" : getTextOfNode(name);
        }
        function getNameFromIndexInfo(info) {
            return info.declaration ? declarationNameToString(info.declaration.parameters[0].name) : void 0;
        }
        function isComputedNonLiteralName(name) {
            return name.kind === 167 /* ComputedPropertyName */ && !isStringOrNumericLiteralLike(name.expression);
        }
        function tryGetTextOfPropertyName(name) {
            var _a;
            switch (name.kind) {
                case 80 /* Identifier */:
                case 81 /* PrivateIdentifier */:
                    return ((_a = name.emitNode) == null ? void 0 : _a.autoGenerate) ? void 0 : name.escapedText;
                case 11 /* StringLiteral */:
                case 9 /* NumericLiteral */:
                case 15 /* NoSubstitutionTemplateLiteral */:
                    return escapeLeadingUnderscores(name.text);
                case 167 /* ComputedPropertyName */:
                    if (isStringOrNumericLiteralLike(name.expression))
                        return escapeLeadingUnderscores(name.expression.text);
                    return void 0;
                case 295 /* JsxNamespacedName */:
                    return getEscapedTextOfJsxNamespacedName(name);
                default:
                    return Debug.assertNever(name);
            }
        }
        function getTextOfPropertyName(name) {
            return Debug.checkDefined(tryGetTextOfPropertyName(name));
        }
        function entityNameToString(name) {
            switch (name.kind) {
                case 110 /* ThisKeyword */:
                    return "this";
                case 81 /* PrivateIdentifier */:
                case 80 /* Identifier */:
                    return getFullWidth(name) === 0 ? idText(name) : getTextOfNode(name);
                case 166 /* QualifiedName */:
                    return entityNameToString(name.left) + "." + entityNameToString(name.right);
                case 211 /* PropertyAccessExpression */:
                    if (isIdentifier(name.name) || isPrivateIdentifier(name.name)) {
                        return entityNameToString(name.expression) + "." + entityNameToString(name.name);
                    }
                    else {
                        return Debug.assertNever(name.name);
                    }
                case 318 /* JSDocMemberName */:
                    return entityNameToString(name.left) + entityNameToString(name.right);
                case 295 /* JsxNamespacedName */:
                    return entityNameToString(name.namespace) + ":" + entityNameToString(name.name);
                default:
                    return Debug.assertNever(name);
            }
        }
        function createDiagnosticForNode(node, message, ...args) {
            const sourceFile = getSourceFileOfNode(node);
            return createDiagnosticForNodeInSourceFile(sourceFile, node, message, ...args);
        }
        function createDiagnosticForNodeArray(sourceFile, nodes, message, ...args) {
            const start = skipTrivia(sourceFile.text, nodes.pos);
            return createFileDiagnostic(sourceFile, start, nodes.end - start, message, ...args);
        }
        function createDiagnosticForNodeInSourceFile(sourceFile, node, message, ...args) {
            const span = getErrorSpanForNode(sourceFile, node);
            return createFileDiagnostic(sourceFile, span.start, span.length, message, ...args);
        }
        function createDiagnosticForNodeFromMessageChain(sourceFile, node, messageChain, relatedInformation) {
            const span = getErrorSpanForNode(sourceFile, node);
            return createFileDiagnosticFromMessageChain(sourceFile, span.start, span.length, messageChain, relatedInformation);
        }
        function createDiagnosticForNodeArrayFromMessageChain(sourceFile, nodes, messageChain, relatedInformation) {
            const start = skipTrivia(sourceFile.text, nodes.pos);
            return createFileDiagnosticFromMessageChain(sourceFile, start, nodes.end - start, messageChain, relatedInformation);
        }
        function assertDiagnosticLocation(sourceText, start, length2) {
            Debug.assertGreaterThanOrEqual(start, 0);
            Debug.assertGreaterThanOrEqual(length2, 0);
            Debug.assertLessThanOrEqual(start, sourceText.length);
            Debug.assertLessThanOrEqual(start + length2, sourceText.length);
        }
        function createFileDiagnosticFromMessageChain(file, start, length2, messageChain, relatedInformation) {
            assertDiagnosticLocation(file.text, start, length2);
            return {
                file,
                start,
                length: length2,
                code: messageChain.code,
                category: messageChain.category,
                messageText: messageChain.next ? messageChain : messageChain.messageText,
                relatedInformation
            };
        }
        function createDiagnosticForFileFromMessageChain(sourceFile, messageChain, relatedInformation) {
            return {
                file: sourceFile,
                start: 0,
                length: 0,
                code: messageChain.code,
                category: messageChain.category,
                messageText: messageChain.next ? messageChain : messageChain.messageText,
                relatedInformation
            };
        }
        function createDiagnosticMessageChainFromDiagnostic(diagnostic) {
            return typeof diagnostic.messageText === "string" ? {
                code: diagnostic.code,
                category: diagnostic.category,
                messageText: diagnostic.messageText,
                next: diagnostic.next
            } : diagnostic.messageText;
        }
        function createDiagnosticForRange(sourceFile, range, message) {
            return {
                file: sourceFile,
                start: range.pos,
                length: range.end - range.pos,
                code: message.code,
                category: message.category,
                messageText: message.message
            };
        }
        function getSpanOfTokenAtPosition(sourceFile, pos) {
            const scanner2 = createScanner(sourceFile.languageVersion, 
            /*skipTrivia*/
            true, sourceFile.languageVariant, sourceFile.text, 
            /*onError*/
            void 0, pos);
            scanner2.scan();
            const start = scanner2.getTokenStart();
            return createTextSpanFromBounds(start, scanner2.getTokenEnd());
        }
        function scanTokenAtPosition(sourceFile, pos) {
            const scanner2 = createScanner(sourceFile.languageVersion, 
            /*skipTrivia*/
            true, sourceFile.languageVariant, sourceFile.text, 
            /*onError*/
            void 0, pos);
            scanner2.scan();
            return scanner2.getToken();
        }
        function getErrorSpanForArrowFunction(sourceFile, node) {
            const pos = skipTrivia(sourceFile.text, node.pos);
            if (node.body && node.body.kind === 241 /* Block */) {
                const { line: startLine } = getLineAndCharacterOfPosition(sourceFile, node.body.pos);
                const { line: endLine } = getLineAndCharacterOfPosition(sourceFile, node.body.end);
                if (startLine < endLine) {
                    return createTextSpan(pos, getEndLinePosition(startLine, sourceFile) - pos + 1);
                }
            }
            return createTextSpanFromBounds(pos, node.end);
        }
        function getErrorSpanForNode(sourceFile, node) {
            let errorNode = node;
            switch (node.kind) {
                case 312 /* SourceFile */: {
                    const pos2 = skipTrivia(sourceFile.text, 0, 
                    /*stopAfterLineBreak*/
                    false);
                    if (pos2 === sourceFile.text.length) {
                        return createTextSpan(0, 0);
                    }
                    return getSpanOfTokenAtPosition(sourceFile, pos2);
                }
                case 260 /* VariableDeclaration */:
                case 208 /* BindingElement */:
                case 263 /* ClassDeclaration */:
                case 231 /* ClassExpression */:
                case 264 /* InterfaceDeclaration */:
                case 267 /* ModuleDeclaration */:
                case 266 /* EnumDeclaration */:
                case 306 /* EnumMember */:
                case 262 /* FunctionDeclaration */:
                case 218 /* FunctionExpression */:
                case 174 /* MethodDeclaration */:
                case 177 /* GetAccessor */:
                case 178 /* SetAccessor */:
                case 265 /* TypeAliasDeclaration */:
                case 172 /* PropertyDeclaration */:
                case 171 /* PropertySignature */:
                case 274 /* NamespaceImport */:
                    errorNode = node.name;
                    break;
                case 219 /* ArrowFunction */:
                    return getErrorSpanForArrowFunction(sourceFile, node);
                case 296 /* CaseClause */:
                case 297 /* DefaultClause */: {
                    const start = skipTrivia(sourceFile.text, node.pos);
                    const end = node.statements.length > 0 ? node.statements[0].pos : node.end;
                    return createTextSpanFromBounds(start, end);
                }
                case 253 /* ReturnStatement */:
                case 229 /* YieldExpression */: {
                    const pos2 = skipTrivia(sourceFile.text, node.pos);
                    return getSpanOfTokenAtPosition(sourceFile, pos2);
                }
                case 238 /* SatisfiesExpression */: {
                    const pos2 = skipTrivia(sourceFile.text, node.expression.end);
                    return getSpanOfTokenAtPosition(sourceFile, pos2);
                }
                case 357 /* JSDocSatisfiesTag */: {
                    const pos2 = skipTrivia(sourceFile.text, node.tagName.pos);
                    return getSpanOfTokenAtPosition(sourceFile, pos2);
                }
            }
            if (errorNode === void 0) {
                return getSpanOfTokenAtPosition(sourceFile, node.pos);
            }
            Debug.assert(!isJSDoc(errorNode));
            const isMissing = nodeIsMissing(errorNode);
            const pos = isMissing || isJsxText(node) ? errorNode.pos : skipTrivia(sourceFile.text, errorNode.pos);
            if (isMissing) {
                Debug.assert(pos === errorNode.pos, "This failure could trigger https://github.com/Microsoft/TypeScript/issues/20809");
                Debug.assert(pos === errorNode.end, "This failure could trigger https://github.com/Microsoft/TypeScript/issues/20809");
            }
            else {
                Debug.assert(pos >= errorNode.pos, "This failure could trigger https://github.com/Microsoft/TypeScript/issues/20809");
                Debug.assert(pos <= errorNode.end, "This failure could trigger https://github.com/Microsoft/TypeScript/issues/20809");
            }
            return createTextSpanFromBounds(pos, errorNode.end);
        }
        function isExternalOrCommonJsModule(file) {
            return (file.externalModuleIndicator || file.commonJsModuleIndicator) !== void 0;
        }
        function isJsonSourceFile(file) {
            return file.scriptKind === 6 /* JSON */;
        }
        function isEnumConst(node) {
            return !!(getCombinedModifierFlags(node) & 4096 /* Const */);
        }
        function isDeclarationReadonly(declaration) {
            return !!(getCombinedModifierFlags(declaration) & 8 /* Readonly */ && !isParameterPropertyDeclaration(declaration, declaration.parent));
        }
        function isVarAwaitUsing(node) {
            return (getCombinedNodeFlags(node) & 7 /* BlockScoped */) === 6 /* AwaitUsing */;
        }
        function isVarUsing(node) {
            return (getCombinedNodeFlags(node) & 7 /* BlockScoped */) === 4 /* Using */;
        }
        function isVarConst(node) {
            return (getCombinedNodeFlags(node) & 7 /* BlockScoped */) === 2 /* Const */;
        }
        function isLet(node) {
            return (getCombinedNodeFlags(node) & 7 /* BlockScoped */) === 1 /* Let */;
        }
        function isSuperCall(n) {
            return n.kind === 213 /* CallExpression */ && n.expression.kind === 108 /* SuperKeyword */;
        }
        function isImportCall(n) {
            return n.kind === 213 /* CallExpression */ && n.expression.kind === 102 /* ImportKeyword */;
        }
        function isImportMeta(n) {
            return isMetaProperty(n) && n.keywordToken === 102 /* ImportKeyword */ && n.name.escapedText === "meta";
        }
        function isLiteralImportTypeNode(n) {
            return isImportTypeNode(n) && isLiteralTypeNode(n.argument) && isStringLiteral(n.argument.literal);
        }
        function isPrologueDirective(node) {
            return node.kind === 244 /* ExpressionStatement */ && node.expression.kind === 11 /* StringLiteral */;
        }
        function isCustomPrologue(node) {
            return !!(getEmitFlags(node) & 2097152 /* CustomPrologue */);
        }
        function isHoistedFunction(node) {
            return isCustomPrologue(node) && isFunctionDeclaration(node);
        }
        function isHoistedVariable(node) {
            return isIdentifier(node.name) && !node.initializer;
        }
        function isHoistedVariableStatement(node) {
            return isCustomPrologue(node) && isVariableStatement(node) && every(node.declarationList.declarations, isHoistedVariable);
        }
        function getLeadingCommentRangesOfNode(node, sourceFileOfNode) {
            return node.kind !== 12 /* JsxText */ ? getLeadingCommentRanges(sourceFileOfNode.text, node.pos) : void 0;
        }
        function getJSDocCommentRanges(node, text) {
            const commentRanges = node.kind === 169 /* Parameter */ || node.kind === 168 /* TypeParameter */ || node.kind === 218 /* FunctionExpression */ || node.kind === 219 /* ArrowFunction */ || node.kind === 217 /* ParenthesizedExpression */ || node.kind === 260 /* VariableDeclaration */ || node.kind === 281 /* ExportSpecifier */ ? concatenate(getTrailingCommentRanges(text, node.pos), getLeadingCommentRanges(text, node.pos)) : getLeadingCommentRanges(text, node.pos);
            return filter(commentRanges, (comment) => text.charCodeAt(comment.pos + 1) === 42 /* asterisk */ && text.charCodeAt(comment.pos + 2) === 42 /* asterisk */ && text.charCodeAt(comment.pos + 3) !== 47 /* slash */);
        }
        function isPartOfTypeNode(node) {
            if (182 /* FirstTypeNode */ <= node.kind && node.kind <= 205 /* LastTypeNode */) {
                return true;
            }
            switch (node.kind) {
                case 133 /* AnyKeyword */:
                case 159 /* UnknownKeyword */:
                case 150 /* NumberKeyword */:
                case 163 /* BigIntKeyword */:
                case 154 /* StringKeyword */:
                case 136 /* BooleanKeyword */:
                case 155 /* SymbolKeyword */:
                case 151 /* ObjectKeyword */:
                case 157 /* UndefinedKeyword */:
                case 106 /* NullKeyword */:
                case 146 /* NeverKeyword */:
                    return true;
                case 116 /* VoidKeyword */:
                    return node.parent.kind !== 222 /* VoidExpression */;
                case 233 /* ExpressionWithTypeArguments */:
                    return isPartOfTypeExpressionWithTypeArguments(node);
                case 168 /* TypeParameter */:
                    return node.parent.kind === 200 /* MappedType */ || node.parent.kind === 195 /* InferType */;
                case 80 /* Identifier */:
                    if (node.parent.kind === 166 /* QualifiedName */ && node.parent.right === node) {
                        node = node.parent;
                    }
                    else if (node.parent.kind === 211 /* PropertyAccessExpression */ && node.parent.name === node) {
                        node = node.parent;
                    }
                    Debug.assert(node.kind === 80 /* Identifier */ || node.kind === 166 /* QualifiedName */ || node.kind === 211 /* PropertyAccessExpression */, "'node' was expected to be a qualified name, identifier or property access in 'isPartOfTypeNode'.");
                case 166 /* QualifiedName */:
                case 211 /* PropertyAccessExpression */:
                case 110 /* ThisKeyword */: {
                    const { parent: parent2 } = node;
                    if (parent2.kind === 186 /* TypeQuery */) {
                        return false;
                    }
                    if (parent2.kind === 205 /* ImportType */) {
                        return !parent2.isTypeOf;
                    }
                    if (182 /* FirstTypeNode */ <= parent2.kind && parent2.kind <= 205 /* LastTypeNode */) {
                        return true;
                    }
                    switch (parent2.kind) {
                        case 233 /* ExpressionWithTypeArguments */:
                            return isPartOfTypeExpressionWithTypeArguments(parent2);
                        case 168 /* TypeParameter */:
                            return node === parent2.constraint;
                        case 352 /* JSDocTemplateTag */:
                            return node === parent2.constraint;
                        case 172 /* PropertyDeclaration */:
                        case 171 /* PropertySignature */:
                        case 169 /* Parameter */:
                        case 260 /* VariableDeclaration */:
                            return node === parent2.type;
                        case 262 /* FunctionDeclaration */:
                        case 218 /* FunctionExpression */:
                        case 219 /* ArrowFunction */:
                        case 176 /* Constructor */:
                        case 174 /* MethodDeclaration */:
                        case 173 /* MethodSignature */:
                        case 177 /* GetAccessor */:
                        case 178 /* SetAccessor */:
                            return node === parent2.type;
                        case 179 /* CallSignature */:
                        case 180 /* ConstructSignature */:
                        case 181 /* IndexSignature */:
                            return node === parent2.type;
                        case 216 /* TypeAssertionExpression */:
                            return node === parent2.type;
                        case 213 /* CallExpression */:
                        case 214 /* NewExpression */:
                        case 215 /* TaggedTemplateExpression */:
                            return contains(parent2.typeArguments, node);
                    }
                }
            }
            return false;
        }
        function isPartOfTypeExpressionWithTypeArguments(node) {
            return isJSDocImplementsTag(node.parent) || isJSDocAugmentsTag(node.parent) || isHeritageClause(node.parent) && !isExpressionWithTypeArgumentsInClassExtendsClause(node);
        }
        function isChildOfNodeWithKind(node, kind) {
            while (node) {
                if (node.kind === kind) {
                    return true;
                }
                node = node.parent;
            }
            return false;
        }
        function forEachReturnStatement(body, visitor) {
            return traverse(body);
            function traverse(node) {
                switch (node.kind) {
                    case 253 /* ReturnStatement */:
                        return visitor(node);
                    case 269 /* CaseBlock */:
                    case 241 /* Block */:
                    case 245 /* IfStatement */:
                    case 246 /* DoStatement */:
                    case 247 /* WhileStatement */:
                    case 248 /* ForStatement */:
                    case 249 /* ForInStatement */:
                    case 250 /* ForOfStatement */:
                    case 254 /* WithStatement */:
                    case 255 /* SwitchStatement */:
                    case 296 /* CaseClause */:
                    case 297 /* DefaultClause */:
                    case 256 /* LabeledStatement */:
                    case 258 /* TryStatement */:
                    case 299 /* CatchClause */:
                        return forEachChild(node, traverse);
                }
            }
        }
        function forEachYieldExpression(body, visitor) {
            return traverse(body);
            function traverse(node) {
                switch (node.kind) {
                    case 229 /* YieldExpression */:
                        visitor(node);
                        const operand = node.expression;
                        if (operand) {
                            traverse(operand);
                        }
                        return;
                    case 266 /* EnumDeclaration */:
                    case 264 /* InterfaceDeclaration */:
                    case 267 /* ModuleDeclaration */:
                    case 265 /* TypeAliasDeclaration */:
                        return;
                    default:
                        if (isFunctionLike(node)) {
                            if (node.name && node.name.kind === 167 /* ComputedPropertyName */) {
                                traverse(node.name.expression);
                                return;
                            }
                        }
                        else if (!isPartOfTypeNode(node)) {
                            forEachChild(node, traverse);
                        }
                }
            }
        }
        function getRestParameterElementType(node) {
            if (node && node.kind === 188 /* ArrayType */) {
                return node.elementType;
            }
            else if (node && node.kind === 183 /* TypeReference */) {
                return singleOrUndefined(node.typeArguments);
            }
            else {
                return void 0;
            }
        }
        function getMembersOfDeclaration(node) {
            switch (node.kind) {
                case 264 /* InterfaceDeclaration */:
                case 263 /* ClassDeclaration */:
                case 231 /* ClassExpression */:
                case 187 /* TypeLiteral */:
                    return node.members;
                case 210 /* ObjectLiteralExpression */:
                    return node.properties;
            }
        }
        function isVariableLike(node) {
            if (node) {
                switch (node.kind) {
                    case 208 /* BindingElement */:
                    case 306 /* EnumMember */:
                    case 169 /* Parameter */:
                    case 303 /* PropertyAssignment */:
                    case 172 /* PropertyDeclaration */:
                    case 171 /* PropertySignature */:
                    case 304 /* ShorthandPropertyAssignment */:
                    case 260 /* VariableDeclaration */:
                        return true;
                }
            }
            return false;
        }
        function isVariableLikeOrAccessor(node) {
            return isVariableLike(node) || isAccessor(node);
        }
        function isVariableDeclarationInVariableStatement(node) {
            return node.parent.kind === 261 /* VariableDeclarationList */ && node.parent.parent.kind === 243 /* VariableStatement */;
        }
        function isCommonJsExportedExpression(node) {
            if (!isInJSFile(node))
                return false;
            return isObjectLiteralExpression(node.parent) && isBinaryExpression(node.parent.parent) && getAssignmentDeclarationKind(node.parent.parent) === 2 /* ModuleExports */ || isCommonJsExportPropertyAssignment(node.parent);
        }
        function isCommonJsExportPropertyAssignment(node) {
            if (!isInJSFile(node))
                return false;
            return isBinaryExpression(node) && getAssignmentDeclarationKind(node) === 1 /* ExportsProperty */;
        }
        function isValidESSymbolDeclaration(node) {
            return (isVariableDeclaration(node) ? isVarConst(node) && isIdentifier(node.name) && isVariableDeclarationInVariableStatement(node) : isPropertyDeclaration(node) ? hasEffectiveReadonlyModifier(node) && hasStaticModifier(node) : isPropertySignature(node) && hasEffectiveReadonlyModifier(node)) || isCommonJsExportPropertyAssignment(node);
        }
        function introducesArgumentsExoticObject(node) {
            switch (node.kind) {
                case 174 /* MethodDeclaration */:
                case 173 /* MethodSignature */:
                case 176 /* Constructor */:
                case 177 /* GetAccessor */:
                case 178 /* SetAccessor */:
                case 262 /* FunctionDeclaration */:
                case 218 /* FunctionExpression */:
                    return true;
            }
            return false;
        }
        function unwrapInnermostStatementOfLabel(node, beforeUnwrapLabelCallback) {
            while (true) {
                if (beforeUnwrapLabelCallback) {
                    beforeUnwrapLabelCallback(node);
                }
                if (node.statement.kind !== 256 /* LabeledStatement */) {
                    return node.statement;
                }
                node = node.statement;
            }
        }
        function isFunctionBlock(node) {
            return node && node.kind === 241 /* Block */ && isFunctionLike(node.parent);
        }
        function isObjectLiteralMethod(node) {
            return node && node.kind === 174 /* MethodDeclaration */ && node.parent.kind === 210 /* ObjectLiteralExpression */;
        }
        function isObjectLiteralOrClassExpressionMethodOrAccessor(node) {
            return (node.kind === 174 /* MethodDeclaration */ || node.kind === 177 /* GetAccessor */ || node.kind === 178 /* SetAccessor */) && (node.parent.kind === 210 /* ObjectLiteralExpression */ || node.parent.kind === 231 /* ClassExpression */);
        }
        function isIdentifierTypePredicate(predicate) {
            return predicate && predicate.kind === 1 /* Identifier */;
        }
        function isThisTypePredicate(predicate) {
            return predicate && predicate.kind === 0 /* This */;
        }
        function forEachPropertyAssignment(objectLiteral, key, callback, key2) {
            return forEach(objectLiteral == null ? void 0 : objectLiteral.properties, (property) => {
                if (!isPropertyAssignment(property))
                    return void 0;
                const propName = tryGetTextOfPropertyName(property.name);
                return key === propName || key2 && key2 === propName ? callback(property) : void 0;
            });
        }
        function getPropertyArrayElementValue(objectLiteral, propKey, elementValue) {
            return forEachPropertyAssignment(objectLiteral, propKey, (property) => isArrayLiteralExpression(property.initializer) ? find(property.initializer.elements, (element) => isStringLiteral(element) && element.text === elementValue) : void 0);
        }
        function getTsConfigObjectLiteralExpression(tsConfigSourceFile) {
            if (tsConfigSourceFile && tsConfigSourceFile.statements.length) {
                const expression = tsConfigSourceFile.statements[0].expression;
                return tryCast(expression, isObjectLiteralExpression);
            }
        }
        function getTsConfigPropArrayElementValue(tsConfigSourceFile, propKey, elementValue) {
            return forEachTsConfigPropArray(tsConfigSourceFile, propKey, (property) => isArrayLiteralExpression(property.initializer) ? find(property.initializer.elements, (element) => isStringLiteral(element) && element.text === elementValue) : void 0);
        }
        function forEachTsConfigPropArray(tsConfigSourceFile, propKey, callback) {
            return forEachPropertyAssignment(getTsConfigObjectLiteralExpression(tsConfigSourceFile), propKey, callback);
        }
        function getContainingFunction(node) {
            return findAncestor(node.parent, isFunctionLike);
        }
        function getContainingFunctionDeclaration(node) {
            return findAncestor(node.parent, isFunctionLikeDeclaration);
        }
        function getContainingClass(node) {
            return findAncestor(node.parent, isClassLike);
        }
        function getContainingClassStaticBlock(node) {
            return findAncestor(node.parent, (n) => {
                if (isClassLike(n) || isFunctionLike(n)) {
                    return "quit";
                }
                return isClassStaticBlockDeclaration(n);
            });
        }
        function getContainingFunctionOrClassStaticBlock(node) {
            return findAncestor(node.parent, isFunctionLikeOrClassStaticBlockDeclaration);
        }
        function getContainingClassExcludingClassDecorators(node) {
            const decorator = findAncestor(node.parent, (n) => isClassLike(n) ? "quit" : isDecorator(n));
            return decorator && isClassLike(decorator.parent) ? getContainingClass(decorator.parent) : getContainingClass(decorator ?? node);
        }
        function getThisContainer(node, includeArrowFunctions, includeClassComputedPropertyName) {
            Debug.assert(node.kind !== 312 /* SourceFile */);
            while (true) {
                node = node.parent;
                if (!node) {
                    return Debug.fail();
                }
                switch (node.kind) {
                    case 167 /* ComputedPropertyName */:
                        if (includeClassComputedPropertyName && isClassLike(node.parent.parent)) {
                            return node;
                        }
                        node = node.parent.parent;
                        break;
                    case 170 /* Decorator */:
                        if (node.parent.kind === 169 /* Parameter */ && isClassElement(node.parent.parent)) {
                            node = node.parent.parent;
                        }
                        else if (isClassElement(node.parent)) {
                            node = node.parent;
                        }
                        break;
                    case 219 /* ArrowFunction */:
                        if (!includeArrowFunctions) {
                            continue;
                        }
                    case 262 /* FunctionDeclaration */:
                    case 218 /* FunctionExpression */:
                    case 267 /* ModuleDeclaration */:
                    case 175 /* ClassStaticBlockDeclaration */:
                    case 172 /* PropertyDeclaration */:
                    case 171 /* PropertySignature */:
                    case 174 /* MethodDeclaration */:
                    case 173 /* MethodSignature */:
                    case 176 /* Constructor */:
                    case 177 /* GetAccessor */:
                    case 178 /* SetAccessor */:
                    case 179 /* CallSignature */:
                    case 180 /* ConstructSignature */:
                    case 181 /* IndexSignature */:
                    case 266 /* EnumDeclaration */:
                    case 312 /* SourceFile */:
                        return node;
                }
            }
        }
        function isThisContainerOrFunctionBlock(node) {
            switch (node.kind) {
                case 219 /* ArrowFunction */:
                case 262 /* FunctionDeclaration */:
                case 218 /* FunctionExpression */:
                case 172 /* PropertyDeclaration */:
                    return true;
                case 241 /* Block */:
                    switch (node.parent.kind) {
                        case 176 /* Constructor */:
                        case 174 /* MethodDeclaration */:
                        case 177 /* GetAccessor */:
                        case 178 /* SetAccessor */:
                            return true;
                        default:
                            return false;
                    }
                default:
                    return false;
            }
        }
        function isInTopLevelContext(node) {
            if (isIdentifier(node) && (isClassDeclaration(node.parent) || isFunctionDeclaration(node.parent)) && node.parent.name === node) {
                node = node.parent;
            }
            const container = getThisContainer(node, 
            /*includeArrowFunctions*/
            true, 
            /*includeClassComputedPropertyName*/
            false);
            return isSourceFile(container);
        }
        function getNewTargetContainer(node) {
            const container = getThisContainer(node, 
            /*includeArrowFunctions*/
            false, 
            /*includeClassComputedPropertyName*/
            false);
            if (container) {
                switch (container.kind) {
                    case 176 /* Constructor */:
                    case 262 /* FunctionDeclaration */:
                    case 218 /* FunctionExpression */:
                        return container;
                }
            }
            return void 0;
        }
        function getSuperContainer(node, stopOnFunctions) {
            while (true) {
                node = node.parent;
                if (!node) {
                    return void 0;
                }
                switch (node.kind) {
                    case 167 /* ComputedPropertyName */:
                        node = node.parent;
                        break;
                    case 262 /* FunctionDeclaration */:
                    case 218 /* FunctionExpression */:
                    case 219 /* ArrowFunction */:
                        if (!stopOnFunctions) {
                            continue;
                        }
                    case 172 /* PropertyDeclaration */:
                    case 171 /* PropertySignature */:
                    case 174 /* MethodDeclaration */:
                    case 173 /* MethodSignature */:
                    case 176 /* Constructor */:
                    case 177 /* GetAccessor */:
                    case 178 /* SetAccessor */:
                    case 175 /* ClassStaticBlockDeclaration */:
                        return node;
                    case 170 /* Decorator */:
                        if (node.parent.kind === 169 /* Parameter */ && isClassElement(node.parent.parent)) {
                            node = node.parent.parent;
                        }
                        else if (isClassElement(node.parent)) {
                            node = node.parent;
                        }
                        break;
                }
            }
        }
        function getImmediatelyInvokedFunctionExpression(func) {
            if (func.kind === 218 /* FunctionExpression */ || func.kind === 219 /* ArrowFunction */) {
                let prev = func;
                let parent2 = func.parent;
                while (parent2.kind === 217 /* ParenthesizedExpression */) {
                    prev = parent2;
                    parent2 = parent2.parent;
                }
                if (parent2.kind === 213 /* CallExpression */ && parent2.expression === prev) {
                    return parent2;
                }
            }
        }
        function isSuperOrSuperProperty(node) {
            return node.kind === 108 /* SuperKeyword */ || isSuperProperty(node);
        }
        function isSuperProperty(node) {
            const kind = node.kind;
            return (kind === 211 /* PropertyAccessExpression */ || kind === 212 /* ElementAccessExpression */) && node.expression.kind === 108 /* SuperKeyword */;
        }
        function isThisProperty(node) {
            const kind = node.kind;
            return (kind === 211 /* PropertyAccessExpression */ || kind === 212 /* ElementAccessExpression */) && node.expression.kind === 110 /* ThisKeyword */;
        }
        function isThisInitializedDeclaration(node) {
            var _a;
            return !!node && isVariableDeclaration(node) && ((_a = node.initializer) == null ? void 0 : _a.kind) === 110 /* ThisKeyword */;
        }
        function isThisInitializedObjectBindingExpression(node) {
            return !!node && (isShorthandPropertyAssignment(node) || isPropertyAssignment(node)) && isBinaryExpression(node.parent.parent) && node.parent.parent.operatorToken.kind === 64 /* EqualsToken */ && node.parent.parent.right.kind === 110 /* ThisKeyword */;
        }
        function getEntityNameFromTypeNode(node) {
            switch (node.kind) {
                case 183 /* TypeReference */:
                    return node.typeName;
                case 233 /* ExpressionWithTypeArguments */:
                    return isEntityNameExpression(node.expression) ? node.expression : void 0;
                case 80 /* Identifier */:
                case 166 /* QualifiedName */:
                    return node;
            }
            return void 0;
        }
        function getInvokedExpression(node) {
            switch (node.kind) {
                case 215 /* TaggedTemplateExpression */:
                    return node.tag;
                case 286 /* JsxOpeningElement */:
                case 285 /* JsxSelfClosingElement */:
                    return node.tagName;
                case 226 /* BinaryExpression */:
                    return node.right;
                default:
                    return node.expression;
            }
        }
        function nodeCanBeDecorated(useLegacyDecorators, node, parent2, grandparent) {
            if (useLegacyDecorators && isNamedDeclaration(node) && isPrivateIdentifier(node.name)) {
                return false;
            }
            switch (node.kind) {
                case 263 /* ClassDeclaration */:
                    return true;
                case 231 /* ClassExpression */:
                    return !useLegacyDecorators;
                case 172 /* PropertyDeclaration */:
                    return parent2 !== void 0 && (useLegacyDecorators ? isClassDeclaration(parent2) : isClassLike(parent2) && !hasAbstractModifier(node) && !hasAmbientModifier(node));
                case 177 /* GetAccessor */:
                case 178 /* SetAccessor */:
                case 174 /* MethodDeclaration */:
                    return node.body !== void 0 && parent2 !== void 0 && (useLegacyDecorators ? isClassDeclaration(parent2) : isClassLike(parent2));
                case 169 /* Parameter */:
                    if (!useLegacyDecorators)
                        return false;
                    return parent2 !== void 0 && parent2.body !== void 0 && (parent2.kind === 176 /* Constructor */ || parent2.kind === 174 /* MethodDeclaration */ || parent2.kind === 178 /* SetAccessor */) && getThisParameter(parent2) !== node && grandparent !== void 0 && grandparent.kind === 263 /* ClassDeclaration */;
            }
            return false;
        }
        function nodeIsDecorated(useLegacyDecorators, node, parent2, grandparent) {
            return hasDecorators(node) && nodeCanBeDecorated(useLegacyDecorators, node, parent2, grandparent);
        }
        function nodeOrChildIsDecorated(useLegacyDecorators, node, parent2, grandparent) {
            return nodeIsDecorated(useLegacyDecorators, node, parent2, grandparent) || childIsDecorated(useLegacyDecorators, node, parent2);
        }
        function childIsDecorated(useLegacyDecorators, node, parent2) {
            switch (node.kind) {
                case 263 /* ClassDeclaration */:
                    return some(node.members, (m) => nodeOrChildIsDecorated(useLegacyDecorators, m, node, parent2));
                case 231 /* ClassExpression */:
                    return !useLegacyDecorators && some(node.members, (m) => nodeOrChildIsDecorated(useLegacyDecorators, m, node, parent2));
                case 174 /* MethodDeclaration */:
                case 178 /* SetAccessor */:
                case 176 /* Constructor */:
                    return some(node.parameters, (p) => nodeIsDecorated(useLegacyDecorators, p, node, parent2));
                default:
                    return false;
            }
        }
        function classOrConstructorParameterIsDecorated(useLegacyDecorators, node) {
            if (nodeIsDecorated(useLegacyDecorators, node))
                return true;
            const constructor = getFirstConstructorWithBody(node);
            return !!constructor && childIsDecorated(useLegacyDecorators, constructor, node);
        }
        function classElementOrClassElementParameterIsDecorated(useLegacyDecorators, node, parent2) {
            let parameters;
            if (isAccessor(node)) {
                const { firstAccessor, secondAccessor, setAccessor } = getAllAccessorDeclarations(parent2.members, node);
                const firstAccessorWithDecorators = hasDecorators(firstAccessor) ? firstAccessor : secondAccessor && hasDecorators(secondAccessor) ? secondAccessor : void 0;
                if (!firstAccessorWithDecorators || node !== firstAccessorWithDecorators) {
                    return false;
                }
                parameters = setAccessor == null ? void 0 : setAccessor.parameters;
            }
            else if (isMethodDeclaration(node)) {
                parameters = node.parameters;
            }
            if (nodeIsDecorated(useLegacyDecorators, node, parent2)) {
                return true;
            }
            if (parameters) {
                for (const parameter of parameters) {
                    if (parameterIsThisKeyword(parameter))
                        continue;
                    if (nodeIsDecorated(useLegacyDecorators, parameter, node, parent2))
                        return true;
                }
            }
            return false;
        }
        function isEmptyStringLiteral(node) {
            if (node.textSourceNode) {
                switch (node.textSourceNode.kind) {
                    case 11 /* StringLiteral */:
                        return isEmptyStringLiteral(node.textSourceNode);
                    case 15 /* NoSubstitutionTemplateLiteral */:
                        return node.text === "";
                }
                return false;
            }
            return node.text === "";
        }
        function isJSXTagName(node) {
            const { parent: parent2 } = node;
            if (parent2.kind === 286 /* JsxOpeningElement */ || parent2.kind === 285 /* JsxSelfClosingElement */ || parent2.kind === 287 /* JsxClosingElement */) {
                return parent2.tagName === node;
            }
            return false;
        }
        function isExpressionNode(node) {
            switch (node.kind) {
                case 108 /* SuperKeyword */:
                case 106 /* NullKeyword */:
                case 112 /* TrueKeyword */:
                case 97 /* FalseKeyword */:
                case 14 /* RegularExpressionLiteral */:
                case 209 /* ArrayLiteralExpression */:
                case 210 /* ObjectLiteralExpression */:
                case 211 /* PropertyAccessExpression */:
                case 212 /* ElementAccessExpression */:
                case 213 /* CallExpression */:
                case 214 /* NewExpression */:
                case 215 /* TaggedTemplateExpression */:
                case 234 /* AsExpression */:
                case 216 /* TypeAssertionExpression */:
                case 238 /* SatisfiesExpression */:
                case 235 /* NonNullExpression */:
                case 217 /* ParenthesizedExpression */:
                case 218 /* FunctionExpression */:
                case 231 /* ClassExpression */:
                case 219 /* ArrowFunction */:
                case 222 /* VoidExpression */:
                case 220 /* DeleteExpression */:
                case 221 /* TypeOfExpression */:
                case 224 /* PrefixUnaryExpression */:
                case 225 /* PostfixUnaryExpression */:
                case 226 /* BinaryExpression */:
                case 227 /* ConditionalExpression */:
                case 230 /* SpreadElement */:
                case 228 /* TemplateExpression */:
                case 232 /* OmittedExpression */:
                case 284 /* JsxElement */:
                case 285 /* JsxSelfClosingElement */:
                case 288 /* JsxFragment */:
                case 229 /* YieldExpression */:
                case 223 /* AwaitExpression */:
                case 236 /* MetaProperty */:
                    return true;
                case 233 /* ExpressionWithTypeArguments */:
                    return !isHeritageClause(node.parent) && !isJSDocAugmentsTag(node.parent);
                case 166 /* QualifiedName */:
                    while (node.parent.kind === 166 /* QualifiedName */) {
                        node = node.parent;
                    }
                    return node.parent.kind === 186 /* TypeQuery */ || isJSDocLinkLike(node.parent) || isJSDocNameReference(node.parent) || isJSDocMemberName(node.parent) || isJSXTagName(node);
                case 318 /* JSDocMemberName */:
                    while (isJSDocMemberName(node.parent)) {
                        node = node.parent;
                    }
                    return node.parent.kind === 186 /* TypeQuery */ || isJSDocLinkLike(node.parent) || isJSDocNameReference(node.parent) || isJSDocMemberName(node.parent) || isJSXTagName(node);
                case 81 /* PrivateIdentifier */:
                    return isBinaryExpression(node.parent) && node.parent.left === node && node.parent.operatorToken.kind === 103 /* InKeyword */;
                case 80 /* Identifier */:
                    if (node.parent.kind === 186 /* TypeQuery */ || isJSDocLinkLike(node.parent) || isJSDocNameReference(node.parent) || isJSDocMemberName(node.parent) || isJSXTagName(node)) {
                        return true;
                    }
                case 9 /* NumericLiteral */:
                case 10 /* BigIntLiteral */:
                case 11 /* StringLiteral */:
                case 15 /* NoSubstitutionTemplateLiteral */:
                case 110 /* ThisKeyword */:
                    return isInExpressionContext(node);
                default:
                    return false;
            }
        }
        function isInExpressionContext(node) {
            const { parent: parent2 } = node;
            switch (parent2.kind) {
                case 260 /* VariableDeclaration */:
                case 169 /* Parameter */:
                case 172 /* PropertyDeclaration */:
                case 171 /* PropertySignature */:
                case 306 /* EnumMember */:
                case 303 /* PropertyAssignment */:
                case 208 /* BindingElement */:
                    return parent2.initializer === node;
                case 244 /* ExpressionStatement */:
                case 245 /* IfStatement */:
                case 246 /* DoStatement */:
                case 247 /* WhileStatement */:
                case 253 /* ReturnStatement */:
                case 254 /* WithStatement */:
                case 255 /* SwitchStatement */:
                case 296 /* CaseClause */:
                case 257 /* ThrowStatement */:
                    return parent2.expression === node;
                case 248 /* ForStatement */:
                    const forStatement = parent2;
                    return forStatement.initializer === node && forStatement.initializer.kind !== 261 /* VariableDeclarationList */ || forStatement.condition === node || forStatement.incrementor === node;
                case 249 /* ForInStatement */:
                case 250 /* ForOfStatement */:
                    const forInOrOfStatement = parent2;
                    return forInOrOfStatement.initializer === node && forInOrOfStatement.initializer.kind !== 261 /* VariableDeclarationList */ || forInOrOfStatement.expression === node;
                case 216 /* TypeAssertionExpression */:
                case 234 /* AsExpression */:
                    return node === parent2.expression;
                case 239 /* TemplateSpan */:
                    return node === parent2.expression;
                case 167 /* ComputedPropertyName */:
                    return node === parent2.expression;
                case 170 /* Decorator */:
                case 294 /* JsxExpression */:
                case 293 /* JsxSpreadAttribute */:
                case 305 /* SpreadAssignment */:
                    return true;
                case 233 /* ExpressionWithTypeArguments */:
                    return parent2.expression === node && !isPartOfTypeNode(parent2);
                case 304 /* ShorthandPropertyAssignment */:
                    return parent2.objectAssignmentInitializer === node;
                case 238 /* SatisfiesExpression */:
                    return node === parent2.expression;
                default:
                    return isExpressionNode(parent2);
            }
        }
        function isPartOfTypeQuery(node) {
            while (node.kind === 166 /* QualifiedName */ || node.kind === 80 /* Identifier */) {
                node = node.parent;
            }
            return node.kind === 186 /* TypeQuery */;
        }
        function isNamespaceReexportDeclaration(node) {
            return isNamespaceExport(node) && !!node.parent.moduleSpecifier;
        }
        function isExternalModuleImportEqualsDeclaration(node) {
            return node.kind === 271 /* ImportEqualsDeclaration */ && node.moduleReference.kind === 283 /* ExternalModuleReference */;
        }
        function getExternalModuleImportEqualsDeclarationExpression(node) {
            Debug.assert(isExternalModuleImportEqualsDeclaration(node));
            return node.moduleReference.expression;
        }
        function getExternalModuleRequireArgument(node) {
            return isVariableDeclarationInitializedToBareOrAccessedRequire(node) && getLeftmostAccessExpression(node.initializer).arguments[0];
        }
        function isInternalModuleImportEqualsDeclaration(node) {
            return node.kind === 271 /* ImportEqualsDeclaration */ && node.moduleReference.kind !== 283 /* ExternalModuleReference */;
        }
        function isSourceFileJS(file) {
            return isInJSFile(file);
        }
        function isSourceFileNotJS(file) {
            return !isInJSFile(file);
        }
        function isInJSFile(node) {
            return !!node && !!(node.flags & 524288 /* JavaScriptFile */);
        }
        function isInJsonFile(node) {
            return !!node && !!(node.flags & 134217728 /* JsonFile */);
        }
        function isSourceFileNotJson(file) {
            return !isJsonSourceFile(file);
        }
        function isInJSDoc(node) {
            return !!node && !!(node.flags & 16777216 /* JSDoc */);
        }
        function isJSDocIndexSignature(node) {
            return isTypeReferenceNode(node) && isIdentifier(node.typeName) && node.typeName.escapedText === "Object" && node.typeArguments && node.typeArguments.length === 2 && (node.typeArguments[0].kind === 154 /* StringKeyword */ || node.typeArguments[0].kind === 150 /* NumberKeyword */);
        }
        function isRequireCall(callExpression, requireStringLiteralLikeArgument) {
            if (callExpression.kind !== 213 /* CallExpression */) {
                return false;
            }
            const { expression, arguments: args } = callExpression;
            if (expression.kind !== 80 /* Identifier */ || expression.escapedText !== "require") {
                return false;
            }
            if (args.length !== 1) {
                return false;
            }
            const arg = args[0];
            return !requireStringLiteralLikeArgument || isStringLiteralLike(arg);
        }
        function isVariableDeclarationInitializedToRequire(node) {
            return isVariableDeclarationInitializedWithRequireHelper(node, 
            /*allowAccessedRequire*/
            false);
        }
        function isVariableDeclarationInitializedToBareOrAccessedRequire(node) {
            return isVariableDeclarationInitializedWithRequireHelper(node, 
            /*allowAccessedRequire*/
            true);
        }
        function isBindingElementOfBareOrAccessedRequire(node) {
            return isBindingElement(node) && isVariableDeclarationInitializedToBareOrAccessedRequire(node.parent.parent);
        }
        function isVariableDeclarationInitializedWithRequireHelper(node, allowAccessedRequire) {
            return isVariableDeclaration(node) && !!node.initializer && isRequireCall(allowAccessedRequire ? getLeftmostAccessExpression(node.initializer) : node.initializer, 
            /*requireStringLiteralLikeArgument*/
            true);
        }
        function isRequireVariableStatement(node) {
            return isVariableStatement(node) && node.declarationList.declarations.length > 0 && every(node.declarationList.declarations, (decl) => isVariableDeclarationInitializedToRequire(decl));
        }
        function isSingleOrDoubleQuote(charCode) {
            return charCode === 39 /* singleQuote */ || charCode === 34 /* doubleQuote */;
        }
        function isStringDoubleQuoted(str, sourceFile) {
            return getSourceTextOfNodeFromSourceFile(sourceFile, str).charCodeAt(0) === 34 /* doubleQuote */;
        }
        function isAssignmentDeclaration(decl) {
            return isBinaryExpression(decl) || isAccessExpression(decl) || isIdentifier(decl) || isCallExpression(decl);
        }
        function getEffectiveInitializer(node) {
            if (isInJSFile(node) && node.initializer && isBinaryExpression(node.initializer) && (node.initializer.operatorToken.kind === 57 /* BarBarToken */ || node.initializer.operatorToken.kind === 61 /* QuestionQuestionToken */) && node.name && isEntityNameExpression(node.name) && isSameEntityName(node.name, node.initializer.left)) {
                return node.initializer.right;
            }
            return node.initializer;
        }
        function getDeclaredExpandoInitializer(node) {
            const init = getEffectiveInitializer(node);
            return init && getExpandoInitializer(init, isPrototypeAccess(node.name));
        }
        function hasExpandoValueProperty(node, isPrototypeAssignment) {
            return forEach(node.properties, (p) => isPropertyAssignment(p) && isIdentifier(p.name) && p.name.escapedText === "value" && p.initializer && getExpandoInitializer(p.initializer, isPrototypeAssignment));
        }
        function getAssignedExpandoInitializer(node) {
            if (node && node.parent && isBinaryExpression(node.parent) && node.parent.operatorToken.kind === 64 /* EqualsToken */) {
                const isPrototypeAssignment = isPrototypeAccess(node.parent.left);
                return getExpandoInitializer(node.parent.right, isPrototypeAssignment) || getDefaultedExpandoInitializer(node.parent.left, node.parent.right, isPrototypeAssignment);
            }
            if (node && isCallExpression(node) && isBindableObjectDefinePropertyCall(node)) {
                const result = hasExpandoValueProperty(node.arguments[2], node.arguments[1].text === "prototype");
                if (result) {
                    return result;
                }
            }
        }
        function getExpandoInitializer(initializer, isPrototypeAssignment) {
            if (isCallExpression(initializer)) {
                const e = skipParentheses(initializer.expression);
                return e.kind === 218 /* FunctionExpression */ || e.kind === 219 /* ArrowFunction */ ? initializer : void 0;
            }
            if (initializer.kind === 218 /* FunctionExpression */ || initializer.kind === 231 /* ClassExpression */ || initializer.kind === 219 /* ArrowFunction */) {
                return initializer;
            }
            if (isObjectLiteralExpression(initializer) && (initializer.properties.length === 0 || isPrototypeAssignment)) {
                return initializer;
            }
        }
        function getDefaultedExpandoInitializer(name, initializer, isPrototypeAssignment) {
            const e = isBinaryExpression(initializer) && (initializer.operatorToken.kind === 57 /* BarBarToken */ || initializer.operatorToken.kind === 61 /* QuestionQuestionToken */) && getExpandoInitializer(initializer.right, isPrototypeAssignment);
            if (e && isSameEntityName(name, initializer.left)) {
                return e;
            }
        }
        function isDefaultedExpandoInitializer(node) {
            const name = isVariableDeclaration(node.parent) ? node.parent.name : isBinaryExpression(node.parent) && node.parent.operatorToken.kind === 64 /* EqualsToken */ ? node.parent.left : void 0;
            return name && getExpandoInitializer(node.right, isPrototypeAccess(name)) && isEntityNameExpression(name) && isSameEntityName(name, node.left);
        }
        function getNameOfExpando(node) {
            if (isBinaryExpression(node.parent)) {
                const parent2 = (node.parent.operatorToken.kind === 57 /* BarBarToken */ || node.parent.operatorToken.kind === 61 /* QuestionQuestionToken */) && isBinaryExpression(node.parent.parent) ? node.parent.parent : node.parent;
                if (parent2.operatorToken.kind === 64 /* EqualsToken */ && isIdentifier(parent2.left)) {
                    return parent2.left;
                }
            }
            else if (isVariableDeclaration(node.parent)) {
                return node.parent.name;
            }
        }
        function isSameEntityName(name, initializer) {
            if (isPropertyNameLiteral(name) && isPropertyNameLiteral(initializer)) {
                return getTextOfIdentifierOrLiteral(name) === getTextOfIdentifierOrLiteral(initializer);
            }
            if (isMemberName(name) && isLiteralLikeAccess(initializer) && (initializer.expression.kind === 110 /* ThisKeyword */ || isIdentifier(initializer.expression) && (initializer.expression.escapedText === "window" || initializer.expression.escapedText === "self" || initializer.expression.escapedText === "global"))) {
                return isSameEntityName(name, getNameOrArgument(initializer));
            }
            if (isLiteralLikeAccess(name) && isLiteralLikeAccess(initializer)) {
                return getElementOrPropertyAccessName(name) === getElementOrPropertyAccessName(initializer) && isSameEntityName(name.expression, initializer.expression);
            }
            return false;
        }
        function getRightMostAssignedExpression(node) {
            while (isAssignmentExpression(node, 
            /*excludeCompoundAssignment*/
            true)) {
                node = node.right;
            }
            return node;
        }
        function isExportsIdentifier(node) {
            return isIdentifier(node) && node.escapedText === "exports";
        }
        function isModuleIdentifier(node) {
            return isIdentifier(node) && node.escapedText === "module";
        }
        function isModuleExportsAccessExpression(node) {
            return (isPropertyAccessExpression(node) || isLiteralLikeElementAccess(node)) && isModuleIdentifier(node.expression) && getElementOrPropertyAccessName(node) === "exports";
        }
        function getAssignmentDeclarationKind(expr) {
            const special = getAssignmentDeclarationKindWorker(expr);
            return special === 5 /* Property */ || isInJSFile(expr) ? special : 0 /* None */;
        }
        function isBindableObjectDefinePropertyCall(expr) {
            return length(expr.arguments) === 3 && isPropertyAccessExpression(expr.expression) && isIdentifier(expr.expression.expression) && idText(expr.expression.expression) === "Object" && idText(expr.expression.name) === "defineProperty" && isStringOrNumericLiteralLike(expr.arguments[1]) && isBindableStaticNameExpression(expr.arguments[0], 
            /*excludeThisKeyword*/
            true);
        }
        function isLiteralLikeAccess(node) {
            return isPropertyAccessExpression(node) || isLiteralLikeElementAccess(node);
        }
        function isLiteralLikeElementAccess(node) {
            return isElementAccessExpression(node) && isStringOrNumericLiteralLike(node.argumentExpression);
        }
        function isBindableStaticAccessExpression(node, excludeThisKeyword) {
            return isPropertyAccessExpression(node) && (!excludeThisKeyword && node.expression.kind === 110 /* ThisKeyword */ || isIdentifier(node.name) && isBindableStaticNameExpression(node.expression, 
            /*excludeThisKeyword*/
            true)) || isBindableStaticElementAccessExpression(node, excludeThisKeyword);
        }
        function isBindableStaticElementAccessExpression(node, excludeThisKeyword) {
            return isLiteralLikeElementAccess(node) && (!excludeThisKeyword && node.expression.kind === 110 /* ThisKeyword */ || isEntityNameExpression(node.expression) || isBindableStaticAccessExpression(node.expression, 
            /*excludeThisKeyword*/
            true));
        }
        function isBindableStaticNameExpression(node, excludeThisKeyword) {
            return isEntityNameExpression(node) || isBindableStaticAccessExpression(node, excludeThisKeyword);
        }
        function getNameOrArgument(expr) {
            if (isPropertyAccessExpression(expr)) {
                return expr.name;
            }
            return expr.argumentExpression;
        }
        function getAssignmentDeclarationKindWorker(expr) {
            if (isCallExpression(expr)) {
                if (!isBindableObjectDefinePropertyCall(expr)) {
                    return 0 /* None */;
                }
                const entityName = expr.arguments[0];
                if (isExportsIdentifier(entityName) || isModuleExportsAccessExpression(entityName)) {
                    return 8 /* ObjectDefinePropertyExports */;
                }
                if (isBindableStaticAccessExpression(entityName) && getElementOrPropertyAccessName(entityName) === "prototype") {
                    return 9 /* ObjectDefinePrototypeProperty */;
                }
                return 7 /* ObjectDefinePropertyValue */;
            }
            if (expr.operatorToken.kind !== 64 /* EqualsToken */ || !isAccessExpression(expr.left) || isVoidZero(getRightMostAssignedExpression(expr))) {
                return 0 /* None */;
            }
            if (isBindableStaticNameExpression(expr.left.expression, 
            /*excludeThisKeyword*/
            true) && getElementOrPropertyAccessName(expr.left) === "prototype" && isObjectLiteralExpression(getInitializerOfBinaryExpression(expr))) {
                return 6 /* Prototype */;
            }
            return getAssignmentDeclarationPropertyAccessKind(expr.left);
        }
        function isVoidZero(node) {
            return isVoidExpression(node) && isNumericLiteral(node.expression) && node.expression.text === "0";
        }
        function getElementOrPropertyAccessArgumentExpressionOrName(node) {
            if (isPropertyAccessExpression(node)) {
                return node.name;
            }
            const arg = skipParentheses(node.argumentExpression);
            if (isNumericLiteral(arg) || isStringLiteralLike(arg)) {
                return arg;
            }
            return node;
        }
        function getElementOrPropertyAccessName(node) {
            const name = getElementOrPropertyAccessArgumentExpressionOrName(node);
            if (name) {
                if (isIdentifier(name)) {
                    return name.escapedText;
                }
                if (isStringLiteralLike(name) || isNumericLiteral(name)) {
                    return escapeLeadingUnderscores(name.text);
                }
            }
            return void 0;
        }
        function getAssignmentDeclarationPropertyAccessKind(lhs) {
            if (lhs.expression.kind === 110 /* ThisKeyword */) {
                return 4 /* ThisProperty */;
            }
            else if (isModuleExportsAccessExpression(lhs)) {
                return 2 /* ModuleExports */;
            }
            else if (isBindableStaticNameExpression(lhs.expression, 
            /*excludeThisKeyword*/
            true)) {
                if (isPrototypeAccess(lhs.expression)) {
                    return 3 /* PrototypeProperty */;
                }
                let nextToLast = lhs;
                while (!isIdentifier(nextToLast.expression)) {
                    nextToLast = nextToLast.expression;
                }
                const id = nextToLast.expression;
                if ((id.escapedText === "exports" || id.escapedText === "module" && getElementOrPropertyAccessName(nextToLast) === "exports") && // ExportsProperty does not support binding with computed names
                    isBindableStaticAccessExpression(lhs)) {
                    return 1 /* ExportsProperty */;
                }
                if (isBindableStaticNameExpression(lhs, 
                /*excludeThisKeyword*/
                true) || isElementAccessExpression(lhs) && isDynamicName(lhs)) {
                    return 5 /* Property */;
                }
            }
            return 0 /* None */;
        }
        function getInitializerOfBinaryExpression(expr) {
            while (isBinaryExpression(expr.right)) {
                expr = expr.right;
            }
            return expr.right;
        }
        function isPrototypePropertyAssignment(node) {
            return isBinaryExpression(node) && getAssignmentDeclarationKind(node) === 3 /* PrototypeProperty */;
        }
        function isSpecialPropertyDeclaration(expr) {
            return isInJSFile(expr) && expr.parent && expr.parent.kind === 244 /* ExpressionStatement */ && (!isElementAccessExpression(expr) || isLiteralLikeElementAccess(expr)) && !!getJSDocTypeTag(expr.parent);
        }
        function setValueDeclaration(symbol, node) {
            const { valueDeclaration } = symbol;
            if (!valueDeclaration || !(node.flags & 33554432 /* Ambient */ && !isInJSFile(node) && !(valueDeclaration.flags & 33554432 /* Ambient */)) && (isAssignmentDeclaration(valueDeclaration) && !isAssignmentDeclaration(node)) || valueDeclaration.kind !== node.kind && isEffectiveModuleDeclaration(valueDeclaration)) {
                symbol.valueDeclaration = node;
            }
        }
        function isFunctionSymbol(symbol) {
            if (!symbol || !symbol.valueDeclaration) {
                return false;
            }
            const decl = symbol.valueDeclaration;
            return decl.kind === 262 /* FunctionDeclaration */ || isVariableDeclaration(decl) && decl.initializer && isFunctionLike(decl.initializer);
        }
        function tryGetModuleSpecifierFromDeclaration(node) {
            var _a, _b;
            switch (node.kind) {
                case 260 /* VariableDeclaration */:
                case 208 /* BindingElement */:
                    return (_a = findAncestor(node.initializer, (node2) => isRequireCall(node2, 
                    /*requireStringLiteralLikeArgument*/
                    true))) == null ? void 0 : _a.arguments[0];
                case 272 /* ImportDeclaration */:
                case 278 /* ExportDeclaration */:
                    return tryCast(node.moduleSpecifier, isStringLiteralLike);
                case 271 /* ImportEqualsDeclaration */:
                    return tryCast((_b = tryCast(node.moduleReference, isExternalModuleReference)) == null ? void 0 : _b.expression, isStringLiteralLike);
                case 273 /* ImportClause */:
                case 280 /* NamespaceExport */:
                    return tryCast(node.parent.moduleSpecifier, isStringLiteralLike);
                case 274 /* NamespaceImport */:
                case 281 /* ExportSpecifier */:
                    return tryCast(node.parent.parent.moduleSpecifier, isStringLiteralLike);
                case 276 /* ImportSpecifier */:
                    return tryCast(node.parent.parent.parent.moduleSpecifier, isStringLiteralLike);
                case 205 /* ImportType */:
                    return isLiteralImportTypeNode(node) ? node.argument.literal : void 0;
                default:
                    Debug.assertNever(node);
            }
        }
        function importFromModuleSpecifier(node) {
            return tryGetImportFromModuleSpecifier(node) || Debug.failBadSyntaxKind(node.parent);
        }
        function tryGetImportFromModuleSpecifier(node) {
            switch (node.parent.kind) {
                case 272 /* ImportDeclaration */:
                case 278 /* ExportDeclaration */:
                    return node.parent;
                case 283 /* ExternalModuleReference */:
                    return node.parent.parent;
                case 213 /* CallExpression */:
                    return isImportCall(node.parent) || isRequireCall(node.parent, 
                    /*requireStringLiteralLikeArgument*/
                    false) ? node.parent : void 0;
                case 201 /* LiteralType */:
                    Debug.assert(isStringLiteral(node));
                    return tryCast(node.parent.parent, isImportTypeNode);
                default:
                    return void 0;
            }
        }
        function getExternalModuleName(node) {
            switch (node.kind) {
                case 272 /* ImportDeclaration */:
                case 278 /* ExportDeclaration */:
                    return node.moduleSpecifier;
                case 271 /* ImportEqualsDeclaration */:
                    return node.moduleReference.kind === 283 /* ExternalModuleReference */ ? node.moduleReference.expression : void 0;
                case 205 /* ImportType */:
                    return isLiteralImportTypeNode(node) ? node.argument.literal : void 0;
                case 213 /* CallExpression */:
                    return node.arguments[0];
                case 267 /* ModuleDeclaration */:
                    return node.name.kind === 11 /* StringLiteral */ ? node.name : void 0;
                default:
                    return Debug.assertNever(node);
            }
        }
        function getNamespaceDeclarationNode(node) {
            switch (node.kind) {
                case 272 /* ImportDeclaration */:
                    return node.importClause && tryCast(node.importClause.namedBindings, isNamespaceImport);
                case 271 /* ImportEqualsDeclaration */:
                    return node;
                case 278 /* ExportDeclaration */:
                    return node.exportClause && tryCast(node.exportClause, isNamespaceExport);
                default:
                    return Debug.assertNever(node);
            }
        }
        function isDefaultImport(node) {
            return node.kind === 272 /* ImportDeclaration */ && !!node.importClause && !!node.importClause.name;
        }
        function forEachImportClauseDeclaration(node, action) {
            if (node.name) {
                const result = action(node);
                if (result)
                    return result;
            }
            if (node.namedBindings) {
                const result = isNamespaceImport(node.namedBindings) ? action(node.namedBindings) : forEach(node.namedBindings.elements, action);
                if (result)
                    return result;
            }
        }
        function hasQuestionToken(node) {
            if (node) {
                switch (node.kind) {
                    case 169 /* Parameter */:
                    case 174 /* MethodDeclaration */:
                    case 173 /* MethodSignature */:
                    case 304 /* ShorthandPropertyAssignment */:
                    case 303 /* PropertyAssignment */:
                    case 172 /* PropertyDeclaration */:
                    case 171 /* PropertySignature */:
                        return node.questionToken !== void 0;
                }
            }
            return false;
        }
        function isJSDocConstructSignature(node) {
            const param = isJSDocFunctionType(node) ? firstOrUndefined(node.parameters) : void 0;
            const name = tryCast(param && param.name, isIdentifier);
            return !!name && name.escapedText === "new";
        }
        function isJSDocTypeAlias(node) {
            return node.kind === 353 /* JSDocTypedefTag */ || node.kind === 345 /* JSDocCallbackTag */ || node.kind === 347 /* JSDocEnumTag */;
        }
        function isTypeAlias(node) {
            return isJSDocTypeAlias(node) || isTypeAliasDeclaration(node);
        }
        function getSourceOfAssignment(node) {
            return isExpressionStatement(node) && isBinaryExpression(node.expression) && node.expression.operatorToken.kind === 64 /* EqualsToken */ ? getRightMostAssignedExpression(node.expression) : void 0;
        }
        function getSourceOfDefaultedAssignment(node) {
            return isExpressionStatement(node) && isBinaryExpression(node.expression) && getAssignmentDeclarationKind(node.expression) !== 0 /* None */ && isBinaryExpression(node.expression.right) && (node.expression.right.operatorToken.kind === 57 /* BarBarToken */ || node.expression.right.operatorToken.kind === 61 /* QuestionQuestionToken */) ? node.expression.right.right : void 0;
        }
        function getSingleInitializerOfVariableStatementOrPropertyDeclaration(node) {
            switch (node.kind) {
                case 243 /* VariableStatement */:
                    const v = getSingleVariableOfVariableStatement(node);
                    return v && v.initializer;
                case 172 /* PropertyDeclaration */:
                    return node.initializer;
                case 303 /* PropertyAssignment */:
                    return node.initializer;
            }
        }
        function getSingleVariableOfVariableStatement(node) {
            return isVariableStatement(node) ? firstOrUndefined(node.declarationList.declarations) : void 0;
        }
        function getNestedModuleDeclaration(node) {
            return isModuleDeclaration(node) && node.body && node.body.kind === 267 /* ModuleDeclaration */ ? node.body : void 0;
        }
        function canHaveFlowNode(node) {
            if (node.kind >= 243 /* FirstStatement */ && node.kind <= 259 /* LastStatement */) {
                return true;
            }
            switch (node.kind) {
                case 80 /* Identifier */:
                case 110 /* ThisKeyword */:
                case 108 /* SuperKeyword */:
                case 166 /* QualifiedName */:
                case 236 /* MetaProperty */:
                case 212 /* ElementAccessExpression */:
                case 211 /* PropertyAccessExpression */:
                case 208 /* BindingElement */:
                case 218 /* FunctionExpression */:
                case 219 /* ArrowFunction */:
                case 174 /* MethodDeclaration */:
                case 177 /* GetAccessor */:
                case 178 /* SetAccessor */:
                    return true;
                default:
                    return false;
            }
        }
        function canHaveJSDoc(node) {
            switch (node.kind) {
                case 219 /* ArrowFunction */:
                case 226 /* BinaryExpression */:
                case 241 /* Block */:
                case 252 /* BreakStatement */:
                case 179 /* CallSignature */:
                case 296 /* CaseClause */:
                case 263 /* ClassDeclaration */:
                case 231 /* ClassExpression */:
                case 175 /* ClassStaticBlockDeclaration */:
                case 176 /* Constructor */:
                case 185 /* ConstructorType */:
                case 180 /* ConstructSignature */:
                case 251 /* ContinueStatement */:
                case 259 /* DebuggerStatement */:
                case 246 /* DoStatement */:
                case 212 /* ElementAccessExpression */:
                case 242 /* EmptyStatement */:
                case 1 /* EndOfFileToken */:
                case 266 /* EnumDeclaration */:
                case 306 /* EnumMember */:
                case 277 /* ExportAssignment */:
                case 278 /* ExportDeclaration */:
                case 281 /* ExportSpecifier */:
                case 244 /* ExpressionStatement */:
                case 249 /* ForInStatement */:
                case 250 /* ForOfStatement */:
                case 248 /* ForStatement */:
                case 262 /* FunctionDeclaration */:
                case 218 /* FunctionExpression */:
                case 184 /* FunctionType */:
                case 177 /* GetAccessor */:
                case 80 /* Identifier */:
                case 245 /* IfStatement */:
                case 272 /* ImportDeclaration */:
                case 271 /* ImportEqualsDeclaration */:
                case 181 /* IndexSignature */:
                case 264 /* InterfaceDeclaration */:
                case 324 /* JSDocFunctionType */:
                case 330 /* JSDocSignature */:
                case 256 /* LabeledStatement */:
                case 174 /* MethodDeclaration */:
                case 173 /* MethodSignature */:
                case 267 /* ModuleDeclaration */:
                case 202 /* NamedTupleMember */:
                case 270 /* NamespaceExportDeclaration */:
                case 210 /* ObjectLiteralExpression */:
                case 169 /* Parameter */:
                case 217 /* ParenthesizedExpression */:
                case 211 /* PropertyAccessExpression */:
                case 303 /* PropertyAssignment */:
                case 172 /* PropertyDeclaration */:
                case 171 /* PropertySignature */:
                case 253 /* ReturnStatement */:
                case 240 /* SemicolonClassElement */:
                case 178 /* SetAccessor */:
                case 304 /* ShorthandPropertyAssignment */:
                case 305 /* SpreadAssignment */:
                case 255 /* SwitchStatement */:
                case 257 /* ThrowStatement */:
                case 258 /* TryStatement */:
                case 265 /* TypeAliasDeclaration */:
                case 168 /* TypeParameter */:
                case 260 /* VariableDeclaration */:
                case 243 /* VariableStatement */:
                case 247 /* WhileStatement */:
                case 254 /* WithStatement */:
                    return true;
                default:
                    return false;
            }
        }
        function getJSDocCommentsAndTags(hostNode, noCache) {
            let result;
            if (isVariableLike(hostNode) && hasInitializer(hostNode) && hasJSDocNodes(hostNode.initializer)) {
                result = addRange(result, filterOwnedJSDocTags(hostNode, hostNode.initializer.jsDoc));
            }
            let node = hostNode;
            while (node && node.parent) {
                if (hasJSDocNodes(node)) {
                    result = addRange(result, filterOwnedJSDocTags(hostNode, node.jsDoc));
                }
                if (node.kind === 169 /* Parameter */) {
                    result = addRange(result, (noCache ? getJSDocParameterTagsNoCache : getJSDocParameterTags)(node));
                    break;
                }
                if (node.kind === 168 /* TypeParameter */) {
                    result = addRange(result, (noCache ? getJSDocTypeParameterTagsNoCache : getJSDocTypeParameterTags)(node));
                    break;
                }
                node = getNextJSDocCommentLocation(node);
            }
            return result || emptyArray;
        }
        function filterOwnedJSDocTags(hostNode, comments) {
            const lastJsDoc = last(comments);
            return flatMap(comments, (jsDoc) => {
                if (jsDoc === lastJsDoc) {
                    const ownedTags = filter(jsDoc.tags, (tag) => ownsJSDocTag(hostNode, tag));
                    return jsDoc.tags === ownedTags ? [jsDoc] : ownedTags;
                }
                else {
                    return filter(jsDoc.tags, isJSDocOverloadTag);
                }
            });
        }
        function ownsJSDocTag(hostNode, tag) {
            return !(isJSDocTypeTag(tag) || isJSDocSatisfiesTag(tag)) || !tag.parent || !isJSDoc(tag.parent) || !isParenthesizedExpression(tag.parent.parent) || tag.parent.parent === hostNode;
        }
        function getNextJSDocCommentLocation(node) {
            const parent2 = node.parent;
            if (parent2.kind === 303 /* PropertyAssignment */ || parent2.kind === 277 /* ExportAssignment */ || parent2.kind === 172 /* PropertyDeclaration */ || parent2.kind === 244 /* ExpressionStatement */ && node.kind === 211 /* PropertyAccessExpression */ || parent2.kind === 253 /* ReturnStatement */ || getNestedModuleDeclaration(parent2) || isAssignmentExpression(node)) {
                return parent2;
            }
            else if (parent2.parent && (getSingleVariableOfVariableStatement(parent2.parent) === node || isAssignmentExpression(parent2))) {
                return parent2.parent;
            }
            else if (parent2.parent && parent2.parent.parent && (getSingleVariableOfVariableStatement(parent2.parent.parent) || getSingleInitializerOfVariableStatementOrPropertyDeclaration(parent2.parent.parent) === node || getSourceOfDefaultedAssignment(parent2.parent.parent))) {
                return parent2.parent.parent;
            }
        }
        function getParameterSymbolFromJSDoc(node) {
            if (node.symbol) {
                return node.symbol;
            }
            if (!isIdentifier(node.name)) {
                return void 0;
            }
            const name = node.name.escapedText;
            const decl = getHostSignatureFromJSDoc(node);
            if (!decl) {
                return void 0;
            }
            const parameter = find(decl.parameters, (p) => p.name.kind === 80 /* Identifier */ && p.name.escapedText === name);
            return parameter && parameter.symbol;
        }
        function getEffectiveContainerForJSDocTemplateTag(node) {
            if (isJSDoc(node.parent) && node.parent.tags) {
                const typeAlias = find(node.parent.tags, isJSDocTypeAlias);
                if (typeAlias) {
                    return typeAlias;
                }
            }
            return getHostSignatureFromJSDoc(node);
        }
        function getJSDocOverloadTags(node) {
            return getAllJSDocTags(node, isJSDocOverloadTag);
        }
        function getHostSignatureFromJSDoc(node) {
            const host = getEffectiveJSDocHost(node);
            if (host) {
                return isPropertySignature(host) && host.type && isFunctionLike(host.type) ? host.type : isFunctionLike(host) ? host : void 0;
            }
            return void 0;
        }
        function getEffectiveJSDocHost(node) {
            const host = getJSDocHost(node);
            if (host) {
                return getSourceOfDefaultedAssignment(host) || getSourceOfAssignment(host) || getSingleInitializerOfVariableStatementOrPropertyDeclaration(host) || getSingleVariableOfVariableStatement(host) || getNestedModuleDeclaration(host) || host;
            }
        }
        function getJSDocHost(node) {
            const jsDoc = getJSDocRoot(node);
            if (!jsDoc) {
                return void 0;
            }
            const host = jsDoc.parent;
            if (host && host.jsDoc && jsDoc === lastOrUndefined(host.jsDoc)) {
                return host;
            }
        }
        function getJSDocRoot(node) {
            return findAncestor(node.parent, isJSDoc);
        }
        function getTypeParameterFromJsDoc(node) {
            const name = node.name.escapedText;
            const { typeParameters } = node.parent.parent.parent;
            return typeParameters && find(typeParameters, (p) => p.name.escapedText === name);
        }
        function hasTypeArguments(node) {
            return !!node.typeArguments;
        }
        function getAssignmentTarget(node) {
            let parent2 = node.parent;
            while (true) {
                switch (parent2.kind) {
                    case 226 /* BinaryExpression */:
                        const binaryExpression = parent2;
                        const binaryOperator = binaryExpression.operatorToken.kind;
                        return isAssignmentOperator(binaryOperator) && binaryExpression.left === node ? binaryExpression : void 0;
                    case 224 /* PrefixUnaryExpression */:
                    case 225 /* PostfixUnaryExpression */:
                        const unaryExpression = parent2;
                        const unaryOperator = unaryExpression.operator;
                        return unaryOperator === 46 /* PlusPlusToken */ || unaryOperator === 47 /* MinusMinusToken */ ? unaryExpression : void 0;
                    case 249 /* ForInStatement */:
                    case 250 /* ForOfStatement */:
                        const forInOrOfStatement = parent2;
                        return forInOrOfStatement.initializer === node ? forInOrOfStatement : void 0;
                    case 217 /* ParenthesizedExpression */:
                    case 209 /* ArrayLiteralExpression */:
                    case 230 /* SpreadElement */:
                    case 235 /* NonNullExpression */:
                        node = parent2;
                        break;
                    case 305 /* SpreadAssignment */:
                        node = parent2.parent;
                        break;
                    case 304 /* ShorthandPropertyAssignment */:
                        if (parent2.name !== node) {
                            return void 0;
                        }
                        node = parent2.parent;
                        break;
                    case 303 /* PropertyAssignment */:
                        if (parent2.name === node) {
                            return void 0;
                        }
                        node = parent2.parent;
                        break;
                    default:
                        return void 0;
                }
                parent2 = node.parent;
            }
        }
        function getAssignmentTargetKind(node) {
            const target = getAssignmentTarget(node);
            if (!target) {
                return 0 /* None */;
            }
            switch (target.kind) {
                case 226 /* BinaryExpression */:
                    const binaryOperator = target.operatorToken.kind;
                    return binaryOperator === 64 /* EqualsToken */ || isLogicalOrCoalescingAssignmentOperator(binaryOperator) ? 1 /* Definite */ : 2 /* Compound */;
                case 224 /* PrefixUnaryExpression */:
                case 225 /* PostfixUnaryExpression */:
                    return 2 /* Compound */;
                case 249 /* ForInStatement */:
                case 250 /* ForOfStatement */:
                    return 1 /* Definite */;
            }
        }
        function isAssignmentTarget(node) {
            return !!getAssignmentTarget(node);
        }
        function isCompoundLikeAssignment(assignment) {
            const right = skipParentheses(assignment.right);
            return right.kind === 226 /* BinaryExpression */ && isShiftOperatorOrHigher(right.operatorToken.kind);
        }
        function isInCompoundLikeAssignment(node) {
            const target = getAssignmentTarget(node);
            return !!target && isAssignmentExpression(target, 
            /*excludeCompoundAssignment*/
            true) && isCompoundLikeAssignment(target);
        }
        function isNodeWithPossibleHoistedDeclaration(node) {
            switch (node.kind) {
                case 241 /* Block */:
                case 243 /* VariableStatement */:
                case 254 /* WithStatement */:
                case 245 /* IfStatement */:
                case 255 /* SwitchStatement */:
                case 269 /* CaseBlock */:
                case 296 /* CaseClause */:
                case 297 /* DefaultClause */:
                case 256 /* LabeledStatement */:
                case 248 /* ForStatement */:
                case 249 /* ForInStatement */:
                case 250 /* ForOfStatement */:
                case 246 /* DoStatement */:
                case 247 /* WhileStatement */:
                case 258 /* TryStatement */:
                case 299 /* CatchClause */:
                    return true;
            }
            return false;
        }
        function isValueSignatureDeclaration(node) {
            return isFunctionExpression(node) || isArrowFunction(node) || isMethodOrAccessor(node) || isFunctionDeclaration(node) || isConstructorDeclaration(node);
        }
        function walkUp(node, kind) {
            while (node && node.kind === kind) {
                node = node.parent;
            }
            return node;
        }
        function walkUpParenthesizedTypes(node) {
            return walkUp(node, 196 /* ParenthesizedType */);
        }
        function walkUpParenthesizedExpressions(node) {
            return walkUp(node, 217 /* ParenthesizedExpression */);
        }
        function walkUpParenthesizedTypesAndGetParentAndChild(node) {
            let child;
            while (node && node.kind === 196 /* ParenthesizedType */) {
                child = node;
                node = node.parent;
            }
            return [child, node];
        }
        function skipTypeParentheses(node) {
            while (isParenthesizedTypeNode(node))
                node = node.type;
            return node;
        }
        function skipParentheses(node, excludeJSDocTypeAssertions) {
            const flags = excludeJSDocTypeAssertions ? 1 /* Parentheses */ | 16 /* ExcludeJSDocTypeAssertion */ : 1 /* Parentheses */;
            return skipOuterExpressions(node, flags);
        }
        function isDeleteTarget(node) {
            if (node.kind !== 211 /* PropertyAccessExpression */ && node.kind !== 212 /* ElementAccessExpression */) {
                return false;
            }
            node = walkUpParenthesizedExpressions(node.parent);
            return node && node.kind === 220 /* DeleteExpression */;
        }
        function isNodeDescendantOf(node, ancestor) {
            while (node) {
                if (node === ancestor)
                    return true;
                node = node.parent;
            }
            return false;
        }
        function isDeclarationName(name) {
            return !isSourceFile(name) && !isBindingPattern(name) && isDeclaration(name.parent) && name.parent.name === name;
        }
        function getDeclarationFromName(name) {
            const parent2 = name.parent;
            switch (name.kind) {
                case 11 /* StringLiteral */:
                case 15 /* NoSubstitutionTemplateLiteral */:
                case 9 /* NumericLiteral */:
                    if (isComputedPropertyName(parent2))
                        return parent2.parent;
                case 80 /* Identifier */:
                    if (isDeclaration(parent2)) {
                        return parent2.name === name ? parent2 : void 0;
                    }
                    else if (isQualifiedName(parent2)) {
                        const tag = parent2.parent;
                        return isJSDocParameterTag(tag) && tag.name === parent2 ? tag : void 0;
                    }
                    else {
                        const binExp = parent2.parent;
                        return isBinaryExpression(binExp) && getAssignmentDeclarationKind(binExp) !== 0 /* None */ && (binExp.left.symbol || binExp.symbol) && getNameOfDeclaration(binExp) === name ? binExp : void 0;
                    }
                case 81 /* PrivateIdentifier */:
                    return isDeclaration(parent2) && parent2.name === name ? parent2 : void 0;
                default:
                    return void 0;
            }
        }
        function isLiteralComputedPropertyDeclarationName(node) {
            return isStringOrNumericLiteralLike(node) && node.parent.kind === 167 /* ComputedPropertyName */ && isDeclaration(node.parent.parent);
        }
        function isIdentifierName(node) {
            const parent2 = node.parent;
            switch (parent2.kind) {
                case 172 /* PropertyDeclaration */:
                case 171 /* PropertySignature */:
                case 174 /* MethodDeclaration */:
                case 173 /* MethodSignature */:
                case 177 /* GetAccessor */:
                case 178 /* SetAccessor */:
                case 306 /* EnumMember */:
                case 303 /* PropertyAssignment */:
                case 211 /* PropertyAccessExpression */:
                    return parent2.name === node;
                case 166 /* QualifiedName */:
                    return parent2.right === node;
                case 208 /* BindingElement */:
                case 276 /* ImportSpecifier */:
                    return parent2.propertyName === node;
                case 281 /* ExportSpecifier */:
                case 291 /* JsxAttribute */:
                case 285 /* JsxSelfClosingElement */:
                case 286 /* JsxOpeningElement */:
                case 287 /* JsxClosingElement */:
                    return true;
            }
            return false;
        }
        function isAliasSymbolDeclaration(node) {
            if (node.kind === 271 /* ImportEqualsDeclaration */ || node.kind === 270 /* NamespaceExportDeclaration */ || node.kind === 273 /* ImportClause */ && !!node.name || node.kind === 274 /* NamespaceImport */ || node.kind === 280 /* NamespaceExport */ || node.kind === 276 /* ImportSpecifier */ || node.kind === 281 /* ExportSpecifier */ || node.kind === 277 /* ExportAssignment */ && exportAssignmentIsAlias(node)) {
                return true;
            }
            return isInJSFile(node) && (isBinaryExpression(node) && getAssignmentDeclarationKind(node) === 2 /* ModuleExports */ && exportAssignmentIsAlias(node) || isPropertyAccessExpression(node) && isBinaryExpression(node.parent) && node.parent.left === node && node.parent.operatorToken.kind === 64 /* EqualsToken */ && isAliasableExpression(node.parent.right));
        }
        function getAliasDeclarationFromName(node) {
            switch (node.parent.kind) {
                case 273 /* ImportClause */:
                case 276 /* ImportSpecifier */:
                case 274 /* NamespaceImport */:
                case 281 /* ExportSpecifier */:
                case 277 /* ExportAssignment */:
                case 271 /* ImportEqualsDeclaration */:
                case 280 /* NamespaceExport */:
                    return node.parent;
                case 166 /* QualifiedName */:
                    do {
                        node = node.parent;
                    } while (node.parent.kind === 166 /* QualifiedName */);
                    return getAliasDeclarationFromName(node);
            }
        }
        function isAliasableExpression(e) {
            return isEntityNameExpression(e) || isClassExpression(e);
        }
        function exportAssignmentIsAlias(node) {
            const e = getExportAssignmentExpression(node);
            return isAliasableExpression(e);
        }
        function getExportAssignmentExpression(node) {
            return isExportAssignment(node) ? node.expression : node.right;
        }
        function getPropertyAssignmentAliasLikeExpression(node) {
            return node.kind === 304 /* ShorthandPropertyAssignment */ ? node.name : node.kind === 303 /* PropertyAssignment */ ? node.initializer : node.parent.right;
        }
        function getEffectiveBaseTypeNode(node) {
            const baseType = getClassExtendsHeritageElement(node);
            if (baseType && isInJSFile(node)) {
                const tag = getJSDocAugmentsTag(node);
                if (tag) {
                    return tag.class;
                }
            }
            return baseType;
        }
        function getClassExtendsHeritageElement(node) {
            const heritageClause = getHeritageClause(node.heritageClauses, 96 /* ExtendsKeyword */);
            return heritageClause && heritageClause.types.length > 0 ? heritageClause.types[0] : void 0;
        }
        function getEffectiveImplementsTypeNodes(node) {
            if (isInJSFile(node)) {
                return getJSDocImplementsTags(node).map((n) => n.class);
            }
            else {
                const heritageClause = getHeritageClause(node.heritageClauses, 119 /* ImplementsKeyword */);
                return heritageClause == null ? void 0 : heritageClause.types;
            }
        }
        function getAllSuperTypeNodes(node) {
            return isInterfaceDeclaration(node) ? getInterfaceBaseTypeNodes(node) || emptyArray : isClassLike(node) ? concatenate(singleElementArray(getEffectiveBaseTypeNode(node)), getEffectiveImplementsTypeNodes(node)) || emptyArray : emptyArray;
        }
        function getInterfaceBaseTypeNodes(node) {
            const heritageClause = getHeritageClause(node.heritageClauses, 96 /* ExtendsKeyword */);
            return heritageClause ? heritageClause.types : void 0;
        }
        function getHeritageClause(clauses, kind) {
            if (clauses) {
                for (const clause of clauses) {
                    if (clause.token === kind) {
                        return clause;
                    }
                }
            }
            return void 0;
        }
        function getAncestor(node, kind) {
            while (node) {
                if (node.kind === kind) {
                    return node;
                }
                node = node.parent;
            }
            return void 0;
        }
        function isKeyword(token) {
            return 83 /* FirstKeyword */ <= token && token <= 165 /* LastKeyword */;
        }
        function isPunctuation(token) {
            return 19 /* FirstPunctuation */ <= token && token <= 79 /* LastPunctuation */;
        }
        function isKeywordOrPunctuation(token) {
            return isKeyword(token) || isPunctuation(token);
        }
        function isContextualKeyword(token) {
            return 128 /* FirstContextualKeyword */ <= token && token <= 165 /* LastContextualKeyword */;
        }
        function isNonContextualKeyword(token) {
            return isKeyword(token) && !isContextualKeyword(token);
        }
        function isFutureReservedKeyword(token) {
            return 119 /* FirstFutureReservedWord */ <= token && token <= 127 /* LastFutureReservedWord */;
        }
        function isStringANonContextualKeyword(name) {
            const token = stringToToken(name);
            return token !== void 0 && isNonContextualKeyword(token);
        }
        function isStringAKeyword(name) {
            const token = stringToToken(name);
            return token !== void 0 && isKeyword(token);
        }
        function isIdentifierANonContextualKeyword(node) {
            const originalKeywordKind = identifierToKeywordKind(node);
            return !!originalKeywordKind && !isContextualKeyword(originalKeywordKind);
        }
        function isTrivia(token) {
            return 2 /* FirstTriviaToken */ <= token && token <= 7 /* LastTriviaToken */;
        }
        function getFunctionFlags(node) {
            if (!node) {
                return 4 /* Invalid */;
            }
            let flags = 0 /* Normal */;
            switch (node.kind) {
                case 262 /* FunctionDeclaration */:
                case 218 /* FunctionExpression */:
                case 174 /* MethodDeclaration */:
                    if (node.asteriskToken) {
                        flags |= 1 /* Generator */;
                    }
                case 219 /* ArrowFunction */:
                    if (hasSyntacticModifier(node, 1024 /* Async */)) {
                        flags |= 2 /* Async */;
                    }
                    break;
            }
            if (!node.body) {
                flags |= 4 /* Invalid */;
            }
            return flags;
        }
        function isAsyncFunction(node) {
            switch (node.kind) {
                case 262 /* FunctionDeclaration */:
                case 218 /* FunctionExpression */:
                case 219 /* ArrowFunction */:
                case 174 /* MethodDeclaration */:
                    return node.body !== void 0 && node.asteriskToken === void 0 && hasSyntacticModifier(node, 1024 /* Async */);
            }
            return false;
        }
        function isStringOrNumericLiteralLike(node) {
            return isStringLiteralLike(node) || isNumericLiteral(node);
        }
        function isSignedNumericLiteral(node) {
            return isPrefixUnaryExpression(node) && (node.operator === 40 /* PlusToken */ || node.operator === 41 /* MinusToken */) && isNumericLiteral(node.operand);
        }
        function hasDynamicName(declaration) {
            const name = getNameOfDeclaration(declaration);
            return !!name && isDynamicName(name);
        }
        function isDynamicName(name) {
            if (!(name.kind === 167 /* ComputedPropertyName */ || name.kind === 212 /* ElementAccessExpression */)) {
                return false;
            }
            const expr = isElementAccessExpression(name) ? skipParentheses(name.argumentExpression) : name.expression;
            return !isStringOrNumericLiteralLike(expr) && !isSignedNumericLiteral(expr);
        }
        function getPropertyNameForPropertyNameNode(name) {
            switch (name.kind) {
                case 80 /* Identifier */:
                case 81 /* PrivateIdentifier */:
                    return name.escapedText;
                case 11 /* StringLiteral */:
                case 15 /* NoSubstitutionTemplateLiteral */:
                case 9 /* NumericLiteral */:
                    return escapeLeadingUnderscores(name.text);
                case 167 /* ComputedPropertyName */:
                    const nameExpression = name.expression;
                    if (isStringOrNumericLiteralLike(nameExpression)) {
                        return escapeLeadingUnderscores(nameExpression.text);
                    }
                    else if (isSignedNumericLiteral(nameExpression)) {
                        if (nameExpression.operator === 41 /* MinusToken */) {
                            return tokenToString(nameExpression.operator) + nameExpression.operand.text;
                        }
                        return nameExpression.operand.text;
                    }
                    return void 0;
                case 295 /* JsxNamespacedName */:
                    return getEscapedTextOfJsxNamespacedName(name);
                default:
                    return Debug.assertNever(name);
            }
        }
        function isPropertyNameLiteral(node) {
            switch (node.kind) {
                case 80 /* Identifier */:
                case 11 /* StringLiteral */:
                case 15 /* NoSubstitutionTemplateLiteral */:
                case 9 /* NumericLiteral */:
                    return true;
                default:
                    return false;
            }
        }
        function getTextOfIdentifierOrLiteral(node) {
            return isMemberName(node) ? idText(node) : isJsxNamespacedName(node) ? getTextOfJsxNamespacedName(node) : node.text;
        }
        function getEscapedTextOfIdentifierOrLiteral(node) {
            return isMemberName(node) ? node.escapedText : isJsxNamespacedName(node) ? getEscapedTextOfJsxNamespacedName(node) : escapeLeadingUnderscores(node.text);
        }
        function getPropertyNameForUniqueESSymbol(symbol) {
            return `__@${getSymbolId(symbol)}@${symbol.escapedName}`;
        }
        function getSymbolNameForPrivateIdentifier(containingClassSymbol, description3) {
            return `__#${getSymbolId(containingClassSymbol)}@${description3}`;
        }
        function isKnownSymbol(symbol) {
            return startsWith(symbol.escapedName, "__@");
        }
        function isPrivateIdentifierSymbol(symbol) {
            return startsWith(symbol.escapedName, "__#");
        }
        function isESSymbolIdentifier(node) {
            return node.kind === 80 /* Identifier */ && node.escapedText === "Symbol";
        }
        function isProtoSetter(node) {
            return isIdentifier(node) ? idText(node) === "__proto__" : isStringLiteral(node) && node.text === "__proto__";
        }
        function isAnonymousFunctionDefinition(node, cb) {
            node = skipOuterExpressions(node);
            switch (node.kind) {
                case 231 /* ClassExpression */:
                    if (classHasDeclaredOrExplicitlyAssignedName(node)) {
                        return false;
                    }
                    break;
                case 218 /* FunctionExpression */:
                    if (node.name) {
                        return false;
                    }
                    break;
                case 219 /* ArrowFunction */:
                    break;
                default:
                    return false;
            }
            return typeof cb === "function" ? cb(node) : true;
        }
        function isNamedEvaluationSource(node) {
            switch (node.kind) {
                case 303 /* PropertyAssignment */:
                    return !isProtoSetter(node.name);
                case 304 /* ShorthandPropertyAssignment */:
                    return !!node.objectAssignmentInitializer;
                case 260 /* VariableDeclaration */:
                    return isIdentifier(node.name) && !!node.initializer;
                case 169 /* Parameter */:
                    return isIdentifier(node.name) && !!node.initializer && !node.dotDotDotToken;
                case 208 /* BindingElement */:
                    return isIdentifier(node.name) && !!node.initializer && !node.dotDotDotToken;
                case 172 /* PropertyDeclaration */:
                    return !!node.initializer;
                case 226 /* BinaryExpression */:
                    switch (node.operatorToken.kind) {
                        case 64 /* EqualsToken */:
                        case 77 /* AmpersandAmpersandEqualsToken */:
                        case 76 /* BarBarEqualsToken */:
                        case 78 /* QuestionQuestionEqualsToken */:
                            return isIdentifier(node.left);
                    }
                    break;
                case 277 /* ExportAssignment */:
                    return true;
            }
            return false;
        }
        function isNamedEvaluation(node, cb) {
            if (!isNamedEvaluationSource(node))
                return false;
            switch (node.kind) {
                case 303 /* PropertyAssignment */:
                    return isAnonymousFunctionDefinition(node.initializer, cb);
                case 304 /* ShorthandPropertyAssignment */:
                    return isAnonymousFunctionDefinition(node.objectAssignmentInitializer, cb);
                case 260 /* VariableDeclaration */:
                case 169 /* Parameter */:
                case 208 /* BindingElement */:
                case 172 /* PropertyDeclaration */:
                    return isAnonymousFunctionDefinition(node.initializer, cb);
                case 226 /* BinaryExpression */:
                    return isAnonymousFunctionDefinition(node.right, cb);
                case 277 /* ExportAssignment */:
                    return isAnonymousFunctionDefinition(node.expression, cb);
            }
        }
        function isPushOrUnshiftIdentifier(node) {
            return node.escapedText === "push" || node.escapedText === "unshift";
        }
        function isParameterDeclaration(node) {
            const root = getRootDeclaration(node);
            return root.kind === 169 /* Parameter */;
        }
        function getRootDeclaration(node) {
            while (node.kind === 208 /* BindingElement */) {
                node = node.parent.parent;
            }
            return node;
        }
        function nodeStartsNewLexicalEnvironment(node) {
            const kind = node.kind;
            return kind === 176 /* Constructor */ || kind === 218 /* FunctionExpression */ || kind === 262 /* FunctionDeclaration */ || kind === 219 /* ArrowFunction */ || kind === 174 /* MethodDeclaration */ || kind === 177 /* GetAccessor */ || kind === 178 /* SetAccessor */ || kind === 267 /* ModuleDeclaration */ || kind === 312 /* SourceFile */;
        }
        function nodeIsSynthesized(range) {
            return positionIsSynthesized(range.pos) || positionIsSynthesized(range.end);
        }
        function getOriginalSourceFile(sourceFile) {
            return getParseTreeNode(sourceFile, isSourceFile) || sourceFile;
        }
        function getExpressionAssociativity(expression) {
            const operator = getOperator(expression);
            const hasArguments = expression.kind === 214 /* NewExpression */ && expression.arguments !== void 0;
            return getOperatorAssociativity(expression.kind, operator, hasArguments);
        }
        function getOperatorAssociativity(kind, operator, hasArguments) {
            switch (kind) {
                case 214 /* NewExpression */:
                    return hasArguments ? 0 /* Left */ : 1 /* Right */;
                case 224 /* PrefixUnaryExpression */:
                case 221 /* TypeOfExpression */:
                case 222 /* VoidExpression */:
                case 220 /* DeleteExpression */:
                case 223 /* AwaitExpression */:
                case 227 /* ConditionalExpression */:
                case 229 /* YieldExpression */:
                    return 1 /* Right */;
                case 226 /* BinaryExpression */:
                    switch (operator) {
                        case 43 /* AsteriskAsteriskToken */:
                        case 64 /* EqualsToken */:
                        case 65 /* PlusEqualsToken */:
                        case 66 /* MinusEqualsToken */:
                        case 68 /* AsteriskAsteriskEqualsToken */:
                        case 67 /* AsteriskEqualsToken */:
                        case 69 /* SlashEqualsToken */:
                        case 70 /* PercentEqualsToken */:
                        case 71 /* LessThanLessThanEqualsToken */:
                        case 72 /* GreaterThanGreaterThanEqualsToken */:
                        case 73 /* GreaterThanGreaterThanGreaterThanEqualsToken */:
                        case 74 /* AmpersandEqualsToken */:
                        case 79 /* CaretEqualsToken */:
                        case 75 /* BarEqualsToken */:
                        case 76 /* BarBarEqualsToken */:
                        case 77 /* AmpersandAmpersandEqualsToken */:
                        case 78 /* QuestionQuestionEqualsToken */:
                            return 1 /* Right */;
                    }
            }
            return 0 /* Left */;
        }
        function getExpressionPrecedence(expression) {
            const operator = getOperator(expression);
            const hasArguments = expression.kind === 214 /* NewExpression */ && expression.arguments !== void 0;
            return getOperatorPrecedence(expression.kind, operator, hasArguments);
        }
        function getOperator(expression) {
            if (expression.kind === 226 /* BinaryExpression */) {
                return expression.operatorToken.kind;
            }
            else if (expression.kind === 224 /* PrefixUnaryExpression */ || expression.kind === 225 /* PostfixUnaryExpression */) {
                return expression.operator;
            }
            else {
                return expression.kind;
            }
        }
        function getOperatorPrecedence(nodeKind, operatorKind, hasArguments) {
            switch (nodeKind) {
                case 361 /* CommaListExpression */:
                    return 0 /* Comma */;
                case 230 /* SpreadElement */:
                    return 1 /* Spread */;
                case 229 /* YieldExpression */:
                    return 2 /* Yield */;
                case 227 /* ConditionalExpression */:
                    return 4 /* Conditional */;
                case 226 /* BinaryExpression */:
                    switch (operatorKind) {
                        case 28 /* CommaToken */:
                            return 0 /* Comma */;
                        case 64 /* EqualsToken */:
                        case 65 /* PlusEqualsToken */:
                        case 66 /* MinusEqualsToken */:
                        case 68 /* AsteriskAsteriskEqualsToken */:
                        case 67 /* AsteriskEqualsToken */:
                        case 69 /* SlashEqualsToken */:
                        case 70 /* PercentEqualsToken */:
                        case 71 /* LessThanLessThanEqualsToken */:
                        case 72 /* GreaterThanGreaterThanEqualsToken */:
                        case 73 /* GreaterThanGreaterThanGreaterThanEqualsToken */:
                        case 74 /* AmpersandEqualsToken */:
                        case 79 /* CaretEqualsToken */:
                        case 75 /* BarEqualsToken */:
                        case 76 /* BarBarEqualsToken */:
                        case 77 /* AmpersandAmpersandEqualsToken */:
                        case 78 /* QuestionQuestionEqualsToken */:
                            return 3 /* Assignment */;
                        default:
                            return getBinaryOperatorPrecedence(operatorKind);
                    }
                case 216 /* TypeAssertionExpression */:
                case 235 /* NonNullExpression */:
                case 224 /* PrefixUnaryExpression */:
                case 221 /* TypeOfExpression */:
                case 222 /* VoidExpression */:
                case 220 /* DeleteExpression */:
                case 223 /* AwaitExpression */:
                    return 16 /* Unary */;
                case 225 /* PostfixUnaryExpression */:
                    return 17 /* Update */;
                case 213 /* CallExpression */:
                    return 18 /* LeftHandSide */;
                case 214 /* NewExpression */:
                    return hasArguments ? 19 /* Member */ : 18 /* LeftHandSide */;
                case 215 /* TaggedTemplateExpression */:
                case 211 /* PropertyAccessExpression */:
                case 212 /* ElementAccessExpression */:
                case 236 /* MetaProperty */:
                    return 19 /* Member */;
                case 234 /* AsExpression */:
                case 238 /* SatisfiesExpression */:
                    return 11 /* Relational */;
                case 110 /* ThisKeyword */:
                case 108 /* SuperKeyword */:
                case 80 /* Identifier */:
                case 81 /* PrivateIdentifier */:
                case 106 /* NullKeyword */:
                case 112 /* TrueKeyword */:
                case 97 /* FalseKeyword */:
                case 9 /* NumericLiteral */:
                case 10 /* BigIntLiteral */:
                case 11 /* StringLiteral */:
                case 209 /* ArrayLiteralExpression */:
                case 210 /* ObjectLiteralExpression */:
                case 218 /* FunctionExpression */:
                case 219 /* ArrowFunction */:
                case 231 /* ClassExpression */:
                case 14 /* RegularExpressionLiteral */:
                case 15 /* NoSubstitutionTemplateLiteral */:
                case 228 /* TemplateExpression */:
                case 217 /* ParenthesizedExpression */:
                case 232 /* OmittedExpression */:
                case 284 /* JsxElement */:
                case 285 /* JsxSelfClosingElement */:
                case 288 /* JsxFragment */:
                    return 20 /* Primary */;
                default:
                    return -1 /* Invalid */;
            }
        }
        function getBinaryOperatorPrecedence(kind) {
            switch (kind) {
                case 61 /* QuestionQuestionToken */:
                    return 4 /* Coalesce */;
                case 57 /* BarBarToken */:
                    return 5 /* LogicalOR */;
                case 56 /* AmpersandAmpersandToken */:
                    return 6 /* LogicalAND */;
                case 52 /* BarToken */:
                    return 7 /* BitwiseOR */;
                case 53 /* CaretToken */:
                    return 8 /* BitwiseXOR */;
                case 51 /* AmpersandToken */:
                    return 9 /* BitwiseAND */;
                case 35 /* EqualsEqualsToken */:
                case 36 /* ExclamationEqualsToken */:
                case 37 /* EqualsEqualsEqualsToken */:
                case 38 /* ExclamationEqualsEqualsToken */:
                    return 10 /* Equality */;
                case 30 /* LessThanToken */:
                case 32 /* GreaterThanToken */:
                case 33 /* LessThanEqualsToken */:
                case 34 /* GreaterThanEqualsToken */:
                case 104 /* InstanceOfKeyword */:
                case 103 /* InKeyword */:
                case 130 /* AsKeyword */:
                case 152 /* SatisfiesKeyword */:
                    return 11 /* Relational */;
                case 48 /* LessThanLessThanToken */:
                case 49 /* GreaterThanGreaterThanToken */:
                case 50 /* GreaterThanGreaterThanGreaterThanToken */:
                    return 12 /* Shift */;
                case 40 /* PlusToken */:
                case 41 /* MinusToken */:
                    return 13 /* Additive */;
                case 42 /* AsteriskToken */:
                case 44 /* SlashToken */:
                case 45 /* PercentToken */:
                    return 14 /* Multiplicative */;
                case 43 /* AsteriskAsteriskToken */:
                    return 15 /* Exponentiation */;
            }
            return -1;
        }
        function getSemanticJsxChildren(children) {
            return filter(children, (i) => {
                switch (i.kind) {
                    case 294 /* JsxExpression */:
                        return !!i.expression;
                    case 12 /* JsxText */:
                        return !i.containsOnlyTriviaWhiteSpaces;
                    default:
                        return true;
                }
            });
        }
        function createDiagnosticCollection() {
            let nonFileDiagnostics = [];
            const filesWithDiagnostics = [];
            const fileDiagnostics = /* @__PURE__ */ new Map();
            let hasReadNonFileDiagnostics = false;
            return {
                add,
                lookup,
                getGlobalDiagnostics,
                getDiagnostics: getDiagnostics2
            };
            function lookup(diagnostic) {
                let diagnostics;
                if (diagnostic.file) {
                    diagnostics = fileDiagnostics.get(diagnostic.file.fileName);
                }
                else {
                    diagnostics = nonFileDiagnostics;
                }
                if (!diagnostics) {
                    return void 0;
                }
                const result = binarySearch(diagnostics, diagnostic, identity, compareDiagnosticsSkipRelatedInformation);
                if (result >= 0) {
                    return diagnostics[result];
                }
                return void 0;
            }
            function add(diagnostic) {
                let diagnostics;
                if (diagnostic.file) {
                    diagnostics = fileDiagnostics.get(diagnostic.file.fileName);
                    if (!diagnostics) {
                        diagnostics = [];
                        fileDiagnostics.set(diagnostic.file.fileName, diagnostics);
                        insertSorted(filesWithDiagnostics, diagnostic.file.fileName, compareStringsCaseSensitive);
                    }
                }
                else {
                    if (hasReadNonFileDiagnostics) {
                        hasReadNonFileDiagnostics = false;
                        nonFileDiagnostics = nonFileDiagnostics.slice();
                    }
                    diagnostics = nonFileDiagnostics;
                }
                insertSorted(diagnostics, diagnostic, compareDiagnosticsSkipRelatedInformation);
            }
            function getGlobalDiagnostics() {
                hasReadNonFileDiagnostics = true;
                return nonFileDiagnostics;
            }
            function getDiagnostics2(fileName) {
                if (fileName) {
                    return fileDiagnostics.get(fileName) || [];
                }
                const fileDiags = flatMapToMutable(filesWithDiagnostics, (f) => fileDiagnostics.get(f));
                if (!nonFileDiagnostics.length) {
                    return fileDiags;
                }
                fileDiags.unshift(...nonFileDiagnostics);
                return fileDiags;
            }
        }
        function escapeTemplateSubstitution(str) {
            return str.replace(templateSubstitutionRegExp, "\\${");
        }
        function containsInvalidEscapeFlag(node) {
            return !!((node.templateFlags || 0) & 2048 /* ContainsInvalidEscape */);
        }
        function hasInvalidEscape(template) {
            return template && !!(isNoSubstitutionTemplateLiteral(template) ? containsInvalidEscapeFlag(template) : containsInvalidEscapeFlag(template.head) || some(template.templateSpans, (span) => containsInvalidEscapeFlag(span.literal)));
        }
        function encodeUtf16EscapeSequence(charCode) {
            const hexCharCode = charCode.toString(16).toUpperCase();
            const paddedHexCode = ("0000" + hexCharCode).slice(-4);
            return "\\u" + paddedHexCode;
        }
        function getReplacement(c, offset, input) {
            if (c.charCodeAt(0) === 0 /* nullCharacter */) {
                const lookAhead = input.charCodeAt(offset + c.length);
                if (lookAhead >= 48 /* _0 */ && lookAhead <= 57 /* _9 */) {
                    return "\\x00";
                }
                return "\\0";
            }
            return escapedCharsMap.get(c) || encodeUtf16EscapeSequence(c.charCodeAt(0));
        }
        function escapeString(s, quoteChar) {
            const escapedCharsRegExp = quoteChar === 96 /* backtick */ ? backtickQuoteEscapedCharsRegExp : quoteChar === 39 /* singleQuote */ ? singleQuoteEscapedCharsRegExp : doubleQuoteEscapedCharsRegExp;
            return s.replace(escapedCharsRegExp, getReplacement);
        }
        function escapeNonAsciiString(s, quoteChar) {
            s = escapeString(s, quoteChar);
            return nonAsciiCharacters.test(s) ? s.replace(nonAsciiCharacters, (c) => encodeUtf16EscapeSequence(c.charCodeAt(0))) : s;
        }
        function encodeJsxCharacterEntity(charCode) {
            const hexCharCode = charCode.toString(16).toUpperCase();
            return "&#x" + hexCharCode + ";";
        }
        function getJsxAttributeStringReplacement(c) {
            if (c.charCodeAt(0) === 0 /* nullCharacter */) {
                return "&#0;";
            }
            return jsxEscapedCharsMap.get(c) || encodeJsxCharacterEntity(c.charCodeAt(0));
        }
        function escapeJsxAttributeString(s, quoteChar) {
            const escapedCharsRegExp = quoteChar === 39 /* singleQuote */ ? jsxSingleQuoteEscapedCharsRegExp : jsxDoubleQuoteEscapedCharsRegExp;
            return s.replace(escapedCharsRegExp, getJsxAttributeStringReplacement);
        }
        function stripQuotes(name) {
            const length2 = name.length;
            if (length2 >= 2 && name.charCodeAt(0) === name.charCodeAt(length2 - 1) && isQuoteOrBacktick(name.charCodeAt(0))) {
                return name.substring(1, length2 - 1);
            }
            return name;
        }
        function isQuoteOrBacktick(charCode) {
            return charCode === 39 /* singleQuote */ || charCode === 34 /* doubleQuote */ || charCode === 96 /* backtick */;
        }
        function isIntrinsicJsxName(name) {
            const ch = name.charCodeAt(0);
            return ch >= 97 /* a */ && ch <= 122 /* z */ || name.includes("-");
        }
        function getIndentString(level) {
            const singleLevel = indentStrings[1];
            for (let current = indentStrings.length; current <= level; current++) {
                indentStrings.push(indentStrings[current - 1] + singleLevel);
            }
            return indentStrings[level];
        }
        function getIndentSize() {
            return indentStrings[1].length;
        }
        function createTextWriter(newLine) {
            var output;
            var indent3;
            var lineStart;
            var lineCount;
            var linePos;
            var hasTrailingComment = false;
            function updateLineCountAndPosFor(s) {
                const lineStartsOfS = computeLineStarts(s);
                if (lineStartsOfS.length > 1) {
                    lineCount = lineCount + lineStartsOfS.length - 1;
                    linePos = output.length - s.length + last(lineStartsOfS);
                    lineStart = linePos - output.length === 0;
                }
                else {
                    lineStart = false;
                }
            }
            function writeText(s) {
                if (s && s.length) {
                    if (lineStart) {
                        s = getIndentString(indent3) + s;
                        lineStart = false;
                    }
                    output += s;
                    updateLineCountAndPosFor(s);
                }
            }
            function write(s) {
                if (s)
                    hasTrailingComment = false;
                writeText(s);
            }
            function writeComment(s) {
                if (s)
                    hasTrailingComment = true;
                writeText(s);
            }
            function reset2() {
                output = "";
                indent3 = 0;
                lineStart = true;
                lineCount = 0;
                linePos = 0;
                hasTrailingComment = false;
            }
            function rawWrite(s) {
                if (s !== void 0) {
                    output += s;
                    updateLineCountAndPosFor(s);
                    hasTrailingComment = false;
                }
            }
            function writeLiteral(s) {
                if (s && s.length) {
                    write(s);
                }
            }
            function writeLine(force) {
                if (!lineStart || force) {
                    output += newLine;
                    lineCount++;
                    linePos = output.length;
                    lineStart = true;
                    hasTrailingComment = false;
                }
            }
            function getTextPosWithWriteLine() {
                return lineStart ? output.length : output.length + newLine.length;
            }
            reset2();
            return {
                write,
                rawWrite,
                writeLiteral,
                writeLine,
                increaseIndent: () => {
                    indent3++;
                },
                decreaseIndent: () => {
                    indent3--;
                },
                getIndent: () => indent3,
                getTextPos: () => output.length,
                getLine: () => lineCount,
                getColumn: () => lineStart ? indent3 * getIndentSize() : output.length - linePos,
                getText: () => output,
                isAtStartOfLine: () => lineStart,
                hasTrailingComment: () => hasTrailingComment,
                hasTrailingWhitespace: () => !!output.length && isWhiteSpaceLike(output.charCodeAt(output.length - 1)),
                clear: reset2,
                writeKeyword: write,
                writeOperator: write,
                writeParameter: write,
                writeProperty: write,
                writePunctuation: write,
                writeSpace: write,
                writeStringLiteral: write,
                writeSymbol: (s, _) => write(s),
                writeTrailingSemicolon: write,
                writeComment,
                getTextPosWithWriteLine
            };
        }
        function getTrailingSemicolonDeferringWriter(writer) {
            let pendingTrailingSemicolon = false;
            function commitPendingTrailingSemicolon() {
                if (pendingTrailingSemicolon) {
                    writer.writeTrailingSemicolon(";");
                    pendingTrailingSemicolon = false;
                }
            }
            return {
                ...writer,
                writeTrailingSemicolon() {
                    pendingTrailingSemicolon = true;
                },
                writeLiteral(s) {
                    commitPendingTrailingSemicolon();
                    writer.writeLiteral(s);
                },
                writeStringLiteral(s) {
                    commitPendingTrailingSemicolon();
                    writer.writeStringLiteral(s);
                },
                writeSymbol(s, sym) {
                    commitPendingTrailingSemicolon();
                    writer.writeSymbol(s, sym);
                },
                writePunctuation(s) {
                    commitPendingTrailingSemicolon();
                    writer.writePunctuation(s);
                },
                writeKeyword(s) {
                    commitPendingTrailingSemicolon();
                    writer.writeKeyword(s);
                },
                writeOperator(s) {
                    commitPendingTrailingSemicolon();
                    writer.writeOperator(s);
                },
                writeParameter(s) {
                    commitPendingTrailingSemicolon();
                    writer.writeParameter(s);
                },
                writeSpace(s) {
                    commitPendingTrailingSemicolon();
                    writer.writeSpace(s);
                },
                writeProperty(s) {
                    commitPendingTrailingSemicolon();
                    writer.writeProperty(s);
                },
                writeComment(s) {
                    commitPendingTrailingSemicolon();
                    writer.writeComment(s);
                },
                writeLine() {
                    commitPendingTrailingSemicolon();
                    writer.writeLine();
                },
                increaseIndent() {
                    commitPendingTrailingSemicolon();
                    writer.increaseIndent();
                },
                decreaseIndent() {
                    commitPendingTrailingSemicolon();
                    writer.decreaseIndent();
                }
            };
        }
        function hostUsesCaseSensitiveFileNames(host) {
            return host.useCaseSensitiveFileNames ? host.useCaseSensitiveFileNames() : false;
        }
        function hostGetCanonicalFileName(host) {
            return createGetCanonicalFileName(hostUsesCaseSensitiveFileNames(host));
        }
        function getResolvedExternalModuleName(host, file, referenceFile) {
            return file.moduleName || getExternalModuleNameFromPath(host, file.fileName, referenceFile && referenceFile.fileName);
        }
        function getCanonicalAbsolutePath(host, path) {
            return host.getCanonicalFileName(getNormalizedAbsolutePath(path, host.getCurrentDirectory()));
        }
        function getExternalModuleNameFromDeclaration(host, resolver, declaration) {
            const file = resolver.getExternalModuleFileFromDeclaration(declaration);
            if (!file || file.isDeclarationFile) {
                return void 0;
            }
            const specifier = getExternalModuleName(declaration);
            if (specifier && isStringLiteralLike(specifier) && !pathIsRelative(specifier.text) && !getCanonicalAbsolutePath(host, file.path).includes(getCanonicalAbsolutePath(host, ensureTrailingDirectorySeparator(host.getCommonSourceDirectory())))) {
                return void 0;
            }
            return getResolvedExternalModuleName(host, file);
        }
        function getExternalModuleNameFromPath(host, fileName, referencePath) {
            const getCanonicalFileName = (f) => host.getCanonicalFileName(f);
            const dir = toPath(referencePath ? getDirectoryPath(referencePath) : host.getCommonSourceDirectory(), host.getCurrentDirectory(), getCanonicalFileName);
            const filePath = getNormalizedAbsolutePath(fileName, host.getCurrentDirectory());
            const relativePath = getRelativePathToDirectoryOrUrl(dir, filePath, dir, getCanonicalFileName, 
            /*isAbsolutePathAnUrl*/
            false);
            const extensionless = removeFileExtension(relativePath);
            return referencePath ? ensurePathIsNonModuleName(extensionless) : extensionless;
        }
        function getOwnEmitOutputFilePath(fileName, host, extension) {
            const compilerOptions = host.getCompilerOptions();
            let emitOutputFilePathWithoutExtension;
            if (compilerOptions.outDir) {
                emitOutputFilePathWithoutExtension = removeFileExtension(getSourceFilePathInNewDir(fileName, host, compilerOptions.outDir));
            }
            else {
                emitOutputFilePathWithoutExtension = removeFileExtension(fileName);
            }
            return emitOutputFilePathWithoutExtension + extension;
        }
        function getDeclarationEmitOutputFilePath(fileName, host) {
            return getDeclarationEmitOutputFilePathWorker(fileName, host.getCompilerOptions(), host.getCurrentDirectory(), host.getCommonSourceDirectory(), (f) => host.getCanonicalFileName(f));
        }
        function getDeclarationEmitOutputFilePathWorker(fileName, options, currentDirectory, commonSourceDirectory, getCanonicalFileName) {
            const outputDir = options.declarationDir || options.outDir;
            const path = outputDir ? getSourceFilePathInNewDirWorker(fileName, outputDir, currentDirectory, commonSourceDirectory, getCanonicalFileName) : fileName;
            const declarationExtension = getDeclarationEmitExtensionForPath(path);
            return removeFileExtension(path) + declarationExtension;
        }
        function getDeclarationEmitExtensionForPath(path) {
            return fileExtensionIsOneOf(path, [".mjs" /* Mjs */, ".mts" /* Mts */]) ? ".d.mts" /* Dmts */ : fileExtensionIsOneOf(path, [".cjs" /* Cjs */, ".cts" /* Cts */]) ? ".d.cts" /* Dcts */ : fileExtensionIsOneOf(path, [".json" /* Json */]) ? `.d.json.ts` : (
            // Drive-by redefinition of json declaration file output name so if it's ever enabled, it behaves well
            ".d.ts" /* Dts */);
        }
        function getPossibleOriginalInputExtensionForExtension(path) {
            return fileExtensionIsOneOf(path, [".d.mts" /* Dmts */, ".mjs" /* Mjs */, ".mts" /* Mts */]) ? [".mts" /* Mts */, ".mjs" /* Mjs */] : fileExtensionIsOneOf(path, [".d.cts" /* Dcts */, ".cjs" /* Cjs */, ".cts" /* Cts */]) ? [".cts" /* Cts */, ".cjs" /* Cjs */] : fileExtensionIsOneOf(path, [`.d.json.ts`]) ? [".json" /* Json */] : [".tsx" /* Tsx */, ".ts" /* Ts */, ".jsx" /* Jsx */, ".js" /* Js */];
        }
        function outFile(options) {
            return options.outFile || options.out;
        }
        function getPathsBasePath(options, host) {
            var _a;
            if (!options.paths)
                return void 0;
            return options.baseUrl ?? Debug.checkDefined(options.pathsBasePath || ((_a = host.getCurrentDirectory) == null ? void 0 : _a.call(host)), "Encountered 'paths' without a 'baseUrl', config file, or host 'getCurrentDirectory'.");
        }
        function getSourceFilesToEmit(host, targetSourceFile, forceDtsEmit) {
            const options = host.getCompilerOptions();
            if (outFile(options)) {
                const moduleKind = getEmitModuleKind(options);
                const moduleEmitEnabled = options.emitDeclarationOnly || moduleKind === 2 /* AMD */ || moduleKind === 4 /* System */;
                return filter(host.getSourceFiles(), (sourceFile) => (moduleEmitEnabled || !isExternalModule(sourceFile)) && sourceFileMayBeEmitted(sourceFile, host, forceDtsEmit));
            }
            else {
                const sourceFiles = targetSourceFile === void 0 ? host.getSourceFiles() : [targetSourceFile];
                return filter(sourceFiles, (sourceFile) => sourceFileMayBeEmitted(sourceFile, host, forceDtsEmit));
            }
        }
        function sourceFileMayBeEmitted(sourceFile, host, forceDtsEmit) {
            const options = host.getCompilerOptions();
            if (options.noEmitForJsFiles && isSourceFileJS(sourceFile))
                return false;
            if (sourceFile.isDeclarationFile)
                return false;
            if (host.isSourceFileFromExternalLibrary(sourceFile))
                return false;
            if (forceDtsEmit)
                return true;
            if (host.isSourceOfProjectReferenceRedirect(sourceFile.fileName))
                return false;
            if (!isJsonSourceFile(sourceFile))
                return true;
            if (host.getResolvedProjectReferenceToRedirect(sourceFile.fileName))
                return false;
            if (outFile(options))
                return true;
            if (!options.outDir)
                return false;
            if (options.rootDir || options.composite && options.configFilePath) {
                const commonDir = getNormalizedAbsolutePath(getCommonSourceDirectory(options, () => [], host.getCurrentDirectory(), host.getCanonicalFileName), host.getCurrentDirectory());
                const outputPath = getSourceFilePathInNewDirWorker(sourceFile.fileName, options.outDir, host.getCurrentDirectory(), commonDir, host.getCanonicalFileName);
                if (comparePaths(sourceFile.fileName, outputPath, host.getCurrentDirectory(), !host.useCaseSensitiveFileNames()) === 0 /* EqualTo */)
                    return false;
            }
            return true;
        }
        function getSourceFilePathInNewDir(fileName, host, newDirPath) {
            return getSourceFilePathInNewDirWorker(fileName, newDirPath, host.getCurrentDirectory(), host.getCommonSourceDirectory(), (f) => host.getCanonicalFileName(f));
        }
        function getSourceFilePathInNewDirWorker(fileName, newDirPath, currentDirectory, commonSourceDirectory, getCanonicalFileName) {
            let sourceFilePath = getNormalizedAbsolutePath(fileName, currentDirectory);
            const isSourceFileInCommonSourceDirectory = getCanonicalFileName(sourceFilePath).indexOf(getCanonicalFileName(commonSourceDirectory)) === 0;
            sourceFilePath = isSourceFileInCommonSourceDirectory ? sourceFilePath.substring(commonSourceDirectory.length) : sourceFilePath;
            return combinePaths(newDirPath, sourceFilePath);
        }
        function writeFile(host, diagnostics, fileName, text, writeByteOrderMark, sourceFiles, data) {
            host.writeFile(fileName, text, writeByteOrderMark, (hostErrorMessage) => {
                diagnostics.add(createCompilerDiagnostic(Diagnostics.Could_not_write_file_0_Colon_1, fileName, hostErrorMessage));
            }, sourceFiles, data);
        }
        function ensureDirectoriesExist(directoryPath, createDirectory, directoryExists) {
            if (directoryPath.length > getRootLength(directoryPath) && !directoryExists(directoryPath)) {
                const parentDirectory = getDirectoryPath(directoryPath);
                ensureDirectoriesExist(parentDirectory, createDirectory, directoryExists);
                createDirectory(directoryPath);
            }
        }
        function writeFileEnsuringDirectories(path, data, writeByteOrderMark, writeFile2, createDirectory, directoryExists) {
            try {
                writeFile2(path, data, writeByteOrderMark);
            }
            catch {
                ensureDirectoriesExist(getDirectoryPath(normalizePath(path)), createDirectory, directoryExists);
                writeFile2(path, data, writeByteOrderMark);
            }
        }
        function getLineOfLocalPosition(sourceFile, pos) {
            const lineStarts = getLineStarts(sourceFile);
            return computeLineOfPosition(lineStarts, pos);
        }
        function getLineOfLocalPositionFromLineMap(lineMap, pos) {
            return computeLineOfPosition(lineMap, pos);
        }
        function getFirstConstructorWithBody(node) {
            return find(node.members, (member) => isConstructorDeclaration(member) && nodeIsPresent(member.body));
        }
        function getSetAccessorValueParameter(accessor) {
            if (accessor && accessor.parameters.length > 0) {
                const hasThis = accessor.parameters.length === 2 && parameterIsThisKeyword(accessor.parameters[0]);
                return accessor.parameters[hasThis ? 1 : 0];
            }
        }
        function getSetAccessorTypeAnnotationNode(accessor) {
            const parameter = getSetAccessorValueParameter(accessor);
            return parameter && parameter.type;
        }
        function getThisParameter(signature) {
            if (signature.parameters.length && !isJSDocSignature(signature)) {
                const thisParameter = signature.parameters[0];
                if (parameterIsThisKeyword(thisParameter)) {
                    return thisParameter;
                }
            }
        }
        function parameterIsThisKeyword(parameter) {
            return isThisIdentifier(parameter.name);
        }
        function isThisIdentifier(node) {
            return !!node && node.kind === 80 /* Identifier */ && identifierIsThisKeyword(node);
        }
        function isInTypeQuery(node) {
            return !!findAncestor(node, (n) => n.kind === 186 /* TypeQuery */ ? true : n.kind === 80 /* Identifier */ || n.kind === 166 /* QualifiedName */ ? false : "quit");
        }
        function isThisInTypeQuery(node) {
            if (!isThisIdentifier(node)) {
                return false;
            }
            while (isQualifiedName(node.parent) && node.parent.left === node) {
                node = node.parent;
            }
            return node.parent.kind === 186 /* TypeQuery */;
        }
        function identifierIsThisKeyword(id) {
            return id.escapedText === "this";
        }
        function getAllAccessorDeclarations(declarations, accessor) {
            let firstAccessor;
            let secondAccessor;
            let getAccessor;
            let setAccessor;
            if (hasDynamicName(accessor)) {
                firstAccessor = accessor;
                if (accessor.kind === 177 /* GetAccessor */) {
                    getAccessor = accessor;
                }
                else if (accessor.kind === 178 /* SetAccessor */) {
                    setAccessor = accessor;
                }
                else {
                    Debug.fail("Accessor has wrong kind");
                }
            }
            else {
                forEach(declarations, (member) => {
                    if (isAccessor(member) && isStatic(member) === isStatic(accessor)) {
                        const memberName = getPropertyNameForPropertyNameNode(member.name);
                        const accessorName = getPropertyNameForPropertyNameNode(accessor.name);
                        if (memberName === accessorName) {
                            if (!firstAccessor) {
                                firstAccessor = member;
                            }
                            else if (!secondAccessor) {
                                secondAccessor = member;
                            }
                            if (member.kind === 177 /* GetAccessor */ && !getAccessor) {
                                getAccessor = member;
                            }
                            if (member.kind === 178 /* SetAccessor */ && !setAccessor) {
                                setAccessor = member;
                            }
                        }
                    }
                });
            }
            return {
                firstAccessor,
                secondAccessor,
                getAccessor,
                setAccessor
            };
        }
        function getEffectiveTypeAnnotationNode(node) {
            if (!isInJSFile(node) && isFunctionDeclaration(node))
                return void 0;
            const type = node.type;
            if (type || !isInJSFile(node))
                return type;
            return isJSDocPropertyLikeTag(node) ? node.typeExpression && node.typeExpression.type : getJSDocType(node);
        }
        function getTypeAnnotationNode(node) {
            return node.type;
        }
        function getEffectiveReturnTypeNode(node) {
            return isJSDocSignature(node) ? node.type && node.type.typeExpression && node.type.typeExpression.type : node.type || (isInJSFile(node) ? getJSDocReturnType(node) : void 0);
        }
        function getJSDocTypeParameterDeclarations(node) {
            return flatMap(getJSDocTags(node), (tag) => isNonTypeAliasTemplate(tag) ? tag.typeParameters : void 0);
        }
        function isNonTypeAliasTemplate(tag) {
            return isJSDocTemplateTag(tag) && !(tag.parent.kind === 327 /* JSDoc */ && (tag.parent.tags.some(isJSDocTypeAlias) || tag.parent.tags.some(isJSDocOverloadTag)));
        }
        function getEffectiveSetAccessorTypeAnnotationNode(node) {
            const parameter = getSetAccessorValueParameter(node);
            return parameter && getEffectiveTypeAnnotationNode(parameter);
        }
        function emitNewLineBeforeLeadingComments(lineMap, writer, node, leadingComments) {
            emitNewLineBeforeLeadingCommentsOfPosition(lineMap, writer, node.pos, leadingComments);
        }
        function emitNewLineBeforeLeadingCommentsOfPosition(lineMap, writer, pos, leadingComments) {
            if (leadingComments && leadingComments.length && pos !== leadingComments[0].pos && getLineOfLocalPositionFromLineMap(lineMap, pos) !== getLineOfLocalPositionFromLineMap(lineMap, leadingComments[0].pos)) {
                writer.writeLine();
            }
        }
        function emitNewLineBeforeLeadingCommentOfPosition(lineMap, writer, pos, commentPos) {
            if (pos !== commentPos && getLineOfLocalPositionFromLineMap(lineMap, pos) !== getLineOfLocalPositionFromLineMap(lineMap, commentPos)) {
                writer.writeLine();
            }
        }
        function emitComments(text, lineMap, writer, comments, leadingSeparator, trailingSeparator, newLine, writeComment) {
            if (comments && comments.length > 0) {
                if (leadingSeparator) {
                    writer.writeSpace(" ");
                }
                let emitInterveningSeparator = false;
                for (const comment of comments) {
                    if (emitInterveningSeparator) {
                        writer.writeSpace(" ");
                        emitInterveningSeparator = false;
                    }
                    writeComment(text, lineMap, writer, comment.pos, comment.end, newLine);
                    if (comment.hasTrailingNewLine) {
                        writer.writeLine();
                    }
                    else {
                        emitInterveningSeparator = true;
                    }
                }
                if (emitInterveningSeparator && trailingSeparator) {
                    writer.writeSpace(" ");
                }
            }
        }
        function emitDetachedComments(text, lineMap, writer, writeComment, node, newLine, removeComments) {
            let leadingComments;
            let currentDetachedCommentInfo;
            if (removeComments) {
                if (node.pos === 0) {
                    leadingComments = filter(getLeadingCommentRanges(text, node.pos), isPinnedCommentLocal);
                }
            }
            else {
                leadingComments = getLeadingCommentRanges(text, node.pos);
            }
            if (leadingComments) {
                const detachedComments = [];
                let lastComment;
                for (const comment of leadingComments) {
                    if (lastComment) {
                        const lastCommentLine = getLineOfLocalPositionFromLineMap(lineMap, lastComment.end);
                        const commentLine = getLineOfLocalPositionFromLineMap(lineMap, comment.pos);
                        if (commentLine >= lastCommentLine + 2) {
                            break;
                        }
                    }
                    detachedComments.push(comment);
                    lastComment = comment;
                }
                if (detachedComments.length) {
                    const lastCommentLine = getLineOfLocalPositionFromLineMap(lineMap, last(detachedComments).end);
                    const nodeLine = getLineOfLocalPositionFromLineMap(lineMap, skipTrivia(text, node.pos));
                    if (nodeLine >= lastCommentLine + 2) {
                        emitNewLineBeforeLeadingComments(lineMap, writer, node, leadingComments);
                        emitComments(text, lineMap, writer, detachedComments, 
                        /*leadingSeparator*/
                        false, 
                        /*trailingSeparator*/
                        true, newLine, writeComment);
                        currentDetachedCommentInfo = { nodePos: node.pos, detachedCommentEndPos: last(detachedComments).end };
                    }
                }
            }
            return currentDetachedCommentInfo;
            function isPinnedCommentLocal(comment) {
                return isPinnedComment(text, comment.pos);
            }
        }
        function writeCommentRange(text, lineMap, writer, commentPos, commentEnd, newLine) {
            if (text.charCodeAt(commentPos + 1) === 42 /* asterisk */) {
                const firstCommentLineAndCharacter = computeLineAndCharacterOfPosition(lineMap, commentPos);
                const lineCount = lineMap.length;
                let firstCommentLineIndent;
                for (let pos = commentPos, currentLine = firstCommentLineAndCharacter.line; pos < commentEnd; currentLine++) {
                    const nextLineStart = currentLine + 1 === lineCount ? text.length + 1 : lineMap[currentLine + 1];
                    if (pos !== commentPos) {
                        if (firstCommentLineIndent === void 0) {
                            firstCommentLineIndent = calculateIndent(text, lineMap[firstCommentLineAndCharacter.line], commentPos);
                        }
                        const currentWriterIndentSpacing = writer.getIndent() * getIndentSize();
                        const spacesToEmit = currentWriterIndentSpacing - firstCommentLineIndent + calculateIndent(text, pos, nextLineStart);
                        if (spacesToEmit > 0) {
                            let numberOfSingleSpacesToEmit = spacesToEmit % getIndentSize();
                            const indentSizeSpaceString = getIndentString((spacesToEmit - numberOfSingleSpacesToEmit) / getIndentSize());
                            writer.rawWrite(indentSizeSpaceString);
                            while (numberOfSingleSpacesToEmit) {
                                writer.rawWrite(" ");
                                numberOfSingleSpacesToEmit--;
                            }
                        }
                        else {
                            writer.rawWrite("");
                        }
                    }
                    writeTrimmedCurrentLine(text, commentEnd, writer, newLine, pos, nextLineStart);
                    pos = nextLineStart;
                }
            }
            else {
                writer.writeComment(text.substring(commentPos, commentEnd));
            }
        }
        function writeTrimmedCurrentLine(text, commentEnd, writer, newLine, pos, nextLineStart) {
            const end = Math.min(commentEnd, nextLineStart - 1);
            const currentLineText = text.substring(pos, end).trim();
            if (currentLineText) {
                writer.writeComment(currentLineText);
                if (end !== commentEnd) {
                    writer.writeLine();
                }
            }
            else {
                writer.rawWrite(newLine);
            }
        }
        function calculateIndent(text, pos, end) {
            let currentLineIndent = 0;
            for (; pos < end && isWhiteSpaceSingleLine(text.charCodeAt(pos)); pos++) {
                if (text.charCodeAt(pos) === 9 /* tab */) {
                    currentLineIndent += getIndentSize() - currentLineIndent % getIndentSize();
                }
                else {
                    currentLineIndent++;
                }
            }
            return currentLineIndent;
        }
        function hasEffectiveModifiers(node) {
            return getEffectiveModifierFlags(node) !== 0 /* None */;
        }
        function hasSyntacticModifiers(node) {
            return getSyntacticModifierFlags(node) !== 0 /* None */;
        }
        function hasEffectiveModifier(node, flags) {
            return !!getSelectedEffectiveModifierFlags(node, flags);
        }
        function hasSyntacticModifier(node, flags) {
            return !!getSelectedSyntacticModifierFlags(node, flags);
        }
        function isStatic(node) {
            return isClassElement(node) && hasStaticModifier(node) || isClassStaticBlockDeclaration(node);
        }
        function hasStaticModifier(node) {
            return hasSyntacticModifier(node, 256 /* Static */);
        }
        function hasOverrideModifier(node) {
            return hasEffectiveModifier(node, 16 /* Override */);
        }
        function hasAbstractModifier(node) {
            return hasSyntacticModifier(node, 64 /* Abstract */);
        }
        function hasAmbientModifier(node) {
            return hasSyntacticModifier(node, 128 /* Ambient */);
        }
        function hasAccessorModifier(node) {
            return hasSyntacticModifier(node, 512 /* Accessor */);
        }
        function hasEffectiveReadonlyModifier(node) {
            return hasEffectiveModifier(node, 8 /* Readonly */);
        }
        function hasDecorators(node) {
            return hasSyntacticModifier(node, 32768 /* Decorator */);
        }
        function getSelectedEffectiveModifierFlags(node, flags) {
            return getEffectiveModifierFlags(node) & flags;
        }
        function getSelectedSyntacticModifierFlags(node, flags) {
            return getSyntacticModifierFlags(node) & flags;
        }
        function getModifierFlagsWorker(node, includeJSDoc, alwaysIncludeJSDoc) {
            if (node.kind >= 0 /* FirstToken */ && node.kind <= 165 /* LastToken */) {
                return 0 /* None */;
            }
            if (!(node.modifierFlagsCache & 536870912 /* HasComputedFlags */)) {
                node.modifierFlagsCache = getSyntacticModifierFlagsNoCache(node) | 536870912 /* HasComputedFlags */;
            }
            if (alwaysIncludeJSDoc || includeJSDoc && isInJSFile(node)) {
                if (!(node.modifierFlagsCache & 268435456 /* HasComputedJSDocModifiers */) && node.parent) {
                    node.modifierFlagsCache |= getRawJSDocModifierFlagsNoCache(node) | 268435456 /* HasComputedJSDocModifiers */;
                }
                return selectEffectiveModifierFlags(node.modifierFlagsCache);
            }
            return selectSyntacticModifierFlags(node.modifierFlagsCache);
        }
        function getEffectiveModifierFlags(node) {
            return getModifierFlagsWorker(node, 
            /*includeJSDoc*/
            true);
        }
        function getEffectiveModifierFlagsAlwaysIncludeJSDoc(node) {
            return getModifierFlagsWorker(node, 
            /*includeJSDoc*/
            true, 
            /*alwaysIncludeJSDoc*/
            true);
        }
        function getSyntacticModifierFlags(node) {
            return getModifierFlagsWorker(node, 
            /*includeJSDoc*/
            false);
        }
        function getRawJSDocModifierFlagsNoCache(node) {
            let flags = 0 /* None */;
            if (!!node.parent && !isParameter(node)) {
                if (isInJSFile(node)) {
                    if (getJSDocPublicTagNoCache(node))
                        flags |= 8388608 /* JSDocPublic */;
                    if (getJSDocPrivateTagNoCache(node))
                        flags |= 16777216 /* JSDocPrivate */;
                    if (getJSDocProtectedTagNoCache(node))
                        flags |= 33554432 /* JSDocProtected */;
                    if (getJSDocReadonlyTagNoCache(node))
                        flags |= 67108864 /* JSDocReadonly */;
                    if (getJSDocOverrideTagNoCache(node))
                        flags |= 134217728 /* JSDocOverride */;
                }
                if (getJSDocDeprecatedTagNoCache(node))
                    flags |= 65536 /* Deprecated */;
            }
            return flags;
        }
        function selectSyntacticModifierFlags(flags) {
            return flags & 65535 /* SyntacticModifiers */;
        }
        function selectEffectiveModifierFlags(flags) {
            return flags & 131071 /* NonCacheOnlyModifiers */ | (flags & 260046848 /* JSDocCacheOnlyModifiers */) >>> 23;
        }
        function getJSDocModifierFlagsNoCache(node) {
            return selectEffectiveModifierFlags(getRawJSDocModifierFlagsNoCache(node));
        }
        function getEffectiveModifierFlagsNoCache(node) {
            return getSyntacticModifierFlagsNoCache(node) | getJSDocModifierFlagsNoCache(node);
        }
        function getSyntacticModifierFlagsNoCache(node) {
            let flags = canHaveModifiers(node) ? modifiersToFlags(node.modifiers) : 0 /* None */;
            if (node.flags & 8 /* NestedNamespace */ || node.kind === 80 /* Identifier */ && node.flags & 4096 /* IdentifierIsInJSDocNamespace */) {
                flags |= 32 /* Export */;
            }
            return flags;
        }
        function modifiersToFlags(modifiers) {
            let flags = 0 /* None */;
            if (modifiers) {
                for (const modifier of modifiers) {
                    flags |= modifierToFlag(modifier.kind);
                }
            }
            return flags;
        }
        function modifierToFlag(token) {
            switch (token) {
                case 126 /* StaticKeyword */:
                    return 256 /* Static */;
                case 125 /* PublicKeyword */:
                    return 1 /* Public */;
                case 124 /* ProtectedKeyword */:
                    return 4 /* Protected */;
                case 123 /* PrivateKeyword */:
                    return 2 /* Private */;
                case 128 /* AbstractKeyword */:
                    return 64 /* Abstract */;
                case 129 /* AccessorKeyword */:
                    return 512 /* Accessor */;
                case 95 /* ExportKeyword */:
                    return 32 /* Export */;
                case 138 /* DeclareKeyword */:
                    return 128 /* Ambient */;
                case 87 /* ConstKeyword */:
                    return 4096 /* Const */;
                case 90 /* DefaultKeyword */:
                    return 2048 /* Default */;
                case 134 /* AsyncKeyword */:
                    return 1024 /* Async */;
                case 148 /* ReadonlyKeyword */:
                    return 8 /* Readonly */;
                case 164 /* OverrideKeyword */:
                    return 16 /* Override */;
                case 103 /* InKeyword */:
                    return 8192 /* In */;
                case 147 /* OutKeyword */:
                    return 16384 /* Out */;
                case 170 /* Decorator */:
                    return 32768 /* Decorator */;
            }
            return 0 /* None */;
        }
        function isBinaryLogicalOperator(token) {
            return token === 57 /* BarBarToken */ || token === 56 /* AmpersandAmpersandToken */;
        }
        function isLogicalOperator(token) {
            return isBinaryLogicalOperator(token) || token === 54 /* ExclamationToken */;
        }
        function isLogicalOrCoalescingAssignmentOperator(token) {
            return token === 76 /* BarBarEqualsToken */ || token === 77 /* AmpersandAmpersandEqualsToken */ || token === 78 /* QuestionQuestionEqualsToken */;
        }
        function isLogicalOrCoalescingAssignmentExpression(expr) {
            return isBinaryExpression(expr) && isLogicalOrCoalescingAssignmentOperator(expr.operatorToken.kind);
        }
        function isLogicalOrCoalescingBinaryOperator(token) {
            return isBinaryLogicalOperator(token) || token === 61 /* QuestionQuestionToken */;
        }
        function isLogicalOrCoalescingBinaryExpression(expr) {
            return isBinaryExpression(expr) && isLogicalOrCoalescingBinaryOperator(expr.operatorToken.kind);
        }
        function isAssignmentOperator(token) {
            return token >= 64 /* FirstAssignment */ && token <= 79 /* LastAssignment */;
        }
        function tryGetClassExtendingExpressionWithTypeArguments(node) {
            const cls = tryGetClassImplementingOrExtendingExpressionWithTypeArguments(node);
            return cls && !cls.isImplements ? cls.class : void 0;
        }
        function tryGetClassImplementingOrExtendingExpressionWithTypeArguments(node) {
            if (isExpressionWithTypeArguments(node)) {
                if (isHeritageClause(node.parent) && isClassLike(node.parent.parent)) {
                    return { class: node.parent.parent, isImplements: node.parent.token === 119 /* ImplementsKeyword */ };
                }
                if (isJSDocAugmentsTag(node.parent)) {
                    const host = getEffectiveJSDocHost(node.parent);
                    if (host && isClassLike(host)) {
                        return { class: host, isImplements: false };
                    }
                }
            }
            return void 0;
        }
        function isAssignmentExpression(node, excludeCompoundAssignment) {
            return isBinaryExpression(node) && (excludeCompoundAssignment ? node.operatorToken.kind === 64 /* EqualsToken */ : isAssignmentOperator(node.operatorToken.kind)) && isLeftHandSideExpression(node.left);
        }
        function isLeftHandSideOfAssignment(node) {
            return isAssignmentExpression(node.parent) && node.parent.left === node;
        }
        function isDestructuringAssignment(node) {
            if (isAssignmentExpression(node, 
            /*excludeCompoundAssignment*/
            true)) {
                const kind = node.left.kind;
                return kind === 210 /* ObjectLiteralExpression */ || kind === 209 /* ArrayLiteralExpression */;
            }
            return false;
        }
        function isExpressionWithTypeArgumentsInClassExtendsClause(node) {
            return tryGetClassExtendingExpressionWithTypeArguments(node) !== void 0;
        }
        function isEntityNameExpression(node) {
            return node.kind === 80 /* Identifier */ || isPropertyAccessEntityNameExpression(node);
        }
        function getFirstIdentifier(node) {
            switch (node.kind) {
                case 80 /* Identifier */:
                    return node;
                case 166 /* QualifiedName */:
                    do {
                        node = node.left;
                    } while (node.kind !== 80 /* Identifier */);
                    return node;
                case 211 /* PropertyAccessExpression */:
                    do {
                        node = node.expression;
                    } while (node.kind !== 80 /* Identifier */);
                    return node;
            }
        }
        function isDottedName(node) {
            return node.kind === 80 /* Identifier */ || node.kind === 110 /* ThisKeyword */ || node.kind === 108 /* SuperKeyword */ || node.kind === 236 /* MetaProperty */ || node.kind === 211 /* PropertyAccessExpression */ && isDottedName(node.expression) || node.kind === 217 /* ParenthesizedExpression */ && isDottedName(node.expression);
        }
        function isPropertyAccessEntityNameExpression(node) {
            return isPropertyAccessExpression(node) && isIdentifier(node.name) && isEntityNameExpression(node.expression);
        }
        function tryGetPropertyAccessOrIdentifierToString(expr) {
            if (isPropertyAccessExpression(expr)) {
                const baseStr = tryGetPropertyAccessOrIdentifierToString(expr.expression);
                if (baseStr !== void 0) {
                    return baseStr + "." + entityNameToString(expr.name);
                }
            }
            else if (isElementAccessExpression(expr)) {
                const baseStr = tryGetPropertyAccessOrIdentifierToString(expr.expression);
                if (baseStr !== void 0 && isPropertyName(expr.argumentExpression)) {
                    return baseStr + "." + getPropertyNameForPropertyNameNode(expr.argumentExpression);
                }
            }
            else if (isIdentifier(expr)) {
                return unescapeLeadingUnderscores(expr.escapedText);
            }
            else if (isJsxNamespacedName(expr)) {
                return getTextOfJsxNamespacedName(expr);
            }
            return void 0;
        }
        function isPrototypeAccess(node) {
            return isBindableStaticAccessExpression(node) && getElementOrPropertyAccessName(node) === "prototype";
        }
        function isRightSideOfQualifiedNameOrPropertyAccess(node) {
            return node.parent.kind === 166 /* QualifiedName */ && node.parent.right === node || node.parent.kind === 211 /* PropertyAccessExpression */ && node.parent.name === node || node.parent.kind === 236 /* MetaProperty */ && node.parent.name === node;
        }
        function isRightSideOfAccessExpression(node) {
            return !!node.parent && (isPropertyAccessExpression(node.parent) && node.parent.name === node || isElementAccessExpression(node.parent) && node.parent.argumentExpression === node);
        }
        function isRightSideOfQualifiedNameOrPropertyAccessOrJSDocMemberName(node) {
            return isQualifiedName(node.parent) && node.parent.right === node || isPropertyAccessExpression(node.parent) && node.parent.name === node || isJSDocMemberName(node.parent) && node.parent.right === node;
        }
        function isInstanceOfExpression(node) {
            return isBinaryExpression(node) && node.operatorToken.kind === 104 /* InstanceOfKeyword */;
        }
        function isRightSideOfInstanceofExpression(node) {
            return isInstanceOfExpression(node.parent) && node === node.parent.right;
        }
        function isEmptyObjectLiteral(expression) {
            return expression.kind === 210 /* ObjectLiteralExpression */ && expression.properties.length === 0;
        }
        function isEmptyArrayLiteral(expression) {
            return expression.kind === 209 /* ArrayLiteralExpression */ && expression.elements.length === 0;
        }
        function getLocalSymbolForExportDefault(symbol) {
            if (!isExportDefaultSymbol(symbol) || !symbol.declarations)
                return void 0;
            for (const decl of symbol.declarations) {
                if (decl.localSymbol)
                    return decl.localSymbol;
            }
            return void 0;
        }
        function isExportDefaultSymbol(symbol) {
            return symbol && length(symbol.declarations) > 0 && hasSyntacticModifier(symbol.declarations[0], 2048 /* Default */);
        }
        function tryExtractTSExtension(fileName) {
            return find(supportedTSExtensionsForExtractExtension, (extension) => fileExtensionIs(fileName, extension));
        }
        function getExpandedCharCodes(input) {
            const output = [];
            const length2 = input.length;
            for (let i = 0; i < length2; i++) {
                const charCode = input.charCodeAt(i);
                if (charCode < 128) {
                    output.push(charCode);
                }
                else if (charCode < 2048) {
                    output.push(charCode >> 6 | 192);
                    output.push(charCode & 63 | 128);
                }
                else if (charCode < 65536) {
                    output.push(charCode >> 12 | 224);
                    output.push(charCode >> 6 & 63 | 128);
                    output.push(charCode & 63 | 128);
                }
                else if (charCode < 131072) {
                    output.push(charCode >> 18 | 240);
                    output.push(charCode >> 12 & 63 | 128);
                    output.push(charCode >> 6 & 63 | 128);
                    output.push(charCode & 63 | 128);
                }
                else {
                    Debug.assert(false, "Unexpected code point");
                }
            }
            return output;
        }
        function convertToBase64(input) {
            let result = "";
            const charCodes = getExpandedCharCodes(input);
            let i = 0;
            const length2 = charCodes.length;
            let byte1, byte2, byte3, byte4;
            while (i < length2) {
                byte1 = charCodes[i] >> 2;
                byte2 = (charCodes[i] & 3) << 4 | charCodes[i + 1] >> 4;
                byte3 = (charCodes[i + 1] & 15) << 2 | charCodes[i + 2] >> 6;
                byte4 = charCodes[i + 2] & 63;
                if (i + 1 >= length2) {
                    byte3 = byte4 = 64;
                }
                else if (i + 2 >= length2) {
                    byte4 = 64;
                }
                result += base64Digits.charAt(byte1) + base64Digits.charAt(byte2) + base64Digits.charAt(byte3) + base64Digits.charAt(byte4);
                i += 3;
            }
            return result;
        }
        function getStringFromExpandedCharCodes(codes) {
            let output = "";
            let i = 0;
            const length2 = codes.length;
            while (i < length2) {
                const charCode = codes[i];
                if (charCode < 128) {
                    output += String.fromCharCode(charCode);
                    i++;
                }
                else if ((charCode & 192) === 192) {
                    let value = charCode & 63;
                    i++;
                    let nextCode = codes[i];
                    while ((nextCode & 192) === 128) {
                        value = value << 6 | nextCode & 63;
                        i++;
                        nextCode = codes[i];
                    }
                    output += String.fromCharCode(value);
                }
                else {
                    output += String.fromCharCode(charCode);
                    i++;
                }
            }
            return output;
        }
        function base64encode(host, input) {
            if (host && host.base64encode) {
                return host.base64encode(input);
            }
            return convertToBase64(input);
        }
        function base64decode(host, input) {
            if (host && host.base64decode) {
                return host.base64decode(input);
            }
            const length2 = input.length;
            const expandedCharCodes = [];
            let i = 0;
            while (i < length2) {
                if (input.charCodeAt(i) === base64Digits.charCodeAt(64)) {
                    break;
                }
                const ch1 = base64Digits.indexOf(input[i]);
                const ch2 = base64Digits.indexOf(input[i + 1]);
                const ch3 = base64Digits.indexOf(input[i + 2]);
                const ch4 = base64Digits.indexOf(input[i + 3]);
                const code1 = (ch1 & 63) << 2 | ch2 >> 4 & 3;
                const code2 = (ch2 & 15) << 4 | ch3 >> 2 & 15;
                const code3 = (ch3 & 3) << 6 | ch4 & 63;
                if (code2 === 0 && ch3 !== 0) {
                    expandedCharCodes.push(code1);
                }
                else if (code3 === 0 && ch4 !== 0) {
                    expandedCharCodes.push(code1, code2);
                }
                else {
                    expandedCharCodes.push(code1, code2, code3);
                }
                i += 4;
            }
            return getStringFromExpandedCharCodes(expandedCharCodes);
        }
        function readJsonOrUndefined(path, hostOrText) {
            const jsonText = isString(hostOrText) ? hostOrText : hostOrText.readFile(path);
            if (!jsonText)
                return void 0;
            const result = parseConfigFileTextToJson(path, jsonText);
            return !result.error ? result.config : void 0;
        }
        function readJson(path, host) {
            return readJsonOrUndefined(path, host) || {};
        }
        function tryParseJson(text) {
            try {
                return JSON.parse(text);
            }
            catch {
                return void 0;
            }
        }
        function directoryProbablyExists(directoryName, host) {
            return !host.directoryExists || host.directoryExists(directoryName);
        }
        function getNewLineCharacter(options) {
            switch (options.newLine) {
                case 0 /* CarriageReturnLineFeed */:
                    return carriageReturnLineFeed;
                case 1 /* LineFeed */:
                case void 0:
                    return lineFeed;
            }
        }
        function createRange(pos, end = pos) {
            Debug.assert(end >= pos || end === -1);
            return { pos, end };
        }
        function moveRangeEnd(range, end) {
            return createRange(range.pos, end);
        }
        function moveRangePos(range, pos) {
            return createRange(pos, range.end);
        }
        function moveRangePastDecorators(node) {
            const lastDecorator = canHaveModifiers(node) ? findLast(node.modifiers, isDecorator) : void 0;
            return lastDecorator && !positionIsSynthesized(lastDecorator.end) ? moveRangePos(node, lastDecorator.end) : node;
        }
        function moveRangePastModifiers(node) {
            if (isPropertyDeclaration(node) || isMethodDeclaration(node)) {
                return moveRangePos(node, node.name.pos);
            }
            const lastModifier = canHaveModifiers(node) ? lastOrUndefined(node.modifiers) : void 0;
            return lastModifier && !positionIsSynthesized(lastModifier.end) ? moveRangePos(node, lastModifier.end) : moveRangePastDecorators(node);
        }
        function isCollapsedRange(range) {
            return range.pos === range.end;
        }
        function createTokenRange(pos, token) {
            return createRange(pos, pos + tokenToString(token).length);
        }
        function rangeIsOnSingleLine(range, sourceFile) {
            return rangeStartIsOnSameLineAsRangeEnd(range, range, sourceFile);
        }
        function rangeStartPositionsAreOnSameLine(range1, range2, sourceFile) {
            return positionsAreOnSameLine(getStartPositionOfRange(range1, sourceFile, 
            /*includeComments*/
            false), getStartPositionOfRange(range2, sourceFile, 
            /*includeComments*/
            false), sourceFile);
        }
        function rangeEndPositionsAreOnSameLine(range1, range2, sourceFile) {
            return positionsAreOnSameLine(range1.end, range2.end, sourceFile);
        }
        function rangeStartIsOnSameLineAsRangeEnd(range1, range2, sourceFile) {
            return positionsAreOnSameLine(getStartPositionOfRange(range1, sourceFile, 
            /*includeComments*/
            false), range2.end, sourceFile);
        }
        function rangeEndIsOnSameLineAsRangeStart(range1, range2, sourceFile) {
            return positionsAreOnSameLine(range1.end, getStartPositionOfRange(range2, sourceFile, 
            /*includeComments*/
            false), sourceFile);
        }
        function getLinesBetweenRangeEndAndRangeStart(range1, range2, sourceFile, includeSecondRangeComments) {
            const range2Start = getStartPositionOfRange(range2, sourceFile, includeSecondRangeComments);
            return getLinesBetweenPositions(sourceFile, range1.end, range2Start);
        }
        function getLinesBetweenRangeEndPositions(range1, range2, sourceFile) {
            return getLinesBetweenPositions(sourceFile, range1.end, range2.end);
        }
        function isNodeArrayMultiLine(list, sourceFile) {
            return !positionsAreOnSameLine(list.pos, list.end, sourceFile);
        }
        function positionsAreOnSameLine(pos1, pos2, sourceFile) {
            return getLinesBetweenPositions(sourceFile, pos1, pos2) === 0;
        }
        function getStartPositionOfRange(range, sourceFile, includeComments) {
            return positionIsSynthesized(range.pos) ? -1 : skipTrivia(sourceFile.text, range.pos, 
            /*stopAfterLineBreak*/
            false, includeComments);
        }
        function getLinesBetweenPositionAndPrecedingNonWhitespaceCharacter(pos, stopPos, sourceFile, includeComments) {
            const startPos = skipTrivia(sourceFile.text, pos, 
            /*stopAfterLineBreak*/
            false, includeComments);
            const prevPos = getPreviousNonWhitespacePosition(startPos, stopPos, sourceFile);
            return getLinesBetweenPositions(sourceFile, prevPos ?? stopPos, startPos);
        }
        function getLinesBetweenPositionAndNextNonWhitespaceCharacter(pos, stopPos, sourceFile, includeComments) {
            const nextPos = skipTrivia(sourceFile.text, pos, 
            /*stopAfterLineBreak*/
            false, includeComments);
            return getLinesBetweenPositions(sourceFile, pos, Math.min(stopPos, nextPos));
        }
        function getPreviousNonWhitespacePosition(pos, stopPos = 0, sourceFile) {
            while (pos-- > stopPos) {
                if (!isWhiteSpaceLike(sourceFile.text.charCodeAt(pos))) {
                    return pos;
                }
            }
        }
        function isDeclarationNameOfEnumOrNamespace(node) {
            const parseNode = getParseTreeNode(node);
            if (parseNode) {
                switch (parseNode.parent.kind) {
                    case 266 /* EnumDeclaration */:
                    case 267 /* ModuleDeclaration */:
                        return parseNode === parseNode.parent.name;
                }
            }
            return false;
        }
        function getInitializedVariables(node) {
            return filter(node.declarations, isInitializedVariable);
        }
        function isInitializedVariable(node) {
            return isVariableDeclaration(node) && node.initializer !== void 0;
        }
        function isWatchSet(options) {
            return options.watch && hasProperty(options, "watch");
        }
        function closeFileWatcher(watcher) {
            watcher.close();
        }
        function getCheckFlags(symbol) {
            return symbol.flags & 33554432 /* Transient */ ? symbol.links.checkFlags : 0;
        }
        function getDeclarationModifierFlagsFromSymbol(s, isWrite = false) {
            if (s.valueDeclaration) {
                const declaration = isWrite && s.declarations && find(s.declarations, isSetAccessorDeclaration) || s.flags & 32768 /* GetAccessor */ && find(s.declarations, isGetAccessorDeclaration) || s.valueDeclaration;
                const flags = getCombinedModifierFlags(declaration);
                return s.parent && s.parent.flags & 32 /* Class */ ? flags : flags & ~7 /* AccessibilityModifier */;
            }
            if (getCheckFlags(s) & 6 /* Synthetic */) {
                const checkFlags = s.links.checkFlags;
                const accessModifier = checkFlags & 1024 /* ContainsPrivate */ ? 2 /* Private */ : checkFlags & 256 /* ContainsPublic */ ? 1 /* Public */ : 4 /* Protected */;
                const staticModifier = checkFlags & 2048 /* ContainsStatic */ ? 256 /* Static */ : 0;
                return accessModifier | staticModifier;
            }
            if (s.flags & 4194304 /* Prototype */) {
                return 1 /* Public */ | 256 /* Static */;
            }
            return 0;
        }
        function skipAlias(symbol, checker) {
            return symbol.flags & 2097152 /* Alias */ ? checker.getAliasedSymbol(symbol) : symbol;
        }
        function getCombinedLocalAndExportSymbolFlags(symbol) {
            return symbol.exportSymbol ? symbol.exportSymbol.flags | symbol.flags : symbol.flags;
        }
        function isWriteOnlyAccess(node) {
            return accessKind(node) === 1 /* Write */;
        }
        function isWriteAccess(node) {
            return accessKind(node) !== 0 /* Read */;
        }
        function accessKind(node) {
            const { parent: parent2 } = node;
            switch (parent2 == null ? void 0 : parent2.kind) {
                case 217 /* ParenthesizedExpression */:
                    return accessKind(parent2);
                case 225 /* PostfixUnaryExpression */:
                case 224 /* PrefixUnaryExpression */:
                    const { operator } = parent2;
                    return operator === 46 /* PlusPlusToken */ || operator === 47 /* MinusMinusToken */ ? 2 /* ReadWrite */ : 0 /* Read */;
                case 226 /* BinaryExpression */:
                    const { left, operatorToken } = parent2;
                    return left === node && isAssignmentOperator(operatorToken.kind) ? operatorToken.kind === 64 /* EqualsToken */ ? 1 /* Write */ : 2 /* ReadWrite */ : 0 /* Read */;
                case 211 /* PropertyAccessExpression */:
                    return parent2.name !== node ? 0 /* Read */ : accessKind(parent2);
                case 303 /* PropertyAssignment */: {
                    const parentAccess = accessKind(parent2.parent);
                    return node === parent2.name ? reverseAccessKind(parentAccess) : parentAccess;
                }
                case 304 /* ShorthandPropertyAssignment */:
                    return node === parent2.objectAssignmentInitializer ? 0 /* Read */ : accessKind(parent2.parent);
                case 209 /* ArrayLiteralExpression */:
                    return accessKind(parent2);
                default:
                    return 0 /* Read */;
            }
        }
        function reverseAccessKind(a) {
            switch (a) {
                case 0 /* Read */:
                    return 1 /* Write */;
                case 1 /* Write */:
                    return 0 /* Read */;
                case 2 /* ReadWrite */:
                    return 2 /* ReadWrite */;
                default:
                    return Debug.assertNever(a);
            }
        }
        function compareDataObjects(dst, src) {
            if (!dst || !src || Object.keys(dst).length !== Object.keys(src).length) {
                return false;
            }
            for (const e in dst) {
                if (typeof dst[e] === "object") {
                    if (!compareDataObjects(dst[e], src[e])) {
                        return false;
                    }
                }
                else if (typeof dst[e] !== "function") {
                    if (dst[e] !== src[e]) {
                        return false;
                    }
                }
            }
            return true;
        }
        function clearMap(map2, onDeleteValue) {
            map2.forEach(onDeleteValue);
            map2.clear();
        }
        function mutateMapSkippingNewValues(map2, newMap, options) {
            const { onDeleteValue, onExistingValue } = options;
            map2.forEach((existingValue, key) => {
                var _a;
                if (!(newMap == null ? void 0 : newMap.has(key))) {
                    map2.delete(key);
                    onDeleteValue(existingValue, key);
                }
                else if (onExistingValue) {
                    onExistingValue(existingValue, (_a = newMap.get) == null ? void 0 : _a.call(newMap, key), key);
                }
            });
        }
        function mutateMap(map2, newMap, options) {
            mutateMapSkippingNewValues(map2, newMap, options);
            const { createNewValue } = options;
            newMap == null ? void 0 : newMap.forEach((valueInNewMap, key) => {
                if (!map2.has(key)) {
                    map2.set(key, createNewValue(key, valueInNewMap));
                }
            });
        }
        function isAbstractConstructorSymbol(symbol) {
            if (symbol.flags & 32 /* Class */) {
                const declaration = getClassLikeDeclarationOfSymbol(symbol);
                return !!declaration && hasSyntacticModifier(declaration, 64 /* Abstract */);
            }
            return false;
        }
        function getClassLikeDeclarationOfSymbol(symbol) {
            var _a;
            return (_a = symbol.declarations) == null ? void 0 : _a.find(isClassLike);
        }
        function getObjectFlags(type) {
            return type.flags & 3899393 /* ObjectFlagsType */ ? type.objectFlags : 0;
        }
        function forSomeAncestorDirectory(directory, callback) {
            return !!forEachAncestorDirectory(directory, (d) => callback(d) ? true : void 0);
        }
        function isUMDExportSymbol(symbol) {
            return !!symbol && !!symbol.declarations && !!symbol.declarations[0] && isNamespaceExportDeclaration(symbol.declarations[0]);
        }
        function showModuleSpecifier({ moduleSpecifier }) {
            return isStringLiteral(moduleSpecifier) ? moduleSpecifier.text : getTextOfNode(moduleSpecifier);
        }
        function getLastChild(node) {
            let lastChild;
            forEachChild(node, (child) => {
                if (nodeIsPresent(child))
                    lastChild = child;
            }, (children) => {
                for (let i = children.length - 1; i >= 0; i--) {
                    if (nodeIsPresent(children[i])) {
                        lastChild = children[i];
                        break;
                    }
                }
            });
            return lastChild;
        }
        function addToSeen(seen, key, value = true) {
            if (seen.has(key)) {
                return false;
            }
            seen.set(key, value);
            return true;
        }
        function isObjectTypeDeclaration(node) {
            return isClassLike(node) || isInterfaceDeclaration(node) || isTypeLiteralNode(node);
        }
        function isTypeNodeKind(kind) {
            return kind >= 182 /* FirstTypeNode */ && kind <= 205 /* LastTypeNode */ || kind === 133 /* AnyKeyword */ || kind === 159 /* UnknownKeyword */ || kind === 150 /* NumberKeyword */ || kind === 163 /* BigIntKeyword */ || kind === 151 /* ObjectKeyword */ || kind === 136 /* BooleanKeyword */ || kind === 154 /* StringKeyword */ || kind === 155 /* SymbolKeyword */ || kind === 116 /* VoidKeyword */ || kind === 157 /* UndefinedKeyword */ || kind === 146 /* NeverKeyword */ || kind === 141 /* IntrinsicKeyword */ || kind === 233 /* ExpressionWithTypeArguments */ || kind === 319 /* JSDocAllType */ || kind === 320 /* JSDocUnknownType */ || kind === 321 /* JSDocNullableType */ || kind === 322 /* JSDocNonNullableType */ || kind === 323 /* JSDocOptionalType */ || kind === 324 /* JSDocFunctionType */ || kind === 325 /* JSDocVariadicType */;
        }
        function isAccessExpression(node) {
            return node.kind === 211 /* PropertyAccessExpression */ || node.kind === 212 /* ElementAccessExpression */;
        }
        function getNameOfAccessExpression(node) {
            if (node.kind === 211 /* PropertyAccessExpression */) {
                return node.name;
            }
            Debug.assert(node.kind === 212 /* ElementAccessExpression */);
            return node.argumentExpression;
        }
        function isBundleFileTextLike(section) {
            switch (section.kind) {
                case "text" /* Text */:
                case "internal" /* Internal */:
                    return true;
                default:
                    return false;
            }
        }
        function isNamedImportsOrExports(node) {
            return node.kind === 275 /* NamedImports */ || node.kind === 279 /* NamedExports */;
        }
        function getLeftmostAccessExpression(expr) {
            while (isAccessExpression(expr)) {
                expr = expr.expression;
            }
            return expr;
        }
        function forEachNameInAccessChainWalkingLeft(name, action) {
            if (isAccessExpression(name.parent) && isRightSideOfAccessExpression(name)) {
                return walkAccessExpression(name.parent);
            }
            function walkAccessExpression(access) {
                if (access.kind === 211 /* PropertyAccessExpression */) {
                    const res = action(access.name);
                    if (res !== void 0) {
                        return res;
                    }
                }
                else if (access.kind === 212 /* ElementAccessExpression */) {
                    if (isIdentifier(access.argumentExpression) || isStringLiteralLike(access.argumentExpression)) {
                        const res = action(access.argumentExpression);
                        if (res !== void 0) {
                            return res;
                        }
                    }
                    else {
                        return void 0;
                    }
                }
                if (isAccessExpression(access.expression)) {
                    return walkAccessExpression(access.expression);
                }
                if (isIdentifier(access.expression)) {
                    return action(access.expression);
                }
                return void 0;
            }
        }
        function getLeftmostExpression(node, stopAtCallExpressions) {
            while (true) {
                switch (node.kind) {
                    case 225 /* PostfixUnaryExpression */:
                        node = node.operand;
                        continue;
                    case 226 /* BinaryExpression */:
                        node = node.left;
                        continue;
                    case 227 /* ConditionalExpression */:
                        node = node.condition;
                        continue;
                    case 215 /* TaggedTemplateExpression */:
                        node = node.tag;
                        continue;
                    case 213 /* CallExpression */:
                        if (stopAtCallExpressions) {
                            return node;
                        }
                    case 234 /* AsExpression */:
                    case 212 /* ElementAccessExpression */:
                    case 211 /* PropertyAccessExpression */:
                    case 235 /* NonNullExpression */:
                    case 360 /* PartiallyEmittedExpression */:
                    case 238 /* SatisfiesExpression */:
                        node = node.expression;
                        continue;
                }
                return node;
            }
        }
        function Symbol4(flags, name) {
            this.flags = flags;
            this.escapedName = name;
            this.declarations = void 0;
            this.valueDeclaration = void 0;
            this.id = 0;
            this.mergeId = 0;
            this.parent = void 0;
            this.members = void 0;
            this.exports = void 0;
            this.exportSymbol = void 0;
            this.constEnumOnlyModule = void 0;
            this.isReferenced = void 0;
            this.lastAssignmentPos = void 0;
            this.links = void 0;
        }
        function Type3(checker, flags) {
            this.flags = flags;
            if (Debug.isDebugging || tracing) {
                this.checker = checker;
            }
        }
        function Signature2(checker, flags) {
            this.flags = flags;
            if (Debug.isDebugging) {
                this.checker = checker;
            }
        }
        function Node4(kind, pos, end) {
            this.pos = pos;
            this.end = end;
            this.kind = kind;
            this.id = 0;
            this.flags = 0 /* None */;
            this.modifierFlagsCache = 0 /* None */;
            this.transformFlags = 0 /* None */;
            this.parent = void 0;
            this.original = void 0;
            this.emitNode = void 0;
        }
        function Token(kind, pos, end) {
            this.pos = pos;
            this.end = end;
            this.kind = kind;
            this.id = 0;
            this.flags = 0 /* None */;
            this.transformFlags = 0 /* None */;
            this.parent = void 0;
            this.emitNode = void 0;
        }
        function Identifier2(kind, pos, end) {
            this.pos = pos;
            this.end = end;
            this.kind = kind;
            this.id = 0;
            this.flags = 0 /* None */;
            this.transformFlags = 0 /* None */;
            this.parent = void 0;
            this.original = void 0;
            this.emitNode = void 0;
        }
        function SourceMapSource(fileName, text, skipTrivia2) {
            this.fileName = fileName;
            this.text = text;
            this.skipTrivia = skipTrivia2 || ((pos) => pos);
        }
        function addObjectAllocatorPatcher(fn) {
            objectAllocatorPatchers.push(fn);
            fn(objectAllocator);
        }
        function setObjectAllocator(alloc) {
            Object.assign(objectAllocator, alloc);
            forEach(objectAllocatorPatchers, (fn) => fn(objectAllocator));
        }
        function formatStringFromArgs(text, args) {
            return text.replace(/{(\d+)}/g, (_match, index) => "" + Debug.checkDefined(args[+index]));
        }
        function setLocalizedDiagnosticMessages(messages) {
            localizedDiagnosticMessages = messages;
        }
        function maybeSetLocalizedDiagnosticMessages(getMessages) {
            if (!localizedDiagnosticMessages && getMessages) {
                localizedDiagnosticMessages = getMessages();
            }
        }
        function getLocaleSpecificMessage(message) {
            return localizedDiagnosticMessages && localizedDiagnosticMessages[message.key] || message.message;
        }
        function createDetachedDiagnostic(fileName, sourceText, start, length2, message, ...args) {
            if (start + length2 > sourceText.length) {
                length2 = sourceText.length - start;
            }
            assertDiagnosticLocation(sourceText, start, length2);
            let text = getLocaleSpecificMessage(message);
            if (some(args)) {
                text = formatStringFromArgs(text, args);
            }
            return {
                file: void 0,
                start,
                length: length2,
                messageText: text,
                category: message.category,
                code: message.code,
                reportsUnnecessary: message.reportsUnnecessary,
                fileName
            };
        }
        function isDiagnosticWithDetachedLocation(diagnostic) {
            return diagnostic.file === void 0 && diagnostic.start !== void 0 && diagnostic.length !== void 0 && typeof diagnostic.fileName === "string";
        }
        function attachFileToDiagnostic(diagnostic, file) {
            const fileName = file.fileName || "";
            const length2 = file.text.length;
            Debug.assertEqual(diagnostic.fileName, fileName);
            Debug.assertLessThanOrEqual(diagnostic.start, length2);
            Debug.assertLessThanOrEqual(diagnostic.start + diagnostic.length, length2);
            const diagnosticWithLocation = {
                file,
                start: diagnostic.start,
                length: diagnostic.length,
                messageText: diagnostic.messageText,
                category: diagnostic.category,
                code: diagnostic.code,
                reportsUnnecessary: diagnostic.reportsUnnecessary
            };
            if (diagnostic.relatedInformation) {
                diagnosticWithLocation.relatedInformation = [];
                for (const related of diagnostic.relatedInformation) {
                    if (isDiagnosticWithDetachedLocation(related) && related.fileName === fileName) {
                        Debug.assertLessThanOrEqual(related.start, length2);
                        Debug.assertLessThanOrEqual(related.start + related.length, length2);
                        diagnosticWithLocation.relatedInformation.push(attachFileToDiagnostic(related, file));
                    }
                    else {
                        diagnosticWithLocation.relatedInformation.push(related);
                    }
                }
            }
            return diagnosticWithLocation;
        }
        function attachFileToDiagnostics(diagnostics, file) {
            const diagnosticsWithLocation = [];
            for (const diagnostic of diagnostics) {
                diagnosticsWithLocation.push(attachFileToDiagnostic(diagnostic, file));
            }
            return diagnosticsWithLocation;
        }
        function createFileDiagnostic(file, start, length2, message, ...args) {
            assertDiagnosticLocation(file.text, start, length2);
            let text = getLocaleSpecificMessage(message);
            if (some(args)) {
                text = formatStringFromArgs(text, args);
            }
            return {
                file,
                start,
                length: length2,
                messageText: text,
                category: message.category,
                code: message.code,
                reportsUnnecessary: message.reportsUnnecessary,
                reportsDeprecated: message.reportsDeprecated
            };
        }
        function formatMessage(message, ...args) {
            let text = getLocaleSpecificMessage(message);
            if (some(args)) {
                text = formatStringFromArgs(text, args);
            }
            return text;
        }
        function createCompilerDiagnostic(message, ...args) {
            let text = getLocaleSpecificMessage(message);
            if (some(args)) {
                text = formatStringFromArgs(text, args);
            }
            return {
                file: void 0,
                start: void 0,
                length: void 0,
                messageText: text,
                category: message.category,
                code: message.code,
                reportsUnnecessary: message.reportsUnnecessary,
                reportsDeprecated: message.reportsDeprecated
            };
        }
        function createCompilerDiagnosticFromMessageChain(chain, relatedInformation) {
            return {
                file: void 0,
                start: void 0,
                length: void 0,
                code: chain.code,
                category: chain.category,
                messageText: chain.next ? chain : chain.messageText,
                relatedInformation
            };
        }
        function chainDiagnosticMessages(details, message, ...args) {
            let text = getLocaleSpecificMessage(message);
            if (some(args)) {
                text = formatStringFromArgs(text, args);
            }
            return {
                messageText: text,
                category: message.category,
                code: message.code,
                next: details === void 0 || Array.isArray(details) ? details : [details]
            };
        }
        function concatenateDiagnosticMessageChains(headChain, tailChain) {
            let lastChain = headChain;
            while (lastChain.next) {
                lastChain = lastChain.next[0];
            }
            lastChain.next = [tailChain];
        }
        function getDiagnosticFilePath(diagnostic) {
            return diagnostic.file ? diagnostic.file.path : void 0;
        }
        function compareDiagnostics(d1, d2) {
            return compareDiagnosticsSkipRelatedInformation(d1, d2) || compareRelatedInformation(d1, d2) || 0 /* EqualTo */;
        }
        function compareDiagnosticsSkipRelatedInformation(d1, d2) {
            return compareStringsCaseSensitive(getDiagnosticFilePath(d1), getDiagnosticFilePath(d2)) || compareValues(d1.start, d2.start) || compareValues(d1.length, d2.length) || compareValues(d1.code, d2.code) || compareMessageText(d1.messageText, d2.messageText) || 0 /* EqualTo */;
        }
        function compareRelatedInformation(d1, d2) {
            if (!d1.relatedInformation && !d2.relatedInformation) {
                return 0 /* EqualTo */;
            }
            if (d1.relatedInformation && d2.relatedInformation) {
                return compareValues(d1.relatedInformation.length, d2.relatedInformation.length) || forEach(d1.relatedInformation, (d1i, index) => {
                    const d2i = d2.relatedInformation[index];
                    return compareDiagnostics(d1i, d2i);
                }) || 0 /* EqualTo */;
            }
            return d1.relatedInformation ? -1 /* LessThan */ : 1 /* GreaterThan */;
        }
        function compareMessageText(t1, t2) {
            if (typeof t1 === "string" && typeof t2 === "string") {
                return compareStringsCaseSensitive(t1, t2);
            }
            else if (typeof t1 === "string") {
                return -1 /* LessThan */;
            }
            else if (typeof t2 === "string") {
                return 1 /* GreaterThan */;
            }
            let res = compareStringsCaseSensitive(t1.messageText, t2.messageText);
            if (res) {
                return res;
            }
            if (!t1.next && !t2.next) {
                return 0 /* EqualTo */;
            }
            if (!t1.next) {
                return -1 /* LessThan */;
            }
            if (!t2.next) {
                return 1 /* GreaterThan */;
            }
            const len = Math.min(t1.next.length, t2.next.length);
            for (let i = 0; i < len; i++) {
                res = compareMessageText(t1.next[i], t2.next[i]);
                if (res) {
                    return res;
                }
            }
            if (t1.next.length < t2.next.length) {
                return -1 /* LessThan */;
            }
            else if (t1.next.length > t2.next.length) {
                return 1 /* GreaterThan */;
            }
            return 0 /* EqualTo */;
        }
        function getLanguageVariant(scriptKind) {
            return scriptKind === 4 /* TSX */ || scriptKind === 2 /* JSX */ || scriptKind === 1 /* JS */ || scriptKind === 6 /* JSON */ ? 1 /* JSX */ : 0 /* Standard */;
        }
        function walkTreeForJSXTags(node) {
            if (!(node.transformFlags & 2 /* ContainsJsx */))
                return void 0;
            return isJsxOpeningLikeElement(node) || isJsxFragment(node) ? node : forEachChild(node, walkTreeForJSXTags);
        }
        function isFileModuleFromUsingJSXTag(file) {
            return !file.isDeclarationFile ? walkTreeForJSXTags(file) : void 0;
        }
        function isFileForcedToBeModuleByFormat(file) {
            return (file.impliedNodeFormat === 99 /* ESNext */ || fileExtensionIsOneOf(file.fileName, [".cjs" /* Cjs */, ".cts" /* Cts */, ".mjs" /* Mjs */, ".mts" /* Mts */])) && !file.isDeclarationFile ? true : void 0;
        }
        function getSetExternalModuleIndicator(options) {
            switch (getEmitModuleDetectionKind(options)) {
                case 3 /* Force */:
                    return (file) => {
                        file.externalModuleIndicator = isFileProbablyExternalModule(file) || !file.isDeclarationFile || void 0;
                    };
                case 1 /* Legacy */:
                    return (file) => {
                        file.externalModuleIndicator = isFileProbablyExternalModule(file);
                    };
                case 2 /* Auto */:
                    const checks = [isFileProbablyExternalModule];
                    if (options.jsx === 4 /* ReactJSX */ || options.jsx === 5 /* ReactJSXDev */) {
                        checks.push(isFileModuleFromUsingJSXTag);
                    }
                    checks.push(isFileForcedToBeModuleByFormat);
                    const combined = or(...checks);
                    const callback = (file) => void (file.externalModuleIndicator = combined(file));
                    return callback;
            }
        }
        function createComputedCompilerOptions(options) {
            return options;
        }
        function emitModuleKindIsNonNodeESM(moduleKind) {
            return moduleKind >= 5 /* ES2015 */ && moduleKind <= 99 /* ESNext */;
        }
        function hasJsonModuleEmitEnabled(options) {
            switch (getEmitModuleKind(options)) {
                case 0 /* None */:
                case 4 /* System */:
                case 3 /* UMD */:
                    return false;
            }
            return true;
        }
        function importNameElisionDisabled(options) {
            return options.verbatimModuleSyntax || options.isolatedModules && options.preserveValueImports;
        }
        function unreachableCodeIsError(options) {
            return options.allowUnreachableCode === false;
        }
        function unusedLabelIsError(options) {
            return options.allowUnusedLabels === false;
        }
        function moduleResolutionSupportsPackageJsonExportsAndImports(moduleResolution) {
            return moduleResolution >= 3 /* Node16 */ && moduleResolution <= 99 /* NodeNext */ || moduleResolution === 100 /* Bundler */;
        }
        function getStrictOptionValue(compilerOptions, flag) {
            return compilerOptions[flag] === void 0 ? !!compilerOptions.strict : !!compilerOptions[flag];
        }
        function getEmitStandardClassFields(compilerOptions) {
            return compilerOptions.useDefineForClassFields !== false && getEmitScriptTarget(compilerOptions) >= 9 /* ES2022 */;
        }
        function compilerOptionsAffectSemanticDiagnostics(newOptions, oldOptions) {
            return optionsHaveChanges(oldOptions, newOptions, semanticDiagnosticsOptionDeclarations);
        }
        function compilerOptionsAffectEmit(newOptions, oldOptions) {
            return optionsHaveChanges(oldOptions, newOptions, affectsEmitOptionDeclarations);
        }
        function compilerOptionsAffectDeclarationPath(newOptions, oldOptions) {
            return optionsHaveChanges(oldOptions, newOptions, affectsDeclarationPathOptionDeclarations);
        }
        function getCompilerOptionValue(options, option) {
            return option.strictFlag ? getStrictOptionValue(options, option.name) : option.allowJsFlag ? getAllowJSCompilerOption(options) : options[option.name];
        }
        function getJSXTransformEnabled(options) {
            const jsx = options.jsx;
            return jsx === 2 /* React */ || jsx === 4 /* ReactJSX */ || jsx === 5 /* ReactJSXDev */;
        }
        function getJSXImplicitImportBase(compilerOptions, file) {
            const jsxImportSourcePragmas = file == null ? void 0 : file.pragmas.get("jsximportsource");
            const jsxImportSourcePragma = isArray(jsxImportSourcePragmas) ? jsxImportSourcePragmas[jsxImportSourcePragmas.length - 1] : jsxImportSourcePragmas;
            return compilerOptions.jsx === 4 /* ReactJSX */ || compilerOptions.jsx === 5 /* ReactJSXDev */ || compilerOptions.jsxImportSource || jsxImportSourcePragma ? (jsxImportSourcePragma == null ? void 0 : jsxImportSourcePragma.arguments.factory) || compilerOptions.jsxImportSource || "react" : void 0;
        }
        function getJSXRuntimeImport(base, options) {
            return base ? `${base}/${options.jsx === 5 /* ReactJSXDev */ ? "jsx-dev-runtime" : "jsx-runtime"}` : void 0;
        }
        function hasZeroOrOneAsteriskCharacter(str) {
            let seenAsterisk = false;
            for (let i = 0; i < str.length; i++) {
                if (str.charCodeAt(i) === 42 /* asterisk */) {
                    if (!seenAsterisk) {
                        seenAsterisk = true;
                    }
                    else {
                        return false;
                    }
                }
            }
            return true;
        }
        function createSymlinkCache(cwd, getCanonicalFileName) {
            let symlinkedDirectories;
            let symlinkedDirectoriesByRealpath;
            let symlinkedFiles;
            let hasProcessedResolutions = false;
            return {
                getSymlinkedFiles: () => symlinkedFiles,
                getSymlinkedDirectories: () => symlinkedDirectories,
                getSymlinkedDirectoriesByRealpath: () => symlinkedDirectoriesByRealpath,
                setSymlinkedFile: (path, real) => (symlinkedFiles || (symlinkedFiles = /* @__PURE__ */ new Map())).set(path, real),
                setSymlinkedDirectory: (symlink, real) => {
                    let symlinkPath = toPath(symlink, cwd, getCanonicalFileName);
                    if (!containsIgnoredPath(symlinkPath)) {
                        symlinkPath = ensureTrailingDirectorySeparator(symlinkPath);
                        if (real !== false && !(symlinkedDirectories == null ? void 0 : symlinkedDirectories.has(symlinkPath))) {
                            (symlinkedDirectoriesByRealpath || (symlinkedDirectoriesByRealpath = createMultiMap())).add(real.realPath, symlink);
                        }
                        (symlinkedDirectories || (symlinkedDirectories = /* @__PURE__ */ new Map())).set(symlinkPath, real);
                    }
                },
                setSymlinksFromResolutions(forEachResolvedModule, forEachResolvedTypeReferenceDirective, typeReferenceDirectives) {
                    Debug.assert(!hasProcessedResolutions);
                    hasProcessedResolutions = true;
                    forEachResolvedModule((resolution) => processResolution(this, resolution.resolvedModule));
                    forEachResolvedTypeReferenceDirective((resolution) => processResolution(this, resolution.resolvedTypeReferenceDirective));
                    typeReferenceDirectives.forEach((resolution) => processResolution(this, resolution.resolvedTypeReferenceDirective));
                },
                hasProcessedResolutions: () => hasProcessedResolutions
            };
            function processResolution(cache, resolution) {
                if (!resolution || !resolution.originalPath || !resolution.resolvedFileName)
                    return;
                const { resolvedFileName, originalPath } = resolution;
                cache.setSymlinkedFile(toPath(originalPath, cwd, getCanonicalFileName), resolvedFileName);
                const [commonResolved, commonOriginal] = guessDirectorySymlink(resolvedFileName, originalPath, cwd, getCanonicalFileName) || emptyArray;
                if (commonResolved && commonOriginal) {
                    cache.setSymlinkedDirectory(commonOriginal, {
                        real: ensureTrailingDirectorySeparator(commonResolved),
                        realPath: ensureTrailingDirectorySeparator(toPath(commonResolved, cwd, getCanonicalFileName))
                    });
                }
            }
        }
        function guessDirectorySymlink(a, b, cwd, getCanonicalFileName) {
            const aParts = getPathComponents(getNormalizedAbsolutePath(a, cwd));
            const bParts = getPathComponents(getNormalizedAbsolutePath(b, cwd));
            let isDirectory = false;
            while (aParts.length >= 2 && bParts.length >= 2 && !isNodeModulesOrScopedPackageDirectory(aParts[aParts.length - 2], getCanonicalFileName) && !isNodeModulesOrScopedPackageDirectory(bParts[bParts.length - 2], getCanonicalFileName) && getCanonicalFileName(aParts[aParts.length - 1]) === getCanonicalFileName(bParts[bParts.length - 1])) {
                aParts.pop();
                bParts.pop();
                isDirectory = true;
            }
            return isDirectory ? [getPathFromPathComponents(aParts), getPathFromPathComponents(bParts)] : void 0;
        }
        function isNodeModulesOrScopedPackageDirectory(s, getCanonicalFileName) {
            return s !== void 0 && (getCanonicalFileName(s) === "node_modules" || startsWith(s, "@"));
        }
        function stripLeadingDirectorySeparator(s) {
            return isAnyDirectorySeparator(s.charCodeAt(0)) ? s.slice(1) : void 0;
        }
        function tryRemoveDirectoryPrefix(path, dirPath, getCanonicalFileName) {
            const withoutPrefix = tryRemovePrefix(path, dirPath, getCanonicalFileName);
            return withoutPrefix === void 0 ? void 0 : stripLeadingDirectorySeparator(withoutPrefix);
        }
        function regExpEscape(text) {
            return text.replace(reservedCharacterPattern, escapeRegExpCharacter);
        }
        function escapeRegExpCharacter(match) {
            return "\\" + match;
        }
        function getRegularExpressionForWildcard(specs, basePath, usage) {
            const patterns = getRegularExpressionsForWildcards(specs, basePath, usage);
            if (!patterns || !patterns.length) {
                return void 0;
            }
            const pattern = patterns.map((pattern2) => `(${pattern2})`).join("|");
            const terminator = usage === "exclude" ? "($|/)" : "$";
            return `^(${pattern})${terminator}`;
        }
        function getRegularExpressionsForWildcards(specs, basePath, usage) {
            if (specs === void 0 || specs.length === 0) {
                return void 0;
            }
            return flatMap(specs, (spec) => spec && getSubPatternFromSpec(spec, basePath, usage, wildcardMatchers[usage]));
        }
        function isImplicitGlob(lastPathComponent) {
            return !/[.*?]/.test(lastPathComponent);
        }
        function getPatternFromSpec(spec, basePath, usage) {
            const pattern = spec && getSubPatternFromSpec(spec, basePath, usage, wildcardMatchers[usage]);
            return pattern && `^(${pattern})${usage === "exclude" ? "($|/)" : "$"}`;
        }
        function getSubPatternFromSpec(spec, basePath, usage, { singleAsteriskRegexFragment, doubleAsteriskRegexFragment, replaceWildcardCharacter: replaceWildcardCharacter2 } = wildcardMatchers[usage]) {
            let subpattern = "";
            let hasWrittenComponent = false;
            const components = getNormalizedPathComponents(spec, basePath);
            const lastComponent = last(components);
            if (usage !== "exclude" && lastComponent === "**") {
                return void 0;
            }
            components[0] = removeTrailingDirectorySeparator(components[0]);
            if (isImplicitGlob(lastComponent)) {
                components.push("**", "*");
            }
            let optionalCount = 0;
            for (let component of components) {
                if (component === "**") {
                    subpattern += doubleAsteriskRegexFragment;
                }
                else {
                    if (usage === "directories") {
                        subpattern += "(";
                        optionalCount++;
                    }
                    if (hasWrittenComponent) {
                        subpattern += directorySeparator;
                    }
                    if (usage !== "exclude") {
                        let componentPattern = "";
                        if (component.charCodeAt(0) === 42 /* asterisk */) {
                            componentPattern += "([^./]" + singleAsteriskRegexFragment + ")?";
                            component = component.substr(1);
                        }
                        else if (component.charCodeAt(0) === 63 /* question */) {
                            componentPattern += "[^./]";
                            component = component.substr(1);
                        }
                        componentPattern += component.replace(reservedCharacterPattern, replaceWildcardCharacter2);
                        if (componentPattern !== component) {
                            subpattern += implicitExcludePathRegexPattern;
                        }
                        subpattern += componentPattern;
                    }
                    else {
                        subpattern += component.replace(reservedCharacterPattern, replaceWildcardCharacter2);
                    }
                }
                hasWrittenComponent = true;
            }
            while (optionalCount > 0) {
                subpattern += ")?";
                optionalCount--;
            }
            return subpattern;
        }
        function replaceWildcardCharacter(match, singleAsteriskRegexFragment) {
            return match === "*" ? singleAsteriskRegexFragment : match === "?" ? "[^/]" : "\\" + match;
        }
        function getFileMatcherPatterns(path, excludes, includes, useCaseSensitiveFileNames2, currentDirectory) {
            path = normalizePath(path);
            currentDirectory = normalizePath(currentDirectory);
            const absolutePath = combinePaths(currentDirectory, path);
            return {
                includeFilePatterns: map(getRegularExpressionsForWildcards(includes, absolutePath, "files"), (pattern) => `^${pattern}$`),
                includeFilePattern: getRegularExpressionForWildcard(includes, absolutePath, "files"),
                includeDirectoryPattern: getRegularExpressionForWildcard(includes, absolutePath, "directories"),
                excludePattern: getRegularExpressionForWildcard(excludes, absolutePath, "exclude"),
                basePaths: getBasePaths(path, includes, useCaseSensitiveFileNames2)
            };
        }
        function getRegexFromPattern(pattern, useCaseSensitiveFileNames2) {
            return new RegExp(pattern, useCaseSensitiveFileNames2 ? "" : "i");
        }
        function matchFiles(path, extensions, excludes, includes, useCaseSensitiveFileNames2, currentDirectory, depth, getFileSystemEntries, realpath) {
            path = normalizePath(path);
            currentDirectory = normalizePath(currentDirectory);
            const patterns = getFileMatcherPatterns(path, excludes, includes, useCaseSensitiveFileNames2, currentDirectory);
            const includeFileRegexes = patterns.includeFilePatterns && patterns.includeFilePatterns.map((pattern) => getRegexFromPattern(pattern, useCaseSensitiveFileNames2));
            const includeDirectoryRegex = patterns.includeDirectoryPattern && getRegexFromPattern(patterns.includeDirectoryPattern, useCaseSensitiveFileNames2);
            const excludeRegex = patterns.excludePattern && getRegexFromPattern(patterns.excludePattern, useCaseSensitiveFileNames2);
            const results = includeFileRegexes ? includeFileRegexes.map(() => []) : [[]];
            const visited = /* @__PURE__ */ new Map();
            const toCanonical = createGetCanonicalFileName(useCaseSensitiveFileNames2);
            for (const basePath of patterns.basePaths) {
                visitDirectory(basePath, combinePaths(currentDirectory, basePath), depth);
            }
            return flatten(results);
            function visitDirectory(path2, absolutePath, depth2) {
                const canonicalPath = toCanonical(realpath(absolutePath));
                if (visited.has(canonicalPath))
                    return;
                visited.set(canonicalPath, true);
                const { files, directories } = getFileSystemEntries(path2);
                for (const current of sort(files, compareStringsCaseSensitive)) {
                    const name = combinePaths(path2, current);
                    const absoluteName = combinePaths(absolutePath, current);
                    if (extensions && !fileExtensionIsOneOf(name, extensions))
                        continue;
                    if (excludeRegex && excludeRegex.test(absoluteName))
                        continue;
                    if (!includeFileRegexes) {
                        results[0].push(name);
                    }
                    else {
                        const includeIndex = findIndex(includeFileRegexes, (re) => re.test(absoluteName));
                        if (includeIndex !== -1) {
                            results[includeIndex].push(name);
                        }
                    }
                }
                if (depth2 !== void 0) {
                    depth2--;
                    if (depth2 === 0) {
                        return;
                    }
                }
                for (const current of sort(directories, compareStringsCaseSensitive)) {
                    const name = combinePaths(path2, current);
                    const absoluteName = combinePaths(absolutePath, current);
                    if ((!includeDirectoryRegex || includeDirectoryRegex.test(absoluteName)) && (!excludeRegex || !excludeRegex.test(absoluteName))) {
                        visitDirectory(name, absoluteName, depth2);
                    }
                }
            }
        }
        function getBasePaths(path, includes, useCaseSensitiveFileNames2) {
            const basePaths = [path];
            if (includes) {
                const includeBasePaths = [];
                for (const include of includes) {
                    const absolute = isRootedDiskPath(include) ? include : normalizePath(combinePaths(path, include));
                    includeBasePaths.push(getIncludeBasePath(absolute));
                }
                includeBasePaths.sort(getStringComparer(!useCaseSensitiveFileNames2));
                for (const includeBasePath of includeBasePaths) {
                    if (every(basePaths, (basePath) => !containsPath(basePath, includeBasePath, path, !useCaseSensitiveFileNames2))) {
                        basePaths.push(includeBasePath);
                    }
                }
            }
            return basePaths;
        }
        function getIncludeBasePath(absolute) {
            const wildcardOffset = indexOfAnyCharCode(absolute, wildcardCharCodes);
            if (wildcardOffset < 0) {
                return !hasExtension(absolute) ? absolute : removeTrailingDirectorySeparator(getDirectoryPath(absolute));
            }
            return absolute.substring(0, absolute.lastIndexOf(directorySeparator, wildcardOffset));
        }
        function ensureScriptKind(fileName, scriptKind) {
            return scriptKind || getScriptKindFromFileName(fileName) || 3 /* TS */;
        }
        function getScriptKindFromFileName(fileName) {
            const ext = fileName.substr(fileName.lastIndexOf("."));
            switch (ext.toLowerCase()) {
                case ".js" /* Js */:
                case ".cjs" /* Cjs */:
                case ".mjs" /* Mjs */:
                    return 1 /* JS */;
                case ".jsx" /* Jsx */:
                    return 2 /* JSX */;
                case ".ts" /* Ts */:
                case ".cts" /* Cts */:
                case ".mts" /* Mts */:
                    return 3 /* TS */;
                case ".tsx" /* Tsx */:
                    return 4 /* TSX */;
                case ".json" /* Json */:
                    return 6 /* JSON */;
                default:
                    return 0 /* Unknown */;
            }
        }
        function getSupportedExtensions(options, extraFileExtensions) {
            const needJsExtensions = options && getAllowJSCompilerOption(options);
            if (!extraFileExtensions || extraFileExtensions.length === 0) {
                return needJsExtensions ? allSupportedExtensions : supportedTSExtensions;
            }
            const builtins = needJsExtensions ? allSupportedExtensions : supportedTSExtensions;
            const flatBuiltins = flatten(builtins);
            const extensions = [
                ...builtins,
                ...mapDefined(extraFileExtensions, (x) => x.scriptKind === 7 /* Deferred */ || needJsExtensions && isJSLike(x.scriptKind) && !flatBuiltins.includes(x.extension) ? [x.extension] : void 0)
            ];
            return extensions;
        }
        function getSupportedExtensionsWithJsonIfResolveJsonModule(options, supportedExtensions) {
            if (!options || !getResolveJsonModule(options))
                return supportedExtensions;
            if (supportedExtensions === allSupportedExtensions)
                return allSupportedExtensionsWithJson;
            if (supportedExtensions === supportedTSExtensions)
                return supportedTSExtensionsWithJson;
            return [...supportedExtensions, [".json" /* Json */]];
        }
        function isJSLike(scriptKind) {
            return scriptKind === 1 /* JS */ || scriptKind === 2 /* JSX */;
        }
        function hasJSFileExtension(fileName) {
            return some(supportedJSExtensionsFlat, (extension) => fileExtensionIs(fileName, extension));
        }
        function hasTSFileExtension(fileName) {
            return some(supportedTSExtensionsFlat, (extension) => fileExtensionIs(fileName, extension));
        }
        function usesExtensionsOnImports({ imports }, hasExtension2 = or(hasJSFileExtension, hasTSFileExtension)) {
            return firstDefined(imports, ({ text }) => pathIsRelative(text) && !fileExtensionIsOneOf(text, extensionsNotSupportingExtensionlessResolution) ? hasExtension2(text) : void 0) || false;
        }
        function getModuleSpecifierEndingPreference(preference, resolutionMode, compilerOptions, sourceFile) {
            const moduleResolution = getEmitModuleResolutionKind(compilerOptions);
            const moduleResolutionIsNodeNext = 3 /* Node16 */ <= moduleResolution && moduleResolution <= 99 /* NodeNext */;
            if (preference === "js" || resolutionMode === 99 /* ESNext */ && moduleResolutionIsNodeNext) {
                if (!shouldAllowImportingTsExtension(compilerOptions)) {
                    return 2 /* JsExtension */;
                }
                return inferPreference() !== 2 /* JsExtension */ ? 3 /* TsExtension */ : 2 /* JsExtension */;
            }
            if (preference === "minimal") {
                return 0 /* Minimal */;
            }
            if (preference === "index") {
                return 1 /* Index */;
            }
            if (!shouldAllowImportingTsExtension(compilerOptions)) {
                return usesExtensionsOnImports(sourceFile) ? 2 /* JsExtension */ : 0 /* Minimal */;
            }
            return inferPreference();
            function inferPreference() {
                let usesJsExtensions = false;
                const specifiers = sourceFile.imports.length ? sourceFile.imports : isSourceFileJS(sourceFile) ? getRequiresAtTopOfFile(sourceFile).map((r) => r.arguments[0]) : emptyArray;
                for (const specifier of specifiers) {
                    if (pathIsRelative(specifier.text)) {
                        if (moduleResolutionIsNodeNext && resolutionMode === 1 /* CommonJS */ && getModeForUsageLocation(sourceFile, specifier, compilerOptions) === 99 /* ESNext */) {
                            continue;
                        }
                        if (fileExtensionIsOneOf(specifier.text, extensionsNotSupportingExtensionlessResolution)) {
                            continue;
                        }
                        if (hasTSFileExtension(specifier.text)) {
                            return 3 /* TsExtension */;
                        }
                        if (hasJSFileExtension(specifier.text)) {
                            usesJsExtensions = true;
                        }
                    }
                }
                return usesJsExtensions ? 2 /* JsExtension */ : 0 /* Minimal */;
            }
        }
        function getRequiresAtTopOfFile(sourceFile) {
            let nonRequireStatementCount = 0;
            let requires;
            for (const statement of sourceFile.statements) {
                if (nonRequireStatementCount > 3) {
                    break;
                }
                if (isRequireVariableStatement(statement)) {
                    requires = concatenate(requires, statement.declarationList.declarations.map((d) => d.initializer));
                }
                else if (isExpressionStatement(statement) && isRequireCall(statement.expression, 
                /*requireStringLiteralLikeArgument*/
                true)) {
                    requires = append(requires, statement.expression);
                }
                else {
                    nonRequireStatementCount++;
                }
            }
            return requires || emptyArray;
        }
        function isSupportedSourceFileName(fileName, compilerOptions, extraFileExtensions) {
            if (!fileName)
                return false;
            const supportedExtensions = getSupportedExtensions(compilerOptions, extraFileExtensions);
            for (const extension of flatten(getSupportedExtensionsWithJsonIfResolveJsonModule(compilerOptions, supportedExtensions))) {
                if (fileExtensionIs(fileName, extension)) {
                    return true;
                }
            }
            return false;
        }
        function numberOfDirectorySeparators(str) {
            const match = str.match(/\//g);
            return match ? match.length : 0;
        }
        function compareNumberOfDirectorySeparators(path1, path2) {
            return compareValues(numberOfDirectorySeparators(path1), numberOfDirectorySeparators(path2));
        }
        function removeFileExtension(path) {
            for (const ext of extensionsToRemove) {
                const extensionless = tryRemoveExtension(path, ext);
                if (extensionless !== void 0) {
                    return extensionless;
                }
            }
            return path;
        }
        function tryRemoveExtension(path, extension) {
            return fileExtensionIs(path, extension) ? removeExtension(path, extension) : void 0;
        }
        function removeExtension(path, extension) {
            return path.substring(0, path.length - extension.length);
        }
        function changeExtension(path, newExtension) {
            return changeAnyExtension(path, newExtension, extensionsToRemove, 
            /*ignoreCase*/
            false);
        }
        function tryParsePattern(pattern) {
            const indexOfStar = pattern.indexOf("*");
            if (indexOfStar === -1) {
                return pattern;
            }
            return pattern.indexOf("*", indexOfStar + 1) !== -1 ? void 0 : {
                prefix: pattern.substr(0, indexOfStar),
                suffix: pattern.substr(indexOfStar + 1)
            };
        }
        function tryParsePatterns(paths) {
            return mapDefined(getOwnKeys(paths), (path) => tryParsePattern(path));
        }
        function positionIsSynthesized(pos) {
            return !(pos >= 0);
        }
        function extensionIsTS(ext) {
            return ext === ".ts" /* Ts */ || ext === ".tsx" /* Tsx */ || ext === ".d.ts" /* Dts */ || ext === ".cts" /* Cts */ || ext === ".mts" /* Mts */ || ext === ".d.mts" /* Dmts */ || ext === ".d.cts" /* Dcts */ || startsWith(ext, ".d.") && endsWith(ext, ".ts");
        }
        function resolutionExtensionIsTSOrJson(ext) {
            return extensionIsTS(ext) || ext === ".json" /* Json */;
        }
        function extensionFromPath(path) {
            const ext = tryGetExtensionFromPath2(path);
            return ext !== void 0 ? ext : Debug.fail(`File ${path} has unknown extension.`);
        }
        function isAnySupportedFileExtension(path) {
            return tryGetExtensionFromPath2(path) !== void 0;
        }
        function tryGetExtensionFromPath2(path) {
            return find(extensionsToRemove, (e) => fileExtensionIs(path, e));
        }
        function isCheckJsEnabledForFile(sourceFile, compilerOptions) {
            return sourceFile.checkJsDirective ? sourceFile.checkJsDirective.enabled : compilerOptions.checkJs;
        }
        function matchPatternOrExact(patternOrStrings, candidate) {
            const patterns = [];
            for (const patternOrString of patternOrStrings) {
                if (patternOrString === candidate) {
                    return candidate;
                }
                if (!isString(patternOrString)) {
                    patterns.push(patternOrString);
                }
            }
            return findBestPatternMatch(patterns, (_) => _, candidate);
        }
        function sliceAfter(arr, value) {
            const index = arr.indexOf(value);
            Debug.assert(index !== -1);
            return arr.slice(index);
        }
        function addRelatedInfo(diagnostic, ...relatedInformation) {
            if (!relatedInformation.length) {
                return diagnostic;
            }
            if (!diagnostic.relatedInformation) {
                diagnostic.relatedInformation = [];
            }
            Debug.assert(diagnostic.relatedInformation !== emptyArray, "Diagnostic had empty array singleton for related info, but is still being constructed!");
            diagnostic.relatedInformation.push(...relatedInformation);
            return diagnostic;
        }
        function minAndMax(arr, getValue) {
            Debug.assert(arr.length !== 0);
            let min2 = getValue(arr[0]);
            let max = min2;
            for (let i = 1; i < arr.length; i++) {
                const value = getValue(arr[i]);
                if (value < min2) {
                    min2 = value;
                }
                else if (value > max) {
                    max = value;
                }
            }
            return { min: min2, max };
        }
        function rangeOfNode(node) {
            return { pos: getTokenPosOfNode(node), end: node.end };
        }
        function rangeOfTypeParameters(sourceFile, typeParameters) {
            const pos = typeParameters.pos - 1;
            const end = Math.min(sourceFile.text.length, skipTrivia(sourceFile.text, typeParameters.end) + 1);
            return { pos, end };
        }
        function skipTypeChecking(sourceFile, options, host) {
            return options.skipLibCheck && sourceFile.isDeclarationFile || options.skipDefaultLibCheck && sourceFile.hasNoDefaultLib || host.isSourceOfProjectReferenceRedirect(sourceFile.fileName);
        }
        function isJsonEqual(a, b) {
            return a === b || typeof a === "object" && a !== null && typeof b === "object" && b !== null && equalOwnProperties(a, b, isJsonEqual);
        }
        function parsePseudoBigInt(stringValue) {
            let log2Base;
            switch (stringValue.charCodeAt(1)) {
                case 98 /* b */:
                case 66 /* B */:
                    log2Base = 1;
                    break;
                case 111 /* o */:
                case 79 /* O */:
                    log2Base = 3;
                    break;
                case 120 /* x */:
                case 88 /* X */:
                    log2Base = 4;
                    break;
                default:
                    const nIndex = stringValue.length - 1;
                    let nonZeroStart = 0;
                    while (stringValue.charCodeAt(nonZeroStart) === 48 /* _0 */) {
                        nonZeroStart++;
                    }
                    return stringValue.slice(nonZeroStart, nIndex) || "0";
            }
            const startIndex = 2, endIndex = stringValue.length - 1;
            const bitsNeeded = (endIndex - startIndex) * log2Base;
            const segments = new Uint16Array((bitsNeeded >>> 4) + (bitsNeeded & 15 ? 1 : 0));
            for (let i = endIndex - 1, bitOffset = 0; i >= startIndex; i--, bitOffset += log2Base) {
                const segment = bitOffset >>> 4;
                const digitChar = stringValue.charCodeAt(i);
                const digit = digitChar <= 57 /* _9 */ ? digitChar - 48 /* _0 */ : 10 + digitChar - (digitChar <= 70 /* F */ ? 65 /* A */ : 97 /* a */);
                const shiftedDigit = digit << (bitOffset & 15);
                segments[segment] |= shiftedDigit;
                const residual = shiftedDigit >>> 16;
                if (residual)
                    segments[segment + 1] |= residual;
            }
            let base10Value = "";
            let firstNonzeroSegment = segments.length - 1;
            let segmentsRemaining = true;
            while (segmentsRemaining) {
                let mod10 = 0;
                segmentsRemaining = false;
                for (let segment = firstNonzeroSegment; segment >= 0; segment--) {
                    const newSegment = mod10 << 16 | segments[segment];
                    const segmentValue = newSegment / 10 | 0;
                    segments[segment] = segmentValue;
                    mod10 = newSegment - segmentValue * 10;
                    if (segmentValue && !segmentsRemaining) {
                        firstNonzeroSegment = segment;
                        segmentsRemaining = true;
                    }
                }
                base10Value = mod10 + base10Value;
            }
            return base10Value;
        }
        function pseudoBigIntToString({ negative, base10Value }) {
            return (negative && base10Value !== "0" ? "-" : "") + base10Value;
        }
        function parseBigInt(text) {
            if (!isValidBigIntString(text, 
            /*roundTripOnly*/
            false)) {
                return void 0;
            }
            return parseValidBigInt(text);
        }
        function parseValidBigInt(text) {
            const negative = text.startsWith("-");
            const base10Value = parsePseudoBigInt(`${negative ? text.slice(1) : text}n`);
            return { negative, base10Value };
        }
        function isValidBigIntString(s, roundTripOnly) {
            if (s === "")
                return false;
            const scanner2 = createScanner(99 /* ESNext */, 
            /*skipTrivia*/
            false);
            let success = true;
            scanner2.setOnError(() => success = false);
            scanner2.setText(s + "n");
            let result = scanner2.scan();
            const negative = result === 41 /* MinusToken */;
            if (negative) {
                result = scanner2.scan();
            }
            const flags = scanner2.getTokenFlags();
            return success && result === 10 /* BigIntLiteral */ && scanner2.getTokenEnd() === s.length + 1 && !(flags & 512 /* ContainsSeparator */) && (!roundTripOnly || s === pseudoBigIntToString({ negative, base10Value: parsePseudoBigInt(scanner2.getTokenValue()) }));
        }
        function isValidTypeOnlyAliasUseSite(useSite) {
            return !!(useSite.flags & 33554432 /* Ambient */) || isPartOfTypeQuery(useSite) || isIdentifierInNonEmittingHeritageClause(useSite) || isPartOfPossiblyValidTypeOrAbstractComputedPropertyName(useSite) || !(isExpressionNode(useSite) || isShorthandPropertyNameUseSite(useSite));
        }
        function isShorthandPropertyNameUseSite(useSite) {
            return isIdentifier(useSite) && isShorthandPropertyAssignment(useSite.parent) && useSite.parent.name === useSite;
        }
        function isPartOfPossiblyValidTypeOrAbstractComputedPropertyName(node) {
            while (node.kind === 80 /* Identifier */ || node.kind === 211 /* PropertyAccessExpression */) {
                node = node.parent;
            }
            if (node.kind !== 167 /* ComputedPropertyName */) {
                return false;
            }
            if (hasSyntacticModifier(node.parent, 64 /* Abstract */)) {
                return true;
            }
            const containerKind = node.parent.parent.kind;
            return containerKind === 264 /* InterfaceDeclaration */ || containerKind === 187 /* TypeLiteral */;
        }
        function isIdentifierInNonEmittingHeritageClause(node) {
            if (node.kind !== 80 /* Identifier */)
                return false;
            const heritageClause = findAncestor(node.parent, (parent2) => {
                switch (parent2.kind) {
                    case 298 /* HeritageClause */:
                        return true;
                    case 211 /* PropertyAccessExpression */:
                    case 233 /* ExpressionWithTypeArguments */:
                        return false;
                    default:
                        return "quit";
                }
            });
            return (heritageClause == null ? void 0 : heritageClause.token) === 119 /* ImplementsKeyword */ || (heritageClause == null ? void 0 : heritageClause.parent.kind) === 264 /* InterfaceDeclaration */;
        }
        function isIdentifierTypeReference(node) {
            return isTypeReferenceNode(node) && isIdentifier(node.typeName);
        }
        function arrayIsHomogeneous(array, comparer = equateValues) {
            if (array.length < 2)
                return true;
            const first2 = array[0];
            for (let i = 1, length2 = array.length; i < length2; i++) {
                const target = array[i];
                if (!comparer(first2, target))
                    return false;
            }
            return true;
        }
        function setTextRangePos(range, pos) {
            range.pos = pos;
            return range;
        }
        function setTextRangeEnd(range, end) {
            range.end = end;
            return range;
        }
        function setTextRangePosEnd(range, pos, end) {
            return setTextRangeEnd(setTextRangePos(range, pos), end);
        }
        function setTextRangePosWidth(range, pos, width) {
            return setTextRangePosEnd(range, pos, pos + width);
        }
        function setNodeFlags(node, newFlags) {
            if (node) {
                node.flags = newFlags;
            }
            return node;
        }
        function setParent(child, parent2) {
            if (child && parent2) {
                child.parent = parent2;
            }
            return child;
        }
        function setEachParent(children, parent2) {
            if (children) {
                for (const child of children) {
                    setParent(child, parent2);
                }
            }
            return children;
        }
        function setParentRecursive(rootNode, incremental) {
            if (!rootNode)
                return rootNode;
            forEachChildRecursively(rootNode, isJSDocNode(rootNode) ? bindParentToChildIgnoringJSDoc : bindParentToChild);
            return rootNode;
            function bindParentToChildIgnoringJSDoc(child, parent2) {
                if (incremental && child.parent === parent2) {
                    return "skip";
                }
                setParent(child, parent2);
            }
            function bindJSDoc(child) {
                if (hasJSDocNodes(child)) {
                    for (const doc of child.jsDoc) {
                        bindParentToChildIgnoringJSDoc(doc, child);
                        forEachChildRecursively(doc, bindParentToChildIgnoringJSDoc);
                    }
                }
            }
            function bindParentToChild(child, parent2) {
                return bindParentToChildIgnoringJSDoc(child, parent2) || bindJSDoc(child);
            }
        }
        function isPackedElement(node) {
            return !isOmittedExpression(node);
        }
        function isPackedArrayLiteral(node) {
            return isArrayLiteralExpression(node) && every(node.elements, isPackedElement);
        }
        function expressionResultIsUnused(node) {
            Debug.assertIsDefined(node.parent);
            while (true) {
                const parent2 = node.parent;
                if (isParenthesizedExpression(parent2)) {
                    node = parent2;
                    continue;
                }
                if (isExpressionStatement(parent2) || isVoidExpression(parent2) || isForStatement(parent2) && (parent2.initializer === node || parent2.incrementor === node)) {
                    return true;
                }
                if (isCommaListExpression(parent2)) {
                    if (node !== last(parent2.elements))
                        return true;
                    node = parent2;
                    continue;
                }
                if (isBinaryExpression(parent2) && parent2.operatorToken.kind === 28 /* CommaToken */) {
                    if (node === parent2.left)
                        return true;
                    node = parent2;
                    continue;
                }
                return false;
            }
        }
        function containsIgnoredPath(path) {
            return some(ignoredPaths, (p) => path.includes(p));
        }
        function getContainingNodeArray(node) {
            if (!node.parent)
                return void 0;
            switch (node.kind) {
                case 168 /* TypeParameter */:
                    const { parent: parent3 } = node;
                    return parent3.kind === 195 /* InferType */ ? void 0 : parent3.typeParameters;
                case 169 /* Parameter */:
                    return node.parent.parameters;
                case 204 /* TemplateLiteralTypeSpan */:
                    return node.parent.templateSpans;
                case 239 /* TemplateSpan */:
                    return node.parent.templateSpans;
                case 170 /* Decorator */: {
                    const { parent: parent4 } = node;
                    return canHaveDecorators(parent4) ? parent4.modifiers : void 0;
                }
                case 298 /* HeritageClause */:
                    return node.parent.heritageClauses;
            }
            const { parent: parent2 } = node;
            if (isJSDocTag(node)) {
                return isJSDocTypeLiteral(node.parent) ? void 0 : node.parent.tags;
            }
            switch (parent2.kind) {
                case 187 /* TypeLiteral */:
                case 264 /* InterfaceDeclaration */:
                    return isTypeElement(node) ? parent2.members : void 0;
                case 192 /* UnionType */:
                case 193 /* IntersectionType */:
                    return parent2.types;
                case 189 /* TupleType */:
                case 209 /* ArrayLiteralExpression */:
                case 361 /* CommaListExpression */:
                case 275 /* NamedImports */:
                case 279 /* NamedExports */:
                    return parent2.elements;
                case 210 /* ObjectLiteralExpression */:
                case 292 /* JsxAttributes */:
                    return parent2.properties;
                case 213 /* CallExpression */:
                case 214 /* NewExpression */:
                    return isTypeNode(node) ? parent2.typeArguments : parent2.expression === node ? void 0 : parent2.arguments;
                case 284 /* JsxElement */:
                case 288 /* JsxFragment */:
                    return isJsxChild(node) ? parent2.children : void 0;
                case 286 /* JsxOpeningElement */:
                case 285 /* JsxSelfClosingElement */:
                    return isTypeNode(node) ? parent2.typeArguments : void 0;
                case 241 /* Block */:
                case 296 /* CaseClause */:
                case 297 /* DefaultClause */:
                case 268 /* ModuleBlock */:
                    return parent2.statements;
                case 269 /* CaseBlock */:
                    return parent2.clauses;
                case 263 /* ClassDeclaration */:
                case 231 /* ClassExpression */:
                    return isClassElement(node) ? parent2.members : void 0;
                case 266 /* EnumDeclaration */:
                    return isEnumMember(node) ? parent2.members : void 0;
                case 312 /* SourceFile */:
                    return parent2.statements;
            }
        }
        function hasContextSensitiveParameters(node) {
            if (!node.typeParameters) {
                if (some(node.parameters, (p) => !getEffectiveTypeAnnotationNode(p))) {
                    return true;
                }
                if (node.kind !== 219 /* ArrowFunction */) {
                    const parameter = firstOrUndefined(node.parameters);
                    if (!(parameter && parameterIsThisKeyword(parameter))) {
                        return true;
                    }
                }
            }
            return false;
        }
        function isInfinityOrNaNString(name) {
            return name === "Infinity" || name === "-Infinity" || name === "NaN";
        }
        function isCatchClauseVariableDeclaration(node) {
            return node.kind === 260 /* VariableDeclaration */ && node.parent.kind === 299 /* CatchClause */;
        }
        function isFunctionExpressionOrArrowFunction(node) {
            return node.kind === 218 /* FunctionExpression */ || node.kind === 219 /* ArrowFunction */;
        }
        function escapeSnippetText(text) {
            return text.replace(/\$/gm, () => "\\$");
        }
        function isNumericLiteralName(name) {
            return (+name).toString() === name;
        }
        function createPropertyNameNodeForIdentifierOrLiteral(name, target, singleQuote, stringNamed, isMethod) {
            const isMethodNamedNew = isMethod && name === "new";
            return !isMethodNamedNew && isIdentifierText(name, target) ? factory.createIdentifier(name) : !stringNamed && !isMethodNamedNew && isNumericLiteralName(name) && +name >= 0 ? factory.createNumericLiteral(+name) : factory.createStringLiteral(name, !!singleQuote);
        }
        function isThisTypeParameter(type) {
            return !!(type.flags & 262144 /* TypeParameter */ && type.isThisType);
        }
        function getNodeModulePathParts(fullPath) {
            let topLevelNodeModulesIndex = 0;
            let topLevelPackageNameIndex = 0;
            let packageRootIndex = 0;
            let fileNameIndex = 0;
            let States;
            ((States2) => {
                States2[States2["BeforeNodeModules"] = 0] = "BeforeNodeModules";
                States2[States2["NodeModules"] = 1] = "NodeModules";
                States2[States2["Scope"] = 2] = "Scope";
                States2[States2["PackageContent"] = 3] = "PackageContent";
            })(States || (States = {}));
            let partStart = 0;
            let partEnd = 0;
            let state = 0 /* BeforeNodeModules */;
            while (partEnd >= 0) {
                partStart = partEnd;
                partEnd = fullPath.indexOf("/", partStart + 1);
                switch (state) {
                    case 0 /* BeforeNodeModules */:
                        if (fullPath.indexOf(nodeModulesPathPart, partStart) === partStart) {
                            topLevelNodeModulesIndex = partStart;
                            topLevelPackageNameIndex = partEnd;
                            state = 1 /* NodeModules */;
                        }
                        break;
                    case 1 /* NodeModules */:
                    case 2 /* Scope */:
                        if (state === 1 /* NodeModules */ && fullPath.charAt(partStart + 1) === "@") {
                            state = 2 /* Scope */;
                        }
                        else {
                            packageRootIndex = partEnd;
                            state = 3 /* PackageContent */;
                        }
                        break;
                    case 3 /* PackageContent */:
                        if (fullPath.indexOf(nodeModulesPathPart, partStart) === partStart) {
                            state = 1 /* NodeModules */;
                        }
                        else {
                            state = 3 /* PackageContent */;
                        }
                        break;
                }
            }
            fileNameIndex = partStart;
            return state > 1 /* NodeModules */ ? { topLevelNodeModulesIndex, topLevelPackageNameIndex, packageRootIndex, fileNameIndex } : void 0;
        }
        function getParameterTypeNode(parameter) {
            var _a;
            return parameter.kind === 348 /* JSDocParameterTag */ ? (_a = parameter.typeExpression) == null ? void 0 : _a.type : parameter.type;
        }
        function isTypeDeclaration(node) {
            switch (node.kind) {
                case 168 /* TypeParameter */:
                case 263 /* ClassDeclaration */:
                case 264 /* InterfaceDeclaration */:
                case 265 /* TypeAliasDeclaration */:
                case 266 /* EnumDeclaration */:
                case 353 /* JSDocTypedefTag */:
                case 345 /* JSDocCallbackTag */:
                case 347 /* JSDocEnumTag */:
                    return true;
                case 273 /* ImportClause */:
                    return node.isTypeOnly;
                case 276 /* ImportSpecifier */:
                case 281 /* ExportSpecifier */:
                    return node.parent.parent.isTypeOnly;
                default:
                    return false;
            }
        }
        function canHaveExportModifier(node) {
            return isEnumDeclaration(node) || isVariableStatement(node) || isFunctionDeclaration(node) || isClassDeclaration(node) || isInterfaceDeclaration(node) || isTypeDeclaration(node) || isModuleDeclaration(node) && !isExternalModuleAugmentation(node) && !isGlobalScopeAugmentation(node);
        }
        function isOptionalJSDocPropertyLikeTag(node) {
            if (!isJSDocPropertyLikeTag(node)) {
                return false;
            }
            const { isBracketed, typeExpression } = node;
            return isBracketed || !!typeExpression && typeExpression.type.kind === 323 /* JSDocOptionalType */;
        }
        function canUsePropertyAccess(name, languageVersion) {
            if (name.length === 0) {
                return false;
            }
            const firstChar = name.charCodeAt(0);
            return firstChar === 35 /* hash */ ? name.length > 1 && isIdentifierStart(name.charCodeAt(1), languageVersion) : isIdentifierStart(firstChar, languageVersion);
        }
        function hasTabstop(node) {
            var _a;
            return ((_a = getSnippetElement(node)) == null ? void 0 : _a.kind) === 0 /* TabStop */;
        }
        function isJSDocOptionalParameter(node) {
            return isInJSFile(node) && // node.type should only be a JSDocOptionalType when node is a parameter of a JSDocFunctionType
                (node.type && node.type.kind === 323 /* JSDocOptionalType */ || getJSDocParameterTags(node).some(({ isBracketed, typeExpression }) => isBracketed || !!typeExpression && typeExpression.type.kind === 323 /* JSDocOptionalType */));
        }
        function isOptionalDeclaration(declaration) {
            switch (declaration.kind) {
                case 172 /* PropertyDeclaration */:
                case 171 /* PropertySignature */:
                    return !!declaration.questionToken;
                case 169 /* Parameter */:
                    return !!declaration.questionToken || isJSDocOptionalParameter(declaration);
                case 355 /* JSDocPropertyTag */:
                case 348 /* JSDocParameterTag */:
                    return isOptionalJSDocPropertyLikeTag(declaration);
                default:
                    return false;
            }
        }
        function isNonNullAccess(node) {
            const kind = node.kind;
            return (kind === 211 /* PropertyAccessExpression */ || kind === 212 /* ElementAccessExpression */) && isNonNullExpression(node.expression);
        }
        function isJSDocSatisfiesExpression(node) {
            return isInJSFile(node) && isParenthesizedExpression(node) && hasJSDocNodes(node) && !!getJSDocSatisfiesTag(node);
        }
        function getJSDocSatisfiesExpressionType(node) {
            return Debug.checkDefined(tryGetJSDocSatisfiesTypeNode(node));
        }
        function tryGetJSDocSatisfiesTypeNode(node) {
            const tag = getJSDocSatisfiesTag(node);
            return tag && tag.typeExpression && tag.typeExpression.type;
        }
        function getEscapedTextOfJsxAttributeName(node) {
            return isIdentifier(node) ? node.escapedText : getEscapedTextOfJsxNamespacedName(node);
        }
        function getTextOfJsxAttributeName(node) {
            return isIdentifier(node) ? idText(node) : getTextOfJsxNamespacedName(node);
        }
        function isJsxAttributeName(node) {
            const kind = node.kind;
            return kind === 80 /* Identifier */ || kind === 295 /* JsxNamespacedName */;
        }
        function getEscapedTextOfJsxNamespacedName(node) {
            return `${node.namespace.escapedText}:${idText(node.name)}`;
        }
        function getTextOfJsxNamespacedName(node) {
            return `${idText(node.namespace)}:${idText(node.name)}`;
        }
        function intrinsicTagNameToString(node) {
            return isIdentifier(node) ? idText(node) : getTextOfJsxNamespacedName(node);
        }
        function isTypeUsableAsPropertyName(type) {
            return !!(type.flags & 8576 /* StringOrNumberLiteralOrUnique */);
        }
        function getPropertyNameFromType(type) {
            if (type.flags & 8192 /* UniqueESSymbol */) {
                return type.escapedName;
            }
            if (type.flags & (128 /* StringLiteral */ | 256 /* NumberLiteral */)) {
                return escapeLeadingUnderscores("" + type.value);
            }
            return Debug.fail();
        }
        function isExpandoPropertyDeclaration(declaration) {
            return !!declaration && (isPropertyAccessExpression(declaration) || isElementAccessExpression(declaration) || isBinaryExpression(declaration));
        }
        function hasResolutionModeOverride(node) {
            if (node === void 0) {
                return false;
            }
            return !!getResolutionModeOverride(node.attributes);
        }
        function replaceFirstStar(s, replacement) {
            return stringReplace.call(s, "*", replacement);
        }
        function getNameFromImportAttribute(node) {
            return isIdentifier(node.name) ? node.name.escapedText : escapeLeadingUnderscores(node.name.text);
        }
        var resolvingEmptyArray, externalHelpersModuleNameText, defaultMaximumTruncationLength, noTruncationMaximumTruncationLength, stringWriter, getScriptTargetFeatures, GetLiteralTextFlags, fullTripleSlashReferencePathRegEx, fullTripleSlashReferenceTypeReferenceDirectiveRegEx, fullTripleSlashLibReferenceRegEx, fullTripleSlashAMDReferencePathRegEx, fullTripleSlashAMDModuleRegEx, defaultLibReferenceRegEx, AssignmentKind, FunctionFlags, Associativity, OperatorPrecedence, templateSubstitutionRegExp, doubleQuoteEscapedCharsRegExp, singleQuoteEscapedCharsRegExp, backtickQuoteEscapedCharsRegExp, escapedCharsMap, nonAsciiCharacters, jsxDoubleQuoteEscapedCharsRegExp, jsxSingleQuoteEscapedCharsRegExp, jsxEscapedCharsMap, indentStrings, base64Digits, carriageReturnLineFeed, lineFeed, objectAllocator, objectAllocatorPatchers, localizedDiagnosticMessages, computedOptions, getEmitScriptTarget, getEmitModuleKind, getEmitModuleResolutionKind, getEmitModuleDetectionKind, getIsolatedModules, getESModuleInterop, getAllowSyntheticDefaultImports, getResolvePackageJsonExports, getResolvePackageJsonImports, getResolveJsonModule, getEmitDeclarations, shouldPreserveConstEnums, isIncrementalCompilation, getAreDeclarationMapsEnabled, getAllowJSCompilerOption, getUseDefineForClassFields, reservedCharacterPattern, wildcardCharCodes, commonPackageFolders, implicitExcludePathRegexPattern, filesMatcher, directoriesMatcher, excludeMatcher, wildcardMatchers, supportedTSExtensions, supportedTSExtensionsFlat, supportedTSExtensionsWithJson, supportedTSExtensionsForExtractExtension, supportedJSExtensions, supportedJSExtensionsFlat, allSupportedExtensions, allSupportedExtensionsWithJson, supportedDeclarationExtensions, supportedTSImplementationExtensions, extensionsNotSupportingExtensionlessResolution, ModuleSpecifierEnding, extensionsToRemove, emptyFileSystemEntries, stringReplace;
        var init_utilities = __esm({
            "src/compiler/utilities.ts"() {
                "use strict";
                init_ts2();
                resolvingEmptyArray = [];
                externalHelpersModuleNameText = "tslib";
                defaultMaximumTruncationLength = 160;
                noTruncationMaximumTruncationLength = 1e6;
                stringWriter = createSingleLineStringWriter();
                getScriptTargetFeatures = /* @__PURE__ */ memoize(() => new Map(Object.entries({
                    Array: new Map(Object.entries({
                        es2015: [
                            "find",
                            "findIndex",
                            "fill",
                            "copyWithin",
                            "entries",
                            "keys",
                            "values"
                        ],
                        es2016: [
                            "includes"
                        ],
                        es2019: [
                            "flat",
                            "flatMap"
                        ],
                        es2022: [
                            "at"
                        ],
                        es2023: [
                            "findLastIndex",
                            "findLast"
                        ]
                    })),
                    Iterator: new Map(Object.entries({
                        es2015: emptyArray
                    })),
                    AsyncIterator: new Map(Object.entries({
                        es2015: emptyArray
                    })),
                    Atomics: new Map(Object.entries({
                        es2017: emptyArray
                    })),
                    SharedArrayBuffer: new Map(Object.entries({
                        es2017: emptyArray
                    })),
                    AsyncIterable: new Map(Object.entries({
                        es2018: emptyArray
                    })),
                    AsyncIterableIterator: new Map(Object.entries({
                        es2018: emptyArray
                    })),
                    AsyncGenerator: new Map(Object.entries({
                        es2018: emptyArray
                    })),
                    AsyncGeneratorFunction: new Map(Object.entries({
                        es2018: emptyArray
                    })),
                    RegExp: new Map(Object.entries({
                        es2015: [
                            "flags",
                            "sticky",
                            "unicode"
                        ],
                        es2018: [
                            "dotAll"
                        ]
                    })),
                    Reflect: new Map(Object.entries({
                        es2015: [
                            "apply",
                            "construct",
                            "defineProperty",
                            "deleteProperty",
                            "get",
                            "getOwnPropertyDescriptor",
                            "getPrototypeOf",
                            "has",
                            "isExtensible",
                            "ownKeys",
                            "preventExtensions",
                            "set",
                            "setPrototypeOf"
                        ]
                    })),
                    ArrayConstructor: new Map(Object.entries({
                        es2015: [
                            "from",
                            "of"
                        ]
                    })),
                    ObjectConstructor: new Map(Object.entries({
                        es2015: [
                            "assign",
                            "getOwnPropertySymbols",
                            "keys",
                            "is",
                            "setPrototypeOf"
                        ],
                        es2017: [
                            "values",
                            "entries",
                            "getOwnPropertyDescriptors"
                        ],
                        es2019: [
                            "fromEntries"
                        ],
                        es2022: [
                            "hasOwn"
                        ]
                    })),
                    NumberConstructor: new Map(Object.entries({
                        es2015: [
                            "isFinite",
                            "isInteger",
                            "isNaN",
                            "isSafeInteger",
                            "parseFloat",
                            "parseInt"
                        ]
                    })),
                    Math: new Map(Object.entries({
                        es2015: [
                            "clz32",
                            "imul",
                            "sign",
                            "log10",
                            "log2",
                            "log1p",
                            "expm1",
                            "cosh",
                            "sinh",
                            "tanh",
                            "acosh",
                            "asinh",
                            "atanh",
                            "hypot",
                            "trunc",
                            "fround",
                            "cbrt"
                        ]
                    })),
                    Map: new Map(Object.entries({
                        es2015: [
                            "entries",
                            "keys",
                            "values"
                        ]
                    })),
                    Set: new Map(Object.entries({
                        es2015: [
                            "entries",
                            "keys",
                            "values"
                        ]
                    })),
                    PromiseConstructor: new Map(Object.entries({
                        es2015: [
                            "all",
                            "race",
                            "reject",
                            "resolve"
                        ],
                        es2020: [
                            "allSettled"
                        ],
                        es2021: [
                            "any"
                        ]
                    })),
                    Symbol: new Map(Object.entries({
                        es2015: [
                            "for",
                            "keyFor"
                        ],
                        es2019: [
                            "description"
                        ]
                    })),
                    WeakMap: new Map(Object.entries({
                        es2015: [
                            "entries",
                            "keys",
                            "values"
                        ]
                    })),
                    WeakSet: new Map(Object.entries({
                        es2015: [
                            "entries",
                            "keys",
                            "values"
                        ]
                    })),
                    String: new Map(Object.entries({
                        es2015: [
                            "codePointAt",
                            "includes",
                            "endsWith",
                            "normalize",
                            "repeat",
                            "startsWith",
                            "anchor",
                            "big",
                            "blink",
                            "bold",
                            "fixed",
                            "fontcolor",
                            "fontsize",
                            "italics",
                            "link",
                            "small",
                            "strike",
                            "sub",
                            "sup"
                        ],
                        es2017: [
                            "padStart",
                            "padEnd"
                        ],
                        es2019: [
                            "trimStart",
                            "trimEnd",
                            "trimLeft",
                            "trimRight"
                        ],
                        es2020: [
                            "matchAll"
                        ],
                        es2021: [
                            "replaceAll"
                        ],
                        es2022: [
                            "at"
                        ]
                    })),
                    StringConstructor: new Map(Object.entries({
                        es2015: [
                            "fromCodePoint",
                            "raw"
                        ]
                    })),
                    DateTimeFormat: new Map(Object.entries({
                        es2017: [
                            "formatToParts"
                        ]
                    })),
                    Promise: new Map(Object.entries({
                        es2015: emptyArray,
                        es2018: [
                            "finally"
                        ]
                    })),
                    RegExpMatchArray: new Map(Object.entries({
                        es2018: [
                            "groups"
                        ]
                    })),
                    RegExpExecArray: new Map(Object.entries({
                        es2018: [
                            "groups"
                        ]
                    })),
                    Intl: new Map(Object.entries({
                        es2018: [
                            "PluralRules"
                        ]
                    })),
                    NumberFormat: new Map(Object.entries({
                        es2018: [
                            "formatToParts"
                        ]
                    })),
                    SymbolConstructor: new Map(Object.entries({
                        es2020: [
                            "matchAll"
                        ]
                    })),
                    DataView: new Map(Object.entries({
                        es2020: [
                            "setBigInt64",
                            "setBigUint64",
                            "getBigInt64",
                            "getBigUint64"
                        ]
                    })),
                    BigInt: new Map(Object.entries({
                        es2020: emptyArray
                    })),
                    RelativeTimeFormat: new Map(Object.entries({
                        es2020: [
                            "format",
                            "formatToParts",
                            "resolvedOptions"
                        ]
                    })),
                    Int8Array: new Map(Object.entries({
                        es2022: [
                            "at"
                        ],
                        es2023: [
                            "findLastIndex",
                            "findLast"
                        ]
                    })),
                    Uint8Array: new Map(Object.entries({
                        es2022: [
                            "at"
                        ],
                        es2023: [
                            "findLastIndex",
                            "findLast"
                        ]
                    })),
                    Uint8ClampedArray: new Map(Object.entries({
                        es2022: [
                            "at"
                        ],
                        es2023: [
                            "findLastIndex",
                            "findLast"
                        ]
                    })),
                    Int16Array: new Map(Object.entries({
                        es2022: [
                            "at"
                        ],
                        es2023: [
                            "findLastIndex",
                            "findLast"
                        ]
                    })),
                    Uint16Array: new Map(Object.entries({
                        es2022: [
                            "at"
                        ],
                        es2023: [
                            "findLastIndex",
                            "findLast"
                        ]
                    })),
                    Int32Array: new Map(Object.entries({
                        es2022: [
                            "at"
                        ],
                        es2023: [
                            "findLastIndex",
                            "findLast"
                        ]
                    })),
                    Uint32Array: new Map(Object.entries({
                        es2022: [
                            "at"
                        ],
                        es2023: [
                            "findLastIndex",
                            "findLast"
                        ]
                    })),
                    Float32Array: new Map(Object.entries({
                        es2022: [
                            "at"
                        ],
                        es2023: [
                            "findLastIndex",
                            "findLast"
                        ]
                    })),
                    Float64Array: new Map(Object.entries({
                        es2022: [
                            "at"
                        ],
                        es2023: [
                            "findLastIndex",
                            "findLast"
                        ]
                    })),
                    BigInt64Array: new Map(Object.entries({
                        es2020: emptyArray,
                        es2022: [
                            "at"
                        ],
                        es2023: [
                            "findLastIndex",
                            "findLast"
                        ]
                    })),
                    BigUint64Array: new Map(Object.entries({
                        es2020: emptyArray,
                        es2022: [
                            "at"
                        ],
                        es2023: [
                            "findLastIndex",
                            "findLast"
                        ]
                    })),
                    Error: new Map(Object.entries({
                        es2022: [
                            "cause"
                        ]
                    }))
                })));
                GetLiteralTextFlags = /* @__PURE__ */ ((GetLiteralTextFlags2) => {
                    GetLiteralTextFlags2[GetLiteralTextFlags2["None"] = 0] = "None";
                    GetLiteralTextFlags2[GetLiteralTextFlags2["NeverAsciiEscape"] = 1] = "NeverAsciiEscape";
                    GetLiteralTextFlags2[GetLiteralTextFlags2["JsxAttributeEscape"] = 2] = "JsxAttributeEscape";
                    GetLiteralTextFlags2[GetLiteralTextFlags2["TerminateUnterminatedLiterals"] = 4] = "TerminateUnterminatedLiterals";
                    GetLiteralTextFlags2[GetLiteralTextFlags2["AllowNumericSeparator"] = 8] = "AllowNumericSeparator";
                    return GetLiteralTextFlags2;
                })(GetLiteralTextFlags || {});
                fullTripleSlashReferencePathRegEx = /^(\/\/\/\s*<reference\s+path\s*=\s*)(('[^']*')|("[^"]*")).*?\/>/;
                fullTripleSlashReferenceTypeReferenceDirectiveRegEx = /^(\/\/\/\s*<reference\s+types\s*=\s*)(('[^']*')|("[^"]*")).*?\/>/;
                fullTripleSlashLibReferenceRegEx = /^(\/\/\/\s*<reference\s+lib\s*=\s*)(('[^']*')|("[^"]*")).*?\/>/;
                fullTripleSlashAMDReferencePathRegEx = /^(\/\/\/\s*<amd-dependency\s+path\s*=\s*)(('[^']*')|("[^"]*")).*?\/>/;
                fullTripleSlashAMDModuleRegEx = /^\/\/\/\s*<amd-module\s+.*?\/>/;
                defaultLibReferenceRegEx = /^(\/\/\/\s*<reference\s+no-default-lib\s*=\s*)(('[^']*')|("[^"]*"))\s*\/>/;
                AssignmentKind = /* @__PURE__ */ ((AssignmentKind2) => {
                    AssignmentKind2[AssignmentKind2["None"] = 0] = "None";
                    AssignmentKind2[AssignmentKind2["Definite"] = 1] = "Definite";
                    AssignmentKind2[AssignmentKind2["Compound"] = 2] = "Compound";
                    return AssignmentKind2;
                })(AssignmentKind || {});
                FunctionFlags = /* @__PURE__ */ ((FunctionFlags2) => {
                    FunctionFlags2[FunctionFlags2["Normal"] = 0] = "Normal";
                    FunctionFlags2[FunctionFlags2["Generator"] = 1] = "Generator";
                    FunctionFlags2[FunctionFlags2["Async"] = 2] = "Async";
                    FunctionFlags2[FunctionFlags2["Invalid"] = 4] = "Invalid";
                    FunctionFlags2[FunctionFlags2["AsyncGenerator"] = 3] = "AsyncGenerator";
                    return FunctionFlags2;
                })(FunctionFlags || {});
                Associativity = /* @__PURE__ */ ((Associativity2) => {
                    Associativity2[Associativity2["Left"] = 0] = "Left";
                    Associativity2[Associativity2["Right"] = 1] = "Right";
                    return Associativity2;
                })(Associativity || {});
                OperatorPrecedence = /* @__PURE__ */ ((OperatorPrecedence2) => {
                    OperatorPrecedence2[OperatorPrecedence2["Comma"] = 0] = "Comma";
                    OperatorPrecedence2[OperatorPrecedence2["Spread"] = 1] = "Spread";
                    OperatorPrecedence2[OperatorPrecedence2["Yield"] = 2] = "Yield";
                    OperatorPrecedence2[OperatorPrecedence2["Assignment"] = 3] = "Assignment";
                    OperatorPrecedence2[OperatorPrecedence2["Conditional"] = 4] = "Conditional";
                    OperatorPrecedence2[OperatorPrecedence2["Coalesce"] = 4 /* Conditional */] = "Coalesce";
                    OperatorPrecedence2[OperatorPrecedence2["LogicalOR"] = 5] = "LogicalOR";
                    OperatorPrecedence2[OperatorPrecedence2["LogicalAND"] = 6] = "LogicalAND";
                    OperatorPrecedence2[OperatorPrecedence2["BitwiseOR"] = 7] = "BitwiseOR";
                    OperatorPrecedence2[OperatorPrecedence2["BitwiseXOR"] = 8] = "BitwiseXOR";
                    OperatorPrecedence2[OperatorPrecedence2["BitwiseAND"] = 9] = "BitwiseAND";
                    OperatorPrecedence2[OperatorPrecedence2["Equality"] = 10] = "Equality";
                    OperatorPrecedence2[OperatorPrecedence2["Relational"] = 11] = "Relational";
                    OperatorPrecedence2[OperatorPrecedence2["Shift"] = 12] = "Shift";
                    OperatorPrecedence2[OperatorPrecedence2["Additive"] = 13] = "Additive";
                    OperatorPrecedence2[OperatorPrecedence2["Multiplicative"] = 14] = "Multiplicative";
                    OperatorPrecedence2[OperatorPrecedence2["Exponentiation"] = 15] = "Exponentiation";
                    OperatorPrecedence2[OperatorPrecedence2["Unary"] = 16] = "Unary";
                    OperatorPrecedence2[OperatorPrecedence2["Update"] = 17] = "Update";
                    OperatorPrecedence2[OperatorPrecedence2["LeftHandSide"] = 18] = "LeftHandSide";
                    OperatorPrecedence2[OperatorPrecedence2["Member"] = 19] = "Member";
                    OperatorPrecedence2[OperatorPrecedence2["Primary"] = 20] = "Primary";
                    OperatorPrecedence2[OperatorPrecedence2["Highest"] = 20 /* Primary */] = "Highest";
                    OperatorPrecedence2[OperatorPrecedence2["Lowest"] = 0 /* Comma */] = "Lowest";
                    OperatorPrecedence2[OperatorPrecedence2["Invalid"] = -1] = "Invalid";
                    return OperatorPrecedence2;
                })(OperatorPrecedence || {});
                templateSubstitutionRegExp = /\$\{/g;
                doubleQuoteEscapedCharsRegExp = /[\\"\u0000-\u001f\t\v\f\b\r\n\u2028\u2029\u0085]/g;
                singleQuoteEscapedCharsRegExp = /[\\'\u0000-\u001f\t\v\f\b\r\n\u2028\u2029\u0085]/g;
                backtickQuoteEscapedCharsRegExp = /\r\n|[\\`\u0000-\u001f\t\v\f\b\r\u2028\u2029\u0085]/g;
                escapedCharsMap = new Map(Object.entries({
                    "	": "\\t",
                    "\v": "\\v",
                    "\f": "\\f",
                    "\b": "\\b",
                    "\r": "\\r",
                    "\n": "\\n",
                    "\\": "\\\\",
                    '"': '\\"',
                    "'": "\\'",
                    "`": "\\`",
                    "\u2028": "\\u2028",
                    // lineSeparator
                    "\u2029": "\\u2029",
                    // paragraphSeparator
                    "\x85": "\\u0085",
                    // nextLine
                    "\r\n": "\\r\\n"
                    // special case for CRLFs in backticks
                }));
                nonAsciiCharacters = /[^\u0000-\u007F]/g;
                jsxDoubleQuoteEscapedCharsRegExp = /["\u0000-\u001f\u2028\u2029\u0085]/g;
                jsxSingleQuoteEscapedCharsRegExp = /['\u0000-\u001f\u2028\u2029\u0085]/g;
                jsxEscapedCharsMap = new Map(Object.entries({
                    '"': "&quot;",
                    "'": "&apos;"
                }));
                indentStrings = ["", "    "];
                base64Digits = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=";
                carriageReturnLineFeed = "\r\n";
                lineFeed = "\n";
                objectAllocator = {
                    getNodeConstructor: () => Node4,
                    getTokenConstructor: () => Token,
                    getIdentifierConstructor: () => Identifier2,
                    getPrivateIdentifierConstructor: () => Node4,
                    getSourceFileConstructor: () => Node4,
                    getSymbolConstructor: () => Symbol4,
                    getTypeConstructor: () => Type3,
                    getSignatureConstructor: () => Signature2,
                    getSourceMapSourceConstructor: () => SourceMapSource
                };
                objectAllocatorPatchers = [];
                computedOptions = createComputedCompilerOptions({
                    target: {
                        dependencies: ["module"],
                        computeValue: (compilerOptions) => {
                            return compilerOptions.target ?? (compilerOptions.module === 100 /* Node16 */ && 9 /* ES2022 */ || compilerOptions.module === 199 /* NodeNext */ && 99 /* ESNext */ || 1 /* ES5 */);
                        }
                    },
                    module: {
                        dependencies: ["target"],
                        computeValue: (compilerOptions) => {
                            return typeof compilerOptions.module === "number" ? compilerOptions.module : computedOptions.target.computeValue(compilerOptions) >= 2 /* ES2015 */ ? 5 /* ES2015 */ : 1 /* CommonJS */;
                        }
                    },
                    moduleResolution: {
                        dependencies: ["module", "target"],
                        computeValue: (compilerOptions) => {
                            let moduleResolution = compilerOptions.moduleResolution;
                            if (moduleResolution === void 0) {
                                switch (computedOptions.module.computeValue(compilerOptions)) {
                                    case 1 /* CommonJS */:
                                        moduleResolution = 2 /* Node10 */;
                                        break;
                                    case 100 /* Node16 */:
                                        moduleResolution = 3 /* Node16 */;
                                        break;
                                    case 199 /* NodeNext */:
                                        moduleResolution = 99 /* NodeNext */;
                                        break;
                                    case 200 /* Preserve */:
                                        moduleResolution = 100 /* Bundler */;
                                        break;
                                    default:
                                        moduleResolution = 1 /* Classic */;
                                        break;
                                }
                            }
                            return moduleResolution;
                        }
                    },
                    moduleDetection: {
                        dependencies: ["module", "target"],
                        computeValue: (compilerOptions) => {
                            return compilerOptions.moduleDetection || (computedOptions.module.computeValue(compilerOptions) === 100 /* Node16 */ || computedOptions.module.computeValue(compilerOptions) === 199 /* NodeNext */ ? 3 /* Force */ : 2 /* Auto */);
                        }
                    },
                    isolatedModules: {
                        dependencies: ["verbatimModuleSyntax"],
                        computeValue: (compilerOptions) => {
                            return !!(compilerOptions.isolatedModules || compilerOptions.verbatimModuleSyntax);
                        }
                    },
                    esModuleInterop: {
                        dependencies: ["module", "target"],
                        computeValue: (compilerOptions) => {
                            if (compilerOptions.esModuleInterop !== void 0) {
                                return compilerOptions.esModuleInterop;
                            }
                            switch (computedOptions.module.computeValue(compilerOptions)) {
                                case 100 /* Node16 */:
                                case 199 /* NodeNext */:
                                case 200 /* Preserve */:
                                    return true;
                            }
                            return false;
                        }
                    },
                    allowSyntheticDefaultImports: {
                        dependencies: ["module", "target", "moduleResolution"],
                        computeValue: (compilerOptions) => {
                            if (compilerOptions.allowSyntheticDefaultImports !== void 0) {
                                return compilerOptions.allowSyntheticDefaultImports;
                            }
                            return computedOptions.esModuleInterop.computeValue(compilerOptions) || computedOptions.module.computeValue(compilerOptions) === 4 /* System */ || computedOptions.moduleResolution.computeValue(compilerOptions) === 100 /* Bundler */;
                        }
                    },
                    resolvePackageJsonExports: {
                        dependencies: ["moduleResolution"],
                        computeValue: (compilerOptions) => {
                            const moduleResolution = computedOptions.moduleResolution.computeValue(compilerOptions);
                            if (!moduleResolutionSupportsPackageJsonExportsAndImports(moduleResolution)) {
                                return false;
                            }
                            if (compilerOptions.resolvePackageJsonExports !== void 0) {
                                return compilerOptions.resolvePackageJsonExports;
                            }
                            switch (moduleResolution) {
                                case 3 /* Node16 */:
                                case 99 /* NodeNext */:
                                case 100 /* Bundler */:
                                    return true;
                            }
                            return false;
                        }
                    },
                    resolvePackageJsonImports: {
                        dependencies: ["moduleResolution", "resolvePackageJsonExports"],
                        computeValue: (compilerOptions) => {
                            const moduleResolution = computedOptions.moduleResolution.computeValue(compilerOptions);
                            if (!moduleResolutionSupportsPackageJsonExportsAndImports(moduleResolution)) {
                                return false;
                            }
                            if (compilerOptions.resolvePackageJsonExports !== void 0) {
                                return compilerOptions.resolvePackageJsonExports;
                            }
                            switch (moduleResolution) {
                                case 3 /* Node16 */:
                                case 99 /* NodeNext */:
                                case 100 /* Bundler */:
                                    return true;
                            }
                            return false;
                        }
                    },
                    resolveJsonModule: {
                        dependencies: ["moduleResolution", "module", "target"],
                        computeValue: (compilerOptions) => {
                            if (compilerOptions.resolveJsonModule !== void 0) {
                                return compilerOptions.resolveJsonModule;
                            }
                            return computedOptions.moduleResolution.computeValue(compilerOptions) === 100 /* Bundler */;
                        }
                    },
                    declaration: {
                        dependencies: ["composite"],
                        computeValue: (compilerOptions) => {
                            return !!(compilerOptions.declaration || compilerOptions.composite);
                        }
                    },
                    preserveConstEnums: {
                        dependencies: ["isolatedModules", "verbatimModuleSyntax"],
                        computeValue: (compilerOptions) => {
                            return !!(compilerOptions.preserveConstEnums || computedOptions.isolatedModules.computeValue(compilerOptions));
                        }
                    },
                    incremental: {
                        dependencies: ["composite"],
                        computeValue: (compilerOptions) => {
                            return !!(compilerOptions.incremental || compilerOptions.composite);
                        }
                    },
                    declarationMap: {
                        dependencies: ["declaration", "composite"],
                        computeValue: (compilerOptions) => {
                            return !!(compilerOptions.declarationMap && computedOptions.declaration.computeValue(compilerOptions));
                        }
                    },
                    allowJs: {
                        dependencies: ["checkJs"],
                        computeValue: (compilerOptions) => {
                            return compilerOptions.allowJs === void 0 ? !!compilerOptions.checkJs : compilerOptions.allowJs;
                        }
                    },
                    useDefineForClassFields: {
                        dependencies: ["target", "module"],
                        computeValue: (compilerOptions) => {
                            return compilerOptions.useDefineForClassFields === void 0 ? computedOptions.target.computeValue(compilerOptions) >= 9 /* ES2022 */ : compilerOptions.useDefineForClassFields;
                        }
                    },
                    noImplicitAny: {
                        dependencies: ["strict"],
                        computeValue: (compilerOptions) => {
                            return getStrictOptionValue(compilerOptions, "noImplicitAny");
                        }
                    },
                    noImplicitThis: {
                        dependencies: ["strict"],
                        computeValue: (compilerOptions) => {
                            return getStrictOptionValue(compilerOptions, "noImplicitThis");
                        }
                    },
                    strictNullChecks: {
                        dependencies: ["strict"],
                        computeValue: (compilerOptions) => {
                            return getStrictOptionValue(compilerOptions, "strictNullChecks");
                        }
                    },
                    strictFunctionTypes: {
                        dependencies: ["strict"],
                        computeValue: (compilerOptions) => {
                            return getStrictOptionValue(compilerOptions, "strictFunctionTypes");
                        }
                    },
                    strictBindCallApply: {
                        dependencies: ["strict"],
                        computeValue: (compilerOptions) => {
                            return getStrictOptionValue(compilerOptions, "strictBindCallApply");
                        }
                    },
                    strictPropertyInitialization: {
                        dependencies: ["strict"],
                        computeValue: (compilerOptions) => {
                            return getStrictOptionValue(compilerOptions, "strictPropertyInitialization");
                        }
                    },
                    alwaysStrict: {
                        dependencies: ["strict"],
                        computeValue: (compilerOptions) => {
                            return getStrictOptionValue(compilerOptions, "alwaysStrict");
                        }
                    },
                    useUnknownInCatchVariables: {
                        dependencies: ["strict"],
                        computeValue: (compilerOptions) => {
                            return getStrictOptionValue(compilerOptions, "useUnknownInCatchVariables");
                        }
                    }
                });
                getEmitScriptTarget = computedOptions.target.computeValue;
                getEmitModuleKind = computedOptions.module.computeValue;
                getEmitModuleResolutionKind = computedOptions.moduleResolution.computeValue;
                getEmitModuleDetectionKind = computedOptions.moduleDetection.computeValue;
                getIsolatedModules = computedOptions.isolatedModules.computeValue;
                getESModuleInterop = computedOptions.esModuleInterop.computeValue;
                getAllowSyntheticDefaultImports = computedOptions.allowSyntheticDefaultImports.computeValue;
                getResolvePackageJsonExports = computedOptions.resolvePackageJsonExports.computeValue;
                getResolvePackageJsonImports = computedOptions.resolvePackageJsonImports.computeValue;
                getResolveJsonModule = computedOptions.resolveJsonModule.computeValue;
                getEmitDeclarations = computedOptions.declaration.computeValue;
                shouldPreserveConstEnums = computedOptions.preserveConstEnums.computeValue;
                isIncrementalCompilation = computedOptions.incremental.computeValue;
                getAreDeclarationMapsEnabled = computedOptions.declarationMap.computeValue;
                getAllowJSCompilerOption = computedOptions.allowJs.computeValue;
                getUseDefineForClassFields = computedOptions.useDefineForClassFields.computeValue;
                reservedCharacterPattern = /[^\w\s/]/g;
                wildcardCharCodes = [42 /* asterisk */, 63 /* question */];
                commonPackageFolders = ["node_modules", "bower_components", "jspm_packages"];
                implicitExcludePathRegexPattern = `(?!(${commonPackageFolders.join("|")})(/|$))`;
                filesMatcher = {
                    /**
                     * Matches any single directory segment unless it is the last segment and a .min.js file
                     * Breakdown:
                     *  [^./]                   # matches everything up to the first . character (excluding directory separators)
                     *  (\\.(?!min\\.js$))?     # matches . characters but not if they are part of the .min.js file extension
                     */
                    singleAsteriskRegexFragment: "([^./]|(\\.(?!min\\.js$))?)*",
                    /**
                     * Regex for the ** wildcard. Matches any number of subdirectories. When used for including
                     * files or directories, does not match subdirectories that start with a . character
                     */
                    doubleAsteriskRegexFragment: `(/${implicitExcludePathRegexPattern}[^/.][^/]*)*?`,
                    replaceWildcardCharacter: (match) => replaceWildcardCharacter(match, filesMatcher.singleAsteriskRegexFragment)
                };
                directoriesMatcher = {
                    singleAsteriskRegexFragment: "[^/]*",
                    /**
                     * Regex for the ** wildcard. Matches any number of subdirectories. When used for including
                     * files or directories, does not match subdirectories that start with a . character
                     */
                    doubleAsteriskRegexFragment: `(/${implicitExcludePathRegexPattern}[^/.][^/]*)*?`,
                    replaceWildcardCharacter: (match) => replaceWildcardCharacter(match, directoriesMatcher.singleAsteriskRegexFragment)
                };
                excludeMatcher = {
                    singleAsteriskRegexFragment: "[^/]*",
                    doubleAsteriskRegexFragment: "(/.+?)?",
                    replaceWildcardCharacter: (match) => replaceWildcardCharacter(match, excludeMatcher.singleAsteriskRegexFragment)
                };
                wildcardMatchers = {
                    files: filesMatcher,
                    directories: directoriesMatcher,
                    exclude: excludeMatcher
                };
                supportedTSExtensions = [[".ts" /* Ts */, ".tsx" /* Tsx */, ".d.ts" /* Dts */], [".cts" /* Cts */, ".d.cts" /* Dcts */], [".mts" /* Mts */, ".d.mts" /* Dmts */]];
                supportedTSExtensionsFlat = flatten(supportedTSExtensions);
                supportedTSExtensionsWithJson = [...supportedTSExtensions, [".json" /* Json */]];
                supportedTSExtensionsForExtractExtension = [".d.ts" /* Dts */, ".d.cts" /* Dcts */, ".d.mts" /* Dmts */, ".cts" /* Cts */, ".mts" /* Mts */, ".ts" /* Ts */, ".tsx" /* Tsx */];
                supportedJSExtensions = [[".js" /* Js */, ".jsx" /* Jsx */], [".mjs" /* Mjs */], [".cjs" /* Cjs */]];
                supportedJSExtensionsFlat = flatten(supportedJSExtensions);
                allSupportedExtensions = [[".ts" /* Ts */, ".tsx" /* Tsx */, ".d.ts" /* Dts */, ".js" /* Js */, ".jsx" /* Jsx */], [".cts" /* Cts */, ".d.cts" /* Dcts */, ".cjs" /* Cjs */], [".mts" /* Mts */, ".d.mts" /* Dmts */, ".mjs" /* Mjs */]];
                allSupportedExtensionsWithJson = [...allSupportedExtensions, [".json" /* Json */]];
                supportedDeclarationExtensions = [".d.ts" /* Dts */, ".d.cts" /* Dcts */, ".d.mts" /* Dmts */];
                supportedTSImplementationExtensions = [".ts" /* Ts */, ".cts" /* Cts */, ".mts" /* Mts */, ".tsx" /* Tsx */];
                extensionsNotSupportingExtensionlessResolution = [".mts" /* Mts */, ".d.mts" /* Dmts */, ".mjs" /* Mjs */, ".cts" /* Cts */, ".d.cts" /* Dcts */, ".cjs" /* Cjs */];
                ModuleSpecifierEnding = /* @__PURE__ */ ((ModuleSpecifierEnding2) => {
                    ModuleSpecifierEnding2[ModuleSpecifierEnding2["Minimal"] = 0] = "Minimal";
                    ModuleSpecifierEnding2[ModuleSpecifierEnding2["Index"] = 1] = "Index";
                    ModuleSpecifierEnding2[ModuleSpecifierEnding2["JsExtension"] = 2] = "JsExtension";
                    ModuleSpecifierEnding2[ModuleSpecifierEnding2["TsExtension"] = 3] = "TsExtension";
                    return ModuleSpecifierEnding2;
                })(ModuleSpecifierEnding || {});
                extensionsToRemove = [".d.ts" /* Dts */, ".d.mts" /* Dmts */, ".d.cts" /* Dcts */, ".mjs" /* Mjs */, ".mts" /* Mts */, ".cjs" /* Cjs */, ".cts" /* Cts */, ".ts" /* Ts */, ".js" /* Js */, ".tsx" /* Tsx */, ".jsx" /* Jsx */, ".json" /* Json */];
                emptyFileSystemEntries = {
                    files: emptyArray,
                    directories: emptyArray
                };
                stringReplace = String.prototype.replace;
            }
        });
        // src/compiler/factory/baseNodeFactory.ts
        function createBaseNodeFactory() {
            let NodeConstructor2;
            let TokenConstructor2;
            let IdentifierConstructor2;
            let PrivateIdentifierConstructor2;
            let SourceFileConstructor2;
            return {
                createBaseSourceFileNode,
                createBaseIdentifierNode,
                createBasePrivateIdentifierNode,
                createBaseTokenNode,
                createBaseNode
            };
            function createBaseSourceFileNode(kind) {
                return new (SourceFileConstructor2 || (SourceFileConstructor2 = objectAllocator.getSourceFileConstructor()))(kind, 
                /*pos*/
                -1, 
                /*end*/
                -1);
            }
            function createBaseIdentifierNode(kind) {
                return new (IdentifierConstructor2 || (IdentifierConstructor2 = objectAllocator.getIdentifierConstructor()))(kind, 
                /*pos*/
                -1, 
                /*end*/
                -1);
            }
            function createBasePrivateIdentifierNode(kind) {
                return new (PrivateIdentifierConstructor2 || (PrivateIdentifierConstructor2 = objectAllocator.getPrivateIdentifierConstructor()))(kind, 
                /*pos*/
                -1, 
                /*end*/
                -1);
            }
            function createBaseTokenNode(kind) {
                return new (TokenConstructor2 || (TokenConstructor2 = objectAllocator.getTokenConstructor()))(kind, 
                /*pos*/
                -1, 
                /*end*/
                -1);
            }
            function createBaseNode(kind) {
                return new (NodeConstructor2 || (NodeConstructor2 = objectAllocator.getNodeConstructor()))(kind, 
                /*pos*/
                -1, 
                /*end*/
                -1);
            }
        }
        var init_baseNodeFactory = __esm({
            "src/compiler/factory/baseNodeFactory.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/factory/parenthesizerRules.ts
        function createParenthesizerRules(factory2) {
            let binaryLeftOperandParenthesizerCache;
            let binaryRightOperandParenthesizerCache;
            return {
                getParenthesizeLeftSideOfBinaryForOperator,
                getParenthesizeRightSideOfBinaryForOperator,
                parenthesizeLeftSideOfBinary,
                parenthesizeRightSideOfBinary,
                parenthesizeExpressionOfComputedPropertyName,
                parenthesizeConditionOfConditionalExpression,
                parenthesizeBranchOfConditionalExpression,
                parenthesizeExpressionOfExportDefault,
                parenthesizeExpressionOfNew,
                parenthesizeLeftSideOfAccess,
                parenthesizeOperandOfPostfixUnary,
                parenthesizeOperandOfPrefixUnary,
                parenthesizeExpressionsOfCommaDelimitedList,
                parenthesizeExpressionForDisallowedComma,
                parenthesizeExpressionOfExpressionStatement,
                parenthesizeConciseBodyOfArrowFunction,
                parenthesizeCheckTypeOfConditionalType,
                parenthesizeExtendsTypeOfConditionalType,
                parenthesizeConstituentTypesOfUnionType,
                parenthesizeConstituentTypeOfUnionType,
                parenthesizeConstituentTypesOfIntersectionType,
                parenthesizeConstituentTypeOfIntersectionType,
                parenthesizeOperandOfTypeOperator,
                parenthesizeOperandOfReadonlyTypeOperator,
                parenthesizeNonArrayTypeOfPostfixType,
                parenthesizeElementTypesOfTupleType,
                parenthesizeElementTypeOfTupleType,
                parenthesizeTypeOfOptionalType,
                parenthesizeTypeArguments,
                parenthesizeLeadingTypeArgument
            };
            function getParenthesizeLeftSideOfBinaryForOperator(operatorKind) {
                binaryLeftOperandParenthesizerCache || (binaryLeftOperandParenthesizerCache = /* @__PURE__ */ new Map());
                let parenthesizerRule = binaryLeftOperandParenthesizerCache.get(operatorKind);
                if (!parenthesizerRule) {
                    parenthesizerRule = (node) => parenthesizeLeftSideOfBinary(operatorKind, node);
                    binaryLeftOperandParenthesizerCache.set(operatorKind, parenthesizerRule);
                }
                return parenthesizerRule;
            }
            function getParenthesizeRightSideOfBinaryForOperator(operatorKind) {
                binaryRightOperandParenthesizerCache || (binaryRightOperandParenthesizerCache = /* @__PURE__ */ new Map());
                let parenthesizerRule = binaryRightOperandParenthesizerCache.get(operatorKind);
                if (!parenthesizerRule) {
                    parenthesizerRule = (node) => parenthesizeRightSideOfBinary(operatorKind, 
                    /*leftSide*/
                    void 0, node);
                    binaryRightOperandParenthesizerCache.set(operatorKind, parenthesizerRule);
                }
                return parenthesizerRule;
            }
            function binaryOperandNeedsParentheses(binaryOperator, operand, isLeftSideOfBinary, leftOperand) {
                const binaryOperatorPrecedence = getOperatorPrecedence(226 /* BinaryExpression */, binaryOperator);
                const binaryOperatorAssociativity = getOperatorAssociativity(226 /* BinaryExpression */, binaryOperator);
                const emittedOperand = skipPartiallyEmittedExpressions(operand);
                if (!isLeftSideOfBinary && operand.kind === 219 /* ArrowFunction */ && binaryOperatorPrecedence > 3 /* Assignment */) {
                    return true;
                }
                const operandPrecedence = getExpressionPrecedence(emittedOperand);
                switch (compareValues(operandPrecedence, binaryOperatorPrecedence)) {
                    case -1 /* LessThan */:
                        if (!isLeftSideOfBinary && binaryOperatorAssociativity === 1 /* Right */ && operand.kind === 229 /* YieldExpression */) {
                            return false;
                        }
                        return true;
                    case 1 /* GreaterThan */:
                        return false;
                    case 0 /* EqualTo */:
                        if (isLeftSideOfBinary) {
                            return binaryOperatorAssociativity === 1 /* Right */;
                        }
                        else {
                            if (isBinaryExpression(emittedOperand) && emittedOperand.operatorToken.kind === binaryOperator) {
                                if (operatorHasAssociativeProperty(binaryOperator)) {
                                    return false;
                                }
                                if (binaryOperator === 40 /* PlusToken */) {
                                    const leftKind = leftOperand ? getLiteralKindOfBinaryPlusOperand(leftOperand) : 0 /* Unknown */;
                                    if (isLiteralKind(leftKind) && leftKind === getLiteralKindOfBinaryPlusOperand(emittedOperand)) {
                                        return false;
                                    }
                                }
                            }
                            const operandAssociativity = getExpressionAssociativity(emittedOperand);
                            return operandAssociativity === 0 /* Left */;
                        }
                }
            }
            function operatorHasAssociativeProperty(binaryOperator) {
                return binaryOperator === 42 /* AsteriskToken */ || binaryOperator === 52 /* BarToken */ || binaryOperator === 51 /* AmpersandToken */ || binaryOperator === 53 /* CaretToken */ || binaryOperator === 28 /* CommaToken */;
            }
            function getLiteralKindOfBinaryPlusOperand(node) {
                node = skipPartiallyEmittedExpressions(node);
                if (isLiteralKind(node.kind)) {
                    return node.kind;
                }
                if (node.kind === 226 /* BinaryExpression */ && node.operatorToken.kind === 40 /* PlusToken */) {
                    if (node.cachedLiteralKind !== void 0) {
                        return node.cachedLiteralKind;
                    }
                    const leftKind = getLiteralKindOfBinaryPlusOperand(node.left);
                    const literalKind = isLiteralKind(leftKind) && leftKind === getLiteralKindOfBinaryPlusOperand(node.right) ? leftKind : 0 /* Unknown */;
                    node.cachedLiteralKind = literalKind;
                    return literalKind;
                }
                return 0 /* Unknown */;
            }
            function parenthesizeBinaryOperand(binaryOperator, operand, isLeftSideOfBinary, leftOperand) {
                const skipped = skipPartiallyEmittedExpressions(operand);
                if (skipped.kind === 217 /* ParenthesizedExpression */) {
                    return operand;
                }
                return binaryOperandNeedsParentheses(binaryOperator, operand, isLeftSideOfBinary, leftOperand) ? factory2.createParenthesizedExpression(operand) : operand;
            }
            function parenthesizeLeftSideOfBinary(binaryOperator, leftSide) {
                return parenthesizeBinaryOperand(binaryOperator, leftSide, 
                /*isLeftSideOfBinary*/
                true);
            }
            function parenthesizeRightSideOfBinary(binaryOperator, leftSide, rightSide) {
                return parenthesizeBinaryOperand(binaryOperator, rightSide, 
                /*isLeftSideOfBinary*/
                false, leftSide);
            }
            function parenthesizeExpressionOfComputedPropertyName(expression) {
                return isCommaSequence(expression) ? factory2.createParenthesizedExpression(expression) : expression;
            }
            function parenthesizeConditionOfConditionalExpression(condition) {
                const conditionalPrecedence = getOperatorPrecedence(227 /* ConditionalExpression */, 58 /* QuestionToken */);
                const emittedCondition = skipPartiallyEmittedExpressions(condition);
                const conditionPrecedence = getExpressionPrecedence(emittedCondition);
                if (compareValues(conditionPrecedence, conditionalPrecedence) !== 1 /* GreaterThan */) {
                    return factory2.createParenthesizedExpression(condition);
                }
                return condition;
            }
            function parenthesizeBranchOfConditionalExpression(branch) {
                const emittedExpression = skipPartiallyEmittedExpressions(branch);
                return isCommaSequence(emittedExpression) ? factory2.createParenthesizedExpression(branch) : branch;
            }
            function parenthesizeExpressionOfExportDefault(expression) {
                const check = skipPartiallyEmittedExpressions(expression);
                let needsParens = isCommaSequence(check);
                if (!needsParens) {
                    switch (getLeftmostExpression(check, 
                    /*stopAtCallExpressions*/
                    false).kind) {
                        case 231 /* ClassExpression */:
                        case 218 /* FunctionExpression */:
                            needsParens = true;
                    }
                }
                return needsParens ? factory2.createParenthesizedExpression(expression) : expression;
            }
            function parenthesizeExpressionOfNew(expression) {
                const leftmostExpr = getLeftmostExpression(expression, 
                /*stopAtCallExpressions*/
                true);
                switch (leftmostExpr.kind) {
                    case 213 /* CallExpression */:
                        return factory2.createParenthesizedExpression(expression);
                    case 214 /* NewExpression */:
                        return !leftmostExpr.arguments ? factory2.createParenthesizedExpression(expression) : expression;
                }
                return parenthesizeLeftSideOfAccess(expression);
            }
            function parenthesizeLeftSideOfAccess(expression, optionalChain) {
                const emittedExpression = skipPartiallyEmittedExpressions(expression);
                if (isLeftHandSideExpression(emittedExpression) && (emittedExpression.kind !== 214 /* NewExpression */ || emittedExpression.arguments) && (optionalChain || !isOptionalChain(emittedExpression))) {
                    return expression;
                }
                return setTextRange(factory2.createParenthesizedExpression(expression), expression);
            }
            function parenthesizeOperandOfPostfixUnary(operand) {
                return isLeftHandSideExpression(operand) ? operand : setTextRange(factory2.createParenthesizedExpression(operand), operand);
            }
            function parenthesizeOperandOfPrefixUnary(operand) {
                return isUnaryExpression(operand) ? operand : setTextRange(factory2.createParenthesizedExpression(operand), operand);
            }
            function parenthesizeExpressionsOfCommaDelimitedList(elements) {
                const result = sameMap(elements, parenthesizeExpressionForDisallowedComma);
                return setTextRange(factory2.createNodeArray(result, elements.hasTrailingComma), elements);
            }
            function parenthesizeExpressionForDisallowedComma(expression) {
                const emittedExpression = skipPartiallyEmittedExpressions(expression);
                const expressionPrecedence = getExpressionPrecedence(emittedExpression);
                const commaPrecedence = getOperatorPrecedence(226 /* BinaryExpression */, 28 /* CommaToken */);
                return expressionPrecedence > commaPrecedence ? expression : setTextRange(factory2.createParenthesizedExpression(expression), expression);
            }
            function parenthesizeExpressionOfExpressionStatement(expression) {
                const emittedExpression = skipPartiallyEmittedExpressions(expression);
                if (isCallExpression(emittedExpression)) {
                    const callee = emittedExpression.expression;
                    const kind = skipPartiallyEmittedExpressions(callee).kind;
                    if (kind === 218 /* FunctionExpression */ || kind === 219 /* ArrowFunction */) {
                        const updated = factory2.updateCallExpression(emittedExpression, setTextRange(factory2.createParenthesizedExpression(callee), callee), emittedExpression.typeArguments, emittedExpression.arguments);
                        return factory2.restoreOuterExpressions(expression, updated, 8 /* PartiallyEmittedExpressions */);
                    }
                }
                const leftmostExpressionKind = getLeftmostExpression(emittedExpression, 
                /*stopAtCallExpressions*/
                false).kind;
                if (leftmostExpressionKind === 210 /* ObjectLiteralExpression */ || leftmostExpressionKind === 218 /* FunctionExpression */) {
                    return setTextRange(factory2.createParenthesizedExpression(expression), expression);
                }
                return expression;
            }
            function parenthesizeConciseBodyOfArrowFunction(body) {
                if (!isBlock(body) && (isCommaSequence(body) || getLeftmostExpression(body, 
                /*stopAtCallExpressions*/
                false).kind === 210 /* ObjectLiteralExpression */)) {
                    return setTextRange(factory2.createParenthesizedExpression(body), body);
                }
                return body;
            }
            function parenthesizeCheckTypeOfConditionalType(checkType) {
                switch (checkType.kind) {
                    case 184 /* FunctionType */:
                    case 185 /* ConstructorType */:
                    case 194 /* ConditionalType */:
                        return factory2.createParenthesizedType(checkType);
                }
                return checkType;
            }
            function parenthesizeExtendsTypeOfConditionalType(extendsType) {
                switch (extendsType.kind) {
                    case 194 /* ConditionalType */:
                        return factory2.createParenthesizedType(extendsType);
                }
                return extendsType;
            }
            function parenthesizeConstituentTypeOfUnionType(type) {
                switch (type.kind) {
                    case 192 /* UnionType */:
                    case 193 /* IntersectionType */:
                        return factory2.createParenthesizedType(type);
                }
                return parenthesizeCheckTypeOfConditionalType(type);
            }
            function parenthesizeConstituentTypesOfUnionType(members) {
                return factory2.createNodeArray(sameMap(members, parenthesizeConstituentTypeOfUnionType));
            }
            function parenthesizeConstituentTypeOfIntersectionType(type) {
                switch (type.kind) {
                    case 192 /* UnionType */:
                    case 193 /* IntersectionType */:
                        return factory2.createParenthesizedType(type);
                }
                return parenthesizeConstituentTypeOfUnionType(type);
            }
            function parenthesizeConstituentTypesOfIntersectionType(members) {
                return factory2.createNodeArray(sameMap(members, parenthesizeConstituentTypeOfIntersectionType));
            }
            function parenthesizeOperandOfTypeOperator(type) {
                switch (type.kind) {
                    case 193 /* IntersectionType */:
                        return factory2.createParenthesizedType(type);
                }
                return parenthesizeConstituentTypeOfIntersectionType(type);
            }
            function parenthesizeOperandOfReadonlyTypeOperator(type) {
                switch (type.kind) {
                    case 198 /* TypeOperator */:
                        return factory2.createParenthesizedType(type);
                }
                return parenthesizeOperandOfTypeOperator(type);
            }
            function parenthesizeNonArrayTypeOfPostfixType(type) {
                switch (type.kind) {
                    case 195 /* InferType */:
                    case 198 /* TypeOperator */:
                    case 186 /* TypeQuery */:
                        return factory2.createParenthesizedType(type);
                }
                return parenthesizeOperandOfTypeOperator(type);
            }
            function parenthesizeElementTypesOfTupleType(types) {
                return factory2.createNodeArray(sameMap(types, parenthesizeElementTypeOfTupleType));
            }
            function parenthesizeElementTypeOfTupleType(type) {
                if (hasJSDocPostfixQuestion(type))
                    return factory2.createParenthesizedType(type);
                return type;
            }
            function hasJSDocPostfixQuestion(type) {
                if (isJSDocNullableType(type))
                    return type.postfix;
                if (isNamedTupleMember(type))
                    return hasJSDocPostfixQuestion(type.type);
                if (isFunctionTypeNode(type) || isConstructorTypeNode(type) || isTypeOperatorNode(type))
                    return hasJSDocPostfixQuestion(type.type);
                if (isConditionalTypeNode(type))
                    return hasJSDocPostfixQuestion(type.falseType);
                if (isUnionTypeNode(type))
                    return hasJSDocPostfixQuestion(last(type.types));
                if (isIntersectionTypeNode(type))
                    return hasJSDocPostfixQuestion(last(type.types));
                if (isInferTypeNode(type))
                    return !!type.typeParameter.constraint && hasJSDocPostfixQuestion(type.typeParameter.constraint);
                return false;
            }
            function parenthesizeTypeOfOptionalType(type) {
                if (hasJSDocPostfixQuestion(type))
                    return factory2.createParenthesizedType(type);
                return parenthesizeNonArrayTypeOfPostfixType(type);
            }
            function parenthesizeLeadingTypeArgument(node) {
                return isFunctionOrConstructorTypeNode(node) && node.typeParameters ? factory2.createParenthesizedType(node) : node;
            }
            function parenthesizeOrdinalTypeArgument(node, i) {
                return i === 0 ? parenthesizeLeadingTypeArgument(node) : node;
            }
            function parenthesizeTypeArguments(typeArguments) {
                if (some(typeArguments)) {
                    return factory2.createNodeArray(sameMap(typeArguments, parenthesizeOrdinalTypeArgument));
                }
            }
        }
        var nullParenthesizerRules;
        var init_parenthesizerRules = __esm({
            "src/compiler/factory/parenthesizerRules.ts"() {
                "use strict";
                init_ts2();
                nullParenthesizerRules = {
                    getParenthesizeLeftSideOfBinaryForOperator: (_) => identity,
                    getParenthesizeRightSideOfBinaryForOperator: (_) => identity,
                    parenthesizeLeftSideOfBinary: (_binaryOperator, leftSide) => leftSide,
                    parenthesizeRightSideOfBinary: (_binaryOperator, _leftSide, rightSide) => rightSide,
                    parenthesizeExpressionOfComputedPropertyName: identity,
                    parenthesizeConditionOfConditionalExpression: identity,
                    parenthesizeBranchOfConditionalExpression: identity,
                    parenthesizeExpressionOfExportDefault: identity,
                    parenthesizeExpressionOfNew: (expression) => cast(expression, isLeftHandSideExpression),
                    parenthesizeLeftSideOfAccess: (expression) => cast(expression, isLeftHandSideExpression),
                    parenthesizeOperandOfPostfixUnary: (operand) => cast(operand, isLeftHandSideExpression),
                    parenthesizeOperandOfPrefixUnary: (operand) => cast(operand, isUnaryExpression),
                    parenthesizeExpressionsOfCommaDelimitedList: (nodes) => cast(nodes, isNodeArray),
                    parenthesizeExpressionForDisallowedComma: identity,
                    parenthesizeExpressionOfExpressionStatement: identity,
                    parenthesizeConciseBodyOfArrowFunction: identity,
                    parenthesizeCheckTypeOfConditionalType: identity,
                    parenthesizeExtendsTypeOfConditionalType: identity,
                    parenthesizeConstituentTypesOfUnionType: (nodes) => cast(nodes, isNodeArray),
                    parenthesizeConstituentTypeOfUnionType: identity,
                    parenthesizeConstituentTypesOfIntersectionType: (nodes) => cast(nodes, isNodeArray),
                    parenthesizeConstituentTypeOfIntersectionType: identity,
                    parenthesizeOperandOfTypeOperator: identity,
                    parenthesizeOperandOfReadonlyTypeOperator: identity,
                    parenthesizeNonArrayTypeOfPostfixType: identity,
                    parenthesizeElementTypesOfTupleType: (nodes) => cast(nodes, isNodeArray),
                    parenthesizeElementTypeOfTupleType: identity,
                    parenthesizeTypeOfOptionalType: identity,
                    parenthesizeTypeArguments: (nodes) => nodes && cast(nodes, isNodeArray),
                    parenthesizeLeadingTypeArgument: identity
                };
            }
        });
        // src/compiler/factory/nodeConverters.ts
        function createNodeConverters(factory2) {
            return {
                convertToFunctionBlock,
                convertToFunctionExpression,
                convertToClassExpression,
                convertToArrayAssignmentElement,
                convertToObjectAssignmentElement,
                convertToAssignmentPattern,
                convertToObjectAssignmentPattern,
                convertToArrayAssignmentPattern,
                convertToAssignmentElementTarget
            };
            function convertToFunctionBlock(node, multiLine) {
                if (isBlock(node))
                    return node;
                const returnStatement = factory2.createReturnStatement(node);
                setTextRange(returnStatement, node);
                const body = factory2.createBlock([returnStatement], multiLine);
                setTextRange(body, node);
                return body;
            }
            function convertToFunctionExpression(node) {
                var _a;
                if (!node.body)
                    return Debug.fail(`Cannot convert a FunctionDeclaration without a body`);
                const updated = factory2.createFunctionExpression((_a = getModifiers(node)) == null ? void 0 : _a.filter((modifier) => !isExportModifier(modifier) && !isDefaultModifier(modifier)), node.asteriskToken, node.name, node.typeParameters, node.parameters, node.type, node.body);
                setOriginalNode(updated, node);
                setTextRange(updated, node);
                if (getStartsOnNewLine(node)) {
                    setStartsOnNewLine(updated, 
                    /*newLine*/
                    true);
                }
                return updated;
            }
            function convertToClassExpression(node) {
                var _a;
                const updated = factory2.createClassExpression((_a = node.modifiers) == null ? void 0 : _a.filter((modifier) => !isExportModifier(modifier) && !isDefaultModifier(modifier)), node.name, node.typeParameters, node.heritageClauses, node.members);
                setOriginalNode(updated, node);
                setTextRange(updated, node);
                if (getStartsOnNewLine(node)) {
                    setStartsOnNewLine(updated, 
                    /*newLine*/
                    true);
                }
                return updated;
            }
            function convertToArrayAssignmentElement(element) {
                if (isBindingElement(element)) {
                    if (element.dotDotDotToken) {
                        Debug.assertNode(element.name, isIdentifier);
                        return setOriginalNode(setTextRange(factory2.createSpreadElement(element.name), element), element);
                    }
                    const expression = convertToAssignmentElementTarget(element.name);
                    return element.initializer ? setOriginalNode(setTextRange(factory2.createAssignment(expression, element.initializer), element), element) : expression;
                }
                return cast(element, isExpression);
            }
            function convertToObjectAssignmentElement(element) {
                if (isBindingElement(element)) {
                    if (element.dotDotDotToken) {
                        Debug.assertNode(element.name, isIdentifier);
                        return setOriginalNode(setTextRange(factory2.createSpreadAssignment(element.name), element), element);
                    }
                    if (element.propertyName) {
                        const expression = convertToAssignmentElementTarget(element.name);
                        return setOriginalNode(setTextRange(factory2.createPropertyAssignment(element.propertyName, element.initializer ? factory2.createAssignment(expression, element.initializer) : expression), element), element);
                    }
                    Debug.assertNode(element.name, isIdentifier);
                    return setOriginalNode(setTextRange(factory2.createShorthandPropertyAssignment(element.name, element.initializer), element), element);
                }
                return cast(element, isObjectLiteralElementLike);
            }
            function convertToAssignmentPattern(node) {
                switch (node.kind) {
                    case 207 /* ArrayBindingPattern */:
                    case 209 /* ArrayLiteralExpression */:
                        return convertToArrayAssignmentPattern(node);
                    case 206 /* ObjectBindingPattern */:
                    case 210 /* ObjectLiteralExpression */:
                        return convertToObjectAssignmentPattern(node);
                }
            }
            function convertToObjectAssignmentPattern(node) {
                if (isObjectBindingPattern(node)) {
                    return setOriginalNode(setTextRange(factory2.createObjectLiteralExpression(map(node.elements, convertToObjectAssignmentElement)), node), node);
                }
                return cast(node, isObjectLiteralExpression);
            }
            function convertToArrayAssignmentPattern(node) {
                if (isArrayBindingPattern(node)) {
                    return setOriginalNode(setTextRange(factory2.createArrayLiteralExpression(map(node.elements, convertToArrayAssignmentElement)), node), node);
                }
                return cast(node, isArrayLiteralExpression);
            }
            function convertToAssignmentElementTarget(node) {
                if (isBindingPattern(node)) {
                    return convertToAssignmentPattern(node);
                }
                return cast(node, isExpression);
            }
        }
        var nullNodeConverters;
        var init_nodeConverters = __esm({
            "src/compiler/factory/nodeConverters.ts"() {
                "use strict";
                init_ts2();
                nullNodeConverters = {
                    convertToFunctionBlock: notImplemented,
                    convertToFunctionExpression: notImplemented,
                    convertToClassExpression: notImplemented,
                    convertToArrayAssignmentElement: notImplemented,
                    convertToObjectAssignmentElement: notImplemented,
                    convertToAssignmentPattern: notImplemented,
                    convertToObjectAssignmentPattern: notImplemented,
                    convertToArrayAssignmentPattern: notImplemented,
                    convertToAssignmentElementTarget: notImplemented
                };
            }
        });
        // src/compiler/factory/nodeFactory.ts
        function addNodeFactoryPatcher(fn) {
            nodeFactoryPatchers.push(fn);
        }
        function createNodeFactory(flags, baseFactory2) {
            const setOriginal = flags & 8 /* NoOriginalNode */ ? identity : setOriginalNode;
            const parenthesizerRules = memoize(() => flags & 1 /* NoParenthesizerRules */ ? nullParenthesizerRules : createParenthesizerRules(factory2));
            const converters = memoize(() => flags & 2 /* NoNodeConverters */ ? nullNodeConverters : createNodeConverters(factory2));
            const getBinaryCreateFunction = memoizeOne((operator) => (left, right) => createBinaryExpression(left, operator, right));
            const getPrefixUnaryCreateFunction = memoizeOne((operator) => (operand) => createPrefixUnaryExpression(operator, operand));
            const getPostfixUnaryCreateFunction = memoizeOne((operator) => (operand) => createPostfixUnaryExpression(operand, operator));
            const getJSDocPrimaryTypeCreateFunction = memoizeOne((kind) => () => createJSDocPrimaryTypeWorker(kind));
            const getJSDocUnaryTypeCreateFunction = memoizeOne((kind) => (type) => createJSDocUnaryTypeWorker(kind, type));
            const getJSDocUnaryTypeUpdateFunction = memoizeOne((kind) => (node, type) => updateJSDocUnaryTypeWorker(kind, node, type));
            const getJSDocPrePostfixUnaryTypeCreateFunction = memoizeOne((kind) => (type, postfix) => createJSDocPrePostfixUnaryTypeWorker(kind, type, postfix));
            const getJSDocPrePostfixUnaryTypeUpdateFunction = memoizeOne((kind) => (node, type) => updateJSDocPrePostfixUnaryTypeWorker(kind, node, type));
            const getJSDocSimpleTagCreateFunction = memoizeOne((kind) => (tagName, comment) => createJSDocSimpleTagWorker(kind, tagName, comment));
            const getJSDocSimpleTagUpdateFunction = memoizeOne((kind) => (node, tagName, comment) => updateJSDocSimpleTagWorker(kind, node, tagName, comment));
            const getJSDocTypeLikeTagCreateFunction = memoizeOne((kind) => (tagName, typeExpression, comment) => createJSDocTypeLikeTagWorker(kind, tagName, typeExpression, comment));
            const getJSDocTypeLikeTagUpdateFunction = memoizeOne((kind) => (node, tagName, typeExpression, comment) => updateJSDocTypeLikeTagWorker(kind, node, tagName, typeExpression, comment));
            const factory2 = {
                get parenthesizer() {
                    return parenthesizerRules();
                },
                get converters() {
                    return converters();
                },
                baseFactory: baseFactory2,
                flags,
                createNodeArray,
                createNumericLiteral,
                createBigIntLiteral,
                createStringLiteral,
                createStringLiteralFromNode,
                createRegularExpressionLiteral,
                createLiteralLikeNode,
                createIdentifier,
                createTempVariable,
                createLoopVariable,
                createUniqueName,
                getGeneratedNameForNode,
                createPrivateIdentifier,
                createUniquePrivateName,
                getGeneratedPrivateNameForNode,
                createToken,
                createSuper,
                createThis,
                createNull,
                createTrue,
                createFalse,
                createModifier,
                createModifiersFromModifierFlags,
                createQualifiedName,
                updateQualifiedName,
                createComputedPropertyName,
                updateComputedPropertyName,
                createTypeParameterDeclaration,
                updateTypeParameterDeclaration,
                createParameterDeclaration,
                updateParameterDeclaration,
                createDecorator,
                updateDecorator,
                createPropertySignature,
                updatePropertySignature,
                createPropertyDeclaration,
                updatePropertyDeclaration: updatePropertyDeclaration2,
                createMethodSignature,
                updateMethodSignature,
                createMethodDeclaration,
                updateMethodDeclaration,
                createConstructorDeclaration,
                updateConstructorDeclaration,
                createGetAccessorDeclaration,
                updateGetAccessorDeclaration,
                createSetAccessorDeclaration,
                updateSetAccessorDeclaration,
                createCallSignature,
                updateCallSignature,
                createConstructSignature,
                updateConstructSignature,
                createIndexSignature,
                updateIndexSignature,
                createClassStaticBlockDeclaration,
                updateClassStaticBlockDeclaration,
                createTemplateLiteralTypeSpan,
                updateTemplateLiteralTypeSpan,
                createKeywordTypeNode,
                createTypePredicateNode,
                updateTypePredicateNode,
                createTypeReferenceNode,
                updateTypeReferenceNode,
                createFunctionTypeNode,
                updateFunctionTypeNode,
                createConstructorTypeNode,
                updateConstructorTypeNode,
                createTypeQueryNode,
                updateTypeQueryNode,
                createTypeLiteralNode,
                updateTypeLiteralNode,
                createArrayTypeNode,
                updateArrayTypeNode,
                createTupleTypeNode,
                updateTupleTypeNode,
                createNamedTupleMember,
                updateNamedTupleMember,
                createOptionalTypeNode,
                updateOptionalTypeNode,
                createRestTypeNode,
                updateRestTypeNode,
                createUnionTypeNode,
                updateUnionTypeNode,
                createIntersectionTypeNode,
                updateIntersectionTypeNode,
                createConditionalTypeNode,
                updateConditionalTypeNode,
                createInferTypeNode,
                updateInferTypeNode,
                createImportTypeNode,
                updateImportTypeNode,
                createParenthesizedType,
                updateParenthesizedType,
                createThisTypeNode,
                createTypeOperatorNode,
                updateTypeOperatorNode,
                createIndexedAccessTypeNode,
                updateIndexedAccessTypeNode,
                createMappedTypeNode,
                updateMappedTypeNode,
                createLiteralTypeNode,
                updateLiteralTypeNode,
                createTemplateLiteralType,
                updateTemplateLiteralType,
                createObjectBindingPattern,
                updateObjectBindingPattern,
                createArrayBindingPattern,
                updateArrayBindingPattern,
                createBindingElement,
                updateBindingElement,
                createArrayLiteralExpression,
                updateArrayLiteralExpression,
                createObjectLiteralExpression,
                updateObjectLiteralExpression,
                createPropertyAccessExpression: flags & 4 /* NoIndentationOnFreshPropertyAccess */ ? (expression, name) => setEmitFlags(createPropertyAccessExpression(expression, name), 262144 /* NoIndentation */) : createPropertyAccessExpression,
                updatePropertyAccessExpression,
                createPropertyAccessChain: flags & 4 /* NoIndentationOnFreshPropertyAccess */ ? (expression, questionDotToken, name) => setEmitFlags(createPropertyAccessChain(expression, questionDotToken, name), 262144 /* NoIndentation */) : createPropertyAccessChain,
                updatePropertyAccessChain,
                createElementAccessExpression,
                updateElementAccessExpression,
                createElementAccessChain,
                updateElementAccessChain,
                createCallExpression,
                updateCallExpression,
                createCallChain,
                updateCallChain,
                createNewExpression,
                updateNewExpression,
                createTaggedTemplateExpression,
                updateTaggedTemplateExpression,
                createTypeAssertion,
                updateTypeAssertion,
                createParenthesizedExpression,
                updateParenthesizedExpression,
                createFunctionExpression,
                updateFunctionExpression,
                createArrowFunction,
                updateArrowFunction,
                createDeleteExpression,
                updateDeleteExpression,
                createTypeOfExpression,
                updateTypeOfExpression,
                createVoidExpression,
                updateVoidExpression,
                createAwaitExpression,
                updateAwaitExpression,
                createPrefixUnaryExpression,
                updatePrefixUnaryExpression,
                createPostfixUnaryExpression,
                updatePostfixUnaryExpression,
                createBinaryExpression,
                updateBinaryExpression,
                createConditionalExpression,
                updateConditionalExpression,
                createTemplateExpression,
                updateTemplateExpression,
                createTemplateHead,
                createTemplateMiddle,
                createTemplateTail,
                createNoSubstitutionTemplateLiteral,
                createTemplateLiteralLikeNode,
                createYieldExpression,
                updateYieldExpression,
                createSpreadElement,
                updateSpreadElement,
                createClassExpression,
                updateClassExpression,
                createOmittedExpression,
                createExpressionWithTypeArguments,
                updateExpressionWithTypeArguments,
                createAsExpression,
                updateAsExpression,
                createNonNullExpression,
                updateNonNullExpression,
                createSatisfiesExpression,
                updateSatisfiesExpression,
                createNonNullChain,
                updateNonNullChain,
                createMetaProperty,
                updateMetaProperty,
                createTemplateSpan,
                updateTemplateSpan,
                createSemicolonClassElement,
                createBlock,
                updateBlock,
                createVariableStatement,
                updateVariableStatement,
                createEmptyStatement,
                createExpressionStatement,
                updateExpressionStatement,
                createIfStatement,
                updateIfStatement,
                createDoStatement,
                updateDoStatement,
                createWhileStatement,
                updateWhileStatement,
                createForStatement,
                updateForStatement,
                createForInStatement,
                updateForInStatement,
                createForOfStatement,
                updateForOfStatement,
                createContinueStatement,
                updateContinueStatement,
                createBreakStatement,
                updateBreakStatement,
                createReturnStatement,
                updateReturnStatement,
                createWithStatement,
                updateWithStatement,
                createSwitchStatement,
                updateSwitchStatement,
                createLabeledStatement,
                updateLabeledStatement,
                createThrowStatement,
                updateThrowStatement,
                createTryStatement,
                updateTryStatement,
                createDebuggerStatement,
                createVariableDeclaration,
                updateVariableDeclaration,
                createVariableDeclarationList,
                updateVariableDeclarationList,
                createFunctionDeclaration,
                updateFunctionDeclaration,
                createClassDeclaration,
                updateClassDeclaration,
                createInterfaceDeclaration,
                updateInterfaceDeclaration,
                createTypeAliasDeclaration,
                updateTypeAliasDeclaration,
                createEnumDeclaration,
                updateEnumDeclaration,
                createModuleDeclaration,
                updateModuleDeclaration,
                createModuleBlock,
                updateModuleBlock,
                createCaseBlock,
                updateCaseBlock,
                createNamespaceExportDeclaration,
                updateNamespaceExportDeclaration,
                createImportEqualsDeclaration,
                updateImportEqualsDeclaration,
                createImportDeclaration,
                updateImportDeclaration,
                createImportClause,
                updateImportClause,
                createAssertClause,
                updateAssertClause,
                createAssertEntry,
                updateAssertEntry,
                createImportTypeAssertionContainer,
                updateImportTypeAssertionContainer,
                createImportAttributes,
                updateImportAttributes,
                createImportAttribute,
                updateImportAttribute,
                createNamespaceImport,
                updateNamespaceImport,
                createNamespaceExport,
                updateNamespaceExport,
                createNamedImports,
                updateNamedImports,
                createImportSpecifier,
                updateImportSpecifier,
                createExportAssignment: createExportAssignment2,
                updateExportAssignment,
                createExportDeclaration,
                updateExportDeclaration,
                createNamedExports,
                updateNamedExports,
                createExportSpecifier,
                updateExportSpecifier,
                createMissingDeclaration,
                createExternalModuleReference,
                updateExternalModuleReference,
                // lazily load factory members for JSDoc types with similar structure
                get createJSDocAllType() {
                    return getJSDocPrimaryTypeCreateFunction(319 /* JSDocAllType */);
                },
                get createJSDocUnknownType() {
                    return getJSDocPrimaryTypeCreateFunction(320 /* JSDocUnknownType */);
                },
                get createJSDocNonNullableType() {
                    return getJSDocPrePostfixUnaryTypeCreateFunction(322 /* JSDocNonNullableType */);
                },
                get updateJSDocNonNullableType() {
                    return getJSDocPrePostfixUnaryTypeUpdateFunction(322 /* JSDocNonNullableType */);
                },
                get createJSDocNullableType() {
                    return getJSDocPrePostfixUnaryTypeCreateFunction(321 /* JSDocNullableType */);
                },
                get updateJSDocNullableType() {
                    return getJSDocPrePostfixUnaryTypeUpdateFunction(321 /* JSDocNullableType */);
                },
                get createJSDocOptionalType() {
                    return getJSDocUnaryTypeCreateFunction(323 /* JSDocOptionalType */);
                },
                get updateJSDocOptionalType() {
                    return getJSDocUnaryTypeUpdateFunction(323 /* JSDocOptionalType */);
                },
                get createJSDocVariadicType() {
                    return getJSDocUnaryTypeCreateFunction(325 /* JSDocVariadicType */);
                },
                get updateJSDocVariadicType() {
                    return getJSDocUnaryTypeUpdateFunction(325 /* JSDocVariadicType */);
                },
                get createJSDocNamepathType() {
                    return getJSDocUnaryTypeCreateFunction(326 /* JSDocNamepathType */);
                },
                get updateJSDocNamepathType() {
                    return getJSDocUnaryTypeUpdateFunction(326 /* JSDocNamepathType */);
                },
                createJSDocFunctionType,
                updateJSDocFunctionType,
                createJSDocTypeLiteral,
                updateJSDocTypeLiteral,
                createJSDocTypeExpression,
                updateJSDocTypeExpression,
                createJSDocSignature,
                updateJSDocSignature,
                createJSDocTemplateTag,
                updateJSDocTemplateTag,
                createJSDocTypedefTag,
                updateJSDocTypedefTag,
                createJSDocParameterTag,
                updateJSDocParameterTag,
                createJSDocPropertyTag,
                updateJSDocPropertyTag,
                createJSDocCallbackTag,
                updateJSDocCallbackTag,
                createJSDocOverloadTag,
                updateJSDocOverloadTag,
                createJSDocAugmentsTag,
                updateJSDocAugmentsTag,
                createJSDocImplementsTag,
                updateJSDocImplementsTag,
                createJSDocSeeTag,
                updateJSDocSeeTag,
                createJSDocNameReference,
                updateJSDocNameReference,
                createJSDocMemberName,
                updateJSDocMemberName,
                createJSDocLink,
                updateJSDocLink,
                createJSDocLinkCode,
                updateJSDocLinkCode,
                createJSDocLinkPlain,
                updateJSDocLinkPlain,
                // lazily load factory members for JSDoc tags with similar structure
                get createJSDocTypeTag() {
                    return getJSDocTypeLikeTagCreateFunction(351 /* JSDocTypeTag */);
                },
                get updateJSDocTypeTag() {
                    return getJSDocTypeLikeTagUpdateFunction(351 /* JSDocTypeTag */);
                },
                get createJSDocReturnTag() {
                    return getJSDocTypeLikeTagCreateFunction(349 /* JSDocReturnTag */);
                },
                get updateJSDocReturnTag() {
                    return getJSDocTypeLikeTagUpdateFunction(349 /* JSDocReturnTag */);
                },
                get createJSDocThisTag() {
                    return getJSDocTypeLikeTagCreateFunction(350 /* JSDocThisTag */);
                },
                get updateJSDocThisTag() {
                    return getJSDocTypeLikeTagUpdateFunction(350 /* JSDocThisTag */);
                },
                get createJSDocAuthorTag() {
                    return getJSDocSimpleTagCreateFunction(337 /* JSDocAuthorTag */);
                },
                get updateJSDocAuthorTag() {
                    return getJSDocSimpleTagUpdateFunction(337 /* JSDocAuthorTag */);
                },
                get createJSDocClassTag() {
                    return getJSDocSimpleTagCreateFunction(339 /* JSDocClassTag */);
                },
                get updateJSDocClassTag() {
                    return getJSDocSimpleTagUpdateFunction(339 /* JSDocClassTag */);
                },
                get createJSDocPublicTag() {
                    return getJSDocSimpleTagCreateFunction(340 /* JSDocPublicTag */);
                },
                get updateJSDocPublicTag() {
                    return getJSDocSimpleTagUpdateFunction(340 /* JSDocPublicTag */);
                },
                get createJSDocPrivateTag() {
                    return getJSDocSimpleTagCreateFunction(341 /* JSDocPrivateTag */);
                },
                get updateJSDocPrivateTag() {
                    return getJSDocSimpleTagUpdateFunction(341 /* JSDocPrivateTag */);
                },
                get createJSDocProtectedTag() {
                    return getJSDocSimpleTagCreateFunction(342 /* JSDocProtectedTag */);
                },
                get updateJSDocProtectedTag() {
                    return getJSDocSimpleTagUpdateFunction(342 /* JSDocProtectedTag */);
                },
                get createJSDocReadonlyTag() {
                    return getJSDocSimpleTagCreateFunction(343 /* JSDocReadonlyTag */);
                },
                get updateJSDocReadonlyTag() {
                    return getJSDocSimpleTagUpdateFunction(343 /* JSDocReadonlyTag */);
                },
                get createJSDocOverrideTag() {
                    return getJSDocSimpleTagCreateFunction(344 /* JSDocOverrideTag */);
                },
                get updateJSDocOverrideTag() {
                    return getJSDocSimpleTagUpdateFunction(344 /* JSDocOverrideTag */);
                },
                get createJSDocDeprecatedTag() {
                    return getJSDocSimpleTagCreateFunction(338 /* JSDocDeprecatedTag */);
                },
                get updateJSDocDeprecatedTag() {
                    return getJSDocSimpleTagUpdateFunction(338 /* JSDocDeprecatedTag */);
                },
                get createJSDocThrowsTag() {
                    return getJSDocTypeLikeTagCreateFunction(356 /* JSDocThrowsTag */);
                },
                get updateJSDocThrowsTag() {
                    return getJSDocTypeLikeTagUpdateFunction(356 /* JSDocThrowsTag */);
                },
                get createJSDocSatisfiesTag() {
                    return getJSDocTypeLikeTagCreateFunction(357 /* JSDocSatisfiesTag */);
                },
                get updateJSDocSatisfiesTag() {
                    return getJSDocTypeLikeTagUpdateFunction(357 /* JSDocSatisfiesTag */);
                },
                createJSDocEnumTag,
                updateJSDocEnumTag,
                createJSDocUnknownTag,
                updateJSDocUnknownTag,
                createJSDocText,
                updateJSDocText,
                createJSDocComment,
                updateJSDocComment,
                createJsxElement,
                updateJsxElement,
                createJsxSelfClosingElement,
                updateJsxSelfClosingElement,
                createJsxOpeningElement,
                updateJsxOpeningElement,
                createJsxClosingElement,
                updateJsxClosingElement,
                createJsxFragment,
                createJsxText,
                updateJsxText,
                createJsxOpeningFragment,
                createJsxJsxClosingFragment,
                updateJsxFragment,
                createJsxAttribute,
                updateJsxAttribute,
                createJsxAttributes,
                updateJsxAttributes,
                createJsxSpreadAttribute,
                updateJsxSpreadAttribute,
                createJsxExpression,
                updateJsxExpression,
                createJsxNamespacedName,
                updateJsxNamespacedName,
                createCaseClause,
                updateCaseClause,
                createDefaultClause,
                updateDefaultClause,
                createHeritageClause,
                updateHeritageClause,
                createCatchClause,
                updateCatchClause,
                createPropertyAssignment,
                updatePropertyAssignment,
                createShorthandPropertyAssignment,
                updateShorthandPropertyAssignment,
                createSpreadAssignment,
                updateSpreadAssignment,
                createEnumMember,
                updateEnumMember,
                createSourceFile: createSourceFile2,
                updateSourceFile: updateSourceFile2,
                createRedirectedSourceFile,
                createBundle,
                updateBundle,
                createUnparsedSource,
                createUnparsedPrologue,
                createUnparsedPrepend,
                createUnparsedTextLike,
                createUnparsedSyntheticReference,
                createInputFiles: createInputFiles2,
                createSyntheticExpression,
                createSyntaxList: createSyntaxList3,
                createNotEmittedStatement,
                createPartiallyEmittedExpression,
                updatePartiallyEmittedExpression,
                createCommaListExpression,
                updateCommaListExpression,
                createSyntheticReferenceExpression,
                updateSyntheticReferenceExpression,
                cloneNode,
                // Lazily load factory methods for common operator factories and utilities
                get createComma() {
                    return getBinaryCreateFunction(28 /* CommaToken */);
                },
                get createAssignment() {
                    return getBinaryCreateFunction(64 /* EqualsToken */);
                },
                get createLogicalOr() {
                    return getBinaryCreateFunction(57 /* BarBarToken */);
                },
                get createLogicalAnd() {
                    return getBinaryCreateFunction(56 /* AmpersandAmpersandToken */);
                },
                get createBitwiseOr() {
                    return getBinaryCreateFunction(52 /* BarToken */);
                },
                get createBitwiseXor() {
                    return getBinaryCreateFunction(53 /* CaretToken */);
                },
                get createBitwiseAnd() {
                    return getBinaryCreateFunction(51 /* AmpersandToken */);
                },
                get createStrictEquality() {
                    return getBinaryCreateFunction(37 /* EqualsEqualsEqualsToken */);
                },
                get createStrictInequality() {
                    return getBinaryCreateFunction(38 /* ExclamationEqualsEqualsToken */);
                },
                get createEquality() {
                    return getBinaryCreateFunction(35 /* EqualsEqualsToken */);
                },
                get createInequality() {
                    return getBinaryCreateFunction(36 /* ExclamationEqualsToken */);
                },
                get createLessThan() {
                    return getBinaryCreateFunction(30 /* LessThanToken */);
                },
                get createLessThanEquals() {
                    return getBinaryCreateFunction(33 /* LessThanEqualsToken */);
                },
                get createGreaterThan() {
                    return getBinaryCreateFunction(32 /* GreaterThanToken */);
                },
                get createGreaterThanEquals() {
                    return getBinaryCreateFunction(34 /* GreaterThanEqualsToken */);
                },
                get createLeftShift() {
                    return getBinaryCreateFunction(48 /* LessThanLessThanToken */);
                },
                get createRightShift() {
                    return getBinaryCreateFunction(49 /* GreaterThanGreaterThanToken */);
                },
                get createUnsignedRightShift() {
                    return getBinaryCreateFunction(50 /* GreaterThanGreaterThanGreaterThanToken */);
                },
                get createAdd() {
                    return getBinaryCreateFunction(40 /* PlusToken */);
                },
                get createSubtract() {
                    return getBinaryCreateFunction(41 /* MinusToken */);
                },
                get createMultiply() {
                    return getBinaryCreateFunction(42 /* AsteriskToken */);
                },
                get createDivide() {
                    return getBinaryCreateFunction(44 /* SlashToken */);
                },
                get createModulo() {
                    return getBinaryCreateFunction(45 /* PercentToken */);
                },
                get createExponent() {
                    return getBinaryCreateFunction(43 /* AsteriskAsteriskToken */);
                },
                get createPrefixPlus() {
                    return getPrefixUnaryCreateFunction(40 /* PlusToken */);
                },
                get createPrefixMinus() {
                    return getPrefixUnaryCreateFunction(41 /* MinusToken */);
                },
                get createPrefixIncrement() {
                    return getPrefixUnaryCreateFunction(46 /* PlusPlusToken */);
                },
                get createPrefixDecrement() {
                    return getPrefixUnaryCreateFunction(47 /* MinusMinusToken */);
                },
                get createBitwiseNot() {
                    return getPrefixUnaryCreateFunction(55 /* TildeToken */);
                },
                get createLogicalNot() {
                    return getPrefixUnaryCreateFunction(54 /* ExclamationToken */);
                },
                get createPostfixIncrement() {
                    return getPostfixUnaryCreateFunction(46 /* PlusPlusToken */);
                },
                get createPostfixDecrement() {
                    return getPostfixUnaryCreateFunction(47 /* MinusMinusToken */);
                },
                // Compound nodes
                createImmediatelyInvokedFunctionExpression,
                createImmediatelyInvokedArrowFunction,
                createVoidZero,
                createExportDefault,
                createExternalModuleExport,
                createTypeCheck,
                createIsNotTypeCheck,
                createMethodCall,
                createGlobalMethodCall,
                createFunctionBindCall,
                createFunctionCallCall,
                createFunctionApplyCall,
                createArraySliceCall,
                createArrayConcatCall,
                createObjectDefinePropertyCall,
                createObjectGetOwnPropertyDescriptorCall,
                createReflectGetCall,
                createReflectSetCall,
                createPropertyDescriptor,
                createCallBinding,
                createAssignmentTargetWrapper,
                // Utilities
                inlineExpressions,
                getInternalName,
                getLocalName,
                getExportName,
                getDeclarationName,
                getNamespaceMemberName,
                getExternalModuleOrNamespaceExportName,
                restoreOuterExpressions,
                restoreEnclosingLabel,
                createUseStrictPrologue,
                copyPrologue,
                copyStandardPrologue,
                copyCustomPrologue,
                ensureUseStrict,
                liftToBlock,
                mergeLexicalEnvironment,
                replaceModifiers,
                replaceDecoratorsAndModifiers,
                replacePropertyName
            };
            forEach(nodeFactoryPatchers, (fn) => fn(factory2));
            return factory2;
            function createNodeArray(elements, hasTrailingComma) {
                if (elements === void 0 || elements === emptyArray) {
                    elements = [];
                }
                else if (isNodeArray(elements)) {
                    if (hasTrailingComma === void 0 || elements.hasTrailingComma === hasTrailingComma) {
                        if (elements.transformFlags === void 0) {
                            aggregateChildrenFlags(elements);
                        }
                        Debug.attachNodeArrayDebugInfo(elements);
                        return elements;
                    }
                    const array2 = elements.slice();
                    array2.pos = elements.pos;
                    array2.end = elements.end;
                    array2.hasTrailingComma = hasTrailingComma;
                    array2.transformFlags = elements.transformFlags;
                    Debug.attachNodeArrayDebugInfo(array2);
                    return array2;
                }
                const length2 = elements.length;
                const array = length2 >= 1 && length2 <= 4 ? elements.slice() : elements;
                array.pos = -1;
                array.end = -1;
                array.hasTrailingComma = !!hasTrailingComma;
                array.transformFlags = 0 /* None */;
                aggregateChildrenFlags(array);
                Debug.attachNodeArrayDebugInfo(array);
                return array;
            }
            function createBaseNode(kind) {
                return baseFactory2.createBaseNode(kind);
            }
            function createBaseDeclaration(kind) {
                const node = createBaseNode(kind);
                node.symbol = void 0;
                node.localSymbol = void 0;
                return node;
            }
            function finishUpdateBaseSignatureDeclaration(updated, original) {
                if (updated !== original) {
                    updated.typeArguments = original.typeArguments;
                }
                return update(updated, original);
            }
            function createNumericLiteral(value, numericLiteralFlags = 0 /* None */) {
                const text = typeof value === "number" ? value + "" : value;
                Debug.assert(text.charCodeAt(0) !== 45 /* minus */, "Negative numbers should be created in combination with createPrefixUnaryExpression");
                const node = createBaseDeclaration(9 /* NumericLiteral */);
                node.text = text;
                node.numericLiteralFlags = numericLiteralFlags;
                if (numericLiteralFlags & 384 /* BinaryOrOctalSpecifier */)
                    node.transformFlags |= 1024 /* ContainsES2015 */;
                return node;
            }
            function createBigIntLiteral(value) {
                const node = createBaseToken(10 /* BigIntLiteral */);
                node.text = typeof value === "string" ? value : pseudoBigIntToString(value) + "n";
                node.transformFlags |= 32 /* ContainsES2020 */;
                return node;
            }
            function createBaseStringLiteral(text, isSingleQuote) {
                const node = createBaseDeclaration(11 /* StringLiteral */);
                node.text = text;
                node.singleQuote = isSingleQuote;
                return node;
            }
            function createStringLiteral(text, isSingleQuote, hasExtendedUnicodeEscape) {
                const node = createBaseStringLiteral(text, isSingleQuote);
                node.hasExtendedUnicodeEscape = hasExtendedUnicodeEscape;
                if (hasExtendedUnicodeEscape)
                    node.transformFlags |= 1024 /* ContainsES2015 */;
                return node;
            }
            function createStringLiteralFromNode(sourceNode) {
                const node = createBaseStringLiteral(getTextOfIdentifierOrLiteral(sourceNode), 
                /*isSingleQuote*/
                void 0);
                node.textSourceNode = sourceNode;
                return node;
            }
            function createRegularExpressionLiteral(text) {
                const node = createBaseToken(14 /* RegularExpressionLiteral */);
                node.text = text;
                return node;
            }
            function createLiteralLikeNode(kind, text) {
                switch (kind) {
                    case 9 /* NumericLiteral */:
                        return createNumericLiteral(text, 
                        /*numericLiteralFlags*/
                        0);
                    case 10 /* BigIntLiteral */:
                        return createBigIntLiteral(text);
                    case 11 /* StringLiteral */:
                        return createStringLiteral(text, 
                        /*isSingleQuote*/
                        void 0);
                    case 12 /* JsxText */:
                        return createJsxText(text, 
                        /*containsOnlyTriviaWhiteSpaces*/
                        false);
                    case 13 /* JsxTextAllWhiteSpaces */:
                        return createJsxText(text, 
                        /*containsOnlyTriviaWhiteSpaces*/
                        true);
                    case 14 /* RegularExpressionLiteral */:
                        return createRegularExpressionLiteral(text);
                    case 15 /* NoSubstitutionTemplateLiteral */:
                        return createTemplateLiteralLikeNode(kind, text, 
                        /*rawText*/
                        void 0, 
                        /*templateFlags*/
                        0);
                }
            }
            function createBaseIdentifier(escapedText) {
                const node = baseFactory2.createBaseIdentifierNode(80 /* Identifier */);
                node.escapedText = escapedText;
                node.jsDoc = void 0;
                node.flowNode = void 0;
                node.symbol = void 0;
                return node;
            }
            function createBaseGeneratedIdentifier(text, autoGenerateFlags, prefix, suffix) {
                const node = createBaseIdentifier(escapeLeadingUnderscores(text));
                setIdentifierAutoGenerate(node, {
                    flags: autoGenerateFlags,
                    id: nextAutoGenerateId,
                    prefix,
                    suffix
                });
                nextAutoGenerateId++;
                return node;
            }
            function createIdentifier(text, originalKeywordKind, hasExtendedUnicodeEscape) {
                if (originalKeywordKind === void 0 && text) {
                    originalKeywordKind = stringToToken(text);
                }
                if (originalKeywordKind === 80 /* Identifier */) {
                    originalKeywordKind = void 0;
                }
                const node = createBaseIdentifier(escapeLeadingUnderscores(text));
                if (hasExtendedUnicodeEscape)
                    node.flags |= 256 /* IdentifierHasExtendedUnicodeEscape */;
                if (node.escapedText === "await") {
                    node.transformFlags |= 67108864 /* ContainsPossibleTopLevelAwait */;
                }
                if (node.flags & 256 /* IdentifierHasExtendedUnicodeEscape */) {
                    node.transformFlags |= 1024 /* ContainsES2015 */;
                }
                return node;
            }
            function createTempVariable(recordTempVariable, reservedInNestedScopes, prefix, suffix) {
                let flags2 = 1 /* Auto */;
                if (reservedInNestedScopes)
                    flags2 |= 8 /* ReservedInNestedScopes */;
                const name = createBaseGeneratedIdentifier("", flags2, prefix, suffix);
                if (recordTempVariable) {
                    recordTempVariable(name);
                }
                return name;
            }
            function createLoopVariable(reservedInNestedScopes) {
                let flags2 = 2 /* Loop */;
                if (reservedInNestedScopes)
                    flags2 |= 8 /* ReservedInNestedScopes */;
                return createBaseGeneratedIdentifier("", flags2, 
                /*prefix*/
                void 0, 
                /*suffix*/
                void 0);
            }
            function createUniqueName(text, flags2 = 0 /* None */, prefix, suffix) {
                Debug.assert(!(flags2 & 7 /* KindMask */), "Argument out of range: flags");
                Debug.assert((flags2 & (16 /* Optimistic */ | 32 /* FileLevel */)) !== 32 /* FileLevel */, "GeneratedIdentifierFlags.FileLevel cannot be set without also setting GeneratedIdentifierFlags.Optimistic");
                return createBaseGeneratedIdentifier(text, 3 /* Unique */ | flags2, prefix, suffix);
            }
            function getGeneratedNameForNode(node, flags2 = 0, prefix, suffix) {
                Debug.assert(!(flags2 & 7 /* KindMask */), "Argument out of range: flags");
                const text = !node ? "" : isMemberName(node) ? formatGeneratedName(
                /*privateName*/
                false, prefix, node, suffix, idText) : `generated@${getNodeId(node)}`;
                if (prefix || suffix)
                    flags2 |= 16 /* Optimistic */;
                const name = createBaseGeneratedIdentifier(text, 4 /* Node */ | flags2, prefix, suffix);
                name.original = node;
                return name;
            }
            function createBasePrivateIdentifier(escapedText) {
                const node = baseFactory2.createBasePrivateIdentifierNode(81 /* PrivateIdentifier */);
                node.escapedText = escapedText;
                node.transformFlags |= 16777216 /* ContainsClassFields */;
                return node;
            }
            function createPrivateIdentifier(text) {
                if (!startsWith(text, "#"))
                    Debug.fail("First character of private identifier must be #: " + text);
                return createBasePrivateIdentifier(escapeLeadingUnderscores(text));
            }
            function createBaseGeneratedPrivateIdentifier(text, autoGenerateFlags, prefix, suffix) {
                const node = createBasePrivateIdentifier(escapeLeadingUnderscores(text));
                setIdentifierAutoGenerate(node, {
                    flags: autoGenerateFlags,
                    id: nextAutoGenerateId,
                    prefix,
                    suffix
                });
                nextAutoGenerateId++;
                return node;
            }
            function createUniquePrivateName(text, prefix, suffix) {
                if (text && !startsWith(text, "#"))
                    Debug.fail("First character of private identifier must be #: " + text);
                const autoGenerateFlags = 8 /* ReservedInNestedScopes */ | (text ? 3 /* Unique */ : 1 /* Auto */);
                return createBaseGeneratedPrivateIdentifier(text ?? "", autoGenerateFlags, prefix, suffix);
            }
            function getGeneratedPrivateNameForNode(node, prefix, suffix) {
                const text = isMemberName(node) ? formatGeneratedName(
                /*privateName*/
                true, prefix, node, suffix, idText) : `#generated@${getNodeId(node)}`;
                const flags2 = prefix || suffix ? 16 /* Optimistic */ : 0 /* None */;
                const name = createBaseGeneratedPrivateIdentifier(text, 4 /* Node */ | flags2, prefix, suffix);
                name.original = node;
                return name;
            }
            function createBaseToken(kind) {
                return baseFactory2.createBaseTokenNode(kind);
            }
            function createToken(token) {
                Debug.assert(token >= 0 /* FirstToken */ && token <= 165 /* LastToken */, "Invalid token");
                Debug.assert(token <= 15 /* FirstTemplateToken */ || token >= 18 /* LastTemplateToken */, "Invalid token. Use 'createTemplateLiteralLikeNode' to create template literals.");
                Debug.assert(token <= 9 /* FirstLiteralToken */ || token >= 15 /* LastLiteralToken */, "Invalid token. Use 'createLiteralLikeNode' to create literals.");
                Debug.assert(token !== 80 /* Identifier */, "Invalid token. Use 'createIdentifier' to create identifiers");
                const node = createBaseToken(token);
                let transformFlags = 0 /* None */;
                switch (token) {
                    case 134 /* AsyncKeyword */:
                        transformFlags = 256 /* ContainsES2017 */ | 128 /* ContainsES2018 */;
                        break;
                    case 160 /* UsingKeyword */:
                        transformFlags = 4 /* ContainsESNext */;
                        break;
                    case 125 /* PublicKeyword */:
                    case 123 /* PrivateKeyword */:
                    case 124 /* ProtectedKeyword */:
                    case 148 /* ReadonlyKeyword */:
                    case 128 /* AbstractKeyword */:
                    case 138 /* DeclareKeyword */:
                    case 87 /* ConstKeyword */:
                    case 133 /* AnyKeyword */:
                    case 150 /* NumberKeyword */:
                    case 163 /* BigIntKeyword */:
                    case 146 /* NeverKeyword */:
                    case 151 /* ObjectKeyword */:
                    case 103 /* InKeyword */:
                    case 147 /* OutKeyword */:
                    case 164 /* OverrideKeyword */:
                    case 154 /* StringKeyword */:
                    case 136 /* BooleanKeyword */:
                    case 155 /* SymbolKeyword */:
                    case 116 /* VoidKeyword */:
                    case 159 /* UnknownKeyword */:
                    case 157 /* UndefinedKeyword */:
                        transformFlags = 1 /* ContainsTypeScript */;
                        break;
                    case 108 /* SuperKeyword */:
                        transformFlags = 1024 /* ContainsES2015 */ | 134217728 /* ContainsLexicalSuper */;
                        node.flowNode = void 0;
                        break;
                    case 126 /* StaticKeyword */:
                        transformFlags = 1024 /* ContainsES2015 */;
                        break;
                    case 129 /* AccessorKeyword */:
                        transformFlags = 16777216 /* ContainsClassFields */;
                        break;
                    case 110 /* ThisKeyword */:
                        transformFlags = 16384 /* ContainsLexicalThis */;
                        node.flowNode = void 0;
                        break;
                }
                if (transformFlags) {
                    node.transformFlags |= transformFlags;
                }
                return node;
            }
            function createSuper() {
                return createToken(108 /* SuperKeyword */);
            }
            function createThis() {
                return createToken(110 /* ThisKeyword */);
            }
            function createNull() {
                return createToken(106 /* NullKeyword */);
            }
            function createTrue() {
                return createToken(112 /* TrueKeyword */);
            }
            function createFalse() {
                return createToken(97 /* FalseKeyword */);
            }
            function createModifier(kind) {
                return createToken(kind);
            }
            function createModifiersFromModifierFlags(flags2) {
                const result = [];
                if (flags2 & 32 /* Export */)
                    result.push(createModifier(95 /* ExportKeyword */));
                if (flags2 & 128 /* Ambient */)
                    result.push(createModifier(138 /* DeclareKeyword */));
                if (flags2 & 2048 /* Default */)
                    result.push(createModifier(90 /* DefaultKeyword */));
                if (flags2 & 4096 /* Const */)
                    result.push(createModifier(87 /* ConstKeyword */));
                if (flags2 & 1 /* Public */)
                    result.push(createModifier(125 /* PublicKeyword */));
                if (flags2 & 2 /* Private */)
                    result.push(createModifier(123 /* PrivateKeyword */));
                if (flags2 & 4 /* Protected */)
                    result.push(createModifier(124 /* ProtectedKeyword */));
                if (flags2 & 64 /* Abstract */)
                    result.push(createModifier(128 /* AbstractKeyword */));
                if (flags2 & 256 /* Static */)
                    result.push(createModifier(126 /* StaticKeyword */));
                if (flags2 & 16 /* Override */)
                    result.push(createModifier(164 /* OverrideKeyword */));
                if (flags2 & 8 /* Readonly */)
                    result.push(createModifier(148 /* ReadonlyKeyword */));
                if (flags2 & 512 /* Accessor */)
                    result.push(createModifier(129 /* AccessorKeyword */));
                if (flags2 & 1024 /* Async */)
                    result.push(createModifier(134 /* AsyncKeyword */));
                if (flags2 & 8192 /* In */)
                    result.push(createModifier(103 /* InKeyword */));
                if (flags2 & 16384 /* Out */)
                    result.push(createModifier(147 /* OutKeyword */));
                return result.length ? result : void 0;
            }
            function createQualifiedName(left, right) {
                const node = createBaseNode(166 /* QualifiedName */);
                node.left = left;
                node.right = asName(right);
                node.transformFlags |= propagateChildFlags(node.left) | propagateIdentifierNameFlags(node.right);
                node.flowNode = void 0;
                return node;
            }
            function updateQualifiedName(node, left, right) {
                return node.left !== left || node.right !== right ? update(createQualifiedName(left, right), node) : node;
            }
            function createComputedPropertyName(expression) {
                const node = createBaseNode(167 /* ComputedPropertyName */);
                node.expression = parenthesizerRules().parenthesizeExpressionOfComputedPropertyName(expression);
                node.transformFlags |= propagateChildFlags(node.expression) | 1024 /* ContainsES2015 */ | 131072 /* ContainsComputedPropertyName */;
                return node;
            }
            function updateComputedPropertyName(node, expression) {
                return node.expression !== expression ? update(createComputedPropertyName(expression), node) : node;
            }
            function createTypeParameterDeclaration(modifiers, name, constraint, defaultType) {
                const node = createBaseDeclaration(168 /* TypeParameter */);
                node.modifiers = asNodeArray(modifiers);
                node.name = asName(name);
                node.constraint = constraint;
                node.default = defaultType;
                node.transformFlags = 1 /* ContainsTypeScript */;
                node.expression = void 0;
                node.jsDoc = void 0;
                return node;
            }
            function updateTypeParameterDeclaration(node, modifiers, name, constraint, defaultType) {
                return node.modifiers !== modifiers || node.name !== name || node.constraint !== constraint || node.default !== defaultType ? update(createTypeParameterDeclaration(modifiers, name, constraint, defaultType), node) : node;
            }
            function createParameterDeclaration(modifiers, dotDotDotToken, name, questionToken, type, initializer) {
                const node = createBaseDeclaration(169 /* Parameter */);
                node.modifiers = asNodeArray(modifiers);
                node.dotDotDotToken = dotDotDotToken;
                node.name = asName(name);
                node.questionToken = questionToken;
                node.type = type;
                node.initializer = asInitializer(initializer);
                if (isThisIdentifier(node.name)) {
                    node.transformFlags = 1 /* ContainsTypeScript */;
                }
                else {
                    node.transformFlags = propagateChildrenFlags(node.modifiers) | propagateChildFlags(node.dotDotDotToken) | propagateNameFlags(node.name) | propagateChildFlags(node.questionToken) | propagateChildFlags(node.initializer) | (node.questionToken ?? node.type ? 1 /* ContainsTypeScript */ : 0 /* None */) | (node.dotDotDotToken ?? node.initializer ? 1024 /* ContainsES2015 */ : 0 /* None */) | (modifiersToFlags(node.modifiers) & 31 /* ParameterPropertyModifier */ ? 8192 /* ContainsTypeScriptClassSyntax */ : 0 /* None */);
                }
                node.jsDoc = void 0;
                return node;
            }
            function updateParameterDeclaration(node, modifiers, dotDotDotToken, name, questionToken, type, initializer) {
                return node.modifiers !== modifiers || node.dotDotDotToken !== dotDotDotToken || node.name !== name || node.questionToken !== questionToken || node.type !== type || node.initializer !== initializer ? update(createParameterDeclaration(modifiers, dotDotDotToken, name, questionToken, type, initializer), node) : node;
            }
            function createDecorator(expression) {
                const node = createBaseNode(170 /* Decorator */);
                node.expression = parenthesizerRules().parenthesizeLeftSideOfAccess(expression, 
                /*optionalChain*/
                false);
                node.transformFlags |= propagateChildFlags(node.expression) | 1 /* ContainsTypeScript */ | 8192 /* ContainsTypeScriptClassSyntax */ | 33554432 /* ContainsDecorators */;
                return node;
            }
            function updateDecorator(node, expression) {
                return node.expression !== expression ? update(createDecorator(expression), node) : node;
            }
            function createPropertySignature(modifiers, name, questionToken, type) {
                const node = createBaseDeclaration(171 /* PropertySignature */);
                node.modifiers = asNodeArray(modifiers);
                node.name = asName(name);
                node.type = type;
                node.questionToken = questionToken;
                node.transformFlags = 1 /* ContainsTypeScript */;
                node.initializer = void 0;
                node.jsDoc = void 0;
                return node;
            }
            function updatePropertySignature(node, modifiers, name, questionToken, type) {
                return node.modifiers !== modifiers || node.name !== name || node.questionToken !== questionToken || node.type !== type ? finishUpdatePropertySignature(createPropertySignature(modifiers, name, questionToken, type), node) : node;
            }
            function finishUpdatePropertySignature(updated, original) {
                if (updated !== original) {
                    updated.initializer = original.initializer;
                }
                return update(updated, original);
            }
            function createPropertyDeclaration(modifiers, name, questionOrExclamationToken, type, initializer) {
                const node = createBaseDeclaration(172 /* PropertyDeclaration */);
                node.modifiers = asNodeArray(modifiers);
                node.name = asName(name);
                node.questionToken = questionOrExclamationToken && isQuestionToken(questionOrExclamationToken) ? questionOrExclamationToken : void 0;
                node.exclamationToken = questionOrExclamationToken && isExclamationToken(questionOrExclamationToken) ? questionOrExclamationToken : void 0;
                node.type = type;
                node.initializer = asInitializer(initializer);
                const isAmbient = node.flags & 33554432 /* Ambient */ || modifiersToFlags(node.modifiers) & 128 /* Ambient */;
                node.transformFlags = propagateChildrenFlags(node.modifiers) | propagateNameFlags(node.name) | propagateChildFlags(node.initializer) | (isAmbient || node.questionToken || node.exclamationToken || node.type ? 1 /* ContainsTypeScript */ : 0 /* None */) | (isComputedPropertyName(node.name) || modifiersToFlags(node.modifiers) & 256 /* Static */ && node.initializer ? 8192 /* ContainsTypeScriptClassSyntax */ : 0 /* None */) | 16777216 /* ContainsClassFields */;
                node.jsDoc = void 0;
                return node;
            }
            function updatePropertyDeclaration2(node, modifiers, name, questionOrExclamationToken, type, initializer) {
                return node.modifiers !== modifiers || node.name !== name || node.questionToken !== (questionOrExclamationToken !== void 0 && isQuestionToken(questionOrExclamationToken) ? questionOrExclamationToken : void 0) || node.exclamationToken !== (questionOrExclamationToken !== void 0 && isExclamationToken(questionOrExclamationToken) ? questionOrExclamationToken : void 0) || node.type !== type || node.initializer !== initializer ? update(createPropertyDeclaration(modifiers, name, questionOrExclamationToken, type, initializer), node) : node;
            }
            function createMethodSignature(modifiers, name, questionToken, typeParameters, parameters, type) {
                const node = createBaseDeclaration(173 /* MethodSignature */);
                node.modifiers = asNodeArray(modifiers);
                node.name = asName(name);
                node.questionToken = questionToken;
                node.typeParameters = asNodeArray(typeParameters);
                node.parameters = asNodeArray(parameters);
                node.type = type;
                node.transformFlags = 1 /* ContainsTypeScript */;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.typeArguments = void 0;
                return node;
            }
            function updateMethodSignature(node, modifiers, name, questionToken, typeParameters, parameters, type) {
                return node.modifiers !== modifiers || node.name !== name || node.questionToken !== questionToken || node.typeParameters !== typeParameters || node.parameters !== parameters || node.type !== type ? finishUpdateBaseSignatureDeclaration(createMethodSignature(modifiers, name, questionToken, typeParameters, parameters, type), node) : node;
            }
            function createMethodDeclaration(modifiers, asteriskToken, name, questionToken, typeParameters, parameters, type, body) {
                const node = createBaseDeclaration(174 /* MethodDeclaration */);
                node.modifiers = asNodeArray(modifiers);
                node.asteriskToken = asteriskToken;
                node.name = asName(name);
                node.questionToken = questionToken;
                node.exclamationToken = void 0;
                node.typeParameters = asNodeArray(typeParameters);
                node.parameters = createNodeArray(parameters);
                node.type = type;
                node.body = body;
                if (!node.body) {
                    node.transformFlags = 1 /* ContainsTypeScript */;
                }
                else {
                    const isAsync = modifiersToFlags(node.modifiers) & 1024 /* Async */;
                    const isGenerator = !!node.asteriskToken;
                    const isAsyncGenerator = isAsync && isGenerator;
                    node.transformFlags = propagateChildrenFlags(node.modifiers) | propagateChildFlags(node.asteriskToken) | propagateNameFlags(node.name) | propagateChildFlags(node.questionToken) | propagateChildrenFlags(node.typeParameters) | propagateChildrenFlags(node.parameters) | propagateChildFlags(node.type) | propagateChildFlags(node.body) & ~67108864 /* ContainsPossibleTopLevelAwait */ | (isAsyncGenerator ? 128 /* ContainsES2018 */ : isAsync ? 256 /* ContainsES2017 */ : isGenerator ? 2048 /* ContainsGenerator */ : 0 /* None */) | (node.questionToken || node.typeParameters || node.type ? 1 /* ContainsTypeScript */ : 0 /* None */) | 1024 /* ContainsES2015 */;
                }
                node.typeArguments = void 0;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.flowNode = void 0;
                node.endFlowNode = void 0;
                node.returnFlowNode = void 0;
                return node;
            }
            function updateMethodDeclaration(node, modifiers, asteriskToken, name, questionToken, typeParameters, parameters, type, body) {
                return node.modifiers !== modifiers || node.asteriskToken !== asteriskToken || node.name !== name || node.questionToken !== questionToken || node.typeParameters !== typeParameters || node.parameters !== parameters || node.type !== type || node.body !== body ? finishUpdateMethodDeclaration(createMethodDeclaration(modifiers, asteriskToken, name, questionToken, typeParameters, parameters, type, body), node) : node;
            }
            function finishUpdateMethodDeclaration(updated, original) {
                if (updated !== original) {
                    updated.exclamationToken = original.exclamationToken;
                }
                return update(updated, original);
            }
            function createClassStaticBlockDeclaration(body) {
                const node = createBaseDeclaration(175 /* ClassStaticBlockDeclaration */);
                node.body = body;
                node.transformFlags = propagateChildFlags(body) | 16777216 /* ContainsClassFields */;
                node.modifiers = void 0;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.endFlowNode = void 0;
                node.returnFlowNode = void 0;
                return node;
            }
            function updateClassStaticBlockDeclaration(node, body) {
                return node.body !== body ? finishUpdateClassStaticBlockDeclaration(createClassStaticBlockDeclaration(body), node) : node;
            }
            function finishUpdateClassStaticBlockDeclaration(updated, original) {
                if (updated !== original) {
                    updated.modifiers = original.modifiers;
                }
                return update(updated, original);
            }
            function createConstructorDeclaration(modifiers, parameters, body) {
                const node = createBaseDeclaration(176 /* Constructor */);
                node.modifiers = asNodeArray(modifiers);
                node.parameters = createNodeArray(parameters);
                node.body = body;
                node.transformFlags = propagateChildrenFlags(node.modifiers) | propagateChildrenFlags(node.parameters) | propagateChildFlags(node.body) & ~67108864 /* ContainsPossibleTopLevelAwait */ | 1024 /* ContainsES2015 */;
                node.typeParameters = void 0;
                node.type = void 0;
                node.typeArguments = void 0;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.endFlowNode = void 0;
                node.returnFlowNode = void 0;
                return node;
            }
            function updateConstructorDeclaration(node, modifiers, parameters, body) {
                return node.modifiers !== modifiers || node.parameters !== parameters || node.body !== body ? finishUpdateConstructorDeclaration(createConstructorDeclaration(modifiers, parameters, body), node) : node;
            }
            function finishUpdateConstructorDeclaration(updated, original) {
                if (updated !== original) {
                    updated.typeParameters = original.typeParameters;
                    updated.type = original.type;
                }
                return finishUpdateBaseSignatureDeclaration(updated, original);
            }
            function createGetAccessorDeclaration(modifiers, name, parameters, type, body) {
                const node = createBaseDeclaration(177 /* GetAccessor */);
                node.modifiers = asNodeArray(modifiers);
                node.name = asName(name);
                node.parameters = createNodeArray(parameters);
                node.type = type;
                node.body = body;
                if (!node.body) {
                    node.transformFlags = 1 /* ContainsTypeScript */;
                }
                else {
                    node.transformFlags = propagateChildrenFlags(node.modifiers) | propagateNameFlags(node.name) | propagateChildrenFlags(node.parameters) | propagateChildFlags(node.type) | propagateChildFlags(node.body) & ~67108864 /* ContainsPossibleTopLevelAwait */ | (node.type ? 1 /* ContainsTypeScript */ : 0 /* None */);
                }
                node.typeArguments = void 0;
                node.typeParameters = void 0;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.flowNode = void 0;
                node.endFlowNode = void 0;
                node.returnFlowNode = void 0;
                return node;
            }
            function updateGetAccessorDeclaration(node, modifiers, name, parameters, type, body) {
                return node.modifiers !== modifiers || node.name !== name || node.parameters !== parameters || node.type !== type || node.body !== body ? finishUpdateGetAccessorDeclaration(createGetAccessorDeclaration(modifiers, name, parameters, type, body), node) : node;
            }
            function finishUpdateGetAccessorDeclaration(updated, original) {
                if (updated !== original) {
                    updated.typeParameters = original.typeParameters;
                }
                return finishUpdateBaseSignatureDeclaration(updated, original);
            }
            function createSetAccessorDeclaration(modifiers, name, parameters, body) {
                const node = createBaseDeclaration(178 /* SetAccessor */);
                node.modifiers = asNodeArray(modifiers);
                node.name = asName(name);
                node.parameters = createNodeArray(parameters);
                node.body = body;
                if (!node.body) {
                    node.transformFlags = 1 /* ContainsTypeScript */;
                }
                else {
                    node.transformFlags = propagateChildrenFlags(node.modifiers) | propagateNameFlags(node.name) | propagateChildrenFlags(node.parameters) | propagateChildFlags(node.body) & ~67108864 /* ContainsPossibleTopLevelAwait */ | (node.type ? 1 /* ContainsTypeScript */ : 0 /* None */);
                }
                node.typeArguments = void 0;
                node.typeParameters = void 0;
                node.type = void 0;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.flowNode = void 0;
                node.endFlowNode = void 0;
                node.returnFlowNode = void 0;
                return node;
            }
            function updateSetAccessorDeclaration(node, modifiers, name, parameters, body) {
                return node.modifiers !== modifiers || node.name !== name || node.parameters !== parameters || node.body !== body ? finishUpdateSetAccessorDeclaration(createSetAccessorDeclaration(modifiers, name, parameters, body), node) : node;
            }
            function finishUpdateSetAccessorDeclaration(updated, original) {
                if (updated !== original) {
                    updated.typeParameters = original.typeParameters;
                    updated.type = original.type;
                }
                return finishUpdateBaseSignatureDeclaration(updated, original);
            }
            function createCallSignature(typeParameters, parameters, type) {
                const node = createBaseDeclaration(179 /* CallSignature */);
                node.typeParameters = asNodeArray(typeParameters);
                node.parameters = asNodeArray(parameters);
                node.type = type;
                node.transformFlags = 1 /* ContainsTypeScript */;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.typeArguments = void 0;
                return node;
            }
            function updateCallSignature(node, typeParameters, parameters, type) {
                return node.typeParameters !== typeParameters || node.parameters !== parameters || node.type !== type ? finishUpdateBaseSignatureDeclaration(createCallSignature(typeParameters, parameters, type), node) : node;
            }
            function createConstructSignature(typeParameters, parameters, type) {
                const node = createBaseDeclaration(180 /* ConstructSignature */);
                node.typeParameters = asNodeArray(typeParameters);
                node.parameters = asNodeArray(parameters);
                node.type = type;
                node.transformFlags = 1 /* ContainsTypeScript */;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.typeArguments = void 0;
                return node;
            }
            function updateConstructSignature(node, typeParameters, parameters, type) {
                return node.typeParameters !== typeParameters || node.parameters !== parameters || node.type !== type ? finishUpdateBaseSignatureDeclaration(createConstructSignature(typeParameters, parameters, type), node) : node;
            }
            function createIndexSignature(modifiers, parameters, type) {
                const node = createBaseDeclaration(181 /* IndexSignature */);
                node.modifiers = asNodeArray(modifiers);
                node.parameters = asNodeArray(parameters);
                node.type = type;
                node.transformFlags = 1 /* ContainsTypeScript */;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.typeArguments = void 0;
                return node;
            }
            function updateIndexSignature(node, modifiers, parameters, type) {
                return node.parameters !== parameters || node.type !== type || node.modifiers !== modifiers ? finishUpdateBaseSignatureDeclaration(createIndexSignature(modifiers, parameters, type), node) : node;
            }
            function createTemplateLiteralTypeSpan(type, literal) {
                const node = createBaseNode(204 /* TemplateLiteralTypeSpan */);
                node.type = type;
                node.literal = literal;
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateTemplateLiteralTypeSpan(node, type, literal) {
                return node.type !== type || node.literal !== literal ? update(createTemplateLiteralTypeSpan(type, literal), node) : node;
            }
            function createKeywordTypeNode(kind) {
                return createToken(kind);
            }
            function createTypePredicateNode(assertsModifier, parameterName, type) {
                const node = createBaseNode(182 /* TypePredicate */);
                node.assertsModifier = assertsModifier;
                node.parameterName = asName(parameterName);
                node.type = type;
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateTypePredicateNode(node, assertsModifier, parameterName, type) {
                return node.assertsModifier !== assertsModifier || node.parameterName !== parameterName || node.type !== type ? update(createTypePredicateNode(assertsModifier, parameterName, type), node) : node;
            }
            function createTypeReferenceNode(typeName, typeArguments) {
                const node = createBaseNode(183 /* TypeReference */);
                node.typeName = asName(typeName);
                node.typeArguments = typeArguments && parenthesizerRules().parenthesizeTypeArguments(createNodeArray(typeArguments));
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateTypeReferenceNode(node, typeName, typeArguments) {
                return node.typeName !== typeName || node.typeArguments !== typeArguments ? update(createTypeReferenceNode(typeName, typeArguments), node) : node;
            }
            function createFunctionTypeNode(typeParameters, parameters, type) {
                const node = createBaseDeclaration(184 /* FunctionType */);
                node.typeParameters = asNodeArray(typeParameters);
                node.parameters = asNodeArray(parameters);
                node.type = type;
                node.transformFlags = 1 /* ContainsTypeScript */;
                node.modifiers = void 0;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.typeArguments = void 0;
                return node;
            }
            function updateFunctionTypeNode(node, typeParameters, parameters, type) {
                return node.typeParameters !== typeParameters || node.parameters !== parameters || node.type !== type ? finishUpdateFunctionTypeNode(createFunctionTypeNode(typeParameters, parameters, type), node) : node;
            }
            function finishUpdateFunctionTypeNode(updated, original) {
                if (updated !== original) {
                    updated.modifiers = original.modifiers;
                }
                return finishUpdateBaseSignatureDeclaration(updated, original);
            }
            function createConstructorTypeNode(...args) {
                return args.length === 4 ? createConstructorTypeNode1(...args) : args.length === 3 ? createConstructorTypeNode2(...args) : Debug.fail("Incorrect number of arguments specified.");
            }
            function createConstructorTypeNode1(modifiers, typeParameters, parameters, type) {
                const node = createBaseDeclaration(185 /* ConstructorType */);
                node.modifiers = asNodeArray(modifiers);
                node.typeParameters = asNodeArray(typeParameters);
                node.parameters = asNodeArray(parameters);
                node.type = type;
                node.transformFlags = 1 /* ContainsTypeScript */;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.typeArguments = void 0;
                return node;
            }
            function createConstructorTypeNode2(typeParameters, parameters, type) {
                return createConstructorTypeNode1(
                /*modifiers*/
                void 0, typeParameters, parameters, type);
            }
            function updateConstructorTypeNode(...args) {
                return args.length === 5 ? updateConstructorTypeNode1(...args) : args.length === 4 ? updateConstructorTypeNode2(...args) : Debug.fail("Incorrect number of arguments specified.");
            }
            function updateConstructorTypeNode1(node, modifiers, typeParameters, parameters, type) {
                return node.modifiers !== modifiers || node.typeParameters !== typeParameters || node.parameters !== parameters || node.type !== type ? finishUpdateBaseSignatureDeclaration(createConstructorTypeNode(modifiers, typeParameters, parameters, type), node) : node;
            }
            function updateConstructorTypeNode2(node, typeParameters, parameters, type) {
                return updateConstructorTypeNode1(node, node.modifiers, typeParameters, parameters, type);
            }
            function createTypeQueryNode(exprName, typeArguments) {
                const node = createBaseNode(186 /* TypeQuery */);
                node.exprName = exprName;
                node.typeArguments = typeArguments && parenthesizerRules().parenthesizeTypeArguments(typeArguments);
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateTypeQueryNode(node, exprName, typeArguments) {
                return node.exprName !== exprName || node.typeArguments !== typeArguments ? update(createTypeQueryNode(exprName, typeArguments), node) : node;
            }
            function createTypeLiteralNode(members) {
                const node = createBaseDeclaration(187 /* TypeLiteral */);
                node.members = createNodeArray(members);
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateTypeLiteralNode(node, members) {
                return node.members !== members ? update(createTypeLiteralNode(members), node) : node;
            }
            function createArrayTypeNode(elementType) {
                const node = createBaseNode(188 /* ArrayType */);
                node.elementType = parenthesizerRules().parenthesizeNonArrayTypeOfPostfixType(elementType);
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateArrayTypeNode(node, elementType) {
                return node.elementType !== elementType ? update(createArrayTypeNode(elementType), node) : node;
            }
            function createTupleTypeNode(elements) {
                const node = createBaseNode(189 /* TupleType */);
                node.elements = createNodeArray(parenthesizerRules().parenthesizeElementTypesOfTupleType(elements));
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateTupleTypeNode(node, elements) {
                return node.elements !== elements ? update(createTupleTypeNode(elements), node) : node;
            }
            function createNamedTupleMember(dotDotDotToken, name, questionToken, type) {
                const node = createBaseDeclaration(202 /* NamedTupleMember */);
                node.dotDotDotToken = dotDotDotToken;
                node.name = name;
                node.questionToken = questionToken;
                node.type = type;
                node.transformFlags = 1 /* ContainsTypeScript */;
                node.jsDoc = void 0;
                return node;
            }
            function updateNamedTupleMember(node, dotDotDotToken, name, questionToken, type) {
                return node.dotDotDotToken !== dotDotDotToken || node.name !== name || node.questionToken !== questionToken || node.type !== type ? update(createNamedTupleMember(dotDotDotToken, name, questionToken, type), node) : node;
            }
            function createOptionalTypeNode(type) {
                const node = createBaseNode(190 /* OptionalType */);
                node.type = parenthesizerRules().parenthesizeTypeOfOptionalType(type);
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateOptionalTypeNode(node, type) {
                return node.type !== type ? update(createOptionalTypeNode(type), node) : node;
            }
            function createRestTypeNode(type) {
                const node = createBaseNode(191 /* RestType */);
                node.type = type;
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateRestTypeNode(node, type) {
                return node.type !== type ? update(createRestTypeNode(type), node) : node;
            }
            function createUnionOrIntersectionTypeNode(kind, types, parenthesize) {
                const node = createBaseNode(kind);
                node.types = factory2.createNodeArray(parenthesize(types));
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateUnionOrIntersectionTypeNode(node, types, parenthesize) {
                return node.types !== types ? update(createUnionOrIntersectionTypeNode(node.kind, types, parenthesize), node) : node;
            }
            function createUnionTypeNode(types) {
                return createUnionOrIntersectionTypeNode(192 /* UnionType */, types, parenthesizerRules().parenthesizeConstituentTypesOfUnionType);
            }
            function updateUnionTypeNode(node, types) {
                return updateUnionOrIntersectionTypeNode(node, types, parenthesizerRules().parenthesizeConstituentTypesOfUnionType);
            }
            function createIntersectionTypeNode(types) {
                return createUnionOrIntersectionTypeNode(193 /* IntersectionType */, types, parenthesizerRules().parenthesizeConstituentTypesOfIntersectionType);
            }
            function updateIntersectionTypeNode(node, types) {
                return updateUnionOrIntersectionTypeNode(node, types, parenthesizerRules().parenthesizeConstituentTypesOfIntersectionType);
            }
            function createConditionalTypeNode(checkType, extendsType, trueType, falseType) {
                const node = createBaseNode(194 /* ConditionalType */);
                node.checkType = parenthesizerRules().parenthesizeCheckTypeOfConditionalType(checkType);
                node.extendsType = parenthesizerRules().parenthesizeExtendsTypeOfConditionalType(extendsType);
                node.trueType = trueType;
                node.falseType = falseType;
                node.transformFlags = 1 /* ContainsTypeScript */;
                node.locals = void 0;
                node.nextContainer = void 0;
                return node;
            }
            function updateConditionalTypeNode(node, checkType, extendsType, trueType, falseType) {
                return node.checkType !== checkType || node.extendsType !== extendsType || node.trueType !== trueType || node.falseType !== falseType ? update(createConditionalTypeNode(checkType, extendsType, trueType, falseType), node) : node;
            }
            function createInferTypeNode(typeParameter) {
                const node = createBaseNode(195 /* InferType */);
                node.typeParameter = typeParameter;
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateInferTypeNode(node, typeParameter) {
                return node.typeParameter !== typeParameter ? update(createInferTypeNode(typeParameter), node) : node;
            }
            function createTemplateLiteralType(head, templateSpans) {
                const node = createBaseNode(203 /* TemplateLiteralType */);
                node.head = head;
                node.templateSpans = createNodeArray(templateSpans);
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateTemplateLiteralType(node, head, templateSpans) {
                return node.head !== head || node.templateSpans !== templateSpans ? update(createTemplateLiteralType(head, templateSpans), node) : node;
            }
            function createImportTypeNode(argument, attributes, qualifier, typeArguments, isTypeOf = false) {
                const node = createBaseNode(205 /* ImportType */);
                node.argument = argument;
                node.attributes = attributes;
                if (node.assertions && node.assertions.assertClause && node.attributes) {
                    node.assertions.assertClause = node.attributes;
                }
                node.qualifier = qualifier;
                node.typeArguments = typeArguments && parenthesizerRules().parenthesizeTypeArguments(typeArguments);
                node.isTypeOf = isTypeOf;
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateImportTypeNode(node, argument, attributes, qualifier, typeArguments, isTypeOf = node.isTypeOf) {
                return node.argument !== argument || node.attributes !== attributes || node.qualifier !== qualifier || node.typeArguments !== typeArguments || node.isTypeOf !== isTypeOf ? update(createImportTypeNode(argument, attributes, qualifier, typeArguments, isTypeOf), node) : node;
            }
            function createParenthesizedType(type) {
                const node = createBaseNode(196 /* ParenthesizedType */);
                node.type = type;
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateParenthesizedType(node, type) {
                return node.type !== type ? update(createParenthesizedType(type), node) : node;
            }
            function createThisTypeNode() {
                const node = createBaseNode(197 /* ThisType */);
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function createTypeOperatorNode(operator, type) {
                const node = createBaseNode(198 /* TypeOperator */);
                node.operator = operator;
                node.type = operator === 148 /* ReadonlyKeyword */ ? parenthesizerRules().parenthesizeOperandOfReadonlyTypeOperator(type) : parenthesizerRules().parenthesizeOperandOfTypeOperator(type);
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateTypeOperatorNode(node, type) {
                return node.type !== type ? update(createTypeOperatorNode(node.operator, type), node) : node;
            }
            function createIndexedAccessTypeNode(objectType, indexType) {
                const node = createBaseNode(199 /* IndexedAccessType */);
                node.objectType = parenthesizerRules().parenthesizeNonArrayTypeOfPostfixType(objectType);
                node.indexType = indexType;
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateIndexedAccessTypeNode(node, objectType, indexType) {
                return node.objectType !== objectType || node.indexType !== indexType ? update(createIndexedAccessTypeNode(objectType, indexType), node) : node;
            }
            function createMappedTypeNode(readonlyToken, typeParameter, nameType, questionToken, type, members) {
                const node = createBaseDeclaration(200 /* MappedType */);
                node.readonlyToken = readonlyToken;
                node.typeParameter = typeParameter;
                node.nameType = nameType;
                node.questionToken = questionToken;
                node.type = type;
                node.members = members && createNodeArray(members);
                node.transformFlags = 1 /* ContainsTypeScript */;
                node.locals = void 0;
                node.nextContainer = void 0;
                return node;
            }
            function updateMappedTypeNode(node, readonlyToken, typeParameter, nameType, questionToken, type, members) {
                return node.readonlyToken !== readonlyToken || node.typeParameter !== typeParameter || node.nameType !== nameType || node.questionToken !== questionToken || node.type !== type || node.members !== members ? update(createMappedTypeNode(readonlyToken, typeParameter, nameType, questionToken, type, members), node) : node;
            }
            function createLiteralTypeNode(literal) {
                const node = createBaseNode(201 /* LiteralType */);
                node.literal = literal;
                node.transformFlags = 1 /* ContainsTypeScript */;
                return node;
            }
            function updateLiteralTypeNode(node, literal) {
                return node.literal !== literal ? update(createLiteralTypeNode(literal), node) : node;
            }
            function createObjectBindingPattern(elements) {
                const node = createBaseNode(206 /* ObjectBindingPattern */);
                node.elements = createNodeArray(elements);
                node.transformFlags |= propagateChildrenFlags(node.elements) | 1024 /* ContainsES2015 */ | 524288 /* ContainsBindingPattern */;
                if (node.transformFlags & 32768 /* ContainsRestOrSpread */) {
                    node.transformFlags |= 128 /* ContainsES2018 */ | 65536 /* ContainsObjectRestOrSpread */;
                }
                return node;
            }
            function updateObjectBindingPattern(node, elements) {
                return node.elements !== elements ? update(createObjectBindingPattern(elements), node) : node;
            }
            function createArrayBindingPattern(elements) {
                const node = createBaseNode(207 /* ArrayBindingPattern */);
                node.elements = createNodeArray(elements);
                node.transformFlags |= propagateChildrenFlags(node.elements) | 1024 /* ContainsES2015 */ | 524288 /* ContainsBindingPattern */;
                return node;
            }
            function updateArrayBindingPattern(node, elements) {
                return node.elements !== elements ? update(createArrayBindingPattern(elements), node) : node;
            }
            function createBindingElement(dotDotDotToken, propertyName, name, initializer) {
                const node = createBaseDeclaration(208 /* BindingElement */);
                node.dotDotDotToken = dotDotDotToken;
                node.propertyName = asName(propertyName);
                node.name = asName(name);
                node.initializer = asInitializer(initializer);
                node.transformFlags |= propagateChildFlags(node.dotDotDotToken) | propagateNameFlags(node.propertyName) | propagateNameFlags(node.name) | propagateChildFlags(node.initializer) | (node.dotDotDotToken ? 32768 /* ContainsRestOrSpread */ : 0 /* None */) | 1024 /* ContainsES2015 */;
                node.flowNode = void 0;
                return node;
            }
            function updateBindingElement(node, dotDotDotToken, propertyName, name, initializer) {
                return node.propertyName !== propertyName || node.dotDotDotToken !== dotDotDotToken || node.name !== name || node.initializer !== initializer ? update(createBindingElement(dotDotDotToken, propertyName, name, initializer), node) : node;
            }
            function createArrayLiteralExpression(elements, multiLine) {
                const node = createBaseNode(209 /* ArrayLiteralExpression */);
                const lastElement = elements && lastOrUndefined(elements);
                const elementsArray = createNodeArray(elements, lastElement && isOmittedExpression(lastElement) ? true : void 0);
                node.elements = parenthesizerRules().parenthesizeExpressionsOfCommaDelimitedList(elementsArray);
                node.multiLine = multiLine;
                node.transformFlags |= propagateChildrenFlags(node.elements);
                return node;
            }
            function updateArrayLiteralExpression(node, elements) {
                return node.elements !== elements ? update(createArrayLiteralExpression(elements, node.multiLine), node) : node;
            }
            function createObjectLiteralExpression(properties, multiLine) {
                const node = createBaseDeclaration(210 /* ObjectLiteralExpression */);
                node.properties = createNodeArray(properties);
                node.multiLine = multiLine;
                node.transformFlags |= propagateChildrenFlags(node.properties);
                node.jsDoc = void 0;
                return node;
            }
            function updateObjectLiteralExpression(node, properties) {
                return node.properties !== properties ? update(createObjectLiteralExpression(properties, node.multiLine), node) : node;
            }
            function createBasePropertyAccessExpression(expression, questionDotToken, name) {
                const node = createBaseDeclaration(211 /* PropertyAccessExpression */);
                node.expression = expression;
                node.questionDotToken = questionDotToken;
                node.name = name;
                node.transformFlags = propagateChildFlags(node.expression) | propagateChildFlags(node.questionDotToken) | (isIdentifier(node.name) ? propagateIdentifierNameFlags(node.name) : propagateChildFlags(node.name) | 536870912 /* ContainsPrivateIdentifierInExpression */);
                node.jsDoc = void 0;
                node.flowNode = void 0;
                return node;
            }
            function createPropertyAccessExpression(expression, name) {
                const node = createBasePropertyAccessExpression(parenthesizerRules().parenthesizeLeftSideOfAccess(expression, 
                /*optionalChain*/
                false), 
                /*questionDotToken*/
                void 0, asName(name));
                if (isSuperKeyword(expression)) {
                    node.transformFlags |= 256 /* ContainsES2017 */ | 128 /* ContainsES2018 */;
                }
                return node;
            }
            function updatePropertyAccessExpression(node, expression, name) {
                if (isPropertyAccessChain(node)) {
                    return updatePropertyAccessChain(node, expression, node.questionDotToken, cast(name, isIdentifier));
                }
                return node.expression !== expression || node.name !== name ? update(createPropertyAccessExpression(expression, name), node) : node;
            }
            function createPropertyAccessChain(expression, questionDotToken, name) {
                const node = createBasePropertyAccessExpression(parenthesizerRules().parenthesizeLeftSideOfAccess(expression, 
                /*optionalChain*/
                true), questionDotToken, asName(name));
                node.flags |= 64 /* OptionalChain */;
                node.transformFlags |= 32 /* ContainsES2020 */;
                return node;
            }
            function updatePropertyAccessChain(node, expression, questionDotToken, name) {
                Debug.assert(!!(node.flags & 64 /* OptionalChain */), "Cannot update a PropertyAccessExpression using updatePropertyAccessChain. Use updatePropertyAccess instead.");
                return node.expression !== expression || node.questionDotToken !== questionDotToken || node.name !== name ? update(createPropertyAccessChain(expression, questionDotToken, name), node) : node;
            }
            function createBaseElementAccessExpression(expression, questionDotToken, argumentExpression) {
                const node = createBaseDeclaration(212 /* ElementAccessExpression */);
                node.expression = expression;
                node.questionDotToken = questionDotToken;
                node.argumentExpression = argumentExpression;
                node.transformFlags |= propagateChildFlags(node.expression) | propagateChildFlags(node.questionDotToken) | propagateChildFlags(node.argumentExpression);
                node.jsDoc = void 0;
                node.flowNode = void 0;
                return node;
            }
            function createElementAccessExpression(expression, index) {
                const node = createBaseElementAccessExpression(parenthesizerRules().parenthesizeLeftSideOfAccess(expression, 
                /*optionalChain*/
                false), 
                /*questionDotToken*/
                void 0, asExpression(index));
                if (isSuperKeyword(expression)) {
                    node.transformFlags |= 256 /* ContainsES2017 */ | 128 /* ContainsES2018 */;
                }
                return node;
            }
            function updateElementAccessExpression(node, expression, argumentExpression) {
                if (isElementAccessChain(node)) {
                    return updateElementAccessChain(node, expression, node.questionDotToken, argumentExpression);
                }
                return node.expression !== expression || node.argumentExpression !== argumentExpression ? update(createElementAccessExpression(expression, argumentExpression), node) : node;
            }
            function createElementAccessChain(expression, questionDotToken, index) {
                const node = createBaseElementAccessExpression(parenthesizerRules().parenthesizeLeftSideOfAccess(expression, 
                /*optionalChain*/
                true), questionDotToken, asExpression(index));
                node.flags |= 64 /* OptionalChain */;
                node.transformFlags |= 32 /* ContainsES2020 */;
                return node;
            }
            function updateElementAccessChain(node, expression, questionDotToken, argumentExpression) {
                Debug.assert(!!(node.flags & 64 /* OptionalChain */), "Cannot update a ElementAccessExpression using updateElementAccessChain. Use updateElementAccess instead.");
                return node.expression !== expression || node.questionDotToken !== questionDotToken || node.argumentExpression !== argumentExpression ? update(createElementAccessChain(expression, questionDotToken, argumentExpression), node) : node;
            }
            function createBaseCallExpression(expression, questionDotToken, typeArguments, argumentsArray) {
                const node = createBaseDeclaration(213 /* CallExpression */);
                node.expression = expression;
                node.questionDotToken = questionDotToken;
                node.typeArguments = typeArguments;
                node.arguments = argumentsArray;
                node.transformFlags |= propagateChildFlags(node.expression) | propagateChildFlags(node.questionDotToken) | propagateChildrenFlags(node.typeArguments) | propagateChildrenFlags(node.arguments);
                if (node.typeArguments) {
                    node.transformFlags |= 1 /* ContainsTypeScript */;
                }
                if (isSuperProperty(node.expression)) {
                    node.transformFlags |= 16384 /* ContainsLexicalThis */;
                }
                return node;
            }
            function createCallExpression(expression, typeArguments, argumentsArray) {
                const node = createBaseCallExpression(parenthesizerRules().parenthesizeLeftSideOfAccess(expression, 
                /*optionalChain*/
                false), 
                /*questionDotToken*/
                void 0, asNodeArray(typeArguments), parenthesizerRules().parenthesizeExpressionsOfCommaDelimitedList(createNodeArray(argumentsArray)));
                if (isImportKeyword(node.expression)) {
                    node.transformFlags |= 8388608 /* ContainsDynamicImport */;
                }
                return node;
            }
            function updateCallExpression(node, expression, typeArguments, argumentsArray) {
                if (isCallChain(node)) {
                    return updateCallChain(node, expression, node.questionDotToken, typeArguments, argumentsArray);
                }
                return node.expression !== expression || node.typeArguments !== typeArguments || node.arguments !== argumentsArray ? update(createCallExpression(expression, typeArguments, argumentsArray), node) : node;
            }
            function createCallChain(expression, questionDotToken, typeArguments, argumentsArray) {
                const node = createBaseCallExpression(parenthesizerRules().parenthesizeLeftSideOfAccess(expression, 
                /*optionalChain*/
                true), questionDotToken, asNodeArray(typeArguments), parenthesizerRules().parenthesizeExpressionsOfCommaDelimitedList(createNodeArray(argumentsArray)));
                node.flags |= 64 /* OptionalChain */;
                node.transformFlags |= 32 /* ContainsES2020 */;
                return node;
            }
            function updateCallChain(node, expression, questionDotToken, typeArguments, argumentsArray) {
                Debug.assert(!!(node.flags & 64 /* OptionalChain */), "Cannot update a CallExpression using updateCallChain. Use updateCall instead.");
                return node.expression !== expression || node.questionDotToken !== questionDotToken || node.typeArguments !== typeArguments || node.arguments !== argumentsArray ? update(createCallChain(expression, questionDotToken, typeArguments, argumentsArray), node) : node;
            }
            function createNewExpression(expression, typeArguments, argumentsArray) {
                const node = createBaseDeclaration(214 /* NewExpression */);
                node.expression = parenthesizerRules().parenthesizeExpressionOfNew(expression);
                node.typeArguments = asNodeArray(typeArguments);
                node.arguments = argumentsArray ? parenthesizerRules().parenthesizeExpressionsOfCommaDelimitedList(argumentsArray) : void 0;
                node.transformFlags |= propagateChildFlags(node.expression) | propagateChildrenFlags(node.typeArguments) | propagateChildrenFlags(node.arguments) | 32 /* ContainsES2020 */;
                if (node.typeArguments) {
                    node.transformFlags |= 1 /* ContainsTypeScript */;
                }
                return node;
            }
            function updateNewExpression(node, expression, typeArguments, argumentsArray) {
                return node.expression !== expression || node.typeArguments !== typeArguments || node.arguments !== argumentsArray ? update(createNewExpression(expression, typeArguments, argumentsArray), node) : node;
            }
            function createTaggedTemplateExpression(tag, typeArguments, template) {
                const node = createBaseNode(215 /* TaggedTemplateExpression */);
                node.tag = parenthesizerRules().parenthesizeLeftSideOfAccess(tag, 
                /*optionalChain*/
                false);
                node.typeArguments = asNodeArray(typeArguments);
                node.template = template;
                node.transformFlags |= propagateChildFlags(node.tag) | propagateChildrenFlags(node.typeArguments) | propagateChildFlags(node.template) | 1024 /* ContainsES2015 */;
                if (node.typeArguments) {
                    node.transformFlags |= 1 /* ContainsTypeScript */;
                }
                if (hasInvalidEscape(node.template)) {
                    node.transformFlags |= 128 /* ContainsES2018 */;
                }
                return node;
            }
            function updateTaggedTemplateExpression(node, tag, typeArguments, template) {
                return node.tag !== tag || node.typeArguments !== typeArguments || node.template !== template ? update(createTaggedTemplateExpression(tag, typeArguments, template), node) : node;
            }
            function createTypeAssertion(type, expression) {
                const node = createBaseNode(216 /* TypeAssertionExpression */);
                node.expression = parenthesizerRules().parenthesizeOperandOfPrefixUnary(expression);
                node.type = type;
                node.transformFlags |= propagateChildFlags(node.expression) | propagateChildFlags(node.type) | 1 /* ContainsTypeScript */;
                return node;
            }
            function updateTypeAssertion(node, type, expression) {
                return node.type !== type || node.expression !== expression ? update(createTypeAssertion(type, expression), node) : node;
            }
            function createParenthesizedExpression(expression) {
                const node = createBaseNode(217 /* ParenthesizedExpression */);
                node.expression = expression;
                node.transformFlags = propagateChildFlags(node.expression);
                node.jsDoc = void 0;
                return node;
            }
            function updateParenthesizedExpression(node, expression) {
                return node.expression !== expression ? update(createParenthesizedExpression(expression), node) : node;
            }
            function createFunctionExpression(modifiers, asteriskToken, name, typeParameters, parameters, type, body) {
                const node = createBaseDeclaration(218 /* FunctionExpression */);
                node.modifiers = asNodeArray(modifiers);
                node.asteriskToken = asteriskToken;
                node.name = asName(name);
                node.typeParameters = asNodeArray(typeParameters);
                node.parameters = createNodeArray(parameters);
                node.type = type;
                node.body = body;
                const isAsync = modifiersToFlags(node.modifiers) & 1024 /* Async */;
                const isGenerator = !!node.asteriskToken;
                const isAsyncGenerator = isAsync && isGenerator;
                node.transformFlags = propagateChildrenFlags(node.modifiers) | propagateChildFlags(node.asteriskToken) | propagateNameFlags(node.name) | propagateChildrenFlags(node.typeParameters) | propagateChildrenFlags(node.parameters) | propagateChildFlags(node.type) | propagateChildFlags(node.body) & ~67108864 /* ContainsPossibleTopLevelAwait */ | (isAsyncGenerator ? 128 /* ContainsES2018 */ : isAsync ? 256 /* ContainsES2017 */ : isGenerator ? 2048 /* ContainsGenerator */ : 0 /* None */) | (node.typeParameters || node.type ? 1 /* ContainsTypeScript */ : 0 /* None */) | 4194304 /* ContainsHoistedDeclarationOrCompletion */;
                node.typeArguments = void 0;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.flowNode = void 0;
                node.endFlowNode = void 0;
                node.returnFlowNode = void 0;
                return node;
            }
            function updateFunctionExpression(node, modifiers, asteriskToken, name, typeParameters, parameters, type, body) {
                return node.name !== name || node.modifiers !== modifiers || node.asteriskToken !== asteriskToken || node.typeParameters !== typeParameters || node.parameters !== parameters || node.type !== type || node.body !== body ? finishUpdateBaseSignatureDeclaration(createFunctionExpression(modifiers, asteriskToken, name, typeParameters, parameters, type, body), node) : node;
            }
            function createArrowFunction(modifiers, typeParameters, parameters, type, equalsGreaterThanToken, body) {
                const node = createBaseDeclaration(219 /* ArrowFunction */);
                node.modifiers = asNodeArray(modifiers);
                node.typeParameters = asNodeArray(typeParameters);
                node.parameters = createNodeArray(parameters);
                node.type = type;
                node.equalsGreaterThanToken = equalsGreaterThanToken ?? createToken(39 /* EqualsGreaterThanToken */);
                node.body = parenthesizerRules().parenthesizeConciseBodyOfArrowFunction(body);
                const isAsync = modifiersToFlags(node.modifiers) & 1024 /* Async */;
                node.transformFlags = propagateChildrenFlags(node.modifiers) | propagateChildrenFlags(node.typeParameters) | propagateChildrenFlags(node.parameters) | propagateChildFlags(node.type) | propagateChildFlags(node.equalsGreaterThanToken) | propagateChildFlags(node.body) & ~67108864 /* ContainsPossibleTopLevelAwait */ | (node.typeParameters || node.type ? 1 /* ContainsTypeScript */ : 0 /* None */) | (isAsync ? 256 /* ContainsES2017 */ | 16384 /* ContainsLexicalThis */ : 0 /* None */) | 1024 /* ContainsES2015 */;
                node.typeArguments = void 0;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.flowNode = void 0;
                node.endFlowNode = void 0;
                node.returnFlowNode = void 0;
                return node;
            }
            function updateArrowFunction(node, modifiers, typeParameters, parameters, type, equalsGreaterThanToken, body) {
                return node.modifiers !== modifiers || node.typeParameters !== typeParameters || node.parameters !== parameters || node.type !== type || node.equalsGreaterThanToken !== equalsGreaterThanToken || node.body !== body ? finishUpdateBaseSignatureDeclaration(createArrowFunction(modifiers, typeParameters, parameters, type, equalsGreaterThanToken, body), node) : node;
            }
            function createDeleteExpression(expression) {
                const node = createBaseNode(220 /* DeleteExpression */);
                node.expression = parenthesizerRules().parenthesizeOperandOfPrefixUnary(expression);
                node.transformFlags |= propagateChildFlags(node.expression);
                return node;
            }
            function updateDeleteExpression(node, expression) {
                return node.expression !== expression ? update(createDeleteExpression(expression), node) : node;
            }
            function createTypeOfExpression(expression) {
                const node = createBaseNode(221 /* TypeOfExpression */);
                node.expression = parenthesizerRules().parenthesizeOperandOfPrefixUnary(expression);
                node.transformFlags |= propagateChildFlags(node.expression);
                return node;
            }
            function updateTypeOfExpression(node, expression) {
                return node.expression !== expression ? update(createTypeOfExpression(expression), node) : node;
            }
            function createVoidExpression(expression) {
                const node = createBaseNode(222 /* VoidExpression */);
                node.expression = parenthesizerRules().parenthesizeOperandOfPrefixUnary(expression);
                node.transformFlags |= propagateChildFlags(node.expression);
                return node;
            }
            function updateVoidExpression(node, expression) {
                return node.expression !== expression ? update(createVoidExpression(expression), node) : node;
            }
            function createAwaitExpression(expression) {
                const node = createBaseNode(223 /* AwaitExpression */);
                node.expression = parenthesizerRules().parenthesizeOperandOfPrefixUnary(expression);
                node.transformFlags |= propagateChildFlags(node.expression) | 256 /* ContainsES2017 */ | 128 /* ContainsES2018 */ | 2097152 /* ContainsAwait */;
                return node;
            }
            function updateAwaitExpression(node, expression) {
                return node.expression !== expression ? update(createAwaitExpression(expression), node) : node;
            }
            function createPrefixUnaryExpression(operator, operand) {
                const node = createBaseNode(224 /* PrefixUnaryExpression */);
                node.operator = operator;
                node.operand = parenthesizerRules().parenthesizeOperandOfPrefixUnary(operand);
                node.transformFlags |= propagateChildFlags(node.operand);
                if ((operator === 46 /* PlusPlusToken */ || operator === 47 /* MinusMinusToken */) && isIdentifier(node.operand) && !isGeneratedIdentifier(node.operand) && !isLocalName(node.operand)) {
                    node.transformFlags |= 268435456 /* ContainsUpdateExpressionForIdentifier */;
                }
                return node;
            }
            function updatePrefixUnaryExpression(node, operand) {
                return node.operand !== operand ? update(createPrefixUnaryExpression(node.operator, operand), node) : node;
            }
            function createPostfixUnaryExpression(operand, operator) {
                const node = createBaseNode(225 /* PostfixUnaryExpression */);
                node.operator = operator;
                node.operand = parenthesizerRules().parenthesizeOperandOfPostfixUnary(operand);
                node.transformFlags |= propagateChildFlags(node.operand);
                if (isIdentifier(node.operand) && !isGeneratedIdentifier(node.operand) && !isLocalName(node.operand)) {
                    node.transformFlags |= 268435456 /* ContainsUpdateExpressionForIdentifier */;
                }
                return node;
            }
            function updatePostfixUnaryExpression(node, operand) {
                return node.operand !== operand ? update(createPostfixUnaryExpression(operand, node.operator), node) : node;
            }
            function createBinaryExpression(left, operator, right) {
                const node = createBaseDeclaration(226 /* BinaryExpression */);
                const operatorToken = asToken(operator);
                const operatorKind = operatorToken.kind;
                node.left = parenthesizerRules().parenthesizeLeftSideOfBinary(operatorKind, left);
                node.operatorToken = operatorToken;
                node.right = parenthesizerRules().parenthesizeRightSideOfBinary(operatorKind, node.left, right);
                node.transformFlags |= propagateChildFlags(node.left) | propagateChildFlags(node.operatorToken) | propagateChildFlags(node.right);
                if (operatorKind === 61 /* QuestionQuestionToken */) {
                    node.transformFlags |= 32 /* ContainsES2020 */;
                }
                else if (operatorKind === 64 /* EqualsToken */) {
                    if (isObjectLiteralExpression(node.left)) {
                        node.transformFlags |= 1024 /* ContainsES2015 */ | 128 /* ContainsES2018 */ | 4096 /* ContainsDestructuringAssignment */ | propagateAssignmentPatternFlags(node.left);
                    }
                    else if (isArrayLiteralExpression(node.left)) {
                        node.transformFlags |= 1024 /* ContainsES2015 */ | 4096 /* ContainsDestructuringAssignment */ | propagateAssignmentPatternFlags(node.left);
                    }
                }
                else if (operatorKind === 43 /* AsteriskAsteriskToken */ || operatorKind === 68 /* AsteriskAsteriskEqualsToken */) {
                    node.transformFlags |= 512 /* ContainsES2016 */;
                }
                else if (isLogicalOrCoalescingAssignmentOperator(operatorKind)) {
                    node.transformFlags |= 16 /* ContainsES2021 */;
                }
                if (operatorKind === 103 /* InKeyword */ && isPrivateIdentifier(node.left)) {
                    node.transformFlags |= 536870912 /* ContainsPrivateIdentifierInExpression */;
                }
                node.jsDoc = void 0;
                return node;
            }
            function propagateAssignmentPatternFlags(node) {
                return containsObjectRestOrSpread(node) ? 65536 /* ContainsObjectRestOrSpread */ : 0 /* None */;
            }
            function updateBinaryExpression(node, left, operator, right) {
                return node.left !== left || node.operatorToken !== operator || node.right !== right ? update(createBinaryExpression(left, operator, right), node) : node;
            }
            function createConditionalExpression(condition, questionToken, whenTrue, colonToken, whenFalse) {
                const node = createBaseNode(227 /* ConditionalExpression */);
                node.condition = parenthesizerRules().parenthesizeConditionOfConditionalExpression(condition);
                node.questionToken = questionToken ?? createToken(58 /* QuestionToken */);
                node.whenTrue = parenthesizerRules().parenthesizeBranchOfConditionalExpression(whenTrue);
                node.colonToken = colonToken ?? createToken(59 /* ColonToken */);
                node.whenFalse = parenthesizerRules().parenthesizeBranchOfConditionalExpression(whenFalse);
                node.transformFlags |= propagateChildFlags(node.condition) | propagateChildFlags(node.questionToken) | propagateChildFlags(node.whenTrue) | propagateChildFlags(node.colonToken) | propagateChildFlags(node.whenFalse);
                return node;
            }
            function updateConditionalExpression(node, condition, questionToken, whenTrue, colonToken, whenFalse) {
                return node.condition !== condition || node.questionToken !== questionToken || node.whenTrue !== whenTrue || node.colonToken !== colonToken || node.whenFalse !== whenFalse ? update(createConditionalExpression(condition, questionToken, whenTrue, colonToken, whenFalse), node) : node;
            }
            function createTemplateExpression(head, templateSpans) {
                const node = createBaseNode(228 /* TemplateExpression */);
                node.head = head;
                node.templateSpans = createNodeArray(templateSpans);
                node.transformFlags |= propagateChildFlags(node.head) | propagateChildrenFlags(node.templateSpans) | 1024 /* ContainsES2015 */;
                return node;
            }
            function updateTemplateExpression(node, head, templateSpans) {
                return node.head !== head || node.templateSpans !== templateSpans ? update(createTemplateExpression(head, templateSpans), node) : node;
            }
            function checkTemplateLiteralLikeNode(kind, text, rawText, templateFlags = 0 /* None */) {
                Debug.assert(!(templateFlags & ~7176 /* TemplateLiteralLikeFlags */), "Unsupported template flags.");
                let cooked = void 0;
                if (rawText !== void 0 && rawText !== text) {
                    cooked = getCookedText(kind, rawText);
                    if (typeof cooked === "object") {
                        return Debug.fail("Invalid raw text");
                    }
                }
                if (text === void 0) {
                    if (cooked === void 0) {
                        return Debug.fail("Arguments 'text' and 'rawText' may not both be undefined.");
                    }
                    text = cooked;
                }
                else if (cooked !== void 0) {
                    Debug.assert(text === cooked, "Expected argument 'text' to be the normalized (i.e. 'cooked') version of argument 'rawText'.");
                }
                return text;
            }
            function getTransformFlagsOfTemplateLiteralLike(templateFlags) {
                let transformFlags = 1024 /* ContainsES2015 */;
                if (templateFlags) {
                    transformFlags |= 128 /* ContainsES2018 */;
                }
                return transformFlags;
            }
            function createTemplateLiteralLikeToken(kind, text, rawText, templateFlags) {
                const node = createBaseToken(kind);
                node.text = text;
                node.rawText = rawText;
                node.templateFlags = templateFlags & 7176 /* TemplateLiteralLikeFlags */;
                node.transformFlags = getTransformFlagsOfTemplateLiteralLike(node.templateFlags);
                return node;
            }
            function createTemplateLiteralLikeDeclaration(kind, text, rawText, templateFlags) {
                const node = createBaseDeclaration(kind);
                node.text = text;
                node.rawText = rawText;
                node.templateFlags = templateFlags & 7176 /* TemplateLiteralLikeFlags */;
                node.transformFlags = getTransformFlagsOfTemplateLiteralLike(node.templateFlags);
                return node;
            }
            function createTemplateLiteralLikeNode(kind, text, rawText, templateFlags) {
                if (kind === 15 /* NoSubstitutionTemplateLiteral */) {
                    return createTemplateLiteralLikeDeclaration(kind, text, rawText, templateFlags);
                }
                return createTemplateLiteralLikeToken(kind, text, rawText, templateFlags);
            }
            function createTemplateHead(text, rawText, templateFlags) {
                text = checkTemplateLiteralLikeNode(16 /* TemplateHead */, text, rawText, templateFlags);
                return createTemplateLiteralLikeNode(16 /* TemplateHead */, text, rawText, templateFlags);
            }
            function createTemplateMiddle(text, rawText, templateFlags) {
                text = checkTemplateLiteralLikeNode(16 /* TemplateHead */, text, rawText, templateFlags);
                return createTemplateLiteralLikeNode(17 /* TemplateMiddle */, text, rawText, templateFlags);
            }
            function createTemplateTail(text, rawText, templateFlags) {
                text = checkTemplateLiteralLikeNode(16 /* TemplateHead */, text, rawText, templateFlags);
                return createTemplateLiteralLikeNode(18 /* TemplateTail */, text, rawText, templateFlags);
            }
            function createNoSubstitutionTemplateLiteral(text, rawText, templateFlags) {
                text = checkTemplateLiteralLikeNode(16 /* TemplateHead */, text, rawText, templateFlags);
                return createTemplateLiteralLikeDeclaration(15 /* NoSubstitutionTemplateLiteral */, text, rawText, templateFlags);
            }
            function createYieldExpression(asteriskToken, expression) {
                Debug.assert(!asteriskToken || !!expression, "A `YieldExpression` with an asteriskToken must have an expression.");
                const node = createBaseNode(229 /* YieldExpression */);
                node.expression = expression && parenthesizerRules().parenthesizeExpressionForDisallowedComma(expression);
                node.asteriskToken = asteriskToken;
                node.transformFlags |= propagateChildFlags(node.expression) | propagateChildFlags(node.asteriskToken) | 1024 /* ContainsES2015 */ | 128 /* ContainsES2018 */ | 1048576 /* ContainsYield */;
                return node;
            }
            function updateYieldExpression(node, asteriskToken, expression) {
                return node.expression !== expression || node.asteriskToken !== asteriskToken ? update(createYieldExpression(asteriskToken, expression), node) : node;
            }
            function createSpreadElement(expression) {
                const node = createBaseNode(230 /* SpreadElement */);
                node.expression = parenthesizerRules().parenthesizeExpressionForDisallowedComma(expression);
                node.transformFlags |= propagateChildFlags(node.expression) | 1024 /* ContainsES2015 */ | 32768 /* ContainsRestOrSpread */;
                return node;
            }
            function updateSpreadElement(node, expression) {
                return node.expression !== expression ? update(createSpreadElement(expression), node) : node;
            }
            function createClassExpression(modifiers, name, typeParameters, heritageClauses, members) {
                const node = createBaseDeclaration(231 /* ClassExpression */);
                node.modifiers = asNodeArray(modifiers);
                node.name = asName(name);
                node.typeParameters = asNodeArray(typeParameters);
                node.heritageClauses = asNodeArray(heritageClauses);
                node.members = createNodeArray(members);
                node.transformFlags |= propagateChildrenFlags(node.modifiers) | propagateNameFlags(node.name) | propagateChildrenFlags(node.typeParameters) | propagateChildrenFlags(node.heritageClauses) | propagateChildrenFlags(node.members) | (node.typeParameters ? 1 /* ContainsTypeScript */ : 0 /* None */) | 1024 /* ContainsES2015 */;
                node.jsDoc = void 0;
                return node;
            }
            function updateClassExpression(node, modifiers, name, typeParameters, heritageClauses, members) {
                return node.modifiers !== modifiers || node.name !== name || node.typeParameters !== typeParameters || node.heritageClauses !== heritageClauses || node.members !== members ? update(createClassExpression(modifiers, name, typeParameters, heritageClauses, members), node) : node;
            }
            function createOmittedExpression() {
                return createBaseNode(232 /* OmittedExpression */);
            }
            function createExpressionWithTypeArguments(expression, typeArguments) {
                const node = createBaseNode(233 /* ExpressionWithTypeArguments */);
                node.expression = parenthesizerRules().parenthesizeLeftSideOfAccess(expression, 
                /*optionalChain*/
                false);
                node.typeArguments = typeArguments && parenthesizerRules().parenthesizeTypeArguments(typeArguments);
                node.transformFlags |= propagateChildFlags(node.expression) | propagateChildrenFlags(node.typeArguments) | 1024 /* ContainsES2015 */;
                return node;
            }
            function updateExpressionWithTypeArguments(node, expression, typeArguments) {
                return node.expression !== expression || node.typeArguments !== typeArguments ? update(createExpressionWithTypeArguments(expression, typeArguments), node) : node;
            }
            function createAsExpression(expression, type) {
                const node = createBaseNode(234 /* AsExpression */);
                node.expression = expression;
                node.type = type;
                node.transformFlags |= propagateChildFlags(node.expression) | propagateChildFlags(node.type) | 1 /* ContainsTypeScript */;
                return node;
            }
            function updateAsExpression(node, expression, type) {
                return node.expression !== expression || node.type !== type ? update(createAsExpression(expression, type), node) : node;
            }
            function createNonNullExpression(expression) {
                const node = createBaseNode(235 /* NonNullExpression */);
                node.expression = parenthesizerRules().parenthesizeLeftSideOfAccess(expression, 
                /*optionalChain*/
                false);
                node.transformFlags |= propagateChildFlags(node.expression) | 1 /* ContainsTypeScript */;
                return node;
            }
            function updateNonNullExpression(node, expression) {
                if (isNonNullChain(node)) {
                    return updateNonNullChain(node, expression);
                }
                return node.expression !== expression ? update(createNonNullExpression(expression), node) : node;
            }
            function createSatisfiesExpression(expression, type) {
                const node = createBaseNode(238 /* SatisfiesExpression */);
                node.expression = expression;
                node.type = type;
                node.transformFlags |= propagateChildFlags(node.expression) | propagateChildFlags(node.type) | 1 /* ContainsTypeScript */;
                return node;
            }
            function updateSatisfiesExpression(node, expression, type) {
                return node.expression !== expression || node.type !== type ? update(createSatisfiesExpression(expression, type), node) : node;
            }
            function createNonNullChain(expression) {
                const node = createBaseNode(235 /* NonNullExpression */);
                node.flags |= 64 /* OptionalChain */;
                node.expression = parenthesizerRules().parenthesizeLeftSideOfAccess(expression, 
                /*optionalChain*/
                true);
                node.transformFlags |= propagateChildFlags(node.expression) | 1 /* ContainsTypeScript */;
                return node;
            }
            function updateNonNullChain(node, expression) {
                Debug.assert(!!(node.flags & 64 /* OptionalChain */), "Cannot update a NonNullExpression using updateNonNullChain. Use updateNonNullExpression instead.");
                return node.expression !== expression ? update(createNonNullChain(expression), node) : node;
            }
            function createMetaProperty(keywordToken, name) {
                const node = createBaseNode(236 /* MetaProperty */);
                node.keywordToken = keywordToken;
                node.name = name;
                node.transformFlags |= propagateChildFlags(node.name);
                switch (keywordToken) {
                    case 105 /* NewKeyword */:
                        node.transformFlags |= 1024 /* ContainsES2015 */;
                        break;
                    case 102 /* ImportKeyword */:
                        node.transformFlags |= 32 /* ContainsES2020 */;
                        break;
                    default:
                        return Debug.assertNever(keywordToken);
                }
                node.flowNode = void 0;
                return node;
            }
            function updateMetaProperty(node, name) {
                return node.name !== name ? update(createMetaProperty(node.keywordToken, name), node) : node;
            }
            function createTemplateSpan(expression, literal) {
                const node = createBaseNode(239 /* TemplateSpan */);
                node.expression = expression;
                node.literal = literal;
                node.transformFlags |= propagateChildFlags(node.expression) | propagateChildFlags(node.literal) | 1024 /* ContainsES2015 */;
                return node;
            }
            function updateTemplateSpan(node, expression, literal) {
                return node.expression !== expression || node.literal !== literal ? update(createTemplateSpan(expression, literal), node) : node;
            }
            function createSemicolonClassElement() {
                const node = createBaseNode(240 /* SemicolonClassElement */);
                node.transformFlags |= 1024 /* ContainsES2015 */;
                return node;
            }
            function createBlock(statements, multiLine) {
                const node = createBaseNode(241 /* Block */);
                node.statements = createNodeArray(statements);
                node.multiLine = multiLine;
                node.transformFlags |= propagateChildrenFlags(node.statements);
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                return node;
            }
            function updateBlock(node, statements) {
                return node.statements !== statements ? update(createBlock(statements, node.multiLine), node) : node;
            }
            function createVariableStatement(modifiers, declarationList) {
                const node = createBaseNode(243 /* VariableStatement */);
                node.modifiers = asNodeArray(modifiers);
                node.declarationList = isArray(declarationList) ? createVariableDeclarationList(declarationList) : declarationList;
                node.transformFlags |= propagateChildrenFlags(node.modifiers) | propagateChildFlags(node.declarationList);
                if (modifiersToFlags(node.modifiers) & 128 /* Ambient */) {
                    node.transformFlags = 1 /* ContainsTypeScript */;
                }
                node.jsDoc = void 0;
                node.flowNode = void 0;
                return node;
            }
            function updateVariableStatement(node, modifiers, declarationList) {
                return node.modifiers !== modifiers || node.declarationList !== declarationList ? update(createVariableStatement(modifiers, declarationList), node) : node;
            }
            function createEmptyStatement() {
                const node = createBaseNode(242 /* EmptyStatement */);
                node.jsDoc = void 0;
                return node;
            }
            function createExpressionStatement(expression) {
                const node = createBaseNode(244 /* ExpressionStatement */);
                node.expression = parenthesizerRules().parenthesizeExpressionOfExpressionStatement(expression);
                node.transformFlags |= propagateChildFlags(node.expression);
                node.jsDoc = void 0;
                node.flowNode = void 0;
                return node;
            }
            function updateExpressionStatement(node, expression) {
                return node.expression !== expression ? update(createExpressionStatement(expression), node) : node;
            }
            function createIfStatement(expression, thenStatement, elseStatement) {
                const node = createBaseNode(245 /* IfStatement */);
                node.expression = expression;
                node.thenStatement = asEmbeddedStatement(thenStatement);
                node.elseStatement = asEmbeddedStatement(elseStatement);
                node.transformFlags |= propagateChildFlags(node.expression) | propagateChildFlags(node.thenStatement) | propagateChildFlags(node.elseStatement);
                node.jsDoc = void 0;
                node.flowNode = void 0;
                return node;
            }
            function updateIfStatement(node, expression, thenStatement, elseStatement) {
                return node.expression !== expression || node.thenStatement !== thenStatement || node.elseStatement !== elseStatement ? update(createIfStatement(expression, thenStatement, elseStatement), node) : node;
            }
            function createDoStatement(statement, expression) {
                const node = createBaseNode(246 /* DoStatement */);
                node.statement = asEmbeddedStatement(statement);
                node.expression = expression;
                node.transformFlags |= propagateChildFlags(node.statement) | propagateChildFlags(node.expression);
                node.jsDoc = void 0;
                node.flowNode = void 0;
                return node;
            }
            function updateDoStatement(node, statement, expression) {
                return node.statement !== statement || node.expression !== expression ? update(createDoStatement(statement, expression), node) : node;
            }
            function createWhileStatement(expression, statement) {
                const node = createBaseNode(247 /* WhileStatement */);
                node.expression = expression;
                node.statement = asEmbeddedStatement(statement);
                node.transformFlags |= propagateChildFlags(node.expression) | propagateChildFlags(node.statement);
                node.jsDoc = void 0;
                node.flowNode = void 0;
                return node;
            }
            function updateWhileStatement(node, expression, statement) {
                return node.expression !== expression || node.statement !== statement ? update(createWhileStatement(expression, statement), node) : node;
            }
            function createForStatement(initializer, condition, incrementor, statement) {
                const node = createBaseNode(248 /* ForStatement */);
                node.initializer = initializer;
                node.condition = condition;
                node.incrementor = incrementor;
                node.statement = asEmbeddedStatement(statement);
                node.transformFlags |= propagateChildFlags(node.initializer) | propagateChildFlags(node.condition) | propagateChildFlags(node.incrementor) | propagateChildFlags(node.statement);
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.flowNode = void 0;
                return node;
            }
            function updateForStatement(node, initializer, condition, incrementor, statement) {
                return node.initializer !== initializer || node.condition !== condition || node.incrementor !== incrementor || node.statement !== statement ? update(createForStatement(initializer, condition, incrementor, statement), node) : node;
            }
            function createForInStatement(initializer, expression, statement) {
                const node = createBaseNode(249 /* ForInStatement */);
                node.initializer = initializer;
                node.expression = expression;
                node.statement = asEmbeddedStatement(statement);
                node.transformFlags |= propagateChildFlags(node.initializer) | propagateChildFlags(node.expression) | propagateChildFlags(node.statement);
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.flowNode = void 0;
                return node;
            }
            function updateForInStatement(node, initializer, expression, statement) {
                return node.initializer !== initializer || node.expression !== expression || node.statement !== statement ? update(createForInStatement(initializer, expression, statement), node) : node;
            }
            function createForOfStatement(awaitModifier, initializer, expression, statement) {
                const node = createBaseNode(250 /* ForOfStatement */);
                node.awaitModifier = awaitModifier;
                node.initializer = initializer;
                node.expression = parenthesizerRules().parenthesizeExpressionForDisallowedComma(expression);
                node.statement = asEmbeddedStatement(statement);
                node.transformFlags |= propagateChildFlags(node.awaitModifier) | propagateChildFlags(node.initializer) | propagateChildFlags(node.expression) | propagateChildFlags(node.statement) | 1024 /* ContainsES2015 */;
                if (awaitModifier)
                    node.transformFlags |= 128 /* ContainsES2018 */;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.flowNode = void 0;
                return node;
            }
            function updateForOfStatement(node, awaitModifier, initializer, expression, statement) {
                return node.awaitModifier !== awaitModifier || node.initializer !== initializer || node.expression !== expression || node.statement !== statement ? update(createForOfStatement(awaitModifier, initializer, expression, statement), node) : node;
            }
            function createContinueStatement(label) {
                const node = createBaseNode(251 /* ContinueStatement */);
                node.label = asName(label);
                node.transformFlags |= propagateChildFlags(node.label) | 4194304 /* ContainsHoistedDeclarationOrCompletion */;
                node.jsDoc = void 0;
                node.flowNode = void 0;
                return node;
            }
            function updateContinueStatement(node, label) {
                return node.label !== label ? update(createContinueStatement(label), node) : node;
            }
            function createBreakStatement(label) {
                const node = createBaseNode(252 /* BreakStatement */);
                node.label = asName(label);
                node.transformFlags |= propagateChildFlags(node.label) | 4194304 /* ContainsHoistedDeclarationOrCompletion */;
                node.jsDoc = void 0;
                node.flowNode = void 0;
                return node;
            }
            function updateBreakStatement(node, label) {
                return node.label !== label ? update(createBreakStatement(label), node) : node;
            }
            function createReturnStatement(expression) {
                const node = createBaseNode(253 /* ReturnStatement */);
                node.expression = expression;
                node.transformFlags |= propagateChildFlags(node.expression) | 128 /* ContainsES2018 */ | 4194304 /* ContainsHoistedDeclarationOrCompletion */;
                node.jsDoc = void 0;
                node.flowNode = void 0;
                return node;
            }
            function updateReturnStatement(node, expression) {
                return node.expression !== expression ? update(createReturnStatement(expression), node) : node;
            }
            function createWithStatement(expression, statement) {
                const node = createBaseNode(254 /* WithStatement */);
                node.expression = expression;
                node.statement = asEmbeddedStatement(statement);
                node.transformFlags |= propagateChildFlags(node.expression) | propagateChildFlags(node.statement);
                node.jsDoc = void 0;
                node.flowNode = void 0;
                return node;
            }
            function updateWithStatement(node, expression, statement) {
                return node.expression !== expression || node.statement !== statement ? update(createWithStatement(expression, statement), node) : node;
            }
            function createSwitchStatement(expression, caseBlock) {
                const node = createBaseNode(255 /* SwitchStatement */);
                node.expression = parenthesizerRules().parenthesizeExpressionForDisallowedComma(expression);
                node.caseBlock = caseBlock;
                node.transformFlags |= propagateChildFlags(node.expression) | propagateChildFlags(node.caseBlock);
                node.jsDoc = void 0;
                node.flowNode = void 0;
                node.possiblyExhaustive = false;
                return node;
            }
            function updateSwitchStatement(node, expression, caseBlock) {
                return node.expression !== expression || node.caseBlock !== caseBlock ? update(createSwitchStatement(expression, caseBlock), node) : node;
            }
            function createLabeledStatement(label, statement) {
                const node = createBaseNode(256 /* LabeledStatement */);
                node.label = asName(label);
                node.statement = asEmbeddedStatement(statement);
                node.transformFlags |= propagateChildFlags(node.label) | propagateChildFlags(node.statement);
                node.jsDoc = void 0;
                node.flowNode = void 0;
                return node;
            }
            function updateLabeledStatement(node, label, statement) {
                return node.label !== label || node.statement !== statement ? update(createLabeledStatement(label, statement), node) : node;
            }
            function createThrowStatement(expression) {
                const node = createBaseNode(257 /* ThrowStatement */);
                node.expression = expression;
                node.transformFlags |= propagateChildFlags(node.expression);
                node.jsDoc = void 0;
                node.flowNode = void 0;
                return node;
            }
            function updateThrowStatement(node, expression) {
                return node.expression !== expression ? update(createThrowStatement(expression), node) : node;
            }
            function createTryStatement(tryBlock, catchClause, finallyBlock) {
                const node = createBaseNode(258 /* TryStatement */);
                node.tryBlock = tryBlock;
                node.catchClause = catchClause;
                node.finallyBlock = finallyBlock;
                node.transformFlags |= propagateChildFlags(node.tryBlock) | propagateChildFlags(node.catchClause) | propagateChildFlags(node.finallyBlock);
                node.jsDoc = void 0;
                node.flowNode = void 0;
                return node;
            }
            function updateTryStatement(node, tryBlock, catchClause, finallyBlock) {
                return node.tryBlock !== tryBlock || node.catchClause !== catchClause || node.finallyBlock !== finallyBlock ? update(createTryStatement(tryBlock, catchClause, finallyBlock), node) : node;
            }
            function createDebuggerStatement() {
                const node = createBaseNode(259 /* DebuggerStatement */);
                node.jsDoc = void 0;
                node.flowNode = void 0;
                return node;
            }
            function createVariableDeclaration(name, exclamationToken, type, initializer) {
                const node = createBaseDeclaration(260 /* VariableDeclaration */);
                node.name = asName(name);
                node.exclamationToken = exclamationToken;
                node.type = type;
                node.initializer = asInitializer(initializer);
                node.transformFlags |= propagateNameFlags(node.name) | propagateChildFlags(node.initializer) | (node.exclamationToken ?? node.type ? 1 /* ContainsTypeScript */ : 0 /* None */);
                node.jsDoc = void 0;
                return node;
            }
            function updateVariableDeclaration(node, name, exclamationToken, type, initializer) {
                return node.name !== name || node.type !== type || node.exclamationToken !== exclamationToken || node.initializer !== initializer ? update(createVariableDeclaration(name, exclamationToken, type, initializer), node) : node;
            }
            function createVariableDeclarationList(declarations, flags2 = 0 /* None */) {
                const node = createBaseNode(261 /* VariableDeclarationList */);
                node.flags |= flags2 & 7 /* BlockScoped */;
                node.declarations = createNodeArray(declarations);
                node.transformFlags |= propagateChildrenFlags(node.declarations) | 4194304 /* ContainsHoistedDeclarationOrCompletion */;
                if (flags2 & 7 /* BlockScoped */) {
                    node.transformFlags |= 1024 /* ContainsES2015 */ | 262144 /* ContainsBlockScopedBinding */;
                }
                if (flags2 & 4 /* Using */) {
                    node.transformFlags |= 4 /* ContainsESNext */;
                }
                return node;
            }
            function updateVariableDeclarationList(node, declarations) {
                return node.declarations !== declarations ? update(createVariableDeclarationList(declarations, node.flags), node) : node;
            }
            function createFunctionDeclaration(modifiers, asteriskToken, name, typeParameters, parameters, type, body) {
                const node = createBaseDeclaration(262 /* FunctionDeclaration */);
                node.modifiers = asNodeArray(modifiers);
                node.asteriskToken = asteriskToken;
                node.name = asName(name);
                node.typeParameters = asNodeArray(typeParameters);
                node.parameters = createNodeArray(parameters);
                node.type = type;
                node.body = body;
                if (!node.body || modifiersToFlags(node.modifiers) & 128 /* Ambient */) {
                    node.transformFlags = 1 /* ContainsTypeScript */;
                }
                else {
                    const isAsync = modifiersToFlags(node.modifiers) & 1024 /* Async */;
                    const isGenerator = !!node.asteriskToken;
                    const isAsyncGenerator = isAsync && isGenerator;
                    node.transformFlags = propagateChildrenFlags(node.modifiers) | propagateChildFlags(node.asteriskToken) | propagateNameFlags(node.name) | propagateChildrenFlags(node.typeParameters) | propagateChildrenFlags(node.parameters) | propagateChildFlags(node.type) | propagateChildFlags(node.body) & ~67108864 /* ContainsPossibleTopLevelAwait */ | (isAsyncGenerator ? 128 /* ContainsES2018 */ : isAsync ? 256 /* ContainsES2017 */ : isGenerator ? 2048 /* ContainsGenerator */ : 0 /* None */) | (node.typeParameters || node.type ? 1 /* ContainsTypeScript */ : 0 /* None */) | 4194304 /* ContainsHoistedDeclarationOrCompletion */;
                }
                node.typeArguments = void 0;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.endFlowNode = void 0;
                node.returnFlowNode = void 0;
                return node;
            }
            function updateFunctionDeclaration(node, modifiers, asteriskToken, name, typeParameters, parameters, type, body) {
                return node.modifiers !== modifiers || node.asteriskToken !== asteriskToken || node.name !== name || node.typeParameters !== typeParameters || node.parameters !== parameters || node.type !== type || node.body !== body ? finishUpdateFunctionDeclaration(createFunctionDeclaration(modifiers, asteriskToken, name, typeParameters, parameters, type, body), node) : node;
            }
            function finishUpdateFunctionDeclaration(updated, original) {
                if (updated !== original) {
                    if (updated.modifiers === original.modifiers) {
                        updated.modifiers = original.modifiers;
                    }
                }
                return finishUpdateBaseSignatureDeclaration(updated, original);
            }
            function createClassDeclaration(modifiers, name, typeParameters, heritageClauses, members) {
                const node = createBaseDeclaration(263 /* ClassDeclaration */);
                node.modifiers = asNodeArray(modifiers);
                node.name = asName(name);
                node.typeParameters = asNodeArray(typeParameters);
                node.heritageClauses = asNodeArray(heritageClauses);
                node.members = createNodeArray(members);
                if (modifiersToFlags(node.modifiers) & 128 /* Ambient */) {
                    node.transformFlags = 1 /* ContainsTypeScript */;
                }
                else {
                    node.transformFlags |= propagateChildrenFlags(node.modifiers) | propagateNameFlags(node.name) | propagateChildrenFlags(node.typeParameters) | propagateChildrenFlags(node.heritageClauses) | propagateChildrenFlags(node.members) | (node.typeParameters ? 1 /* ContainsTypeScript */ : 0 /* None */) | 1024 /* ContainsES2015 */;
                    if (node.transformFlags & 8192 /* ContainsTypeScriptClassSyntax */) {
                        node.transformFlags |= 1 /* ContainsTypeScript */;
                    }
                }
                node.jsDoc = void 0;
                return node;
            }
            function updateClassDeclaration(node, modifiers, name, typeParameters, heritageClauses, members) {
                return node.modifiers !== modifiers || node.name !== name || node.typeParameters !== typeParameters || node.heritageClauses !== heritageClauses || node.members !== members ? update(createClassDeclaration(modifiers, name, typeParameters, heritageClauses, members), node) : node;
            }
            function createInterfaceDeclaration(modifiers, name, typeParameters, heritageClauses, members) {
                const node = createBaseDeclaration(264 /* InterfaceDeclaration */);
                node.modifiers = asNodeArray(modifiers);
                node.name = asName(name);
                node.typeParameters = asNodeArray(typeParameters);
                node.heritageClauses = asNodeArray(heritageClauses);
                node.members = createNodeArray(members);
                node.transformFlags = 1 /* ContainsTypeScript */;
                node.jsDoc = void 0;
                return node;
            }
            function updateInterfaceDeclaration(node, modifiers, name, typeParameters, heritageClauses, members) {
                return node.modifiers !== modifiers || node.name !== name || node.typeParameters !== typeParameters || node.heritageClauses !== heritageClauses || node.members !== members ? update(createInterfaceDeclaration(modifiers, name, typeParameters, heritageClauses, members), node) : node;
            }
            function createTypeAliasDeclaration(modifiers, name, typeParameters, type) {
                const node = createBaseDeclaration(265 /* TypeAliasDeclaration */);
                node.modifiers = asNodeArray(modifiers);
                node.name = asName(name);
                node.typeParameters = asNodeArray(typeParameters);
                node.type = type;
                node.transformFlags = 1 /* ContainsTypeScript */;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                return node;
            }
            function updateTypeAliasDeclaration(node, modifiers, name, typeParameters, type) {
                return node.modifiers !== modifiers || node.name !== name || node.typeParameters !== typeParameters || node.type !== type ? update(createTypeAliasDeclaration(modifiers, name, typeParameters, type), node) : node;
            }
            function createEnumDeclaration(modifiers, name, members) {
                const node = createBaseDeclaration(266 /* EnumDeclaration */);
                node.modifiers = asNodeArray(modifiers);
                node.name = asName(name);
                node.members = createNodeArray(members);
                node.transformFlags |= propagateChildrenFlags(node.modifiers) | propagateChildFlags(node.name) | propagateChildrenFlags(node.members) | 1 /* ContainsTypeScript */;
                node.transformFlags &= ~67108864 /* ContainsPossibleTopLevelAwait */;
                node.jsDoc = void 0;
                return node;
            }
            function updateEnumDeclaration(node, modifiers, name, members) {
                return node.modifiers !== modifiers || node.name !== name || node.members !== members ? update(createEnumDeclaration(modifiers, name, members), node) : node;
            }
            function createModuleDeclaration(modifiers, name, body, flags2 = 0 /* None */) {
                const node = createBaseDeclaration(267 /* ModuleDeclaration */);
                node.modifiers = asNodeArray(modifiers);
                node.flags |= flags2 & (32 /* Namespace */ | 8 /* NestedNamespace */ | 2048 /* GlobalAugmentation */);
                node.name = name;
                node.body = body;
                if (modifiersToFlags(node.modifiers) & 128 /* Ambient */) {
                    node.transformFlags = 1 /* ContainsTypeScript */;
                }
                else {
                    node.transformFlags |= propagateChildrenFlags(node.modifiers) | propagateChildFlags(node.name) | propagateChildFlags(node.body) | 1 /* ContainsTypeScript */;
                }
                node.transformFlags &= ~67108864 /* ContainsPossibleTopLevelAwait */;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                return node;
            }
            function updateModuleDeclaration(node, modifiers, name, body) {
                return node.modifiers !== modifiers || node.name !== name || node.body !== body ? update(createModuleDeclaration(modifiers, name, body, node.flags), node) : node;
            }
            function createModuleBlock(statements) {
                const node = createBaseNode(268 /* ModuleBlock */);
                node.statements = createNodeArray(statements);
                node.transformFlags |= propagateChildrenFlags(node.statements);
                node.jsDoc = void 0;
                return node;
            }
            function updateModuleBlock(node, statements) {
                return node.statements !== statements ? update(createModuleBlock(statements), node) : node;
            }
            function createCaseBlock(clauses) {
                const node = createBaseNode(269 /* CaseBlock */);
                node.clauses = createNodeArray(clauses);
                node.transformFlags |= propagateChildrenFlags(node.clauses);
                node.locals = void 0;
                node.nextContainer = void 0;
                return node;
            }
            function updateCaseBlock(node, clauses) {
                return node.clauses !== clauses ? update(createCaseBlock(clauses), node) : node;
            }
            function createNamespaceExportDeclaration(name) {
                const node = createBaseDeclaration(270 /* NamespaceExportDeclaration */);
                node.name = asName(name);
                node.transformFlags |= propagateIdentifierNameFlags(node.name) | 1 /* ContainsTypeScript */;
                node.modifiers = void 0;
                node.jsDoc = void 0;
                return node;
            }
            function updateNamespaceExportDeclaration(node, name) {
                return node.name !== name ? finishUpdateNamespaceExportDeclaration(createNamespaceExportDeclaration(name), node) : node;
            }
            function finishUpdateNamespaceExportDeclaration(updated, original) {
                if (updated !== original) {
                    updated.modifiers = original.modifiers;
                }
                return update(updated, original);
            }
            function createImportEqualsDeclaration(modifiers, isTypeOnly, name, moduleReference) {
                const node = createBaseDeclaration(271 /* ImportEqualsDeclaration */);
                node.modifiers = asNodeArray(modifiers);
                node.name = asName(name);
                node.isTypeOnly = isTypeOnly;
                node.moduleReference = moduleReference;
                node.transformFlags |= propagateChildrenFlags(node.modifiers) | propagateIdentifierNameFlags(node.name) | propagateChildFlags(node.moduleReference);
                if (!isExternalModuleReference(node.moduleReference)) {
                    node.transformFlags |= 1 /* ContainsTypeScript */;
                }
                node.transformFlags &= ~67108864 /* ContainsPossibleTopLevelAwait */;
                node.jsDoc = void 0;
                return node;
            }
            function updateImportEqualsDeclaration(node, modifiers, isTypeOnly, name, moduleReference) {
                return node.modifiers !== modifiers || node.isTypeOnly !== isTypeOnly || node.name !== name || node.moduleReference !== moduleReference ? update(createImportEqualsDeclaration(modifiers, isTypeOnly, name, moduleReference), node) : node;
            }
            function createImportDeclaration(modifiers, importClause, moduleSpecifier, attributes) {
                const node = createBaseNode(272 /* ImportDeclaration */);
                node.modifiers = asNodeArray(modifiers);
                node.importClause = importClause;
                node.moduleSpecifier = moduleSpecifier;
                node.attributes = node.assertClause = attributes;
                node.transformFlags |= propagateChildFlags(node.importClause) | propagateChildFlags(node.moduleSpecifier);
                node.transformFlags &= ~67108864 /* ContainsPossibleTopLevelAwait */;
                node.jsDoc = void 0;
                return node;
            }
            function updateImportDeclaration(node, modifiers, importClause, moduleSpecifier, attributes) {
                return node.modifiers !== modifiers || node.importClause !== importClause || node.moduleSpecifier !== moduleSpecifier || node.attributes !== attributes ? update(createImportDeclaration(modifiers, importClause, moduleSpecifier, attributes), node) : node;
            }
            function createImportClause(isTypeOnly, name, namedBindings) {
                const node = createBaseDeclaration(273 /* ImportClause */);
                node.isTypeOnly = isTypeOnly;
                node.name = name;
                node.namedBindings = namedBindings;
                node.transformFlags |= propagateChildFlags(node.name) | propagateChildFlags(node.namedBindings);
                if (isTypeOnly) {
                    node.transformFlags |= 1 /* ContainsTypeScript */;
                }
                node.transformFlags &= ~67108864 /* ContainsPossibleTopLevelAwait */;
                return node;
            }
            function updateImportClause(node, isTypeOnly, name, namedBindings) {
                return node.isTypeOnly !== isTypeOnly || node.name !== name || node.namedBindings !== namedBindings ? update(createImportClause(isTypeOnly, name, namedBindings), node) : node;
            }
            function createAssertClause(elements, multiLine) {
                const node = createBaseNode(300 /* AssertClause */);
                node.elements = createNodeArray(elements);
                node.multiLine = multiLine;
                node.token = 132 /* AssertKeyword */;
                node.transformFlags |= 4 /* ContainsESNext */;
                return node;
            }
            function updateAssertClause(node, elements, multiLine) {
                return node.elements !== elements || node.multiLine !== multiLine ? update(createAssertClause(elements, multiLine), node) : node;
            }
            function createAssertEntry(name, value) {
                const node = createBaseNode(301 /* AssertEntry */);
                node.name = name;
                node.value = value;
                node.transformFlags |= 4 /* ContainsESNext */;
                return node;
            }
            function updateAssertEntry(node, name, value) {
                return node.name !== name || node.value !== value ? update(createAssertEntry(name, value), node) : node;
            }
            function createImportTypeAssertionContainer(clause, multiLine) {
                const node = createBaseNode(302 /* ImportTypeAssertionContainer */);
                node.assertClause = clause;
                node.multiLine = multiLine;
                return node;
            }
            function updateImportTypeAssertionContainer(node, clause, multiLine) {
                return node.assertClause !== clause || node.multiLine !== multiLine ? update(createImportTypeAssertionContainer(clause, multiLine), node) : node;
            }
            function createImportAttributes(elements, multiLine, token) {
                const node = createBaseNode(300 /* ImportAttributes */);
                node.token = token ?? 118 /* WithKeyword */;
                node.elements = createNodeArray(elements);
                node.multiLine = multiLine;
                node.transformFlags |= 4 /* ContainsESNext */;
                return node;
            }
            function updateImportAttributes(node, elements, multiLine) {
                return node.elements !== elements || node.multiLine !== multiLine ? update(createImportAttributes(elements, multiLine, node.token), node) : node;
            }
            function createImportAttribute(name, value) {
                const node = createBaseNode(301 /* ImportAttribute */);
                node.name = name;
                node.value = value;
                node.transformFlags |= 4 /* ContainsESNext */;
                return node;
            }
            function updateImportAttribute(node, name, value) {
                return node.name !== name || node.value !== value ? update(createImportAttribute(name, value), node) : node;
            }
            function createNamespaceImport(name) {
                const node = createBaseDeclaration(274 /* NamespaceImport */);
                node.name = name;
                node.transformFlags |= propagateChildFlags(node.name);
                node.transformFlags &= ~67108864 /* ContainsPossibleTopLevelAwait */;
                return node;
            }
            function updateNamespaceImport(node, name) {
                return node.name !== name ? update(createNamespaceImport(name), node) : node;
            }
            function createNamespaceExport(name) {
                const node = createBaseDeclaration(280 /* NamespaceExport */);
                node.name = name;
                node.transformFlags |= propagateChildFlags(node.name) | 32 /* ContainsES2020 */;
                node.transformFlags &= ~67108864 /* ContainsPossibleTopLevelAwait */;
                return node;
            }
            function updateNamespaceExport(node, name) {
                return node.name !== name ? update(createNamespaceExport(name), node) : node;
            }
            function createNamedImports(elements) {
                const node = createBaseNode(275 /* NamedImports */);
                node.elements = createNodeArray(elements);
                node.transformFlags |= propagateChildrenFlags(node.elements);
                node.transformFlags &= ~67108864 /* ContainsPossibleTopLevelAwait */;
                return node;
            }
            function updateNamedImports(node, elements) {
                return node.elements !== elements ? update(createNamedImports(elements), node) : node;
            }
            function createImportSpecifier(isTypeOnly, propertyName, name) {
                const node = createBaseDeclaration(276 /* ImportSpecifier */);
                node.isTypeOnly = isTypeOnly;
                node.propertyName = propertyName;
                node.name = name;
                node.transformFlags |= propagateChildFlags(node.propertyName) | propagateChildFlags(node.name);
                node.transformFlags &= ~67108864 /* ContainsPossibleTopLevelAwait */;
                return node;
            }
            function updateImportSpecifier(node, isTypeOnly, propertyName, name) {
                return node.isTypeOnly !== isTypeOnly || node.propertyName !== propertyName || node.name !== name ? update(createImportSpecifier(isTypeOnly, propertyName, name), node) : node;
            }
            function createExportAssignment2(modifiers, isExportEquals, expression) {
                const node = createBaseDeclaration(277 /* ExportAssignment */);
                node.modifiers = asNodeArray(modifiers);
                node.isExportEquals = isExportEquals;
                node.expression = isExportEquals ? parenthesizerRules().parenthesizeRightSideOfBinary(64 /* EqualsToken */, 
                /*leftSide*/
                void 0, expression) : parenthesizerRules().parenthesizeExpressionOfExportDefault(expression);
                node.transformFlags |= propagateChildrenFlags(node.modifiers) | propagateChildFlags(node.expression);
                node.transformFlags &= ~67108864 /* ContainsPossibleTopLevelAwait */;
                node.jsDoc = void 0;
                return node;
            }
            function updateExportAssignment(node, modifiers, expression) {
                return node.modifiers !== modifiers || node.expression !== expression ? update(createExportAssignment2(modifiers, node.isExportEquals, expression), node) : node;
            }
            function createExportDeclaration(modifiers, isTypeOnly, exportClause, moduleSpecifier, attributes) {
                const node = createBaseDeclaration(278 /* ExportDeclaration */);
                node.modifiers = asNodeArray(modifiers);
                node.isTypeOnly = isTypeOnly;
                node.exportClause = exportClause;
                node.moduleSpecifier = moduleSpecifier;
                node.attributes = node.assertClause = attributes;
                node.transformFlags |= propagateChildrenFlags(node.modifiers) | propagateChildFlags(node.exportClause) | propagateChildFlags(node.moduleSpecifier);
                node.transformFlags &= ~67108864 /* ContainsPossibleTopLevelAwait */;
                node.jsDoc = void 0;
                return node;
            }
            function updateExportDeclaration(node, modifiers, isTypeOnly, exportClause, moduleSpecifier, attributes) {
                return node.modifiers !== modifiers || node.isTypeOnly !== isTypeOnly || node.exportClause !== exportClause || node.moduleSpecifier !== moduleSpecifier || node.attributes !== attributes ? finishUpdateExportDeclaration(createExportDeclaration(modifiers, isTypeOnly, exportClause, moduleSpecifier, attributes), node) : node;
            }
            function finishUpdateExportDeclaration(updated, original) {
                if (updated !== original) {
                    if (updated.modifiers === original.modifiers) {
                        updated.modifiers = original.modifiers;
                    }
                }
                return update(updated, original);
            }
            function createNamedExports(elements) {
                const node = createBaseNode(279 /* NamedExports */);
                node.elements = createNodeArray(elements);
                node.transformFlags |= propagateChildrenFlags(node.elements);
                node.transformFlags &= ~67108864 /* ContainsPossibleTopLevelAwait */;
                return node;
            }
            function updateNamedExports(node, elements) {
                return node.elements !== elements ? update(createNamedExports(elements), node) : node;
            }
            function createExportSpecifier(isTypeOnly, propertyName, name) {
                const node = createBaseNode(281 /* ExportSpecifier */);
                node.isTypeOnly = isTypeOnly;
                node.propertyName = asName(propertyName);
                node.name = asName(name);
                node.transformFlags |= propagateChildFlags(node.propertyName) | propagateChildFlags(node.name);
                node.transformFlags &= ~67108864 /* ContainsPossibleTopLevelAwait */;
                node.jsDoc = void 0;
                return node;
            }
            function updateExportSpecifier(node, isTypeOnly, propertyName, name) {
                return node.isTypeOnly !== isTypeOnly || node.propertyName !== propertyName || node.name !== name ? update(createExportSpecifier(isTypeOnly, propertyName, name), node) : node;
            }
            function createMissingDeclaration() {
                const node = createBaseDeclaration(282 /* MissingDeclaration */);
                node.jsDoc = void 0;
                return node;
            }
            function createExternalModuleReference(expression) {
                const node = createBaseNode(283 /* ExternalModuleReference */);
                node.expression = expression;
                node.transformFlags |= propagateChildFlags(node.expression);
                node.transformFlags &= ~67108864 /* ContainsPossibleTopLevelAwait */;
                return node;
            }
            function updateExternalModuleReference(node, expression) {
                return node.expression !== expression ? update(createExternalModuleReference(expression), node) : node;
            }
            function createJSDocPrimaryTypeWorker(kind) {
                return createBaseNode(kind);
            }
            function createJSDocPrePostfixUnaryTypeWorker(kind, type, postfix = false) {
                const node = createJSDocUnaryTypeWorker(kind, postfix ? type && parenthesizerRules().parenthesizeNonArrayTypeOfPostfixType(type) : type);
                node.postfix = postfix;
                return node;
            }
            function createJSDocUnaryTypeWorker(kind, type) {
                const node = createBaseNode(kind);
                node.type = type;
                return node;
            }
            function updateJSDocPrePostfixUnaryTypeWorker(kind, node, type) {
                return node.type !== type ? update(createJSDocPrePostfixUnaryTypeWorker(kind, type, node.postfix), node) : node;
            }
            function updateJSDocUnaryTypeWorker(kind, node, type) {
                return node.type !== type ? update(createJSDocUnaryTypeWorker(kind, type), node) : node;
            }
            function createJSDocFunctionType(parameters, type) {
                const node = createBaseDeclaration(324 /* JSDocFunctionType */);
                node.parameters = asNodeArray(parameters);
                node.type = type;
                node.transformFlags = propagateChildrenFlags(node.parameters) | (node.type ? 1 /* ContainsTypeScript */ : 0 /* None */);
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                node.typeArguments = void 0;
                return node;
            }
            function updateJSDocFunctionType(node, parameters, type) {
                return node.parameters !== parameters || node.type !== type ? update(createJSDocFunctionType(parameters, type), node) : node;
            }
            function createJSDocTypeLiteral(propertyTags, isArrayType = false) {
                const node = createBaseDeclaration(329 /* JSDocTypeLiteral */);
                node.jsDocPropertyTags = asNodeArray(propertyTags);
                node.isArrayType = isArrayType;
                return node;
            }
            function updateJSDocTypeLiteral(node, propertyTags, isArrayType) {
                return node.jsDocPropertyTags !== propertyTags || node.isArrayType !== isArrayType ? update(createJSDocTypeLiteral(propertyTags, isArrayType), node) : node;
            }
            function createJSDocTypeExpression(type) {
                const node = createBaseNode(316 /* JSDocTypeExpression */);
                node.type = type;
                return node;
            }
            function updateJSDocTypeExpression(node, type) {
                return node.type !== type ? update(createJSDocTypeExpression(type), node) : node;
            }
            function createJSDocSignature(typeParameters, parameters, type) {
                const node = createBaseDeclaration(330 /* JSDocSignature */);
                node.typeParameters = asNodeArray(typeParameters);
                node.parameters = createNodeArray(parameters);
                node.type = type;
                node.jsDoc = void 0;
                node.locals = void 0;
                node.nextContainer = void 0;
                return node;
            }
            function updateJSDocSignature(node, typeParameters, parameters, type) {
                return node.typeParameters !== typeParameters || node.parameters !== parameters || node.type !== type ? update(createJSDocSignature(typeParameters, parameters, type), node) : node;
            }
            function getDefaultTagName(node) {
                const defaultTagName = getDefaultTagNameForKind(node.kind);
                return node.tagName.escapedText === escapeLeadingUnderscores(defaultTagName) ? node.tagName : createIdentifier(defaultTagName);
            }
            function createBaseJSDocTag(kind, tagName, comment) {
                const node = createBaseNode(kind);
                node.tagName = tagName;
                node.comment = comment;
                return node;
            }
            function createBaseJSDocTagDeclaration(kind, tagName, comment) {
                const node = createBaseDeclaration(kind);
                node.tagName = tagName;
                node.comment = comment;
                return node;
            }
            function createJSDocTemplateTag(tagName, constraint, typeParameters, comment) {
                const node = createBaseJSDocTag(352 /* JSDocTemplateTag */, tagName ?? createIdentifier("template"), comment);
                node.constraint = constraint;
                node.typeParameters = createNodeArray(typeParameters);
                return node;
            }
            function updateJSDocTemplateTag(node, tagName = getDefaultTagName(node), constraint, typeParameters, comment) {
                return node.tagName !== tagName || node.constraint !== constraint || node.typeParameters !== typeParameters || node.comment !== comment ? update(createJSDocTemplateTag(tagName, constraint, typeParameters, comment), node) : node;
            }
            function createJSDocTypedefTag(tagName, typeExpression, fullName, comment) {
                const node = createBaseJSDocTagDeclaration(353 /* JSDocTypedefTag */, tagName ?? createIdentifier("typedef"), comment);
                node.typeExpression = typeExpression;
                node.fullName = fullName;
                node.name = getJSDocTypeAliasName(fullName);
                node.locals = void 0;
                node.nextContainer = void 0;
                return node;
            }
            function updateJSDocTypedefTag(node, tagName = getDefaultTagName(node), typeExpression, fullName, comment) {
                return node.tagName !== tagName || node.typeExpression !== typeExpression || node.fullName !== fullName || node.comment !== comment ? update(createJSDocTypedefTag(tagName, typeExpression, fullName, comment), node) : node;
            }
            function createJSDocParameterTag(tagName, name, isBracketed, typeExpression, isNameFirst, comment) {
                const node = createBaseJSDocTagDeclaration(348 /* JSDocParameterTag */, tagName ?? createIdentifier("param"), comment);
                node.typeExpression = typeExpression;
                node.name = name;
                node.isNameFirst = !!isNameFirst;
                node.isBracketed = isBracketed;
                return node;
            }
            function updateJSDocParameterTag(node, tagName = getDefaultTagName(node), name, isBracketed, typeExpression, isNameFirst, comment) {
                return node.tagName !== tagName || node.name !== name || node.isBracketed !== isBracketed || node.typeExpression !== typeExpression || node.isNameFirst !== isNameFirst || node.comment !== comment ? update(createJSDocParameterTag(tagName, name, isBracketed, typeExpression, isNameFirst, comment), node) : node;
            }
            function createJSDocPropertyTag(tagName, name, isBracketed, typeExpression, isNameFirst, comment) {
                const node = createBaseJSDocTagDeclaration(355 /* JSDocPropertyTag */, tagName ?? createIdentifier("prop"), comment);
                node.typeExpression = typeExpression;
                node.name = name;
                node.isNameFirst = !!isNameFirst;
                node.isBracketed = isBracketed;
                return node;
            }
            function updateJSDocPropertyTag(node, tagName = getDefaultTagName(node), name, isBracketed, typeExpression, isNameFirst, comment) {
                return node.tagName !== tagName || node.name !== name || node.isBracketed !== isBracketed || node.typeExpression !== typeExpression || node.isNameFirst !== isNameFirst || node.comment !== comment ? update(createJSDocPropertyTag(tagName, name, isBracketed, typeExpression, isNameFirst, comment), node) : node;
            }
            function createJSDocCallbackTag(tagName, typeExpression, fullName, comment) {
                const node = createBaseJSDocTagDeclaration(345 /* JSDocCallbackTag */, tagName ?? createIdentifier("callback"), comment);
                node.typeExpression = typeExpression;
                node.fullName = fullName;
                node.name = getJSDocTypeAliasName(fullName);
                node.locals = void 0;
                node.nextContainer = void 0;
                return node;
            }
            function updateJSDocCallbackTag(node, tagName = getDefaultTagName(node), typeExpression, fullName, comment) {
                return node.tagName !== tagName || node.typeExpression !== typeExpression || node.fullName !== fullName || node.comment !== comment ? update(createJSDocCallbackTag(tagName, typeExpression, fullName, comment), node) : node;
            }
            function createJSDocOverloadTag(tagName, typeExpression, comment) {
                const node = createBaseJSDocTag(346 /* JSDocOverloadTag */, tagName ?? createIdentifier("overload"), comment);
                node.typeExpression = typeExpression;
                return node;
            }
            function updateJSDocOverloadTag(node, tagName = getDefaultTagName(node), typeExpression, comment) {
                return node.tagName !== tagName || node.typeExpression !== typeExpression || node.comment !== comment ? update(createJSDocOverloadTag(tagName, typeExpression, comment), node) : node;
            }
            function createJSDocAugmentsTag(tagName, className, comment) {
                const node = createBaseJSDocTag(335 /* JSDocAugmentsTag */, tagName ?? createIdentifier("augments"), comment);
                node.class = className;
                return node;
            }
            function updateJSDocAugmentsTag(node, tagName = getDefaultTagName(node), className, comment) {
                return node.tagName !== tagName || node.class !== className || node.comment !== comment ? update(createJSDocAugmentsTag(tagName, className, comment), node) : node;
            }
            function createJSDocImplementsTag(tagName, className, comment) {
                const node = createBaseJSDocTag(336 /* JSDocImplementsTag */, tagName ?? createIdentifier("implements"), comment);
                node.class = className;
                return node;
            }
            function createJSDocSeeTag(tagName, name, comment) {
                const node = createBaseJSDocTag(354 /* JSDocSeeTag */, tagName ?? createIdentifier("see"), comment);
                node.name = name;
                return node;
            }
            function updateJSDocSeeTag(node, tagName, name, comment) {
                return node.tagName !== tagName || node.name !== name || node.comment !== comment ? update(createJSDocSeeTag(tagName, name, comment), node) : node;
            }
            function createJSDocNameReference(name) {
                const node = createBaseNode(317 /* JSDocNameReference */);
                node.name = name;
                return node;
            }
            function updateJSDocNameReference(node, name) {
                return node.name !== name ? update(createJSDocNameReference(name), node) : node;
            }
            function createJSDocMemberName(left, right) {
                const node = createBaseNode(318 /* JSDocMemberName */);
                node.left = left;
                node.right = right;
                node.transformFlags |= propagateChildFlags(node.left) | propagateChildFlags(node.right);
                return node;
            }
            function updateJSDocMemberName(node, left, right) {
                return node.left !== left || node.right !== right ? update(createJSDocMemberName(left, right), node) : node;
            }
            function createJSDocLink(name, text) {
                const node = createBaseNode(331 /* JSDocLink */);
                node.name = name;
                node.text = text;
                return node;
            }
            function updateJSDocLink(node, name, text) {
                return node.name !== name ? update(createJSDocLink(name, text), node) : node;
            }
            function createJSDocLinkCode(name, text) {
                const node = createBaseNode(332 /* JSDocLinkCode */);
                node.name = name;
                node.text = text;
                return node;
            }
            function updateJSDocLinkCode(node, name, text) {
                return node.name !== name ? update(createJSDocLinkCode(name, text), node) : node;
            }
            function createJSDocLinkPlain(name, text) {
                const node = createBaseNode(333 /* JSDocLinkPlain */);
                node.name = name;
                node.text = text;
                return node;
            }
            function updateJSDocLinkPlain(node, name, text) {
                return node.name !== name ? update(createJSDocLinkPlain(name, text), node) : node;
            }
            function updateJSDocImplementsTag(node, tagName = getDefaultTagName(node), className, comment) {
                return node.tagName !== tagName || node.class !== className || node.comment !== comment ? update(createJSDocImplementsTag(tagName, className, comment), node) : node;
            }
            function createJSDocSimpleTagWorker(kind, tagName, comment) {
                const node = createBaseJSDocTag(kind, tagName ?? createIdentifier(getDefaultTagNameForKind(kind)), comment);
                return node;
            }
            function updateJSDocSimpleTagWorker(kind, node, tagName = getDefaultTagName(node), comment) {
                return node.tagName !== tagName || node.comment !== comment ? update(createJSDocSimpleTagWorker(kind, tagName, comment), node) : node;
            }
            function createJSDocTypeLikeTagWorker(kind, tagName, typeExpression, comment) {
                const node = createBaseJSDocTag(kind, tagName ?? createIdentifier(getDefaultTagNameForKind(kind)), comment);
                node.typeExpression = typeExpression;
                return node;
            }
            function updateJSDocTypeLikeTagWorker(kind, node, tagName = getDefaultTagName(node), typeExpression, comment) {
                return node.tagName !== tagName || node.typeExpression !== typeExpression || node.comment !== comment ? update(createJSDocTypeLikeTagWorker(kind, tagName, typeExpression, comment), node) : node;
            }
            function createJSDocUnknownTag(tagName, comment) {
                const node = createBaseJSDocTag(334 /* JSDocTag */, tagName, comment);
                return node;
            }
            function updateJSDocUnknownTag(node, tagName, comment) {
                return node.tagName !== tagName || node.comment !== comment ? update(createJSDocUnknownTag(tagName, comment), node) : node;
            }
            function createJSDocEnumTag(tagName, typeExpression, comment) {
                const node = createBaseJSDocTagDeclaration(347 /* JSDocEnumTag */, tagName ?? createIdentifier(getDefaultTagNameForKind(347 /* JSDocEnumTag */)), comment);
                node.typeExpression = typeExpression;
                node.locals = void 0;
                node.nextContainer = void 0;
                return node;
            }
            function updateJSDocEnumTag(node, tagName = getDefaultTagName(node), typeExpression, comment) {
                return node.tagName !== tagName || node.typeExpression !== typeExpression || node.comment !== comment ? update(createJSDocEnumTag(tagName, typeExpression, comment), node) : node;
            }
            function createJSDocText(text) {
                const node = createBaseNode(328 /* JSDocText */);
                node.text = text;
                return node;
            }
            function updateJSDocText(node, text) {
                return node.text !== text ? update(createJSDocText(text), node) : node;
            }
            function createJSDocComment(comment, tags) {
                const node = createBaseNode(327 /* JSDoc */);
                node.comment = comment;
                node.tags = asNodeArray(tags);
                return node;
            }
            function updateJSDocComment(node, comment, tags) {
                return node.comment !== comment || node.tags !== tags ? update(createJSDocComment(comment, tags), node) : node;
            }
            function createJsxElement(openingElement, children, closingElement) {
                const node = createBaseNode(284 /* JsxElement */);
                node.openingElement = openingElement;
                node.children = createNodeArray(children);
                node.closingElement = closingElement;
                node.transformFlags |= propagateChildFlags(node.openingElement) | propagateChildrenFlags(node.children) | propagateChildFlags(node.closingElement) | 2 /* ContainsJsx */;
                return node;
            }
            function updateJsxElement(node, openingElement, children, closingElement) {
                return node.openingElement !== openingElement || node.children !== children || node.closingElement !== closingElement ? update(createJsxElement(openingElement, children, closingElement), node) : node;
            }
            function createJsxSelfClosingElement(tagName, typeArguments, attributes) {
                const node = createBaseNode(285 /* JsxSelfClosingElement */);
                node.tagName = tagName;
                node.typeArguments = asNodeArray(typeArguments);
                node.attributes = attributes;
                node.transformFlags |= propagateChildFlags(node.tagName) | propagateChildrenFlags(node.typeArguments) | propagateChildFlags(node.attributes) | 2 /* ContainsJsx */;
                if (node.typeArguments) {
                    node.transformFlags |= 1 /* ContainsTypeScript */;
                }
                return node;
            }
            function updateJsxSelfClosingElement(node, tagName, typeArguments, attributes) {
                return node.tagName !== tagName || node.typeArguments !== typeArguments || node.attributes !== attributes ? update(createJsxSelfClosingElement(tagName, typeArguments, attributes), node) : node;
            }
            function createJsxOpeningElement(tagName, typeArguments, attributes) {
                const node = createBaseNode(286 /* JsxOpeningElement */);
                node.tagName = tagName;
                node.typeArguments = asNodeArray(typeArguments);
                node.attributes = attributes;
                node.transformFlags |= propagateChildFlags(node.tagName) | propagateChildrenFlags(node.typeArguments) | propagateChildFlags(node.attributes) | 2 /* ContainsJsx */;
                if (typeArguments) {
                    node.transformFlags |= 1 /* ContainsTypeScript */;
                }
                return node;
            }
            function updateJsxOpeningElement(node, tagName, typeArguments, attributes) {
                return node.tagName !== tagName || node.typeArguments !== typeArguments || node.attributes !== attributes ? update(createJsxOpeningElement(tagName, typeArguments, attributes), node) : node;
            }
            function createJsxClosingElement(tagName) {
                const node = createBaseNode(287 /* JsxClosingElement */);
                node.tagName = tagName;
                node.transformFlags |= propagateChildFlags(node.tagName) | 2 /* ContainsJsx */;
                return node;
            }
            function updateJsxClosingElement(node, tagName) {
                return node.tagName !== tagName ? update(createJsxClosingElement(tagName), node) : node;
            }
            function createJsxFragment(openingFragment, children, closingFragment) {
                const node = createBaseNode(288 /* JsxFragment */);
                node.openingFragment = openingFragment;
                node.children = createNodeArray(children);
                node.closingFragment = closingFragment;
                node.transformFlags |= propagateChildFlags(node.openingFragment) | propagateChildrenFlags(node.children) | propagateChildFlags(node.closingFragment) | 2 /* ContainsJsx */;
                return node;
            }
            function updateJsxFragment(node, openingFragment, children, closingFragment) {
                return node.openingFragment !== openingFragment || node.children !== children || node.closingFragment !== closingFragment ? update(createJsxFragment(openingFragment, children, closingFragment), node) : node;
            }
            function createJsxText(text, containsOnlyTriviaWhiteSpaces) {
                const node = createBaseNode(12 /* JsxText */);
                node.text = text;
                node.containsOnlyTriviaWhiteSpaces = !!containsOnlyTriviaWhiteSpaces;
                node.transformFlags |= 2 /* ContainsJsx */;
                return node;
            }
            function updateJsxText(node, text, containsOnlyTriviaWhiteSpaces) {
                return node.text !== text || node.containsOnlyTriviaWhiteSpaces !== containsOnlyTriviaWhiteSpaces ? update(createJsxText(text, containsOnlyTriviaWhiteSpaces), node) : node;
            }
            function createJsxOpeningFragment() {
                const node = createBaseNode(289 /* JsxOpeningFragment */);
                node.transformFlags |= 2 /* ContainsJsx */;
                return node;
            }
            function createJsxJsxClosingFragment() {
                const node = createBaseNode(290 /* JsxClosingFragment */);
                node.transformFlags |= 2 /* ContainsJsx */;
                return node;
            }
            function createJsxAttribute(name, initializer) {
                const node = createBaseDeclaration(291 /* JsxAttribute */);
                node.name = name;
                node.initializer = initializer;
                node.transformFlags |= propagateChildFlags(node.name) | propagateChildFlags(node.initializer) | 2 /* ContainsJsx */;
                return node;
            }
            function updateJsxAttribute(node, name, initializer) {
                return node.name !== name || node.initializer !== initializer ? update(createJsxAttribute(name, initializer), node) : node;
            }
            function createJsxAttributes(properties) {
                const node = createBaseDeclaration(292 /* JsxAttributes */);
                node.properties = createNodeArray(properties);
                node.transformFlags |= propagateChildrenFlags(node.properties) | 2 /* ContainsJsx */;
                return node;
            }
            function updateJsxAttributes(node, properties) {
                return node.properties !== properties ? update(createJsxAttributes(properties), node) : node;
            }
            function createJsxSpreadAttribute(expression) {
                const node = createBaseNode(293 /* JsxSpreadAttribute */);
                node.expression = expression;
                node.transformFlags |= propagateChildFlags(node.expression) | 2 /* ContainsJsx */;
                return node;
            }
            function updateJsxSpreadAttribute(node, expression) {
                return node.expression !== expression ? update(createJsxSpreadAttribute(expression), node) : node;
            }
            function createJsxExpression(dotDotDotToken, expression) {
                const node = createBaseNode(294 /* JsxExpression */);
                node.dotDotDotToken = dotDotDotToken;
                node.expression = expression;
                node.transformFlags |= propagateChildFlags(node.dotDotDotToken) | propagateChildFlags(node.expression) | 2 /* ContainsJsx */;
                return node;
            }
            function updateJsxExpression(node, expression) {
                return node.expression !== expression ? update(createJsxExpression(node.dotDotDotToken, expression), node) : node;
            }
            function createJsxNamespacedName(namespace, name) {
                const node = createBaseNode(295 /* JsxNamespacedName */);
                node.namespace = namespace;
                node.name = name;
                node.transformFlags |= propagateChildFlags(node.namespace) | propagateChildFlags(node.name) | 2 /* ContainsJsx */;
                return node;
            }
            function updateJsxNamespacedName(node, namespace, name) {
                return node.namespace !== namespace || node.name !== name ? update(createJsxNamespacedName(namespace, name), node) : node;
            }
            function createCaseClause(expression, statements) {
                const node = createBaseNode(296 /* CaseClause */);
                node.expression = parenthesizerRules().parenthesizeExpressionForDisallowedComma(expression);
                node.statements = createNodeArray(statements);
                node.transformFlags |= propagateChildFlags(node.expression) | propagateChildrenFlags(node.statements);
                node.jsDoc = void 0;
                return node;
            }
            function updateCaseClause(node, expression, statements) {
                return node.expression !== expression || node.statements !== statements ? update(createCaseClause(expression, statements), node) : node;
            }
            function createDefaultClause(statements) {
                const node = createBaseNode(297 /* DefaultClause */);
                node.statements = createNodeArray(statements);
                node.transformFlags = propagateChildrenFlags(node.statements);
                return node;
            }
            function updateDefaultClause(node, statements) {
                return node.statements !== statements ? update(createDefaultClause(statements), node) : node;
            }
            function createHeritageClause(token, types) {
                const node = createBaseNode(298 /* HeritageClause */);
                node.token = token;
                node.types = createNodeArray(types);
                node.transformFlags |= propagateChildrenFlags(node.types);
                switch (token) {
                    case 96 /* ExtendsKeyword */:
                        node.transformFlags |= 1024 /* ContainsES2015 */;
                        break;
                    case 119 /* ImplementsKeyword */:
                        node.transformFlags |= 1 /* ContainsTypeScript */;
                        break;
                    default:
                        return Debug.assertNever(token);
                }
                return node;
            }
            function updateHeritageClause(node, types) {
                return node.types !== types ? update(createHeritageClause(node.token, types), node) : node;
            }
            function createCatchClause(variableDeclaration, block) {
                const node = createBaseNode(299 /* CatchClause */);
                node.variableDeclaration = asVariableDeclaration(variableDeclaration);
                node.block = block;
                node.transformFlags |= propagateChildFlags(node.variableDeclaration) | propagateChildFlags(node.block) | (!variableDeclaration ? 64 /* ContainsES2019 */ : 0 /* None */);
                node.locals = void 0;
                node.nextContainer = void 0;
                return node;
            }
            function updateCatchClause(node, variableDeclaration, block) {
                return node.variableDeclaration !== variableDeclaration || node.block !== block ? update(createCatchClause(variableDeclaration, block), node) : node;
            }
            function createPropertyAssignment(name, initializer) {
                const node = createBaseDeclaration(303 /* PropertyAssignment */);
                node.name = asName(name);
                node.initializer = parenthesizerRules().parenthesizeExpressionForDisallowedComma(initializer);
                node.transformFlags |= propagateNameFlags(node.name) | propagateChildFlags(node.initializer);
                node.modifiers = void 0;
                node.questionToken = void 0;
                node.exclamationToken = void 0;
                node.jsDoc = void 0;
                return node;
            }
            function updatePropertyAssignment(node, name, initializer) {
                return node.name !== name || node.initializer !== initializer ? finishUpdatePropertyAssignment(createPropertyAssignment(name, initializer), node) : node;
            }
            function finishUpdatePropertyAssignment(updated, original) {
                if (updated !== original) {
                    updated.modifiers = original.modifiers;
                    updated.questionToken = original.questionToken;
                    updated.exclamationToken = original.exclamationToken;
                }
                return update(updated, original);
            }
            function createShorthandPropertyAssignment(name, objectAssignmentInitializer) {
                const node = createBaseDeclaration(304 /* ShorthandPropertyAssignment */);
                node.name = asName(name);
                node.objectAssignmentInitializer = objectAssignmentInitializer && parenthesizerRules().parenthesizeExpressionForDisallowedComma(objectAssignmentInitializer);
                node.transformFlags |= propagateIdentifierNameFlags(node.name) | propagateChildFlags(node.objectAssignmentInitializer) | 1024 /* ContainsES2015 */;
                node.equalsToken = void 0;
                node.modifiers = void 0;
                node.questionToken = void 0;
                node.exclamationToken = void 0;
                node.jsDoc = void 0;
                return node;
            }
            function updateShorthandPropertyAssignment(node, name, objectAssignmentInitializer) {
                return node.name !== name || node.objectAssignmentInitializer !== objectAssignmentInitializer ? finishUpdateShorthandPropertyAssignment(createShorthandPropertyAssignment(name, objectAssignmentInitializer), node) : node;
            }
            function finishUpdateShorthandPropertyAssignment(updated, original) {
                if (updated !== original) {
                    updated.modifiers = original.modifiers;
                    updated.questionToken = original.questionToken;
                    updated.exclamationToken = original.exclamationToken;
                    updated.equalsToken = original.equalsToken;
                }
                return update(updated, original);
            }
            function createSpreadAssignment(expression) {
                const node = createBaseDeclaration(305 /* SpreadAssignment */);
                node.expression = parenthesizerRules().parenthesizeExpressionForDisallowedComma(expression);
                node.transformFlags |= propagateChildFlags(node.expression) | 128 /* ContainsES2018 */ | 65536 /* ContainsObjectRestOrSpread */;
                node.jsDoc = void 0;
                return node;
            }
            function updateSpreadAssignment(node, expression) {
                return node.expression !== expression ? update(createSpreadAssignment(expression), node) : node;
            }
            function createEnumMember(name, initializer) {
                const node = createBaseDeclaration(306 /* EnumMember */);
                node.name = asName(name);
                node.initializer = initializer && parenthesizerRules().parenthesizeExpressionForDisallowedComma(initializer);
                node.transformFlags |= propagateChildFlags(node.name) | propagateChildFlags(node.initializer) | 1 /* ContainsTypeScript */;
                node.jsDoc = void 0;
                return node;
            }
            function updateEnumMember(node, name, initializer) {
                return node.name !== name || node.initializer !== initializer ? update(createEnumMember(name, initializer), node) : node;
            }
            function createSourceFile2(statements, endOfFileToken, flags2) {
                const node = baseFactory2.createBaseSourceFileNode(312 /* SourceFile */);
                node.statements = createNodeArray(statements);
                node.endOfFileToken = endOfFileToken;
                node.flags |= flags2;
                node.text = "";
                node.fileName = "";
                node.path = "";
                node.resolvedPath = "";
                node.originalFileName = "";
                node.languageVersion = 0;
                node.languageVariant = 0;
                node.scriptKind = 0;
                node.isDeclarationFile = false;
                node.hasNoDefaultLib = false;
                node.transformFlags |= propagateChildrenFlags(node.statements) | propagateChildFlags(node.endOfFileToken);
                node.locals = void 0;
                node.nextContainer = void 0;
                node.endFlowNode = void 0;
                node.nodeCount = 0;
                node.identifierCount = 0;
                node.symbolCount = 0;
                node.parseDiagnostics = void 0;
                node.bindDiagnostics = void 0;
                node.bindSuggestionDiagnostics = void 0;
                node.lineMap = void 0;
                node.externalModuleIndicator = void 0;
                node.setExternalModuleIndicator = void 0;
                node.pragmas = void 0;
                node.checkJsDirective = void 0;
                node.referencedFiles = void 0;
                node.typeReferenceDirectives = void 0;
                node.libReferenceDirectives = void 0;
                node.amdDependencies = void 0;
                node.commentDirectives = void 0;
                node.identifiers = void 0;
                node.packageJsonLocations = void 0;
                node.packageJsonScope = void 0;
                node.imports = void 0;
                node.moduleAugmentations = void 0;
                node.ambientModuleNames = void 0;
                node.classifiableNames = void 0;
                node.impliedNodeFormat = void 0;
                return node;
            }
            function createRedirectedSourceFile(redirectInfo) {
                const node = Object.create(redirectInfo.redirectTarget);
                Object.defineProperties(node, {
                    id: {
                        get() {
                            return this.redirectInfo.redirectTarget.id;
                        },
                        set(value) {
                            this.redirectInfo.redirectTarget.id = value;
                        }
                    },
                    symbol: {
                        get() {
                            return this.redirectInfo.redirectTarget.symbol;
                        },
                        set(value) {
                            this.redirectInfo.redirectTarget.symbol = value;
                        }
                    }
                });
                node.redirectInfo = redirectInfo;
                return node;
            }
            function cloneRedirectedSourceFile(source) {
                const node = createRedirectedSourceFile(source.redirectInfo);
                node.flags |= source.flags & ~16 /* Synthesized */;
                node.fileName = source.fileName;
                node.path = source.path;
                node.resolvedPath = source.resolvedPath;
                node.originalFileName = source.originalFileName;
                node.packageJsonLocations = source.packageJsonLocations;
                node.packageJsonScope = source.packageJsonScope;
                node.emitNode = void 0;
                return node;
            }
            function cloneSourceFileWorker(source) {
                const node = baseFactory2.createBaseSourceFileNode(312 /* SourceFile */);
                node.flags |= source.flags & ~16 /* Synthesized */;
                for (const p in source) {
                    if (hasProperty(node, p) || !hasProperty(source, p)) {
                        continue;
                    }
                    if (p === "emitNode") {
                        node.emitNode = void 0;
                        continue;
                    }
                    node[p] = source[p];
                }
                return node;
            }
            function cloneSourceFile(source) {
                const node = source.redirectInfo ? cloneRedirectedSourceFile(source) : cloneSourceFileWorker(source);
                setOriginal(node, source);
                return node;
            }
            function cloneSourceFileWithChanges(source, statements, isDeclarationFile, referencedFiles, typeReferences, hasNoDefaultLib, libReferences) {
                const node = cloneSourceFile(source);
                node.statements = createNodeArray(statements);
                node.isDeclarationFile = isDeclarationFile;
                node.referencedFiles = referencedFiles;
                node.typeReferenceDirectives = typeReferences;
                node.hasNoDefaultLib = hasNoDefaultLib;
                node.libReferenceDirectives = libReferences;
                node.transformFlags = propagateChildrenFlags(node.statements) | propagateChildFlags(node.endOfFileToken);
                return node;
            }
            function updateSourceFile2(node, statements, isDeclarationFile = node.isDeclarationFile, referencedFiles = node.referencedFiles, typeReferenceDirectives = node.typeReferenceDirectives, hasNoDefaultLib = node.hasNoDefaultLib, libReferenceDirectives = node.libReferenceDirectives) {
                return node.statements !== statements || node.isDeclarationFile !== isDeclarationFile || node.referencedFiles !== referencedFiles || node.typeReferenceDirectives !== typeReferenceDirectives || node.hasNoDefaultLib !== hasNoDefaultLib || node.libReferenceDirectives !== libReferenceDirectives ? update(cloneSourceFileWithChanges(node, statements, isDeclarationFile, referencedFiles, typeReferenceDirectives, hasNoDefaultLib, libReferenceDirectives), node) : node;
            }
            function createBundle(sourceFiles, prepends = emptyArray) {
                const node = createBaseNode(313 /* Bundle */);
                node.prepends = prepends;
                node.sourceFiles = sourceFiles;
                node.syntheticFileReferences = void 0;
                node.syntheticTypeReferences = void 0;
                node.syntheticLibReferences = void 0;
                node.hasNoDefaultLib = void 0;
                return node;
            }
            function updateBundle(node, sourceFiles, prepends = emptyArray) {
                return node.sourceFiles !== sourceFiles || node.prepends !== prepends ? update(createBundle(sourceFiles, prepends), node) : node;
            }
            function createUnparsedSource(prologues, syntheticReferences, texts) {
                const node = createBaseNode(314 /* UnparsedSource */);
                node.prologues = prologues;
                node.syntheticReferences = syntheticReferences;
                node.texts = texts;
                node.fileName = "";
                node.text = "";
                node.referencedFiles = emptyArray;
                node.libReferenceDirectives = emptyArray;
                node.getLineAndCharacterOfPosition = (pos) => getLineAndCharacterOfPosition(node, pos);
                return node;
            }
            function createBaseUnparsedNode(kind, data) {
                const node = createBaseNode(kind);
                node.data = data;
                return node;
            }
            function createUnparsedPrologue(data) {
                return createBaseUnparsedNode(307 /* UnparsedPrologue */, data);
            }
            function createUnparsedPrepend(data, texts) {
                const node = createBaseUnparsedNode(308 /* UnparsedPrepend */, data);
                node.texts = texts;
                return node;
            }
            function createUnparsedTextLike(data, internal) {
                return createBaseUnparsedNode(internal ? 310 /* UnparsedInternalText */ : 309 /* UnparsedText */, data);
            }
            function createUnparsedSyntheticReference(section) {
                const node = createBaseNode(311 /* UnparsedSyntheticReference */);
                node.data = section.data;
                node.section = section;
                return node;
            }
            function createInputFiles2() {
                const node = createBaseNode(315 /* InputFiles */);
                node.javascriptText = "";
                node.declarationText = "";
                return node;
            }
            function createSyntheticExpression(type, isSpread = false, tupleNameSource) {
                const node = createBaseNode(237 /* SyntheticExpression */);
                node.type = type;
                node.isSpread = isSpread;
                node.tupleNameSource = tupleNameSource;
                return node;
            }
            function createSyntaxList3(children) {
                const node = createBaseNode(358 /* SyntaxList */);
                node._children = children;
                return node;
            }
            function createNotEmittedStatement(original) {
                const node = createBaseNode(359 /* NotEmittedStatement */);
                node.original = original;
                setTextRange(node, original);
                return node;
            }
            function createPartiallyEmittedExpression(expression, original) {
                const node = createBaseNode(360 /* PartiallyEmittedExpression */);
                node.expression = expression;
                node.original = original;
                node.transformFlags |= propagateChildFlags(node.expression) | 1 /* ContainsTypeScript */;
                setTextRange(node, original);
                return node;
            }
            function updatePartiallyEmittedExpression(node, expression) {
                return node.expression !== expression ? update(createPartiallyEmittedExpression(expression, node.original), node) : node;
            }
            function flattenCommaElements(node) {
                if (nodeIsSynthesized(node) && !isParseTreeNode(node) && !node.original && !node.emitNode && !node.id) {
                    if (isCommaListExpression(node)) {
                        return node.elements;
                    }
                    if (isBinaryExpression(node) && isCommaToken(node.operatorToken)) {
                        return [node.left, node.right];
                    }
                }
                return node;
            }
            function createCommaListExpression(elements) {
                const node = createBaseNode(361 /* CommaListExpression */);
                node.elements = createNodeArray(sameFlatMap(elements, flattenCommaElements));
                node.transformFlags |= propagateChildrenFlags(node.elements);
                return node;
            }
            function updateCommaListExpression(node, elements) {
                return node.elements !== elements ? update(createCommaListExpression(elements), node) : node;
            }
            function createSyntheticReferenceExpression(expression, thisArg) {
                const node = createBaseNode(362 /* SyntheticReferenceExpression */);
                node.expression = expression;
                node.thisArg = thisArg;
                node.transformFlags |= propagateChildFlags(node.expression) | propagateChildFlags(node.thisArg);
                return node;
            }
            function updateSyntheticReferenceExpression(node, expression, thisArg) {
                return node.expression !== expression || node.thisArg !== thisArg ? update(createSyntheticReferenceExpression(expression, thisArg), node) : node;
            }
            function cloneGeneratedIdentifier(node) {
                const clone2 = createBaseIdentifier(node.escapedText);
                clone2.flags |= node.flags & ~16 /* Synthesized */;
                clone2.transformFlags = node.transformFlags;
                setOriginal(clone2, node);
                setIdentifierAutoGenerate(clone2, { ...node.emitNode.autoGenerate });
                return clone2;
            }
            function cloneIdentifier(node) {
                const clone2 = createBaseIdentifier(node.escapedText);
                clone2.flags |= node.flags & ~16 /* Synthesized */;
                clone2.jsDoc = node.jsDoc;
                clone2.flowNode = node.flowNode;
                clone2.symbol = node.symbol;
                clone2.transformFlags = node.transformFlags;
                setOriginal(clone2, node);
                const typeArguments = getIdentifierTypeArguments(node);
                if (typeArguments)
                    setIdentifierTypeArguments(clone2, typeArguments);
                return clone2;
            }
            function cloneGeneratedPrivateIdentifier(node) {
                const clone2 = createBasePrivateIdentifier(node.escapedText);
                clone2.flags |= node.flags & ~16 /* Synthesized */;
                clone2.transformFlags = node.transformFlags;
                setOriginal(clone2, node);
                setIdentifierAutoGenerate(clone2, { ...node.emitNode.autoGenerate });
                return clone2;
            }
            function clonePrivateIdentifier(node) {
                const clone2 = createBasePrivateIdentifier(node.escapedText);
                clone2.flags |= node.flags & ~16 /* Synthesized */;
                clone2.transformFlags = node.transformFlags;
                setOriginal(clone2, node);
                return clone2;
            }
            function cloneNode(node) {
                if (node === void 0) {
                    return node;
                }
                if (isSourceFile(node)) {
                    return cloneSourceFile(node);
                }
                if (isGeneratedIdentifier(node)) {
                    return cloneGeneratedIdentifier(node);
                }
                if (isIdentifier(node)) {
                    return cloneIdentifier(node);
                }
                if (isGeneratedPrivateIdentifier(node)) {
                    return cloneGeneratedPrivateIdentifier(node);
                }
                if (isPrivateIdentifier(node)) {
                    return clonePrivateIdentifier(node);
                }
                const clone2 = !isNodeKind(node.kind) ? baseFactory2.createBaseTokenNode(node.kind) : baseFactory2.createBaseNode(node.kind);
                clone2.flags |= node.flags & ~16 /* Synthesized */;
                clone2.transformFlags = node.transformFlags;
                setOriginal(clone2, node);
                for (const key in node) {
                    if (hasProperty(clone2, key) || !hasProperty(node, key)) {
                        continue;
                    }
                    clone2[key] = node[key];
                }
                return clone2;
            }
            function createImmediatelyInvokedFunctionExpression(statements, param, paramValue) {
                return createCallExpression(createFunctionExpression(
                /*modifiers*/
                void 0, 
                /*asteriskToken*/
                void 0, 
                /*name*/
                void 0, 
                /*typeParameters*/
                void 0, 
                /*parameters*/
                param ? [param] : [], 
                /*type*/
                void 0, createBlock(statements, 
                /*multiLine*/
                true)), 
                /*typeArguments*/
                void 0, 
                /*argumentsArray*/
                paramValue ? [paramValue] : []);
            }
            function createImmediatelyInvokedArrowFunction(statements, param, paramValue) {
                return createCallExpression(createArrowFunction(
                /*modifiers*/
                void 0, 
                /*typeParameters*/
                void 0, 
                /*parameters*/
                param ? [param] : [], 
                /*type*/
                void 0, 
                /*equalsGreaterThanToken*/
                void 0, createBlock(statements, 
                /*multiLine*/
                true)), 
                /*typeArguments*/
                void 0, 
                /*argumentsArray*/
                paramValue ? [paramValue] : []);
            }
            function createVoidZero() {
                return createVoidExpression(createNumericLiteral("0"));
            }
            function createExportDefault(expression) {
                return createExportAssignment2(
                /*modifiers*/
                void 0, 
                /*isExportEquals*/
                false, expression);
            }
            function createExternalModuleExport(exportName) {
                return createExportDeclaration(
                /*modifiers*/
                void 0, 
                /*isTypeOnly*/
                false, createNamedExports([
                    createExportSpecifier(
                    /*isTypeOnly*/
                    false, 
                    /*propertyName*/
                    void 0, exportName)
                ]));
            }
            function createTypeCheck(value, tag) {
                return tag === "null" ? factory2.createStrictEquality(value, createNull()) : tag === "undefined" ? factory2.createStrictEquality(value, createVoidZero()) : factory2.createStrictEquality(createTypeOfExpression(value), createStringLiteral(tag));
            }
            function createIsNotTypeCheck(value, tag) {
                return tag === "null" ? factory2.createStrictInequality(value, createNull()) : tag === "undefined" ? factory2.createStrictInequality(value, createVoidZero()) : factory2.createStrictInequality(createTypeOfExpression(value), createStringLiteral(tag));
            }
            function createMethodCall(object, methodName, argumentsList) {
                if (isCallChain(object)) {
                    return createCallChain(createPropertyAccessChain(object, 
                    /*questionDotToken*/
                    void 0, methodName), 
                    /*questionDotToken*/
                    void 0, 
                    /*typeArguments*/
                    void 0, argumentsList);
                }
                return createCallExpression(createPropertyAccessExpression(object, methodName), 
                /*typeArguments*/
                void 0, argumentsList);
            }
            function createFunctionBindCall(target, thisArg, argumentsList) {
                return createMethodCall(target, "bind", [thisArg, ...argumentsList]);
            }
            function createFunctionCallCall(target, thisArg, argumentsList) {
                return createMethodCall(target, "call", [thisArg, ...argumentsList]);
            }
            function createFunctionApplyCall(target, thisArg, argumentsExpression) {
                return createMethodCall(target, "apply", [thisArg, argumentsExpression]);
            }
            function createGlobalMethodCall(globalObjectName, methodName, argumentsList) {
                return createMethodCall(createIdentifier(globalObjectName), methodName, argumentsList);
            }
            function createArraySliceCall(array, start) {
                return createMethodCall(array, "slice", start === void 0 ? [] : [asExpression(start)]);
            }
            function createArrayConcatCall(array, argumentsList) {
                return createMethodCall(array, "concat", argumentsList);
            }
            function createObjectDefinePropertyCall(target, propertyName, attributes) {
                return createGlobalMethodCall("Object", "defineProperty", [target, asExpression(propertyName), attributes]);
            }
            function createObjectGetOwnPropertyDescriptorCall(target, propertyName) {
                return createGlobalMethodCall("Object", "getOwnPropertyDescriptor", [target, asExpression(propertyName)]);
            }
            function createReflectGetCall(target, propertyKey, receiver) {
                return createGlobalMethodCall("Reflect", "get", receiver ? [target, propertyKey, receiver] : [target, propertyKey]);
            }
            function createReflectSetCall(target, propertyKey, value, receiver) {
                return createGlobalMethodCall("Reflect", "set", receiver ? [target, propertyKey, value, receiver] : [target, propertyKey, value]);
            }
            function tryAddPropertyAssignment(properties, propertyName, expression) {
                if (expression) {
                    properties.push(createPropertyAssignment(propertyName, expression));
                    return true;
                }
                return false;
            }
            function createPropertyDescriptor(attributes, singleLine) {
                const properties = [];
                tryAddPropertyAssignment(properties, "enumerable", asExpression(attributes.enumerable));
                tryAddPropertyAssignment(properties, "configurable", asExpression(attributes.configurable));
                let isData = tryAddPropertyAssignment(properties, "writable", asExpression(attributes.writable));
                isData = tryAddPropertyAssignment(properties, "value", attributes.value) || isData;
                let isAccessor2 = tryAddPropertyAssignment(properties, "get", attributes.get);
                isAccessor2 = tryAddPropertyAssignment(properties, "set", attributes.set) || isAccessor2;
                Debug.assert(!(isData && isAccessor2), "A PropertyDescriptor may not be both an accessor descriptor and a data descriptor.");
                return createObjectLiteralExpression(properties, !singleLine);
            }
            function updateOuterExpression(outerExpression, expression) {
                switch (outerExpression.kind) {
                    case 217 /* ParenthesizedExpression */:
                        return updateParenthesizedExpression(outerExpression, expression);
                    case 216 /* TypeAssertionExpression */:
                        return updateTypeAssertion(outerExpression, outerExpression.type, expression);
                    case 234 /* AsExpression */:
                        return updateAsExpression(outerExpression, expression, outerExpression.type);
                    case 238 /* SatisfiesExpression */:
                        return updateSatisfiesExpression(outerExpression, expression, outerExpression.type);
                    case 235 /* NonNullExpression */:
                        return updateNonNullExpression(outerExpression, expression);
                    case 360 /* PartiallyEmittedExpression */:
                        return updatePartiallyEmittedExpression(outerExpression, expression);
                }
            }
            function isIgnorableParen(node) {
                return isParenthesizedExpression(node) && nodeIsSynthesized(node) && nodeIsSynthesized(getSourceMapRange(node)) && nodeIsSynthesized(getCommentRange(node)) && !some(getSyntheticLeadingComments(node)) && !some(getSyntheticTrailingComments(node));
            }
            function restoreOuterExpressions(outerExpression, innerExpression, kinds = 15 /* All */) {
                if (outerExpression && isOuterExpression(outerExpression, kinds) && !isIgnorableParen(outerExpression)) {
                    return updateOuterExpression(outerExpression, restoreOuterExpressions(outerExpression.expression, innerExpression));
                }
                return innerExpression;
            }
            function restoreEnclosingLabel(node, outermostLabeledStatement, afterRestoreLabelCallback) {
                if (!outermostLabeledStatement) {
                    return node;
                }
                const updated = updateLabeledStatement(outermostLabeledStatement, outermostLabeledStatement.label, isLabeledStatement(outermostLabeledStatement.statement) ? restoreEnclosingLabel(node, outermostLabeledStatement.statement) : node);
                if (afterRestoreLabelCallback) {
                    afterRestoreLabelCallback(outermostLabeledStatement);
                }
                return updated;
            }
            function shouldBeCapturedInTempVariable(node, cacheIdentifiers) {
                const target = skipParentheses(node);
                switch (target.kind) {
                    case 80 /* Identifier */:
                        return cacheIdentifiers;
                    case 110 /* ThisKeyword */:
                    case 9 /* NumericLiteral */:
                    case 10 /* BigIntLiteral */:
                    case 11 /* StringLiteral */:
                        return false;
                    case 209 /* ArrayLiteralExpression */:
                        const elements = target.elements;
                        if (elements.length === 0) {
                            return false;
                        }
                        return true;
                    case 210 /* ObjectLiteralExpression */:
                        return target.properties.length > 0;
                    default:
                        return true;
                }
            }
            function createCallBinding(expression, recordTempVariable, languageVersion, cacheIdentifiers = false) {
                const callee = skipOuterExpressions(expression, 15 /* All */);
                let thisArg;
                let target;
                if (isSuperProperty(callee)) {
                    thisArg = createThis();
                    target = callee;
                }
                else if (isSuperKeyword(callee)) {
                    thisArg = createThis();
                    target = languageVersion !== void 0 && languageVersion < 2 /* ES2015 */ ? setTextRange(createIdentifier("_super"), callee) : callee;
                }
                else if (getEmitFlags(callee) & 8192 /* HelperName */) {
                    thisArg = createVoidZero();
                    target = parenthesizerRules().parenthesizeLeftSideOfAccess(callee, 
                    /*optionalChain*/
                    false);
                }
                else if (isPropertyAccessExpression(callee)) {
                    if (shouldBeCapturedInTempVariable(callee.expression, cacheIdentifiers)) {
                        thisArg = createTempVariable(recordTempVariable);
                        target = createPropertyAccessExpression(setTextRange(factory2.createAssignment(thisArg, callee.expression), callee.expression), callee.name);
                        setTextRange(target, callee);
                    }
                    else {
                        thisArg = callee.expression;
                        target = callee;
                    }
                }
                else if (isElementAccessExpression(callee)) {
                    if (shouldBeCapturedInTempVariable(callee.expression, cacheIdentifiers)) {
                        thisArg = createTempVariable(recordTempVariable);
                        target = createElementAccessExpression(setTextRange(factory2.createAssignment(thisArg, callee.expression), callee.expression), callee.argumentExpression);
                        setTextRange(target, callee);
                    }
                    else {
                        thisArg = callee.expression;
                        target = callee;
                    }
                }
                else {
                    thisArg = createVoidZero();
                    target = parenthesizerRules().parenthesizeLeftSideOfAccess(expression, 
                    /*optionalChain*/
                    false);
                }
                return { target, thisArg };
            }
            function createAssignmentTargetWrapper(paramName, expression) {
                return createPropertyAccessExpression(
                // Explicit parens required because of v8 regression (https://bugs.chromium.org/p/v8/issues/detail?id=9560)
                createParenthesizedExpression(createObjectLiteralExpression([
                    createSetAccessorDeclaration(
                    /*modifiers*/
                    void 0, "value", [createParameterDeclaration(
                        /*modifiers*/
                        void 0, 
                        /*dotDotDotToken*/
                        void 0, paramName, 
                        /*questionToken*/
                        void 0, 
                        /*type*/
                        void 0, 
                        /*initializer*/
                        void 0)], createBlock([
                        createExpressionStatement(expression)
                    ]))
                ])), "value");
            }
            function inlineExpressions(expressions) {
                return expressions.length > 10 ? createCommaListExpression(expressions) : reduceLeft(expressions, factory2.createComma);
            }
            function getName(node, allowComments, allowSourceMaps, emitFlags = 0, ignoreAssignedName) {
                const nodeName = ignoreAssignedName ? node && getNonAssignedNameOfDeclaration(node) : getNameOfDeclaration(node);
                if (nodeName && isIdentifier(nodeName) && !isGeneratedIdentifier(nodeName)) {
                    const name = setParent(setTextRange(cloneNode(nodeName), nodeName), nodeName.parent);
                    emitFlags |= getEmitFlags(nodeName);
                    if (!allowSourceMaps)
                        emitFlags |= 96 /* NoSourceMap */;
                    if (!allowComments)
                        emitFlags |= 3072 /* NoComments */;
                    if (emitFlags)
                        setEmitFlags(name, emitFlags);
                    return name;
                }
                return getGeneratedNameForNode(node);
            }
            function getInternalName(node, allowComments, allowSourceMaps) {
                return getName(node, allowComments, allowSourceMaps, 32768 /* LocalName */ | 65536 /* InternalName */);
            }
            function getLocalName(node, allowComments, allowSourceMaps, ignoreAssignedName) {
                return getName(node, allowComments, allowSourceMaps, 32768 /* LocalName */, ignoreAssignedName);
            }
            function getExportName(node, allowComments, allowSourceMaps) {
                return getName(node, allowComments, allowSourceMaps, 16384 /* ExportName */);
            }
            function getDeclarationName(node, allowComments, allowSourceMaps) {
                return getName(node, allowComments, allowSourceMaps);
            }
            function getNamespaceMemberName(ns, name, allowComments, allowSourceMaps) {
                const qualifiedName = createPropertyAccessExpression(ns, nodeIsSynthesized(name) ? name : cloneNode(name));
                setTextRange(qualifiedName, name);
                let emitFlags = 0;
                if (!allowSourceMaps)
                    emitFlags |= 96 /* NoSourceMap */;
                if (!allowComments)
                    emitFlags |= 3072 /* NoComments */;
                if (emitFlags)
                    setEmitFlags(qualifiedName, emitFlags);
                return qualifiedName;
            }
            function getExternalModuleOrNamespaceExportName(ns, node, allowComments, allowSourceMaps) {
                if (ns && hasSyntacticModifier(node, 32 /* Export */)) {
                    return getNamespaceMemberName(ns, getName(node), allowComments, allowSourceMaps);
                }
                return getExportName(node, allowComments, allowSourceMaps);
            }
            function copyPrologue(source, target, ensureUseStrict2, visitor) {
                const offset = copyStandardPrologue(source, target, 0, ensureUseStrict2);
                return copyCustomPrologue(source, target, offset, visitor);
            }
            function isUseStrictPrologue2(node) {
                return isStringLiteral(node.expression) && node.expression.text === "use strict";
            }
            function createUseStrictPrologue() {
                return startOnNewLine(createExpressionStatement(createStringLiteral("use strict")));
            }
            function copyStandardPrologue(source, target, statementOffset = 0, ensureUseStrict2) {
                Debug.assert(target.length === 0, "Prologue directives should be at the first statement in the target statements array");
                let foundUseStrict = false;
                const numStatements = source.length;
                while (statementOffset < numStatements) {
                    const statement = source[statementOffset];
                    if (isPrologueDirective(statement)) {
                        if (isUseStrictPrologue2(statement)) {
                            foundUseStrict = true;
                        }
                        target.push(statement);
                    }
                    else {
                        break;
                    }
                    statementOffset++;
                }
                if (ensureUseStrict2 && !foundUseStrict) {
                    target.push(createUseStrictPrologue());
                }
                return statementOffset;
            }
            function copyCustomPrologue(source, target, statementOffset, visitor, filter2 = returnTrue) {
                const numStatements = source.length;
                while (statementOffset !== void 0 && statementOffset < numStatements) {
                    const statement = source[statementOffset];
                    if (getEmitFlags(statement) & 2097152 /* CustomPrologue */ && filter2(statement)) {
                        append(target, visitor ? visitNode(statement, visitor, isStatement) : statement);
                    }
                    else {
                        break;
                    }
                    statementOffset++;
                }
                return statementOffset;
            }
            function ensureUseStrict(statements) {
                const foundUseStrict = findUseStrictPrologue(statements);
                if (!foundUseStrict) {
                    return setTextRange(createNodeArray([createUseStrictPrologue(), ...statements]), statements);
                }
                return statements;
            }
            function liftToBlock(nodes) {
                Debug.assert(every(nodes, isStatementOrBlock), "Cannot lift nodes to a Block.");
                return singleOrUndefined(nodes) || createBlock(nodes);
            }
            function findSpanEnd(array, test, start) {
                let i = start;
                while (i < array.length && test(array[i])) {
                    i++;
                }
                return i;
            }
            function mergeLexicalEnvironment(statements, declarations) {
                if (!some(declarations)) {
                    return statements;
                }
                const leftStandardPrologueEnd = findSpanEnd(statements, isPrologueDirective, 0);
                const leftHoistedFunctionsEnd = findSpanEnd(statements, isHoistedFunction, leftStandardPrologueEnd);
                const leftHoistedVariablesEnd = findSpanEnd(statements, isHoistedVariableStatement, leftHoistedFunctionsEnd);
                const rightStandardPrologueEnd = findSpanEnd(declarations, isPrologueDirective, 0);
                const rightHoistedFunctionsEnd = findSpanEnd(declarations, isHoistedFunction, rightStandardPrologueEnd);
                const rightHoistedVariablesEnd = findSpanEnd(declarations, isHoistedVariableStatement, rightHoistedFunctionsEnd);
                const rightCustomPrologueEnd = findSpanEnd(declarations, isCustomPrologue, rightHoistedVariablesEnd);
                Debug.assert(rightCustomPrologueEnd === declarations.length, "Expected declarations to be valid standard or custom prologues");
                const left = isNodeArray(statements) ? statements.slice() : statements;
                if (rightCustomPrologueEnd > rightHoistedVariablesEnd) {
                    left.splice(leftHoistedVariablesEnd, 0, ...declarations.slice(rightHoistedVariablesEnd, rightCustomPrologueEnd));
                }
                if (rightHoistedVariablesEnd > rightHoistedFunctionsEnd) {
                    left.splice(leftHoistedFunctionsEnd, 0, ...declarations.slice(rightHoistedFunctionsEnd, rightHoistedVariablesEnd));
                }
                if (rightHoistedFunctionsEnd > rightStandardPrologueEnd) {
                    left.splice(leftStandardPrologueEnd, 0, ...declarations.slice(rightStandardPrologueEnd, rightHoistedFunctionsEnd));
                }
                if (rightStandardPrologueEnd > 0) {
                    if (leftStandardPrologueEnd === 0) {
                        left.splice(0, 0, ...declarations.slice(0, rightStandardPrologueEnd));
                    }
                    else {
                        const leftPrologues = /* @__PURE__ */ new Map();
                        for (let i = 0; i < leftStandardPrologueEnd; i++) {
                            const leftPrologue = statements[i];
                            leftPrologues.set(leftPrologue.expression.text, true);
                        }
                        for (let i = rightStandardPrologueEnd - 1; i >= 0; i--) {
                            const rightPrologue = declarations[i];
                            if (!leftPrologues.has(rightPrologue.expression.text)) {
                                left.unshift(rightPrologue);
                            }
                        }
                    }
                }
                if (isNodeArray(statements)) {
                    return setTextRange(createNodeArray(left, statements.hasTrailingComma), statements);
                }
                return statements;
            }
            function replaceModifiers(node, modifiers) {
                let modifierArray;
                if (typeof modifiers === "number") {
                    modifierArray = createModifiersFromModifierFlags(modifiers);
                }
                else {
                    modifierArray = modifiers;
                }
                return isTypeParameterDeclaration(node) ? updateTypeParameterDeclaration(node, modifierArray, node.name, node.constraint, node.default) : isParameter(node) ? updateParameterDeclaration(node, modifierArray, node.dotDotDotToken, node.name, node.questionToken, node.type, node.initializer) : isConstructorTypeNode(node) ? updateConstructorTypeNode1(node, modifierArray, node.typeParameters, node.parameters, node.type) : isPropertySignature(node) ? updatePropertySignature(node, modifierArray, node.name, node.questionToken, node.type) : isPropertyDeclaration(node) ? updatePropertyDeclaration2(node, modifierArray, node.name, node.questionToken ?? node.exclamationToken, node.type, node.initializer) : isMethodSignature(node) ? updateMethodSignature(node, modifierArray, node.name, node.questionToken, node.typeParameters, node.parameters, node.type) : isMethodDeclaration(node) ? updateMethodDeclaration(node, modifierArray, node.asteriskToken, node.name, node.questionToken, node.typeParameters, node.parameters, node.type, node.body) : isConstructorDeclaration(node) ? updateConstructorDeclaration(node, modifierArray, node.parameters, node.body) : isGetAccessorDeclaration(node) ? updateGetAccessorDeclaration(node, modifierArray, node.name, node.parameters, node.type, node.body) : isSetAccessorDeclaration(node) ? updateSetAccessorDeclaration(node, modifierArray, node.name, node.parameters, node.body) : isIndexSignatureDeclaration(node) ? updateIndexSignature(node, modifierArray, node.parameters, node.type) : isFunctionExpression(node) ? updateFunctionExpression(node, modifierArray, node.asteriskToken, node.name, node.typeParameters, node.parameters, node.type, node.body) : isArrowFunction(node) ? updateArrowFunction(node, modifierArray, node.typeParameters, node.parameters, node.type, node.equalsGreaterThanToken, node.body) : isClassExpression(node) ? updateClassExpression(node, modifierArray, node.name, node.typeParameters, node.heritageClauses, node.members) : isVariableStatement(node) ? updateVariableStatement(node, modifierArray, node.declarationList) : isFunctionDeclaration(node) ? updateFunctionDeclaration(node, modifierArray, node.asteriskToken, node.name, node.typeParameters, node.parameters, node.type, node.body) : isClassDeclaration(node) ? updateClassDeclaration(node, modifierArray, node.name, node.typeParameters, node.heritageClauses, node.members) : isInterfaceDeclaration(node) ? updateInterfaceDeclaration(node, modifierArray, node.name, node.typeParameters, node.heritageClauses, node.members) : isTypeAliasDeclaration(node) ? updateTypeAliasDeclaration(node, modifierArray, node.name, node.typeParameters, node.type) : isEnumDeclaration(node) ? updateEnumDeclaration(node, modifierArray, node.name, node.members) : isModuleDeclaration(node) ? updateModuleDeclaration(node, modifierArray, node.name, node.body) : isImportEqualsDeclaration(node) ? updateImportEqualsDeclaration(node, modifierArray, node.isTypeOnly, node.name, node.moduleReference) : isImportDeclaration(node) ? updateImportDeclaration(node, modifierArray, node.importClause, node.moduleSpecifier, node.attributes) : isExportAssignment(node) ? updateExportAssignment(node, modifierArray, node.expression) : isExportDeclaration(node) ? updateExportDeclaration(node, modifierArray, node.isTypeOnly, node.exportClause, node.moduleSpecifier, node.attributes) : Debug.assertNever(node);
            }
            function replaceDecoratorsAndModifiers(node, modifierArray) {
                return isParameter(node) ? updateParameterDeclaration(node, modifierArray, node.dotDotDotToken, node.name, node.questionToken, node.type, node.initializer) : isPropertyDeclaration(node) ? updatePropertyDeclaration2(node, modifierArray, node.name, node.questionToken ?? node.exclamationToken, node.type, node.initializer) : isMethodDeclaration(node) ? updateMethodDeclaration(node, modifierArray, node.asteriskToken, node.name, node.questionToken, node.typeParameters, node.parameters, node.type, node.body) : isGetAccessorDeclaration(node) ? updateGetAccessorDeclaration(node, modifierArray, node.name, node.parameters, node.type, node.body) : isSetAccessorDeclaration(node) ? updateSetAccessorDeclaration(node, modifierArray, node.name, node.parameters, node.body) : isClassExpression(node) ? updateClassExpression(node, modifierArray, node.name, node.typeParameters, node.heritageClauses, node.members) : isClassDeclaration(node) ? updateClassDeclaration(node, modifierArray, node.name, node.typeParameters, node.heritageClauses, node.members) : Debug.assertNever(node);
            }
            function replacePropertyName(node, name) {
                switch (node.kind) {
                    case 177 /* GetAccessor */:
                        return updateGetAccessorDeclaration(node, node.modifiers, name, node.parameters, node.type, node.body);
                    case 178 /* SetAccessor */:
                        return updateSetAccessorDeclaration(node, node.modifiers, name, node.parameters, node.body);
                    case 174 /* MethodDeclaration */:
                        return updateMethodDeclaration(node, node.modifiers, node.asteriskToken, name, node.questionToken, node.typeParameters, node.parameters, node.type, node.body);
                    case 173 /* MethodSignature */:
                        return updateMethodSignature(node, node.modifiers, name, node.questionToken, node.typeParameters, node.parameters, node.type);
                    case 172 /* PropertyDeclaration */:
                        return updatePropertyDeclaration2(node, node.modifiers, name, node.questionToken ?? node.exclamationToken, node.type, node.initializer);
                    case 171 /* PropertySignature */:
                        return updatePropertySignature(node, node.modifiers, name, node.questionToken, node.type);
                    case 303 /* PropertyAssignment */:
                        return updatePropertyAssignment(node, name, node.initializer);
                }
            }
            function asNodeArray(array) {
                return array ? createNodeArray(array) : void 0;
            }
            function asName(name) {
                return typeof name === "string" ? createIdentifier(name) : name;
            }
            function asExpression(value) {
                return typeof value === "string" ? createStringLiteral(value) : typeof value === "number" ? createNumericLiteral(value) : typeof value === "boolean" ? value ? createTrue() : createFalse() : value;
            }
            function asInitializer(node) {
                return node && parenthesizerRules().parenthesizeExpressionForDisallowedComma(node);
            }
            function asToken(value) {
                return typeof value === "number" ? createToken(value) : value;
            }
            function asEmbeddedStatement(statement) {
                return statement && isNotEmittedStatement(statement) ? setTextRange(setOriginal(createEmptyStatement(), statement), statement) : statement;
            }
            function asVariableDeclaration(variableDeclaration) {
                if (typeof variableDeclaration === "string" || variableDeclaration && !isVariableDeclaration(variableDeclaration)) {
                    return createVariableDeclaration(variableDeclaration, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, 
                    /*initializer*/
                    void 0);
                }
                return variableDeclaration;
            }
            function update(updated, original) {
                if (updated !== original) {
                    setOriginal(updated, original);
                    setTextRange(updated, original);
                }
                return updated;
            }
        }
        function getDefaultTagNameForKind(kind) {
            switch (kind) {
                case 351 /* JSDocTypeTag */:
                    return "type";
                case 349 /* JSDocReturnTag */:
                    return "returns";
                case 350 /* JSDocThisTag */:
                    return "this";
                case 347 /* JSDocEnumTag */:
                    return "enum";
                case 337 /* JSDocAuthorTag */:
                    return "author";
                case 339 /* JSDocClassTag */:
                    return "class";
                case 340 /* JSDocPublicTag */:
                    return "public";
                case 341 /* JSDocPrivateTag */:
                    return "private";
                case 342 /* JSDocProtectedTag */:
                    return "protected";
                case 343 /* JSDocReadonlyTag */:
                    return "readonly";
                case 344 /* JSDocOverrideTag */:
                    return "override";
                case 352 /* JSDocTemplateTag */:
                    return "template";
                case 353 /* JSDocTypedefTag */:
                    return "typedef";
                case 348 /* JSDocParameterTag */:
                    return "param";
                case 355 /* JSDocPropertyTag */:
                    return "prop";
                case 345 /* JSDocCallbackTag */:
                    return "callback";
                case 346 /* JSDocOverloadTag */:
                    return "overload";
                case 335 /* JSDocAugmentsTag */:
                    return "augments";
                case 336 /* JSDocImplementsTag */:
                    return "implements";
                default:
                    return Debug.fail(`Unsupported kind: ${Debug.formatSyntaxKind(kind)}`);
            }
        }
        function getCookedText(kind, rawText) {
            if (!rawTextScanner) {
                rawTextScanner = createScanner(99 /* Latest */, 
                /*skipTrivia*/
                false, 0 /* Standard */);
            }
            switch (kind) {
                case 15 /* NoSubstitutionTemplateLiteral */:
                    rawTextScanner.setText("`" + rawText + "`");
                    break;
                case 16 /* TemplateHead */:
                    rawTextScanner.setText("`" + rawText + "${");
                    break;
                case 17 /* TemplateMiddle */:
                    rawTextScanner.setText("}" + rawText + "${");
                    break;
                case 18 /* TemplateTail */:
                    rawTextScanner.setText("}" + rawText + "`");
                    break;
            }
            let token = rawTextScanner.scan();
            if (token === 20 /* CloseBraceToken */) {
                token = rawTextScanner.reScanTemplateToken(
                /*isTaggedTemplate*/
                false);
            }
            if (rawTextScanner.isUnterminated()) {
                rawTextScanner.setText(void 0);
                return invalidValueSentinel;
            }
            let tokenValue;
            switch (token) {
                case 15 /* NoSubstitutionTemplateLiteral */:
                case 16 /* TemplateHead */:
                case 17 /* TemplateMiddle */:
                case 18 /* TemplateTail */:
                    tokenValue = rawTextScanner.getTokenValue();
                    break;
            }
            if (tokenValue === void 0 || rawTextScanner.scan() !== 1 /* EndOfFileToken */) {
                rawTextScanner.setText(void 0);
                return invalidValueSentinel;
            }
            rawTextScanner.setText(void 0);
            return tokenValue;
        }
        function propagateNameFlags(node) {
            return node && isIdentifier(node) ? propagateIdentifierNameFlags(node) : propagateChildFlags(node);
        }
        function propagateIdentifierNameFlags(node) {
            return propagateChildFlags(node) & ~67108864 /* ContainsPossibleTopLevelAwait */;
        }
        function propagatePropertyNameFlagsOfChild(node, transformFlags) {
            return transformFlags | node.transformFlags & 134234112 /* PropertyNamePropagatingFlags */;
        }
        function propagateChildFlags(child) {
            if (!child)
                return 0 /* None */;
            const childFlags = child.transformFlags & ~getTransformFlagsSubtreeExclusions(child.kind);
            return isNamedDeclaration(child) && isPropertyName(child.name) ? propagatePropertyNameFlagsOfChild(child.name, childFlags) : childFlags;
        }
        function propagateChildrenFlags(children) {
            return children ? children.transformFlags : 0 /* None */;
        }
        function aggregateChildrenFlags(children) {
            let subtreeFlags = 0 /* None */;
            for (const child of children) {
                subtreeFlags |= propagateChildFlags(child);
            }
            children.transformFlags = subtreeFlags;
        }
        function getTransformFlagsSubtreeExclusions(kind) {
            if (kind >= 182 /* FirstTypeNode */ && kind <= 205 /* LastTypeNode */) {
                return -2 /* TypeExcludes */;
            }
            switch (kind) {
                case 213 /* CallExpression */:
                case 214 /* NewExpression */:
                case 209 /* ArrayLiteralExpression */:
                    return -2147450880 /* ArrayLiteralOrCallOrNewExcludes */;
                case 267 /* ModuleDeclaration */:
                    return -1941676032 /* ModuleExcludes */;
                case 169 /* Parameter */:
                    return -2147483648 /* ParameterExcludes */;
                case 219 /* ArrowFunction */:
                    return -2072174592 /* ArrowFunctionExcludes */;
                case 218 /* FunctionExpression */:
                case 262 /* FunctionDeclaration */:
                    return -1937940480 /* FunctionExcludes */;
                case 261 /* VariableDeclarationList */:
                    return -2146893824 /* VariableDeclarationListExcludes */;
                case 263 /* ClassDeclaration */:
                case 231 /* ClassExpression */:
                    return -2147344384 /* ClassExcludes */;
                case 176 /* Constructor */:
                    return -1937948672 /* ConstructorExcludes */;
                case 172 /* PropertyDeclaration */:
                    return -2013249536 /* PropertyExcludes */;
                case 174 /* MethodDeclaration */:
                case 177 /* GetAccessor */:
                case 178 /* SetAccessor */:
                    return -2005057536 /* MethodOrAccessorExcludes */;
                case 133 /* AnyKeyword */:
                case 150 /* NumberKeyword */:
                case 163 /* BigIntKeyword */:
                case 146 /* NeverKeyword */:
                case 154 /* StringKeyword */:
                case 151 /* ObjectKeyword */:
                case 136 /* BooleanKeyword */:
                case 155 /* SymbolKeyword */:
                case 116 /* VoidKeyword */:
                case 168 /* TypeParameter */:
                case 171 /* PropertySignature */:
                case 173 /* MethodSignature */:
                case 179 /* CallSignature */:
                case 180 /* ConstructSignature */:
                case 181 /* IndexSignature */:
                case 264 /* InterfaceDeclaration */:
                case 265 /* TypeAliasDeclaration */:
                    return -2 /* TypeExcludes */;
                case 210 /* ObjectLiteralExpression */:
                    return -2147278848 /* ObjectLiteralExcludes */;
                case 299 /* CatchClause */:
                    return -2147418112 /* CatchClauseExcludes */;
                case 206 /* ObjectBindingPattern */:
                case 207 /* ArrayBindingPattern */:
                    return -2147450880 /* BindingPatternExcludes */;
                case 216 /* TypeAssertionExpression */:
                case 238 /* SatisfiesExpression */:
                case 234 /* AsExpression */:
                case 360 /* PartiallyEmittedExpression */:
                case 217 /* ParenthesizedExpression */:
                case 108 /* SuperKeyword */:
                    return -2147483648 /* OuterExpressionExcludes */;
                case 211 /* PropertyAccessExpression */:
                case 212 /* ElementAccessExpression */:
                    return -2147483648 /* PropertyAccessExcludes */;
                default:
                    return -2147483648 /* NodeExcludes */;
            }
        }
        function makeSynthetic(node) {
            node.flags |= 16 /* Synthesized */;
            return node;
        }
        function createUnparsedSourceFile(textOrInputFiles, mapPathOrType, mapTextOrStripInternal) {
            let stripInternal;
            let bundleFileInfo;
            let fileName;
            let text;
            let length2;
            let sourceMapPath;
            let sourceMapText;
            let getText;
            let getSourceMapText;
            let oldFileOfCurrentEmit;
            if (!isString(textOrInputFiles)) {
                Debug.assert(mapPathOrType === "js" || mapPathOrType === "dts");
                fileName = (mapPathOrType === "js" ? textOrInputFiles.javascriptPath : textOrInputFiles.declarationPath) || "";
                sourceMapPath = mapPathOrType === "js" ? textOrInputFiles.javascriptMapPath : textOrInputFiles.declarationMapPath;
                getText = () => mapPathOrType === "js" ? textOrInputFiles.javascriptText : textOrInputFiles.declarationText;
                getSourceMapText = () => mapPathOrType === "js" ? textOrInputFiles.javascriptMapText : textOrInputFiles.declarationMapText;
                length2 = () => getText().length;
                if (textOrInputFiles.buildInfo && textOrInputFiles.buildInfo.bundle) {
                    Debug.assert(mapTextOrStripInternal === void 0 || typeof mapTextOrStripInternal === "boolean");
                    stripInternal = mapTextOrStripInternal;
                    bundleFileInfo = mapPathOrType === "js" ? textOrInputFiles.buildInfo.bundle.js : textOrInputFiles.buildInfo.bundle.dts;
                    oldFileOfCurrentEmit = textOrInputFiles.oldFileOfCurrentEmit;
                }
            }
            else {
                fileName = "";
                text = textOrInputFiles;
                length2 = textOrInputFiles.length;
                sourceMapPath = mapPathOrType;
                sourceMapText = mapTextOrStripInternal;
            }
            const node = oldFileOfCurrentEmit ? parseOldFileOfCurrentEmit(Debug.checkDefined(bundleFileInfo)) : parseUnparsedSourceFile(bundleFileInfo, stripInternal, length2);
            node.fileName = fileName;
            node.sourceMapPath = sourceMapPath;
            node.oldFileOfCurrentEmit = oldFileOfCurrentEmit;
            if (getText && getSourceMapText) {
                Object.defineProperty(node, "text", { get: getText });
                Object.defineProperty(node, "sourceMapText", { get: getSourceMapText });
            }
            else {
                Debug.assert(!oldFileOfCurrentEmit);
                node.text = text ?? "";
                node.sourceMapText = sourceMapText;
            }
            return node;
        }
        function parseUnparsedSourceFile(bundleFileInfo, stripInternal, length2) {
            let prologues;
            let helpers;
            let referencedFiles;
            let typeReferenceDirectives;
            let libReferenceDirectives;
            let prependChildren;
            let texts;
            let hasNoDefaultLib;
            for (const section of bundleFileInfo ? bundleFileInfo.sections : emptyArray) {
                switch (section.kind) {
                    case "prologue" /* Prologue */:
                        prologues = append(prologues, setTextRange(factory.createUnparsedPrologue(section.data), section));
                        break;
                    case "emitHelpers" /* EmitHelpers */:
                        helpers = append(helpers, getAllUnscopedEmitHelpers().get(section.data));
                        break;
                    case "no-default-lib" /* NoDefaultLib */:
                        hasNoDefaultLib = true;
                        break;
                    case "reference" /* Reference */:
                        referencedFiles = append(referencedFiles, { pos: -1, end: -1, fileName: section.data });
                        break;
                    case "type" /* Type */:
                        typeReferenceDirectives = append(typeReferenceDirectives, { pos: -1, end: -1, fileName: section.data });
                        break;
                    case "type-import" /* TypeResolutionModeImport */:
                        typeReferenceDirectives = append(typeReferenceDirectives, { pos: -1, end: -1, fileName: section.data, resolutionMode: 99 /* ESNext */ });
                        break;
                    case "type-require" /* TypeResolutionModeRequire */:
                        typeReferenceDirectives = append(typeReferenceDirectives, { pos: -1, end: -1, fileName: section.data, resolutionMode: 1 /* CommonJS */ });
                        break;
                    case "lib" /* Lib */:
                        libReferenceDirectives = append(libReferenceDirectives, { pos: -1, end: -1, fileName: section.data });
                        break;
                    case "prepend" /* Prepend */:
                        let prependTexts;
                        for (const text of section.texts) {
                            if (!stripInternal || text.kind !== "internal" /* Internal */) {
                                prependTexts = append(prependTexts, setTextRange(factory.createUnparsedTextLike(text.data, text.kind === "internal" /* Internal */), text));
                            }
                        }
                        prependChildren = addRange(prependChildren, prependTexts);
                        texts = append(texts, factory.createUnparsedPrepend(section.data, prependTexts ?? emptyArray));
                        break;
                    case "internal" /* Internal */:
                        if (stripInternal) {
                            if (!texts)
                                texts = [];
                            break;
                        }
                    case "text" /* Text */:
                        texts = append(texts, setTextRange(factory.createUnparsedTextLike(section.data, section.kind === "internal" /* Internal */), section));
                        break;
                    default:
                        Debug.assertNever(section);
                }
            }
            if (!texts) {
                const textNode = factory.createUnparsedTextLike(
                /*data*/
                void 0, 
                /*internal*/
                false);
                setTextRangePosWidth(textNode, 0, typeof length2 === "function" ? length2() : length2);
                texts = [textNode];
            }
            const node = parseNodeFactory.createUnparsedSource(prologues ?? emptyArray, 
            /*syntheticReferences*/
            void 0, texts);
            setEachParent(prologues, node);
            setEachParent(texts, node);
            setEachParent(prependChildren, node);
            node.hasNoDefaultLib = hasNoDefaultLib;
            node.helpers = helpers;
            node.referencedFiles = referencedFiles || emptyArray;
            node.typeReferenceDirectives = typeReferenceDirectives;
            node.libReferenceDirectives = libReferenceDirectives || emptyArray;
            return node;
        }
        function parseOldFileOfCurrentEmit(bundleFileInfo) {
            let texts;
            let syntheticReferences;
            for (const section of bundleFileInfo.sections) {
                switch (section.kind) {
                    case "internal" /* Internal */:
                    case "text" /* Text */:
                        texts = append(texts, setTextRange(factory.createUnparsedTextLike(section.data, section.kind === "internal" /* Internal */), section));
                        break;
                    case "no-default-lib" /* NoDefaultLib */:
                    case "reference" /* Reference */:
                    case "type" /* Type */:
                    case "type-import" /* TypeResolutionModeImport */:
                    case "type-require" /* TypeResolutionModeRequire */:
                    case "lib" /* Lib */:
                        syntheticReferences = append(syntheticReferences, setTextRange(factory.createUnparsedSyntheticReference(section), section));
                        break;
                    case "prologue" /* Prologue */:
                    case "emitHelpers" /* EmitHelpers */:
                    case "prepend" /* Prepend */:
                        break;
                    default:
                        Debug.assertNever(section);
                }
            }
            const node = factory.createUnparsedSource(emptyArray, syntheticReferences, texts ?? emptyArray);
            setEachParent(syntheticReferences, node);
            setEachParent(texts, node);
            node.helpers = map(bundleFileInfo.sources && bundleFileInfo.sources.helpers, (name) => getAllUnscopedEmitHelpers().get(name));
            return node;
        }
        function createInputFiles(javascriptTextOrReadFileText, declarationTextOrJavascriptPath, javascriptMapPath, javascriptMapTextOrDeclarationPath, declarationMapPath, declarationMapTextOrBuildInfoPath) {
            return !isString(javascriptTextOrReadFileText) ? createInputFilesWithFilePaths(javascriptTextOrReadFileText, declarationTextOrJavascriptPath, javascriptMapPath, javascriptMapTextOrDeclarationPath, declarationMapPath, declarationMapTextOrBuildInfoPath) : createInputFilesWithFileTexts(
            /*javascriptPath*/
            void 0, javascriptTextOrReadFileText, javascriptMapPath, javascriptMapTextOrDeclarationPath, 
            /*declarationPath*/
            void 0, declarationTextOrJavascriptPath, declarationMapPath, declarationMapTextOrBuildInfoPath);
        }
        function createInputFilesWithFilePaths(readFileText, javascriptPath, javascriptMapPath, declarationPath, declarationMapPath, buildInfoPath, host, options) {
            const node = parseNodeFactory.createInputFiles();
            node.javascriptPath = javascriptPath;
            node.javascriptMapPath = javascriptMapPath;
            node.declarationPath = declarationPath;
            node.declarationMapPath = declarationMapPath;
            node.buildInfoPath = buildInfoPath;
            const cache = /* @__PURE__ */ new Map();
            const textGetter = (path) => {
                if (path === void 0)
                    return void 0;
                let value = cache.get(path);
                if (value === void 0) {
                    value = readFileText(path);
                    cache.set(path, value !== void 0 ? value : false);
                }
                return value !== false ? value : void 0;
            };
            const definedTextGetter = (path) => {
                const result = textGetter(path);
                return result !== void 0 ? result : `/* Input file ${path} was missing */\r
`;
            };
            let buildInfo;
            const getAndCacheBuildInfo = () => {
                if (buildInfo === void 0 && buildInfoPath) {
                    if (host == null ? void 0 : host.getBuildInfo) {
                        buildInfo = host.getBuildInfo(buildInfoPath, options.configFilePath) ?? false;
                    }
                    else {
                        const result = textGetter(buildInfoPath);
                        buildInfo = result !== void 0 ? getBuildInfo(buildInfoPath, result) ?? false : false;
                    }
                }
                return buildInfo || void 0;
            };
            Object.defineProperties(node, {
                javascriptText: { get: () => definedTextGetter(javascriptPath) },
                javascriptMapText: { get: () => textGetter(javascriptMapPath) },
                // TODO:: if there is inline sourceMap in jsFile, use that
                declarationText: { get: () => definedTextGetter(Debug.checkDefined(declarationPath)) },
                declarationMapText: { get: () => textGetter(declarationMapPath) },
                // TODO:: if there is inline sourceMap in dtsFile, use that
                buildInfo: { get: getAndCacheBuildInfo }
            });
            return node;
        }
        function createInputFilesWithFileTexts(javascriptPath, javascriptText, javascriptMapPath, javascriptMapText, declarationPath, declarationText, declarationMapPath, declarationMapText, buildInfoPath, buildInfo, oldFileOfCurrentEmit) {
            const node = parseNodeFactory.createInputFiles();
            node.javascriptPath = javascriptPath;
            node.javascriptText = javascriptText;
            node.javascriptMapPath = javascriptMapPath;
            node.javascriptMapText = javascriptMapText;
            node.declarationPath = declarationPath;
            node.declarationText = declarationText;
            node.declarationMapPath = declarationMapPath;
            node.declarationMapText = declarationMapText;
            node.buildInfoPath = buildInfoPath;
            node.buildInfo = buildInfo;
            node.oldFileOfCurrentEmit = oldFileOfCurrentEmit;
            return node;
        }
        function createSourceMapSource(fileName, text, skipTrivia2) {
            return new (SourceMapSource2 || (SourceMapSource2 = objectAllocator.getSourceMapSourceConstructor()))(fileName, text, skipTrivia2);
        }
        function setOriginalNode(node, original) {
            if (node.original !== original) {
                node.original = original;
                if (original) {
                    const emitNode = original.emitNode;
                    if (emitNode)
                        node.emitNode = mergeEmitNode(emitNode, node.emitNode);
                }
            }
            return node;
        }
        function mergeEmitNode(sourceEmitNode, destEmitNode) {
            const { flags, internalFlags, leadingComments, trailingComments, commentRange, sourceMapRange, tokenSourceMapRanges, constantValue, helpers, startsOnNewLine, snippetElement, classThis, assignedName } = sourceEmitNode;
            if (!destEmitNode)
                destEmitNode = {};
            if (flags) {
                destEmitNode.flags = flags;
            }
            if (internalFlags) {
                destEmitNode.internalFlags = internalFlags & ~8 /* Immutable */;
            }
            if (leadingComments) {
                destEmitNode.leadingComments = addRange(leadingComments.slice(), destEmitNode.leadingComments);
            }
            if (trailingComments) {
                destEmitNode.trailingComments = addRange(trailingComments.slice(), destEmitNode.trailingComments);
            }
            if (commentRange) {
                destEmitNode.commentRange = commentRange;
            }
            if (sourceMapRange) {
                destEmitNode.sourceMapRange = sourceMapRange;
            }
            if (tokenSourceMapRanges) {
                destEmitNode.tokenSourceMapRanges = mergeTokenSourceMapRanges(tokenSourceMapRanges, destEmitNode.tokenSourceMapRanges);
            }
            if (constantValue !== void 0) {
                destEmitNode.constantValue = constantValue;
            }
            if (helpers) {
                for (const helper of helpers) {
                    destEmitNode.helpers = appendIfUnique(destEmitNode.helpers, helper);
                }
            }
            if (startsOnNewLine !== void 0) {
                destEmitNode.startsOnNewLine = startsOnNewLine;
            }
            if (snippetElement !== void 0) {
                destEmitNode.snippetElement = snippetElement;
            }
            if (classThis) {
                destEmitNode.classThis = classThis;
            }
            if (assignedName) {
                destEmitNode.assignedName = assignedName;
            }
            return destEmitNode;
        }
        function mergeTokenSourceMapRanges(sourceRanges, destRanges) {
            if (!destRanges)
                destRanges = [];
            for (const key in sourceRanges) {
                destRanges[key] = sourceRanges[key];
            }
            return destRanges;
        }
        var nextAutoGenerateId, NodeFactoryFlags, nodeFactoryPatchers, rawTextScanner, invalidValueSentinel, baseFactory, syntheticFactory, factory, SourceMapSource2;
        var init_nodeFactory = __esm({
            "src/compiler/factory/nodeFactory.ts"() {
                "use strict";
                init_ts2();
                nextAutoGenerateId = 0;
                NodeFactoryFlags = /* @__PURE__ */ ((NodeFactoryFlags2) => {
                    NodeFactoryFlags2[NodeFactoryFlags2["None"] = 0] = "None";
                    NodeFactoryFlags2[NodeFactoryFlags2["NoParenthesizerRules"] = 1] = "NoParenthesizerRules";
                    NodeFactoryFlags2[NodeFactoryFlags2["NoNodeConverters"] = 2] = "NoNodeConverters";
                    NodeFactoryFlags2[NodeFactoryFlags2["NoIndentationOnFreshPropertyAccess"] = 4] = "NoIndentationOnFreshPropertyAccess";
                    NodeFactoryFlags2[NodeFactoryFlags2["NoOriginalNode"] = 8] = "NoOriginalNode";
                    return NodeFactoryFlags2;
                })(NodeFactoryFlags || {});
                nodeFactoryPatchers = [];
                invalidValueSentinel = {};
                baseFactory = createBaseNodeFactory();
                syntheticFactory = {
                    createBaseSourceFileNode: (kind) => makeSynthetic(baseFactory.createBaseSourceFileNode(kind)),
                    createBaseIdentifierNode: (kind) => makeSynthetic(baseFactory.createBaseIdentifierNode(kind)),
                    createBasePrivateIdentifierNode: (kind) => makeSynthetic(baseFactory.createBasePrivateIdentifierNode(kind)),
                    createBaseTokenNode: (kind) => makeSynthetic(baseFactory.createBaseTokenNode(kind)),
                    createBaseNode: (kind) => makeSynthetic(baseFactory.createBaseNode(kind))
                };
                factory = createNodeFactory(4 /* NoIndentationOnFreshPropertyAccess */, syntheticFactory);
            }
        });
        // src/compiler/factory/emitNode.ts
        function getOrCreateEmitNode(node) {
            if (!node.emitNode) {
                if (isParseTreeNode(node)) {
                    if (node.kind === 312 /* SourceFile */) {
                        return node.emitNode = { annotatedNodes: [node] };
                    }
                    const sourceFile = getSourceFileOfNode(getParseTreeNode(getSourceFileOfNode(node))) ?? Debug.fail("Could not determine parsed source file.");
                    getOrCreateEmitNode(sourceFile).annotatedNodes.push(node);
                }
                node.emitNode = {};
            }
            else {
                Debug.assert(!(node.emitNode.internalFlags & 8 /* Immutable */), "Invalid attempt to mutate an immutable node.");
            }
            return node.emitNode;
        }
        function disposeEmitNodes(sourceFile) {
            var _a, _b;
            const annotatedNodes = (_b = (_a = getSourceFileOfNode(getParseTreeNode(sourceFile))) == null ? void 0 : _a.emitNode) == null ? void 0 : _b.annotatedNodes;
            if (annotatedNodes) {
                for (const node of annotatedNodes) {
                    node.emitNode = void 0;
                }
            }
        }
        function removeAllComments(node) {
            const emitNode = getOrCreateEmitNode(node);
            emitNode.flags |= 3072 /* NoComments */;
            emitNode.leadingComments = void 0;
            emitNode.trailingComments = void 0;
            return node;
        }
        function setEmitFlags(node, emitFlags) {
            getOrCreateEmitNode(node).flags = emitFlags;
            return node;
        }
        function addEmitFlags(node, emitFlags) {
            const emitNode = getOrCreateEmitNode(node);
            emitNode.flags = emitNode.flags | emitFlags;
            return node;
        }
        function setInternalEmitFlags(node, emitFlags) {
            getOrCreateEmitNode(node).internalFlags = emitFlags;
            return node;
        }
        function addInternalEmitFlags(node, emitFlags) {
            const emitNode = getOrCreateEmitNode(node);
            emitNode.internalFlags = emitNode.internalFlags | emitFlags;
            return node;
        }
        function getSourceMapRange(node) {
            var _a;
            return ((_a = node.emitNode) == null ? void 0 : _a.sourceMapRange) ?? node;
        }
        function setSourceMapRange(node, range) {
            getOrCreateEmitNode(node).sourceMapRange = range;
            return node;
        }
        function getTokenSourceMapRange(node, token) {
            var _a, _b;
            return (_b = (_a = node.emitNode) == null ? void 0 : _a.tokenSourceMapRanges) == null ? void 0 : _b[token];
        }
        function setTokenSourceMapRange(node, token, range) {
            const emitNode = getOrCreateEmitNode(node);
            const tokenSourceMapRanges = emitNode.tokenSourceMapRanges ?? (emitNode.tokenSourceMapRanges = []);
            tokenSourceMapRanges[token] = range;
            return node;
        }
        function getStartsOnNewLine(node) {
            var _a;
            return (_a = node.emitNode) == null ? void 0 : _a.startsOnNewLine;
        }
        function setStartsOnNewLine(node, newLine) {
            getOrCreateEmitNode(node).startsOnNewLine = newLine;
            return node;
        }
        function getCommentRange(node) {
            var _a;
            return ((_a = node.emitNode) == null ? void 0 : _a.commentRange) ?? node;
        }
        function setCommentRange(node, range) {
            getOrCreateEmitNode(node).commentRange = range;
            return node;
        }
        function getSyntheticLeadingComments(node) {
            var _a;
            return (_a = node.emitNode) == null ? void 0 : _a.leadingComments;
        }
        function setSyntheticLeadingComments(node, comments) {
            getOrCreateEmitNode(node).leadingComments = comments;
            return node;
        }
        function addSyntheticLeadingComment(node, kind, text, hasTrailingNewLine) {
            return setSyntheticLeadingComments(node, append(getSyntheticLeadingComments(node), { kind, pos: -1, end: -1, hasTrailingNewLine, text }));
        }
        function getSyntheticTrailingComments(node) {
            var _a;
            return (_a = node.emitNode) == null ? void 0 : _a.trailingComments;
        }
        function setSyntheticTrailingComments(node, comments) {
            getOrCreateEmitNode(node).trailingComments = comments;
            return node;
        }
        function addSyntheticTrailingComment(node, kind, text, hasTrailingNewLine) {
            return setSyntheticTrailingComments(node, append(getSyntheticTrailingComments(node), { kind, pos: -1, end: -1, hasTrailingNewLine, text }));
        }
        function moveSyntheticComments(node, original) {
            setSyntheticLeadingComments(node, getSyntheticLeadingComments(original));
            setSyntheticTrailingComments(node, getSyntheticTrailingComments(original));
            const emit = getOrCreateEmitNode(original);
            emit.leadingComments = void 0;
            emit.trailingComments = void 0;
            return node;
        }
        function getConstantValue(node) {
            var _a;
            return (_a = node.emitNode) == null ? void 0 : _a.constantValue;
        }
        function setConstantValue(node, value) {
            const emitNode = getOrCreateEmitNode(node);
            emitNode.constantValue = value;
            return node;
        }
        function addEmitHelper(node, helper) {
            const emitNode = getOrCreateEmitNode(node);
            emitNode.helpers = append(emitNode.helpers, helper);
            return node;
        }
        function addEmitHelpers(node, helpers) {
            if (some(helpers)) {
                const emitNode = getOrCreateEmitNode(node);
                for (const helper of helpers) {
                    emitNode.helpers = appendIfUnique(emitNode.helpers, helper);
                }
            }
            return node;
        }
        function removeEmitHelper(node, helper) {
            var _a;
            const helpers = (_a = node.emitNode) == null ? void 0 : _a.helpers;
            if (helpers) {
                return orderedRemoveItem(helpers, helper);
            }
            return false;
        }
        function getEmitHelpers(node) {
            var _a;
            return (_a = node.emitNode) == null ? void 0 : _a.helpers;
        }
        function moveEmitHelpers(source, target, predicate) {
            const sourceEmitNode = source.emitNode;
            const sourceEmitHelpers = sourceEmitNode && sourceEmitNode.helpers;
            if (!some(sourceEmitHelpers))
                return;
            const targetEmitNode = getOrCreateEmitNode(target);
            let helpersRemoved = 0;
            for (let i = 0; i < sourceEmitHelpers.length; i++) {
                const helper = sourceEmitHelpers[i];
                if (predicate(helper)) {
                    helpersRemoved++;
                    targetEmitNode.helpers = appendIfUnique(targetEmitNode.helpers, helper);
                }
                else if (helpersRemoved > 0) {
                    sourceEmitHelpers[i - helpersRemoved] = helper;
                }
            }
            if (helpersRemoved > 0) {
                sourceEmitHelpers.length -= helpersRemoved;
            }
        }
        function getSnippetElement(node) {
            var _a;
            return (_a = node.emitNode) == null ? void 0 : _a.snippetElement;
        }
        function setSnippetElement(node, snippet) {
            const emitNode = getOrCreateEmitNode(node);
            emitNode.snippetElement = snippet;
            return node;
        }
        function ignoreSourceNewlines(node) {
            getOrCreateEmitNode(node).internalFlags |= 4 /* IgnoreSourceNewlines */;
            return node;
        }
        function setTypeNode(node, type) {
            const emitNode = getOrCreateEmitNode(node);
            emitNode.typeNode = type;
            return node;
        }
        function getTypeNode(node) {
            var _a;
            return (_a = node.emitNode) == null ? void 0 : _a.typeNode;
        }
        function setIdentifierTypeArguments(node, typeArguments) {
            getOrCreateEmitNode(node).identifierTypeArguments = typeArguments;
            return node;
        }
        function getIdentifierTypeArguments(node) {
            var _a;
            return (_a = node.emitNode) == null ? void 0 : _a.identifierTypeArguments;
        }
        function setIdentifierAutoGenerate(node, autoGenerate) {
            getOrCreateEmitNode(node).autoGenerate = autoGenerate;
            return node;
        }
        function getIdentifierAutoGenerate(node) {
            var _a;
            return (_a = node.emitNode) == null ? void 0 : _a.autoGenerate;
        }
        function setIdentifierGeneratedImportReference(node, value) {
            getOrCreateEmitNode(node).generatedImportReference = value;
            return node;
        }
        function getIdentifierGeneratedImportReference(node) {
            var _a;
            return (_a = node.emitNode) == null ? void 0 : _a.generatedImportReference;
        }
        var init_emitNode = __esm({
            "src/compiler/factory/emitNode.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/factory/emitHelpers.ts
        function createEmitHelperFactory(context) {
            const factory2 = context.factory;
            const immutableTrue = memoize(() => setInternalEmitFlags(factory2.createTrue(), 8 /* Immutable */));
            const immutableFalse = memoize(() => setInternalEmitFlags(factory2.createFalse(), 8 /* Immutable */));
            return {
                getUnscopedHelperName,
                // TypeScript Helpers
                createDecorateHelper,
                createMetadataHelper,
                createParamHelper,
                // ES Decorators Helpers
                createESDecorateHelper,
                createRunInitializersHelper,
                // ES2018 Helpers
                createAssignHelper,
                createAwaitHelper,
                createAsyncGeneratorHelper,
                createAsyncDelegatorHelper,
                createAsyncValuesHelper,
                // ES2018 Destructuring Helpers
                createRestHelper,
                // ES2017 Helpers
                createAwaiterHelper,
                // ES2015 Helpers
                createExtendsHelper,
                createTemplateObjectHelper,
                createSpreadArrayHelper,
                createPropKeyHelper,
                createSetFunctionNameHelper,
                // ES2015 Destructuring Helpers
                createValuesHelper,
                createReadHelper,
                // ES2015 Generator Helpers
                createGeneratorHelper,
                // ES Module Helpers
                createCreateBindingHelper,
                createImportStarHelper,
                createImportStarCallbackHelper,
                createImportDefaultHelper,
                createExportStarHelper,
                // Class Fields Helpers
                createClassPrivateFieldGetHelper,
                createClassPrivateFieldSetHelper,
                createClassPrivateFieldInHelper,
                // 'using' helpers
                createAddDisposableResourceHelper,
                createDisposeResourcesHelper
            };
            function getUnscopedHelperName(name) {
                return setEmitFlags(factory2.createIdentifier(name), 8192 /* HelperName */ | 4 /* AdviseOnEmitNode */);
            }
            function createDecorateHelper(decoratorExpressions, target, memberName, descriptor) {
                context.requestEmitHelper(decorateHelper);
                const argumentsArray = [];
                argumentsArray.push(factory2.createArrayLiteralExpression(decoratorExpressions, 
                /*multiLine*/
                true));
                argumentsArray.push(target);
                if (memberName) {
                    argumentsArray.push(memberName);
                    if (descriptor) {
                        argumentsArray.push(descriptor);
                    }
                }
                return factory2.createCallExpression(getUnscopedHelperName("__decorate"), 
                /*typeArguments*/
                void 0, argumentsArray);
            }
            function createMetadataHelper(metadataKey, metadataValue) {
                context.requestEmitHelper(metadataHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__metadata"), 
                /*typeArguments*/
                void 0, [
                    factory2.createStringLiteral(metadataKey),
                    metadataValue
                ]);
            }
            function createParamHelper(expression, parameterOffset, location) {
                context.requestEmitHelper(paramHelper);
                return setTextRange(factory2.createCallExpression(getUnscopedHelperName("__param"), 
                /*typeArguments*/
                void 0, [
                    factory2.createNumericLiteral(parameterOffset + ""),
                    expression
                ]), location);
            }
            function createESDecorateClassContextObject(contextIn) {
                const properties = [
                    factory2.createPropertyAssignment(factory2.createIdentifier("kind"), factory2.createStringLiteral("class")),
                    factory2.createPropertyAssignment(factory2.createIdentifier("name"), contextIn.name),
                    factory2.createPropertyAssignment(factory2.createIdentifier("metadata"), contextIn.metadata)
                ];
                return factory2.createObjectLiteralExpression(properties);
            }
            function createESDecorateClassElementAccessGetMethod(elementName) {
                const accessor = elementName.computed ? factory2.createElementAccessExpression(factory2.createIdentifier("obj"), elementName.name) : factory2.createPropertyAccessExpression(factory2.createIdentifier("obj"), elementName.name);
                return factory2.createPropertyAssignment("get", factory2.createArrowFunction(
                /*modifiers*/
                void 0, 
                /*typeParameters*/
                void 0, [factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, factory2.createIdentifier("obj"))], 
                /*type*/
                void 0, 
                /*equalsGreaterThanToken*/
                void 0, accessor));
            }
            function createESDecorateClassElementAccessSetMethod(elementName) {
                const accessor = elementName.computed ? factory2.createElementAccessExpression(factory2.createIdentifier("obj"), elementName.name) : factory2.createPropertyAccessExpression(factory2.createIdentifier("obj"), elementName.name);
                return factory2.createPropertyAssignment("set", factory2.createArrowFunction(
                /*modifiers*/
                void 0, 
                /*typeParameters*/
                void 0, [
                    factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, factory2.createIdentifier("obj")),
                    factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, factory2.createIdentifier("value"))
                ], 
                /*type*/
                void 0, 
                /*equalsGreaterThanToken*/
                void 0, factory2.createBlock([
                    factory2.createExpressionStatement(factory2.createAssignment(accessor, factory2.createIdentifier("value")))
                ])));
            }
            function createESDecorateClassElementAccessHasMethod(elementName) {
                const propertyName = elementName.computed ? elementName.name : isIdentifier(elementName.name) ? factory2.createStringLiteralFromNode(elementName.name) : elementName.name;
                return factory2.createPropertyAssignment("has", factory2.createArrowFunction(
                /*modifiers*/
                void 0, 
                /*typeParameters*/
                void 0, [factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, factory2.createIdentifier("obj"))], 
                /*type*/
                void 0, 
                /*equalsGreaterThanToken*/
                void 0, factory2.createBinaryExpression(propertyName, 103 /* InKeyword */, factory2.createIdentifier("obj"))));
            }
            function createESDecorateClassElementAccessObject(name, access) {
                const properties = [];
                properties.push(createESDecorateClassElementAccessHasMethod(name));
                if (access.get)
                    properties.push(createESDecorateClassElementAccessGetMethod(name));
                if (access.set)
                    properties.push(createESDecorateClassElementAccessSetMethod(name));
                return factory2.createObjectLiteralExpression(properties);
            }
            function createESDecorateClassElementContextObject(contextIn) {
                const properties = [
                    factory2.createPropertyAssignment(factory2.createIdentifier("kind"), factory2.createStringLiteral(contextIn.kind)),
                    factory2.createPropertyAssignment(factory2.createIdentifier("name"), contextIn.name.computed ? contextIn.name.name : factory2.createStringLiteralFromNode(contextIn.name.name)),
                    factory2.createPropertyAssignment(factory2.createIdentifier("static"), contextIn.static ? factory2.createTrue() : factory2.createFalse()),
                    factory2.createPropertyAssignment(factory2.createIdentifier("private"), contextIn.private ? factory2.createTrue() : factory2.createFalse()),
                    factory2.createPropertyAssignment(factory2.createIdentifier("access"), createESDecorateClassElementAccessObject(contextIn.name, contextIn.access)),
                    factory2.createPropertyAssignment(factory2.createIdentifier("metadata"), contextIn.metadata)
                ];
                return factory2.createObjectLiteralExpression(properties);
            }
            function createESDecorateContextObject(contextIn) {
                return contextIn.kind === "class" ? createESDecorateClassContextObject(contextIn) : createESDecorateClassElementContextObject(contextIn);
            }
            function createESDecorateHelper(ctor, descriptorIn, decorators, contextIn, initializers, extraInitializers) {
                context.requestEmitHelper(esDecorateHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__esDecorate"), 
                /*typeArguments*/
                void 0, [
                    ctor ?? factory2.createNull(),
                    descriptorIn ?? factory2.createNull(),
                    decorators,
                    createESDecorateContextObject(contextIn),
                    initializers,
                    extraInitializers
                ]);
            }
            function createRunInitializersHelper(thisArg, initializers, value) {
                context.requestEmitHelper(runInitializersHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__runInitializers"), 
                /*typeArguments*/
                void 0, value ? [thisArg, initializers, value] : [thisArg, initializers]);
            }
            function createAssignHelper(attributesSegments) {
                if (getEmitScriptTarget(context.getCompilerOptions()) >= 2 /* ES2015 */) {
                    return factory2.createCallExpression(factory2.createPropertyAccessExpression(factory2.createIdentifier("Object"), "assign"), 
                    /*typeArguments*/
                    void 0, attributesSegments);
                }
                context.requestEmitHelper(assignHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__assign"), 
                /*typeArguments*/
                void 0, attributesSegments);
            }
            function createAwaitHelper(expression) {
                context.requestEmitHelper(awaitHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__await"), 
                /*typeArguments*/
                void 0, [expression]);
            }
            function createAsyncGeneratorHelper(generatorFunc, hasLexicalThis) {
                context.requestEmitHelper(awaitHelper);
                context.requestEmitHelper(asyncGeneratorHelper);
                (generatorFunc.emitNode || (generatorFunc.emitNode = {})).flags |= 524288 /* AsyncFunctionBody */ | 1048576 /* ReuseTempVariableScope */;
                return factory2.createCallExpression(getUnscopedHelperName("__asyncGenerator"), 
                /*typeArguments*/
                void 0, [
                    hasLexicalThis ? factory2.createThis() : factory2.createVoidZero(),
                    factory2.createIdentifier("arguments"),
                    generatorFunc
                ]);
            }
            function createAsyncDelegatorHelper(expression) {
                context.requestEmitHelper(awaitHelper);
                context.requestEmitHelper(asyncDelegator);
                return factory2.createCallExpression(getUnscopedHelperName("__asyncDelegator"), 
                /*typeArguments*/
                void 0, [expression]);
            }
            function createAsyncValuesHelper(expression) {
                context.requestEmitHelper(asyncValues);
                return factory2.createCallExpression(getUnscopedHelperName("__asyncValues"), 
                /*typeArguments*/
                void 0, [expression]);
            }
            function createRestHelper(value, elements, computedTempVariables, location) {
                context.requestEmitHelper(restHelper);
                const propertyNames = [];
                let computedTempVariableOffset = 0;
                for (let i = 0; i < elements.length - 1; i++) {
                    const propertyName = getPropertyNameOfBindingOrAssignmentElement(elements[i]);
                    if (propertyName) {
                        if (isComputedPropertyName(propertyName)) {
                            Debug.assertIsDefined(computedTempVariables, "Encountered computed property name but 'computedTempVariables' argument was not provided.");
                            const temp = computedTempVariables[computedTempVariableOffset];
                            computedTempVariableOffset++;
                            propertyNames.push(factory2.createConditionalExpression(factory2.createTypeCheck(temp, "symbol"), 
                            /*questionToken*/
                            void 0, temp, 
                            /*colonToken*/
                            void 0, factory2.createAdd(temp, factory2.createStringLiteral(""))));
                        }
                        else {
                            propertyNames.push(factory2.createStringLiteralFromNode(propertyName));
                        }
                    }
                }
                return factory2.createCallExpression(getUnscopedHelperName("__rest"), 
                /*typeArguments*/
                void 0, [
                    value,
                    setTextRange(factory2.createArrayLiteralExpression(propertyNames), location)
                ]);
            }
            function createAwaiterHelper(hasLexicalThis, argumentsExpression, promiseConstructor, parameters, body) {
                context.requestEmitHelper(awaiterHelper);
                const generatorFunc = factory2.createFunctionExpression(
                /*modifiers*/
                void 0, factory2.createToken(42 /* AsteriskToken */), 
                /*name*/
                void 0, 
                /*typeParameters*/
                void 0, parameters ?? [], 
                /*type*/
                void 0, body);
                (generatorFunc.emitNode || (generatorFunc.emitNode = {})).flags |= 524288 /* AsyncFunctionBody */ | 1048576 /* ReuseTempVariableScope */;
                return factory2.createCallExpression(getUnscopedHelperName("__awaiter"), 
                /*typeArguments*/
                void 0, [
                    hasLexicalThis ? factory2.createThis() : factory2.createVoidZero(),
                    argumentsExpression ?? factory2.createVoidZero(),
                    promiseConstructor ? createExpressionFromEntityName(factory2, promiseConstructor) : factory2.createVoidZero(),
                    generatorFunc
                ]);
            }
            function createExtendsHelper(name) {
                context.requestEmitHelper(extendsHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__extends"), 
                /*typeArguments*/
                void 0, [name, factory2.createUniqueName("_super", 16 /* Optimistic */ | 32 /* FileLevel */)]);
            }
            function createTemplateObjectHelper(cooked, raw) {
                context.requestEmitHelper(templateObjectHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__makeTemplateObject"), 
                /*typeArguments*/
                void 0, [cooked, raw]);
            }
            function createSpreadArrayHelper(to, from, packFrom) {
                context.requestEmitHelper(spreadArrayHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__spreadArray"), 
                /*typeArguments*/
                void 0, [to, from, packFrom ? immutableTrue() : immutableFalse()]);
            }
            function createPropKeyHelper(expr) {
                context.requestEmitHelper(propKeyHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__propKey"), 
                /*typeArguments*/
                void 0, [expr]);
            }
            function createSetFunctionNameHelper(f, name, prefix) {
                context.requestEmitHelper(setFunctionNameHelper);
                return context.factory.createCallExpression(getUnscopedHelperName("__setFunctionName"), 
                /*typeArguments*/
                void 0, prefix ? [f, name, context.factory.createStringLiteral(prefix)] : [f, name]);
            }
            function createValuesHelper(expression) {
                context.requestEmitHelper(valuesHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__values"), 
                /*typeArguments*/
                void 0, [expression]);
            }
            function createReadHelper(iteratorRecord, count) {
                context.requestEmitHelper(readHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__read"), 
                /*typeArguments*/
                void 0, count !== void 0 ? [iteratorRecord, factory2.createNumericLiteral(count + "")] : [iteratorRecord]);
            }
            function createGeneratorHelper(body) {
                context.requestEmitHelper(generatorHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__generator"), 
                /*typeArguments*/
                void 0, [factory2.createThis(), body]);
            }
            function createCreateBindingHelper(module2, inputName, outputName) {
                context.requestEmitHelper(createBindingHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__createBinding"), 
                /*typeArguments*/
                void 0, [factory2.createIdentifier("exports"), module2, inputName, ...outputName ? [outputName] : []]);
            }
            function createImportStarHelper(expression) {
                context.requestEmitHelper(importStarHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__importStar"), 
                /*typeArguments*/
                void 0, [expression]);
            }
            function createImportStarCallbackHelper() {
                context.requestEmitHelper(importStarHelper);
                return getUnscopedHelperName("__importStar");
            }
            function createImportDefaultHelper(expression) {
                context.requestEmitHelper(importDefaultHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__importDefault"), 
                /*typeArguments*/
                void 0, [expression]);
            }
            function createExportStarHelper(moduleExpression, exportsExpression = factory2.createIdentifier("exports")) {
                context.requestEmitHelper(exportStarHelper);
                context.requestEmitHelper(createBindingHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__exportStar"), 
                /*typeArguments*/
                void 0, [moduleExpression, exportsExpression]);
            }
            function createClassPrivateFieldGetHelper(receiver, state, kind, f) {
                context.requestEmitHelper(classPrivateFieldGetHelper);
                let args;
                if (!f) {
                    args = [receiver, state, factory2.createStringLiteral(kind)];
                }
                else {
                    args = [receiver, state, factory2.createStringLiteral(kind), f];
                }
                return factory2.createCallExpression(getUnscopedHelperName("__classPrivateFieldGet"), 
                /*typeArguments*/
                void 0, args);
            }
            function createClassPrivateFieldSetHelper(receiver, state, value, kind, f) {
                context.requestEmitHelper(classPrivateFieldSetHelper);
                let args;
                if (!f) {
                    args = [receiver, state, value, factory2.createStringLiteral(kind)];
                }
                else {
                    args = [receiver, state, value, factory2.createStringLiteral(kind), f];
                }
                return factory2.createCallExpression(getUnscopedHelperName("__classPrivateFieldSet"), 
                /*typeArguments*/
                void 0, args);
            }
            function createClassPrivateFieldInHelper(state, receiver) {
                context.requestEmitHelper(classPrivateFieldInHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__classPrivateFieldIn"), 
                /*typeArguments*/
                void 0, [state, receiver]);
            }
            function createAddDisposableResourceHelper(envBinding, value, async) {
                context.requestEmitHelper(addDisposableResourceHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__addDisposableResource"), 
                /*typeArguments*/
                void 0, [envBinding, value, async ? factory2.createTrue() : factory2.createFalse()]);
            }
            function createDisposeResourcesHelper(envBinding) {
                context.requestEmitHelper(disposeResourcesHelper);
                return factory2.createCallExpression(getUnscopedHelperName("__disposeResources"), 
                /*typeArguments*/
                void 0, [envBinding]);
            }
        }
        function compareEmitHelpers(x, y) {
            if (x === y)
                return 0 /* EqualTo */;
            if (x.priority === y.priority)
                return 0 /* EqualTo */;
            if (x.priority === void 0)
                return 1 /* GreaterThan */;
            if (y.priority === void 0)
                return -1 /* LessThan */;
            return compareValues(x.priority, y.priority);
        }
        function helperString(input, ...args) {
            return (uniqueName) => {
                let result = "";
                for (let i = 0; i < args.length; i++) {
                    result += input[i];
                    result += uniqueName(args[i]);
                }
                result += input[input.length - 1];
                return result;
            };
        }
        function getAllUnscopedEmitHelpers() {
            return allUnscopedEmitHelpers || (allUnscopedEmitHelpers = arrayToMap([
                decorateHelper,
                metadataHelper,
                paramHelper,
                esDecorateHelper,
                runInitializersHelper,
                assignHelper,
                awaitHelper,
                asyncGeneratorHelper,
                asyncDelegator,
                asyncValues,
                restHelper,
                awaiterHelper,
                extendsHelper,
                templateObjectHelper,
                spreadArrayHelper,
                valuesHelper,
                readHelper,
                propKeyHelper,
                setFunctionNameHelper,
                generatorHelper,
                importStarHelper,
                importDefaultHelper,
                exportStarHelper,
                classPrivateFieldGetHelper,
                classPrivateFieldSetHelper,
                classPrivateFieldInHelper,
                createBindingHelper,
                setModuleDefaultHelper,
                addDisposableResourceHelper,
                disposeResourcesHelper
            ], (helper) => helper.name));
        }
        function isCallToHelper(firstSegment, helperName) {
            return isCallExpression(firstSegment) && isIdentifier(firstSegment.expression) && (getEmitFlags(firstSegment.expression) & 8192 /* HelperName */) !== 0 && firstSegment.expression.escapedText === helperName;
        }
        var PrivateIdentifierKind, decorateHelper, metadataHelper, paramHelper, esDecorateHelper, runInitializersHelper, assignHelper, awaitHelper, asyncGeneratorHelper, asyncDelegator, asyncValues, restHelper, awaiterHelper, extendsHelper, templateObjectHelper, readHelper, spreadArrayHelper, propKeyHelper, setFunctionNameHelper, valuesHelper, generatorHelper, createBindingHelper, setModuleDefaultHelper, importStarHelper, importDefaultHelper, exportStarHelper, classPrivateFieldGetHelper, classPrivateFieldSetHelper, classPrivateFieldInHelper, addDisposableResourceHelper, disposeResourcesHelper, allUnscopedEmitHelpers, asyncSuperHelper, advancedAsyncSuperHelper;
        var init_emitHelpers = __esm({
            "src/compiler/factory/emitHelpers.ts"() {
                "use strict";
                init_ts2();
                PrivateIdentifierKind = /* @__PURE__ */ ((PrivateIdentifierKind2) => {
                    PrivateIdentifierKind2["Field"] = "f";
                    PrivateIdentifierKind2["Method"] = "m";
                    PrivateIdentifierKind2["Accessor"] = "a";
                    return PrivateIdentifierKind2;
                })(PrivateIdentifierKind || {});
                decorateHelper = {
                    name: "typescript:decorate",
                    importName: "__decorate",
                    scoped: false,
                    priority: 2,
                    text: `
            var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
                var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
                if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
                else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
                return c > 3 && r && Object.defineProperty(target, key, r), r;
            };`
                };
                metadataHelper = {
                    name: "typescript:metadata",
                    importName: "__metadata",
                    scoped: false,
                    priority: 3,
                    text: `
            var __metadata = (this && this.__metadata) || function (k, v) {
                if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
            };`
                };
                paramHelper = {
                    name: "typescript:param",
                    importName: "__param",
                    scoped: false,
                    priority: 4,
                    text: `
            var __param = (this && this.__param) || function (paramIndex, decorator) {
                return function (target, key) { decorator(target, key, paramIndex); }
            };`
                };
                esDecorateHelper = {
                    name: "typescript:esDecorate",
                    importName: "__esDecorate",
                    scoped: false,
                    priority: 2,
                    text: `
        var __esDecorate = (this && this.__esDecorate) || function (ctor, descriptorIn, decorators, contextIn, initializers, extraInitializers) {
            function accept(f) { if (f !== void 0 && typeof f !== "function") throw new TypeError("Function expected"); return f; }
            var kind = contextIn.kind, key = kind === "getter" ? "get" : kind === "setter" ? "set" : "value";
            var target = !descriptorIn && ctor ? contextIn["static"] ? ctor : ctor.prototype : null;
            var descriptor = descriptorIn || (target ? Object.getOwnPropertyDescriptor(target, contextIn.name) : {});
            var _, done = false;
            for (var i = decorators.length - 1; i >= 0; i--) {
                var context = {};
                for (var p in contextIn) context[p] = p === "access" ? {} : contextIn[p];
                for (var p in contextIn.access) context.access[p] = contextIn.access[p];
                context.addInitializer = function (f) { if (done) throw new TypeError("Cannot add initializers after decoration has completed"); extraInitializers.push(accept(f || null)); };
                var result = (0, decorators[i])(kind === "accessor" ? { get: descriptor.get, set: descriptor.set } : descriptor[key], context);
                if (kind === "accessor") {
                    if (result === void 0) continue;
                    if (result === null || typeof result !== "object") throw new TypeError("Object expected");
                    if (_ = accept(result.get)) descriptor.get = _;
                    if (_ = accept(result.set)) descriptor.set = _;
                    if (_ = accept(result.init)) initializers.unshift(_);
                }
                else if (_ = accept(result)) {
                    if (kind === "field") initializers.unshift(_);
                    else descriptor[key] = _;
                }
            }
            if (target) Object.defineProperty(target, contextIn.name, descriptor);
            done = true;
        };`
                };
                runInitializersHelper = {
                    name: "typescript:runInitializers",
                    importName: "__runInitializers",
                    scoped: false,
                    priority: 2,
                    text: `
        var __runInitializers = (this && this.__runInitializers) || function (thisArg, initializers, value) {
            var useValue = arguments.length > 2;
            for (var i = 0; i < initializers.length; i++) {
                value = useValue ? initializers[i].call(thisArg, value) : initializers[i].call(thisArg);
            }
            return useValue ? value : void 0;
        };`
                };
                assignHelper = {
                    name: "typescript:assign",
                    importName: "__assign",
                    scoped: false,
                    priority: 1,
                    text: `
            var __assign = (this && this.__assign) || function () {
                __assign = Object.assign || function(t) {
                    for (var s, i = 1, n = arguments.length; i < n; i++) {
                        s = arguments[i];
                        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                            t[p] = s[p];
                    }
                    return t;
                };
                return __assign.apply(this, arguments);
            };`
                };
                awaitHelper = {
                    name: "typescript:await",
                    importName: "__await",
                    scoped: false,
                    text: `
            var __await = (this && this.__await) || function (v) { return this instanceof __await ? (this.v = v, this) : new __await(v); }`
                };
                asyncGeneratorHelper = {
                    name: "typescript:asyncGenerator",
                    importName: "__asyncGenerator",
                    scoped: false,
                    dependencies: [awaitHelper],
                    text: `
        var __asyncGenerator = (this && this.__asyncGenerator) || function (thisArg, _arguments, generator) {
            if (!Symbol.asyncIterator) throw new TypeError("Symbol.asyncIterator is not defined.");
            var g = generator.apply(thisArg, _arguments || []), i, q = [];
            return i = {}, verb("next"), verb("throw"), verb("return", awaitReturn), i[Symbol.asyncIterator] = function () { return this; }, i;
            function awaitReturn(f) { return function (v) { return Promise.resolve(v).then(f, reject); }; }
            function verb(n, f) { if (g[n]) { i[n] = function (v) { return new Promise(function (a, b) { q.push([n, v, a, b]) > 1 || resume(n, v); }); }; if (f) i[n] = f(i[n]); } }
            function resume(n, v) { try { step(g[n](v)); } catch (e) { settle(q[0][3], e); } }
            function step(r) { r.value instanceof __await ? Promise.resolve(r.value.v).then(fulfill, reject) : settle(q[0][2], r); }
            function fulfill(value) { resume("next", value); }
            function reject(value) { resume("throw", value); }
            function settle(f, v) { if (f(v), q.shift(), q.length) resume(q[0][0], q[0][1]); }
        };`
                };
                asyncDelegator = {
                    name: "typescript:asyncDelegator",
                    importName: "__asyncDelegator",
                    scoped: false,
                    dependencies: [awaitHelper],
                    text: `
            var __asyncDelegator = (this && this.__asyncDelegator) || function (o) {
                var i, p;
                return i = {}, verb("next"), verb("throw", function (e) { throw e; }), verb("return"), i[Symbol.iterator] = function () { return this; }, i;
                function verb(n, f) { i[n] = o[n] ? function (v) { return (p = !p) ? { value: __await(o[n](v)), done: false } : f ? f(v) : v; } : f; }
            };`
                };
                asyncValues = {
                    name: "typescript:asyncValues",
                    importName: "__asyncValues",
                    scoped: false,
                    text: `
            var __asyncValues = (this && this.__asyncValues) || function (o) {
                if (!Symbol.asyncIterator) throw new TypeError("Symbol.asyncIterator is not defined.");
                var m = o[Symbol.asyncIterator], i;
                return m ? m.call(o) : (o = typeof __values === "function" ? __values(o) : o[Symbol.iterator](), i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i);
                function verb(n) { i[n] = o[n] && function (v) { return new Promise(function (resolve, reject) { v = o[n](v), settle(resolve, reject, v.done, v.value); }); }; }
                function settle(resolve, reject, d, v) { Promise.resolve(v).then(function(v) { resolve({ value: v, done: d }); }, reject); }
            };`
                };
                restHelper = {
                    name: "typescript:rest",
                    importName: "__rest",
                    scoped: false,
                    text: `
            var __rest = (this && this.__rest) || function (s, e) {
                var t = {};
                for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
                    t[p] = s[p];
                if (s != null && typeof Object.getOwnPropertySymbols === "function")
                    for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
                        if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                            t[p[i]] = s[p[i]];
                    }
                return t;
            };`
                };
                awaiterHelper = {
                    name: "typescript:awaiter",
                    importName: "__awaiter",
                    scoped: false,
                    priority: 5,
                    text: `
            var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
                function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
                return new (P || (P = Promise))(function (resolve, reject) {
                    function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
                    function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
                    function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
                    step((generator = generator.apply(thisArg, _arguments || [])).next());
                });
            };`
                };
                extendsHelper = {
                    name: "typescript:extends",
                    importName: "__extends",
                    scoped: false,
                    priority: 0,
                    text: `
            var __extends = (this && this.__extends) || (function () {
                var extendStatics = function (d, b) {
                    extendStatics = Object.setPrototypeOf ||
                        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
                        function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
                    return extendStatics(d, b);
                };

                return function (d, b) {
                    if (typeof b !== "function" && b !== null)
                        throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
                    extendStatics(d, b);
                    function __() { this.constructor = d; }
                    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
                };
            })();`
                };
                templateObjectHelper = {
                    name: "typescript:makeTemplateObject",
                    importName: "__makeTemplateObject",
                    scoped: false,
                    priority: 0,
                    text: `
            var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
                if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
                return cooked;
            };`
                };
                readHelper = {
                    name: "typescript:read",
                    importName: "__read",
                    scoped: false,
                    text: `
            var __read = (this && this.__read) || function (o, n) {
                var m = typeof Symbol === "function" && o[Symbol.iterator];
                if (!m) return o;
                var i = m.call(o), r, ar = [], e;
                try {
                    while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
                }
                catch (error) { e = { error: error }; }
                finally {
                    try {
                        if (r && !r.done && (m = i["return"])) m.call(i);
                    }
                    finally { if (e) throw e.error; }
                }
                return ar;
            };`
                };
                spreadArrayHelper = {
                    name: "typescript:spreadArray",
                    importName: "__spreadArray",
                    scoped: false,
                    text: `
            var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
                if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
                    if (ar || !(i in from)) {
                        if (!ar) ar = Array.prototype.slice.call(from, 0, i);
                        ar[i] = from[i];
                    }
                }
                return to.concat(ar || Array.prototype.slice.call(from));
            };`
                };
                propKeyHelper = {
                    name: "typescript:propKey",
                    importName: "__propKey",
                    scoped: false,
                    text: `
        var __propKey = (this && this.__propKey) || function (x) {
            return typeof x === "symbol" ? x : "".concat(x);
        };`
                };
                setFunctionNameHelper = {
                    name: "typescript:setFunctionName",
                    importName: "__setFunctionName",
                    scoped: false,
                    text: `
        var __setFunctionName = (this && this.__setFunctionName) || function (f, name, prefix) {
            if (typeof name === "symbol") name = name.description ? "[".concat(name.description, "]") : "";
            return Object.defineProperty(f, "name", { configurable: true, value: prefix ? "".concat(prefix, " ", name) : name });
        };`
                };
                valuesHelper = {
                    name: "typescript:values",
                    importName: "__values",
                    scoped: false,
                    text: `
            var __values = (this && this.__values) || function(o) {
                var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
                if (m) return m.call(o);
                if (o && typeof o.length === "number") return {
                    next: function () {
                        if (o && i >= o.length) o = void 0;
                        return { value: o && o[i++], done: !o };
                    }
                };
                throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
            };`
                };
                generatorHelper = {
                    name: "typescript:generator",
                    importName: "__generator",
                    scoped: false,
                    priority: 6,
                    text: `
            var __generator = (this && this.__generator) || function (thisArg, body) {
                var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
                return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
                function verb(n) { return function (v) { return step([n, v]); }; }
                function step(op) {
                    if (f) throw new TypeError("Generator is already executing.");
                    while (g && (g = 0, op[0] && (_ = 0)), _) try {
                        if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
                        if (y = 0, t) op = [op[0] & 2, t.value];
                        switch (op[0]) {
                            case 0: case 1: t = op; break;
                            case 4: _.label++; return { value: op[1], done: false };
                            case 5: _.label++; y = op[1]; op = [0]; continue;
                            case 7: op = _.ops.pop(); _.trys.pop(); continue;
                            default:
                                if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                                if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                                if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                                if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                                if (t[2]) _.ops.pop();
                                _.trys.pop(); continue;
                        }
                        op = body.call(thisArg, _);
                    } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
                    if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
                }
            };`
                };
                createBindingHelper = {
                    name: "typescript:commonjscreatebinding",
                    importName: "__createBinding",
                    scoped: false,
                    priority: 1,
                    text: `
            var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
                if (k2 === undefined) k2 = k;
                var desc = Object.getOwnPropertyDescriptor(m, k);
                if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
                  desc = { enumerable: true, get: function() { return m[k]; } };
                }
                Object.defineProperty(o, k2, desc);
            }) : (function(o, m, k, k2) {
                if (k2 === undefined) k2 = k;
                o[k2] = m[k];
            }));`
                };
                setModuleDefaultHelper = {
                    name: "typescript:commonjscreatevalue",
                    importName: "__setModuleDefault",
                    scoped: false,
                    priority: 1,
                    text: `
            var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
                Object.defineProperty(o, "default", { enumerable: true, value: v });
            }) : function(o, v) {
                o["default"] = v;
            });`
                };
                importStarHelper = {
                    name: "typescript:commonjsimportstar",
                    importName: "__importStar",
                    scoped: false,
                    dependencies: [createBindingHelper, setModuleDefaultHelper],
                    priority: 2,
                    text: `
            var __importStar = (this && this.__importStar) || function (mod) {
                if (mod && mod.__esModule) return mod;
                var result = {};
                if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
                __setModuleDefault(result, mod);
                return result;
            };`
                };
                importDefaultHelper = {
                    name: "typescript:commonjsimportdefault",
                    importName: "__importDefault",
                    scoped: false,
                    text: `
            var __importDefault = (this && this.__importDefault) || function (mod) {
                return (mod && mod.__esModule) ? mod : { "default": mod };
            };`
                };
                exportStarHelper = {
                    name: "typescript:export-star",
                    importName: "__exportStar",
                    scoped: false,
                    dependencies: [createBindingHelper],
                    priority: 2,
                    text: `
            var __exportStar = (this && this.__exportStar) || function(m, exports) {
                for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
            };`
                };
                classPrivateFieldGetHelper = {
                    name: "typescript:classPrivateFieldGet",
                    importName: "__classPrivateFieldGet",
                    scoped: false,
                    text: `
            var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
                if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
                if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
                return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
            };`
                };
                classPrivateFieldSetHelper = {
                    name: "typescript:classPrivateFieldSet",
                    importName: "__classPrivateFieldSet",
                    scoped: false,
                    text: `
            var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
                if (kind === "m") throw new TypeError("Private method is not writable");
                if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
                if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
                return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
            };`
                };
                classPrivateFieldInHelper = {
                    name: "typescript:classPrivateFieldIn",
                    importName: "__classPrivateFieldIn",
                    scoped: false,
                    text: `
            var __classPrivateFieldIn = (this && this.__classPrivateFieldIn) || function(state, receiver) {
                if (receiver === null || (typeof receiver !== "object" && typeof receiver !== "function")) throw new TypeError("Cannot use 'in' operator on non-object");
                return typeof state === "function" ? receiver === state : state.has(receiver);
            };`
                };
                addDisposableResourceHelper = {
                    name: "typescript:addDisposableResource",
                    importName: "__addDisposableResource",
                    scoped: false,
                    text: `
        var __addDisposableResource = (this && this.__addDisposableResource) || function (env, value, async) {
            if (value !== null && value !== void 0) {
                if (typeof value !== "object" && typeof value !== "function") throw new TypeError("Object expected.");
                var dispose;
                if (async) {
                    if (!Symbol.asyncDispose) throw new TypeError("Symbol.asyncDispose is not defined.");
                    dispose = value[Symbol.asyncDispose];
                }
                if (dispose === void 0) {
                    if (!Symbol.dispose) throw new TypeError("Symbol.dispose is not defined.");
                    dispose = value[Symbol.dispose];
                }
                if (typeof dispose !== "function") throw new TypeError("Object not disposable.");
                env.stack.push({ value: value, dispose: dispose, async: async });
            }
            else if (async) {
                env.stack.push({ async: true });
            }
            return value;
        };`
                };
                disposeResourcesHelper = {
                    name: "typescript:disposeResources",
                    importName: "__disposeResources",
                    scoped: false,
                    text: `
        var __disposeResources = (this && this.__disposeResources) || (function (SuppressedError) {
            return function (env) {
                function fail(e) {
                    env.error = env.hasError ? new SuppressedError(e, env.error, "An error was suppressed during disposal.") : e;
                    env.hasError = true;
                }
                function next() {
                    while (env.stack.length) {
                        var rec = env.stack.pop();
                        try {
                            var result = rec.dispose && rec.dispose.call(rec.value);
                            if (rec.async) return Promise.resolve(result).then(next, function(e) { fail(e); return next(); });
                        }
                        catch (e) {
                            fail(e);
                        }
                    }
                    if (env.hasError) throw env.error;
                }
                return next();
            };
        })(typeof SuppressedError === "function" ? SuppressedError : function (error, suppressed, message) {
            var e = new Error(message);
            return e.name = "SuppressedError", e.error = error, e.suppressed = suppressed, e;
        });`
                };
                asyncSuperHelper = {
                    name: "typescript:async-super",
                    scoped: true,
                    text: helperString `
            const ${"_superIndex"} = name => super[name];`
                };
                advancedAsyncSuperHelper = {
                    name: "typescript:advanced-async-super",
                    scoped: true,
                    text: helperString `
            const ${"_superIndex"} = (function (geti, seti) {
                const cache = Object.create(null);
                return name => cache[name] || (cache[name] = { get value() { return geti(name); }, set value(v) { seti(name, v); } });
            })(name => super[name], (name, value) => super[name] = value);`
                };
            }
        });
        // src/compiler/factory/nodeTests.ts
        function isNumericLiteral(node) {
            return node.kind === 9 /* NumericLiteral */;
        }
        function isBigIntLiteral(node) {
            return node.kind === 10 /* BigIntLiteral */;
        }
        function isStringLiteral(node) {
            return node.kind === 11 /* StringLiteral */;
        }
        function isJsxText(node) {
            return node.kind === 12 /* JsxText */;
        }
        function isRegularExpressionLiteral(node) {
            return node.kind === 14 /* RegularExpressionLiteral */;
        }
        function isNoSubstitutionTemplateLiteral(node) {
            return node.kind === 15 /* NoSubstitutionTemplateLiteral */;
        }
        function isTemplateHead(node) {
            return node.kind === 16 /* TemplateHead */;
        }
        function isTemplateMiddle(node) {
            return node.kind === 17 /* TemplateMiddle */;
        }
        function isTemplateTail(node) {
            return node.kind === 18 /* TemplateTail */;
        }
        function isDotDotDotToken(node) {
            return node.kind === 26 /* DotDotDotToken */;
        }
        function isCommaToken(node) {
            return node.kind === 28 /* CommaToken */;
        }
        function isPlusToken(node) {
            return node.kind === 40 /* PlusToken */;
        }
        function isMinusToken(node) {
            return node.kind === 41 /* MinusToken */;
        }
        function isAsteriskToken(node) {
            return node.kind === 42 /* AsteriskToken */;
        }
        function isExclamationToken(node) {
            return node.kind === 54 /* ExclamationToken */;
        }
        function isQuestionToken(node) {
            return node.kind === 58 /* QuestionToken */;
        }
        function isColonToken(node) {
            return node.kind === 59 /* ColonToken */;
        }
        function isQuestionDotToken(node) {
            return node.kind === 29 /* QuestionDotToken */;
        }
        function isEqualsGreaterThanToken(node) {
            return node.kind === 39 /* EqualsGreaterThanToken */;
        }
        function isIdentifier(node) {
            return node.kind === 80 /* Identifier */;
        }
        function isPrivateIdentifier(node) {
            return node.kind === 81 /* PrivateIdentifier */;
        }
        function isExportModifier(node) {
            return node.kind === 95 /* ExportKeyword */;
        }
        function isDefaultModifier(node) {
            return node.kind === 90 /* DefaultKeyword */;
        }
        function isAsyncModifier(node) {
            return node.kind === 134 /* AsyncKeyword */;
        }
        function isAssertsKeyword(node) {
            return node.kind === 131 /* AssertsKeyword */;
        }
        function isAwaitKeyword(node) {
            return node.kind === 135 /* AwaitKeyword */;
        }
        function isReadonlyKeyword(node) {
            return node.kind === 148 /* ReadonlyKeyword */;
        }
        function isStaticModifier(node) {
            return node.kind === 126 /* StaticKeyword */;
        }
        function isAbstractModifier(node) {
            return node.kind === 128 /* AbstractKeyword */;
        }
        function isOverrideModifier(node) {
            return node.kind === 164 /* OverrideKeyword */;
        }
        function isAccessorModifier(node) {
            return node.kind === 129 /* AccessorKeyword */;
        }
        function isSuperKeyword(node) {
            return node.kind === 108 /* SuperKeyword */;
        }
        function isImportKeyword(node) {
            return node.kind === 102 /* ImportKeyword */;
        }
        function isCaseKeyword(node) {
            return node.kind === 84 /* CaseKeyword */;
        }
        function isQualifiedName(node) {
            return node.kind === 166 /* QualifiedName */;
        }
        function isComputedPropertyName(node) {
            return node.kind === 167 /* ComputedPropertyName */;
        }
        function isTypeParameterDeclaration(node) {
            return node.kind === 168 /* TypeParameter */;
        }
        function isParameter(node) {
            return node.kind === 169 /* Parameter */;
        }
        function isDecorator(node) {
            return node.kind === 170 /* Decorator */;
        }
        function isPropertySignature(node) {
            return node.kind === 171 /* PropertySignature */;
        }
        function isPropertyDeclaration(node) {
            return node.kind === 172 /* PropertyDeclaration */;
        }
        function isMethodSignature(node) {
            return node.kind === 173 /* MethodSignature */;
        }
        function isMethodDeclaration(node) {
            return node.kind === 174 /* MethodDeclaration */;
        }
        function isClassStaticBlockDeclaration(node) {
            return node.kind === 175 /* ClassStaticBlockDeclaration */;
        }
        function isConstructorDeclaration(node) {
            return node.kind === 176 /* Constructor */;
        }
        function isGetAccessorDeclaration(node) {
            return node.kind === 177 /* GetAccessor */;
        }
        function isSetAccessorDeclaration(node) {
            return node.kind === 178 /* SetAccessor */;
        }
        function isCallSignatureDeclaration(node) {
            return node.kind === 179 /* CallSignature */;
        }
        function isConstructSignatureDeclaration(node) {
            return node.kind === 180 /* ConstructSignature */;
        }
        function isIndexSignatureDeclaration(node) {
            return node.kind === 181 /* IndexSignature */;
        }
        function isTypePredicateNode(node) {
            return node.kind === 182 /* TypePredicate */;
        }
        function isTypeReferenceNode(node) {
            return node.kind === 183 /* TypeReference */;
        }
        function isFunctionTypeNode(node) {
            return node.kind === 184 /* FunctionType */;
        }
        function isConstructorTypeNode(node) {
            return node.kind === 185 /* ConstructorType */;
        }
        function isTypeQueryNode(node) {
            return node.kind === 186 /* TypeQuery */;
        }
        function isTypeLiteralNode(node) {
            return node.kind === 187 /* TypeLiteral */;
        }
        function isArrayTypeNode(node) {
            return node.kind === 188 /* ArrayType */;
        }
        function isTupleTypeNode(node) {
            return node.kind === 189 /* TupleType */;
        }
        function isNamedTupleMember(node) {
            return node.kind === 202 /* NamedTupleMember */;
        }
        function isOptionalTypeNode(node) {
            return node.kind === 190 /* OptionalType */;
        }
        function isRestTypeNode(node) {
            return node.kind === 191 /* RestType */;
        }
        function isUnionTypeNode(node) {
            return node.kind === 192 /* UnionType */;
        }
        function isIntersectionTypeNode(node) {
            return node.kind === 193 /* IntersectionType */;
        }
        function isConditionalTypeNode(node) {
            return node.kind === 194 /* ConditionalType */;
        }
        function isInferTypeNode(node) {
            return node.kind === 195 /* InferType */;
        }
        function isParenthesizedTypeNode(node) {
            return node.kind === 196 /* ParenthesizedType */;
        }
        function isThisTypeNode(node) {
            return node.kind === 197 /* ThisType */;
        }
        function isTypeOperatorNode(node) {
            return node.kind === 198 /* TypeOperator */;
        }
        function isIndexedAccessTypeNode(node) {
            return node.kind === 199 /* IndexedAccessType */;
        }
        function isMappedTypeNode(node) {
            return node.kind === 200 /* MappedType */;
        }
        function isLiteralTypeNode(node) {
            return node.kind === 201 /* LiteralType */;
        }
        function isImportTypeNode(node) {
            return node.kind === 205 /* ImportType */;
        }
        function isTemplateLiteralTypeSpan(node) {
            return node.kind === 204 /* TemplateLiteralTypeSpan */;
        }
        function isTemplateLiteralTypeNode(node) {
            return node.kind === 203 /* TemplateLiteralType */;
        }
        function isObjectBindingPattern(node) {
            return node.kind === 206 /* ObjectBindingPattern */;
        }
        function isArrayBindingPattern(node) {
            return node.kind === 207 /* ArrayBindingPattern */;
        }
        function isBindingElement(node) {
            return node.kind === 208 /* BindingElement */;
        }
        function isArrayLiteralExpression(node) {
            return node.kind === 209 /* ArrayLiteralExpression */;
        }
        function isObjectLiteralExpression(node) {
            return node.kind === 210 /* ObjectLiteralExpression */;
        }
        function isPropertyAccessExpression(node) {
            return node.kind === 211 /* PropertyAccessExpression */;
        }
        function isElementAccessExpression(node) {
            return node.kind === 212 /* ElementAccessExpression */;
        }
        function isCallExpression(node) {
            return node.kind === 213 /* CallExpression */;
        }
        function isNewExpression(node) {
            return node.kind === 214 /* NewExpression */;
        }
        function isTaggedTemplateExpression(node) {
            return node.kind === 215 /* TaggedTemplateExpression */;
        }
        function isTypeAssertionExpression(node) {
            return node.kind === 216 /* TypeAssertionExpression */;
        }
        function isParenthesizedExpression(node) {
            return node.kind === 217 /* ParenthesizedExpression */;
        }
        function isFunctionExpression(node) {
            return node.kind === 218 /* FunctionExpression */;
        }
        function isArrowFunction(node) {
            return node.kind === 219 /* ArrowFunction */;
        }
        function isDeleteExpression(node) {
            return node.kind === 220 /* DeleteExpression */;
        }
        function isTypeOfExpression(node) {
            return node.kind === 221 /* TypeOfExpression */;
        }
        function isVoidExpression(node) {
            return node.kind === 222 /* VoidExpression */;
        }
        function isAwaitExpression(node) {
            return node.kind === 223 /* AwaitExpression */;
        }
        function isPrefixUnaryExpression(node) {
            return node.kind === 224 /* PrefixUnaryExpression */;
        }
        function isPostfixUnaryExpression(node) {
            return node.kind === 225 /* PostfixUnaryExpression */;
        }
        function isBinaryExpression(node) {
            return node.kind === 226 /* BinaryExpression */;
        }
        function isConditionalExpression(node) {
            return node.kind === 227 /* ConditionalExpression */;
        }
        function isTemplateExpression(node) {
            return node.kind === 228 /* TemplateExpression */;
        }
        function isYieldExpression(node) {
            return node.kind === 229 /* YieldExpression */;
        }
        function isSpreadElement(node) {
            return node.kind === 230 /* SpreadElement */;
        }
        function isClassExpression(node) {
            return node.kind === 231 /* ClassExpression */;
        }
        function isOmittedExpression(node) {
            return node.kind === 232 /* OmittedExpression */;
        }
        function isExpressionWithTypeArguments(node) {
            return node.kind === 233 /* ExpressionWithTypeArguments */;
        }
        function isAsExpression(node) {
            return node.kind === 234 /* AsExpression */;
        }
        function isSatisfiesExpression(node) {
            return node.kind === 238 /* SatisfiesExpression */;
        }
        function isNonNullExpression(node) {
            return node.kind === 235 /* NonNullExpression */;
        }
        function isMetaProperty(node) {
            return node.kind === 236 /* MetaProperty */;
        }
        function isSyntheticExpression(node) {
            return node.kind === 237 /* SyntheticExpression */;
        }
        function isPartiallyEmittedExpression(node) {
            return node.kind === 360 /* PartiallyEmittedExpression */;
        }
        function isCommaListExpression(node) {
            return node.kind === 361 /* CommaListExpression */;
        }
        function isTemplateSpan(node) {
            return node.kind === 239 /* TemplateSpan */;
        }
        function isSemicolonClassElement(node) {
            return node.kind === 240 /* SemicolonClassElement */;
        }
        function isBlock(node) {
            return node.kind === 241 /* Block */;
        }
        function isVariableStatement(node) {
            return node.kind === 243 /* VariableStatement */;
        }
        function isEmptyStatement(node) {
            return node.kind === 242 /* EmptyStatement */;
        }
        function isExpressionStatement(node) {
            return node.kind === 244 /* ExpressionStatement */;
        }
        function isIfStatement(node) {
            return node.kind === 245 /* IfStatement */;
        }
        function isDoStatement(node) {
            return node.kind === 246 /* DoStatement */;
        }
        function isWhileStatement(node) {
            return node.kind === 247 /* WhileStatement */;
        }
        function isForStatement(node) {
            return node.kind === 248 /* ForStatement */;
        }
        function isForInStatement(node) {
            return node.kind === 249 /* ForInStatement */;
        }
        function isForOfStatement(node) {
            return node.kind === 250 /* ForOfStatement */;
        }
        function isContinueStatement(node) {
            return node.kind === 251 /* ContinueStatement */;
        }
        function isBreakStatement(node) {
            return node.kind === 252 /* BreakStatement */;
        }
        function isReturnStatement(node) {
            return node.kind === 253 /* ReturnStatement */;
        }
        function isWithStatement(node) {
            return node.kind === 254 /* WithStatement */;
        }
        function isSwitchStatement(node) {
            return node.kind === 255 /* SwitchStatement */;
        }
        function isLabeledStatement(node) {
            return node.kind === 256 /* LabeledStatement */;
        }
        function isThrowStatement(node) {
            return node.kind === 257 /* ThrowStatement */;
        }
        function isTryStatement(node) {
            return node.kind === 258 /* TryStatement */;
        }
        function isDebuggerStatement(node) {
            return node.kind === 259 /* DebuggerStatement */;
        }
        function isVariableDeclaration(node) {
            return node.kind === 260 /* VariableDeclaration */;
        }
        function isVariableDeclarationList(node) {
            return node.kind === 261 /* VariableDeclarationList */;
        }
        function isFunctionDeclaration(node) {
            return node.kind === 262 /* FunctionDeclaration */;
        }
        function isClassDeclaration(node) {
            return node.kind === 263 /* ClassDeclaration */;
        }
        function isInterfaceDeclaration(node) {
            return node.kind === 264 /* InterfaceDeclaration */;
        }
        function isTypeAliasDeclaration(node) {
            return node.kind === 265 /* TypeAliasDeclaration */;
        }
        function isEnumDeclaration(node) {
            return node.kind === 266 /* EnumDeclaration */;
        }
        function isModuleDeclaration(node) {
            return node.kind === 267 /* ModuleDeclaration */;
        }
        function isModuleBlock(node) {
            return node.kind === 268 /* ModuleBlock */;
        }
        function isCaseBlock(node) {
            return node.kind === 269 /* CaseBlock */;
        }
        function isNamespaceExportDeclaration(node) {
            return node.kind === 270 /* NamespaceExportDeclaration */;
        }
        function isImportEqualsDeclaration(node) {
            return node.kind === 271 /* ImportEqualsDeclaration */;
        }
        function isImportDeclaration(node) {
            return node.kind === 272 /* ImportDeclaration */;
        }
        function isImportClause(node) {
            return node.kind === 273 /* ImportClause */;
        }
        function isImportTypeAssertionContainer(node) {
            return node.kind === 302 /* ImportTypeAssertionContainer */;
        }
        function isAssertClause(node) {
            return node.kind === 300 /* AssertClause */;
        }
        function isAssertEntry(node) {
            return node.kind === 301 /* AssertEntry */;
        }
        function isImportAttributes(node) {
            return node.kind === 300 /* ImportAttributes */;
        }
        function isImportAttribute(node) {
            return node.kind === 301 /* ImportAttribute */;
        }
        function isNamespaceImport(node) {
            return node.kind === 274 /* NamespaceImport */;
        }
        function isNamespaceExport(node) {
            return node.kind === 280 /* NamespaceExport */;
        }
        function isNamedImports(node) {
            return node.kind === 275 /* NamedImports */;
        }
        function isImportSpecifier(node) {
            return node.kind === 276 /* ImportSpecifier */;
        }
        function isExportAssignment(node) {
            return node.kind === 277 /* ExportAssignment */;
        }
        function isExportDeclaration(node) {
            return node.kind === 278 /* ExportDeclaration */;
        }
        function isNamedExports(node) {
            return node.kind === 279 /* NamedExports */;
        }
        function isExportSpecifier(node) {
            return node.kind === 281 /* ExportSpecifier */;
        }
        function isMissingDeclaration(node) {
            return node.kind === 282 /* MissingDeclaration */;
        }
        function isNotEmittedStatement(node) {
            return node.kind === 359 /* NotEmittedStatement */;
        }
        function isSyntheticReference(node) {
            return node.kind === 362 /* SyntheticReferenceExpression */;
        }
        function isExternalModuleReference(node) {
            return node.kind === 283 /* ExternalModuleReference */;
        }
        function isJsxElement(node) {
            return node.kind === 284 /* JsxElement */;
        }
        function isJsxSelfClosingElement(node) {
            return node.kind === 285 /* JsxSelfClosingElement */;
        }
        function isJsxOpeningElement(node) {
            return node.kind === 286 /* JsxOpeningElement */;
        }
        function isJsxClosingElement(node) {
            return node.kind === 287 /* JsxClosingElement */;
        }
        function isJsxFragment(node) {
            return node.kind === 288 /* JsxFragment */;
        }
        function isJsxOpeningFragment(node) {
            return node.kind === 289 /* JsxOpeningFragment */;
        }
        function isJsxClosingFragment(node) {
            return node.kind === 290 /* JsxClosingFragment */;
        }
        function isJsxAttribute(node) {
            return node.kind === 291 /* JsxAttribute */;
        }
        function isJsxAttributes(node) {
            return node.kind === 292 /* JsxAttributes */;
        }
        function isJsxSpreadAttribute(node) {
            return node.kind === 293 /* JsxSpreadAttribute */;
        }
        function isJsxExpression(node) {
            return node.kind === 294 /* JsxExpression */;
        }
        function isJsxNamespacedName(node) {
            return node.kind === 295 /* JsxNamespacedName */;
        }
        function isCaseClause(node) {
            return node.kind === 296 /* CaseClause */;
        }
        function isDefaultClause(node) {
            return node.kind === 297 /* DefaultClause */;
        }
        function isHeritageClause(node) {
            return node.kind === 298 /* HeritageClause */;
        }
        function isCatchClause(node) {
            return node.kind === 299 /* CatchClause */;
        }
        function isPropertyAssignment(node) {
            return node.kind === 303 /* PropertyAssignment */;
        }
        function isShorthandPropertyAssignment(node) {
            return node.kind === 304 /* ShorthandPropertyAssignment */;
        }
        function isSpreadAssignment(node) {
            return node.kind === 305 /* SpreadAssignment */;
        }
        function isEnumMember(node) {
            return node.kind === 306 /* EnumMember */;
        }
        function isUnparsedPrepend(node) {
            return node.kind === 308 /* UnparsedPrepend */;
        }
        function isSourceFile(node) {
            return node.kind === 312 /* SourceFile */;
        }
        function isBundle(node) {
            return node.kind === 313 /* Bundle */;
        }
        function isUnparsedSource(node) {
            return node.kind === 314 /* UnparsedSource */;
        }
        function isJSDocTypeExpression(node) {
            return node.kind === 316 /* JSDocTypeExpression */;
        }
        function isJSDocNameReference(node) {
            return node.kind === 317 /* JSDocNameReference */;
        }
        function isJSDocMemberName(node) {
            return node.kind === 318 /* JSDocMemberName */;
        }
        function isJSDocLink(node) {
            return node.kind === 331 /* JSDocLink */;
        }
        function isJSDocLinkCode(node) {
            return node.kind === 332 /* JSDocLinkCode */;
        }
        function isJSDocLinkPlain(node) {
            return node.kind === 333 /* JSDocLinkPlain */;
        }
        function isJSDocAllType(node) {
            return node.kind === 319 /* JSDocAllType */;
        }
        function isJSDocUnknownType(node) {
            return node.kind === 320 /* JSDocUnknownType */;
        }
        function isJSDocNullableType(node) {
            return node.kind === 321 /* JSDocNullableType */;
        }
        function isJSDocNonNullableType(node) {
            return node.kind === 322 /* JSDocNonNullableType */;
        }
        function isJSDocOptionalType(node) {
            return node.kind === 323 /* JSDocOptionalType */;
        }
        function isJSDocFunctionType(node) {
            return node.kind === 324 /* JSDocFunctionType */;
        }
        function isJSDocVariadicType(node) {
            return node.kind === 325 /* JSDocVariadicType */;
        }
        function isJSDocNamepathType(node) {
            return node.kind === 326 /* JSDocNamepathType */;
        }
        function isJSDoc(node) {
            return node.kind === 327 /* JSDoc */;
        }
        function isJSDocTypeLiteral(node) {
            return node.kind === 329 /* JSDocTypeLiteral */;
        }
        function isJSDocSignature(node) {
            return node.kind === 330 /* JSDocSignature */;
        }
        function isJSDocAugmentsTag(node) {
            return node.kind === 335 /* JSDocAugmentsTag */;
        }
        function isJSDocAuthorTag(node) {
            return node.kind === 337 /* JSDocAuthorTag */;
        }
        function isJSDocClassTag(node) {
            return node.kind === 339 /* JSDocClassTag */;
        }
        function isJSDocCallbackTag(node) {
            return node.kind === 345 /* JSDocCallbackTag */;
        }
        function isJSDocPublicTag(node) {
            return node.kind === 340 /* JSDocPublicTag */;
        }
        function isJSDocPrivateTag(node) {
            return node.kind === 341 /* JSDocPrivateTag */;
        }
        function isJSDocProtectedTag(node) {
            return node.kind === 342 /* JSDocProtectedTag */;
        }
        function isJSDocReadonlyTag(node) {
            return node.kind === 343 /* JSDocReadonlyTag */;
        }
        function isJSDocOverrideTag(node) {
            return node.kind === 344 /* JSDocOverrideTag */;
        }
        function isJSDocOverloadTag(node) {
            return node.kind === 346 /* JSDocOverloadTag */;
        }
        function isJSDocDeprecatedTag(node) {
            return node.kind === 338 /* JSDocDeprecatedTag */;
        }
        function isJSDocSeeTag(node) {
            return node.kind === 354 /* JSDocSeeTag */;
        }
        function isJSDocEnumTag(node) {
            return node.kind === 347 /* JSDocEnumTag */;
        }
        function isJSDocParameterTag(node) {
            return node.kind === 348 /* JSDocParameterTag */;
        }
        function isJSDocReturnTag(node) {
            return node.kind === 349 /* JSDocReturnTag */;
        }
        function isJSDocThisTag(node) {
            return node.kind === 350 /* JSDocThisTag */;
        }
        function isJSDocTypeTag(node) {
            return node.kind === 351 /* JSDocTypeTag */;
        }
        function isJSDocTemplateTag(node) {
            return node.kind === 352 /* JSDocTemplateTag */;
        }
        function isJSDocTypedefTag(node) {
            return node.kind === 353 /* JSDocTypedefTag */;
        }
        function isJSDocUnknownTag(node) {
            return node.kind === 334 /* JSDocTag */;
        }
        function isJSDocPropertyTag(node) {
            return node.kind === 355 /* JSDocPropertyTag */;
        }
        function isJSDocImplementsTag(node) {
            return node.kind === 336 /* JSDocImplementsTag */;
        }
        function isJSDocSatisfiesTag(node) {
            return node.kind === 357 /* JSDocSatisfiesTag */;
        }
        function isJSDocThrowsTag(node) {
            return node.kind === 356 /* JSDocThrowsTag */;
        }
        function isSyntaxList(n) {
            return n.kind === 358 /* SyntaxList */;
        }
        var init_nodeTests = __esm({
            "src/compiler/factory/nodeTests.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/factory/utilities.ts
        function createEmptyExports(factory2) {
            return factory2.createExportDeclaration(
            /*modifiers*/
            void 0, 
            /*isTypeOnly*/
            false, factory2.createNamedExports([]), 
            /*moduleSpecifier*/
            void 0);
        }
        function createMemberAccessForPropertyName(factory2, target, memberName, location) {
            if (isComputedPropertyName(memberName)) {
                return setTextRange(factory2.createElementAccessExpression(target, memberName.expression), location);
            }
            else {
                const expression = setTextRange(isMemberName(memberName) ? factory2.createPropertyAccessExpression(target, memberName) : factory2.createElementAccessExpression(target, memberName), memberName);
                addEmitFlags(expression, 128 /* NoNestedSourceMaps */);
                return expression;
            }
        }
        function createReactNamespace(reactNamespace, parent2) {
            const react = parseNodeFactory.createIdentifier(reactNamespace || "React");
            setParent(react, getParseTreeNode(parent2));
            return react;
        }
        function createJsxFactoryExpressionFromEntityName(factory2, jsxFactory, parent2) {
            if (isQualifiedName(jsxFactory)) {
                const left = createJsxFactoryExpressionFromEntityName(factory2, jsxFactory.left, parent2);
                const right = factory2.createIdentifier(idText(jsxFactory.right));
                right.escapedText = jsxFactory.right.escapedText;
                return factory2.createPropertyAccessExpression(left, right);
            }
            else {
                return createReactNamespace(idText(jsxFactory), parent2);
            }
        }
        function createJsxFactoryExpression(factory2, jsxFactoryEntity, reactNamespace, parent2) {
            return jsxFactoryEntity ? createJsxFactoryExpressionFromEntityName(factory2, jsxFactoryEntity, parent2) : factory2.createPropertyAccessExpression(createReactNamespace(reactNamespace, parent2), "createElement");
        }
        function createJsxFragmentFactoryExpression(factory2, jsxFragmentFactoryEntity, reactNamespace, parent2) {
            return jsxFragmentFactoryEntity ? createJsxFactoryExpressionFromEntityName(factory2, jsxFragmentFactoryEntity, parent2) : factory2.createPropertyAccessExpression(createReactNamespace(reactNamespace, parent2), "Fragment");
        }
        function createExpressionForJsxElement(factory2, callee, tagName, props, children, location) {
            const argumentsList = [tagName];
            if (props) {
                argumentsList.push(props);
            }
            if (children && children.length > 0) {
                if (!props) {
                    argumentsList.push(factory2.createNull());
                }
                if (children.length > 1) {
                    for (const child of children) {
                        startOnNewLine(child);
                        argumentsList.push(child);
                    }
                }
                else {
                    argumentsList.push(children[0]);
                }
            }
            return setTextRange(factory2.createCallExpression(callee, 
            /*typeArguments*/
            void 0, argumentsList), location);
        }
        function createExpressionForJsxFragment(factory2, jsxFactoryEntity, jsxFragmentFactoryEntity, reactNamespace, children, parentElement, location) {
            const tagName = createJsxFragmentFactoryExpression(factory2, jsxFragmentFactoryEntity, reactNamespace, parentElement);
            const argumentsList = [tagName, factory2.createNull()];
            if (children && children.length > 0) {
                if (children.length > 1) {
                    for (const child of children) {
                        startOnNewLine(child);
                        argumentsList.push(child);
                    }
                }
                else {
                    argumentsList.push(children[0]);
                }
            }
            return setTextRange(factory2.createCallExpression(createJsxFactoryExpression(factory2, jsxFactoryEntity, reactNamespace, parentElement), 
            /*typeArguments*/
            void 0, argumentsList), location);
        }
        function createForOfBindingStatement(factory2, node, boundValue) {
            if (isVariableDeclarationList(node)) {
                const firstDeclaration = first(node.declarations);
                const updatedDeclaration = factory2.updateVariableDeclaration(firstDeclaration, firstDeclaration.name, 
                /*exclamationToken*/
                void 0, 
                /*type*/
                void 0, boundValue);
                return setTextRange(factory2.createVariableStatement(
                /*modifiers*/
                void 0, factory2.updateVariableDeclarationList(node, [updatedDeclaration])), 
                /*location*/
                node);
            }
            else {
                const updatedExpression = setTextRange(factory2.createAssignment(node, boundValue), 
                /*location*/
                node);
                return setTextRange(factory2.createExpressionStatement(updatedExpression), 
                /*location*/
                node);
            }
        }
        function insertLeadingStatement(factory2, dest, source) {
            if (isBlock(dest)) {
                return factory2.updateBlock(dest, setTextRange(factory2.createNodeArray([source, ...dest.statements]), dest.statements));
            }
            else {
                return factory2.createBlock(factory2.createNodeArray([dest, source]), 
                /*multiLine*/
                true);
            }
        }
        function createExpressionFromEntityName(factory2, node) {
            if (isQualifiedName(node)) {
                const left = createExpressionFromEntityName(factory2, node.left);
                const right = setParent(setTextRange(factory2.cloneNode(node.right), node.right), node.right.parent);
                return setTextRange(factory2.createPropertyAccessExpression(left, right), node);
            }
            else {
                return setParent(setTextRange(factory2.cloneNode(node), node), node.parent);
            }
        }
        function createExpressionForPropertyName(factory2, memberName) {
            if (isIdentifier(memberName)) {
                return factory2.createStringLiteralFromNode(memberName);
            }
            else if (isComputedPropertyName(memberName)) {
                return setParent(setTextRange(factory2.cloneNode(memberName.expression), memberName.expression), memberName.expression.parent);
            }
            else {
                return setParent(setTextRange(factory2.cloneNode(memberName), memberName), memberName.parent);
            }
        }
        function createExpressionForAccessorDeclaration(factory2, properties, property, receiver, multiLine) {
            const { firstAccessor, getAccessor, setAccessor } = getAllAccessorDeclarations(properties, property);
            if (property === firstAccessor) {
                return setTextRange(factory2.createObjectDefinePropertyCall(receiver, createExpressionForPropertyName(factory2, property.name), factory2.createPropertyDescriptor({
                    enumerable: factory2.createFalse(),
                    configurable: true,
                    get: getAccessor && setTextRange(setOriginalNode(factory2.createFunctionExpression(getModifiers(getAccessor), 
                    /*asteriskToken*/
                    void 0, 
                    /*name*/
                    void 0, 
                    /*typeParameters*/
                    void 0, getAccessor.parameters, 
                    /*type*/
                    void 0, getAccessor.body
                    // TODO: GH#18217
                    ), getAccessor), getAccessor),
                    set: setAccessor && setTextRange(setOriginalNode(factory2.createFunctionExpression(getModifiers(setAccessor), 
                    /*asteriskToken*/
                    void 0, 
                    /*name*/
                    void 0, 
                    /*typeParameters*/
                    void 0, setAccessor.parameters, 
                    /*type*/
                    void 0, setAccessor.body
                    // TODO: GH#18217
                    ), setAccessor), setAccessor)
                }, !multiLine)), firstAccessor);
            }
            return void 0;
        }
        function createExpressionForPropertyAssignment(factory2, property, receiver) {
            return setOriginalNode(setTextRange(factory2.createAssignment(createMemberAccessForPropertyName(factory2, receiver, property.name, 
            /*location*/
            property.name), property.initializer), property), property);
        }
        function createExpressionForShorthandPropertyAssignment(factory2, property, receiver) {
            return setOriginalNode(setTextRange(factory2.createAssignment(createMemberAccessForPropertyName(factory2, receiver, property.name, 
            /*location*/
            property.name), factory2.cloneNode(property.name)), 
            /*location*/
            property), 
            /*original*/
            property);
        }
        function createExpressionForMethodDeclaration(factory2, method, receiver) {
            return setOriginalNode(setTextRange(factory2.createAssignment(createMemberAccessForPropertyName(factory2, receiver, method.name, 
            /*location*/
            method.name), setOriginalNode(setTextRange(factory2.createFunctionExpression(getModifiers(method), method.asteriskToken, 
            /*name*/
            void 0, 
            /*typeParameters*/
            void 0, method.parameters, 
            /*type*/
            void 0, method.body
            // TODO: GH#18217
            ), 
            /*location*/
            method), 
            /*original*/
            method)), 
            /*location*/
            method), 
            /*original*/
            method);
        }
        function createExpressionForObjectLiteralElementLike(factory2, node, property, receiver) {
            if (property.name && isPrivateIdentifier(property.name)) {
                Debug.failBadSyntaxKind(property.name, "Private identifiers are not allowed in object literals.");
            }
            switch (property.kind) {
                case 177 /* GetAccessor */:
                case 178 /* SetAccessor */:
                    return createExpressionForAccessorDeclaration(factory2, node.properties, property, receiver, !!node.multiLine);
                case 303 /* PropertyAssignment */:
                    return createExpressionForPropertyAssignment(factory2, property, receiver);
                case 304 /* ShorthandPropertyAssignment */:
                    return createExpressionForShorthandPropertyAssignment(factory2, property, receiver);
                case 174 /* MethodDeclaration */:
                    return createExpressionForMethodDeclaration(factory2, property, receiver);
            }
        }
        function expandPreOrPostfixIncrementOrDecrementExpression(factory2, node, expression, recordTempVariable, resultVariable) {
            const operator = node.operator;
            Debug.assert(operator === 46 /* PlusPlusToken */ || operator === 47 /* MinusMinusToken */, "Expected 'node' to be a pre- or post-increment or pre- or post-decrement expression");
            const temp = factory2.createTempVariable(recordTempVariable);
            expression = factory2.createAssignment(temp, expression);
            setTextRange(expression, node.operand);
            let operation = isPrefixUnaryExpression(node) ? factory2.createPrefixUnaryExpression(operator, temp) : factory2.createPostfixUnaryExpression(temp, operator);
            setTextRange(operation, node);
            if (resultVariable) {
                operation = factory2.createAssignment(resultVariable, operation);
                setTextRange(operation, node);
            }
            expression = factory2.createComma(expression, operation);
            setTextRange(expression, node);
            if (isPostfixUnaryExpression(node)) {
                expression = factory2.createComma(expression, temp);
                setTextRange(expression, node);
            }
            return expression;
        }
        function isInternalName(node) {
            return (getEmitFlags(node) & 65536 /* InternalName */) !== 0;
        }
        function isLocalName(node) {
            return (getEmitFlags(node) & 32768 /* LocalName */) !== 0;
        }
        function isExportName(node) {
            return (getEmitFlags(node) & 16384 /* ExportName */) !== 0;
        }
        function isUseStrictPrologue(node) {
            return isStringLiteral(node.expression) && node.expression.text === "use strict";
        }
        function findUseStrictPrologue(statements) {
            for (const statement of statements) {
                if (isPrologueDirective(statement)) {
                    if (isUseStrictPrologue(statement)) {
                        return statement;
                    }
                }
                else {
                    break;
                }
            }
            return void 0;
        }
        function startsWithUseStrict(statements) {
            const firstStatement = firstOrUndefined(statements);
            return firstStatement !== void 0 && isPrologueDirective(firstStatement) && isUseStrictPrologue(firstStatement);
        }
        function isCommaExpression(node) {
            return node.kind === 226 /* BinaryExpression */ && node.operatorToken.kind === 28 /* CommaToken */;
        }
        function isCommaSequence(node) {
            return isCommaExpression(node) || isCommaListExpression(node);
        }
        function isJSDocTypeAssertion(node) {
            return isParenthesizedExpression(node) && isInJSFile(node) && !!getJSDocTypeTag(node);
        }
        function getJSDocTypeAssertionType(node) {
            const type = getJSDocType(node);
            Debug.assertIsDefined(type);
            return type;
        }
        function isOuterExpression(node, kinds = 15 /* All */) {
            switch (node.kind) {
                case 217 /* ParenthesizedExpression */:
                    if (kinds & 16 /* ExcludeJSDocTypeAssertion */ && isJSDocTypeAssertion(node)) {
                        return false;
                    }
                    return (kinds & 1 /* Parentheses */) !== 0;
                case 216 /* TypeAssertionExpression */:
                case 234 /* AsExpression */:
                case 233 /* ExpressionWithTypeArguments */:
                case 238 /* SatisfiesExpression */:
                    return (kinds & 2 /* TypeAssertions */) !== 0;
                case 235 /* NonNullExpression */:
                    return (kinds & 4 /* NonNullAssertions */) !== 0;
                case 360 /* PartiallyEmittedExpression */:
                    return (kinds & 8 /* PartiallyEmittedExpressions */) !== 0;
            }
            return false;
        }
        function skipOuterExpressions(node, kinds = 15 /* All */) {
            while (isOuterExpression(node, kinds)) {
                node = node.expression;
            }
            return node;
        }
        function walkUpOuterExpressions(node, kinds = 15 /* All */) {
            let parent2 = node.parent;
            while (isOuterExpression(parent2, kinds)) {
                parent2 = parent2.parent;
                Debug.assert(parent2);
            }
            return parent2;
        }
        function skipAssertions(node) {
            return skipOuterExpressions(node, 6 /* Assertions */);
        }
        function startOnNewLine(node) {
            return setStartsOnNewLine(node, 
            /*newLine*/
            true);
        }
        function getExternalHelpersModuleName(node) {
            const parseNode = getOriginalNode(node, isSourceFile);
            const emitNode = parseNode && parseNode.emitNode;
            return emitNode && emitNode.externalHelpersModuleName;
        }
        function hasRecordedExternalHelpers(sourceFile) {
            const parseNode = getOriginalNode(sourceFile, isSourceFile);
            const emitNode = parseNode && parseNode.emitNode;
            return !!emitNode && (!!emitNode.externalHelpersModuleName || !!emitNode.externalHelpers);
        }
        function createExternalHelpersImportDeclarationIfNeeded(nodeFactory, helperFactory, sourceFile, compilerOptions, hasExportStarsToExportValues, hasImportStar, hasImportDefault) {
            if (compilerOptions.importHelpers && isEffectiveExternalModule(sourceFile, compilerOptions)) {
                let namedBindings;
                const moduleKind = getEmitModuleKind(compilerOptions);
                if (moduleKind >= 5 /* ES2015 */ && moduleKind <= 99 /* ESNext */ || sourceFile.impliedNodeFormat === 99 /* ESNext */) {
                    const helpers = getEmitHelpers(sourceFile);
                    if (helpers) {
                        const helperNames = [];
                        for (const helper of helpers) {
                            if (!helper.scoped) {
                                const importName = helper.importName;
                                if (importName) {
                                    pushIfUnique(helperNames, importName);
                                }
                            }
                        }
                        if (some(helperNames)) {
                            helperNames.sort(compareStringsCaseSensitive);
                            namedBindings = nodeFactory.createNamedImports(map(helperNames, (name) => isFileLevelUniqueName(sourceFile, name) ? nodeFactory.createImportSpecifier(
                            /*isTypeOnly*/
                            false, 
                            /*propertyName*/
                            void 0, nodeFactory.createIdentifier(name)) : nodeFactory.createImportSpecifier(
                            /*isTypeOnly*/
                            false, nodeFactory.createIdentifier(name), helperFactory.getUnscopedHelperName(name))));
                            const parseNode = getOriginalNode(sourceFile, isSourceFile);
                            const emitNode = getOrCreateEmitNode(parseNode);
                            emitNode.externalHelpers = true;
                        }
                    }
                }
                else {
                    const externalHelpersModuleName = getOrCreateExternalHelpersModuleNameIfNeeded(nodeFactory, sourceFile, compilerOptions, hasExportStarsToExportValues, hasImportStar || hasImportDefault);
                    if (externalHelpersModuleName) {
                        namedBindings = nodeFactory.createNamespaceImport(externalHelpersModuleName);
                    }
                }
                if (namedBindings) {
                    const externalHelpersImportDeclaration = nodeFactory.createImportDeclaration(
                    /*modifiers*/
                    void 0, nodeFactory.createImportClause(
                    /*isTypeOnly*/
                    false, 
                    /*name*/
                    void 0, namedBindings), nodeFactory.createStringLiteral(externalHelpersModuleNameText), 
                    /*attributes*/
                    void 0);
                    addInternalEmitFlags(externalHelpersImportDeclaration, 2 /* NeverApplyImportHelper */);
                    return externalHelpersImportDeclaration;
                }
            }
        }
        function getOrCreateExternalHelpersModuleNameIfNeeded(factory2, node, compilerOptions, hasExportStarsToExportValues, hasImportStarOrImportDefault) {
            if (compilerOptions.importHelpers && isEffectiveExternalModule(node, compilerOptions)) {
                const externalHelpersModuleName = getExternalHelpersModuleName(node);
                if (externalHelpersModuleName) {
                    return externalHelpersModuleName;
                }
                const moduleKind = getEmitModuleKind(compilerOptions);
                let create = (hasExportStarsToExportValues || getESModuleInterop(compilerOptions) && hasImportStarOrImportDefault) && moduleKind !== 4 /* System */ && (moduleKind < 5 /* ES2015 */ || node.impliedNodeFormat === 1 /* CommonJS */);
                if (!create) {
                    const helpers = getEmitHelpers(node);
                    if (helpers) {
                        for (const helper of helpers) {
                            if (!helper.scoped) {
                                create = true;
                                break;
                            }
                        }
                    }
                }
                if (create) {
                    const parseNode = getOriginalNode(node, isSourceFile);
                    const emitNode = getOrCreateEmitNode(parseNode);
                    return emitNode.externalHelpersModuleName || (emitNode.externalHelpersModuleName = factory2.createUniqueName(externalHelpersModuleNameText));
                }
            }
        }
        function getLocalNameForExternalImport(factory2, node, sourceFile) {
            const namespaceDeclaration = getNamespaceDeclarationNode(node);
            if (namespaceDeclaration && !isDefaultImport(node) && !isExportNamespaceAsDefaultDeclaration(node)) {
                const name = namespaceDeclaration.name;
                return isGeneratedIdentifier(name) ? name : factory2.createIdentifier(getSourceTextOfNodeFromSourceFile(sourceFile, name) || idText(name));
            }
            if (node.kind === 272 /* ImportDeclaration */ && node.importClause) {
                return factory2.getGeneratedNameForNode(node);
            }
            if (node.kind === 278 /* ExportDeclaration */ && node.moduleSpecifier) {
                return factory2.getGeneratedNameForNode(node);
            }
            return void 0;
        }
        function getExternalModuleNameLiteral(factory2, importNode, sourceFile, host, resolver, compilerOptions) {
            const moduleName = getExternalModuleName(importNode);
            if (moduleName && isStringLiteral(moduleName)) {
                return tryGetModuleNameFromDeclaration(importNode, host, factory2, resolver, compilerOptions) || tryRenameExternalModule(factory2, moduleName, sourceFile) || factory2.cloneNode(moduleName);
            }
            return void 0;
        }
        function tryRenameExternalModule(factory2, moduleName, sourceFile) {
            const rename = sourceFile.renamedDependencies && sourceFile.renamedDependencies.get(moduleName.text);
            return rename ? factory2.createStringLiteral(rename) : void 0;
        }
        function tryGetModuleNameFromFile(factory2, file, host, options) {
            if (!file) {
                return void 0;
            }
            if (file.moduleName) {
                return factory2.createStringLiteral(file.moduleName);
            }
            if (!file.isDeclarationFile && outFile(options)) {
                return factory2.createStringLiteral(getExternalModuleNameFromPath(host, file.fileName));
            }
            return void 0;
        }
        function tryGetModuleNameFromDeclaration(declaration, host, factory2, resolver, compilerOptions) {
            return tryGetModuleNameFromFile(factory2, resolver.getExternalModuleFileFromDeclaration(declaration), host, compilerOptions);
        }
        function getInitializerOfBindingOrAssignmentElement(bindingElement) {
            if (isDeclarationBindingElement(bindingElement)) {
                return bindingElement.initializer;
            }
            if (isPropertyAssignment(bindingElement)) {
                const initializer = bindingElement.initializer;
                return isAssignmentExpression(initializer, 
                /*excludeCompoundAssignment*/
                true) ? initializer.right : void 0;
            }
            if (isShorthandPropertyAssignment(bindingElement)) {
                return bindingElement.objectAssignmentInitializer;
            }
            if (isAssignmentExpression(bindingElement, 
            /*excludeCompoundAssignment*/
            true)) {
                return bindingElement.right;
            }
            if (isSpreadElement(bindingElement)) {
                return getInitializerOfBindingOrAssignmentElement(bindingElement.expression);
            }
        }
        function getTargetOfBindingOrAssignmentElement(bindingElement) {
            if (isDeclarationBindingElement(bindingElement)) {
                return bindingElement.name;
            }
            if (isObjectLiteralElementLike(bindingElement)) {
                switch (bindingElement.kind) {
                    case 303 /* PropertyAssignment */:
                        return getTargetOfBindingOrAssignmentElement(bindingElement.initializer);
                    case 304 /* ShorthandPropertyAssignment */:
                        return bindingElement.name;
                    case 305 /* SpreadAssignment */:
                        return getTargetOfBindingOrAssignmentElement(bindingElement.expression);
                }
                return void 0;
            }
            if (isAssignmentExpression(bindingElement, 
            /*excludeCompoundAssignment*/
            true)) {
                return getTargetOfBindingOrAssignmentElement(bindingElement.left);
            }
            if (isSpreadElement(bindingElement)) {
                return getTargetOfBindingOrAssignmentElement(bindingElement.expression);
            }
            return bindingElement;
        }
        function getRestIndicatorOfBindingOrAssignmentElement(bindingElement) {
            switch (bindingElement.kind) {
                case 169 /* Parameter */:
                case 208 /* BindingElement */:
                    return bindingElement.dotDotDotToken;
                case 230 /* SpreadElement */:
                case 305 /* SpreadAssignment */:
                    return bindingElement;
            }
            return void 0;
        }
        function getPropertyNameOfBindingOrAssignmentElement(bindingElement) {
            const propertyName = tryGetPropertyNameOfBindingOrAssignmentElement(bindingElement);
            Debug.assert(!!propertyName || isSpreadAssignment(bindingElement), "Invalid property name for binding element.");
            return propertyName;
        }
        function tryGetPropertyNameOfBindingOrAssignmentElement(bindingElement) {
            switch (bindingElement.kind) {
                case 208 /* BindingElement */:
                    if (bindingElement.propertyName) {
                        const propertyName = bindingElement.propertyName;
                        if (isPrivateIdentifier(propertyName)) {
                            return Debug.failBadSyntaxKind(propertyName);
                        }
                        return isComputedPropertyName(propertyName) && isStringOrNumericLiteral(propertyName.expression) ? propertyName.expression : propertyName;
                    }
                    break;
                case 303 /* PropertyAssignment */:
                    if (bindingElement.name) {
                        const propertyName = bindingElement.name;
                        if (isPrivateIdentifier(propertyName)) {
                            return Debug.failBadSyntaxKind(propertyName);
                        }
                        return isComputedPropertyName(propertyName) && isStringOrNumericLiteral(propertyName.expression) ? propertyName.expression : propertyName;
                    }
                    break;
                case 305 /* SpreadAssignment */:
                    if (bindingElement.name && isPrivateIdentifier(bindingElement.name)) {
                        return Debug.failBadSyntaxKind(bindingElement.name);
                    }
                    return bindingElement.name;
            }
            const target = getTargetOfBindingOrAssignmentElement(bindingElement);
            if (target && isPropertyName(target)) {
                return target;
            }
        }
        function isStringOrNumericLiteral(node) {
            const kind = node.kind;
            return kind === 11 /* StringLiteral */ || kind === 9 /* NumericLiteral */;
        }
        function getElementsOfBindingOrAssignmentPattern(name) {
            switch (name.kind) {
                case 206 /* ObjectBindingPattern */:
                case 207 /* ArrayBindingPattern */:
                case 209 /* ArrayLiteralExpression */:
                    return name.elements;
                case 210 /* ObjectLiteralExpression */:
                    return name.properties;
            }
        }
        function getJSDocTypeAliasName(fullName) {
            if (fullName) {
                let rightNode = fullName;
                while (true) {
                    if (isIdentifier(rightNode) || !rightNode.body) {
                        return isIdentifier(rightNode) ? rightNode : rightNode.name;
                    }
                    rightNode = rightNode.body;
                }
            }
        }
        function canHaveIllegalType(node) {
            const kind = node.kind;
            return kind === 176 /* Constructor */ || kind === 178 /* SetAccessor */;
        }
        function canHaveIllegalTypeParameters(node) {
            const kind = node.kind;
            return kind === 176 /* Constructor */ || kind === 177 /* GetAccessor */ || kind === 178 /* SetAccessor */;
        }
        function canHaveIllegalDecorators(node) {
            const kind = node.kind;
            return kind === 303 /* PropertyAssignment */ || kind === 304 /* ShorthandPropertyAssignment */ || kind === 262 /* FunctionDeclaration */ || kind === 176 /* Constructor */ || kind === 181 /* IndexSignature */ || kind === 175 /* ClassStaticBlockDeclaration */ || kind === 282 /* MissingDeclaration */ || kind === 243 /* VariableStatement */ || kind === 264 /* InterfaceDeclaration */ || kind === 265 /* TypeAliasDeclaration */ || kind === 266 /* EnumDeclaration */ || kind === 267 /* ModuleDeclaration */ || kind === 271 /* ImportEqualsDeclaration */ || kind === 272 /* ImportDeclaration */ || kind === 270 /* NamespaceExportDeclaration */ || kind === 278 /* ExportDeclaration */ || kind === 277 /* ExportAssignment */;
        }
        function canHaveIllegalModifiers(node) {
            const kind = node.kind;
            return kind === 175 /* ClassStaticBlockDeclaration */ || kind === 303 /* PropertyAssignment */ || kind === 304 /* ShorthandPropertyAssignment */ || kind === 282 /* MissingDeclaration */ || kind === 270 /* NamespaceExportDeclaration */;
        }
        function isQuestionOrExclamationToken(node) {
            return isQuestionToken(node) || isExclamationToken(node);
        }
        function isIdentifierOrThisTypeNode(node) {
            return isIdentifier(node) || isThisTypeNode(node);
        }
        function isReadonlyKeywordOrPlusOrMinusToken(node) {
            return isReadonlyKeyword(node) || isPlusToken(node) || isMinusToken(node);
        }
        function isQuestionOrPlusOrMinusToken(node) {
            return isQuestionToken(node) || isPlusToken(node) || isMinusToken(node);
        }
        function isModuleName(node) {
            return isIdentifier(node) || isStringLiteral(node);
        }
        function isLiteralTypeLikeExpression(node) {
            const kind = node.kind;
            return kind === 106 /* NullKeyword */ || kind === 112 /* TrueKeyword */ || kind === 97 /* FalseKeyword */ || isLiteralExpression(node) || isPrefixUnaryExpression(node);
        }
        function isExponentiationOperator(kind) {
            return kind === 43 /* AsteriskAsteriskToken */;
        }
        function isMultiplicativeOperator(kind) {
            return kind === 42 /* AsteriskToken */ || kind === 44 /* SlashToken */ || kind === 45 /* PercentToken */;
        }
        function isMultiplicativeOperatorOrHigher(kind) {
            return isExponentiationOperator(kind) || isMultiplicativeOperator(kind);
        }
        function isAdditiveOperator(kind) {
            return kind === 40 /* PlusToken */ || kind === 41 /* MinusToken */;
        }
        function isAdditiveOperatorOrHigher(kind) {
            return isAdditiveOperator(kind) || isMultiplicativeOperatorOrHigher(kind);
        }
        function isShiftOperator(kind) {
            return kind === 48 /* LessThanLessThanToken */ || kind === 49 /* GreaterThanGreaterThanToken */ || kind === 50 /* GreaterThanGreaterThanGreaterThanToken */;
        }
        function isShiftOperatorOrHigher(kind) {
            return isShiftOperator(kind) || isAdditiveOperatorOrHigher(kind);
        }
        function isRelationalOperator(kind) {
            return kind === 30 /* LessThanToken */ || kind === 33 /* LessThanEqualsToken */ || kind === 32 /* GreaterThanToken */ || kind === 34 /* GreaterThanEqualsToken */ || kind === 104 /* InstanceOfKeyword */ || kind === 103 /* InKeyword */;
        }
        function isRelationalOperatorOrHigher(kind) {
            return isRelationalOperator(kind) || isShiftOperatorOrHigher(kind);
        }
        function isEqualityOperator(kind) {
            return kind === 35 /* EqualsEqualsToken */ || kind === 37 /* EqualsEqualsEqualsToken */ || kind === 36 /* ExclamationEqualsToken */ || kind === 38 /* ExclamationEqualsEqualsToken */;
        }
        function isEqualityOperatorOrHigher(kind) {
            return isEqualityOperator(kind) || isRelationalOperatorOrHigher(kind);
        }
        function isBitwiseOperator(kind) {
            return kind === 51 /* AmpersandToken */ || kind === 52 /* BarToken */ || kind === 53 /* CaretToken */;
        }
        function isBitwiseOperatorOrHigher(kind) {
            return isBitwiseOperator(kind) || isEqualityOperatorOrHigher(kind);
        }
        function isLogicalOperator2(kind) {
            return kind === 56 /* AmpersandAmpersandToken */ || kind === 57 /* BarBarToken */;
        }
        function isLogicalOperatorOrHigher(kind) {
            return isLogicalOperator2(kind) || isBitwiseOperatorOrHigher(kind);
        }
        function isAssignmentOperatorOrHigher(kind) {
            return kind === 61 /* QuestionQuestionToken */ || isLogicalOperatorOrHigher(kind) || isAssignmentOperator(kind);
        }
        function isBinaryOperator(kind) {
            return isAssignmentOperatorOrHigher(kind) || kind === 28 /* CommaToken */;
        }
        function isBinaryOperatorToken(node) {
            return isBinaryOperator(node.kind);
        }
        function createBinaryExpressionTrampoline(onEnter, onLeft, onOperator, onRight, onExit, foldState) {
            const machine = new BinaryExpressionStateMachine(onEnter, onLeft, onOperator, onRight, onExit, foldState);
            return trampoline;
            function trampoline(node, outerState) {
                const resultHolder = { value: void 0 };
                const stateStack = [BinaryExpressionState.enter];
                const nodeStack = [node];
                const userStateStack = [void 0];
                let stackIndex = 0;
                while (stateStack[stackIndex] !== BinaryExpressionState.done) {
                    stackIndex = stateStack[stackIndex](machine, stackIndex, stateStack, nodeStack, userStateStack, resultHolder, outerState);
                }
                Debug.assertEqual(stackIndex, 0);
                return resultHolder.value;
            }
        }
        function isExportOrDefaultKeywordKind(kind) {
            return kind === 95 /* ExportKeyword */ || kind === 90 /* DefaultKeyword */;
        }
        function isExportOrDefaultModifier(node) {
            const kind = node.kind;
            return isExportOrDefaultKeywordKind(kind);
        }
        function isNonExportDefaultModifier(node) {
            const kind = node.kind;
            return isModifierKind(kind) && !isExportOrDefaultKeywordKind(kind);
        }
        function elideNodes(factory2, nodes) {
            if (nodes === void 0)
                return void 0;
            if (nodes.length === 0)
                return nodes;
            return setTextRange(factory2.createNodeArray([], nodes.hasTrailingComma), nodes);
        }
        function getNodeForGeneratedName(name) {
            var _a;
            const autoGenerate = name.emitNode.autoGenerate;
            if (autoGenerate.flags & 4 /* Node */) {
                const autoGenerateId = autoGenerate.id;
                let node = name;
                let original = node.original;
                while (original) {
                    node = original;
                    const autoGenerate2 = (_a = node.emitNode) == null ? void 0 : _a.autoGenerate;
                    if (isMemberName(node) && (autoGenerate2 === void 0 || !!(autoGenerate2.flags & 4 /* Node */) && autoGenerate2.id !== autoGenerateId)) {
                        break;
                    }
                    original = node.original;
                }
                return node;
            }
            return name;
        }
        function formatGeneratedNamePart(part, generateName) {
            return typeof part === "object" ? formatGeneratedName(
            /*privateName*/
            false, part.prefix, part.node, part.suffix, generateName) : typeof part === "string" ? part.length > 0 && part.charCodeAt(0) === 35 /* hash */ ? part.slice(1) : part : "";
        }
        function formatIdentifier(name, generateName) {
            return typeof name === "string" ? name : formatIdentifierWorker(name, Debug.checkDefined(generateName));
        }
        function formatIdentifierWorker(node, generateName) {
            return isGeneratedPrivateIdentifier(node) ? generateName(node).slice(1) : isGeneratedIdentifier(node) ? generateName(node) : isPrivateIdentifier(node) ? node.escapedText.slice(1) : idText(node);
        }
        function formatGeneratedName(privateName, prefix, baseName, suffix, generateName) {
            prefix = formatGeneratedNamePart(prefix, generateName);
            suffix = formatGeneratedNamePart(suffix, generateName);
            baseName = formatIdentifier(baseName, generateName);
            return `${privateName ? "#" : ""}${prefix}${baseName}${suffix}`;
        }
        function createAccessorPropertyBackingField(factory2, node, modifiers, initializer) {
            return factory2.updatePropertyDeclaration(node, modifiers, factory2.getGeneratedPrivateNameForNode(node.name, 
            /*prefix*/
            void 0, "_accessor_storage"), 
            /*questionOrExclamationToken*/
            void 0, 
            /*type*/
            void 0, initializer);
        }
        function createAccessorPropertyGetRedirector(factory2, node, modifiers, name, receiver = factory2.createThis()) {
            return factory2.createGetAccessorDeclaration(modifiers, name, [], 
            /*type*/
            void 0, factory2.createBlock([
                factory2.createReturnStatement(factory2.createPropertyAccessExpression(receiver, factory2.getGeneratedPrivateNameForNode(node.name, 
                /*prefix*/
                void 0, "_accessor_storage")))
            ]));
        }
        function createAccessorPropertySetRedirector(factory2, node, modifiers, name, receiver = factory2.createThis()) {
            return factory2.createSetAccessorDeclaration(modifiers, name, [factory2.createParameterDeclaration(
                /*modifiers*/
                void 0, 
                /*dotDotDotToken*/
                void 0, "value")], factory2.createBlock([
                factory2.createExpressionStatement(factory2.createAssignment(factory2.createPropertyAccessExpression(receiver, factory2.getGeneratedPrivateNameForNode(node.name, 
                /*prefix*/
                void 0, "_accessor_storage")), factory2.createIdentifier("value")))
            ]));
        }
        function findComputedPropertyNameCacheAssignment(name) {
            let node = name.expression;
            while (true) {
                node = skipOuterExpressions(node);
                if (isCommaListExpression(node)) {
                    node = last(node.elements);
                    continue;
                }
                if (isCommaExpression(node)) {
                    node = node.right;
                    continue;
                }
                if (isAssignmentExpression(node, 
                /*excludeCompoundAssignment*/
                true) && isGeneratedIdentifier(node.left)) {
                    return node;
                }
                break;
            }
        }
        function isSyntheticParenthesizedExpression(node) {
            return isParenthesizedExpression(node) && nodeIsSynthesized(node) && !node.emitNode;
        }
        function flattenCommaListWorker(node, expressions) {
            if (isSyntheticParenthesizedExpression(node)) {
                flattenCommaListWorker(node.expression, expressions);
            }
            else if (isCommaExpression(node)) {
                flattenCommaListWorker(node.left, expressions);
                flattenCommaListWorker(node.right, expressions);
            }
            else if (isCommaListExpression(node)) {
                for (const child of node.elements) {
                    flattenCommaListWorker(child, expressions);
                }
            }
            else {
                expressions.push(node);
            }
        }
        function flattenCommaList(node) {
            const expressions = [];
            flattenCommaListWorker(node, expressions);
            return expressions;
        }
        function containsObjectRestOrSpread(node) {
            if (node.transformFlags & 65536 /* ContainsObjectRestOrSpread */)
                return true;
            if (node.transformFlags & 128 /* ContainsES2018 */) {
                for (const element of getElementsOfBindingOrAssignmentPattern(node)) {
                    const target = getTargetOfBindingOrAssignmentElement(element);
                    if (target && isAssignmentPattern(target)) {
                        if (target.transformFlags & 65536 /* ContainsObjectRestOrSpread */) {
                            return true;
                        }
                        if (target.transformFlags & 128 /* ContainsES2018 */) {
                            if (containsObjectRestOrSpread(target))
                                return true;
                        }
                    }
                }
            }
            return false;
        }
        var BinaryExpressionState, BinaryExpressionStateMachine;
        var init_utilities2 = __esm({
            "src/compiler/factory/utilities.ts"() {
                "use strict";
                init_ts2();
                ((BinaryExpressionState2) => {
                    function enter(machine, stackIndex, stateStack, nodeStack, userStateStack, _resultHolder, outerState) {
                        const prevUserState = stackIndex > 0 ? userStateStack[stackIndex - 1] : void 0;
                        Debug.assertEqual(stateStack[stackIndex], enter);
                        userStateStack[stackIndex] = machine.onEnter(nodeStack[stackIndex], prevUserState, outerState);
                        stateStack[stackIndex] = nextState(machine, enter);
                        return stackIndex;
                    }
                    BinaryExpressionState2.enter = enter;
                    function left(machine, stackIndex, stateStack, nodeStack, userStateStack, _resultHolder, _outerState) {
                        Debug.assertEqual(stateStack[stackIndex], left);
                        Debug.assertIsDefined(machine.onLeft);
                        stateStack[stackIndex] = nextState(machine, left);
                        const nextNode = machine.onLeft(nodeStack[stackIndex].left, userStateStack[stackIndex], nodeStack[stackIndex]);
                        if (nextNode) {
                            checkCircularity(stackIndex, nodeStack, nextNode);
                            return pushStack(stackIndex, stateStack, nodeStack, userStateStack, nextNode);
                        }
                        return stackIndex;
                    }
                    BinaryExpressionState2.left = left;
                    function operator(machine, stackIndex, stateStack, nodeStack, userStateStack, _resultHolder, _outerState) {
                        Debug.assertEqual(stateStack[stackIndex], operator);
                        Debug.assertIsDefined(machine.onOperator);
                        stateStack[stackIndex] = nextState(machine, operator);
                        machine.onOperator(nodeStack[stackIndex].operatorToken, userStateStack[stackIndex], nodeStack[stackIndex]);
                        return stackIndex;
                    }
                    BinaryExpressionState2.operator = operator;
                    function right(machine, stackIndex, stateStack, nodeStack, userStateStack, _resultHolder, _outerState) {
                        Debug.assertEqual(stateStack[stackIndex], right);
                        Debug.assertIsDefined(machine.onRight);
                        stateStack[stackIndex] = nextState(machine, right);
                        const nextNode = machine.onRight(nodeStack[stackIndex].right, userStateStack[stackIndex], nodeStack[stackIndex]);
                        if (nextNode) {
                            checkCircularity(stackIndex, nodeStack, nextNode);
                            return pushStack(stackIndex, stateStack, nodeStack, userStateStack, nextNode);
                        }
                        return stackIndex;
                    }
                    BinaryExpressionState2.right = right;
                    function exit(machine, stackIndex, stateStack, nodeStack, userStateStack, resultHolder, _outerState) {
                        Debug.assertEqual(stateStack[stackIndex], exit);
                        stateStack[stackIndex] = nextState(machine, exit);
                        const result = machine.onExit(nodeStack[stackIndex], userStateStack[stackIndex]);
                        if (stackIndex > 0) {
                            stackIndex--;
                            if (machine.foldState) {
                                const side = stateStack[stackIndex] === exit ? "right" : "left";
                                userStateStack[stackIndex] = machine.foldState(userStateStack[stackIndex], result, side);
                            }
                        }
                        else {
                            resultHolder.value = result;
                        }
                        return stackIndex;
                    }
                    BinaryExpressionState2.exit = exit;
                    function done(_machine, stackIndex, stateStack, _nodeStack, _userStateStack, _resultHolder, _outerState) {
                        Debug.assertEqual(stateStack[stackIndex], done);
                        return stackIndex;
                    }
                    BinaryExpressionState2.done = done;
                    function nextState(machine, currentState) {
                        switch (currentState) {
                            case enter:
                                if (machine.onLeft)
                                    return left;
                            case left:
                                if (machine.onOperator)
                                    return operator;
                            case operator:
                                if (machine.onRight)
                                    return right;
                            case right:
                                return exit;
                            case exit:
                                return done;
                            case done:
                                return done;
                            default:
                                Debug.fail("Invalid state");
                        }
                    }
                    BinaryExpressionState2.nextState = nextState;
                    function pushStack(stackIndex, stateStack, nodeStack, userStateStack, node) {
                        stackIndex++;
                        stateStack[stackIndex] = enter;
                        nodeStack[stackIndex] = node;
                        userStateStack[stackIndex] = void 0;
                        return stackIndex;
                    }
                    function checkCircularity(stackIndex, nodeStack, node) {
                        if (Debug.shouldAssert(2 /* Aggressive */)) {
                            while (stackIndex >= 0) {
                                Debug.assert(nodeStack[stackIndex] !== node, "Circular traversal detected.");
                                stackIndex--;
                            }
                        }
                    }
                })(BinaryExpressionState || (BinaryExpressionState = {}));
                BinaryExpressionStateMachine = class {
                    constructor(onEnter, onLeft, onOperator, onRight, onExit, foldState) {
                        this.onEnter = onEnter;
                        this.onLeft = onLeft;
                        this.onOperator = onOperator;
                        this.onRight = onRight;
                        this.onExit = onExit;
                        this.foldState = foldState;
                    }
                };
            }
        });
        // src/compiler/factory/utilitiesPublic.ts
        function setTextRange(range, location) {
            return location ? setTextRangePosEnd(range, location.pos, location.end) : range;
        }
        function canHaveModifiers(node) {
            const kind = node.kind;
            return kind === 168 /* TypeParameter */ || kind === 169 /* Parameter */ || kind === 171 /* PropertySignature */ || kind === 172 /* PropertyDeclaration */ || kind === 173 /* MethodSignature */ || kind === 174 /* MethodDeclaration */ || kind === 176 /* Constructor */ || kind === 177 /* GetAccessor */ || kind === 178 /* SetAccessor */ || kind === 181 /* IndexSignature */ || kind === 185 /* ConstructorType */ || kind === 218 /* FunctionExpression */ || kind === 219 /* ArrowFunction */ || kind === 231 /* ClassExpression */ || kind === 243 /* VariableStatement */ || kind === 262 /* FunctionDeclaration */ || kind === 263 /* ClassDeclaration */ || kind === 264 /* InterfaceDeclaration */ || kind === 265 /* TypeAliasDeclaration */ || kind === 266 /* EnumDeclaration */ || kind === 267 /* ModuleDeclaration */ || kind === 271 /* ImportEqualsDeclaration */ || kind === 272 /* ImportDeclaration */ || kind === 277 /* ExportAssignment */ || kind === 278 /* ExportDeclaration */;
        }
        function canHaveDecorators(node) {
            const kind = node.kind;
            return kind === 169 /* Parameter */ || kind === 172 /* PropertyDeclaration */ || kind === 174 /* MethodDeclaration */ || kind === 177 /* GetAccessor */ || kind === 178 /* SetAccessor */ || kind === 231 /* ClassExpression */ || kind === 263 /* ClassDeclaration */;
        }
        var init_utilitiesPublic2 = __esm({
            "src/compiler/factory/utilitiesPublic.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/parser.ts
        function visitNode2(cbNode, node) {
            return node && cbNode(node);
        }
        function visitNodes(cbNode, cbNodes, nodes) {
            if (nodes) {
                if (cbNodes) {
                    return cbNodes(nodes);
                }
                for (const node of nodes) {
                    const result = cbNode(node);
                    if (result) {
                        return result;
                    }
                }
            }
        }
        function isJSDocLikeText(text, start) {
            return text.charCodeAt(start + 1) === 42 /* asterisk */ && text.charCodeAt(start + 2) === 42 /* asterisk */ && text.charCodeAt(start + 3) !== 47 /* slash */;
        }
        function isFileProbablyExternalModule(sourceFile) {
            return forEach(sourceFile.statements, isAnExternalModuleIndicatorNode) || getImportMetaIfNecessary(sourceFile);
        }
        function isAnExternalModuleIndicatorNode(node) {
            return canHaveModifiers(node) && hasModifierOfKind(node, 95 /* ExportKeyword */) || isImportEqualsDeclaration(node) && isExternalModuleReference(node.moduleReference) || isImportDeclaration(node) || isExportAssignment(node) || isExportDeclaration(node) ? node : void 0;
        }
        function getImportMetaIfNecessary(sourceFile) {
            return sourceFile.flags & 8388608 /* PossiblyContainsImportMeta */ ? walkTreeForImportMeta(sourceFile) : void 0;
        }
        function walkTreeForImportMeta(node) {
            return isImportMeta2(node) ? node : forEachChild(node, walkTreeForImportMeta);
        }
        function hasModifierOfKind(node, kind) {
            return some(node.modifiers, (m) => m.kind === kind);
        }
        function isImportMeta2(node) {
            return isMetaProperty(node) && node.keywordToken === 102 /* ImportKeyword */ && node.name.escapedText === "meta";
        }
        function forEachChildInCallOrConstructSignature(node, cbNode, cbNodes) {
            return visitNodes(cbNode, cbNodes, node.typeParameters) || visitNodes(cbNode, cbNodes, node.parameters) || visitNode2(cbNode, node.type);
        }
        function forEachChildInUnionOrIntersectionType(node, cbNode, cbNodes) {
            return visitNodes(cbNode, cbNodes, node.types);
        }
        function forEachChildInParenthesizedTypeOrTypeOperator(node, cbNode, _cbNodes) {
            return visitNode2(cbNode, node.type);
        }
        function forEachChildInObjectOrArrayBindingPattern(node, cbNode, cbNodes) {
            return visitNodes(cbNode, cbNodes, node.elements);
        }
        function forEachChildInCallOrNewExpression(node, cbNode, cbNodes) {
            return visitNode2(cbNode, node.expression) || // TODO: should we separate these branches out?
                visitNode2(cbNode, node.questionDotToken) || visitNodes(cbNode, cbNodes, node.typeArguments) || visitNodes(cbNode, cbNodes, node.arguments);
        }
        function forEachChildInBlock(node, cbNode, cbNodes) {
            return visitNodes(cbNode, cbNodes, node.statements);
        }
        function forEachChildInContinueOrBreakStatement(node, cbNode, _cbNodes) {
            return visitNode2(cbNode, node.label);
        }
        function forEachChildInClassDeclarationOrExpression(node, cbNode, cbNodes) {
            return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name) || visitNodes(cbNode, cbNodes, node.typeParameters) || visitNodes(cbNode, cbNodes, node.heritageClauses) || visitNodes(cbNode, cbNodes, node.members);
        }
        function forEachChildInNamedImportsOrExports(node, cbNode, cbNodes) {
            return visitNodes(cbNode, cbNodes, node.elements);
        }
        function forEachChildInImportOrExportSpecifier(node, cbNode, _cbNodes) {
            return visitNode2(cbNode, node.propertyName) || visitNode2(cbNode, node.name);
        }
        function forEachChildInJsxOpeningOrSelfClosingElement(node, cbNode, cbNodes) {
            return visitNode2(cbNode, node.tagName) || visitNodes(cbNode, cbNodes, node.typeArguments) || visitNode2(cbNode, node.attributes);
        }
        function forEachChildInOptionalRestOrJSDocParameterModifier(node, cbNode, _cbNodes) {
            return visitNode2(cbNode, node.type);
        }
        function forEachChildInJSDocParameterOrPropertyTag(node, cbNode, cbNodes) {
            return visitNode2(cbNode, node.tagName) || (node.isNameFirst ? visitNode2(cbNode, node.name) || visitNode2(cbNode, node.typeExpression) : visitNode2(cbNode, node.typeExpression) || visitNode2(cbNode, node.name)) || (typeof node.comment === "string" ? void 0 : visitNodes(cbNode, cbNodes, node.comment));
        }
        function forEachChildInJSDocTypeLikeTag(node, cbNode, cbNodes) {
            return visitNode2(cbNode, node.tagName) || visitNode2(cbNode, node.typeExpression) || (typeof node.comment === "string" ? void 0 : visitNodes(cbNode, cbNodes, node.comment));
        }
        function forEachChildInJSDocLinkCodeOrPlain(node, cbNode, _cbNodes) {
            return visitNode2(cbNode, node.name);
        }
        function forEachChildInJSDocTag(node, cbNode, cbNodes) {
            return visitNode2(cbNode, node.tagName) || (typeof node.comment === "string" ? void 0 : visitNodes(cbNode, cbNodes, node.comment));
        }
        function forEachChildInPartiallyEmittedExpression(node, cbNode, _cbNodes) {
            return visitNode2(cbNode, node.expression);
        }
        function forEachChild(node, cbNode, cbNodes) {
            if (node === void 0 || node.kind <= 165 /* LastToken */) {
                return;
            }
            const fn = forEachChildTable[node.kind];
            return fn === void 0 ? void 0 : fn(node, cbNode, cbNodes);
        }
        function forEachChildRecursively(rootNode, cbNode, cbNodes) {
            const queue = gatherPossibleChildren(rootNode);
            const parents = [];
            while (parents.length < queue.length) {
                parents.push(rootNode);
            }
            while (queue.length !== 0) {
                const current = queue.pop();
                const parent2 = parents.pop();
                if (isArray(current)) {
                    if (cbNodes) {
                        const res = cbNodes(current, parent2);
                        if (res) {
                            if (res === "skip")
                                continue;
                            return res;
                        }
                    }
                    for (let i = current.length - 1; i >= 0; --i) {
                        queue.push(current[i]);
                        parents.push(parent2);
                    }
                }
                else {
                    const res = cbNode(current, parent2);
                    if (res) {
                        if (res === "skip")
                            continue;
                        return res;
                    }
                    if (current.kind >= 166 /* FirstNode */) {
                        for (const child of gatherPossibleChildren(current)) {
                            queue.push(child);
                            parents.push(current);
                        }
                    }
                }
            }
        }
        function gatherPossibleChildren(node) {
            const children = [];
            forEachChild(node, addWorkItem, addWorkItem);
            return children;
            function addWorkItem(n) {
                children.unshift(n);
            }
        }
        function setExternalModuleIndicator(sourceFile) {
            sourceFile.externalModuleIndicator = isFileProbablyExternalModule(sourceFile);
        }
        function createSourceFile(fileName, sourceText, languageVersionOrOptions, setParentNodes = false, scriptKind) {
            var _a, _b, _c, _d;
            (_a = tracing) == null ? void 0 : _a.push(tracing.Phase.Parse, "createSourceFile", { path: fileName }, 
            /*separateBeginAndEnd*/
            true);
            mark("beforeParse");
            let result;
            (_b = perfLogger) == null ? void 0 : _b.logStartParseSourceFile(fileName);
            const { languageVersion, setExternalModuleIndicator: overrideSetExternalModuleIndicator, impliedNodeFormat: format, jsDocParsingMode } = typeof languageVersionOrOptions === "object" ? languageVersionOrOptions : { languageVersion: languageVersionOrOptions };
            if (languageVersion === 100 /* JSON */) {
                result = Parser.parseSourceFile(fileName, sourceText, languageVersion, 
                /*syntaxCursor*/
                void 0, setParentNodes, 6 /* JSON */, noop, jsDocParsingMode);
            }
            else {
                const setIndicator = format === void 0 ? overrideSetExternalModuleIndicator : (file) => {
                    file.impliedNodeFormat = format;
                    return (overrideSetExternalModuleIndicator || setExternalModuleIndicator)(file);
                };
                result = Parser.parseSourceFile(fileName, sourceText, languageVersion, 
                /*syntaxCursor*/
                void 0, setParentNodes, scriptKind, setIndicator, jsDocParsingMode);
            }
            (_c = perfLogger) == null ? void 0 : _c.logStopParseSourceFile();
            mark("afterParse");
            measure("Parse", "beforeParse", "afterParse");
            (_d = tracing) == null ? void 0 : _d.pop();
            return result;
        }
        function parseIsolatedEntityName(text, languageVersion) {
            return Parser.parseIsolatedEntityName(text, languageVersion);
        }
        function parseJsonText(fileName, sourceText) {
            return Parser.parseJsonText(fileName, sourceText);
        }
        function isExternalModule(file) {
            return file.externalModuleIndicator !== void 0;
        }
        function updateSourceFile(sourceFile, newText, textChangeRange, aggressiveChecks = false) {
            const newSourceFile = IncrementalParser.updateSourceFile(sourceFile, newText, textChangeRange, aggressiveChecks);
            newSourceFile.flags |= sourceFile.flags & 12582912 /* PermanentlySetIncrementalFlags */;
            return newSourceFile;
        }
        function parseIsolatedJSDocComment(content, start, length2) {
            const result = Parser.JSDocParser.parseIsolatedJSDocComment(content, start, length2);
            if (result && result.jsDoc) {
                Parser.fixupParentReferences(result.jsDoc);
            }
            return result;
        }
        function parseJSDocTypeExpressionForTests(content, start, length2) {
            return Parser.JSDocParser.parseJSDocTypeExpressionForTests(content, start, length2);
        }
        function isDeclarationFileName(fileName) {
            return getDeclarationFileExtension(fileName) !== void 0;
        }
        function getDeclarationFileExtension(fileName) {
            const standardExtension = getAnyExtensionFromPath(fileName, supportedDeclarationExtensions, 
            /*ignoreCase*/
            false);
            if (standardExtension) {
                return standardExtension;
            }
            if (fileExtensionIs(fileName, ".ts" /* Ts */)) {
                const index = getBaseFileName(fileName).lastIndexOf(".d.");
                if (index >= 0) {
                    return fileName.substring(index);
                }
            }
            return void 0;
        }
        function parseResolutionMode(mode, pos, end, reportDiagnostic) {
            if (!mode) {
                return void 0;
            }
            if (mode === "import") {
                return 99 /* ESNext */;
            }
            if (mode === "require") {
                return 1 /* CommonJS */;
            }
            reportDiagnostic(pos, end - pos, Diagnostics.resolution_mode_should_be_either_require_or_import);
            return void 0;
        }
        function processCommentPragmas(context, sourceText) {
            const pragmas = [];
            for (const range of getLeadingCommentRanges(sourceText, 0) || emptyArray) {
                const comment = sourceText.substring(range.pos, range.end);
                extractPragmas(pragmas, range, comment);
            }
            context.pragmas = /* @__PURE__ */ new Map();
            for (const pragma of pragmas) {
                if (context.pragmas.has(pragma.name)) {
                    const currentValue = context.pragmas.get(pragma.name);
                    if (currentValue instanceof Array) {
                        currentValue.push(pragma.args);
                    }
                    else {
                        context.pragmas.set(pragma.name, [currentValue, pragma.args]);
                    }
                    continue;
                }
                context.pragmas.set(pragma.name, pragma.args);
            }
        }
        function processPragmasIntoFields(context, reportDiagnostic) {
            context.checkJsDirective = void 0;
            context.referencedFiles = [];
            context.typeReferenceDirectives = [];
            context.libReferenceDirectives = [];
            context.amdDependencies = [];
            context.hasNoDefaultLib = false;
            context.pragmas.forEach((entryOrList, key) => {
                switch (key) {
                    case "reference": {
                        const referencedFiles = context.referencedFiles;
                        const typeReferenceDirectives = context.typeReferenceDirectives;
                        const libReferenceDirectives = context.libReferenceDirectives;
                        forEach(toArray(entryOrList), (arg) => {
                            const { types, lib, path, ["resolution-mode"]: res } = arg.arguments;
                            if (arg.arguments["no-default-lib"]) {
                                context.hasNoDefaultLib = true;
                            }
                            else if (types) {
                                const parsed = parseResolutionMode(res, types.pos, types.end, reportDiagnostic);
                                typeReferenceDirectives.push({ pos: types.pos, end: types.end, fileName: types.value, ...parsed ? { resolutionMode: parsed } : {} });
                            }
                            else if (lib) {
                                libReferenceDirectives.push({ pos: lib.pos, end: lib.end, fileName: lib.value });
                            }
                            else if (path) {
                                referencedFiles.push({ pos: path.pos, end: path.end, fileName: path.value });
                            }
                            else {
                                reportDiagnostic(arg.range.pos, arg.range.end - arg.range.pos, Diagnostics.Invalid_reference_directive_syntax);
                            }
                        });
                        break;
                    }
                    case "amd-dependency": {
                        context.amdDependencies = map(toArray(entryOrList), (x) => ({ name: x.arguments.name, path: x.arguments.path }));
                        break;
                    }
                    case "amd-module": {
                        if (entryOrList instanceof Array) {
                            for (const entry of entryOrList) {
                                if (context.moduleName) {
                                    reportDiagnostic(entry.range.pos, entry.range.end - entry.range.pos, Diagnostics.An_AMD_module_cannot_have_multiple_name_assignments);
                                }
                                context.moduleName = entry.arguments.name;
                            }
                        }
                        else {
                            context.moduleName = entryOrList.arguments.name;
                        }
                        break;
                    }
                    case "ts-nocheck":
                    case "ts-check": {
                        forEach(toArray(entryOrList), (entry) => {
                            if (!context.checkJsDirective || entry.range.pos > context.checkJsDirective.pos) {
                                context.checkJsDirective = {
                                    enabled: key === "ts-check",
                                    end: entry.range.end,
                                    pos: entry.range.pos
                                };
                            }
                        });
                        break;
                    }
                    case "jsx":
                    case "jsxfrag":
                    case "jsximportsource":
                    case "jsxruntime":
                        return;
                    default:
                        Debug.fail("Unhandled pragma kind");
                }
            });
        }
        function getNamedArgRegEx(name) {
            if (namedArgRegExCache.has(name)) {
                return namedArgRegExCache.get(name);
            }
            const result = new RegExp(`(\\s${name}\\s*=\\s*)(?:(?:'([^']*)')|(?:"([^"]*)"))`, "im");
            namedArgRegExCache.set(name, result);
            return result;
        }
        function extractPragmas(pragmas, range, text) {
            const tripleSlash = range.kind === 2 /* SingleLineCommentTrivia */ && tripleSlashXMLCommentStartRegEx.exec(text);
            if (tripleSlash) {
                const name = tripleSlash[1].toLowerCase();
                const pragma = commentPragmas[name];
                if (!pragma || !(pragma.kind & 1 /* TripleSlashXML */)) {
                    return;
                }
                if (pragma.args) {
                    const argument = {};
                    for (const arg of pragma.args) {
                        const matcher = getNamedArgRegEx(arg.name);
                        const matchResult = matcher.exec(text);
                        if (!matchResult && !arg.optional) {
                            return;
                        }
                        else if (matchResult) {
                            const value = matchResult[2] || matchResult[3];
                            if (arg.captureSpan) {
                                const startPos = range.pos + matchResult.index + matchResult[1].length + 1;
                                argument[arg.name] = {
                                    value,
                                    pos: startPos,
                                    end: startPos + value.length
                                };
                            }
                            else {
                                argument[arg.name] = value;
                            }
                        }
                    }
                    pragmas.push({ name, args: { arguments: argument, range } });
                }
                else {
                    pragmas.push({ name, args: { arguments: {}, range } });
                }
                return;
            }
            const singleLine = range.kind === 2 /* SingleLineCommentTrivia */ && singleLinePragmaRegEx.exec(text);
            if (singleLine) {
                return addPragmaForMatch(pragmas, range, 2 /* SingleLine */, singleLine);
            }
            if (range.kind === 3 /* MultiLineCommentTrivia */) {
                const multiLinePragmaRegEx = /@(\S+)(\s+.*)?$/gim;
                let multiLineMatch;
                while (multiLineMatch = multiLinePragmaRegEx.exec(text)) {
                    addPragmaForMatch(pragmas, range, 4 /* MultiLine */, multiLineMatch);
                }
            }
        }
        function addPragmaForMatch(pragmas, range, kind, match) {
            if (!match)
                return;
            const name = match[1].toLowerCase();
            const pragma = commentPragmas[name];
            if (!pragma || !(pragma.kind & kind)) {
                return;
            }
            const args = match[2];
            const argument = getNamedPragmaArguments(pragma, args);
            if (argument === "fail")
                return;
            pragmas.push({ name, args: { arguments: argument, range } });
            return;
        }
        function getNamedPragmaArguments(pragma, text) {
            if (!text)
                return {};
            if (!pragma.args)
                return {};
            const args = text.trim().split(/\s+/);
            const argMap = {};
            for (let i = 0; i < pragma.args.length; i++) {
                const argument = pragma.args[i];
                if (!args[i] && !argument.optional) {
                    return "fail";
                }
                if (argument.captureSpan) {
                    return Debug.fail("Capture spans not yet implemented for non-xml pragmas");
                }
                argMap[argument.name] = args[i];
            }
            return argMap;
        }
        function tagNamesAreEquivalent(lhs, rhs) {
            if (lhs.kind !== rhs.kind) {
                return false;
            }
            if (lhs.kind === 80 /* Identifier */) {
                return lhs.escapedText === rhs.escapedText;
            }
            if (lhs.kind === 110 /* ThisKeyword */) {
                return true;
            }
            if (lhs.kind === 295 /* JsxNamespacedName */) {
                return lhs.namespace.escapedText === rhs.namespace.escapedText && lhs.name.escapedText === rhs.name.escapedText;
            }
            return lhs.name.escapedText === rhs.name.escapedText && tagNamesAreEquivalent(lhs.expression, rhs.expression);
        }
        var NodeConstructor, TokenConstructor, IdentifierConstructor, PrivateIdentifierConstructor, SourceFileConstructor, parseBaseNodeFactory, parseNodeFactory, forEachChildTable, Parser, IncrementalParser, namedArgRegExCache, tripleSlashXMLCommentStartRegEx, singleLinePragmaRegEx;
        var init_parser = __esm({
            "src/compiler/parser.ts"() {
                "use strict";
                init_ts2();
                init_ts_performance();
                parseBaseNodeFactory = {
                    createBaseSourceFileNode: (kind) => new (SourceFileConstructor || (SourceFileConstructor = objectAllocator.getSourceFileConstructor()))(kind, -1, -1),
                    createBaseIdentifierNode: (kind) => new (IdentifierConstructor || (IdentifierConstructor = objectAllocator.getIdentifierConstructor()))(kind, -1, -1),
                    createBasePrivateIdentifierNode: (kind) => new (PrivateIdentifierConstructor || (PrivateIdentifierConstructor = objectAllocator.getPrivateIdentifierConstructor()))(kind, -1, -1),
                    createBaseTokenNode: (kind) => new (TokenConstructor || (TokenConstructor = objectAllocator.getTokenConstructor()))(kind, -1, -1),
                    createBaseNode: (kind) => new (NodeConstructor || (NodeConstructor = objectAllocator.getNodeConstructor()))(kind, -1, -1)
                };
                parseNodeFactory = createNodeFactory(1 /* NoParenthesizerRules */, parseBaseNodeFactory);
                forEachChildTable = {
                    [166 /* QualifiedName */]: function forEachChildInQualifiedName(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.left) || visitNode2(cbNode, node.right);
                    },
                    [168 /* TypeParameter */]: function forEachChildInTypeParameter(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name) || visitNode2(cbNode, node.constraint) || visitNode2(cbNode, node.default) || visitNode2(cbNode, node.expression);
                    },
                    [304 /* ShorthandPropertyAssignment */]: function forEachChildInShorthandPropertyAssignment(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name) || visitNode2(cbNode, node.questionToken) || visitNode2(cbNode, node.exclamationToken) || visitNode2(cbNode, node.equalsToken) || visitNode2(cbNode, node.objectAssignmentInitializer);
                    },
                    [305 /* SpreadAssignment */]: function forEachChildInSpreadAssignment(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression);
                    },
                    [169 /* Parameter */]: function forEachChildInParameter(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.dotDotDotToken) || visitNode2(cbNode, node.name) || visitNode2(cbNode, node.questionToken) || visitNode2(cbNode, node.type) || visitNode2(cbNode, node.initializer);
                    },
                    [172 /* PropertyDeclaration */]: function forEachChildInPropertyDeclaration(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name) || visitNode2(cbNode, node.questionToken) || visitNode2(cbNode, node.exclamationToken) || visitNode2(cbNode, node.type) || visitNode2(cbNode, node.initializer);
                    },
                    [171 /* PropertySignature */]: function forEachChildInPropertySignature(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name) || visitNode2(cbNode, node.questionToken) || visitNode2(cbNode, node.type) || visitNode2(cbNode, node.initializer);
                    },
                    [303 /* PropertyAssignment */]: function forEachChildInPropertyAssignment(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name) || visitNode2(cbNode, node.questionToken) || visitNode2(cbNode, node.exclamationToken) || visitNode2(cbNode, node.initializer);
                    },
                    [260 /* VariableDeclaration */]: function forEachChildInVariableDeclaration(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.name) || visitNode2(cbNode, node.exclamationToken) || visitNode2(cbNode, node.type) || visitNode2(cbNode, node.initializer);
                    },
                    [208 /* BindingElement */]: function forEachChildInBindingElement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.dotDotDotToken) || visitNode2(cbNode, node.propertyName) || visitNode2(cbNode, node.name) || visitNode2(cbNode, node.initializer);
                    },
                    [181 /* IndexSignature */]: function forEachChildInIndexSignature(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNodes(cbNode, cbNodes, node.typeParameters) || visitNodes(cbNode, cbNodes, node.parameters) || visitNode2(cbNode, node.type);
                    },
                    [185 /* ConstructorType */]: function forEachChildInConstructorType(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNodes(cbNode, cbNodes, node.typeParameters) || visitNodes(cbNode, cbNodes, node.parameters) || visitNode2(cbNode, node.type);
                    },
                    [184 /* FunctionType */]: function forEachChildInFunctionType(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNodes(cbNode, cbNodes, node.typeParameters) || visitNodes(cbNode, cbNodes, node.parameters) || visitNode2(cbNode, node.type);
                    },
                    [179 /* CallSignature */]: forEachChildInCallOrConstructSignature,
                    [180 /* ConstructSignature */]: forEachChildInCallOrConstructSignature,
                    [174 /* MethodDeclaration */]: function forEachChildInMethodDeclaration(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.asteriskToken) || visitNode2(cbNode, node.name) || visitNode2(cbNode, node.questionToken) || visitNode2(cbNode, node.exclamationToken) || visitNodes(cbNode, cbNodes, node.typeParameters) || visitNodes(cbNode, cbNodes, node.parameters) || visitNode2(cbNode, node.type) || visitNode2(cbNode, node.body);
                    },
                    [173 /* MethodSignature */]: function forEachChildInMethodSignature(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name) || visitNode2(cbNode, node.questionToken) || visitNodes(cbNode, cbNodes, node.typeParameters) || visitNodes(cbNode, cbNodes, node.parameters) || visitNode2(cbNode, node.type);
                    },
                    [176 /* Constructor */]: function forEachChildInConstructor(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name) || visitNodes(cbNode, cbNodes, node.typeParameters) || visitNodes(cbNode, cbNodes, node.parameters) || visitNode2(cbNode, node.type) || visitNode2(cbNode, node.body);
                    },
                    [177 /* GetAccessor */]: function forEachChildInGetAccessor(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name) || visitNodes(cbNode, cbNodes, node.typeParameters) || visitNodes(cbNode, cbNodes, node.parameters) || visitNode2(cbNode, node.type) || visitNode2(cbNode, node.body);
                    },
                    [178 /* SetAccessor */]: function forEachChildInSetAccessor(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name) || visitNodes(cbNode, cbNodes, node.typeParameters) || visitNodes(cbNode, cbNodes, node.parameters) || visitNode2(cbNode, node.type) || visitNode2(cbNode, node.body);
                    },
                    [262 /* FunctionDeclaration */]: function forEachChildInFunctionDeclaration(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.asteriskToken) || visitNode2(cbNode, node.name) || visitNodes(cbNode, cbNodes, node.typeParameters) || visitNodes(cbNode, cbNodes, node.parameters) || visitNode2(cbNode, node.type) || visitNode2(cbNode, node.body);
                    },
                    [218 /* FunctionExpression */]: function forEachChildInFunctionExpression(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.asteriskToken) || visitNode2(cbNode, node.name) || visitNodes(cbNode, cbNodes, node.typeParameters) || visitNodes(cbNode, cbNodes, node.parameters) || visitNode2(cbNode, node.type) || visitNode2(cbNode, node.body);
                    },
                    [219 /* ArrowFunction */]: function forEachChildInArrowFunction(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNodes(cbNode, cbNodes, node.typeParameters) || visitNodes(cbNode, cbNodes, node.parameters) || visitNode2(cbNode, node.type) || visitNode2(cbNode, node.equalsGreaterThanToken) || visitNode2(cbNode, node.body);
                    },
                    [175 /* ClassStaticBlockDeclaration */]: function forEachChildInClassStaticBlockDeclaration(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.body);
                    },
                    [183 /* TypeReference */]: function forEachChildInTypeReference(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.typeName) || visitNodes(cbNode, cbNodes, node.typeArguments);
                    },
                    [182 /* TypePredicate */]: function forEachChildInTypePredicate(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.assertsModifier) || visitNode2(cbNode, node.parameterName) || visitNode2(cbNode, node.type);
                    },
                    [186 /* TypeQuery */]: function forEachChildInTypeQuery(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.exprName) || visitNodes(cbNode, cbNodes, node.typeArguments);
                    },
                    [187 /* TypeLiteral */]: function forEachChildInTypeLiteral(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.members);
                    },
                    [188 /* ArrayType */]: function forEachChildInArrayType(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.elementType);
                    },
                    [189 /* TupleType */]: function forEachChildInTupleType(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.elements);
                    },
                    [192 /* UnionType */]: forEachChildInUnionOrIntersectionType,
                    [193 /* IntersectionType */]: forEachChildInUnionOrIntersectionType,
                    [194 /* ConditionalType */]: function forEachChildInConditionalType(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.checkType) || visitNode2(cbNode, node.extendsType) || visitNode2(cbNode, node.trueType) || visitNode2(cbNode, node.falseType);
                    },
                    [195 /* InferType */]: function forEachChildInInferType(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.typeParameter);
                    },
                    [205 /* ImportType */]: function forEachChildInImportType(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.argument) || visitNode2(cbNode, node.attributes) || visitNode2(cbNode, node.qualifier) || visitNodes(cbNode, cbNodes, node.typeArguments);
                    },
                    [302 /* ImportTypeAssertionContainer */]: function forEachChildInImportTypeAssertionContainer(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.assertClause);
                    },
                    [196 /* ParenthesizedType */]: forEachChildInParenthesizedTypeOrTypeOperator,
                    [198 /* TypeOperator */]: forEachChildInParenthesizedTypeOrTypeOperator,
                    [199 /* IndexedAccessType */]: function forEachChildInIndexedAccessType(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.objectType) || visitNode2(cbNode, node.indexType);
                    },
                    [200 /* MappedType */]: function forEachChildInMappedType(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.readonlyToken) || visitNode2(cbNode, node.typeParameter) || visitNode2(cbNode, node.nameType) || visitNode2(cbNode, node.questionToken) || visitNode2(cbNode, node.type) || visitNodes(cbNode, cbNodes, node.members);
                    },
                    [201 /* LiteralType */]: function forEachChildInLiteralType(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.literal);
                    },
                    [202 /* NamedTupleMember */]: function forEachChildInNamedTupleMember(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.dotDotDotToken) || visitNode2(cbNode, node.name) || visitNode2(cbNode, node.questionToken) || visitNode2(cbNode, node.type);
                    },
                    [206 /* ObjectBindingPattern */]: forEachChildInObjectOrArrayBindingPattern,
                    [207 /* ArrayBindingPattern */]: forEachChildInObjectOrArrayBindingPattern,
                    [209 /* ArrayLiteralExpression */]: function forEachChildInArrayLiteralExpression(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.elements);
                    },
                    [210 /* ObjectLiteralExpression */]: function forEachChildInObjectLiteralExpression(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.properties);
                    },
                    [211 /* PropertyAccessExpression */]: function forEachChildInPropertyAccessExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression) || visitNode2(cbNode, node.questionDotToken) || visitNode2(cbNode, node.name);
                    },
                    [212 /* ElementAccessExpression */]: function forEachChildInElementAccessExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression) || visitNode2(cbNode, node.questionDotToken) || visitNode2(cbNode, node.argumentExpression);
                    },
                    [213 /* CallExpression */]: forEachChildInCallOrNewExpression,
                    [214 /* NewExpression */]: forEachChildInCallOrNewExpression,
                    [215 /* TaggedTemplateExpression */]: function forEachChildInTaggedTemplateExpression(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.tag) || visitNode2(cbNode, node.questionDotToken) || visitNodes(cbNode, cbNodes, node.typeArguments) || visitNode2(cbNode, node.template);
                    },
                    [216 /* TypeAssertionExpression */]: function forEachChildInTypeAssertionExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.type) || visitNode2(cbNode, node.expression);
                    },
                    [217 /* ParenthesizedExpression */]: function forEachChildInParenthesizedExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression);
                    },
                    [220 /* DeleteExpression */]: function forEachChildInDeleteExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression);
                    },
                    [221 /* TypeOfExpression */]: function forEachChildInTypeOfExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression);
                    },
                    [222 /* VoidExpression */]: function forEachChildInVoidExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression);
                    },
                    [224 /* PrefixUnaryExpression */]: function forEachChildInPrefixUnaryExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.operand);
                    },
                    [229 /* YieldExpression */]: function forEachChildInYieldExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.asteriskToken) || visitNode2(cbNode, node.expression);
                    },
                    [223 /* AwaitExpression */]: function forEachChildInAwaitExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression);
                    },
                    [225 /* PostfixUnaryExpression */]: function forEachChildInPostfixUnaryExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.operand);
                    },
                    [226 /* BinaryExpression */]: function forEachChildInBinaryExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.left) || visitNode2(cbNode, node.operatorToken) || visitNode2(cbNode, node.right);
                    },
                    [234 /* AsExpression */]: function forEachChildInAsExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression) || visitNode2(cbNode, node.type);
                    },
                    [235 /* NonNullExpression */]: function forEachChildInNonNullExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression);
                    },
                    [238 /* SatisfiesExpression */]: function forEachChildInSatisfiesExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression) || visitNode2(cbNode, node.type);
                    },
                    [236 /* MetaProperty */]: function forEachChildInMetaProperty(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.name);
                    },
                    [227 /* ConditionalExpression */]: function forEachChildInConditionalExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.condition) || visitNode2(cbNode, node.questionToken) || visitNode2(cbNode, node.whenTrue) || visitNode2(cbNode, node.colonToken) || visitNode2(cbNode, node.whenFalse);
                    },
                    [230 /* SpreadElement */]: function forEachChildInSpreadElement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression);
                    },
                    [241 /* Block */]: forEachChildInBlock,
                    [268 /* ModuleBlock */]: forEachChildInBlock,
                    [312 /* SourceFile */]: function forEachChildInSourceFile(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.statements) || visitNode2(cbNode, node.endOfFileToken);
                    },
                    [243 /* VariableStatement */]: function forEachChildInVariableStatement(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.declarationList);
                    },
                    [261 /* VariableDeclarationList */]: function forEachChildInVariableDeclarationList(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.declarations);
                    },
                    [244 /* ExpressionStatement */]: function forEachChildInExpressionStatement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression);
                    },
                    [245 /* IfStatement */]: function forEachChildInIfStatement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression) || visitNode2(cbNode, node.thenStatement) || visitNode2(cbNode, node.elseStatement);
                    },
                    [246 /* DoStatement */]: function forEachChildInDoStatement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.statement) || visitNode2(cbNode, node.expression);
                    },
                    [247 /* WhileStatement */]: function forEachChildInWhileStatement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression) || visitNode2(cbNode, node.statement);
                    },
                    [248 /* ForStatement */]: function forEachChildInForStatement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.initializer) || visitNode2(cbNode, node.condition) || visitNode2(cbNode, node.incrementor) || visitNode2(cbNode, node.statement);
                    },
                    [249 /* ForInStatement */]: function forEachChildInForInStatement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.initializer) || visitNode2(cbNode, node.expression) || visitNode2(cbNode, node.statement);
                    },
                    [250 /* ForOfStatement */]: function forEachChildInForOfStatement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.awaitModifier) || visitNode2(cbNode, node.initializer) || visitNode2(cbNode, node.expression) || visitNode2(cbNode, node.statement);
                    },
                    [251 /* ContinueStatement */]: forEachChildInContinueOrBreakStatement,
                    [252 /* BreakStatement */]: forEachChildInContinueOrBreakStatement,
                    [253 /* ReturnStatement */]: function forEachChildInReturnStatement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression);
                    },
                    [254 /* WithStatement */]: function forEachChildInWithStatement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression) || visitNode2(cbNode, node.statement);
                    },
                    [255 /* SwitchStatement */]: function forEachChildInSwitchStatement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression) || visitNode2(cbNode, node.caseBlock);
                    },
                    [269 /* CaseBlock */]: function forEachChildInCaseBlock(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.clauses);
                    },
                    [296 /* CaseClause */]: function forEachChildInCaseClause(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.expression) || visitNodes(cbNode, cbNodes, node.statements);
                    },
                    [297 /* DefaultClause */]: function forEachChildInDefaultClause(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.statements);
                    },
                    [256 /* LabeledStatement */]: function forEachChildInLabeledStatement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.label) || visitNode2(cbNode, node.statement);
                    },
                    [257 /* ThrowStatement */]: function forEachChildInThrowStatement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression);
                    },
                    [258 /* TryStatement */]: function forEachChildInTryStatement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.tryBlock) || visitNode2(cbNode, node.catchClause) || visitNode2(cbNode, node.finallyBlock);
                    },
                    [299 /* CatchClause */]: function forEachChildInCatchClause(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.variableDeclaration) || visitNode2(cbNode, node.block);
                    },
                    [170 /* Decorator */]: function forEachChildInDecorator(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression);
                    },
                    [263 /* ClassDeclaration */]: forEachChildInClassDeclarationOrExpression,
                    [231 /* ClassExpression */]: forEachChildInClassDeclarationOrExpression,
                    [264 /* InterfaceDeclaration */]: function forEachChildInInterfaceDeclaration(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name) || visitNodes(cbNode, cbNodes, node.typeParameters) || visitNodes(cbNode, cbNodes, node.heritageClauses) || visitNodes(cbNode, cbNodes, node.members);
                    },
                    [265 /* TypeAliasDeclaration */]: function forEachChildInTypeAliasDeclaration(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name) || visitNodes(cbNode, cbNodes, node.typeParameters) || visitNode2(cbNode, node.type);
                    },
                    [266 /* EnumDeclaration */]: function forEachChildInEnumDeclaration(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name) || visitNodes(cbNode, cbNodes, node.members);
                    },
                    [306 /* EnumMember */]: function forEachChildInEnumMember(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.name) || visitNode2(cbNode, node.initializer);
                    },
                    [267 /* ModuleDeclaration */]: function forEachChildInModuleDeclaration(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name) || visitNode2(cbNode, node.body);
                    },
                    [271 /* ImportEqualsDeclaration */]: function forEachChildInImportEqualsDeclaration(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name) || visitNode2(cbNode, node.moduleReference);
                    },
                    [272 /* ImportDeclaration */]: function forEachChildInImportDeclaration(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.importClause) || visitNode2(cbNode, node.moduleSpecifier) || visitNode2(cbNode, node.attributes);
                    },
                    [273 /* ImportClause */]: function forEachChildInImportClause(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.name) || visitNode2(cbNode, node.namedBindings);
                    },
                    [300 /* ImportAttributes */]: function forEachChildInImportAttributes(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.elements);
                    },
                    [301 /* ImportAttribute */]: function forEachChildInImportAttribute(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.name) || visitNode2(cbNode, node.value);
                    },
                    [270 /* NamespaceExportDeclaration */]: function forEachChildInNamespaceExportDeclaration(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.name);
                    },
                    [274 /* NamespaceImport */]: function forEachChildInNamespaceImport(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.name);
                    },
                    [280 /* NamespaceExport */]: function forEachChildInNamespaceExport(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.name);
                    },
                    [275 /* NamedImports */]: forEachChildInNamedImportsOrExports,
                    [279 /* NamedExports */]: forEachChildInNamedImportsOrExports,
                    [278 /* ExportDeclaration */]: function forEachChildInExportDeclaration(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.exportClause) || visitNode2(cbNode, node.moduleSpecifier) || visitNode2(cbNode, node.attributes);
                    },
                    [276 /* ImportSpecifier */]: forEachChildInImportOrExportSpecifier,
                    [281 /* ExportSpecifier */]: forEachChildInImportOrExportSpecifier,
                    [277 /* ExportAssignment */]: function forEachChildInExportAssignment(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers) || visitNode2(cbNode, node.expression);
                    },
                    [228 /* TemplateExpression */]: function forEachChildInTemplateExpression(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.head) || visitNodes(cbNode, cbNodes, node.templateSpans);
                    },
                    [239 /* TemplateSpan */]: function forEachChildInTemplateSpan(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression) || visitNode2(cbNode, node.literal);
                    },
                    [203 /* TemplateLiteralType */]: function forEachChildInTemplateLiteralType(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.head) || visitNodes(cbNode, cbNodes, node.templateSpans);
                    },
                    [204 /* TemplateLiteralTypeSpan */]: function forEachChildInTemplateLiteralTypeSpan(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.type) || visitNode2(cbNode, node.literal);
                    },
                    [167 /* ComputedPropertyName */]: function forEachChildInComputedPropertyName(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression);
                    },
                    [298 /* HeritageClause */]: function forEachChildInHeritageClause(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.types);
                    },
                    [233 /* ExpressionWithTypeArguments */]: function forEachChildInExpressionWithTypeArguments(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.expression) || visitNodes(cbNode, cbNodes, node.typeArguments);
                    },
                    [283 /* ExternalModuleReference */]: function forEachChildInExternalModuleReference(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression);
                    },
                    [282 /* MissingDeclaration */]: function forEachChildInMissingDeclaration(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.modifiers);
                    },
                    [361 /* CommaListExpression */]: function forEachChildInCommaListExpression(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.elements);
                    },
                    [284 /* JsxElement */]: function forEachChildInJsxElement(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.openingElement) || visitNodes(cbNode, cbNodes, node.children) || visitNode2(cbNode, node.closingElement);
                    },
                    [288 /* JsxFragment */]: function forEachChildInJsxFragment(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.openingFragment) || visitNodes(cbNode, cbNodes, node.children) || visitNode2(cbNode, node.closingFragment);
                    },
                    [285 /* JsxSelfClosingElement */]: forEachChildInJsxOpeningOrSelfClosingElement,
                    [286 /* JsxOpeningElement */]: forEachChildInJsxOpeningOrSelfClosingElement,
                    [292 /* JsxAttributes */]: function forEachChildInJsxAttributes(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.properties);
                    },
                    [291 /* JsxAttribute */]: function forEachChildInJsxAttribute(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.name) || visitNode2(cbNode, node.initializer);
                    },
                    [293 /* JsxSpreadAttribute */]: function forEachChildInJsxSpreadAttribute(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.expression);
                    },
                    [294 /* JsxExpression */]: function forEachChildInJsxExpression(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.dotDotDotToken) || visitNode2(cbNode, node.expression);
                    },
                    [287 /* JsxClosingElement */]: function forEachChildInJsxClosingElement(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.tagName);
                    },
                    [295 /* JsxNamespacedName */]: function forEachChildInJsxNamespacedName(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.namespace) || visitNode2(cbNode, node.name);
                    },
                    [190 /* OptionalType */]: forEachChildInOptionalRestOrJSDocParameterModifier,
                    [191 /* RestType */]: forEachChildInOptionalRestOrJSDocParameterModifier,
                    [316 /* JSDocTypeExpression */]: forEachChildInOptionalRestOrJSDocParameterModifier,
                    [322 /* JSDocNonNullableType */]: forEachChildInOptionalRestOrJSDocParameterModifier,
                    [321 /* JSDocNullableType */]: forEachChildInOptionalRestOrJSDocParameterModifier,
                    [323 /* JSDocOptionalType */]: forEachChildInOptionalRestOrJSDocParameterModifier,
                    [325 /* JSDocVariadicType */]: forEachChildInOptionalRestOrJSDocParameterModifier,
                    [324 /* JSDocFunctionType */]: function forEachChildInJSDocFunctionType(node, cbNode, cbNodes) {
                        return visitNodes(cbNode, cbNodes, node.parameters) || visitNode2(cbNode, node.type);
                    },
                    [327 /* JSDoc */]: function forEachChildInJSDoc(node, cbNode, cbNodes) {
                        return (typeof node.comment === "string" ? void 0 : visitNodes(cbNode, cbNodes, node.comment)) || visitNodes(cbNode, cbNodes, node.tags);
                    },
                    [354 /* JSDocSeeTag */]: function forEachChildInJSDocSeeTag(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.tagName) || visitNode2(cbNode, node.name) || (typeof node.comment === "string" ? void 0 : visitNodes(cbNode, cbNodes, node.comment));
                    },
                    [317 /* JSDocNameReference */]: function forEachChildInJSDocNameReference(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.name);
                    },
                    [318 /* JSDocMemberName */]: function forEachChildInJSDocMemberName(node, cbNode, _cbNodes) {
                        return visitNode2(cbNode, node.left) || visitNode2(cbNode, node.right);
                    },
                    [348 /* JSDocParameterTag */]: forEachChildInJSDocParameterOrPropertyTag,
                    [355 /* JSDocPropertyTag */]: forEachChildInJSDocParameterOrPropertyTag,
                    [337 /* JSDocAuthorTag */]: function forEachChildInJSDocAuthorTag(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.tagName) || (typeof node.comment === "string" ? void 0 : visitNodes(cbNode, cbNodes, node.comment));
                    },
                    [336 /* JSDocImplementsTag */]: function forEachChildInJSDocImplementsTag(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.tagName) || visitNode2(cbNode, node.class) || (typeof node.comment === "string" ? void 0 : visitNodes(cbNode, cbNodes, node.comment));
                    },
                    [335 /* JSDocAugmentsTag */]: function forEachChildInJSDocAugmentsTag(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.tagName) || visitNode2(cbNode, node.class) || (typeof node.comment === "string" ? void 0 : visitNodes(cbNode, cbNodes, node.comment));
                    },
                    [352 /* JSDocTemplateTag */]: function forEachChildInJSDocTemplateTag(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.tagName) || visitNode2(cbNode, node.constraint) || visitNodes(cbNode, cbNodes, node.typeParameters) || (typeof node.comment === "string" ? void 0 : visitNodes(cbNode, cbNodes, node.comment));
                    },
                    [353 /* JSDocTypedefTag */]: function forEachChildInJSDocTypedefTag(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.tagName) || (node.typeExpression && node.typeExpression.kind === 316 /* JSDocTypeExpression */ ? visitNode2(cbNode, node.typeExpression) || visitNode2(cbNode, node.fullName) || (typeof node.comment === "string" ? void 0 : visitNodes(cbNode, cbNodes, node.comment)) : visitNode2(cbNode, node.fullName) || visitNode2(cbNode, node.typeExpression) || (typeof node.comment === "string" ? void 0 : visitNodes(cbNode, cbNodes, node.comment)));
                    },
                    [345 /* JSDocCallbackTag */]: function forEachChildInJSDocCallbackTag(node, cbNode, cbNodes) {
                        return visitNode2(cbNode, node.tagName) || visitNode2(cbNode, node.fullName) || visitNode2(cbNode, node.typeExpression) || (typeof node.comment === "string" ? void 0 : visitNodes(cbNode, cbNodes, node.comment));
                    },
                    [349 /* JSDocReturnTag */]: forEachChildInJSDocTypeLikeTag,
                    [351 /* JSDocTypeTag */]: forEachChildInJSDocTypeLikeTag,
                    [350 /* JSDocThisTag */]: forEachChildInJSDocTypeLikeTag,
                    [347 /* JSDocEnumTag */]: forEachChildInJSDocTypeLikeTag,
                    [357 /* JSDocSatisfiesTag */]: forEachChildInJSDocTypeLikeTag,
                    [356 /* JSDocThrowsTag */]: forEachChildInJSDocTypeLikeTag,
                    [346 /* JSDocOverloadTag */]: forEachChildInJSDocTypeLikeTag,
                    [330 /* JSDocSignature */]: function forEachChildInJSDocSignature(node, cbNode, _cbNodes) {
                        return forEach(node.typeParameters, cbNode) || forEach(node.parameters, cbNode) || visitNode2(cbNode, node.type);
                    },
                    [331 /* JSDocLink */]: forEachChildInJSDocLinkCodeOrPlain,
                    [332 /* JSDocLinkCode */]: forEachChildInJSDocLinkCodeOrPlain,
                    [333 /* JSDocLinkPlain */]: forEachChildInJSDocLinkCodeOrPlain,
                    [329 /* JSDocTypeLiteral */]: function forEachChildInJSDocTypeLiteral(node, cbNode, _cbNodes) {
                        return forEach(node.jsDocPropertyTags, cbNode);
                    },
                    [334 /* JSDocTag */]: forEachChildInJSDocTag,
                    [339 /* JSDocClassTag */]: forEachChildInJSDocTag,
                    [340 /* JSDocPublicTag */]: forEachChildInJSDocTag,
                    [341 /* JSDocPrivateTag */]: forEachChildInJSDocTag,
                    [342 /* JSDocProtectedTag */]: forEachChildInJSDocTag,
                    [343 /* JSDocReadonlyTag */]: forEachChildInJSDocTag,
                    [338 /* JSDocDeprecatedTag */]: forEachChildInJSDocTag,
                    [344 /* JSDocOverrideTag */]: forEachChildInJSDocTag,
                    [360 /* PartiallyEmittedExpression */]: forEachChildInPartiallyEmittedExpression
                };
                ((Parser2) => {
                    var scanner2 = createScanner(99 /* Latest */, 
                    /*skipTrivia*/
                    true);
                    var disallowInAndDecoratorContext = 8192 /* DisallowInContext */ | 32768 /* DecoratorContext */;
                    var NodeConstructor2;
                    var TokenConstructor2;
                    var IdentifierConstructor2;
                    var PrivateIdentifierConstructor2;
                    var SourceFileConstructor2;
                    function countNode(node) {
                        nodeCount++;
                        return node;
                    }
                    var baseNodeFactory = {
                        createBaseSourceFileNode: (kind) => countNode(new SourceFileConstructor2(kind, 
                        /*pos*/
                        0, 
                        /*end*/
                        0)),
                        createBaseIdentifierNode: (kind) => countNode(new IdentifierConstructor2(kind, 
                        /*pos*/
                        0, 
                        /*end*/
                        0)),
                        createBasePrivateIdentifierNode: (kind) => countNode(new PrivateIdentifierConstructor2(kind, 
                        /*pos*/
                        0, 
                        /*end*/
                        0)),
                        createBaseTokenNode: (kind) => countNode(new TokenConstructor2(kind, 
                        /*pos*/
                        0, 
                        /*end*/
                        0)),
                        createBaseNode: (kind) => countNode(new NodeConstructor2(kind, 
                        /*pos*/
                        0, 
                        /*end*/
                        0))
                    };
                    var factory2 = createNodeFactory(1 /* NoParenthesizerRules */ | 2 /* NoNodeConverters */ | 8 /* NoOriginalNode */, baseNodeFactory);
                    var { createNodeArray: factoryCreateNodeArray, createNumericLiteral: factoryCreateNumericLiteral, createStringLiteral: factoryCreateStringLiteral, createLiteralLikeNode: factoryCreateLiteralLikeNode, createIdentifier: factoryCreateIdentifier, createPrivateIdentifier: factoryCreatePrivateIdentifier, createToken: factoryCreateToken, createArrayLiteralExpression: factoryCreateArrayLiteralExpression, createObjectLiteralExpression: factoryCreateObjectLiteralExpression, createPropertyAccessExpression: factoryCreatePropertyAccessExpression, createPropertyAccessChain: factoryCreatePropertyAccessChain, createElementAccessExpression: factoryCreateElementAccessExpression, createElementAccessChain: factoryCreateElementAccessChain, createCallExpression: factoryCreateCallExpression, createCallChain: factoryCreateCallChain, createNewExpression: factoryCreateNewExpression, createParenthesizedExpression: factoryCreateParenthesizedExpression, createBlock: factoryCreateBlock, createVariableStatement: factoryCreateVariableStatement, createExpressionStatement: factoryCreateExpressionStatement, createIfStatement: factoryCreateIfStatement, createWhileStatement: factoryCreateWhileStatement, createForStatement: factoryCreateForStatement, createForOfStatement: factoryCreateForOfStatement, createVariableDeclaration: factoryCreateVariableDeclaration, createVariableDeclarationList: factoryCreateVariableDeclarationList } = factory2;
                    var fileName;
                    var sourceFlags;
                    var sourceText;
                    var languageVersion;
                    var scriptKind;
                    var languageVariant;
                    var parseDiagnostics;
                    var jsDocDiagnostics;
                    var syntaxCursor;
                    var currentToken;
                    var nodeCount;
                    var identifiers;
                    var identifierCount;
                    var parsingContext;
                    var notParenthesizedArrow;
                    var contextFlags;
                    var topLevel = true;
                    var parseErrorBeforeNextFinishedNode = false;
                    function parseSourceFile(fileName2, sourceText2, languageVersion2, syntaxCursor2, setParentNodes = false, scriptKind2, setExternalModuleIndicatorOverride, jsDocParsingMode = 0 /* ParseAll */) {
                        var _a;
                        scriptKind2 = ensureScriptKind(fileName2, scriptKind2);
                        if (scriptKind2 === 6 /* JSON */) {
                            const result2 = parseJsonText2(fileName2, sourceText2, languageVersion2, syntaxCursor2, setParentNodes);
                            convertToJson(result2, (_a = result2.statements[0]) == null ? void 0 : _a.expression, result2.parseDiagnostics, 
                            /*returnValue*/
                            false, 
                            /*jsonConversionNotifier*/
                            void 0);
                            result2.referencedFiles = emptyArray;
                            result2.typeReferenceDirectives = emptyArray;
                            result2.libReferenceDirectives = emptyArray;
                            result2.amdDependencies = emptyArray;
                            result2.hasNoDefaultLib = false;
                            result2.pragmas = emptyMap;
                            return result2;
                        }
                        initializeState(fileName2, sourceText2, languageVersion2, syntaxCursor2, scriptKind2, jsDocParsingMode);
                        const result = parseSourceFileWorker(languageVersion2, setParentNodes, scriptKind2, setExternalModuleIndicatorOverride || setExternalModuleIndicator, jsDocParsingMode);
                        clearState();
                        return result;
                    }
                    Parser2.parseSourceFile = parseSourceFile;
                    function parseIsolatedEntityName2(content, languageVersion2) {
                        initializeState("", content, languageVersion2, 
                        /*syntaxCursor*/
                        void 0, 1 /* JS */, 0 /* ParseAll */);
                        nextToken();
                        const entityName = parseEntityName(
                        /*allowReservedWords*/
                        true);
                        const isValid = token() === 1 /* EndOfFileToken */ && !parseDiagnostics.length;
                        clearState();
                        return isValid ? entityName : void 0;
                    }
                    Parser2.parseIsolatedEntityName = parseIsolatedEntityName2;
                    function parseJsonText2(fileName2, sourceText2, languageVersion2 = 2 /* ES2015 */, syntaxCursor2, setParentNodes = false) {
                        initializeState(fileName2, sourceText2, languageVersion2, syntaxCursor2, 6 /* JSON */, 0 /* ParseAll */);
                        sourceFlags = contextFlags;
                        nextToken();
                        const pos = getNodePos();
                        let statements, endOfFileToken;
                        if (token() === 1 /* EndOfFileToken */) {
                            statements = createNodeArray([], pos, pos);
                            endOfFileToken = parseTokenNode();
                        }
                        else {
                            let expressions;
                            while (token() !== 1 /* EndOfFileToken */) {
                                let expression2;
                                switch (token()) {
                                    case 23 /* OpenBracketToken */:
                                        expression2 = parseArrayLiteralExpression();
                                        break;
                                    case 112 /* TrueKeyword */:
                                    case 97 /* FalseKeyword */:
                                    case 106 /* NullKeyword */:
                                        expression2 = parseTokenNode();
                                        break;
                                    case 41 /* MinusToken */:
                                        if (lookAhead(() => nextToken() === 9 /* NumericLiteral */ && nextToken() !== 59 /* ColonToken */)) {
                                            expression2 = parsePrefixUnaryExpression();
                                        }
                                        else {
                                            expression2 = parseObjectLiteralExpression();
                                        }
                                        break;
                                    case 9 /* NumericLiteral */:
                                    case 11 /* StringLiteral */:
                                        if (lookAhead(() => nextToken() !== 59 /* ColonToken */)) {
                                            expression2 = parseLiteralNode();
                                            break;
                                        }
                                    default:
                                        expression2 = parseObjectLiteralExpression();
                                        break;
                                }
                                if (expressions && isArray(expressions)) {
                                    expressions.push(expression2);
                                }
                                else if (expressions) {
                                    expressions = [expressions, expression2];
                                }
                                else {
                                    expressions = expression2;
                                    if (token() !== 1 /* EndOfFileToken */) {
                                        parseErrorAtCurrentToken(Diagnostics.Unexpected_token);
                                    }
                                }
                            }
                            const expression = isArray(expressions) ? finishNode(factoryCreateArrayLiteralExpression(expressions), pos) : Debug.checkDefined(expressions);
                            const statement = factoryCreateExpressionStatement(expression);
                            finishNode(statement, pos);
                            statements = createNodeArray([statement], pos);
                            endOfFileToken = parseExpectedToken(1 /* EndOfFileToken */, Diagnostics.Unexpected_token);
                        }
                        const sourceFile = createSourceFile2(fileName2, 2 /* ES2015 */, 6 /* JSON */, 
                        /*isDeclarationFile*/
                        false, statements, endOfFileToken, sourceFlags, noop);
                        if (setParentNodes) {
                            fixupParentReferences(sourceFile);
                        }
                        sourceFile.nodeCount = nodeCount;
                        sourceFile.identifierCount = identifierCount;
                        sourceFile.identifiers = identifiers;
                        sourceFile.parseDiagnostics = attachFileToDiagnostics(parseDiagnostics, sourceFile);
                        if (jsDocDiagnostics) {
                            sourceFile.jsDocDiagnostics = attachFileToDiagnostics(jsDocDiagnostics, sourceFile);
                        }
                        const result = sourceFile;
                        clearState();
                        return result;
                    }
                    Parser2.parseJsonText = parseJsonText2;
                    function initializeState(_fileName, _sourceText, _languageVersion, _syntaxCursor, _scriptKind, _jsDocParsingMode) {
                        NodeConstructor2 = objectAllocator.getNodeConstructor();
                        TokenConstructor2 = objectAllocator.getTokenConstructor();
                        IdentifierConstructor2 = objectAllocator.getIdentifierConstructor();
                        PrivateIdentifierConstructor2 = objectAllocator.getPrivateIdentifierConstructor();
                        SourceFileConstructor2 = objectAllocator.getSourceFileConstructor();
                        fileName = normalizePath(_fileName);
                        sourceText = _sourceText;
                        languageVersion = _languageVersion;
                        syntaxCursor = _syntaxCursor;
                        scriptKind = _scriptKind;
                        languageVariant = getLanguageVariant(_scriptKind);
                        parseDiagnostics = [];
                        parsingContext = 0;
                        identifiers = /* @__PURE__ */ new Map();
                        identifierCount = 0;
                        nodeCount = 0;
                        sourceFlags = 0;
                        topLevel = true;
                        switch (scriptKind) {
                            case 1 /* JS */:
                            case 2 /* JSX */:
                                contextFlags = 524288 /* JavaScriptFile */;
                                break;
                            case 6 /* JSON */:
                                contextFlags = 524288 /* JavaScriptFile */ | 134217728 /* JsonFile */;
                                break;
                            default:
                                contextFlags = 0 /* None */;
                                break;
                        }
                        parseErrorBeforeNextFinishedNode = false;
                        scanner2.setText(sourceText);
                        scanner2.setOnError(scanError);
                        scanner2.setScriptTarget(languageVersion);
                        scanner2.setLanguageVariant(languageVariant);
                        scanner2.setScriptKind(scriptKind);
                        scanner2.setJSDocParsingMode(_jsDocParsingMode);
                    }
                    function clearState() {
                        scanner2.clearCommentDirectives();
                        scanner2.setText("");
                        scanner2.setOnError(void 0);
                        scanner2.setScriptKind(0 /* Unknown */);
                        scanner2.setJSDocParsingMode(0 /* ParseAll */);
                        sourceText = void 0;
                        languageVersion = void 0;
                        syntaxCursor = void 0;
                        scriptKind = void 0;
                        languageVariant = void 0;
                        sourceFlags = 0;
                        parseDiagnostics = void 0;
                        jsDocDiagnostics = void 0;
                        parsingContext = 0;
                        identifiers = void 0;
                        notParenthesizedArrow = void 0;
                        topLevel = true;
                    }
                    function parseSourceFileWorker(languageVersion2, setParentNodes, scriptKind2, setExternalModuleIndicator2, jsDocParsingMode) {
                        const isDeclarationFile = isDeclarationFileName(fileName);
                        if (isDeclarationFile) {
                            contextFlags |= 33554432 /* Ambient */;
                        }
                        sourceFlags = contextFlags;
                        nextToken();
                        const statements = parseList(0 /* SourceElements */, parseStatement);
                        Debug.assert(token() === 1 /* EndOfFileToken */);
                        const endHasJSDoc = hasPrecedingJSDocComment();
                        const endOfFileToken = withJSDoc(parseTokenNode(), endHasJSDoc);
                        const sourceFile = createSourceFile2(fileName, languageVersion2, scriptKind2, isDeclarationFile, statements, endOfFileToken, sourceFlags, setExternalModuleIndicator2);
                        processCommentPragmas(sourceFile, sourceText);
                        processPragmasIntoFields(sourceFile, reportPragmaDiagnostic);
                        sourceFile.commentDirectives = scanner2.getCommentDirectives();
                        sourceFile.nodeCount = nodeCount;
                        sourceFile.identifierCount = identifierCount;
                        sourceFile.identifiers = identifiers;
                        sourceFile.parseDiagnostics = attachFileToDiagnostics(parseDiagnostics, sourceFile);
                        sourceFile.jsDocParsingMode = jsDocParsingMode;
                        if (jsDocDiagnostics) {
                            sourceFile.jsDocDiagnostics = attachFileToDiagnostics(jsDocDiagnostics, sourceFile);
                        }
                        if (setParentNodes) {
                            fixupParentReferences(sourceFile);
                        }
                        return sourceFile;
                        function reportPragmaDiagnostic(pos, end, diagnostic) {
                            parseDiagnostics.push(createDetachedDiagnostic(fileName, sourceText, pos, end, diagnostic));
                        }
                    }
                    let hasDeprecatedTag = false;
                    function withJSDoc(node, hasJSDoc) {
                        if (!hasJSDoc) {
                            return node;
                        }
                        Debug.assert(!node.jsDoc);
                        const jsDoc = mapDefined(getJSDocCommentRanges(node, sourceText), (comment) => JSDocParser.parseJSDocComment(node, comment.pos, comment.end - comment.pos));
                        if (jsDoc.length)
                            node.jsDoc = jsDoc;
                        if (hasDeprecatedTag) {
                            hasDeprecatedTag = false;
                            node.flags |= 536870912 /* Deprecated */;
                        }
                        return node;
                    }
                    function reparseTopLevelAwait(sourceFile) {
                        const savedSyntaxCursor = syntaxCursor;
                        const baseSyntaxCursor = IncrementalParser.createSyntaxCursor(sourceFile);
                        syntaxCursor = { currentNode: currentNode2 };
                        const statements = [];
                        const savedParseDiagnostics = parseDiagnostics;
                        parseDiagnostics = [];
                        let pos = 0;
                        let start = findNextStatementWithAwait(sourceFile.statements, 0);
                        while (start !== -1) {
                            const prevStatement = sourceFile.statements[pos];
                            const nextStatement = sourceFile.statements[start];
                            addRange(statements, sourceFile.statements, pos, start);
                            pos = findNextStatementWithoutAwait(sourceFile.statements, start);
                            const diagnosticStart = findIndex(savedParseDiagnostics, (diagnostic) => diagnostic.start >= prevStatement.pos);
                            const diagnosticEnd = diagnosticStart >= 0 ? findIndex(savedParseDiagnostics, (diagnostic) => diagnostic.start >= nextStatement.pos, diagnosticStart) : -1;
                            if (diagnosticStart >= 0) {
                                addRange(parseDiagnostics, savedParseDiagnostics, diagnosticStart, diagnosticEnd >= 0 ? diagnosticEnd : void 0);
                            }
                            speculationHelper(() => {
                                const savedContextFlags = contextFlags;
                                contextFlags |= 65536 /* AwaitContext */;
                                scanner2.resetTokenState(nextStatement.pos);
                                nextToken();
                                while (token() !== 1 /* EndOfFileToken */) {
                                    const startPos = scanner2.getTokenFullStart();
                                    const statement = parseListElement(0 /* SourceElements */, parseStatement);
                                    statements.push(statement);
                                    if (startPos === scanner2.getTokenFullStart()) {
                                        nextToken();
                                    }
                                    if (pos >= 0) {
                                        const nonAwaitStatement = sourceFile.statements[pos];
                                        if (statement.end === nonAwaitStatement.pos) {
                                            break;
                                        }
                                        if (statement.end > nonAwaitStatement.pos) {
                                            pos = findNextStatementWithoutAwait(sourceFile.statements, pos + 1);
                                        }
                                    }
                                }
                                contextFlags = savedContextFlags;
                            }, 2 /* Reparse */);
                            start = pos >= 0 ? findNextStatementWithAwait(sourceFile.statements, pos) : -1;
                        }
                        if (pos >= 0) {
                            const prevStatement = sourceFile.statements[pos];
                            addRange(statements, sourceFile.statements, pos);
                            const diagnosticStart = findIndex(savedParseDiagnostics, (diagnostic) => diagnostic.start >= prevStatement.pos);
                            if (diagnosticStart >= 0) {
                                addRange(parseDiagnostics, savedParseDiagnostics, diagnosticStart);
                            }
                        }
                        syntaxCursor = savedSyntaxCursor;
                        return factory2.updateSourceFile(sourceFile, setTextRange(factoryCreateNodeArray(statements), sourceFile.statements));
                        function containsPossibleTopLevelAwait(node) {
                            return !(node.flags & 65536 /* AwaitContext */) && !!(node.transformFlags & 67108864 /* ContainsPossibleTopLevelAwait */);
                        }
                        function findNextStatementWithAwait(statements2, start2) {
                            for (let i = start2; i < statements2.length; i++) {
                                if (containsPossibleTopLevelAwait(statements2[i])) {
                                    return i;
                                }
                            }
                            return -1;
                        }
                        function findNextStatementWithoutAwait(statements2, start2) {
                            for (let i = start2; i < statements2.length; i++) {
                                if (!containsPossibleTopLevelAwait(statements2[i])) {
                                    return i;
                                }
                            }
                            return -1;
                        }
                        function currentNode2(position) {
                            const node = baseSyntaxCursor.currentNode(position);
                            if (topLevel && node && containsPossibleTopLevelAwait(node)) {
                                node.intersectsChange = true;
                            }
                            return node;
                        }
                    }
                    function fixupParentReferences(rootNode) {
                        setParentRecursive(rootNode, 
                        /*incremental*/
                        true);
                    }
                    Parser2.fixupParentReferences = fixupParentReferences;
                    function createSourceFile2(fileName2, languageVersion2, scriptKind2, isDeclarationFile, statements, endOfFileToken, flags, setExternalModuleIndicator2) {
                        let sourceFile = factory2.createSourceFile(statements, endOfFileToken, flags);
                        setTextRangePosWidth(sourceFile, 0, sourceText.length);
                        setFields(sourceFile);
                        if (!isDeclarationFile && isExternalModule(sourceFile) && sourceFile.transformFlags & 67108864 /* ContainsPossibleTopLevelAwait */) {
                            const oldSourceFile = sourceFile;
                            sourceFile = reparseTopLevelAwait(sourceFile);
                            if (oldSourceFile !== sourceFile)
                                setFields(sourceFile);
                        }
                        return sourceFile;
                        function setFields(sourceFile2) {
                            sourceFile2.text = sourceText;
                            sourceFile2.bindDiagnostics = [];
                            sourceFile2.bindSuggestionDiagnostics = void 0;
                            sourceFile2.languageVersion = languageVersion2;
                            sourceFile2.fileName = fileName2;
                            sourceFile2.languageVariant = getLanguageVariant(scriptKind2);
                            sourceFile2.isDeclarationFile = isDeclarationFile;
                            sourceFile2.scriptKind = scriptKind2;
                            setExternalModuleIndicator2(sourceFile2);
                            sourceFile2.setExternalModuleIndicator = setExternalModuleIndicator2;
                        }
                    }
                    function setContextFlag(val, flag) {
                        if (val) {
                            contextFlags |= flag;
                        }
                        else {
                            contextFlags &= ~flag;
                        }
                    }
                    function setDisallowInContext(val) {
                        setContextFlag(val, 8192 /* DisallowInContext */);
                    }
                    function setYieldContext(val) {
                        setContextFlag(val, 16384 /* YieldContext */);
                    }
                    function setDecoratorContext(val) {
                        setContextFlag(val, 32768 /* DecoratorContext */);
                    }
                    function setAwaitContext(val) {
                        setContextFlag(val, 65536 /* AwaitContext */);
                    }
                    function doOutsideOfContext(context, func) {
                        const contextFlagsToClear = context & contextFlags;
                        if (contextFlagsToClear) {
                            setContextFlag(
                            /*val*/
                            false, contextFlagsToClear);
                            const result = func();
                            setContextFlag(
                            /*val*/
                            true, contextFlagsToClear);
                            return result;
                        }
                        return func();
                    }
                    function doInsideOfContext(context, func) {
                        const contextFlagsToSet = context & ~contextFlags;
                        if (contextFlagsToSet) {
                            setContextFlag(
                            /*val*/
                            true, contextFlagsToSet);
                            const result = func();
                            setContextFlag(
                            /*val*/
                            false, contextFlagsToSet);
                            return result;
                        }
                        return func();
                    }
                    function allowInAnd(func) {
                        return doOutsideOfContext(8192 /* DisallowInContext */, func);
                    }
                    function disallowInAnd(func) {
                        return doInsideOfContext(8192 /* DisallowInContext */, func);
                    }
                    function allowConditionalTypesAnd(func) {
                        return doOutsideOfContext(131072 /* DisallowConditionalTypesContext */, func);
                    }
                    function disallowConditionalTypesAnd(func) {
                        return doInsideOfContext(131072 /* DisallowConditionalTypesContext */, func);
                    }
                    function doInYieldContext(func) {
                        return doInsideOfContext(16384 /* YieldContext */, func);
                    }
                    function doInDecoratorContext(func) {
                        return doInsideOfContext(32768 /* DecoratorContext */, func);
                    }
                    function doInAwaitContext(func) {
                        return doInsideOfContext(65536 /* AwaitContext */, func);
                    }
                    function doOutsideOfAwaitContext(func) {
                        return doOutsideOfContext(65536 /* AwaitContext */, func);
                    }
                    function doInYieldAndAwaitContext(func) {
                        return doInsideOfContext(16384 /* YieldContext */ | 65536 /* AwaitContext */, func);
                    }
                    function doOutsideOfYieldAndAwaitContext(func) {
                        return doOutsideOfContext(16384 /* YieldContext */ | 65536 /* AwaitContext */, func);
                    }
                    function inContext(flags) {
                        return (contextFlags & flags) !== 0;
                    }
                    function inYieldContext() {
                        return inContext(16384 /* YieldContext */);
                    }
                    function inDisallowInContext() {
                        return inContext(8192 /* DisallowInContext */);
                    }
                    function inDisallowConditionalTypesContext() {
                        return inContext(131072 /* DisallowConditionalTypesContext */);
                    }
                    function inDecoratorContext() {
                        return inContext(32768 /* DecoratorContext */);
                    }
                    function inAwaitContext() {
                        return inContext(65536 /* AwaitContext */);
                    }
                    function parseErrorAtCurrentToken(message, ...args) {
                        return parseErrorAt(scanner2.getTokenStart(), scanner2.getTokenEnd(), message, ...args);
                    }
                    function parseErrorAtPosition(start, length2, message, ...args) {
                        const lastError = lastOrUndefined(parseDiagnostics);
                        let result;
                        if (!lastError || start !== lastError.start) {
                            result = createDetachedDiagnostic(fileName, sourceText, start, length2, message, ...args);
                            parseDiagnostics.push(result);
                        }
                        parseErrorBeforeNextFinishedNode = true;
                        return result;
                    }
                    function parseErrorAt(start, end, message, ...args) {
                        return parseErrorAtPosition(start, end - start, message, ...args);
                    }
                    function parseErrorAtRange(range, message, ...args) {
                        parseErrorAt(range.pos, range.end, message, ...args);
                    }
                    function scanError(message, length2, arg0) {
                        parseErrorAtPosition(scanner2.getTokenEnd(), length2, message, arg0);
                    }
                    function getNodePos() {
                        return scanner2.getTokenFullStart();
                    }
                    function hasPrecedingJSDocComment() {
                        return scanner2.hasPrecedingJSDocComment();
                    }
                    function token() {
                        return currentToken;
                    }
                    function nextTokenWithoutCheck() {
                        return currentToken = scanner2.scan();
                    }
                    function nextTokenAnd(func) {
                        nextToken();
                        return func();
                    }
                    function nextToken() {
                        if (isKeyword(currentToken) && (scanner2.hasUnicodeEscape() || scanner2.hasExtendedUnicodeEscape())) {
                            parseErrorAt(scanner2.getTokenStart(), scanner2.getTokenEnd(), Diagnostics.Keywords_cannot_contain_escape_characters);
                        }
                        return nextTokenWithoutCheck();
                    }
                    function nextTokenJSDoc() {
                        return currentToken = scanner2.scanJsDocToken();
                    }
                    function nextJSDocCommentTextToken(inBackticks) {
                        return currentToken = scanner2.scanJSDocCommentTextToken(inBackticks);
                    }
                    function reScanGreaterToken() {
                        return currentToken = scanner2.reScanGreaterToken();
                    }
                    function reScanSlashToken() {
                        return currentToken = scanner2.reScanSlashToken();
                    }
                    function reScanTemplateToken(isTaggedTemplate) {
                        return currentToken = scanner2.reScanTemplateToken(isTaggedTemplate);
                    }
                    function reScanLessThanToken() {
                        return currentToken = scanner2.reScanLessThanToken();
                    }
                    function reScanHashToken() {
                        return currentToken = scanner2.reScanHashToken();
                    }
                    function scanJsxIdentifier() {
                        return currentToken = scanner2.scanJsxIdentifier();
                    }
                    function scanJsxText() {
                        return currentToken = scanner2.scanJsxToken();
                    }
                    function scanJsxAttributeValue() {
                        return currentToken = scanner2.scanJsxAttributeValue();
                    }
                    function speculationHelper(callback, speculationKind) {
                        const saveToken = currentToken;
                        const saveParseDiagnosticsLength = parseDiagnostics.length;
                        const saveParseErrorBeforeNextFinishedNode = parseErrorBeforeNextFinishedNode;
                        const saveContextFlags = contextFlags;
                        const result = speculationKind !== 0 /* TryParse */ ? scanner2.lookAhead(callback) : scanner2.tryScan(callback);
                        Debug.assert(saveContextFlags === contextFlags);
                        if (!result || speculationKind !== 0 /* TryParse */) {
                            currentToken = saveToken;
                            if (speculationKind !== 2 /* Reparse */) {
                                parseDiagnostics.length = saveParseDiagnosticsLength;
                            }
                            parseErrorBeforeNextFinishedNode = saveParseErrorBeforeNextFinishedNode;
                        }
                        return result;
                    }
                    function lookAhead(callback) {
                        return speculationHelper(callback, 1 /* Lookahead */);
                    }
                    function tryParse(callback) {
                        return speculationHelper(callback, 0 /* TryParse */);
                    }
                    function isBindingIdentifier() {
                        if (token() === 80 /* Identifier */) {
                            return true;
                        }
                        return token() > 118 /* LastReservedWord */;
                    }
                    function isIdentifier2() {
                        if (token() === 80 /* Identifier */) {
                            return true;
                        }
                        if (token() === 127 /* YieldKeyword */ && inYieldContext()) {
                            return false;
                        }
                        if (token() === 135 /* AwaitKeyword */ && inAwaitContext()) {
                            return false;
                        }
                        return token() > 118 /* LastReservedWord */;
                    }
                    function parseExpected(kind, diagnosticMessage, shouldAdvance = true) {
                        if (token() === kind) {
                            if (shouldAdvance) {
                                nextToken();
                            }
                            return true;
                        }
                        if (diagnosticMessage) {
                            parseErrorAtCurrentToken(diagnosticMessage);
                        }
                        else {
                            parseErrorAtCurrentToken(Diagnostics._0_expected, tokenToString(kind));
                        }
                        return false;
                    }
                    const viableKeywordSuggestions = Object.keys(textToKeywordObj).filter((keyword) => keyword.length > 2);
                    function parseErrorForMissingSemicolonAfter(node) {
                        if (isTaggedTemplateExpression(node)) {
                            parseErrorAt(skipTrivia(sourceText, node.template.pos), node.template.end, Diagnostics.Module_declaration_names_may_only_use_or_quoted_strings);
                            return;
                        }
                        const expressionText = isIdentifier(node) ? idText(node) : void 0;
                        if (!expressionText || !isIdentifierText(expressionText, languageVersion)) {
                            parseErrorAtCurrentToken(Diagnostics._0_expected, tokenToString(27 /* SemicolonToken */));
                            return;
                        }
                        const pos = skipTrivia(sourceText, node.pos);
                        switch (expressionText) {
                            case "const":
                            case "let":
                            case "var":
                                parseErrorAt(pos, node.end, Diagnostics.Variable_declaration_not_allowed_at_this_location);
                                return;
                            case "declare":
                                return;
                            case "interface":
                                parseErrorForInvalidName(Diagnostics.Interface_name_cannot_be_0, Diagnostics.Interface_must_be_given_a_name, 19 /* OpenBraceToken */);
                                return;
                            case "is":
                                parseErrorAt(pos, scanner2.getTokenStart(), Diagnostics.A_type_predicate_is_only_allowed_in_return_type_position_for_functions_and_methods);
                                return;
                            case "module":
                            case "namespace":
                                parseErrorForInvalidName(Diagnostics.Namespace_name_cannot_be_0, Diagnostics.Namespace_must_be_given_a_name, 19 /* OpenBraceToken */);
                                return;
                            case "type":
                                parseErrorForInvalidName(Diagnostics.Type_alias_name_cannot_be_0, Diagnostics.Type_alias_must_be_given_a_name, 64 /* EqualsToken */);
                                return;
                        }
                        const suggestion = getSpellingSuggestion(expressionText, viableKeywordSuggestions, (n) => n) ?? getSpaceSuggestion(expressionText);
                        if (suggestion) {
                            parseErrorAt(pos, node.end, Diagnostics.Unknown_keyword_or_identifier_Did_you_mean_0, suggestion);
                            return;
                        }
                        if (token() === 0 /* Unknown */) {
                            return;
                        }
                        parseErrorAt(pos, node.end, Diagnostics.Unexpected_keyword_or_identifier);
                    }
                    function parseErrorForInvalidName(nameDiagnostic, blankDiagnostic, tokenIfBlankName) {
                        if (token() === tokenIfBlankName) {
                            parseErrorAtCurrentToken(blankDiagnostic);
                        }
                        else {
                            parseErrorAtCurrentToken(nameDiagnostic, scanner2.getTokenValue());
                        }
                    }
                    function getSpaceSuggestion(expressionText) {
                        for (const keyword of viableKeywordSuggestions) {
                            if (expressionText.length > keyword.length + 2 && startsWith(expressionText, keyword)) {
                                return `${keyword} ${expressionText.slice(keyword.length)}`;
                            }
                        }
                        return void 0;
                    }
                    function parseSemicolonAfterPropertyName(name, type, initializer) {
                        if (token() === 60 /* AtToken */ && !scanner2.hasPrecedingLineBreak()) {
                            parseErrorAtCurrentToken(Diagnostics.Decorators_must_precede_the_name_and_all_keywords_of_property_declarations);
                            return;
                        }
                        if (token() === 21 /* OpenParenToken */) {
                            parseErrorAtCurrentToken(Diagnostics.Cannot_start_a_function_call_in_a_type_annotation);
                            nextToken();
                            return;
                        }
                        if (type && !canParseSemicolon()) {
                            if (initializer) {
                                parseErrorAtCurrentToken(Diagnostics._0_expected, tokenToString(27 /* SemicolonToken */));
                            }
                            else {
                                parseErrorAtCurrentToken(Diagnostics.Expected_for_property_initializer);
                            }
                            return;
                        }
                        if (tryParseSemicolon()) {
                            return;
                        }
                        if (initializer) {
                            parseErrorAtCurrentToken(Diagnostics._0_expected, tokenToString(27 /* SemicolonToken */));
                            return;
                        }
                        parseErrorForMissingSemicolonAfter(name);
                    }
                    function parseExpectedJSDoc(kind) {
                        if (token() === kind) {
                            nextTokenJSDoc();
                            return true;
                        }
                        Debug.assert(isKeywordOrPunctuation(kind));
                        parseErrorAtCurrentToken(Diagnostics._0_expected, tokenToString(kind));
                        return false;
                    }
                    function parseExpectedMatchingBrackets(openKind, closeKind, openParsed, openPosition) {
                        if (token() === closeKind) {
                            nextToken();
                            return;
                        }
                        const lastError = parseErrorAtCurrentToken(Diagnostics._0_expected, tokenToString(closeKind));
                        if (!openParsed) {
                            return;
                        }
                        if (lastError) {
                            addRelatedInfo(lastError, createDetachedDiagnostic(fileName, sourceText, openPosition, 1, Diagnostics.The_parser_expected_to_find_a_1_to_match_the_0_token_here, tokenToString(openKind), tokenToString(closeKind)));
                        }
                    }
                    function parseOptional(t) {
                        if (token() === t) {
                            nextToken();
                            return true;
                        }
                        return false;
                    }
                    function parseOptionalToken(t) {
                        if (token() === t) {
                            return parseTokenNode();
                        }
                        return void 0;
                    }
                    function parseOptionalTokenJSDoc(t) {
                        if (token() === t) {
                            return parseTokenNodeJSDoc();
                        }
                        return void 0;
                    }
                    function parseExpectedToken(t, diagnosticMessage, arg0) {
                        return parseOptionalToken(t) || createMissingNode(t, 
                        /*reportAtCurrentPosition*/
                        false, diagnosticMessage || Diagnostics._0_expected, arg0 || tokenToString(t));
                    }
                    function parseExpectedTokenJSDoc(t) {
                        const optional = parseOptionalTokenJSDoc(t);
                        if (optional)
                            return optional;
                        Debug.assert(isKeywordOrPunctuation(t));
                        return createMissingNode(t, 
                        /*reportAtCurrentPosition*/
                        false, Diagnostics._0_expected, tokenToString(t));
                    }
                    function parseTokenNode() {
                        const pos = getNodePos();
                        const kind = token();
                        nextToken();
                        return finishNode(factoryCreateToken(kind), pos);
                    }
                    function parseTokenNodeJSDoc() {
                        const pos = getNodePos();
                        const kind = token();
                        nextTokenJSDoc();
                        return finishNode(factoryCreateToken(kind), pos);
                    }
                    function canParseSemicolon() {
                        if (token() === 27 /* SemicolonToken */) {
                            return true;
                        }
                        return token() === 20 /* CloseBraceToken */ || token() === 1 /* EndOfFileToken */ || scanner2.hasPrecedingLineBreak();
                    }
                    function tryParseSemicolon() {
                        if (!canParseSemicolon()) {
                            return false;
                        }
                        if (token() === 27 /* SemicolonToken */) {
                            nextToken();
                        }
                        return true;
                    }
                    function parseSemicolon() {
                        return tryParseSemicolon() || parseExpected(27 /* SemicolonToken */);
                    }
                    function createNodeArray(elements, pos, end, hasTrailingComma) {
                        const array = factoryCreateNodeArray(elements, hasTrailingComma);
                        setTextRangePosEnd(array, pos, end ?? scanner2.getTokenFullStart());
                        return array;
                    }
                    function finishNode(node, pos, end) {
                        setTextRangePosEnd(node, pos, end ?? scanner2.getTokenFullStart());
                        if (contextFlags) {
                            node.flags |= contextFlags;
                        }
                        if (parseErrorBeforeNextFinishedNode) {
                            parseErrorBeforeNextFinishedNode = false;
                            node.flags |= 262144 /* ThisNodeHasError */;
                        }
                        return node;
                    }
                    function createMissingNode(kind, reportAtCurrentPosition, diagnosticMessage, ...args) {
                        if (reportAtCurrentPosition) {
                            parseErrorAtPosition(scanner2.getTokenFullStart(), 0, diagnosticMessage, ...args);
                        }
                        else if (diagnosticMessage) {
                            parseErrorAtCurrentToken(diagnosticMessage, ...args);
                        }
                        const pos = getNodePos();
                        const result = kind === 80 /* Identifier */ ? factoryCreateIdentifier("", 
                        /*originalKeywordKind*/
                        void 0) : isTemplateLiteralKind(kind) ? factory2.createTemplateLiteralLikeNode(kind, "", "", 
                        /*templateFlags*/
                        void 0) : kind === 9 /* NumericLiteral */ ? factoryCreateNumericLiteral("", 
                        /*numericLiteralFlags*/
                        void 0) : kind === 11 /* StringLiteral */ ? factoryCreateStringLiteral("", 
                        /*isSingleQuote*/
                        void 0) : kind === 282 /* MissingDeclaration */ ? factory2.createMissingDeclaration() : factoryCreateToken(kind);
                        return finishNode(result, pos);
                    }
                    function internIdentifier(text) {
                        let identifier = identifiers.get(text);
                        if (identifier === void 0) {
                            identifiers.set(text, identifier = text);
                        }
                        return identifier;
                    }
                    function createIdentifier(isIdentifier3, diagnosticMessage, privateIdentifierDiagnosticMessage) {
                        if (isIdentifier3) {
                            identifierCount++;
                            const pos = getNodePos();
                            const originalKeywordKind = token();
                            const text = internIdentifier(scanner2.getTokenValue());
                            const hasExtendedUnicodeEscape = scanner2.hasExtendedUnicodeEscape();
                            nextTokenWithoutCheck();
                            return finishNode(factoryCreateIdentifier(text, originalKeywordKind, hasExtendedUnicodeEscape), pos);
                        }
                        if (token() === 81 /* PrivateIdentifier */) {
                            parseErrorAtCurrentToken(privateIdentifierDiagnosticMessage || Diagnostics.Private_identifiers_are_not_allowed_outside_class_bodies);
                            return createIdentifier(
                            /*isIdentifier*/
                            true);
                        }
                        if (token() === 0 /* Unknown */ && scanner2.tryScan(() => scanner2.reScanInvalidIdentifier() === 80 /* Identifier */)) {
                            return createIdentifier(
                            /*isIdentifier*/
                            true);
                        }
                        identifierCount++;
                        const reportAtCurrentPosition = token() === 1 /* EndOfFileToken */;
                        const isReservedWord = scanner2.isReservedWord();
                        const msgArg = scanner2.getTokenText();
                        const defaultMessage = isReservedWord ? Diagnostics.Identifier_expected_0_is_a_reserved_word_that_cannot_be_used_here : Diagnostics.Identifier_expected;
                        return createMissingNode(80 /* Identifier */, reportAtCurrentPosition, diagnosticMessage || defaultMessage, msgArg);
                    }
                    function parseBindingIdentifier(privateIdentifierDiagnosticMessage) {
                        return createIdentifier(isBindingIdentifier(), 
                        /*diagnosticMessage*/
                        void 0, privateIdentifierDiagnosticMessage);
                    }
                    function parseIdentifier(diagnosticMessage, privateIdentifierDiagnosticMessage) {
                        return createIdentifier(isIdentifier2(), diagnosticMessage, privateIdentifierDiagnosticMessage);
                    }
                    function parseIdentifierName(diagnosticMessage) {
                        return createIdentifier(tokenIsIdentifierOrKeyword(token()), diagnosticMessage);
                    }
                    function parseIdentifierNameErrorOnUnicodeEscapeSequence() {
                        if (scanner2.hasUnicodeEscape() || scanner2.hasExtendedUnicodeEscape()) {
                            parseErrorAtCurrentToken(Diagnostics.Unicode_escape_sequence_cannot_appear_here);
                        }
                        return createIdentifier(tokenIsIdentifierOrKeyword(token()));
                    }
                    function isLiteralPropertyName() {
                        return tokenIsIdentifierOrKeyword(token()) || token() === 11 /* StringLiteral */ || token() === 9 /* NumericLiteral */;
                    }
                    function isImportAttributeName2() {
                        return tokenIsIdentifierOrKeyword(token()) || token() === 11 /* StringLiteral */;
                    }
                    function parsePropertyNameWorker(allowComputedPropertyNames) {
                        if (token() === 11 /* StringLiteral */ || token() === 9 /* NumericLiteral */) {
                            const node = parseLiteralNode();
                            node.text = internIdentifier(node.text);
                            return node;
                        }
                        if (allowComputedPropertyNames && token() === 23 /* OpenBracketToken */) {
                            return parseComputedPropertyName();
                        }
                        if (token() === 81 /* PrivateIdentifier */) {
                            return parsePrivateIdentifier();
                        }
                        return parseIdentifierName();
                    }
                    function parsePropertyName() {
                        return parsePropertyNameWorker(
                        /*allowComputedPropertyNames*/
                        true);
                    }
                    function parseComputedPropertyName() {
                        const pos = getNodePos();
                        parseExpected(23 /* OpenBracketToken */);
                        const expression = allowInAnd(parseExpression);
                        parseExpected(24 /* CloseBracketToken */);
                        return finishNode(factory2.createComputedPropertyName(expression), pos);
                    }
                    function parsePrivateIdentifier() {
                        const pos = getNodePos();
                        const node = factoryCreatePrivateIdentifier(internIdentifier(scanner2.getTokenValue()));
                        nextToken();
                        return finishNode(node, pos);
                    }
                    function parseContextualModifier(t) {
                        return token() === t && tryParse(nextTokenCanFollowModifier);
                    }
                    function nextTokenIsOnSameLineAndCanFollowModifier() {
                        nextToken();
                        if (scanner2.hasPrecedingLineBreak()) {
                            return false;
                        }
                        return canFollowModifier();
                    }
                    function nextTokenCanFollowModifier() {
                        switch (token()) {
                            case 87 /* ConstKeyword */:
                                return nextToken() === 94 /* EnumKeyword */;
                            case 95 /* ExportKeyword */:
                                nextToken();
                                if (token() === 90 /* DefaultKeyword */) {
                                    return lookAhead(nextTokenCanFollowDefaultKeyword);
                                }
                                if (token() === 156 /* TypeKeyword */) {
                                    return lookAhead(nextTokenCanFollowExportModifier);
                                }
                                return canFollowExportModifier();
                            case 90 /* DefaultKeyword */:
                                return nextTokenCanFollowDefaultKeyword();
                            case 126 /* StaticKeyword */:
                            case 139 /* GetKeyword */:
                            case 153 /* SetKeyword */:
                                nextToken();
                                return canFollowModifier();
                            default:
                                return nextTokenIsOnSameLineAndCanFollowModifier();
                        }
                    }
                    function canFollowExportModifier() {
                        return token() === 60 /* AtToken */ || token() !== 42 /* AsteriskToken */ && token() !== 130 /* AsKeyword */ && token() !== 19 /* OpenBraceToken */ && canFollowModifier();
                    }
                    function nextTokenCanFollowExportModifier() {
                        nextToken();
                        return canFollowExportModifier();
                    }
                    function parseAnyContextualModifier() {
                        return isModifierKind(token()) && tryParse(nextTokenCanFollowModifier);
                    }
                    function canFollowModifier() {
                        return token() === 23 /* OpenBracketToken */ || token() === 19 /* OpenBraceToken */ || token() === 42 /* AsteriskToken */ || token() === 26 /* DotDotDotToken */ || isLiteralPropertyName();
                    }
                    function nextTokenCanFollowDefaultKeyword() {
                        nextToken();
                        return token() === 86 /* ClassKeyword */ || token() === 100 /* FunctionKeyword */ || token() === 120 /* InterfaceKeyword */ || token() === 60 /* AtToken */ || token() === 128 /* AbstractKeyword */ && lookAhead(nextTokenIsClassKeywordOnSameLine) || token() === 134 /* AsyncKeyword */ && lookAhead(nextTokenIsFunctionKeywordOnSameLine);
                    }
                    function isListElement2(parsingContext2, inErrorRecovery) {
                        const node = currentNode(parsingContext2);
                        if (node) {
                            return true;
                        }
                        switch (parsingContext2) {
                            case 0 /* SourceElements */:
                            case 1 /* BlockStatements */:
                            case 3 /* SwitchClauseStatements */:
                                return !(token() === 27 /* SemicolonToken */ && inErrorRecovery) && isStartOfStatement();
                            case 2 /* SwitchClauses */:
                                return token() === 84 /* CaseKeyword */ || token() === 90 /* DefaultKeyword */;
                            case 4 /* TypeMembers */:
                                return lookAhead(isTypeMemberStart);
                            case 5 /* ClassMembers */:
                                return lookAhead(isClassMemberStart) || token() === 27 /* SemicolonToken */ && !inErrorRecovery;
                            case 6 /* EnumMembers */:
                                return token() === 23 /* OpenBracketToken */ || isLiteralPropertyName();
                            case 12 /* ObjectLiteralMembers */:
                                switch (token()) {
                                    case 23 /* OpenBracketToken */:
                                    case 42 /* AsteriskToken */:
                                    case 26 /* DotDotDotToken */:
                                    case 25 /* DotToken */:
                                        return true;
                                    default:
                                        return isLiteralPropertyName();
                                }
                            case 18 /* RestProperties */:
                                return isLiteralPropertyName();
                            case 9 /* ObjectBindingElements */:
                                return token() === 23 /* OpenBracketToken */ || token() === 26 /* DotDotDotToken */ || isLiteralPropertyName();
                            case 24 /* ImportAttributes */:
                                return isImportAttributeName2();
                            case 7 /* HeritageClauseElement */:
                                if (token() === 19 /* OpenBraceToken */) {
                                    return lookAhead(isValidHeritageClauseObjectLiteral);
                                }
                                if (!inErrorRecovery) {
                                    return isStartOfLeftHandSideExpression() && !isHeritageClauseExtendsOrImplementsKeyword();
                                }
                                else {
                                    return isIdentifier2() && !isHeritageClauseExtendsOrImplementsKeyword();
                                }
                            case 8 /* VariableDeclarations */:
                                return isBindingIdentifierOrPrivateIdentifierOrPattern();
                            case 10 /* ArrayBindingElements */:
                                return token() === 28 /* CommaToken */ || token() === 26 /* DotDotDotToken */ || isBindingIdentifierOrPrivateIdentifierOrPattern();
                            case 19 /* TypeParameters */:
                                return token() === 103 /* InKeyword */ || token() === 87 /* ConstKeyword */ || isIdentifier2();
                            case 15 /* ArrayLiteralMembers */:
                                switch (token()) {
                                    case 28 /* CommaToken */:
                                    case 25 /* DotToken */:
                                        return true;
                                }
                            case 11 /* ArgumentExpressions */:
                                return token() === 26 /* DotDotDotToken */ || isStartOfExpression();
                            case 16 /* Parameters */:
                                return isStartOfParameter(
                                /*isJSDocParameter*/
                                false);
                            case 17 /* JSDocParameters */:
                                return isStartOfParameter(
                                /*isJSDocParameter*/
                                true);
                            case 20 /* TypeArguments */:
                            case 21 /* TupleElementTypes */:
                                return token() === 28 /* CommaToken */ || isStartOfType();
                            case 22 /* HeritageClauses */:
                                return isHeritageClause2();
                            case 23 /* ImportOrExportSpecifiers */:
                                if (token() === 161 /* FromKeyword */ && lookAhead(nextTokenIsStringLiteral)) {
                                    return false;
                                }
                                return tokenIsIdentifierOrKeyword(token());
                            case 13 /* JsxAttributes */:
                                return tokenIsIdentifierOrKeyword(token()) || token() === 19 /* OpenBraceToken */;
                            case 14 /* JsxChildren */:
                                return true;
                            case 25 /* JSDocComment */:
                                return true;
                            case 26 /* Count */:
                                return Debug.fail("ParsingContext.Count used as a context");
                            default:
                                Debug.assertNever(parsingContext2, "Non-exhaustive case in 'isListElement'.");
                        }
                    }
                    function isValidHeritageClauseObjectLiteral() {
                        Debug.assert(token() === 19 /* OpenBraceToken */);
                        if (nextToken() === 20 /* CloseBraceToken */) {
                            const next = nextToken();
                            return next === 28 /* CommaToken */ || next === 19 /* OpenBraceToken */ || next === 96 /* ExtendsKeyword */ || next === 119 /* ImplementsKeyword */;
                        }
                        return true;
                    }
                    function nextTokenIsIdentifier() {
                        nextToken();
                        return isIdentifier2();
                    }
                    function nextTokenIsIdentifierOrKeyword() {
                        nextToken();
                        return tokenIsIdentifierOrKeyword(token());
                    }
                    function nextTokenIsIdentifierOrKeywordOrGreaterThan() {
                        nextToken();
                        return tokenIsIdentifierOrKeywordOrGreaterThan(token());
                    }
                    function isHeritageClauseExtendsOrImplementsKeyword() {
                        if (token() === 119 /* ImplementsKeyword */ || token() === 96 /* ExtendsKeyword */) {
                            return lookAhead(nextTokenIsStartOfExpression);
                        }
                        return false;
                    }
                    function nextTokenIsStartOfExpression() {
                        nextToken();
                        return isStartOfExpression();
                    }
                    function nextTokenIsStartOfType() {
                        nextToken();
                        return isStartOfType();
                    }
                    function isListTerminator(kind) {
                        if (token() === 1 /* EndOfFileToken */) {
                            return true;
                        }
                        switch (kind) {
                            case 1 /* BlockStatements */:
                            case 2 /* SwitchClauses */:
                            case 4 /* TypeMembers */:
                            case 5 /* ClassMembers */:
                            case 6 /* EnumMembers */:
                            case 12 /* ObjectLiteralMembers */:
                            case 9 /* ObjectBindingElements */:
                            case 23 /* ImportOrExportSpecifiers */:
                            case 24 /* ImportAttributes */:
                                return token() === 20 /* CloseBraceToken */;
                            case 3 /* SwitchClauseStatements */:
                                return token() === 20 /* CloseBraceToken */ || token() === 84 /* CaseKeyword */ || token() === 90 /* DefaultKeyword */;
                            case 7 /* HeritageClauseElement */:
                                return token() === 19 /* OpenBraceToken */ || token() === 96 /* ExtendsKeyword */ || token() === 119 /* ImplementsKeyword */;
                            case 8 /* VariableDeclarations */:
                                return isVariableDeclaratorListTerminator();
                            case 19 /* TypeParameters */:
                                return token() === 32 /* GreaterThanToken */ || token() === 21 /* OpenParenToken */ || token() === 19 /* OpenBraceToken */ || token() === 96 /* ExtendsKeyword */ || token() === 119 /* ImplementsKeyword */;
                            case 11 /* ArgumentExpressions */:
                                return token() === 22 /* CloseParenToken */ || token() === 27 /* SemicolonToken */;
                            case 15 /* ArrayLiteralMembers */:
                            case 21 /* TupleElementTypes */:
                            case 10 /* ArrayBindingElements */:
                                return token() === 24 /* CloseBracketToken */;
                            case 17 /* JSDocParameters */:
                            case 16 /* Parameters */:
                            case 18 /* RestProperties */:
                                return token() === 22 /* CloseParenToken */ || token() === 24 /* CloseBracketToken */;
                            case 20 /* TypeArguments */:
                                return token() !== 28 /* CommaToken */;
                            case 22 /* HeritageClauses */:
                                return token() === 19 /* OpenBraceToken */ || token() === 20 /* CloseBraceToken */;
                            case 13 /* JsxAttributes */:
                                return token() === 32 /* GreaterThanToken */ || token() === 44 /* SlashToken */;
                            case 14 /* JsxChildren */:
                                return token() === 30 /* LessThanToken */ && lookAhead(nextTokenIsSlash);
                            default:
                                return false;
                        }
                    }
                    function isVariableDeclaratorListTerminator() {
                        if (canParseSemicolon()) {
                            return true;
                        }
                        if (isInOrOfKeyword(token())) {
                            return true;
                        }
                        if (token() === 39 /* EqualsGreaterThanToken */) {
                            return true;
                        }
                        return false;
                    }
                    function isInSomeParsingContext() {
                        Debug.assert(parsingContext, "Missing parsing context");
                        for (let kind = 0; kind < 26 /* Count */; kind++) {
                            if (parsingContext & 1 << kind) {
                                if (isListElement2(kind, 
                                /*inErrorRecovery*/
                                true) || isListTerminator(kind)) {
                                    return true;
                                }
                            }
                        }
                        return false;
                    }
                    function parseList(kind, parseElement) {
                        const saveParsingContext = parsingContext;
                        parsingContext |= 1 << kind;
                        const list = [];
                        const listPos = getNodePos();
                        while (!isListTerminator(kind)) {
                            if (isListElement2(kind, 
                            /*inErrorRecovery*/
                            false)) {
                                list.push(parseListElement(kind, parseElement));
                                continue;
                            }
                            if (abortParsingListOrMoveToNextToken(kind)) {
                                break;
                            }
                        }
                        parsingContext = saveParsingContext;
                        return createNodeArray(list, listPos);
                    }
                    function parseListElement(parsingContext2, parseElement) {
                        const node = currentNode(parsingContext2);
                        if (node) {
                            return consumeNode(node);
                        }
                        return parseElement();
                    }
                    function currentNode(parsingContext2, pos) {
                        var _a;
                        if (!syntaxCursor || !isReusableParsingContext(parsingContext2) || parseErrorBeforeNextFinishedNode) {
                            return void 0;
                        }
                        const node = syntaxCursor.currentNode(pos ?? scanner2.getTokenFullStart());
                        if (nodeIsMissing(node) || node.intersectsChange || containsParseError(node)) {
                            return void 0;
                        }
                        const nodeContextFlags = node.flags & 101441536 /* ContextFlags */;
                        if (nodeContextFlags !== contextFlags) {
                            return void 0;
                        }
                        if (!canReuseNode(node, parsingContext2)) {
                            return void 0;
                        }
                        if (canHaveJSDoc(node) && ((_a = node.jsDoc) == null ? void 0 : _a.jsDocCache)) {
                            node.jsDoc.jsDocCache = void 0;
                        }
                        return node;
                    }
                    function consumeNode(node) {
                        scanner2.resetTokenState(node.end);
                        nextToken();
                        return node;
                    }
                    function isReusableParsingContext(parsingContext2) {
                        switch (parsingContext2) {
                            case 5 /* ClassMembers */:
                            case 2 /* SwitchClauses */:
                            case 0 /* SourceElements */:
                            case 1 /* BlockStatements */:
                            case 3 /* SwitchClauseStatements */:
                            case 6 /* EnumMembers */:
                            case 4 /* TypeMembers */:
                            case 8 /* VariableDeclarations */:
                            case 17 /* JSDocParameters */:
                            case 16 /* Parameters */:
                                return true;
                        }
                        return false;
                    }
                    function canReuseNode(node, parsingContext2) {
                        switch (parsingContext2) {
                            case 5 /* ClassMembers */:
                                return isReusableClassMember(node);
                            case 2 /* SwitchClauses */:
                                return isReusableSwitchClause(node);
                            case 0 /* SourceElements */:
                            case 1 /* BlockStatements */:
                            case 3 /* SwitchClauseStatements */:
                                return isReusableStatement(node);
                            case 6 /* EnumMembers */:
                                return isReusableEnumMember(node);
                            case 4 /* TypeMembers */:
                                return isReusableTypeMember(node);
                            case 8 /* VariableDeclarations */:
                                return isReusableVariableDeclaration(node);
                            case 17 /* JSDocParameters */:
                            case 16 /* Parameters */:
                                return isReusableParameter(node);
                        }
                        return false;
                    }
                    function isReusableClassMember(node) {
                        if (node) {
                            switch (node.kind) {
                                case 176 /* Constructor */:
                                case 181 /* IndexSignature */:
                                case 177 /* GetAccessor */:
                                case 178 /* SetAccessor */:
                                case 172 /* PropertyDeclaration */:
                                case 240 /* SemicolonClassElement */:
                                    return true;
                                case 174 /* MethodDeclaration */:
                                    const methodDeclaration = node;
                                    const nameIsConstructor = methodDeclaration.name.kind === 80 /* Identifier */ && methodDeclaration.name.escapedText === "constructor";
                                    return !nameIsConstructor;
                            }
                        }
                        return false;
                    }
                    function isReusableSwitchClause(node) {
                        if (node) {
                            switch (node.kind) {
                                case 296 /* CaseClause */:
                                case 297 /* DefaultClause */:
                                    return true;
                            }
                        }
                        return false;
                    }
                    function isReusableStatement(node) {
                        if (node) {
                            switch (node.kind) {
                                case 262 /* FunctionDeclaration */:
                                case 243 /* VariableStatement */:
                                case 241 /* Block */:
                                case 245 /* IfStatement */:
                                case 244 /* ExpressionStatement */:
                                case 257 /* ThrowStatement */:
                                case 253 /* ReturnStatement */:
                                case 255 /* SwitchStatement */:
                                case 252 /* BreakStatement */:
                                case 251 /* ContinueStatement */:
                                case 249 /* ForInStatement */:
                                case 250 /* ForOfStatement */:
                                case 248 /* ForStatement */:
                                case 247 /* WhileStatement */:
                                case 254 /* WithStatement */:
                                case 242 /* EmptyStatement */:
                                case 258 /* TryStatement */:
                                case 256 /* LabeledStatement */:
                                case 246 /* DoStatement */:
                                case 259 /* DebuggerStatement */:
                                case 272 /* ImportDeclaration */:
                                case 271 /* ImportEqualsDeclaration */:
                                case 278 /* ExportDeclaration */:
                                case 277 /* ExportAssignment */:
                                case 267 /* ModuleDeclaration */:
                                case 263 /* ClassDeclaration */:
                                case 264 /* InterfaceDeclaration */:
                                case 266 /* EnumDeclaration */:
                                case 265 /* TypeAliasDeclaration */:
                                    return true;
                            }
                        }
                        return false;
                    }
                    function isReusableEnumMember(node) {
                        return node.kind === 306 /* EnumMember */;
                    }
                    function isReusableTypeMember(node) {
                        if (node) {
                            switch (node.kind) {
                                case 180 /* ConstructSignature */:
                                case 173 /* MethodSignature */:
                                case 181 /* IndexSignature */:
                                case 171 /* PropertySignature */:
                                case 179 /* CallSignature */:
                                    return true;
                            }
                        }
                        return false;
                    }
                    function isReusableVariableDeclaration(node) {
                        if (node.kind !== 260 /* VariableDeclaration */) {
                            return false;
                        }
                        const variableDeclarator = node;
                        return variableDeclarator.initializer === void 0;
                    }
                    function isReusableParameter(node) {
                        if (node.kind !== 169 /* Parameter */) {
                            return false;
                        }
                        const parameter = node;
                        return parameter.initializer === void 0;
                    }
                    function abortParsingListOrMoveToNextToken(kind) {
                        parsingContextErrors(kind);
                        if (isInSomeParsingContext()) {
                            return true;
                        }
                        nextToken();
                        return false;
                    }
                    function parsingContextErrors(context) {
                        switch (context) {
                            case 0 /* SourceElements */:
                                return token() === 90 /* DefaultKeyword */ ? parseErrorAtCurrentToken(Diagnostics._0_expected, tokenToString(95 /* ExportKeyword */)) : parseErrorAtCurrentToken(Diagnostics.Declaration_or_statement_expected);
                            case 1 /* BlockStatements */:
                                return parseErrorAtCurrentToken(Diagnostics.Declaration_or_statement_expected);
                            case 2 /* SwitchClauses */:
                                return parseErrorAtCurrentToken(Diagnostics.case_or_default_expected);
                            case 3 /* SwitchClauseStatements */:
                                return parseErrorAtCurrentToken(Diagnostics.Statement_expected);
                            case 18 /* RestProperties */:
                            case 4 /* TypeMembers */:
                                return parseErrorAtCurrentToken(Diagnostics.Property_or_signature_expected);
                            case 5 /* ClassMembers */:
                                return parseErrorAtCurrentToken(Diagnostics.Unexpected_token_A_constructor_method_accessor_or_property_was_expected);
                            case 6 /* EnumMembers */:
                                return parseErrorAtCurrentToken(Diagnostics.Enum_member_expected);
                            case 7 /* HeritageClauseElement */:
                                return parseErrorAtCurrentToken(Diagnostics.Expression_expected);
                            case 8 /* VariableDeclarations */:
                                return isKeyword(token()) ? parseErrorAtCurrentToken(Diagnostics._0_is_not_allowed_as_a_variable_declaration_name, tokenToString(token())) : parseErrorAtCurrentToken(Diagnostics.Variable_declaration_expected);
                            case 9 /* ObjectBindingElements */:
                                return parseErrorAtCurrentToken(Diagnostics.Property_destructuring_pattern_expected);
                            case 10 /* ArrayBindingElements */:
                                return parseErrorAtCurrentToken(Diagnostics.Array_element_destructuring_pattern_expected);
                            case 11 /* ArgumentExpressions */:
                                return parseErrorAtCurrentToken(Diagnostics.Argument_expression_expected);
                            case 12 /* ObjectLiteralMembers */:
                                return parseErrorAtCurrentToken(Diagnostics.Property_assignment_expected);
                            case 15 /* ArrayLiteralMembers */:
                                return parseErrorAtCurrentToken(Diagnostics.Expression_or_comma_expected);
                            case 17 /* JSDocParameters */:
                                return parseErrorAtCurrentToken(Diagnostics.Parameter_declaration_expected);
                            case 16 /* Parameters */:
                                return isKeyword(token()) ? parseErrorAtCurrentToken(Diagnostics._0_is_not_allowed_as_a_parameter_name, tokenToString(token())) : parseErrorAtCurrentToken(Diagnostics.Parameter_declaration_expected);
                            case 19 /* TypeParameters */:
                                return parseErrorAtCurrentToken(Diagnostics.Type_parameter_declaration_expected);
                            case 20 /* TypeArguments */:
                                return parseErrorAtCurrentToken(Diagnostics.Type_argument_expected);
                            case 21 /* TupleElementTypes */:
                                return parseErrorAtCurrentToken(Diagnostics.Type_expected);
                            case 22 /* HeritageClauses */:
                                return parseErrorAtCurrentToken(Diagnostics.Unexpected_token_expected);
                            case 23 /* ImportOrExportSpecifiers */:
                                if (token() === 161 /* FromKeyword */) {
                                    return parseErrorAtCurrentToken(Diagnostics._0_expected, "}");
                                }
                                return parseErrorAtCurrentToken(Diagnostics.Identifier_expected);
                            case 13 /* JsxAttributes */:
                                return parseErrorAtCurrentToken(Diagnostics.Identifier_expected);
                            case 14 /* JsxChildren */:
                                return parseErrorAtCurrentToken(Diagnostics.Identifier_expected);
                            case 24 /* ImportAttributes */:
                                return parseErrorAtCurrentToken(Diagnostics.Identifier_or_string_literal_expected);
                            case 25 /* JSDocComment */:
                                return parseErrorAtCurrentToken(Diagnostics.Identifier_expected);
                            case 26 /* Count */:
                                return Debug.fail("ParsingContext.Count used as a context");
                            default:
                                Debug.assertNever(context);
                        }
                    }
                    function parseDelimitedList(kind, parseElement, considerSemicolonAsDelimiter) {
                        const saveParsingContext = parsingContext;
                        parsingContext |= 1 << kind;
                        const list = [];
                        const listPos = getNodePos();
                        let commaStart = -1;
                        while (true) {
                            if (isListElement2(kind, 
                            /*inErrorRecovery*/
                            false)) {
                                const startPos = scanner2.getTokenFullStart();
                                const result = parseListElement(kind, parseElement);
                                if (!result) {
                                    parsingContext = saveParsingContext;
                                    return void 0;
                                }
                                list.push(result);
                                commaStart = scanner2.getTokenStart();
                                if (parseOptional(28 /* CommaToken */)) {
                                    continue;
                                }
                                commaStart = -1;
                                if (isListTerminator(kind)) {
                                    break;
                                }
                                parseExpected(28 /* CommaToken */, getExpectedCommaDiagnostic(kind));
                                if (considerSemicolonAsDelimiter && token() === 27 /* SemicolonToken */ && !scanner2.hasPrecedingLineBreak()) {
                                    nextToken();
                                }
                                if (startPos === scanner2.getTokenFullStart()) {
                                    nextToken();
                                }
                                continue;
                            }
                            if (isListTerminator(kind)) {
                                break;
                            }
                            if (abortParsingListOrMoveToNextToken(kind)) {
                                break;
                            }
                        }
                        parsingContext = saveParsingContext;
                        return createNodeArray(list, listPos, 
                        /*end*/
                        void 0, commaStart >= 0);
                    }
                    function getExpectedCommaDiagnostic(kind) {
                        return kind === 6 /* EnumMembers */ ? Diagnostics.An_enum_member_name_must_be_followed_by_a_or : void 0;
                    }
                    function createMissingList() {
                        const list = createNodeArray([], getNodePos());
                        list.isMissingList = true;
                        return list;
                    }
                    function isMissingList(arr) {
                        return !!arr.isMissingList;
                    }
                    function parseBracketedList(kind, parseElement, open, close) {
                        if (parseExpected(open)) {
                            const result = parseDelimitedList(kind, parseElement);
                            parseExpected(close);
                            return result;
                        }
                        return createMissingList();
                    }
                    function parseEntityName(allowReservedWords, diagnosticMessage) {
                        const pos = getNodePos();
                        let entity = allowReservedWords ? parseIdentifierName(diagnosticMessage) : parseIdentifier(diagnosticMessage);
                        while (parseOptional(25 /* DotToken */)) {
                            if (token() === 30 /* LessThanToken */) {
                                break;
                            }
                            entity = finishNode(factory2.createQualifiedName(entity, parseRightSideOfDot(allowReservedWords, 
                            /*allowPrivateIdentifiers*/
                            false, 
                            /*allowUnicodeEscapeSequenceInIdentifierName*/
                            true)), pos);
                        }
                        return entity;
                    }
                    function createQualifiedName(entity, name) {
                        return finishNode(factory2.createQualifiedName(entity, name), entity.pos);
                    }
                    function parseRightSideOfDot(allowIdentifierNames, allowPrivateIdentifiers, allowUnicodeEscapeSequenceInIdentifierName) {
                        if (scanner2.hasPrecedingLineBreak() && tokenIsIdentifierOrKeyword(token())) {
                            const matchesPattern = lookAhead(nextTokenIsIdentifierOrKeywordOnSameLine);
                            if (matchesPattern) {
                                return createMissingNode(80 /* Identifier */, 
                                /*reportAtCurrentPosition*/
                                true, Diagnostics.Identifier_expected);
                            }
                        }
                        if (token() === 81 /* PrivateIdentifier */) {
                            const node = parsePrivateIdentifier();
                            return allowPrivateIdentifiers ? node : createMissingNode(80 /* Identifier */, 
                            /*reportAtCurrentPosition*/
                            true, Diagnostics.Identifier_expected);
                        }
                        if (allowIdentifierNames) {
                            return allowUnicodeEscapeSequenceInIdentifierName ? parseIdentifierName() : parseIdentifierNameErrorOnUnicodeEscapeSequence();
                        }
                        return parseIdentifier();
                    }
                    function parseTemplateSpans(isTaggedTemplate) {
                        const pos = getNodePos();
                        const list = [];
                        let node;
                        do {
                            node = parseTemplateSpan(isTaggedTemplate);
                            list.push(node);
                        } while (node.literal.kind === 17 /* TemplateMiddle */);
                        return createNodeArray(list, pos);
                    }
                    function parseTemplateExpression(isTaggedTemplate) {
                        const pos = getNodePos();
                        return finishNode(factory2.createTemplateExpression(parseTemplateHead(isTaggedTemplate), parseTemplateSpans(isTaggedTemplate)), pos);
                    }
                    function parseTemplateType() {
                        const pos = getNodePos();
                        return finishNode(factory2.createTemplateLiteralType(parseTemplateHead(
                        /*isTaggedTemplate*/
                        false), parseTemplateTypeSpans()), pos);
                    }
                    function parseTemplateTypeSpans() {
                        const pos = getNodePos();
                        const list = [];
                        let node;
                        do {
                            node = parseTemplateTypeSpan();
                            list.push(node);
                        } while (node.literal.kind === 17 /* TemplateMiddle */);
                        return createNodeArray(list, pos);
                    }
                    function parseTemplateTypeSpan() {
                        const pos = getNodePos();
                        return finishNode(factory2.createTemplateLiteralTypeSpan(parseType(), parseLiteralOfTemplateSpan(
                        /*isTaggedTemplate*/
                        false)), pos);
                    }
                    function parseLiteralOfTemplateSpan(isTaggedTemplate) {
                        if (token() === 20 /* CloseBraceToken */) {
                            reScanTemplateToken(isTaggedTemplate);
                            return parseTemplateMiddleOrTemplateTail();
                        }
                        else {
                            return parseExpectedToken(18 /* TemplateTail */, Diagnostics._0_expected, tokenToString(20 /* CloseBraceToken */));
                        }
                    }
                    function parseTemplateSpan(isTaggedTemplate) {
                        const pos = getNodePos();
                        return finishNode(factory2.createTemplateSpan(allowInAnd(parseExpression), parseLiteralOfTemplateSpan(isTaggedTemplate)), pos);
                    }
                    function parseLiteralNode() {
                        return parseLiteralLikeNode(token());
                    }
                    function parseTemplateHead(isTaggedTemplate) {
                        if (!isTaggedTemplate && scanner2.getTokenFlags() & 26656 /* IsInvalid */) {
                            reScanTemplateToken(
                            /*isTaggedTemplate*/
                            false);
                        }
                        const fragment = parseLiteralLikeNode(token());
                        Debug.assert(fragment.kind === 16 /* TemplateHead */, "Template head has wrong token kind");
                        return fragment;
                    }
                    function parseTemplateMiddleOrTemplateTail() {
                        const fragment = parseLiteralLikeNode(token());
                        Debug.assert(fragment.kind === 17 /* TemplateMiddle */ || fragment.kind === 18 /* TemplateTail */, "Template fragment has wrong token kind");
                        return fragment;
                    }
                    function getTemplateLiteralRawText(kind) {
                        const isLast = kind === 15 /* NoSubstitutionTemplateLiteral */ || kind === 18 /* TemplateTail */;
                        const tokenText = scanner2.getTokenText();
                        return tokenText.substring(1, tokenText.length - (scanner2.isUnterminated() ? 0 : isLast ? 1 : 2));
                    }
                    function parseLiteralLikeNode(kind) {
                        const pos = getNodePos();
                        const node = isTemplateLiteralKind(kind) ? factory2.createTemplateLiteralLikeNode(kind, scanner2.getTokenValue(), getTemplateLiteralRawText(kind), scanner2.getTokenFlags() & 7176 /* TemplateLiteralLikeFlags */) : (
                        // Note that theoretically the following condition would hold true literals like 009,
                        // which is not octal. But because of how the scanner separates the tokens, we would
                        // never get a token like this. Instead, we would get 00 and 9 as two separate tokens.
                        // We also do not need to check for negatives because any prefix operator would be part of a
                        // parent unary expression.
                        kind === 9 /* NumericLiteral */ ? factoryCreateNumericLiteral(scanner2.getTokenValue(), scanner2.getNumericLiteralFlags()) : kind === 11 /* StringLiteral */ ? factoryCreateStringLiteral(scanner2.getTokenValue(), 
                        /*isSingleQuote*/
                        void 0, scanner2.hasExtendedUnicodeEscape()) : isLiteralKind(kind) ? factoryCreateLiteralLikeNode(kind, scanner2.getTokenValue()) : Debug.fail());
                        if (scanner2.hasExtendedUnicodeEscape()) {
                            node.hasExtendedUnicodeEscape = true;
                        }
                        if (scanner2.isUnterminated()) {
                            node.isUnterminated = true;
                        }
                        nextToken();
                        return finishNode(node, pos);
                    }
                    function parseEntityNameOfTypeReference() {
                        return parseEntityName(
                        /*allowReservedWords*/
                        true, Diagnostics.Type_expected);
                    }
                    function parseTypeArgumentsOfTypeReference() {
                        if (!scanner2.hasPrecedingLineBreak() && reScanLessThanToken() === 30 /* LessThanToken */) {
                            return parseBracketedList(20 /* TypeArguments */, parseType, 30 /* LessThanToken */, 32 /* GreaterThanToken */);
                        }
                    }
                    function parseTypeReference() {
                        const pos = getNodePos();
                        return finishNode(factory2.createTypeReferenceNode(parseEntityNameOfTypeReference(), parseTypeArgumentsOfTypeReference()), pos);
                    }
                    function typeHasArrowFunctionBlockingParseError(node) {
                        switch (node.kind) {
                            case 183 /* TypeReference */:
                                return nodeIsMissing(node.typeName);
                            case 184 /* FunctionType */:
                            case 185 /* ConstructorType */: {
                                const { parameters, type } = node;
                                return isMissingList(parameters) || typeHasArrowFunctionBlockingParseError(type);
                            }
                            case 196 /* ParenthesizedType */:
                                return typeHasArrowFunctionBlockingParseError(node.type);
                            default:
                                return false;
                        }
                    }
                    function parseThisTypePredicate(lhs) {
                        nextToken();
                        return finishNode(factory2.createTypePredicateNode(
                        /*assertsModifier*/
                        void 0, lhs, parseType()), lhs.pos);
                    }
                    function parseThisTypeNode() {
                        const pos = getNodePos();
                        nextToken();
                        return finishNode(factory2.createThisTypeNode(), pos);
                    }
                    function parseJSDocAllType() {
                        const pos = getNodePos();
                        nextToken();
                        return finishNode(factory2.createJSDocAllType(), pos);
                    }
                    function parseJSDocNonNullableType() {
                        const pos = getNodePos();
                        nextToken();
                        return finishNode(factory2.createJSDocNonNullableType(parseNonArrayType(), 
                        /*postfix*/
                        false), pos);
                    }
                    function parseJSDocUnknownOrNullableType() {
                        const pos = getNodePos();
                        nextToken();
                        if (token() === 28 /* CommaToken */ || token() === 20 /* CloseBraceToken */ || token() === 22 /* CloseParenToken */ || token() === 32 /* GreaterThanToken */ || token() === 64 /* EqualsToken */ || token() === 52 /* BarToken */) {
                            return finishNode(factory2.createJSDocUnknownType(), pos);
                        }
                        else {
                            return finishNode(factory2.createJSDocNullableType(parseType(), 
                            /*postfix*/
                            false), pos);
                        }
                    }
                    function parseJSDocFunctionType() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        if (tryParse(nextTokenIsOpenParen)) {
                            const parameters = parseParameters(4 /* Type */ | 32 /* JSDoc */);
                            const type = parseReturnType(59 /* ColonToken */, 
                            /*isType*/
                            false);
                            return withJSDoc(finishNode(factory2.createJSDocFunctionType(parameters, type), pos), hasJSDoc);
                        }
                        return finishNode(factory2.createTypeReferenceNode(parseIdentifierName(), 
                        /*typeArguments*/
                        void 0), pos);
                    }
                    function parseJSDocParameter() {
                        const pos = getNodePos();
                        let name;
                        if (token() === 110 /* ThisKeyword */ || token() === 105 /* NewKeyword */) {
                            name = parseIdentifierName();
                            parseExpected(59 /* ColonToken */);
                        }
                        return finishNode(factory2.createParameterDeclaration(
                        /*modifiers*/
                        void 0, 
                        /*dotDotDotToken*/
                        void 0, 
                        // TODO(rbuckton): JSDoc parameters don't have names (except `this`/`new`), should we manufacture an empty identifier?
                        name, 
                        /*questionToken*/
                        void 0, parseJSDocType(), 
                        /*initializer*/
                        void 0), pos);
                    }
                    function parseJSDocType() {
                        scanner2.setInJSDocType(true);
                        const pos = getNodePos();
                        if (parseOptional(144 /* ModuleKeyword */)) {
                            const moduleTag = factory2.createJSDocNamepathType(
                            /*type*/
                            void 0);
                            terminate: while (true) {
                                switch (token()) {
                                    case 20 /* CloseBraceToken */:
                                    case 1 /* EndOfFileToken */:
                                    case 28 /* CommaToken */:
                                    case 5 /* WhitespaceTrivia */:
                                        break terminate;
                                    default:
                                        nextTokenJSDoc();
                                }
                            }
                            scanner2.setInJSDocType(false);
                            return finishNode(moduleTag, pos);
                        }
                        const hasDotDotDot = parseOptional(26 /* DotDotDotToken */);
                        let type = parseTypeOrTypePredicate();
                        scanner2.setInJSDocType(false);
                        if (hasDotDotDot) {
                            type = finishNode(factory2.createJSDocVariadicType(type), pos);
                        }
                        if (token() === 64 /* EqualsToken */) {
                            nextToken();
                            return finishNode(factory2.createJSDocOptionalType(type), pos);
                        }
                        return type;
                    }
                    function parseTypeQuery() {
                        const pos = getNodePos();
                        parseExpected(114 /* TypeOfKeyword */);
                        const entityName = parseEntityName(
                        /*allowReservedWords*/
                        true);
                        const typeArguments = !scanner2.hasPrecedingLineBreak() ? tryParseTypeArguments() : void 0;
                        return finishNode(factory2.createTypeQueryNode(entityName, typeArguments), pos);
                    }
                    function parseTypeParameter() {
                        const pos = getNodePos();
                        const modifiers = parseModifiers(
                        /*allowDecorators*/
                        false, 
                        /*permitConstAsModifier*/
                        true);
                        const name = parseIdentifier();
                        let constraint;
                        let expression;
                        if (parseOptional(96 /* ExtendsKeyword */)) {
                            if (isStartOfType() || !isStartOfExpression()) {
                                constraint = parseType();
                            }
                            else {
                                expression = parseUnaryExpressionOrHigher();
                            }
                        }
                        const defaultType = parseOptional(64 /* EqualsToken */) ? parseType() : void 0;
                        const node = factory2.createTypeParameterDeclaration(modifiers, name, constraint, defaultType);
                        node.expression = expression;
                        return finishNode(node, pos);
                    }
                    function parseTypeParameters() {
                        if (token() === 30 /* LessThanToken */) {
                            return parseBracketedList(19 /* TypeParameters */, parseTypeParameter, 30 /* LessThanToken */, 32 /* GreaterThanToken */);
                        }
                    }
                    function isStartOfParameter(isJSDocParameter) {
                        return token() === 26 /* DotDotDotToken */ || isBindingIdentifierOrPrivateIdentifierOrPattern() || isModifierKind(token()) || token() === 60 /* AtToken */ || isStartOfType(
                        /*inStartOfParameter*/
                        !isJSDocParameter);
                    }
                    function parseNameOfParameter(modifiers) {
                        const name = parseIdentifierOrPattern(Diagnostics.Private_identifiers_cannot_be_used_as_parameters);
                        if (getFullWidth(name) === 0 && !some(modifiers) && isModifierKind(token())) {
                            nextToken();
                        }
                        return name;
                    }
                    function isParameterNameStart() {
                        return isBindingIdentifier() || token() === 23 /* OpenBracketToken */ || token() === 19 /* OpenBraceToken */;
                    }
                    function parseParameter(inOuterAwaitContext) {
                        return parseParameterWorker(inOuterAwaitContext);
                    }
                    function parseParameterForSpeculation(inOuterAwaitContext) {
                        return parseParameterWorker(inOuterAwaitContext, 
                        /*allowAmbiguity*/
                        false);
                    }
                    function parseParameterWorker(inOuterAwaitContext, allowAmbiguity = true) {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        const modifiers = inOuterAwaitContext ? doInAwaitContext(() => parseModifiers(
                        /*allowDecorators*/
                        true)) : doOutsideOfAwaitContext(() => parseModifiers(
                        /*allowDecorators*/
                        true));
                        if (token() === 110 /* ThisKeyword */) {
                            const node2 = factory2.createParameterDeclaration(modifiers, 
                            /*dotDotDotToken*/
                            void 0, createIdentifier(
                            /*isIdentifier*/
                            true), 
                            /*questionToken*/
                            void 0, parseTypeAnnotation(), 
                            /*initializer*/
                            void 0);
                            const modifier = firstOrUndefined(modifiers);
                            if (modifier) {
                                parseErrorAtRange(modifier, Diagnostics.Neither_decorators_nor_modifiers_may_be_applied_to_this_parameters);
                            }
                            return withJSDoc(finishNode(node2, pos), hasJSDoc);
                        }
                        const savedTopLevel = topLevel;
                        topLevel = false;
                        const dotDotDotToken = parseOptionalToken(26 /* DotDotDotToken */);
                        if (!allowAmbiguity && !isParameterNameStart()) {
                            return void 0;
                        }
                        const node = withJSDoc(finishNode(factory2.createParameterDeclaration(modifiers, dotDotDotToken, parseNameOfParameter(modifiers), parseOptionalToken(58 /* QuestionToken */), parseTypeAnnotation(), parseInitializer()), pos), hasJSDoc);
                        topLevel = savedTopLevel;
                        return node;
                    }
                    function parseReturnType(returnToken, isType) {
                        if (shouldParseReturnType(returnToken, isType)) {
                            return allowConditionalTypesAnd(parseTypeOrTypePredicate);
                        }
                    }
                    function shouldParseReturnType(returnToken, isType) {
                        if (returnToken === 39 /* EqualsGreaterThanToken */) {
                            parseExpected(returnToken);
                            return true;
                        }
                        else if (parseOptional(59 /* ColonToken */)) {
                            return true;
                        }
                        else if (isType && token() === 39 /* EqualsGreaterThanToken */) {
                            parseErrorAtCurrentToken(Diagnostics._0_expected, tokenToString(59 /* ColonToken */));
                            nextToken();
                            return true;
                        }
                        return false;
                    }
                    function parseParametersWorker(flags, allowAmbiguity) {
                        const savedYieldContext = inYieldContext();
                        const savedAwaitContext = inAwaitContext();
                        setYieldContext(!!(flags & 1 /* Yield */));
                        setAwaitContext(!!(flags & 2 /* Await */));
                        const parameters = flags & 32 /* JSDoc */ ? parseDelimitedList(17 /* JSDocParameters */, parseJSDocParameter) : parseDelimitedList(16 /* Parameters */, () => allowAmbiguity ? parseParameter(savedAwaitContext) : parseParameterForSpeculation(savedAwaitContext));
                        setYieldContext(savedYieldContext);
                        setAwaitContext(savedAwaitContext);
                        return parameters;
                    }
                    function parseParameters(flags) {
                        if (!parseExpected(21 /* OpenParenToken */)) {
                            return createMissingList();
                        }
                        const parameters = parseParametersWorker(flags, 
                        /*allowAmbiguity*/
                        true);
                        parseExpected(22 /* CloseParenToken */);
                        return parameters;
                    }
                    function parseTypeMemberSemicolon() {
                        if (parseOptional(28 /* CommaToken */)) {
                            return;
                        }
                        parseSemicolon();
                    }
                    function parseSignatureMember(kind) {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        if (kind === 180 /* ConstructSignature */) {
                            parseExpected(105 /* NewKeyword */);
                        }
                        const typeParameters = parseTypeParameters();
                        const parameters = parseParameters(4 /* Type */);
                        const type = parseReturnType(59 /* ColonToken */, 
                        /*isType*/
                        true);
                        parseTypeMemberSemicolon();
                        const node = kind === 179 /* CallSignature */ ? factory2.createCallSignature(typeParameters, parameters, type) : factory2.createConstructSignature(typeParameters, parameters, type);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function isIndexSignature() {
                        return token() === 23 /* OpenBracketToken */ && lookAhead(isUnambiguouslyIndexSignature);
                    }
                    function isUnambiguouslyIndexSignature() {
                        nextToken();
                        if (token() === 26 /* DotDotDotToken */ || token() === 24 /* CloseBracketToken */) {
                            return true;
                        }
                        if (isModifierKind(token())) {
                            nextToken();
                            if (isIdentifier2()) {
                                return true;
                            }
                        }
                        else if (!isIdentifier2()) {
                            return false;
                        }
                        else {
                            nextToken();
                        }
                        if (token() === 59 /* ColonToken */ || token() === 28 /* CommaToken */) {
                            return true;
                        }
                        if (token() !== 58 /* QuestionToken */) {
                            return false;
                        }
                        nextToken();
                        return token() === 59 /* ColonToken */ || token() === 28 /* CommaToken */ || token() === 24 /* CloseBracketToken */;
                    }
                    function parseIndexSignatureDeclaration(pos, hasJSDoc, modifiers) {
                        const parameters = parseBracketedList(16 /* Parameters */, () => parseParameter(
                        /*inOuterAwaitContext*/
                        false), 23 /* OpenBracketToken */, 24 /* CloseBracketToken */);
                        const type = parseTypeAnnotation();
                        parseTypeMemberSemicolon();
                        const node = factory2.createIndexSignature(modifiers, parameters, type);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parsePropertyOrMethodSignature(pos, hasJSDoc, modifiers) {
                        const name = parsePropertyName();
                        const questionToken = parseOptionalToken(58 /* QuestionToken */);
                        let node;
                        if (token() === 21 /* OpenParenToken */ || token() === 30 /* LessThanToken */) {
                            const typeParameters = parseTypeParameters();
                            const parameters = parseParameters(4 /* Type */);
                            const type = parseReturnType(59 /* ColonToken */, 
                            /*isType*/
                            true);
                            node = factory2.createMethodSignature(modifiers, name, questionToken, typeParameters, parameters, type);
                        }
                        else {
                            const type = parseTypeAnnotation();
                            node = factory2.createPropertySignature(modifiers, name, questionToken, type);
                            if (token() === 64 /* EqualsToken */)
                                node.initializer = parseInitializer();
                        }
                        parseTypeMemberSemicolon();
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function isTypeMemberStart() {
                        if (token() === 21 /* OpenParenToken */ || token() === 30 /* LessThanToken */ || token() === 139 /* GetKeyword */ || token() === 153 /* SetKeyword */) {
                            return true;
                        }
                        let idToken = false;
                        while (isModifierKind(token())) {
                            idToken = true;
                            nextToken();
                        }
                        if (token() === 23 /* OpenBracketToken */) {
                            return true;
                        }
                        if (isLiteralPropertyName()) {
                            idToken = true;
                            nextToken();
                        }
                        if (idToken) {
                            return token() === 21 /* OpenParenToken */ || token() === 30 /* LessThanToken */ || token() === 58 /* QuestionToken */ || token() === 59 /* ColonToken */ || token() === 28 /* CommaToken */ || canParseSemicolon();
                        }
                        return false;
                    }
                    function parseTypeMember() {
                        if (token() === 21 /* OpenParenToken */ || token() === 30 /* LessThanToken */) {
                            return parseSignatureMember(179 /* CallSignature */);
                        }
                        if (token() === 105 /* NewKeyword */ && lookAhead(nextTokenIsOpenParenOrLessThan)) {
                            return parseSignatureMember(180 /* ConstructSignature */);
                        }
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        const modifiers = parseModifiers(
                        /*allowDecorators*/
                        false);
                        if (parseContextualModifier(139 /* GetKeyword */)) {
                            return parseAccessorDeclaration(pos, hasJSDoc, modifiers, 177 /* GetAccessor */, 4 /* Type */);
                        }
                        if (parseContextualModifier(153 /* SetKeyword */)) {
                            return parseAccessorDeclaration(pos, hasJSDoc, modifiers, 178 /* SetAccessor */, 4 /* Type */);
                        }
                        if (isIndexSignature()) {
                            return parseIndexSignatureDeclaration(pos, hasJSDoc, modifiers);
                        }
                        return parsePropertyOrMethodSignature(pos, hasJSDoc, modifiers);
                    }
                    function nextTokenIsOpenParenOrLessThan() {
                        nextToken();
                        return token() === 21 /* OpenParenToken */ || token() === 30 /* LessThanToken */;
                    }
                    function nextTokenIsDot() {
                        return nextToken() === 25 /* DotToken */;
                    }
                    function nextTokenIsOpenParenOrLessThanOrDot() {
                        switch (nextToken()) {
                            case 21 /* OpenParenToken */:
                            case 30 /* LessThanToken */:
                            case 25 /* DotToken */:
                                return true;
                        }
                        return false;
                    }
                    function parseTypeLiteral() {
                        const pos = getNodePos();
                        return finishNode(factory2.createTypeLiteralNode(parseObjectTypeMembers()), pos);
                    }
                    function parseObjectTypeMembers() {
                        let members;
                        if (parseExpected(19 /* OpenBraceToken */)) {
                            members = parseList(4 /* TypeMembers */, parseTypeMember);
                            parseExpected(20 /* CloseBraceToken */);
                        }
                        else {
                            members = createMissingList();
                        }
                        return members;
                    }
                    function isStartOfMappedType() {
                        nextToken();
                        if (token() === 40 /* PlusToken */ || token() === 41 /* MinusToken */) {
                            return nextToken() === 148 /* ReadonlyKeyword */;
                        }
                        if (token() === 148 /* ReadonlyKeyword */) {
                            nextToken();
                        }
                        return token() === 23 /* OpenBracketToken */ && nextTokenIsIdentifier() && nextToken() === 103 /* InKeyword */;
                    }
                    function parseMappedTypeParameter() {
                        const pos = getNodePos();
                        const name = parseIdentifierName();
                        parseExpected(103 /* InKeyword */);
                        const type = parseType();
                        return finishNode(factory2.createTypeParameterDeclaration(
                        /*modifiers*/
                        void 0, name, type, 
                        /*defaultType*/
                        void 0), pos);
                    }
                    function parseMappedType() {
                        const pos = getNodePos();
                        parseExpected(19 /* OpenBraceToken */);
                        let readonlyToken;
                        if (token() === 148 /* ReadonlyKeyword */ || token() === 40 /* PlusToken */ || token() === 41 /* MinusToken */) {
                            readonlyToken = parseTokenNode();
                            if (readonlyToken.kind !== 148 /* ReadonlyKeyword */) {
                                parseExpected(148 /* ReadonlyKeyword */);
                            }
                        }
                        parseExpected(23 /* OpenBracketToken */);
                        const typeParameter = parseMappedTypeParameter();
                        const nameType = parseOptional(130 /* AsKeyword */) ? parseType() : void 0;
                        parseExpected(24 /* CloseBracketToken */);
                        let questionToken;
                        if (token() === 58 /* QuestionToken */ || token() === 40 /* PlusToken */ || token() === 41 /* MinusToken */) {
                            questionToken = parseTokenNode();
                            if (questionToken.kind !== 58 /* QuestionToken */) {
                                parseExpected(58 /* QuestionToken */);
                            }
                        }
                        const type = parseTypeAnnotation();
                        parseSemicolon();
                        const members = parseList(4 /* TypeMembers */, parseTypeMember);
                        parseExpected(20 /* CloseBraceToken */);
                        return finishNode(factory2.createMappedTypeNode(readonlyToken, typeParameter, nameType, questionToken, type, members), pos);
                    }
                    function parseTupleElementType() {
                        const pos = getNodePos();
                        if (parseOptional(26 /* DotDotDotToken */)) {
                            return finishNode(factory2.createRestTypeNode(parseType()), pos);
                        }
                        const type = parseType();
                        if (isJSDocNullableType(type) && type.pos === type.type.pos) {
                            const node = factory2.createOptionalTypeNode(type.type);
                            setTextRange(node, type);
                            node.flags = type.flags;
                            return node;
                        }
                        return type;
                    }
                    function isNextTokenColonOrQuestionColon() {
                        return nextToken() === 59 /* ColonToken */ || token() === 58 /* QuestionToken */ && nextToken() === 59 /* ColonToken */;
                    }
                    function isTupleElementName() {
                        if (token() === 26 /* DotDotDotToken */) {
                            return tokenIsIdentifierOrKeyword(nextToken()) && isNextTokenColonOrQuestionColon();
                        }
                        return tokenIsIdentifierOrKeyword(token()) && isNextTokenColonOrQuestionColon();
                    }
                    function parseTupleElementNameOrTupleElementType() {
                        if (lookAhead(isTupleElementName)) {
                            const pos = getNodePos();
                            const hasJSDoc = hasPrecedingJSDocComment();
                            const dotDotDotToken = parseOptionalToken(26 /* DotDotDotToken */);
                            const name = parseIdentifierName();
                            const questionToken = parseOptionalToken(58 /* QuestionToken */);
                            parseExpected(59 /* ColonToken */);
                            const type = parseTupleElementType();
                            const node = factory2.createNamedTupleMember(dotDotDotToken, name, questionToken, type);
                            return withJSDoc(finishNode(node, pos), hasJSDoc);
                        }
                        return parseTupleElementType();
                    }
                    function parseTupleType() {
                        const pos = getNodePos();
                        return finishNode(factory2.createTupleTypeNode(parseBracketedList(21 /* TupleElementTypes */, parseTupleElementNameOrTupleElementType, 23 /* OpenBracketToken */, 24 /* CloseBracketToken */)), pos);
                    }
                    function parseParenthesizedType() {
                        const pos = getNodePos();
                        parseExpected(21 /* OpenParenToken */);
                        const type = parseType();
                        parseExpected(22 /* CloseParenToken */);
                        return finishNode(factory2.createParenthesizedType(type), pos);
                    }
                    function parseModifiersForConstructorType() {
                        let modifiers;
                        if (token() === 128 /* AbstractKeyword */) {
                            const pos = getNodePos();
                            nextToken();
                            const modifier = finishNode(factoryCreateToken(128 /* AbstractKeyword */), pos);
                            modifiers = createNodeArray([modifier], pos);
                        }
                        return modifiers;
                    }
                    function parseFunctionOrConstructorType() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        const modifiers = parseModifiersForConstructorType();
                        const isConstructorType = parseOptional(105 /* NewKeyword */);
                        Debug.assert(!modifiers || isConstructorType, "Per isStartOfFunctionOrConstructorType, a function type cannot have modifiers.");
                        const typeParameters = parseTypeParameters();
                        const parameters = parseParameters(4 /* Type */);
                        const type = parseReturnType(39 /* EqualsGreaterThanToken */, 
                        /*isType*/
                        false);
                        const node = isConstructorType ? factory2.createConstructorTypeNode(modifiers, typeParameters, parameters, type) : factory2.createFunctionTypeNode(typeParameters, parameters, type);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseKeywordAndNoDot() {
                        const node = parseTokenNode();
                        return token() === 25 /* DotToken */ ? void 0 : node;
                    }
                    function parseLiteralTypeNode(negative) {
                        const pos = getNodePos();
                        if (negative) {
                            nextToken();
                        }
                        let expression = token() === 112 /* TrueKeyword */ || token() === 97 /* FalseKeyword */ || token() === 106 /* NullKeyword */ ? parseTokenNode() : parseLiteralLikeNode(token());
                        if (negative) {
                            expression = finishNode(factory2.createPrefixUnaryExpression(41 /* MinusToken */, expression), pos);
                        }
                        return finishNode(factory2.createLiteralTypeNode(expression), pos);
                    }
                    function isStartOfTypeOfImportType() {
                        nextToken();
                        return token() === 102 /* ImportKeyword */;
                    }
                    function parseImportType() {
                        sourceFlags |= 4194304 /* PossiblyContainsDynamicImport */;
                        const pos = getNodePos();
                        const isTypeOf = parseOptional(114 /* TypeOfKeyword */);
                        parseExpected(102 /* ImportKeyword */);
                        parseExpected(21 /* OpenParenToken */);
                        const type = parseType();
                        let attributes;
                        if (parseOptional(28 /* CommaToken */)) {
                            const openBracePosition = scanner2.getTokenStart();
                            parseExpected(19 /* OpenBraceToken */);
                            const currentToken2 = token();
                            if (currentToken2 === 118 /* WithKeyword */ || currentToken2 === 132 /* AssertKeyword */) {
                                nextToken();
                            }
                            else {
                                parseErrorAtCurrentToken(Diagnostics._0_expected, tokenToString(118 /* WithKeyword */));
                            }
                            parseExpected(59 /* ColonToken */);
                            attributes = parseImportAttributes(currentToken2, 
                            /*skipKeyword*/
                            true);
                            if (!parseExpected(20 /* CloseBraceToken */)) {
                                const lastError = lastOrUndefined(parseDiagnostics);
                                if (lastError && lastError.code === Diagnostics._0_expected.code) {
                                    addRelatedInfo(lastError, createDetachedDiagnostic(fileName, sourceText, openBracePosition, 1, Diagnostics.The_parser_expected_to_find_a_1_to_match_the_0_token_here, "{", "}"));
                                }
                            }
                        }
                        parseExpected(22 /* CloseParenToken */);
                        const qualifier = parseOptional(25 /* DotToken */) ? parseEntityNameOfTypeReference() : void 0;
                        const typeArguments = parseTypeArgumentsOfTypeReference();
                        return finishNode(factory2.createImportTypeNode(type, attributes, qualifier, typeArguments, isTypeOf), pos);
                    }
                    function nextTokenIsNumericOrBigIntLiteral() {
                        nextToken();
                        return token() === 9 /* NumericLiteral */ || token() === 10 /* BigIntLiteral */;
                    }
                    function parseNonArrayType() {
                        switch (token()) {
                            case 133 /* AnyKeyword */:
                            case 159 /* UnknownKeyword */:
                            case 154 /* StringKeyword */:
                            case 150 /* NumberKeyword */:
                            case 163 /* BigIntKeyword */:
                            case 155 /* SymbolKeyword */:
                            case 136 /* BooleanKeyword */:
                            case 157 /* UndefinedKeyword */:
                            case 146 /* NeverKeyword */:
                            case 151 /* ObjectKeyword */:
                                return tryParse(parseKeywordAndNoDot) || parseTypeReference();
                            case 67 /* AsteriskEqualsToken */:
                                scanner2.reScanAsteriskEqualsToken();
                            case 42 /* AsteriskToken */:
                                return parseJSDocAllType();
                            case 61 /* QuestionQuestionToken */:
                                scanner2.reScanQuestionToken();
                            case 58 /* QuestionToken */:
                                return parseJSDocUnknownOrNullableType();
                            case 100 /* FunctionKeyword */:
                                return parseJSDocFunctionType();
                            case 54 /* ExclamationToken */:
                                return parseJSDocNonNullableType();
                            case 15 /* NoSubstitutionTemplateLiteral */:
                            case 11 /* StringLiteral */:
                            case 9 /* NumericLiteral */:
                            case 10 /* BigIntLiteral */:
                            case 112 /* TrueKeyword */:
                            case 97 /* FalseKeyword */:
                            case 106 /* NullKeyword */:
                                return parseLiteralTypeNode();
                            case 41 /* MinusToken */:
                                return lookAhead(nextTokenIsNumericOrBigIntLiteral) ? parseLiteralTypeNode(
                                /*negative*/
                                true) : parseTypeReference();
                            case 116 /* VoidKeyword */:
                                return parseTokenNode();
                            case 110 /* ThisKeyword */: {
                                const thisKeyword = parseThisTypeNode();
                                if (token() === 142 /* IsKeyword */ && !scanner2.hasPrecedingLineBreak()) {
                                    return parseThisTypePredicate(thisKeyword);
                                }
                                else {
                                    return thisKeyword;
                                }
                            }
                            case 114 /* TypeOfKeyword */:
                                return lookAhead(isStartOfTypeOfImportType) ? parseImportType() : parseTypeQuery();
                            case 19 /* OpenBraceToken */:
                                return lookAhead(isStartOfMappedType) ? parseMappedType() : parseTypeLiteral();
                            case 23 /* OpenBracketToken */:
                                return parseTupleType();
                            case 21 /* OpenParenToken */:
                                return parseParenthesizedType();
                            case 102 /* ImportKeyword */:
                                return parseImportType();
                            case 131 /* AssertsKeyword */:
                                return lookAhead(nextTokenIsIdentifierOrKeywordOnSameLine) ? parseAssertsTypePredicate() : parseTypeReference();
                            case 16 /* TemplateHead */:
                                return parseTemplateType();
                            default:
                                return parseTypeReference();
                        }
                    }
                    function isStartOfType(inStartOfParameter) {
                        switch (token()) {
                            case 133 /* AnyKeyword */:
                            case 159 /* UnknownKeyword */:
                            case 154 /* StringKeyword */:
                            case 150 /* NumberKeyword */:
                            case 163 /* BigIntKeyword */:
                            case 136 /* BooleanKeyword */:
                            case 148 /* ReadonlyKeyword */:
                            case 155 /* SymbolKeyword */:
                            case 158 /* UniqueKeyword */:
                            case 116 /* VoidKeyword */:
                            case 157 /* UndefinedKeyword */:
                            case 106 /* NullKeyword */:
                            case 110 /* ThisKeyword */:
                            case 114 /* TypeOfKeyword */:
                            case 146 /* NeverKeyword */:
                            case 19 /* OpenBraceToken */:
                            case 23 /* OpenBracketToken */:
                            case 30 /* LessThanToken */:
                            case 52 /* BarToken */:
                            case 51 /* AmpersandToken */:
                            case 105 /* NewKeyword */:
                            case 11 /* StringLiteral */:
                            case 9 /* NumericLiteral */:
                            case 10 /* BigIntLiteral */:
                            case 112 /* TrueKeyword */:
                            case 97 /* FalseKeyword */:
                            case 151 /* ObjectKeyword */:
                            case 42 /* AsteriskToken */:
                            case 58 /* QuestionToken */:
                            case 54 /* ExclamationToken */:
                            case 26 /* DotDotDotToken */:
                            case 140 /* InferKeyword */:
                            case 102 /* ImportKeyword */:
                            case 131 /* AssertsKeyword */:
                            case 15 /* NoSubstitutionTemplateLiteral */:
                            case 16 /* TemplateHead */:
                                return true;
                            case 100 /* FunctionKeyword */:
                                return !inStartOfParameter;
                            case 41 /* MinusToken */:
                                return !inStartOfParameter && lookAhead(nextTokenIsNumericOrBigIntLiteral);
                            case 21 /* OpenParenToken */:
                                return !inStartOfParameter && lookAhead(isStartOfParenthesizedOrFunctionType);
                            default:
                                return isIdentifier2();
                        }
                    }
                    function isStartOfParenthesizedOrFunctionType() {
                        nextToken();
                        return token() === 22 /* CloseParenToken */ || isStartOfParameter(
                        /*isJSDocParameter*/
                        false) || isStartOfType();
                    }
                    function parsePostfixTypeOrHigher() {
                        const pos = getNodePos();
                        let type = parseNonArrayType();
                        while (!scanner2.hasPrecedingLineBreak()) {
                            switch (token()) {
                                case 54 /* ExclamationToken */:
                                    nextToken();
                                    type = finishNode(factory2.createJSDocNonNullableType(type, 
                                    /*postfix*/
                                    true), pos);
                                    break;
                                case 58 /* QuestionToken */:
                                    if (lookAhead(nextTokenIsStartOfType)) {
                                        return type;
                                    }
                                    nextToken();
                                    type = finishNode(factory2.createJSDocNullableType(type, 
                                    /*postfix*/
                                    true), pos);
                                    break;
                                case 23 /* OpenBracketToken */:
                                    parseExpected(23 /* OpenBracketToken */);
                                    if (isStartOfType()) {
                                        const indexType = parseType();
                                        parseExpected(24 /* CloseBracketToken */);
                                        type = finishNode(factory2.createIndexedAccessTypeNode(type, indexType), pos);
                                    }
                                    else {
                                        parseExpected(24 /* CloseBracketToken */);
                                        type = finishNode(factory2.createArrayTypeNode(type), pos);
                                    }
                                    break;
                                default:
                                    return type;
                            }
                        }
                        return type;
                    }
                    function parseTypeOperator(operator) {
                        const pos = getNodePos();
                        parseExpected(operator);
                        return finishNode(factory2.createTypeOperatorNode(operator, parseTypeOperatorOrHigher()), pos);
                    }
                    function tryParseConstraintOfInferType() {
                        if (parseOptional(96 /* ExtendsKeyword */)) {
                            const constraint = disallowConditionalTypesAnd(parseType);
                            if (inDisallowConditionalTypesContext() || token() !== 58 /* QuestionToken */) {
                                return constraint;
                            }
                        }
                    }
                    function parseTypeParameterOfInferType() {
                        const pos = getNodePos();
                        const name = parseIdentifier();
                        const constraint = tryParse(tryParseConstraintOfInferType);
                        const node = factory2.createTypeParameterDeclaration(
                        /*modifiers*/
                        void 0, name, constraint);
                        return finishNode(node, pos);
                    }
                    function parseInferType() {
                        const pos = getNodePos();
                        parseExpected(140 /* InferKeyword */);
                        return finishNode(factory2.createInferTypeNode(parseTypeParameterOfInferType()), pos);
                    }
                    function parseTypeOperatorOrHigher() {
                        const operator = token();
                        switch (operator) {
                            case 143 /* KeyOfKeyword */:
                            case 158 /* UniqueKeyword */:
                            case 148 /* ReadonlyKeyword */:
                                return parseTypeOperator(operator);
                            case 140 /* InferKeyword */:
                                return parseInferType();
                        }
                        return allowConditionalTypesAnd(parsePostfixTypeOrHigher);
                    }
                    function parseFunctionOrConstructorTypeToError(isInUnionType) {
                        if (isStartOfFunctionTypeOrConstructorType()) {
                            const type = parseFunctionOrConstructorType();
                            let diagnostic;
                            if (isFunctionTypeNode(type)) {
                                diagnostic = isInUnionType ? Diagnostics.Function_type_notation_must_be_parenthesized_when_used_in_a_union_type : Diagnostics.Function_type_notation_must_be_parenthesized_when_used_in_an_intersection_type;
                            }
                            else {
                                diagnostic = isInUnionType ? Diagnostics.Constructor_type_notation_must_be_parenthesized_when_used_in_a_union_type : Diagnostics.Constructor_type_notation_must_be_parenthesized_when_used_in_an_intersection_type;
                            }
                            parseErrorAtRange(type, diagnostic);
                            return type;
                        }
                        return void 0;
                    }
                    function parseUnionOrIntersectionType(operator, parseConstituentType, createTypeNode) {
                        const pos = getNodePos();
                        const isUnionType = operator === 52 /* BarToken */;
                        const hasLeadingOperator = parseOptional(operator);
                        let type = hasLeadingOperator && parseFunctionOrConstructorTypeToError(isUnionType) || parseConstituentType();
                        if (token() === operator || hasLeadingOperator) {
                            const types = [type];
                            while (parseOptional(operator)) {
                                types.push(parseFunctionOrConstructorTypeToError(isUnionType) || parseConstituentType());
                            }
                            type = finishNode(createTypeNode(createNodeArray(types, pos)), pos);
                        }
                        return type;
                    }
                    function parseIntersectionTypeOrHigher() {
                        return parseUnionOrIntersectionType(51 /* AmpersandToken */, parseTypeOperatorOrHigher, factory2.createIntersectionTypeNode);
                    }
                    function parseUnionTypeOrHigher() {
                        return parseUnionOrIntersectionType(52 /* BarToken */, parseIntersectionTypeOrHigher, factory2.createUnionTypeNode);
                    }
                    function nextTokenIsNewKeyword() {
                        nextToken();
                        return token() === 105 /* NewKeyword */;
                    }
                    function isStartOfFunctionTypeOrConstructorType() {
                        if (token() === 30 /* LessThanToken */) {
                            return true;
                        }
                        if (token() === 21 /* OpenParenToken */ && lookAhead(isUnambiguouslyStartOfFunctionType)) {
                            return true;
                        }
                        return token() === 105 /* NewKeyword */ || token() === 128 /* AbstractKeyword */ && lookAhead(nextTokenIsNewKeyword);
                    }
                    function skipParameterStart() {
                        if (isModifierKind(token())) {
                            parseModifiers(
                            /*allowDecorators*/
                            false);
                        }
                        if (isIdentifier2() || token() === 110 /* ThisKeyword */) {
                            nextToken();
                            return true;
                        }
                        if (token() === 23 /* OpenBracketToken */ || token() === 19 /* OpenBraceToken */) {
                            const previousErrorCount = parseDiagnostics.length;
                            parseIdentifierOrPattern();
                            return previousErrorCount === parseDiagnostics.length;
                        }
                        return false;
                    }
                    function isUnambiguouslyStartOfFunctionType() {
                        nextToken();
                        if (token() === 22 /* CloseParenToken */ || token() === 26 /* DotDotDotToken */) {
                            return true;
                        }
                        if (skipParameterStart()) {
                            if (token() === 59 /* ColonToken */ || token() === 28 /* CommaToken */ || token() === 58 /* QuestionToken */ || token() === 64 /* EqualsToken */) {
                                return true;
                            }
                            if (token() === 22 /* CloseParenToken */) {
                                nextToken();
                                if (token() === 39 /* EqualsGreaterThanToken */) {
                                    return true;
                                }
                            }
                        }
                        return false;
                    }
                    function parseTypeOrTypePredicate() {
                        const pos = getNodePos();
                        const typePredicateVariable = isIdentifier2() && tryParse(parseTypePredicatePrefix);
                        const type = parseType();
                        if (typePredicateVariable) {
                            return finishNode(factory2.createTypePredicateNode(
                            /*assertsModifier*/
                            void 0, typePredicateVariable, type), pos);
                        }
                        else {
                            return type;
                        }
                    }
                    function parseTypePredicatePrefix() {
                        const id = parseIdentifier();
                        if (token() === 142 /* IsKeyword */ && !scanner2.hasPrecedingLineBreak()) {
                            nextToken();
                            return id;
                        }
                    }
                    function parseAssertsTypePredicate() {
                        const pos = getNodePos();
                        const assertsModifier = parseExpectedToken(131 /* AssertsKeyword */);
                        const parameterName = token() === 110 /* ThisKeyword */ ? parseThisTypeNode() : parseIdentifier();
                        const type = parseOptional(142 /* IsKeyword */) ? parseType() : void 0;
                        return finishNode(factory2.createTypePredicateNode(assertsModifier, parameterName, type), pos);
                    }
                    function parseType() {
                        if (contextFlags & 81920 /* TypeExcludesFlags */) {
                            return doOutsideOfContext(81920 /* TypeExcludesFlags */, parseType);
                        }
                        if (isStartOfFunctionTypeOrConstructorType()) {
                            return parseFunctionOrConstructorType();
                        }
                        const pos = getNodePos();
                        const type = parseUnionTypeOrHigher();
                        if (!inDisallowConditionalTypesContext() && !scanner2.hasPrecedingLineBreak() && parseOptional(96 /* ExtendsKeyword */)) {
                            const extendsType = disallowConditionalTypesAnd(parseType);
                            parseExpected(58 /* QuestionToken */);
                            const trueType = allowConditionalTypesAnd(parseType);
                            parseExpected(59 /* ColonToken */);
                            const falseType = allowConditionalTypesAnd(parseType);
                            return finishNode(factory2.createConditionalTypeNode(type, extendsType, trueType, falseType), pos);
                        }
                        return type;
                    }
                    function parseTypeAnnotation() {
                        return parseOptional(59 /* ColonToken */) ? parseType() : void 0;
                    }
                    function isStartOfLeftHandSideExpression() {
                        switch (token()) {
                            case 110 /* ThisKeyword */:
                            case 108 /* SuperKeyword */:
                            case 106 /* NullKeyword */:
                            case 112 /* TrueKeyword */:
                            case 97 /* FalseKeyword */:
                            case 9 /* NumericLiteral */:
                            case 10 /* BigIntLiteral */:
                            case 11 /* StringLiteral */:
                            case 15 /* NoSubstitutionTemplateLiteral */:
                            case 16 /* TemplateHead */:
                            case 21 /* OpenParenToken */:
                            case 23 /* OpenBracketToken */:
                            case 19 /* OpenBraceToken */:
                            case 100 /* FunctionKeyword */:
                            case 86 /* ClassKeyword */:
                            case 105 /* NewKeyword */:
                            case 44 /* SlashToken */:
                            case 69 /* SlashEqualsToken */:
                            case 80 /* Identifier */:
                                return true;
                            case 102 /* ImportKeyword */:
                                return lookAhead(nextTokenIsOpenParenOrLessThanOrDot);
                            default:
                                return isIdentifier2();
                        }
                    }
                    function isStartOfExpression() {
                        if (isStartOfLeftHandSideExpression()) {
                            return true;
                        }
                        switch (token()) {
                            case 40 /* PlusToken */:
                            case 41 /* MinusToken */:
                            case 55 /* TildeToken */:
                            case 54 /* ExclamationToken */:
                            case 91 /* DeleteKeyword */:
                            case 114 /* TypeOfKeyword */:
                            case 116 /* VoidKeyword */:
                            case 46 /* PlusPlusToken */:
                            case 47 /* MinusMinusToken */:
                            case 30 /* LessThanToken */:
                            case 135 /* AwaitKeyword */:
                            case 127 /* YieldKeyword */:
                            case 81 /* PrivateIdentifier */:
                            case 60 /* AtToken */:
                                return true;
                            default:
                                if (isBinaryOperator2()) {
                                    return true;
                                }
                                return isIdentifier2();
                        }
                    }
                    function isStartOfExpressionStatement() {
                        return token() !== 19 /* OpenBraceToken */ && token() !== 100 /* FunctionKeyword */ && token() !== 86 /* ClassKeyword */ && token() !== 60 /* AtToken */ && isStartOfExpression();
                    }
                    function parseExpression() {
                        const saveDecoratorContext = inDecoratorContext();
                        if (saveDecoratorContext) {
                            setDecoratorContext(
                            /*val*/
                            false);
                        }
                        const pos = getNodePos();
                        let expr = parseAssignmentExpressionOrHigher(
                        /*allowReturnTypeInArrowFunction*/
                        true);
                        let operatorToken;
                        while (operatorToken = parseOptionalToken(28 /* CommaToken */)) {
                            expr = makeBinaryExpression(expr, operatorToken, parseAssignmentExpressionOrHigher(
                            /*allowReturnTypeInArrowFunction*/
                            true), pos);
                        }
                        if (saveDecoratorContext) {
                            setDecoratorContext(
                            /*val*/
                            true);
                        }
                        return expr;
                    }
                    function parseInitializer() {
                        return parseOptional(64 /* EqualsToken */) ? parseAssignmentExpressionOrHigher(
                        /*allowReturnTypeInArrowFunction*/
                        true) : void 0;
                    }
                    function parseAssignmentExpressionOrHigher(allowReturnTypeInArrowFunction) {
                        if (isYieldExpression2()) {
                            return parseYieldExpression();
                        }
                        const arrowExpression = tryParseParenthesizedArrowFunctionExpression(allowReturnTypeInArrowFunction) || tryParseAsyncSimpleArrowFunctionExpression(allowReturnTypeInArrowFunction);
                        if (arrowExpression) {
                            return arrowExpression;
                        }
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        const expr = parseBinaryExpressionOrHigher(0 /* Lowest */);
                        if (expr.kind === 80 /* Identifier */ && token() === 39 /* EqualsGreaterThanToken */) {
                            return parseSimpleArrowFunctionExpression(pos, expr, allowReturnTypeInArrowFunction, hasJSDoc, 
                            /*asyncModifier*/
                            void 0);
                        }
                        if (isLeftHandSideExpression(expr) && isAssignmentOperator(reScanGreaterToken())) {
                            return makeBinaryExpression(expr, parseTokenNode(), parseAssignmentExpressionOrHigher(allowReturnTypeInArrowFunction), pos);
                        }
                        return parseConditionalExpressionRest(expr, pos, allowReturnTypeInArrowFunction);
                    }
                    function isYieldExpression2() {
                        if (token() === 127 /* YieldKeyword */) {
                            if (inYieldContext()) {
                                return true;
                            }
                            return lookAhead(nextTokenIsIdentifierOrKeywordOrLiteralOnSameLine);
                        }
                        return false;
                    }
                    function nextTokenIsIdentifierOnSameLine() {
                        nextToken();
                        return !scanner2.hasPrecedingLineBreak() && isIdentifier2();
                    }
                    function parseYieldExpression() {
                        const pos = getNodePos();
                        nextToken();
                        if (!scanner2.hasPrecedingLineBreak() && (token() === 42 /* AsteriskToken */ || isStartOfExpression())) {
                            return finishNode(factory2.createYieldExpression(parseOptionalToken(42 /* AsteriskToken */), parseAssignmentExpressionOrHigher(
                            /*allowReturnTypeInArrowFunction*/
                            true)), pos);
                        }
                        else {
                            return finishNode(factory2.createYieldExpression(
                            /*asteriskToken*/
                            void 0, 
                            /*expression*/
                            void 0), pos);
                        }
                    }
                    function parseSimpleArrowFunctionExpression(pos, identifier, allowReturnTypeInArrowFunction, hasJSDoc, asyncModifier) {
                        Debug.assert(token() === 39 /* EqualsGreaterThanToken */, "parseSimpleArrowFunctionExpression should only have been called if we had a =>");
                        const parameter = factory2.createParameterDeclaration(
                        /*modifiers*/
                        void 0, 
                        /*dotDotDotToken*/
                        void 0, identifier, 
                        /*questionToken*/
                        void 0, 
                        /*type*/
                        void 0, 
                        /*initializer*/
                        void 0);
                        finishNode(parameter, identifier.pos);
                        const parameters = createNodeArray([parameter], parameter.pos, parameter.end);
                        const equalsGreaterThanToken = parseExpectedToken(39 /* EqualsGreaterThanToken */);
                        const body = parseArrowFunctionExpressionBody(
                        /*isAsync*/
                        !!asyncModifier, allowReturnTypeInArrowFunction);
                        const node = factory2.createArrowFunction(asyncModifier, 
                        /*typeParameters*/
                        void 0, parameters, 
                        /*type*/
                        void 0, equalsGreaterThanToken, body);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function tryParseParenthesizedArrowFunctionExpression(allowReturnTypeInArrowFunction) {
                        const triState = isParenthesizedArrowFunctionExpression();
                        if (triState === 0 /* False */) {
                            return void 0;
                        }
                        return triState === 1 /* True */ ? parseParenthesizedArrowFunctionExpression(
                        /*allowAmbiguity*/
                        true, 
                        /*allowReturnTypeInArrowFunction*/
                        true) : tryParse(() => parsePossibleParenthesizedArrowFunctionExpression(allowReturnTypeInArrowFunction));
                    }
                    function isParenthesizedArrowFunctionExpression() {
                        if (token() === 21 /* OpenParenToken */ || token() === 30 /* LessThanToken */ || token() === 134 /* AsyncKeyword */) {
                            return lookAhead(isParenthesizedArrowFunctionExpressionWorker);
                        }
                        if (token() === 39 /* EqualsGreaterThanToken */) {
                            return 1 /* True */;
                        }
                        return 0 /* False */;
                    }
                    function isParenthesizedArrowFunctionExpressionWorker() {
                        if (token() === 134 /* AsyncKeyword */) {
                            nextToken();
                            if (scanner2.hasPrecedingLineBreak()) {
                                return 0 /* False */;
                            }
                            if (token() !== 21 /* OpenParenToken */ && token() !== 30 /* LessThanToken */) {
                                return 0 /* False */;
                            }
                        }
                        const first2 = token();
                        const second = nextToken();
                        if (first2 === 21 /* OpenParenToken */) {
                            if (second === 22 /* CloseParenToken */) {
                                const third = nextToken();
                                switch (third) {
                                    case 39 /* EqualsGreaterThanToken */:
                                    case 59 /* ColonToken */:
                                    case 19 /* OpenBraceToken */:
                                        return 1 /* True */;
                                    default:
                                        return 0 /* False */;
                                }
                            }
                            if (second === 23 /* OpenBracketToken */ || second === 19 /* OpenBraceToken */) {
                                return 2 /* Unknown */;
                            }
                            if (second === 26 /* DotDotDotToken */) {
                                return 1 /* True */;
                            }
                            if (isModifierKind(second) && second !== 134 /* AsyncKeyword */ && lookAhead(nextTokenIsIdentifier)) {
                                if (nextToken() === 130 /* AsKeyword */) {
                                    return 0 /* False */;
                                }
                                return 1 /* True */;
                            }
                            if (!isIdentifier2() && second !== 110 /* ThisKeyword */) {
                                return 0 /* False */;
                            }
                            switch (nextToken()) {
                                case 59 /* ColonToken */:
                                    return 1 /* True */;
                                case 58 /* QuestionToken */:
                                    nextToken();
                                    if (token() === 59 /* ColonToken */ || token() === 28 /* CommaToken */ || token() === 64 /* EqualsToken */ || token() === 22 /* CloseParenToken */) {
                                        return 1 /* True */;
                                    }
                                    return 0 /* False */;
                                case 28 /* CommaToken */:
                                case 64 /* EqualsToken */:
                                case 22 /* CloseParenToken */:
                                    return 2 /* Unknown */;
                            }
                            return 0 /* False */;
                        }
                        else {
                            Debug.assert(first2 === 30 /* LessThanToken */);
                            if (!isIdentifier2() && token() !== 87 /* ConstKeyword */) {
                                return 0 /* False */;
                            }
                            if (languageVariant === 1 /* JSX */) {
                                const isArrowFunctionInJsx = lookAhead(() => {
                                    parseOptional(87 /* ConstKeyword */);
                                    const third = nextToken();
                                    if (third === 96 /* ExtendsKeyword */) {
                                        const fourth = nextToken();
                                        switch (fourth) {
                                            case 64 /* EqualsToken */:
                                            case 32 /* GreaterThanToken */:
                                            case 44 /* SlashToken */:
                                                return false;
                                            default:
                                                return true;
                                        }
                                    }
                                    else if (third === 28 /* CommaToken */ || third === 64 /* EqualsToken */) {
                                        return true;
                                    }
                                    return false;
                                });
                                if (isArrowFunctionInJsx) {
                                    return 1 /* True */;
                                }
                                return 0 /* False */;
                            }
                            return 2 /* Unknown */;
                        }
                    }
                    function parsePossibleParenthesizedArrowFunctionExpression(allowReturnTypeInArrowFunction) {
                        const tokenPos = scanner2.getTokenStart();
                        if (notParenthesizedArrow == null ? void 0 : notParenthesizedArrow.has(tokenPos)) {
                            return void 0;
                        }
                        const result = parseParenthesizedArrowFunctionExpression(
                        /*allowAmbiguity*/
                        false, allowReturnTypeInArrowFunction);
                        if (!result) {
                            (notParenthesizedArrow || (notParenthesizedArrow = /* @__PURE__ */ new Set())).add(tokenPos);
                        }
                        return result;
                    }
                    function tryParseAsyncSimpleArrowFunctionExpression(allowReturnTypeInArrowFunction) {
                        if (token() === 134 /* AsyncKeyword */) {
                            if (lookAhead(isUnParenthesizedAsyncArrowFunctionWorker) === 1 /* True */) {
                                const pos = getNodePos();
                                const hasJSDoc = hasPrecedingJSDocComment();
                                const asyncModifier = parseModifiersForArrowFunction();
                                const expr = parseBinaryExpressionOrHigher(0 /* Lowest */);
                                return parseSimpleArrowFunctionExpression(pos, expr, allowReturnTypeInArrowFunction, hasJSDoc, asyncModifier);
                            }
                        }
                        return void 0;
                    }
                    function isUnParenthesizedAsyncArrowFunctionWorker() {
                        if (token() === 134 /* AsyncKeyword */) {
                            nextToken();
                            if (scanner2.hasPrecedingLineBreak() || token() === 39 /* EqualsGreaterThanToken */) {
                                return 0 /* False */;
                            }
                            const expr = parseBinaryExpressionOrHigher(0 /* Lowest */);
                            if (!scanner2.hasPrecedingLineBreak() && expr.kind === 80 /* Identifier */ && token() === 39 /* EqualsGreaterThanToken */) {
                                return 1 /* True */;
                            }
                        }
                        return 0 /* False */;
                    }
                    function parseParenthesizedArrowFunctionExpression(allowAmbiguity, allowReturnTypeInArrowFunction) {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        const modifiers = parseModifiersForArrowFunction();
                        const isAsync = some(modifiers, isAsyncModifier) ? 2 /* Await */ : 0 /* None */;
                        const typeParameters = parseTypeParameters();
                        let parameters;
                        if (!parseExpected(21 /* OpenParenToken */)) {
                            if (!allowAmbiguity) {
                                return void 0;
                            }
                            parameters = createMissingList();
                        }
                        else {
                            if (!allowAmbiguity) {
                                const maybeParameters = parseParametersWorker(isAsync, allowAmbiguity);
                                if (!maybeParameters) {
                                    return void 0;
                                }
                                parameters = maybeParameters;
                            }
                            else {
                                parameters = parseParametersWorker(isAsync, allowAmbiguity);
                            }
                            if (!parseExpected(22 /* CloseParenToken */) && !allowAmbiguity) {
                                return void 0;
                            }
                        }
                        const hasReturnColon = token() === 59 /* ColonToken */;
                        const type = parseReturnType(59 /* ColonToken */, 
                        /*isType*/
                        false);
                        if (type && !allowAmbiguity && typeHasArrowFunctionBlockingParseError(type)) {
                            return void 0;
                        }
                        let unwrappedType = type;
                        while ((unwrappedType == null ? void 0 : unwrappedType.kind) === 196 /* ParenthesizedType */) {
                            unwrappedType = unwrappedType.type;
                        }
                        const hasJSDocFunctionType = unwrappedType && isJSDocFunctionType(unwrappedType);
                        if (!allowAmbiguity && token() !== 39 /* EqualsGreaterThanToken */ && (hasJSDocFunctionType || token() !== 19 /* OpenBraceToken */)) {
                            return void 0;
                        }
                        const lastToken = token();
                        const equalsGreaterThanToken = parseExpectedToken(39 /* EqualsGreaterThanToken */);
                        const body = lastToken === 39 /* EqualsGreaterThanToken */ || lastToken === 19 /* OpenBraceToken */ ? parseArrowFunctionExpressionBody(some(modifiers, isAsyncModifier), allowReturnTypeInArrowFunction) : parseIdentifier();
                        if (!allowReturnTypeInArrowFunction && hasReturnColon) {
                            if (token() !== 59 /* ColonToken */) {
                                return void 0;
                            }
                        }
                        const node = factory2.createArrowFunction(modifiers, typeParameters, parameters, type, equalsGreaterThanToken, body);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseArrowFunctionExpressionBody(isAsync, allowReturnTypeInArrowFunction) {
                        if (token() === 19 /* OpenBraceToken */) {
                            return parseFunctionBlock(isAsync ? 2 /* Await */ : 0 /* None */);
                        }
                        if (token() !== 27 /* SemicolonToken */ && token() !== 100 /* FunctionKeyword */ && token() !== 86 /* ClassKeyword */ && isStartOfStatement() && !isStartOfExpressionStatement()) {
                            return parseFunctionBlock(16 /* IgnoreMissingOpenBrace */ | (isAsync ? 2 /* Await */ : 0 /* None */));
                        }
                        const savedTopLevel = topLevel;
                        topLevel = false;
                        const node = isAsync ? doInAwaitContext(() => parseAssignmentExpressionOrHigher(allowReturnTypeInArrowFunction)) : doOutsideOfAwaitContext(() => parseAssignmentExpressionOrHigher(allowReturnTypeInArrowFunction));
                        topLevel = savedTopLevel;
                        return node;
                    }
                    function parseConditionalExpressionRest(leftOperand, pos, allowReturnTypeInArrowFunction) {
                        const questionToken = parseOptionalToken(58 /* QuestionToken */);
                        if (!questionToken) {
                            return leftOperand;
                        }
                        let colonToken;
                        return finishNode(factory2.createConditionalExpression(leftOperand, questionToken, doOutsideOfContext(disallowInAndDecoratorContext, () => parseAssignmentExpressionOrHigher(
                        /*allowReturnTypeInArrowFunction*/
                        false)), colonToken = parseExpectedToken(59 /* ColonToken */), nodeIsPresent(colonToken) ? parseAssignmentExpressionOrHigher(allowReturnTypeInArrowFunction) : createMissingNode(80 /* Identifier */, 
                        /*reportAtCurrentPosition*/
                        false, Diagnostics._0_expected, tokenToString(59 /* ColonToken */))), pos);
                    }
                    function parseBinaryExpressionOrHigher(precedence) {
                        const pos = getNodePos();
                        const leftOperand = parseUnaryExpressionOrHigher();
                        return parseBinaryExpressionRest(precedence, leftOperand, pos);
                    }
                    function isInOrOfKeyword(t) {
                        return t === 103 /* InKeyword */ || t === 165 /* OfKeyword */;
                    }
                    function parseBinaryExpressionRest(precedence, leftOperand, pos) {
                        while (true) {
                            reScanGreaterToken();
                            const newPrecedence = getBinaryOperatorPrecedence(token());
                            const consumeCurrentOperator = token() === 43 /* AsteriskAsteriskToken */ ? newPrecedence >= precedence : newPrecedence > precedence;
                            if (!consumeCurrentOperator) {
                                break;
                            }
                            if (token() === 103 /* InKeyword */ && inDisallowInContext()) {
                                break;
                            }
                            if (token() === 130 /* AsKeyword */ || token() === 152 /* SatisfiesKeyword */) {
                                if (scanner2.hasPrecedingLineBreak()) {
                                    break;
                                }
                                else {
                                    const keywordKind = token();
                                    nextToken();
                                    leftOperand = keywordKind === 152 /* SatisfiesKeyword */ ? makeSatisfiesExpression(leftOperand, parseType()) : makeAsExpression(leftOperand, parseType());
                                }
                            }
                            else {
                                leftOperand = makeBinaryExpression(leftOperand, parseTokenNode(), parseBinaryExpressionOrHigher(newPrecedence), pos);
                            }
                        }
                        return leftOperand;
                    }
                    function isBinaryOperator2() {
                        if (inDisallowInContext() && token() === 103 /* InKeyword */) {
                            return false;
                        }
                        return getBinaryOperatorPrecedence(token()) > 0;
                    }
                    function makeSatisfiesExpression(left, right) {
                        return finishNode(factory2.createSatisfiesExpression(left, right), left.pos);
                    }
                    function makeBinaryExpression(left, operatorToken, right, pos) {
                        return finishNode(factory2.createBinaryExpression(left, operatorToken, right), pos);
                    }
                    function makeAsExpression(left, right) {
                        return finishNode(factory2.createAsExpression(left, right), left.pos);
                    }
                    function parsePrefixUnaryExpression() {
                        const pos = getNodePos();
                        return finishNode(factory2.createPrefixUnaryExpression(token(), nextTokenAnd(parseSimpleUnaryExpression)), pos);
                    }
                    function parseDeleteExpression() {
                        const pos = getNodePos();
                        return finishNode(factory2.createDeleteExpression(nextTokenAnd(parseSimpleUnaryExpression)), pos);
                    }
                    function parseTypeOfExpression() {
                        const pos = getNodePos();
                        return finishNode(factory2.createTypeOfExpression(nextTokenAnd(parseSimpleUnaryExpression)), pos);
                    }
                    function parseVoidExpression() {
                        const pos = getNodePos();
                        return finishNode(factory2.createVoidExpression(nextTokenAnd(parseSimpleUnaryExpression)), pos);
                    }
                    function isAwaitExpression2() {
                        if (token() === 135 /* AwaitKeyword */) {
                            if (inAwaitContext()) {
                                return true;
                            }
                            return lookAhead(nextTokenIsIdentifierOrKeywordOrLiteralOnSameLine);
                        }
                        return false;
                    }
                    function parseAwaitExpression() {
                        const pos = getNodePos();
                        return finishNode(factory2.createAwaitExpression(nextTokenAnd(parseSimpleUnaryExpression)), pos);
                    }
                    function parseUnaryExpressionOrHigher() {
                        if (isUpdateExpression()) {
                            const pos = getNodePos();
                            const updateExpression = parseUpdateExpression();
                            return token() === 43 /* AsteriskAsteriskToken */ ? parseBinaryExpressionRest(getBinaryOperatorPrecedence(token()), updateExpression, pos) : updateExpression;
                        }
                        const unaryOperator = token();
                        const simpleUnaryExpression = parseSimpleUnaryExpression();
                        if (token() === 43 /* AsteriskAsteriskToken */) {
                            const pos = skipTrivia(sourceText, simpleUnaryExpression.pos);
                            const { end } = simpleUnaryExpression;
                            if (simpleUnaryExpression.kind === 216 /* TypeAssertionExpression */) {
                                parseErrorAt(pos, end, Diagnostics.A_type_assertion_expression_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_expression_Consider_enclosing_the_expression_in_parentheses);
                            }
                            else {
                                Debug.assert(isKeywordOrPunctuation(unaryOperator));
                                parseErrorAt(pos, end, Diagnostics.An_unary_expression_with_the_0_operator_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_expression_Consider_enclosing_the_expression_in_parentheses, tokenToString(unaryOperator));
                            }
                        }
                        return simpleUnaryExpression;
                    }
                    function parseSimpleUnaryExpression() {
                        switch (token()) {
                            case 40 /* PlusToken */:
                            case 41 /* MinusToken */:
                            case 55 /* TildeToken */:
                            case 54 /* ExclamationToken */:
                                return parsePrefixUnaryExpression();
                            case 91 /* DeleteKeyword */:
                                return parseDeleteExpression();
                            case 114 /* TypeOfKeyword */:
                                return parseTypeOfExpression();
                            case 116 /* VoidKeyword */:
                                return parseVoidExpression();
                            case 30 /* LessThanToken */:
                                if (languageVariant === 1 /* JSX */) {
                                    return parseJsxElementOrSelfClosingElementOrFragment(
                                    /*inExpressionContext*/
                                    true, 
                                    /*topInvalidNodePosition*/
                                    void 0, 
                                    /*openingTag*/
                                    void 0, 
                                    /*mustBeUnary*/
                                    true);
                                }
                                return parseTypeAssertion();
                            case 135 /* AwaitKeyword */:
                                if (isAwaitExpression2()) {
                                    return parseAwaitExpression();
                                }
                            default:
                                return parseUpdateExpression();
                        }
                    }
                    function isUpdateExpression() {
                        switch (token()) {
                            case 40 /* PlusToken */:
                            case 41 /* MinusToken */:
                            case 55 /* TildeToken */:
                            case 54 /* ExclamationToken */:
                            case 91 /* DeleteKeyword */:
                            case 114 /* TypeOfKeyword */:
                            case 116 /* VoidKeyword */:
                            case 135 /* AwaitKeyword */:
                                return false;
                            case 30 /* LessThanToken */:
                                if (languageVariant !== 1 /* JSX */) {
                                    return false;
                                }
                            default:
                                return true;
                        }
                    }
                    function parseUpdateExpression() {
                        if (token() === 46 /* PlusPlusToken */ || token() === 47 /* MinusMinusToken */) {
                            const pos = getNodePos();
                            return finishNode(factory2.createPrefixUnaryExpression(token(), nextTokenAnd(parseLeftHandSideExpressionOrHigher)), pos);
                        }
                        else if (languageVariant === 1 /* JSX */ && token() === 30 /* LessThanToken */ && lookAhead(nextTokenIsIdentifierOrKeywordOrGreaterThan)) {
                            return parseJsxElementOrSelfClosingElementOrFragment(
                            /*inExpressionContext*/
                            true);
                        }
                        const expression = parseLeftHandSideExpressionOrHigher();
                        Debug.assert(isLeftHandSideExpression(expression));
                        if ((token() === 46 /* PlusPlusToken */ || token() === 47 /* MinusMinusToken */) && !scanner2.hasPrecedingLineBreak()) {
                            const operator = token();
                            nextToken();
                            return finishNode(factory2.createPostfixUnaryExpression(expression, operator), expression.pos);
                        }
                        return expression;
                    }
                    function parseLeftHandSideExpressionOrHigher() {
                        const pos = getNodePos();
                        let expression;
                        if (token() === 102 /* ImportKeyword */) {
                            if (lookAhead(nextTokenIsOpenParenOrLessThan)) {
                                sourceFlags |= 4194304 /* PossiblyContainsDynamicImport */;
                                expression = parseTokenNode();
                            }
                            else if (lookAhead(nextTokenIsDot)) {
                                nextToken();
                                nextToken();
                                expression = finishNode(factory2.createMetaProperty(102 /* ImportKeyword */, parseIdentifierName()), pos);
                                sourceFlags |= 8388608 /* PossiblyContainsImportMeta */;
                            }
                            else {
                                expression = parseMemberExpressionOrHigher();
                            }
                        }
                        else {
                            expression = token() === 108 /* SuperKeyword */ ? parseSuperExpression() : parseMemberExpressionOrHigher();
                        }
                        return parseCallExpressionRest(pos, expression);
                    }
                    function parseMemberExpressionOrHigher() {
                        const pos = getNodePos();
                        const expression = parsePrimaryExpression();
                        return parseMemberExpressionRest(pos, expression, 
                        /*allowOptionalChain*/
                        true);
                    }
                    function parseSuperExpression() {
                        const pos = getNodePos();
                        let expression = parseTokenNode();
                        if (token() === 30 /* LessThanToken */) {
                            const startPos = getNodePos();
                            const typeArguments = tryParse(parseTypeArgumentsInExpression);
                            if (typeArguments !== void 0) {
                                parseErrorAt(startPos, getNodePos(), Diagnostics.super_may_not_use_type_arguments);
                                if (!isTemplateStartOfTaggedTemplate()) {
                                    expression = factory2.createExpressionWithTypeArguments(expression, typeArguments);
                                }
                            }
                        }
                        if (token() === 21 /* OpenParenToken */ || token() === 25 /* DotToken */ || token() === 23 /* OpenBracketToken */) {
                            return expression;
                        }
                        parseExpectedToken(25 /* DotToken */, Diagnostics.super_must_be_followed_by_an_argument_list_or_member_access);
                        return finishNode(factoryCreatePropertyAccessExpression(expression, parseRightSideOfDot(
                        /*allowIdentifierNames*/
                        true, 
                        /*allowPrivateIdentifiers*/
                        true, 
                        /*allowUnicodeEscapeSequenceInIdentifierName*/
                        true)), pos);
                    }
                    function parseJsxElementOrSelfClosingElementOrFragment(inExpressionContext, topInvalidNodePosition, openingTag, mustBeUnary = false) {
                        const pos = getNodePos();
                        const opening = parseJsxOpeningOrSelfClosingElementOrOpeningFragment(inExpressionContext);
                        let result;
                        if (opening.kind === 286 /* JsxOpeningElement */) {
                            let children = parseJsxChildren(opening);
                            let closingElement;
                            const lastChild = children[children.length - 1];
                            if ((lastChild == null ? void 0 : lastChild.kind) === 284 /* JsxElement */ && !tagNamesAreEquivalent(lastChild.openingElement.tagName, lastChild.closingElement.tagName) && tagNamesAreEquivalent(opening.tagName, lastChild.closingElement.tagName)) {
                                const end = lastChild.children.end;
                                const newLast = finishNode(factory2.createJsxElement(lastChild.openingElement, lastChild.children, finishNode(factory2.createJsxClosingElement(finishNode(factoryCreateIdentifier(""), end, end)), end, end)), lastChild.openingElement.pos, end);
                                children = createNodeArray([...children.slice(0, children.length - 1), newLast], children.pos, end);
                                closingElement = lastChild.closingElement;
                            }
                            else {
                                closingElement = parseJsxClosingElement(opening, inExpressionContext);
                                if (!tagNamesAreEquivalent(opening.tagName, closingElement.tagName)) {
                                    if (openingTag && isJsxOpeningElement(openingTag) && tagNamesAreEquivalent(closingElement.tagName, openingTag.tagName)) {
                                        parseErrorAtRange(opening.tagName, Diagnostics.JSX_element_0_has_no_corresponding_closing_tag, getTextOfNodeFromSourceText(sourceText, opening.tagName));
                                    }
                                    else {
                                        parseErrorAtRange(closingElement.tagName, Diagnostics.Expected_corresponding_JSX_closing_tag_for_0, getTextOfNodeFromSourceText(sourceText, opening.tagName));
                                    }
                                }
                            }
                            result = finishNode(factory2.createJsxElement(opening, children, closingElement), pos);
                        }
                        else if (opening.kind === 289 /* JsxOpeningFragment */) {
                            result = finishNode(factory2.createJsxFragment(opening, parseJsxChildren(opening), parseJsxClosingFragment(inExpressionContext)), pos);
                        }
                        else {
                            Debug.assert(opening.kind === 285 /* JsxSelfClosingElement */);
                            result = opening;
                        }
                        if (!mustBeUnary && inExpressionContext && token() === 30 /* LessThanToken */) {
                            const topBadPos = typeof topInvalidNodePosition === "undefined" ? result.pos : topInvalidNodePosition;
                            const invalidElement = tryParse(() => parseJsxElementOrSelfClosingElementOrFragment(
                            /*inExpressionContext*/
                            true, topBadPos));
                            if (invalidElement) {
                                const operatorToken = createMissingNode(28 /* CommaToken */, 
                                /*reportAtCurrentPosition*/
                                false);
                                setTextRangePosWidth(operatorToken, invalidElement.pos, 0);
                                parseErrorAt(skipTrivia(sourceText, topBadPos), invalidElement.end, Diagnostics.JSX_expressions_must_have_one_parent_element);
                                return finishNode(factory2.createBinaryExpression(result, operatorToken, invalidElement), pos);
                            }
                        }
                        return result;
                    }
                    function parseJsxText() {
                        const pos = getNodePos();
                        const node = factory2.createJsxText(scanner2.getTokenValue(), currentToken === 13 /* JsxTextAllWhiteSpaces */);
                        currentToken = scanner2.scanJsxToken();
                        return finishNode(node, pos);
                    }
                    function parseJsxChild(openingTag, token2) {
                        switch (token2) {
                            case 1 /* EndOfFileToken */:
                                if (isJsxOpeningFragment(openingTag)) {
                                    parseErrorAtRange(openingTag, Diagnostics.JSX_fragment_has_no_corresponding_closing_tag);
                                }
                                else {
                                    const tag = openingTag.tagName;
                                    const start = Math.min(skipTrivia(sourceText, tag.pos), tag.end);
                                    parseErrorAt(start, tag.end, Diagnostics.JSX_element_0_has_no_corresponding_closing_tag, getTextOfNodeFromSourceText(sourceText, openingTag.tagName));
                                }
                                return void 0;
                            case 31 /* LessThanSlashToken */:
                            case 7 /* ConflictMarkerTrivia */:
                                return void 0;
                            case 12 /* JsxText */:
                            case 13 /* JsxTextAllWhiteSpaces */:
                                return parseJsxText();
                            case 19 /* OpenBraceToken */:
                                return parseJsxExpression(
                                /*inExpressionContext*/
                                false);
                            case 30 /* LessThanToken */:
                                return parseJsxElementOrSelfClosingElementOrFragment(
                                /*inExpressionContext*/
                                false, 
                                /*topInvalidNodePosition*/
                                void 0, openingTag);
                            default:
                                return Debug.assertNever(token2);
                        }
                    }
                    function parseJsxChildren(openingTag) {
                        const list = [];
                        const listPos = getNodePos();
                        const saveParsingContext = parsingContext;
                        parsingContext |= 1 << 14 /* JsxChildren */;
                        while (true) {
                            const child = parseJsxChild(openingTag, currentToken = scanner2.reScanJsxToken());
                            if (!child)
                                break;
                            list.push(child);
                            if (isJsxOpeningElement(openingTag) && (child == null ? void 0 : child.kind) === 284 /* JsxElement */ && !tagNamesAreEquivalent(child.openingElement.tagName, child.closingElement.tagName) && tagNamesAreEquivalent(openingTag.tagName, child.closingElement.tagName)) {
                                break;
                            }
                        }
                        parsingContext = saveParsingContext;
                        return createNodeArray(list, listPos);
                    }
                    function parseJsxAttributes() {
                        const pos = getNodePos();
                        return finishNode(factory2.createJsxAttributes(parseList(13 /* JsxAttributes */, parseJsxAttribute)), pos);
                    }
                    function parseJsxOpeningOrSelfClosingElementOrOpeningFragment(inExpressionContext) {
                        const pos = getNodePos();
                        parseExpected(30 /* LessThanToken */);
                        if (token() === 32 /* GreaterThanToken */) {
                            scanJsxText();
                            return finishNode(factory2.createJsxOpeningFragment(), pos);
                        }
                        const tagName = parseJsxElementName();
                        const typeArguments = (contextFlags & 524288 /* JavaScriptFile */) === 0 ? tryParseTypeArguments() : void 0;
                        const attributes = parseJsxAttributes();
                        let node;
                        if (token() === 32 /* GreaterThanToken */) {
                            scanJsxText();
                            node = factory2.createJsxOpeningElement(tagName, typeArguments, attributes);
                        }
                        else {
                            parseExpected(44 /* SlashToken */);
                            if (parseExpected(32 /* GreaterThanToken */, 
                            /*diagnosticMessage*/
                            void 0, 
                            /*shouldAdvance*/
                            false)) {
                                if (inExpressionContext) {
                                    nextToken();
                                }
                                else {
                                    scanJsxText();
                                }
                            }
                            node = factory2.createJsxSelfClosingElement(tagName, typeArguments, attributes);
                        }
                        return finishNode(node, pos);
                    }
                    function parseJsxElementName() {
                        const pos = getNodePos();
                        const initialExpression = parseJsxTagName();
                        if (isJsxNamespacedName(initialExpression)) {
                            return initialExpression;
                        }
                        let expression = initialExpression;
                        while (parseOptional(25 /* DotToken */)) {
                            expression = finishNode(factoryCreatePropertyAccessExpression(expression, parseRightSideOfDot(
                            /*allowIdentifierNames*/
                            true, 
                            /*allowPrivateIdentifiers*/
                            false, 
                            /*allowUnicodeEscapeSequenceInIdentifierName*/
                            false)), pos);
                        }
                        return expression;
                    }
                    function parseJsxTagName() {
                        const pos = getNodePos();
                        scanJsxIdentifier();
                        const isThis2 = token() === 110 /* ThisKeyword */;
                        const tagName = parseIdentifierNameErrorOnUnicodeEscapeSequence();
                        if (parseOptional(59 /* ColonToken */)) {
                            scanJsxIdentifier();
                            return finishNode(factory2.createJsxNamespacedName(tagName, parseIdentifierNameErrorOnUnicodeEscapeSequence()), pos);
                        }
                        return isThis2 ? finishNode(factory2.createToken(110 /* ThisKeyword */), pos) : tagName;
                    }
                    function parseJsxExpression(inExpressionContext) {
                        const pos = getNodePos();
                        if (!parseExpected(19 /* OpenBraceToken */)) {
                            return void 0;
                        }
                        let dotDotDotToken;
                        let expression;
                        if (token() !== 20 /* CloseBraceToken */) {
                            if (!inExpressionContext) {
                                dotDotDotToken = parseOptionalToken(26 /* DotDotDotToken */);
                            }
                            expression = parseExpression();
                        }
                        if (inExpressionContext) {
                            parseExpected(20 /* CloseBraceToken */);
                        }
                        else {
                            if (parseExpected(20 /* CloseBraceToken */, 
                            /*diagnosticMessage*/
                            void 0, 
                            /*shouldAdvance*/
                            false)) {
                                scanJsxText();
                            }
                        }
                        return finishNode(factory2.createJsxExpression(dotDotDotToken, expression), pos);
                    }
                    function parseJsxAttribute() {
                        if (token() === 19 /* OpenBraceToken */) {
                            return parseJsxSpreadAttribute();
                        }
                        const pos = getNodePos();
                        return finishNode(factory2.createJsxAttribute(parseJsxAttributeName(), parseJsxAttributeValue()), pos);
                    }
                    function parseJsxAttributeValue() {
                        if (token() === 64 /* EqualsToken */) {
                            if (scanJsxAttributeValue() === 11 /* StringLiteral */) {
                                return parseLiteralNode();
                            }
                            if (token() === 19 /* OpenBraceToken */) {
                                return parseJsxExpression(
                                /*inExpressionContext*/
                                true);
                            }
                            if (token() === 30 /* LessThanToken */) {
                                return parseJsxElementOrSelfClosingElementOrFragment(
                                /*inExpressionContext*/
                                true);
                            }
                            parseErrorAtCurrentToken(Diagnostics.or_JSX_element_expected);
                        }
                        return void 0;
                    }
                    function parseJsxAttributeName() {
                        const pos = getNodePos();
                        scanJsxIdentifier();
                        const attrName = parseIdentifierNameErrorOnUnicodeEscapeSequence();
                        if (parseOptional(59 /* ColonToken */)) {
                            scanJsxIdentifier();
                            return finishNode(factory2.createJsxNamespacedName(attrName, parseIdentifierNameErrorOnUnicodeEscapeSequence()), pos);
                        }
                        return attrName;
                    }
                    function parseJsxSpreadAttribute() {
                        const pos = getNodePos();
                        parseExpected(19 /* OpenBraceToken */);
                        parseExpected(26 /* DotDotDotToken */);
                        const expression = parseExpression();
                        parseExpected(20 /* CloseBraceToken */);
                        return finishNode(factory2.createJsxSpreadAttribute(expression), pos);
                    }
                    function parseJsxClosingElement(open, inExpressionContext) {
                        const pos = getNodePos();
                        parseExpected(31 /* LessThanSlashToken */);
                        const tagName = parseJsxElementName();
                        if (parseExpected(32 /* GreaterThanToken */, 
                        /*diagnosticMessage*/
                        void 0, 
                        /*shouldAdvance*/
                        false)) {
                            if (inExpressionContext || !tagNamesAreEquivalent(open.tagName, tagName)) {
                                nextToken();
                            }
                            else {
                                scanJsxText();
                            }
                        }
                        return finishNode(factory2.createJsxClosingElement(tagName), pos);
                    }
                    function parseJsxClosingFragment(inExpressionContext) {
                        const pos = getNodePos();
                        parseExpected(31 /* LessThanSlashToken */);
                        if (parseExpected(32 /* GreaterThanToken */, Diagnostics.Expected_corresponding_closing_tag_for_JSX_fragment, 
                        /*shouldAdvance*/
                        false)) {
                            if (inExpressionContext) {
                                nextToken();
                            }
                            else {
                                scanJsxText();
                            }
                        }
                        return finishNode(factory2.createJsxJsxClosingFragment(), pos);
                    }
                    function parseTypeAssertion() {
                        Debug.assert(languageVariant !== 1 /* JSX */, "Type assertions should never be parsed in JSX; they should be parsed as comparisons or JSX elements/fragments.");
                        const pos = getNodePos();
                        parseExpected(30 /* LessThanToken */);
                        const type = parseType();
                        parseExpected(32 /* GreaterThanToken */);
                        const expression = parseSimpleUnaryExpression();
                        return finishNode(factory2.createTypeAssertion(type, expression), pos);
                    }
                    function nextTokenIsIdentifierOrKeywordOrOpenBracketOrTemplate() {
                        nextToken();
                        return tokenIsIdentifierOrKeyword(token()) || token() === 23 /* OpenBracketToken */ || isTemplateStartOfTaggedTemplate();
                    }
                    function isStartOfOptionalPropertyOrElementAccessChain() {
                        return token() === 29 /* QuestionDotToken */ && lookAhead(nextTokenIsIdentifierOrKeywordOrOpenBracketOrTemplate);
                    }
                    function tryReparseOptionalChain(node) {
                        if (node.flags & 64 /* OptionalChain */) {
                            return true;
                        }
                        if (isNonNullExpression(node)) {
                            let expr = node.expression;
                            while (isNonNullExpression(expr) && !(expr.flags & 64 /* OptionalChain */)) {
                                expr = expr.expression;
                            }
                            if (expr.flags & 64 /* OptionalChain */) {
                                while (isNonNullExpression(node)) {
                                    node.flags |= 64 /* OptionalChain */;
                                    node = node.expression;
                                }
                                return true;
                            }
                        }
                        return false;
                    }
                    function parsePropertyAccessExpressionRest(pos, expression, questionDotToken) {
                        const name = parseRightSideOfDot(
                        /*allowIdentifierNames*/
                        true, 
                        /*allowPrivateIdentifiers*/
                        true, 
                        /*allowUnicodeEscapeSequenceInIdentifierName*/
                        true);
                        const isOptionalChain2 = questionDotToken || tryReparseOptionalChain(expression);
                        const propertyAccess = isOptionalChain2 ? factoryCreatePropertyAccessChain(expression, questionDotToken, name) : factoryCreatePropertyAccessExpression(expression, name);
                        if (isOptionalChain2 && isPrivateIdentifier(propertyAccess.name)) {
                            parseErrorAtRange(propertyAccess.name, Diagnostics.An_optional_chain_cannot_contain_private_identifiers);
                        }
                        if (isExpressionWithTypeArguments(expression) && expression.typeArguments) {
                            const pos2 = expression.typeArguments.pos - 1;
                            const end = skipTrivia(sourceText, expression.typeArguments.end) + 1;
                            parseErrorAt(pos2, end, Diagnostics.An_instantiation_expression_cannot_be_followed_by_a_property_access);
                        }
                        return finishNode(propertyAccess, pos);
                    }
                    function parseElementAccessExpressionRest(pos, expression, questionDotToken) {
                        let argumentExpression;
                        if (token() === 24 /* CloseBracketToken */) {
                            argumentExpression = createMissingNode(80 /* Identifier */, 
                            /*reportAtCurrentPosition*/
                            true, Diagnostics.An_element_access_expression_should_take_an_argument);
                        }
                        else {
                            const argument = allowInAnd(parseExpression);
                            if (isStringOrNumericLiteralLike(argument)) {
                                argument.text = internIdentifier(argument.text);
                            }
                            argumentExpression = argument;
                        }
                        parseExpected(24 /* CloseBracketToken */);
                        const indexedAccess = questionDotToken || tryReparseOptionalChain(expression) ? factoryCreateElementAccessChain(expression, questionDotToken, argumentExpression) : factoryCreateElementAccessExpression(expression, argumentExpression);
                        return finishNode(indexedAccess, pos);
                    }
                    function parseMemberExpressionRest(pos, expression, allowOptionalChain) {
                        while (true) {
                            let questionDotToken;
                            let isPropertyAccess = false;
                            if (allowOptionalChain && isStartOfOptionalPropertyOrElementAccessChain()) {
                                questionDotToken = parseExpectedToken(29 /* QuestionDotToken */);
                                isPropertyAccess = tokenIsIdentifierOrKeyword(token());
                            }
                            else {
                                isPropertyAccess = parseOptional(25 /* DotToken */);
                            }
                            if (isPropertyAccess) {
                                expression = parsePropertyAccessExpressionRest(pos, expression, questionDotToken);
                                continue;
                            }
                            if ((questionDotToken || !inDecoratorContext()) && parseOptional(23 /* OpenBracketToken */)) {
                                expression = parseElementAccessExpressionRest(pos, expression, questionDotToken);
                                continue;
                            }
                            if (isTemplateStartOfTaggedTemplate()) {
                                expression = !questionDotToken && expression.kind === 233 /* ExpressionWithTypeArguments */ ? parseTaggedTemplateRest(pos, expression.expression, questionDotToken, expression.typeArguments) : parseTaggedTemplateRest(pos, expression, questionDotToken, 
                                /*typeArguments*/
                                void 0);
                                continue;
                            }
                            if (!questionDotToken) {
                                if (token() === 54 /* ExclamationToken */ && !scanner2.hasPrecedingLineBreak()) {
                                    nextToken();
                                    expression = finishNode(factory2.createNonNullExpression(expression), pos);
                                    continue;
                                }
                                const typeArguments = tryParse(parseTypeArgumentsInExpression);
                                if (typeArguments) {
                                    expression = finishNode(factory2.createExpressionWithTypeArguments(expression, typeArguments), pos);
                                    continue;
                                }
                            }
                            return expression;
                        }
                    }
                    function isTemplateStartOfTaggedTemplate() {
                        return token() === 15 /* NoSubstitutionTemplateLiteral */ || token() === 16 /* TemplateHead */;
                    }
                    function parseTaggedTemplateRest(pos, tag, questionDotToken, typeArguments) {
                        const tagExpression = factory2.createTaggedTemplateExpression(tag, typeArguments, token() === 15 /* NoSubstitutionTemplateLiteral */ ? (reScanTemplateToken(
                        /*isTaggedTemplate*/
                        true), parseLiteralNode()) : parseTemplateExpression(
                        /*isTaggedTemplate*/
                        true));
                        if (questionDotToken || tag.flags & 64 /* OptionalChain */) {
                            tagExpression.flags |= 64 /* OptionalChain */;
                        }
                        tagExpression.questionDotToken = questionDotToken;
                        return finishNode(tagExpression, pos);
                    }
                    function parseCallExpressionRest(pos, expression) {
                        while (true) {
                            expression = parseMemberExpressionRest(pos, expression, 
                            /*allowOptionalChain*/
                            true);
                            let typeArguments;
                            const questionDotToken = parseOptionalToken(29 /* QuestionDotToken */);
                            if (questionDotToken) {
                                typeArguments = tryParse(parseTypeArgumentsInExpression);
                                if (isTemplateStartOfTaggedTemplate()) {
                                    expression = parseTaggedTemplateRest(pos, expression, questionDotToken, typeArguments);
                                    continue;
                                }
                            }
                            if (typeArguments || token() === 21 /* OpenParenToken */) {
                                if (!questionDotToken && expression.kind === 233 /* ExpressionWithTypeArguments */) {
                                    typeArguments = expression.typeArguments;
                                    expression = expression.expression;
                                }
                                const argumentList = parseArgumentList();
                                const callExpr = questionDotToken || tryReparseOptionalChain(expression) ? factoryCreateCallChain(expression, questionDotToken, typeArguments, argumentList) : factoryCreateCallExpression(expression, typeArguments, argumentList);
                                expression = finishNode(callExpr, pos);
                                continue;
                            }
                            if (questionDotToken) {
                                const name = createMissingNode(80 /* Identifier */, 
                                /*reportAtCurrentPosition*/
                                false, Diagnostics.Identifier_expected);
                                expression = finishNode(factoryCreatePropertyAccessChain(expression, questionDotToken, name), pos);
                            }
                            break;
                        }
                        return expression;
                    }
                    function parseArgumentList() {
                        parseExpected(21 /* OpenParenToken */);
                        const result = parseDelimitedList(11 /* ArgumentExpressions */, parseArgumentExpression);
                        parseExpected(22 /* CloseParenToken */);
                        return result;
                    }
                    function parseTypeArgumentsInExpression() {
                        if ((contextFlags & 524288 /* JavaScriptFile */) !== 0) {
                            return void 0;
                        }
                        if (reScanLessThanToken() !== 30 /* LessThanToken */) {
                            return void 0;
                        }
                        nextToken();
                        const typeArguments = parseDelimitedList(20 /* TypeArguments */, parseType);
                        if (reScanGreaterToken() !== 32 /* GreaterThanToken */) {
                            return void 0;
                        }
                        nextToken();
                        return typeArguments && canFollowTypeArgumentsInExpression() ? typeArguments : void 0;
                    }
                    function canFollowTypeArgumentsInExpression() {
                        switch (token()) {
                            case 21 /* OpenParenToken */:
                            case 15 /* NoSubstitutionTemplateLiteral */:
                            case 16 /* TemplateHead */:
                                return true;
                            case 30 /* LessThanToken */:
                            case 32 /* GreaterThanToken */:
                            case 40 /* PlusToken */:
                            case 41 /* MinusToken */:
                                return false;
                        }
                        return scanner2.hasPrecedingLineBreak() || isBinaryOperator2() || !isStartOfExpression();
                    }
                    function parsePrimaryExpression() {
                        switch (token()) {
                            case 15 /* NoSubstitutionTemplateLiteral */:
                                if (scanner2.getTokenFlags() & 26656 /* IsInvalid */) {
                                    reScanTemplateToken(
                                    /*isTaggedTemplate*/
                                    false);
                                }
                            case 9 /* NumericLiteral */:
                            case 10 /* BigIntLiteral */:
                            case 11 /* StringLiteral */:
                                return parseLiteralNode();
                            case 110 /* ThisKeyword */:
                            case 108 /* SuperKeyword */:
                            case 106 /* NullKeyword */:
                            case 112 /* TrueKeyword */:
                            case 97 /* FalseKeyword */:
                                return parseTokenNode();
                            case 21 /* OpenParenToken */:
                                return parseParenthesizedExpression();
                            case 23 /* OpenBracketToken */:
                                return parseArrayLiteralExpression();
                            case 19 /* OpenBraceToken */:
                                return parseObjectLiteralExpression();
                            case 134 /* AsyncKeyword */:
                                if (!lookAhead(nextTokenIsFunctionKeywordOnSameLine)) {
                                    break;
                                }
                                return parseFunctionExpression();
                            case 60 /* AtToken */:
                                return parseDecoratedExpression();
                            case 86 /* ClassKeyword */:
                                return parseClassExpression();
                            case 100 /* FunctionKeyword */:
                                return parseFunctionExpression();
                            case 105 /* NewKeyword */:
                                return parseNewExpressionOrNewDotTarget();
                            case 44 /* SlashToken */:
                            case 69 /* SlashEqualsToken */:
                                if (reScanSlashToken() === 14 /* RegularExpressionLiteral */) {
                                    return parseLiteralNode();
                                }
                                break;
                            case 16 /* TemplateHead */:
                                return parseTemplateExpression(
                                /*isTaggedTemplate*/
                                false);
                            case 81 /* PrivateIdentifier */:
                                return parsePrivateIdentifier();
                        }
                        return parseIdentifier(Diagnostics.Expression_expected);
                    }
                    function parseParenthesizedExpression() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        parseExpected(21 /* OpenParenToken */);
                        const expression = allowInAnd(parseExpression);
                        parseExpected(22 /* CloseParenToken */);
                        return withJSDoc(finishNode(factoryCreateParenthesizedExpression(expression), pos), hasJSDoc);
                    }
                    function parseSpreadElement() {
                        const pos = getNodePos();
                        parseExpected(26 /* DotDotDotToken */);
                        const expression = parseAssignmentExpressionOrHigher(
                        /*allowReturnTypeInArrowFunction*/
                        true);
                        return finishNode(factory2.createSpreadElement(expression), pos);
                    }
                    function parseArgumentOrArrayLiteralElement() {
                        return token() === 26 /* DotDotDotToken */ ? parseSpreadElement() : token() === 28 /* CommaToken */ ? finishNode(factory2.createOmittedExpression(), getNodePos()) : parseAssignmentExpressionOrHigher(
                        /*allowReturnTypeInArrowFunction*/
                        true);
                    }
                    function parseArgumentExpression() {
                        return doOutsideOfContext(disallowInAndDecoratorContext, parseArgumentOrArrayLiteralElement);
                    }
                    function parseArrayLiteralExpression() {
                        const pos = getNodePos();
                        const openBracketPosition = scanner2.getTokenStart();
                        const openBracketParsed = parseExpected(23 /* OpenBracketToken */);
                        const multiLine = scanner2.hasPrecedingLineBreak();
                        const elements = parseDelimitedList(15 /* ArrayLiteralMembers */, parseArgumentOrArrayLiteralElement);
                        parseExpectedMatchingBrackets(23 /* OpenBracketToken */, 24 /* CloseBracketToken */, openBracketParsed, openBracketPosition);
                        return finishNode(factoryCreateArrayLiteralExpression(elements, multiLine), pos);
                    }
                    function parseObjectLiteralElement() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        if (parseOptionalToken(26 /* DotDotDotToken */)) {
                            const expression = parseAssignmentExpressionOrHigher(
                            /*allowReturnTypeInArrowFunction*/
                            true);
                            return withJSDoc(finishNode(factory2.createSpreadAssignment(expression), pos), hasJSDoc);
                        }
                        const modifiers = parseModifiers(
                        /*allowDecorators*/
                        true);
                        if (parseContextualModifier(139 /* GetKeyword */)) {
                            return parseAccessorDeclaration(pos, hasJSDoc, modifiers, 177 /* GetAccessor */, 0 /* None */);
                        }
                        if (parseContextualModifier(153 /* SetKeyword */)) {
                            return parseAccessorDeclaration(pos, hasJSDoc, modifiers, 178 /* SetAccessor */, 0 /* None */);
                        }
                        const asteriskToken = parseOptionalToken(42 /* AsteriskToken */);
                        const tokenIsIdentifier = isIdentifier2();
                        const name = parsePropertyName();
                        const questionToken = parseOptionalToken(58 /* QuestionToken */);
                        const exclamationToken = parseOptionalToken(54 /* ExclamationToken */);
                        if (asteriskToken || token() === 21 /* OpenParenToken */ || token() === 30 /* LessThanToken */) {
                            return parseMethodDeclaration(pos, hasJSDoc, modifiers, asteriskToken, name, questionToken, exclamationToken);
                        }
                        let node;
                        const isShorthandPropertyAssignment2 = tokenIsIdentifier && token() !== 59 /* ColonToken */;
                        if (isShorthandPropertyAssignment2) {
                            const equalsToken = parseOptionalToken(64 /* EqualsToken */);
                            const objectAssignmentInitializer = equalsToken ? allowInAnd(() => parseAssignmentExpressionOrHigher(
                            /*allowReturnTypeInArrowFunction*/
                            true)) : void 0;
                            node = factory2.createShorthandPropertyAssignment(name, objectAssignmentInitializer);
                            node.equalsToken = equalsToken;
                        }
                        else {
                            parseExpected(59 /* ColonToken */);
                            const initializer = allowInAnd(() => parseAssignmentExpressionOrHigher(
                            /*allowReturnTypeInArrowFunction*/
                            true));
                            node = factory2.createPropertyAssignment(name, initializer);
                        }
                        node.modifiers = modifiers;
                        node.questionToken = questionToken;
                        node.exclamationToken = exclamationToken;
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseObjectLiteralExpression() {
                        const pos = getNodePos();
                        const openBracePosition = scanner2.getTokenStart();
                        const openBraceParsed = parseExpected(19 /* OpenBraceToken */);
                        const multiLine = scanner2.hasPrecedingLineBreak();
                        const properties = parseDelimitedList(12 /* ObjectLiteralMembers */, parseObjectLiteralElement, 
                        /*considerSemicolonAsDelimiter*/
                        true);
                        parseExpectedMatchingBrackets(19 /* OpenBraceToken */, 20 /* CloseBraceToken */, openBraceParsed, openBracePosition);
                        return finishNode(factoryCreateObjectLiteralExpression(properties, multiLine), pos);
                    }
                    function parseFunctionExpression() {
                        const savedDecoratorContext = inDecoratorContext();
                        setDecoratorContext(
                        /*val*/
                        false);
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        const modifiers = parseModifiers(
                        /*allowDecorators*/
                        false);
                        parseExpected(100 /* FunctionKeyword */);
                        const asteriskToken = parseOptionalToken(42 /* AsteriskToken */);
                        const isGenerator = asteriskToken ? 1 /* Yield */ : 0 /* None */;
                        const isAsync = some(modifiers, isAsyncModifier) ? 2 /* Await */ : 0 /* None */;
                        const name = isGenerator && isAsync ? doInYieldAndAwaitContext(parseOptionalBindingIdentifier) : isGenerator ? doInYieldContext(parseOptionalBindingIdentifier) : isAsync ? doInAwaitContext(parseOptionalBindingIdentifier) : parseOptionalBindingIdentifier();
                        const typeParameters = parseTypeParameters();
                        const parameters = parseParameters(isGenerator | isAsync);
                        const type = parseReturnType(59 /* ColonToken */, 
                        /*isType*/
                        false);
                        const body = parseFunctionBlock(isGenerator | isAsync);
                        setDecoratorContext(savedDecoratorContext);
                        const node = factory2.createFunctionExpression(modifiers, asteriskToken, name, typeParameters, parameters, type, body);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseOptionalBindingIdentifier() {
                        return isBindingIdentifier() ? parseBindingIdentifier() : void 0;
                    }
                    function parseNewExpressionOrNewDotTarget() {
                        const pos = getNodePos();
                        parseExpected(105 /* NewKeyword */);
                        if (parseOptional(25 /* DotToken */)) {
                            const name = parseIdentifierName();
                            return finishNode(factory2.createMetaProperty(105 /* NewKeyword */, name), pos);
                        }
                        const expressionPos = getNodePos();
                        let expression = parseMemberExpressionRest(expressionPos, parsePrimaryExpression(), 
                        /*allowOptionalChain*/
                        false);
                        let typeArguments;
                        if (expression.kind === 233 /* ExpressionWithTypeArguments */) {
                            typeArguments = expression.typeArguments;
                            expression = expression.expression;
                        }
                        if (token() === 29 /* QuestionDotToken */) {
                            parseErrorAtCurrentToken(Diagnostics.Invalid_optional_chain_from_new_expression_Did_you_mean_to_call_0, getTextOfNodeFromSourceText(sourceText, expression));
                        }
                        const argumentList = token() === 21 /* OpenParenToken */ ? parseArgumentList() : void 0;
                        return finishNode(factoryCreateNewExpression(expression, typeArguments, argumentList), pos);
                    }
                    function parseBlock(ignoreMissingOpenBrace, diagnosticMessage) {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        const openBracePosition = scanner2.getTokenStart();
                        const openBraceParsed = parseExpected(19 /* OpenBraceToken */, diagnosticMessage);
                        if (openBraceParsed || ignoreMissingOpenBrace) {
                            const multiLine = scanner2.hasPrecedingLineBreak();
                            const statements = parseList(1 /* BlockStatements */, parseStatement);
                            parseExpectedMatchingBrackets(19 /* OpenBraceToken */, 20 /* CloseBraceToken */, openBraceParsed, openBracePosition);
                            const result = withJSDoc(finishNode(factoryCreateBlock(statements, multiLine), pos), hasJSDoc);
                            if (token() === 64 /* EqualsToken */) {
                                parseErrorAtCurrentToken(Diagnostics.Declaration_or_statement_expected_This_follows_a_block_of_statements_so_if_you_intended_to_write_a_destructuring_assignment_you_might_need_to_wrap_the_whole_assignment_in_parentheses);
                                nextToken();
                            }
                            return result;
                        }
                        else {
                            const statements = createMissingList();
                            return withJSDoc(finishNode(factoryCreateBlock(statements, 
                            /*multiLine*/
                            void 0), pos), hasJSDoc);
                        }
                    }
                    function parseFunctionBlock(flags, diagnosticMessage) {
                        const savedYieldContext = inYieldContext();
                        setYieldContext(!!(flags & 1 /* Yield */));
                        const savedAwaitContext = inAwaitContext();
                        setAwaitContext(!!(flags & 2 /* Await */));
                        const savedTopLevel = topLevel;
                        topLevel = false;
                        const saveDecoratorContext = inDecoratorContext();
                        if (saveDecoratorContext) {
                            setDecoratorContext(
                            /*val*/
                            false);
                        }
                        const block = parseBlock(!!(flags & 16 /* IgnoreMissingOpenBrace */), diagnosticMessage);
                        if (saveDecoratorContext) {
                            setDecoratorContext(
                            /*val*/
                            true);
                        }
                        topLevel = savedTopLevel;
                        setYieldContext(savedYieldContext);
                        setAwaitContext(savedAwaitContext);
                        return block;
                    }
                    function parseEmptyStatement() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        parseExpected(27 /* SemicolonToken */);
                        return withJSDoc(finishNode(factory2.createEmptyStatement(), pos), hasJSDoc);
                    }
                    function parseIfStatement() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        parseExpected(101 /* IfKeyword */);
                        const openParenPosition = scanner2.getTokenStart();
                        const openParenParsed = parseExpected(21 /* OpenParenToken */);
                        const expression = allowInAnd(parseExpression);
                        parseExpectedMatchingBrackets(21 /* OpenParenToken */, 22 /* CloseParenToken */, openParenParsed, openParenPosition);
                        const thenStatement = parseStatement();
                        const elseStatement = parseOptional(93 /* ElseKeyword */) ? parseStatement() : void 0;
                        return withJSDoc(finishNode(factoryCreateIfStatement(expression, thenStatement, elseStatement), pos), hasJSDoc);
                    }
                    function parseDoStatement() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        parseExpected(92 /* DoKeyword */);
                        const statement = parseStatement();
                        parseExpected(117 /* WhileKeyword */);
                        const openParenPosition = scanner2.getTokenStart();
                        const openParenParsed = parseExpected(21 /* OpenParenToken */);
                        const expression = allowInAnd(parseExpression);
                        parseExpectedMatchingBrackets(21 /* OpenParenToken */, 22 /* CloseParenToken */, openParenParsed, openParenPosition);
                        parseOptional(27 /* SemicolonToken */);
                        return withJSDoc(finishNode(factory2.createDoStatement(statement, expression), pos), hasJSDoc);
                    }
                    function parseWhileStatement() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        parseExpected(117 /* WhileKeyword */);
                        const openParenPosition = scanner2.getTokenStart();
                        const openParenParsed = parseExpected(21 /* OpenParenToken */);
                        const expression = allowInAnd(parseExpression);
                        parseExpectedMatchingBrackets(21 /* OpenParenToken */, 22 /* CloseParenToken */, openParenParsed, openParenPosition);
                        const statement = parseStatement();
                        return withJSDoc(finishNode(factoryCreateWhileStatement(expression, statement), pos), hasJSDoc);
                    }
                    function parseForOrForInOrForOfStatement() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        parseExpected(99 /* ForKeyword */);
                        const awaitToken = parseOptionalToken(135 /* AwaitKeyword */);
                        parseExpected(21 /* OpenParenToken */);
                        let initializer;
                        if (token() !== 27 /* SemicolonToken */) {
                            if (token() === 115 /* VarKeyword */ || token() === 121 /* LetKeyword */ || token() === 87 /* ConstKeyword */ || token() === 160 /* UsingKeyword */ && lookAhead(nextTokenIsBindingIdentifierOrStartOfDestructuringOnSameLineDisallowOf) || // this one is meant to allow of
                                token() === 135 /* AwaitKeyword */ && lookAhead(nextTokenIsUsingKeywordThenBindingIdentifierOrStartOfObjectDestructuringOnSameLine)) {
                                initializer = parseVariableDeclarationList(
                                /*inForStatementInitializer*/
                                true);
                            }
                            else {
                                initializer = disallowInAnd(parseExpression);
                            }
                        }
                        let node;
                        if (awaitToken ? parseExpected(165 /* OfKeyword */) : parseOptional(165 /* OfKeyword */)) {
                            const expression = allowInAnd(() => parseAssignmentExpressionOrHigher(
                            /*allowReturnTypeInArrowFunction*/
                            true));
                            parseExpected(22 /* CloseParenToken */);
                            node = factoryCreateForOfStatement(awaitToken, initializer, expression, parseStatement());
                        }
                        else if (parseOptional(103 /* InKeyword */)) {
                            const expression = allowInAnd(parseExpression);
                            parseExpected(22 /* CloseParenToken */);
                            node = factory2.createForInStatement(initializer, expression, parseStatement());
                        }
                        else {
                            parseExpected(27 /* SemicolonToken */);
                            const condition = token() !== 27 /* SemicolonToken */ && token() !== 22 /* CloseParenToken */ ? allowInAnd(parseExpression) : void 0;
                            parseExpected(27 /* SemicolonToken */);
                            const incrementor = token() !== 22 /* CloseParenToken */ ? allowInAnd(parseExpression) : void 0;
                            parseExpected(22 /* CloseParenToken */);
                            node = factoryCreateForStatement(initializer, condition, incrementor, parseStatement());
                        }
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseBreakOrContinueStatement(kind) {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        parseExpected(kind === 252 /* BreakStatement */ ? 83 /* BreakKeyword */ : 88 /* ContinueKeyword */);
                        const label = canParseSemicolon() ? void 0 : parseIdentifier();
                        parseSemicolon();
                        const node = kind === 252 /* BreakStatement */ ? factory2.createBreakStatement(label) : factory2.createContinueStatement(label);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseReturnStatement() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        parseExpected(107 /* ReturnKeyword */);
                        const expression = canParseSemicolon() ? void 0 : allowInAnd(parseExpression);
                        parseSemicolon();
                        return withJSDoc(finishNode(factory2.createReturnStatement(expression), pos), hasJSDoc);
                    }
                    function parseWithStatement() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        parseExpected(118 /* WithKeyword */);
                        const openParenPosition = scanner2.getTokenStart();
                        const openParenParsed = parseExpected(21 /* OpenParenToken */);
                        const expression = allowInAnd(parseExpression);
                        parseExpectedMatchingBrackets(21 /* OpenParenToken */, 22 /* CloseParenToken */, openParenParsed, openParenPosition);
                        const statement = doInsideOfContext(67108864 /* InWithStatement */, parseStatement);
                        return withJSDoc(finishNode(factory2.createWithStatement(expression, statement), pos), hasJSDoc);
                    }
                    function parseCaseClause() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        parseExpected(84 /* CaseKeyword */);
                        const expression = allowInAnd(parseExpression);
                        parseExpected(59 /* ColonToken */);
                        const statements = parseList(3 /* SwitchClauseStatements */, parseStatement);
                        return withJSDoc(finishNode(factory2.createCaseClause(expression, statements), pos), hasJSDoc);
                    }
                    function parseDefaultClause() {
                        const pos = getNodePos();
                        parseExpected(90 /* DefaultKeyword */);
                        parseExpected(59 /* ColonToken */);
                        const statements = parseList(3 /* SwitchClauseStatements */, parseStatement);
                        return finishNode(factory2.createDefaultClause(statements), pos);
                    }
                    function parseCaseOrDefaultClause() {
                        return token() === 84 /* CaseKeyword */ ? parseCaseClause() : parseDefaultClause();
                    }
                    function parseCaseBlock() {
                        const pos = getNodePos();
                        parseExpected(19 /* OpenBraceToken */);
                        const clauses = parseList(2 /* SwitchClauses */, parseCaseOrDefaultClause);
                        parseExpected(20 /* CloseBraceToken */);
                        return finishNode(factory2.createCaseBlock(clauses), pos);
                    }
                    function parseSwitchStatement() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        parseExpected(109 /* SwitchKeyword */);
                        parseExpected(21 /* OpenParenToken */);
                        const expression = allowInAnd(parseExpression);
                        parseExpected(22 /* CloseParenToken */);
                        const caseBlock = parseCaseBlock();
                        return withJSDoc(finishNode(factory2.createSwitchStatement(expression, caseBlock), pos), hasJSDoc);
                    }
                    function parseThrowStatement() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        parseExpected(111 /* ThrowKeyword */);
                        let expression = scanner2.hasPrecedingLineBreak() ? void 0 : allowInAnd(parseExpression);
                        if (expression === void 0) {
                            identifierCount++;
                            expression = finishNode(factoryCreateIdentifier(""), getNodePos());
                        }
                        if (!tryParseSemicolon()) {
                            parseErrorForMissingSemicolonAfter(expression);
                        }
                        return withJSDoc(finishNode(factory2.createThrowStatement(expression), pos), hasJSDoc);
                    }
                    function parseTryStatement() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        parseExpected(113 /* TryKeyword */);
                        const tryBlock = parseBlock(
                        /*ignoreMissingOpenBrace*/
                        false);
                        const catchClause = token() === 85 /* CatchKeyword */ ? parseCatchClause() : void 0;
                        let finallyBlock;
                        if (!catchClause || token() === 98 /* FinallyKeyword */) {
                            parseExpected(98 /* FinallyKeyword */, Diagnostics.catch_or_finally_expected);
                            finallyBlock = parseBlock(
                            /*ignoreMissingOpenBrace*/
                            false);
                        }
                        return withJSDoc(finishNode(factory2.createTryStatement(tryBlock, catchClause, finallyBlock), pos), hasJSDoc);
                    }
                    function parseCatchClause() {
                        const pos = getNodePos();
                        parseExpected(85 /* CatchKeyword */);
                        let variableDeclaration;
                        if (parseOptional(21 /* OpenParenToken */)) {
                            variableDeclaration = parseVariableDeclaration();
                            parseExpected(22 /* CloseParenToken */);
                        }
                        else {
                            variableDeclaration = void 0;
                        }
                        const block = parseBlock(
                        /*ignoreMissingOpenBrace*/
                        false);
                        return finishNode(factory2.createCatchClause(variableDeclaration, block), pos);
                    }
                    function parseDebuggerStatement() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        parseExpected(89 /* DebuggerKeyword */);
                        parseSemicolon();
                        return withJSDoc(finishNode(factory2.createDebuggerStatement(), pos), hasJSDoc);
                    }
                    function parseExpressionOrLabeledStatement() {
                        const pos = getNodePos();
                        let hasJSDoc = hasPrecedingJSDocComment();
                        let node;
                        const hasParen = token() === 21 /* OpenParenToken */;
                        const expression = allowInAnd(parseExpression);
                        if (isIdentifier(expression) && parseOptional(59 /* ColonToken */)) {
                            node = factory2.createLabeledStatement(expression, parseStatement());
                        }
                        else {
                            if (!tryParseSemicolon()) {
                                parseErrorForMissingSemicolonAfter(expression);
                            }
                            node = factoryCreateExpressionStatement(expression);
                            if (hasParen) {
                                hasJSDoc = false;
                            }
                        }
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function nextTokenIsIdentifierOrKeywordOnSameLine() {
                        nextToken();
                        return tokenIsIdentifierOrKeyword(token()) && !scanner2.hasPrecedingLineBreak();
                    }
                    function nextTokenIsClassKeywordOnSameLine() {
                        nextToken();
                        return token() === 86 /* ClassKeyword */ && !scanner2.hasPrecedingLineBreak();
                    }
                    function nextTokenIsFunctionKeywordOnSameLine() {
                        nextToken();
                        return token() === 100 /* FunctionKeyword */ && !scanner2.hasPrecedingLineBreak();
                    }
                    function nextTokenIsIdentifierOrKeywordOrLiteralOnSameLine() {
                        nextToken();
                        return (tokenIsIdentifierOrKeyword(token()) || token() === 9 /* NumericLiteral */ || token() === 10 /* BigIntLiteral */ || token() === 11 /* StringLiteral */) && !scanner2.hasPrecedingLineBreak();
                    }
                    function isDeclaration2() {
                        while (true) {
                            switch (token()) {
                                case 115 /* VarKeyword */:
                                case 121 /* LetKeyword */:
                                case 87 /* ConstKeyword */:
                                case 100 /* FunctionKeyword */:
                                case 86 /* ClassKeyword */:
                                case 94 /* EnumKeyword */:
                                    return true;
                                case 160 /* UsingKeyword */:
                                    return isUsingDeclaration();
                                case 135 /* AwaitKeyword */:
                                    return isAwaitUsingDeclaration();
                                case 120 /* InterfaceKeyword */:
                                case 156 /* TypeKeyword */:
                                    return nextTokenIsIdentifierOnSameLine();
                                case 144 /* ModuleKeyword */:
                                case 145 /* NamespaceKeyword */:
                                    return nextTokenIsIdentifierOrStringLiteralOnSameLine();
                                case 128 /* AbstractKeyword */:
                                case 129 /* AccessorKeyword */:
                                case 134 /* AsyncKeyword */:
                                case 138 /* DeclareKeyword */:
                                case 123 /* PrivateKeyword */:
                                case 124 /* ProtectedKeyword */:
                                case 125 /* PublicKeyword */:
                                case 148 /* ReadonlyKeyword */:
                                    const previousToken = token();
                                    nextToken();
                                    if (scanner2.hasPrecedingLineBreak()) {
                                        return false;
                                    }
                                    if (previousToken === 138 /* DeclareKeyword */ && token() === 156 /* TypeKeyword */) {
                                        return true;
                                    }
                                    continue;
                                case 162 /* GlobalKeyword */:
                                    nextToken();
                                    return token() === 19 /* OpenBraceToken */ || token() === 80 /* Identifier */ || token() === 95 /* ExportKeyword */;
                                case 102 /* ImportKeyword */:
                                    nextToken();
                                    return token() === 11 /* StringLiteral */ || token() === 42 /* AsteriskToken */ || token() === 19 /* OpenBraceToken */ || tokenIsIdentifierOrKeyword(token());
                                case 95 /* ExportKeyword */:
                                    let currentToken2 = nextToken();
                                    if (currentToken2 === 156 /* TypeKeyword */) {
                                        currentToken2 = lookAhead(nextToken);
                                    }
                                    if (currentToken2 === 64 /* EqualsToken */ || currentToken2 === 42 /* AsteriskToken */ || currentToken2 === 19 /* OpenBraceToken */ || currentToken2 === 90 /* DefaultKeyword */ || currentToken2 === 130 /* AsKeyword */ || currentToken2 === 60 /* AtToken */) {
                                        return true;
                                    }
                                    continue;
                                case 126 /* StaticKeyword */:
                                    nextToken();
                                    continue;
                                default:
                                    return false;
                            }
                        }
                    }
                    function isStartOfDeclaration() {
                        return lookAhead(isDeclaration2);
                    }
                    function isStartOfStatement() {
                        switch (token()) {
                            case 60 /* AtToken */:
                            case 27 /* SemicolonToken */:
                            case 19 /* OpenBraceToken */:
                            case 115 /* VarKeyword */:
                            case 121 /* LetKeyword */:
                            case 160 /* UsingKeyword */:
                            case 100 /* FunctionKeyword */:
                            case 86 /* ClassKeyword */:
                            case 94 /* EnumKeyword */:
                            case 101 /* IfKeyword */:
                            case 92 /* DoKeyword */:
                            case 117 /* WhileKeyword */:
                            case 99 /* ForKeyword */:
                            case 88 /* ContinueKeyword */:
                            case 83 /* BreakKeyword */:
                            case 107 /* ReturnKeyword */:
                            case 118 /* WithKeyword */:
                            case 109 /* SwitchKeyword */:
                            case 111 /* ThrowKeyword */:
                            case 113 /* TryKeyword */:
                            case 89 /* DebuggerKeyword */:
                            case 85 /* CatchKeyword */:
                            case 98 /* FinallyKeyword */:
                                return true;
                            case 102 /* ImportKeyword */:
                                return isStartOfDeclaration() || lookAhead(nextTokenIsOpenParenOrLessThanOrDot);
                            case 87 /* ConstKeyword */:
                            case 95 /* ExportKeyword */:
                                return isStartOfDeclaration();
                            case 134 /* AsyncKeyword */:
                            case 138 /* DeclareKeyword */:
                            case 120 /* InterfaceKeyword */:
                            case 144 /* ModuleKeyword */:
                            case 145 /* NamespaceKeyword */:
                            case 156 /* TypeKeyword */:
                            case 162 /* GlobalKeyword */:
                                return true;
                            case 129 /* AccessorKeyword */:
                            case 125 /* PublicKeyword */:
                            case 123 /* PrivateKeyword */:
                            case 124 /* ProtectedKeyword */:
                            case 126 /* StaticKeyword */:
                            case 148 /* ReadonlyKeyword */:
                                return isStartOfDeclaration() || !lookAhead(nextTokenIsIdentifierOrKeywordOnSameLine);
                            default:
                                return isStartOfExpression();
                        }
                    }
                    function nextTokenIsBindingIdentifierOrStartOfDestructuring() {
                        nextToken();
                        return isBindingIdentifier() || token() === 19 /* OpenBraceToken */ || token() === 23 /* OpenBracketToken */;
                    }
                    function isLetDeclaration() {
                        return lookAhead(nextTokenIsBindingIdentifierOrStartOfDestructuring);
                    }
                    function nextTokenIsBindingIdentifierOrStartOfDestructuringOnSameLineDisallowOf() {
                        return nextTokenIsBindingIdentifierOrStartOfDestructuringOnSameLine(
                        /*disallowOf*/
                        true);
                    }
                    function nextTokenIsBindingIdentifierOrStartOfDestructuringOnSameLine(disallowOf) {
                        nextToken();
                        if (disallowOf && token() === 165 /* OfKeyword */)
                            return false;
                        return (isBindingIdentifier() || token() === 19 /* OpenBraceToken */) && !scanner2.hasPrecedingLineBreak();
                    }
                    function isUsingDeclaration() {
                        return lookAhead(nextTokenIsBindingIdentifierOrStartOfDestructuringOnSameLine);
                    }
                    function nextTokenIsUsingKeywordThenBindingIdentifierOrStartOfObjectDestructuringOnSameLine(disallowOf) {
                        if (nextToken() === 160 /* UsingKeyword */) {
                            return nextTokenIsBindingIdentifierOrStartOfDestructuringOnSameLine(disallowOf);
                        }
                        return false;
                    }
                    function isAwaitUsingDeclaration() {
                        return lookAhead(nextTokenIsUsingKeywordThenBindingIdentifierOrStartOfObjectDestructuringOnSameLine);
                    }
                    function parseStatement() {
                        switch (token()) {
                            case 27 /* SemicolonToken */:
                                return parseEmptyStatement();
                            case 19 /* OpenBraceToken */:
                                return parseBlock(
                                /*ignoreMissingOpenBrace*/
                                false);
                            case 115 /* VarKeyword */:
                                return parseVariableStatement(getNodePos(), hasPrecedingJSDocComment(), 
                                /*modifiers*/
                                void 0);
                            case 121 /* LetKeyword */:
                                if (isLetDeclaration()) {
                                    return parseVariableStatement(getNodePos(), hasPrecedingJSDocComment(), 
                                    /*modifiers*/
                                    void 0);
                                }
                                break;
                            case 135 /* AwaitKeyword */:
                                if (isAwaitUsingDeclaration()) {
                                    return parseVariableStatement(getNodePos(), hasPrecedingJSDocComment(), 
                                    /*modifiers*/
                                    void 0);
                                }
                                break;
                            case 160 /* UsingKeyword */:
                                if (isUsingDeclaration()) {
                                    return parseVariableStatement(getNodePos(), hasPrecedingJSDocComment(), 
                                    /*modifiers*/
                                    void 0);
                                }
                                break;
                            case 100 /* FunctionKeyword */:
                                return parseFunctionDeclaration(getNodePos(), hasPrecedingJSDocComment(), 
                                /*modifiers*/
                                void 0);
                            case 86 /* ClassKeyword */:
                                return parseClassDeclaration(getNodePos(), hasPrecedingJSDocComment(), 
                                /*modifiers*/
                                void 0);
                            case 101 /* IfKeyword */:
                                return parseIfStatement();
                            case 92 /* DoKeyword */:
                                return parseDoStatement();
                            case 117 /* WhileKeyword */:
                                return parseWhileStatement();
                            case 99 /* ForKeyword */:
                                return parseForOrForInOrForOfStatement();
                            case 88 /* ContinueKeyword */:
                                return parseBreakOrContinueStatement(251 /* ContinueStatement */);
                            case 83 /* BreakKeyword */:
                                return parseBreakOrContinueStatement(252 /* BreakStatement */);
                            case 107 /* ReturnKeyword */:
                                return parseReturnStatement();
                            case 118 /* WithKeyword */:
                                return parseWithStatement();
                            case 109 /* SwitchKeyword */:
                                return parseSwitchStatement();
                            case 111 /* ThrowKeyword */:
                                return parseThrowStatement();
                            case 113 /* TryKeyword */:
                            case 85 /* CatchKeyword */:
                            case 98 /* FinallyKeyword */:
                                return parseTryStatement();
                            case 89 /* DebuggerKeyword */:
                                return parseDebuggerStatement();
                            case 60 /* AtToken */:
                                return parseDeclaration();
                            case 134 /* AsyncKeyword */:
                            case 120 /* InterfaceKeyword */:
                            case 156 /* TypeKeyword */:
                            case 144 /* ModuleKeyword */:
                            case 145 /* NamespaceKeyword */:
                            case 138 /* DeclareKeyword */:
                            case 87 /* ConstKeyword */:
                            case 94 /* EnumKeyword */:
                            case 95 /* ExportKeyword */:
                            case 102 /* ImportKeyword */:
                            case 123 /* PrivateKeyword */:
                            case 124 /* ProtectedKeyword */:
                            case 125 /* PublicKeyword */:
                            case 128 /* AbstractKeyword */:
                            case 129 /* AccessorKeyword */:
                            case 126 /* StaticKeyword */:
                            case 148 /* ReadonlyKeyword */:
                            case 162 /* GlobalKeyword */:
                                if (isStartOfDeclaration()) {
                                    return parseDeclaration();
                                }
                                break;
                        }
                        return parseExpressionOrLabeledStatement();
                    }
                    function isDeclareModifier(modifier) {
                        return modifier.kind === 138 /* DeclareKeyword */;
                    }
                    function parseDeclaration() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        const modifiers = parseModifiers(
                        /*allowDecorators*/
                        true);
                        const isAmbient = some(modifiers, isDeclareModifier);
                        if (isAmbient) {
                            const node = tryReuseAmbientDeclaration(pos);
                            if (node) {
                                return node;
                            }
                            for (const m of modifiers) {
                                m.flags |= 33554432 /* Ambient */;
                            }
                            return doInsideOfContext(33554432 /* Ambient */, () => parseDeclarationWorker(pos, hasJSDoc, modifiers));
                        }
                        else {
                            return parseDeclarationWorker(pos, hasJSDoc, modifiers);
                        }
                    }
                    function tryReuseAmbientDeclaration(pos) {
                        return doInsideOfContext(33554432 /* Ambient */, () => {
                            const node = currentNode(parsingContext, pos);
                            if (node) {
                                return consumeNode(node);
                            }
                        });
                    }
                    function parseDeclarationWorker(pos, hasJSDoc, modifiersIn) {
                        switch (token()) {
                            case 115 /* VarKeyword */:
                            case 121 /* LetKeyword */:
                            case 87 /* ConstKeyword */:
                            case 160 /* UsingKeyword */:
                            case 135 /* AwaitKeyword */:
                                return parseVariableStatement(pos, hasJSDoc, modifiersIn);
                            case 100 /* FunctionKeyword */:
                                return parseFunctionDeclaration(pos, hasJSDoc, modifiersIn);
                            case 86 /* ClassKeyword */:
                                return parseClassDeclaration(pos, hasJSDoc, modifiersIn);
                            case 120 /* InterfaceKeyword */:
                                return parseInterfaceDeclaration(pos, hasJSDoc, modifiersIn);
                            case 156 /* TypeKeyword */:
                                return parseTypeAliasDeclaration(pos, hasJSDoc, modifiersIn);
                            case 94 /* EnumKeyword */:
                                return parseEnumDeclaration(pos, hasJSDoc, modifiersIn);
                            case 162 /* GlobalKeyword */:
                            case 144 /* ModuleKeyword */:
                            case 145 /* NamespaceKeyword */:
                                return parseModuleDeclaration(pos, hasJSDoc, modifiersIn);
                            case 102 /* ImportKeyword */:
                                return parseImportDeclarationOrImportEqualsDeclaration(pos, hasJSDoc, modifiersIn);
                            case 95 /* ExportKeyword */:
                                nextToken();
                                switch (token()) {
                                    case 90 /* DefaultKeyword */:
                                    case 64 /* EqualsToken */:
                                        return parseExportAssignment(pos, hasJSDoc, modifiersIn);
                                    case 130 /* AsKeyword */:
                                        return parseNamespaceExportDeclaration(pos, hasJSDoc, modifiersIn);
                                    default:
                                        return parseExportDeclaration(pos, hasJSDoc, modifiersIn);
                                }
                            default:
                                if (modifiersIn) {
                                    const missing = createMissingNode(282 /* MissingDeclaration */, 
                                    /*reportAtCurrentPosition*/
                                    true, Diagnostics.Declaration_expected);
                                    setTextRangePos(missing, pos);
                                    missing.modifiers = modifiersIn;
                                    return missing;
                                }
                                return void 0;
                        }
                    }
                    function nextTokenIsStringLiteral() {
                        return nextToken() === 11 /* StringLiteral */;
                    }
                    function nextTokenIsFromKeywordOrEqualsToken() {
                        nextToken();
                        return token() === 161 /* FromKeyword */ || token() === 64 /* EqualsToken */;
                    }
                    function nextTokenIsIdentifierOrStringLiteralOnSameLine() {
                        nextToken();
                        return !scanner2.hasPrecedingLineBreak() && (isIdentifier2() || token() === 11 /* StringLiteral */);
                    }
                    function parseFunctionBlockOrSemicolon(flags, diagnosticMessage) {
                        if (token() !== 19 /* OpenBraceToken */) {
                            if (flags & 4 /* Type */) {
                                parseTypeMemberSemicolon();
                                return;
                            }
                            if (canParseSemicolon()) {
                                parseSemicolon();
                                return;
                            }
                        }
                        return parseFunctionBlock(flags, diagnosticMessage);
                    }
                    function parseArrayBindingElement() {
                        const pos = getNodePos();
                        if (token() === 28 /* CommaToken */) {
                            return finishNode(factory2.createOmittedExpression(), pos);
                        }
                        const dotDotDotToken = parseOptionalToken(26 /* DotDotDotToken */);
                        const name = parseIdentifierOrPattern();
                        const initializer = parseInitializer();
                        return finishNode(factory2.createBindingElement(dotDotDotToken, 
                        /*propertyName*/
                        void 0, name, initializer), pos);
                    }
                    function parseObjectBindingElement() {
                        const pos = getNodePos();
                        const dotDotDotToken = parseOptionalToken(26 /* DotDotDotToken */);
                        const tokenIsIdentifier = isBindingIdentifier();
                        let propertyName = parsePropertyName();
                        let name;
                        if (tokenIsIdentifier && token() !== 59 /* ColonToken */) {
                            name = propertyName;
                            propertyName = void 0;
                        }
                        else {
                            parseExpected(59 /* ColonToken */);
                            name = parseIdentifierOrPattern();
                        }
                        const initializer = parseInitializer();
                        return finishNode(factory2.createBindingElement(dotDotDotToken, propertyName, name, initializer), pos);
                    }
                    function parseObjectBindingPattern() {
                        const pos = getNodePos();
                        parseExpected(19 /* OpenBraceToken */);
                        const elements = allowInAnd(() => parseDelimitedList(9 /* ObjectBindingElements */, parseObjectBindingElement));
                        parseExpected(20 /* CloseBraceToken */);
                        return finishNode(factory2.createObjectBindingPattern(elements), pos);
                    }
                    function parseArrayBindingPattern() {
                        const pos = getNodePos();
                        parseExpected(23 /* OpenBracketToken */);
                        const elements = allowInAnd(() => parseDelimitedList(10 /* ArrayBindingElements */, parseArrayBindingElement));
                        parseExpected(24 /* CloseBracketToken */);
                        return finishNode(factory2.createArrayBindingPattern(elements), pos);
                    }
                    function isBindingIdentifierOrPrivateIdentifierOrPattern() {
                        return token() === 19 /* OpenBraceToken */ || token() === 23 /* OpenBracketToken */ || token() === 81 /* PrivateIdentifier */ || isBindingIdentifier();
                    }
                    function parseIdentifierOrPattern(privateIdentifierDiagnosticMessage) {
                        if (token() === 23 /* OpenBracketToken */) {
                            return parseArrayBindingPattern();
                        }
                        if (token() === 19 /* OpenBraceToken */) {
                            return parseObjectBindingPattern();
                        }
                        return parseBindingIdentifier(privateIdentifierDiagnosticMessage);
                    }
                    function parseVariableDeclarationAllowExclamation() {
                        return parseVariableDeclaration(
                        /*allowExclamation*/
                        true);
                    }
                    function parseVariableDeclaration(allowExclamation) {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        const name = parseIdentifierOrPattern(Diagnostics.Private_identifiers_are_not_allowed_in_variable_declarations);
                        let exclamationToken;
                        if (allowExclamation && name.kind === 80 /* Identifier */ && token() === 54 /* ExclamationToken */ && !scanner2.hasPrecedingLineBreak()) {
                            exclamationToken = parseTokenNode();
                        }
                        const type = parseTypeAnnotation();
                        const initializer = isInOrOfKeyword(token()) ? void 0 : parseInitializer();
                        const node = factoryCreateVariableDeclaration(name, exclamationToken, type, initializer);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseVariableDeclarationList(inForStatementInitializer) {
                        const pos = getNodePos();
                        let flags = 0;
                        switch (token()) {
                            case 115 /* VarKeyword */:
                                break;
                            case 121 /* LetKeyword */:
                                flags |= 1 /* Let */;
                                break;
                            case 87 /* ConstKeyword */:
                                flags |= 2 /* Const */;
                                break;
                            case 160 /* UsingKeyword */:
                                flags |= 4 /* Using */;
                                break;
                            case 135 /* AwaitKeyword */:
                                Debug.assert(isAwaitUsingDeclaration());
                                flags |= 6 /* AwaitUsing */;
                                nextToken();
                                break;
                            default:
                                Debug.fail();
                        }
                        nextToken();
                        let declarations;
                        if (token() === 165 /* OfKeyword */ && lookAhead(canFollowContextualOfKeyword)) {
                            declarations = createMissingList();
                        }
                        else {
                            const savedDisallowIn = inDisallowInContext();
                            setDisallowInContext(inForStatementInitializer);
                            declarations = parseDelimitedList(8 /* VariableDeclarations */, inForStatementInitializer ? parseVariableDeclaration : parseVariableDeclarationAllowExclamation);
                            setDisallowInContext(savedDisallowIn);
                        }
                        return finishNode(factoryCreateVariableDeclarationList(declarations, flags), pos);
                    }
                    function canFollowContextualOfKeyword() {
                        return nextTokenIsIdentifier() && nextToken() === 22 /* CloseParenToken */;
                    }
                    function parseVariableStatement(pos, hasJSDoc, modifiers) {
                        const declarationList = parseVariableDeclarationList(
                        /*inForStatementInitializer*/
                        false);
                        parseSemicolon();
                        const node = factoryCreateVariableStatement(modifiers, declarationList);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseFunctionDeclaration(pos, hasJSDoc, modifiers) {
                        const savedAwaitContext = inAwaitContext();
                        const modifierFlags = modifiersToFlags(modifiers);
                        parseExpected(100 /* FunctionKeyword */);
                        const asteriskToken = parseOptionalToken(42 /* AsteriskToken */);
                        const name = modifierFlags & 2048 /* Default */ ? parseOptionalBindingIdentifier() : parseBindingIdentifier();
                        const isGenerator = asteriskToken ? 1 /* Yield */ : 0 /* None */;
                        const isAsync = modifierFlags & 1024 /* Async */ ? 2 /* Await */ : 0 /* None */;
                        const typeParameters = parseTypeParameters();
                        if (modifierFlags & 32 /* Export */)
                            setAwaitContext(
                            /*value*/
                            true);
                        const parameters = parseParameters(isGenerator | isAsync);
                        const type = parseReturnType(59 /* ColonToken */, 
                        /*isType*/
                        false);
                        const body = parseFunctionBlockOrSemicolon(isGenerator | isAsync, Diagnostics.or_expected);
                        setAwaitContext(savedAwaitContext);
                        const node = factory2.createFunctionDeclaration(modifiers, asteriskToken, name, typeParameters, parameters, type, body);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseConstructorName() {
                        if (token() === 137 /* ConstructorKeyword */) {
                            return parseExpected(137 /* ConstructorKeyword */);
                        }
                        if (token() === 11 /* StringLiteral */ && lookAhead(nextToken) === 21 /* OpenParenToken */) {
                            return tryParse(() => {
                                const literalNode = parseLiteralNode();
                                return literalNode.text === "constructor" ? literalNode : void 0;
                            });
                        }
                    }
                    function tryParseConstructorDeclaration(pos, hasJSDoc, modifiers) {
                        return tryParse(() => {
                            if (parseConstructorName()) {
                                const typeParameters = parseTypeParameters();
                                const parameters = parseParameters(0 /* None */);
                                const type = parseReturnType(59 /* ColonToken */, 
                                /*isType*/
                                false);
                                const body = parseFunctionBlockOrSemicolon(0 /* None */, Diagnostics.or_expected);
                                const node = factory2.createConstructorDeclaration(modifiers, parameters, body);
                                node.typeParameters = typeParameters;
                                node.type = type;
                                return withJSDoc(finishNode(node, pos), hasJSDoc);
                            }
                        });
                    }
                    function parseMethodDeclaration(pos, hasJSDoc, modifiers, asteriskToken, name, questionToken, exclamationToken, diagnosticMessage) {
                        const isGenerator = asteriskToken ? 1 /* Yield */ : 0 /* None */;
                        const isAsync = some(modifiers, isAsyncModifier) ? 2 /* Await */ : 0 /* None */;
                        const typeParameters = parseTypeParameters();
                        const parameters = parseParameters(isGenerator | isAsync);
                        const type = parseReturnType(59 /* ColonToken */, 
                        /*isType*/
                        false);
                        const body = parseFunctionBlockOrSemicolon(isGenerator | isAsync, diagnosticMessage);
                        const node = factory2.createMethodDeclaration(modifiers, asteriskToken, name, questionToken, typeParameters, parameters, type, body);
                        node.exclamationToken = exclamationToken;
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parsePropertyDeclaration(pos, hasJSDoc, modifiers, name, questionToken) {
                        const exclamationToken = !questionToken && !scanner2.hasPrecedingLineBreak() ? parseOptionalToken(54 /* ExclamationToken */) : void 0;
                        const type = parseTypeAnnotation();
                        const initializer = doOutsideOfContext(16384 /* YieldContext */ | 65536 /* AwaitContext */ | 8192 /* DisallowInContext */, parseInitializer);
                        parseSemicolonAfterPropertyName(name, type, initializer);
                        const node = factory2.createPropertyDeclaration(modifiers, name, questionToken || exclamationToken, type, initializer);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parsePropertyOrMethodDeclaration(pos, hasJSDoc, modifiers) {
                        const asteriskToken = parseOptionalToken(42 /* AsteriskToken */);
                        const name = parsePropertyName();
                        const questionToken = parseOptionalToken(58 /* QuestionToken */);
                        if (asteriskToken || token() === 21 /* OpenParenToken */ || token() === 30 /* LessThanToken */) {
                            return parseMethodDeclaration(pos, hasJSDoc, modifiers, asteriskToken, name, questionToken, 
                            /*exclamationToken*/
                            void 0, Diagnostics.or_expected);
                        }
                        return parsePropertyDeclaration(pos, hasJSDoc, modifiers, name, questionToken);
                    }
                    function parseAccessorDeclaration(pos, hasJSDoc, modifiers, kind, flags) {
                        const name = parsePropertyName();
                        const typeParameters = parseTypeParameters();
                        const parameters = parseParameters(0 /* None */);
                        const type = parseReturnType(59 /* ColonToken */, 
                        /*isType*/
                        false);
                        const body = parseFunctionBlockOrSemicolon(flags);
                        const node = kind === 177 /* GetAccessor */ ? factory2.createGetAccessorDeclaration(modifiers, name, parameters, type, body) : factory2.createSetAccessorDeclaration(modifiers, name, parameters, body);
                        node.typeParameters = typeParameters;
                        if (isSetAccessorDeclaration(node))
                            node.type = type;
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function isClassMemberStart() {
                        let idToken;
                        if (token() === 60 /* AtToken */) {
                            return true;
                        }
                        while (isModifierKind(token())) {
                            idToken = token();
                            if (isClassMemberModifier(idToken)) {
                                return true;
                            }
                            nextToken();
                        }
                        if (token() === 42 /* AsteriskToken */) {
                            return true;
                        }
                        if (isLiteralPropertyName()) {
                            idToken = token();
                            nextToken();
                        }
                        if (token() === 23 /* OpenBracketToken */) {
                            return true;
                        }
                        if (idToken !== void 0) {
                            if (!isKeyword(idToken) || idToken === 153 /* SetKeyword */ || idToken === 139 /* GetKeyword */) {
                                return true;
                            }
                            switch (token()) {
                                case 21 /* OpenParenToken */:
                                case 30 /* LessThanToken */:
                                case 54 /* ExclamationToken */:
                                case 59 /* ColonToken */:
                                case 64 /* EqualsToken */:
                                case 58 /* QuestionToken */:
                                    return true;
                                default:
                                    return canParseSemicolon();
                            }
                        }
                        return false;
                    }
                    function parseClassStaticBlockDeclaration(pos, hasJSDoc, modifiers) {
                        parseExpectedToken(126 /* StaticKeyword */);
                        const body = parseClassStaticBlockBody();
                        const node = withJSDoc(finishNode(factory2.createClassStaticBlockDeclaration(body), pos), hasJSDoc);
                        node.modifiers = modifiers;
                        return node;
                    }
                    function parseClassStaticBlockBody() {
                        const savedYieldContext = inYieldContext();
                        const savedAwaitContext = inAwaitContext();
                        setYieldContext(false);
                        setAwaitContext(true);
                        const body = parseBlock(
                        /*ignoreMissingOpenBrace*/
                        false);
                        setYieldContext(savedYieldContext);
                        setAwaitContext(savedAwaitContext);
                        return body;
                    }
                    function parseDecoratorExpression() {
                        if (inAwaitContext() && token() === 135 /* AwaitKeyword */) {
                            const pos = getNodePos();
                            const awaitExpression = parseIdentifier(Diagnostics.Expression_expected);
                            nextToken();
                            const memberExpression = parseMemberExpressionRest(pos, awaitExpression, 
                            /*allowOptionalChain*/
                            true);
                            return parseCallExpressionRest(pos, memberExpression);
                        }
                        return parseLeftHandSideExpressionOrHigher();
                    }
                    function tryParseDecorator() {
                        const pos = getNodePos();
                        if (!parseOptional(60 /* AtToken */)) {
                            return void 0;
                        }
                        const expression = doInDecoratorContext(parseDecoratorExpression);
                        return finishNode(factory2.createDecorator(expression), pos);
                    }
                    function tryParseModifier(hasSeenStaticModifier, permitConstAsModifier, stopOnStartOfClassStaticBlock) {
                        const pos = getNodePos();
                        const kind = token();
                        if (token() === 87 /* ConstKeyword */ && permitConstAsModifier) {
                            if (!tryParse(nextTokenIsOnSameLineAndCanFollowModifier)) {
                                return void 0;
                            }
                        }
                        else if (stopOnStartOfClassStaticBlock && token() === 126 /* StaticKeyword */ && lookAhead(nextTokenIsOpenBrace)) {
                            return void 0;
                        }
                        else if (hasSeenStaticModifier && token() === 126 /* StaticKeyword */) {
                            return void 0;
                        }
                        else {
                            if (!parseAnyContextualModifier()) {
                                return void 0;
                            }
                        }
                        return finishNode(factoryCreateToken(kind), pos);
                    }
                    function parseModifiers(allowDecorators, permitConstAsModifier, stopOnStartOfClassStaticBlock) {
                        const pos = getNodePos();
                        let list;
                        let decorator, modifier, hasSeenStaticModifier = false, hasLeadingModifier = false, hasTrailingDecorator = false;
                        if (allowDecorators && token() === 60 /* AtToken */) {
                            while (decorator = tryParseDecorator()) {
                                list = append(list, decorator);
                            }
                        }
                        while (modifier = tryParseModifier(hasSeenStaticModifier, permitConstAsModifier, stopOnStartOfClassStaticBlock)) {
                            if (modifier.kind === 126 /* StaticKeyword */)
                                hasSeenStaticModifier = true;
                            list = append(list, modifier);
                            hasLeadingModifier = true;
                        }
                        if (hasLeadingModifier && allowDecorators && token() === 60 /* AtToken */) {
                            while (decorator = tryParseDecorator()) {
                                list = append(list, decorator);
                                hasTrailingDecorator = true;
                            }
                        }
                        if (hasTrailingDecorator) {
                            while (modifier = tryParseModifier(hasSeenStaticModifier, permitConstAsModifier, stopOnStartOfClassStaticBlock)) {
                                if (modifier.kind === 126 /* StaticKeyword */)
                                    hasSeenStaticModifier = true;
                                list = append(list, modifier);
                            }
                        }
                        return list && createNodeArray(list, pos);
                    }
                    function parseModifiersForArrowFunction() {
                        let modifiers;
                        if (token() === 134 /* AsyncKeyword */) {
                            const pos = getNodePos();
                            nextToken();
                            const modifier = finishNode(factoryCreateToken(134 /* AsyncKeyword */), pos);
                            modifiers = createNodeArray([modifier], pos);
                        }
                        return modifiers;
                    }
                    function parseClassElement() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        if (token() === 27 /* SemicolonToken */) {
                            nextToken();
                            return withJSDoc(finishNode(factory2.createSemicolonClassElement(), pos), hasJSDoc);
                        }
                        const modifiers = parseModifiers(
                        /*allowDecorators*/
                        true, 
                        /*permitConstAsModifier*/
                        true, 
                        /*stopOnStartOfClassStaticBlock*/
                        true);
                        if (token() === 126 /* StaticKeyword */ && lookAhead(nextTokenIsOpenBrace)) {
                            return parseClassStaticBlockDeclaration(pos, hasJSDoc, modifiers);
                        }
                        if (parseContextualModifier(139 /* GetKeyword */)) {
                            return parseAccessorDeclaration(pos, hasJSDoc, modifiers, 177 /* GetAccessor */, 0 /* None */);
                        }
                        if (parseContextualModifier(153 /* SetKeyword */)) {
                            return parseAccessorDeclaration(pos, hasJSDoc, modifiers, 178 /* SetAccessor */, 0 /* None */);
                        }
                        if (token() === 137 /* ConstructorKeyword */ || token() === 11 /* StringLiteral */) {
                            const constructorDeclaration = tryParseConstructorDeclaration(pos, hasJSDoc, modifiers);
                            if (constructorDeclaration) {
                                return constructorDeclaration;
                            }
                        }
                        if (isIndexSignature()) {
                            return parseIndexSignatureDeclaration(pos, hasJSDoc, modifiers);
                        }
                        if (tokenIsIdentifierOrKeyword(token()) || token() === 11 /* StringLiteral */ || token() === 9 /* NumericLiteral */ || token() === 42 /* AsteriskToken */ || token() === 23 /* OpenBracketToken */) {
                            const isAmbient = some(modifiers, isDeclareModifier);
                            if (isAmbient) {
                                for (const m of modifiers) {
                                    m.flags |= 33554432 /* Ambient */;
                                }
                                return doInsideOfContext(33554432 /* Ambient */, () => parsePropertyOrMethodDeclaration(pos, hasJSDoc, modifiers));
                            }
                            else {
                                return parsePropertyOrMethodDeclaration(pos, hasJSDoc, modifiers);
                            }
                        }
                        if (modifiers) {
                            const name = createMissingNode(80 /* Identifier */, 
                            /*reportAtCurrentPosition*/
                            true, Diagnostics.Declaration_expected);
                            return parsePropertyDeclaration(pos, hasJSDoc, modifiers, name, 
                            /*questionToken*/
                            void 0);
                        }
                        return Debug.fail("Should not have attempted to parse class member declaration.");
                    }
                    function parseDecoratedExpression() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        const modifiers = parseModifiers(
                        /*allowDecorators*/
                        true);
                        if (token() === 86 /* ClassKeyword */) {
                            return parseClassDeclarationOrExpression(pos, hasJSDoc, modifiers, 231 /* ClassExpression */);
                        }
                        const missing = createMissingNode(282 /* MissingDeclaration */, 
                        /*reportAtCurrentPosition*/
                        true, Diagnostics.Expression_expected);
                        setTextRangePos(missing, pos);
                        missing.modifiers = modifiers;
                        return missing;
                    }
                    function parseClassExpression() {
                        return parseClassDeclarationOrExpression(getNodePos(), hasPrecedingJSDocComment(), 
                        /*modifiers*/
                        void 0, 231 /* ClassExpression */);
                    }
                    function parseClassDeclaration(pos, hasJSDoc, modifiers) {
                        return parseClassDeclarationOrExpression(pos, hasJSDoc, modifiers, 263 /* ClassDeclaration */);
                    }
                    function parseClassDeclarationOrExpression(pos, hasJSDoc, modifiers, kind) {
                        const savedAwaitContext = inAwaitContext();
                        parseExpected(86 /* ClassKeyword */);
                        const name = parseNameOfClassDeclarationOrExpression();
                        const typeParameters = parseTypeParameters();
                        if (some(modifiers, isExportModifier))
                            setAwaitContext(
                            /*value*/
                            true);
                        const heritageClauses = parseHeritageClauses();
                        let members;
                        if (parseExpected(19 /* OpenBraceToken */)) {
                            members = parseClassMembers();
                            parseExpected(20 /* CloseBraceToken */);
                        }
                        else {
                            members = createMissingList();
                        }
                        setAwaitContext(savedAwaitContext);
                        const node = kind === 263 /* ClassDeclaration */ ? factory2.createClassDeclaration(modifiers, name, typeParameters, heritageClauses, members) : factory2.createClassExpression(modifiers, name, typeParameters, heritageClauses, members);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseNameOfClassDeclarationOrExpression() {
                        return isBindingIdentifier() && !isImplementsClause() ? createIdentifier(isBindingIdentifier()) : void 0;
                    }
                    function isImplementsClause() {
                        return token() === 119 /* ImplementsKeyword */ && lookAhead(nextTokenIsIdentifierOrKeyword);
                    }
                    function parseHeritageClauses() {
                        if (isHeritageClause2()) {
                            return parseList(22 /* HeritageClauses */, parseHeritageClause);
                        }
                        return void 0;
                    }
                    function parseHeritageClause() {
                        const pos = getNodePos();
                        const tok = token();
                        Debug.assert(tok === 96 /* ExtendsKeyword */ || tok === 119 /* ImplementsKeyword */);
                        nextToken();
                        const types = parseDelimitedList(7 /* HeritageClauseElement */, parseExpressionWithTypeArguments);
                        return finishNode(factory2.createHeritageClause(tok, types), pos);
                    }
                    function parseExpressionWithTypeArguments() {
                        const pos = getNodePos();
                        const expression = parseLeftHandSideExpressionOrHigher();
                        if (expression.kind === 233 /* ExpressionWithTypeArguments */) {
                            return expression;
                        }
                        const typeArguments = tryParseTypeArguments();
                        return finishNode(factory2.createExpressionWithTypeArguments(expression, typeArguments), pos);
                    }
                    function tryParseTypeArguments() {
                        return token() === 30 /* LessThanToken */ ? parseBracketedList(20 /* TypeArguments */, parseType, 30 /* LessThanToken */, 32 /* GreaterThanToken */) : void 0;
                    }
                    function isHeritageClause2() {
                        return token() === 96 /* ExtendsKeyword */ || token() === 119 /* ImplementsKeyword */;
                    }
                    function parseClassMembers() {
                        return parseList(5 /* ClassMembers */, parseClassElement);
                    }
                    function parseInterfaceDeclaration(pos, hasJSDoc, modifiers) {
                        parseExpected(120 /* InterfaceKeyword */);
                        const name = parseIdentifier();
                        const typeParameters = parseTypeParameters();
                        const heritageClauses = parseHeritageClauses();
                        const members = parseObjectTypeMembers();
                        const node = factory2.createInterfaceDeclaration(modifiers, name, typeParameters, heritageClauses, members);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseTypeAliasDeclaration(pos, hasJSDoc, modifiers) {
                        parseExpected(156 /* TypeKeyword */);
                        if (scanner2.hasPrecedingLineBreak()) {
                            parseErrorAtCurrentToken(Diagnostics.Line_break_not_permitted_here);
                        }
                        const name = parseIdentifier();
                        const typeParameters = parseTypeParameters();
                        parseExpected(64 /* EqualsToken */);
                        const type = token() === 141 /* IntrinsicKeyword */ && tryParse(parseKeywordAndNoDot) || parseType();
                        parseSemicolon();
                        const node = factory2.createTypeAliasDeclaration(modifiers, name, typeParameters, type);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseEnumMember() {
                        const pos = getNodePos();
                        const hasJSDoc = hasPrecedingJSDocComment();
                        const name = parsePropertyName();
                        const initializer = allowInAnd(parseInitializer);
                        return withJSDoc(finishNode(factory2.createEnumMember(name, initializer), pos), hasJSDoc);
                    }
                    function parseEnumDeclaration(pos, hasJSDoc, modifiers) {
                        parseExpected(94 /* EnumKeyword */);
                        const name = parseIdentifier();
                        let members;
                        if (parseExpected(19 /* OpenBraceToken */)) {
                            members = doOutsideOfYieldAndAwaitContext(() => parseDelimitedList(6 /* EnumMembers */, parseEnumMember));
                            parseExpected(20 /* CloseBraceToken */);
                        }
                        else {
                            members = createMissingList();
                        }
                        const node = factory2.createEnumDeclaration(modifiers, name, members);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseModuleBlock() {
                        const pos = getNodePos();
                        let statements;
                        if (parseExpected(19 /* OpenBraceToken */)) {
                            statements = parseList(1 /* BlockStatements */, parseStatement);
                            parseExpected(20 /* CloseBraceToken */);
                        }
                        else {
                            statements = createMissingList();
                        }
                        return finishNode(factory2.createModuleBlock(statements), pos);
                    }
                    function parseModuleOrNamespaceDeclaration(pos, hasJSDoc, modifiers, flags) {
                        const namespaceFlag = flags & 32 /* Namespace */;
                        const name = flags & 8 /* NestedNamespace */ ? parseIdentifierName() : parseIdentifier();
                        const body = parseOptional(25 /* DotToken */) ? parseModuleOrNamespaceDeclaration(getNodePos(), 
                        /*hasJSDoc*/
                        false, 
                        /*modifiers*/
                        void 0, 8 /* NestedNamespace */ | namespaceFlag) : parseModuleBlock();
                        const node = factory2.createModuleDeclaration(modifiers, name, body, flags);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseAmbientExternalModuleDeclaration(pos, hasJSDoc, modifiersIn) {
                        let flags = 0;
                        let name;
                        if (token() === 162 /* GlobalKeyword */) {
                            name = parseIdentifier();
                            flags |= 2048 /* GlobalAugmentation */;
                        }
                        else {
                            name = parseLiteralNode();
                            name.text = internIdentifier(name.text);
                        }
                        let body;
                        if (token() === 19 /* OpenBraceToken */) {
                            body = parseModuleBlock();
                        }
                        else {
                            parseSemicolon();
                        }
                        const node = factory2.createModuleDeclaration(modifiersIn, name, body, flags);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseModuleDeclaration(pos, hasJSDoc, modifiersIn) {
                        let flags = 0;
                        if (token() === 162 /* GlobalKeyword */) {
                            return parseAmbientExternalModuleDeclaration(pos, hasJSDoc, modifiersIn);
                        }
                        else if (parseOptional(145 /* NamespaceKeyword */)) {
                            flags |= 32 /* Namespace */;
                        }
                        else {
                            parseExpected(144 /* ModuleKeyword */);
                            if (token() === 11 /* StringLiteral */) {
                                return parseAmbientExternalModuleDeclaration(pos, hasJSDoc, modifiersIn);
                            }
                        }
                        return parseModuleOrNamespaceDeclaration(pos, hasJSDoc, modifiersIn, flags);
                    }
                    function isExternalModuleReference2() {
                        return token() === 149 /* RequireKeyword */ && lookAhead(nextTokenIsOpenParen);
                    }
                    function nextTokenIsOpenParen() {
                        return nextToken() === 21 /* OpenParenToken */;
                    }
                    function nextTokenIsOpenBrace() {
                        return nextToken() === 19 /* OpenBraceToken */;
                    }
                    function nextTokenIsSlash() {
                        return nextToken() === 44 /* SlashToken */;
                    }
                    function parseNamespaceExportDeclaration(pos, hasJSDoc, modifiers) {
                        parseExpected(130 /* AsKeyword */);
                        parseExpected(145 /* NamespaceKeyword */);
                        const name = parseIdentifier();
                        parseSemicolon();
                        const node = factory2.createNamespaceExportDeclaration(name);
                        node.modifiers = modifiers;
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseImportDeclarationOrImportEqualsDeclaration(pos, hasJSDoc, modifiers) {
                        parseExpected(102 /* ImportKeyword */);
                        const afterImportPos = scanner2.getTokenFullStart();
                        let identifier;
                        if (isIdentifier2()) {
                            identifier = parseIdentifier();
                        }
                        let isTypeOnly = false;
                        if ((identifier == null ? void 0 : identifier.escapedText) === "type" && (token() !== 161 /* FromKeyword */ || isIdentifier2() && lookAhead(nextTokenIsFromKeywordOrEqualsToken)) && (isIdentifier2() || tokenAfterImportDefinitelyProducesImportDeclaration())) {
                            isTypeOnly = true;
                            identifier = isIdentifier2() ? parseIdentifier() : void 0;
                        }
                        if (identifier && !tokenAfterImportedIdentifierDefinitelyProducesImportDeclaration()) {
                            return parseImportEqualsDeclaration(pos, hasJSDoc, modifiers, identifier, isTypeOnly);
                        }
                        let importClause;
                        if (identifier || // import id
                            token() === 42 /* AsteriskToken */ || // import *
                            token() === 19 /* OpenBraceToken */) {
                            importClause = parseImportClause(identifier, afterImportPos, isTypeOnly);
                            parseExpected(161 /* FromKeyword */);
                        }
                        const moduleSpecifier = parseModuleSpecifier();
                        const currentToken2 = token();
                        let attributes;
                        if ((currentToken2 === 118 /* WithKeyword */ || currentToken2 === 132 /* AssertKeyword */) && !scanner2.hasPrecedingLineBreak()) {
                            attributes = parseImportAttributes(currentToken2);
                        }
                        parseSemicolon();
                        const node = factory2.createImportDeclaration(modifiers, importClause, moduleSpecifier, attributes);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseImportAttribute() {
                        const pos = getNodePos();
                        const name = tokenIsIdentifierOrKeyword(token()) ? parseIdentifierName() : parseLiteralLikeNode(11 /* StringLiteral */);
                        parseExpected(59 /* ColonToken */);
                        const value = parseAssignmentExpressionOrHigher(
                        /*allowReturnTypeInArrowFunction*/
                        true);
                        return finishNode(factory2.createImportAttribute(name, value), pos);
                    }
                    function parseImportAttributes(token2, skipKeyword) {
                        const pos = getNodePos();
                        if (!skipKeyword) {
                            parseExpected(token2);
                        }
                        const openBracePosition = scanner2.getTokenStart();
                        if (parseExpected(19 /* OpenBraceToken */)) {
                            const multiLine = scanner2.hasPrecedingLineBreak();
                            const elements = parseDelimitedList(24 /* ImportAttributes */, parseImportAttribute, 
                            /*considerSemicolonAsDelimiter*/
                            true);
                            if (!parseExpected(20 /* CloseBraceToken */)) {
                                const lastError = lastOrUndefined(parseDiagnostics);
                                if (lastError && lastError.code === Diagnostics._0_expected.code) {
                                    addRelatedInfo(lastError, createDetachedDiagnostic(fileName, sourceText, openBracePosition, 1, Diagnostics.The_parser_expected_to_find_a_1_to_match_the_0_token_here, "{", "}"));
                                }
                            }
                            return finishNode(factory2.createImportAttributes(elements, multiLine, token2), pos);
                        }
                        else {
                            const elements = createNodeArray([], getNodePos(), 
                            /*end*/
                            void 0, 
                            /*hasTrailingComma*/
                            false);
                            return finishNode(factory2.createImportAttributes(elements, 
                            /*multiLine*/
                            false, token2), pos);
                        }
                    }
                    function tokenAfterImportDefinitelyProducesImportDeclaration() {
                        return token() === 42 /* AsteriskToken */ || token() === 19 /* OpenBraceToken */;
                    }
                    function tokenAfterImportedIdentifierDefinitelyProducesImportDeclaration() {
                        return token() === 28 /* CommaToken */ || token() === 161 /* FromKeyword */;
                    }
                    function parseImportEqualsDeclaration(pos, hasJSDoc, modifiers, identifier, isTypeOnly) {
                        parseExpected(64 /* EqualsToken */);
                        const moduleReference = parseModuleReference();
                        parseSemicolon();
                        const node = factory2.createImportEqualsDeclaration(modifiers, isTypeOnly, identifier, moduleReference);
                        const finished = withJSDoc(finishNode(node, pos), hasJSDoc);
                        return finished;
                    }
                    function parseImportClause(identifier, pos, isTypeOnly) {
                        let namedBindings;
                        if (!identifier || parseOptional(28 /* CommaToken */)) {
                            namedBindings = token() === 42 /* AsteriskToken */ ? parseNamespaceImport() : parseNamedImportsOrExports(275 /* NamedImports */);
                        }
                        return finishNode(factory2.createImportClause(isTypeOnly, identifier, namedBindings), pos);
                    }
                    function parseModuleReference() {
                        return isExternalModuleReference2() ? parseExternalModuleReference() : parseEntityName(
                        /*allowReservedWords*/
                        false);
                    }
                    function parseExternalModuleReference() {
                        const pos = getNodePos();
                        parseExpected(149 /* RequireKeyword */);
                        parseExpected(21 /* OpenParenToken */);
                        const expression = parseModuleSpecifier();
                        parseExpected(22 /* CloseParenToken */);
                        return finishNode(factory2.createExternalModuleReference(expression), pos);
                    }
                    function parseModuleSpecifier() {
                        if (token() === 11 /* StringLiteral */) {
                            const result = parseLiteralNode();
                            result.text = internIdentifier(result.text);
                            return result;
                        }
                        else {
                            return parseExpression();
                        }
                    }
                    function parseNamespaceImport() {
                        const pos = getNodePos();
                        parseExpected(42 /* AsteriskToken */);
                        parseExpected(130 /* AsKeyword */);
                        const name = parseIdentifier();
                        return finishNode(factory2.createNamespaceImport(name), pos);
                    }
                    function parseNamedImportsOrExports(kind) {
                        const pos = getNodePos();
                        const node = kind === 275 /* NamedImports */ ? factory2.createNamedImports(parseBracketedList(23 /* ImportOrExportSpecifiers */, parseImportSpecifier, 19 /* OpenBraceToken */, 20 /* CloseBraceToken */)) : factory2.createNamedExports(parseBracketedList(23 /* ImportOrExportSpecifiers */, parseExportSpecifier, 19 /* OpenBraceToken */, 20 /* CloseBraceToken */));
                        return finishNode(node, pos);
                    }
                    function parseExportSpecifier() {
                        const hasJSDoc = hasPrecedingJSDocComment();
                        return withJSDoc(parseImportOrExportSpecifier(281 /* ExportSpecifier */), hasJSDoc);
                    }
                    function parseImportSpecifier() {
                        return parseImportOrExportSpecifier(276 /* ImportSpecifier */);
                    }
                    function parseImportOrExportSpecifier(kind) {
                        const pos = getNodePos();
                        let checkIdentifierIsKeyword = isKeyword(token()) && !isIdentifier2();
                        let checkIdentifierStart = scanner2.getTokenStart();
                        let checkIdentifierEnd = scanner2.getTokenEnd();
                        let isTypeOnly = false;
                        let propertyName;
                        let canParseAsKeyword = true;
                        let name = parseIdentifierName();
                        if (name.escapedText === "type") {
                            if (token() === 130 /* AsKeyword */) {
                                const firstAs = parseIdentifierName();
                                if (token() === 130 /* AsKeyword */) {
                                    const secondAs = parseIdentifierName();
                                    if (tokenIsIdentifierOrKeyword(token())) {
                                        isTypeOnly = true;
                                        propertyName = firstAs;
                                        name = parseNameWithKeywordCheck();
                                        canParseAsKeyword = false;
                                    }
                                    else {
                                        propertyName = name;
                                        name = secondAs;
                                        canParseAsKeyword = false;
                                    }
                                }
                                else if (tokenIsIdentifierOrKeyword(token())) {
                                    propertyName = name;
                                    canParseAsKeyword = false;
                                    name = parseNameWithKeywordCheck();
                                }
                                else {
                                    isTypeOnly = true;
                                    name = firstAs;
                                }
                            }
                            else if (tokenIsIdentifierOrKeyword(token())) {
                                isTypeOnly = true;
                                name = parseNameWithKeywordCheck();
                            }
                        }
                        if (canParseAsKeyword && token() === 130 /* AsKeyword */) {
                            propertyName = name;
                            parseExpected(130 /* AsKeyword */);
                            name = parseNameWithKeywordCheck();
                        }
                        if (kind === 276 /* ImportSpecifier */ && checkIdentifierIsKeyword) {
                            parseErrorAt(checkIdentifierStart, checkIdentifierEnd, Diagnostics.Identifier_expected);
                        }
                        const node = kind === 276 /* ImportSpecifier */ ? factory2.createImportSpecifier(isTypeOnly, propertyName, name) : factory2.createExportSpecifier(isTypeOnly, propertyName, name);
                        return finishNode(node, pos);
                        function parseNameWithKeywordCheck() {
                            checkIdentifierIsKeyword = isKeyword(token()) && !isIdentifier2();
                            checkIdentifierStart = scanner2.getTokenStart();
                            checkIdentifierEnd = scanner2.getTokenEnd();
                            return parseIdentifierName();
                        }
                    }
                    function parseNamespaceExport(pos) {
                        return finishNode(factory2.createNamespaceExport(parseIdentifierName()), pos);
                    }
                    function parseExportDeclaration(pos, hasJSDoc, modifiers) {
                        const savedAwaitContext = inAwaitContext();
                        setAwaitContext(
                        /*value*/
                        true);
                        let exportClause;
                        let moduleSpecifier;
                        let attributes;
                        const isTypeOnly = parseOptional(156 /* TypeKeyword */);
                        const namespaceExportPos = getNodePos();
                        if (parseOptional(42 /* AsteriskToken */)) {
                            if (parseOptional(130 /* AsKeyword */)) {
                                exportClause = parseNamespaceExport(namespaceExportPos);
                            }
                            parseExpected(161 /* FromKeyword */);
                            moduleSpecifier = parseModuleSpecifier();
                        }
                        else {
                            exportClause = parseNamedImportsOrExports(279 /* NamedExports */);
                            if (token() === 161 /* FromKeyword */ || token() === 11 /* StringLiteral */ && !scanner2.hasPrecedingLineBreak()) {
                                parseExpected(161 /* FromKeyword */);
                                moduleSpecifier = parseModuleSpecifier();
                            }
                        }
                        const currentToken2 = token();
                        if (moduleSpecifier && (currentToken2 === 118 /* WithKeyword */ || currentToken2 === 132 /* AssertKeyword */) && !scanner2.hasPrecedingLineBreak()) {
                            attributes = parseImportAttributes(currentToken2);
                        }
                        parseSemicolon();
                        setAwaitContext(savedAwaitContext);
                        const node = factory2.createExportDeclaration(modifiers, isTypeOnly, exportClause, moduleSpecifier, attributes);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    function parseExportAssignment(pos, hasJSDoc, modifiers) {
                        const savedAwaitContext = inAwaitContext();
                        setAwaitContext(
                        /*value*/
                        true);
                        let isExportEquals;
                        if (parseOptional(64 /* EqualsToken */)) {
                            isExportEquals = true;
                        }
                        else {
                            parseExpected(90 /* DefaultKeyword */);
                        }
                        const expression = parseAssignmentExpressionOrHigher(
                        /*allowReturnTypeInArrowFunction*/
                        true);
                        parseSemicolon();
                        setAwaitContext(savedAwaitContext);
                        const node = factory2.createExportAssignment(modifiers, isExportEquals, expression);
                        return withJSDoc(finishNode(node, pos), hasJSDoc);
                    }
                    let ParsingContext;
                    ((ParsingContext2) => {
                        ParsingContext2[ParsingContext2["SourceElements"] = 0] = "SourceElements";
                        ParsingContext2[ParsingContext2["BlockStatements"] = 1] = "BlockStatements";
                        ParsingContext2[ParsingContext2["SwitchClauses"] = 2] = "SwitchClauses";
                        ParsingContext2[ParsingContext2["SwitchClauseStatements"] = 3] = "SwitchClauseStatements";
                        ParsingContext2[ParsingContext2["TypeMembers"] = 4] = "TypeMembers";
                        ParsingContext2[ParsingContext2["ClassMembers"] = 5] = "ClassMembers";
                        ParsingContext2[ParsingContext2["EnumMembers"] = 6] = "EnumMembers";
                        ParsingContext2[ParsingContext2["HeritageClauseElement"] = 7] = "HeritageClauseElement";
                        ParsingContext2[ParsingContext2["VariableDeclarations"] = 8] = "VariableDeclarations";
                        ParsingContext2[ParsingContext2["ObjectBindingElements"] = 9] = "ObjectBindingElements";
                        ParsingContext2[ParsingContext2["ArrayBindingElements"] = 10] = "ArrayBindingElements";
                        ParsingContext2[ParsingContext2["ArgumentExpressions"] = 11] = "ArgumentExpressions";
                        ParsingContext2[ParsingContext2["ObjectLiteralMembers"] = 12] = "ObjectLiteralMembers";
                        ParsingContext2[ParsingContext2["JsxAttributes"] = 13] = "JsxAttributes";
                        ParsingContext2[ParsingContext2["JsxChildren"] = 14] = "JsxChildren";
                        ParsingContext2[ParsingContext2["ArrayLiteralMembers"] = 15] = "ArrayLiteralMembers";
                        ParsingContext2[ParsingContext2["Parameters"] = 16] = "Parameters";
                        ParsingContext2[ParsingContext2["JSDocParameters"] = 17] = "JSDocParameters";
                        ParsingContext2[ParsingContext2["RestProperties"] = 18] = "RestProperties";
                        ParsingContext2[ParsingContext2["TypeParameters"] = 19] = "TypeParameters";
                        ParsingContext2[ParsingContext2["TypeArguments"] = 20] = "TypeArguments";
                        ParsingContext2[ParsingContext2["TupleElementTypes"] = 21] = "TupleElementTypes";
                        ParsingContext2[ParsingContext2["HeritageClauses"] = 22] = "HeritageClauses";
                        ParsingContext2[ParsingContext2["ImportOrExportSpecifiers"] = 23] = "ImportOrExportSpecifiers";
                        ParsingContext2[ParsingContext2["ImportAttributes"] = 24] = "ImportAttributes";
                        ParsingContext2[ParsingContext2["JSDocComment"] = 25] = "JSDocComment";
                        ParsingContext2[ParsingContext2["Count"] = 26] = "Count";
                    })(ParsingContext || (ParsingContext = {}));
                    let Tristate;
                    ((Tristate2) => {
                        Tristate2[Tristate2["False"] = 0] = "False";
                        Tristate2[Tristate2["True"] = 1] = "True";
                        Tristate2[Tristate2["Unknown"] = 2] = "Unknown";
                    })(Tristate || (Tristate = {}));
                    let JSDocParser;
                    ((JSDocParser2) => {
                        function parseJSDocTypeExpressionForTests2(content, start, length2) {
                            initializeState("file.js", content, 99 /* Latest */, 
                            /*syntaxCursor*/
                            void 0, 1 /* JS */, 0 /* ParseAll */);
                            scanner2.setText(content, start, length2);
                            currentToken = scanner2.scan();
                            const jsDocTypeExpression = parseJSDocTypeExpression();
                            const sourceFile = createSourceFile2("file.js", 99 /* Latest */, 1 /* JS */, 
                            /*isDeclarationFile*/
                            false, [], factoryCreateToken(1 /* EndOfFileToken */), 0 /* None */, noop);
                            const diagnostics = attachFileToDiagnostics(parseDiagnostics, sourceFile);
                            if (jsDocDiagnostics) {
                                sourceFile.jsDocDiagnostics = attachFileToDiagnostics(jsDocDiagnostics, sourceFile);
                            }
                            clearState();
                            return jsDocTypeExpression ? { jsDocTypeExpression, diagnostics } : void 0;
                        }
                        JSDocParser2.parseJSDocTypeExpressionForTests = parseJSDocTypeExpressionForTests2;
                        function parseJSDocTypeExpression(mayOmitBraces) {
                            const pos = getNodePos();
                            const hasBrace = (mayOmitBraces ? parseOptional : parseExpected)(19 /* OpenBraceToken */);
                            const type = doInsideOfContext(16777216 /* JSDoc */, parseJSDocType);
                            if (!mayOmitBraces || hasBrace) {
                                parseExpectedJSDoc(20 /* CloseBraceToken */);
                            }
                            const result = factory2.createJSDocTypeExpression(type);
                            fixupParentReferences(result);
                            return finishNode(result, pos);
                        }
                        JSDocParser2.parseJSDocTypeExpression = parseJSDocTypeExpression;
                        function parseJSDocNameReference() {
                            const pos = getNodePos();
                            const hasBrace = parseOptional(19 /* OpenBraceToken */);
                            const p2 = getNodePos();
                            let entityName = parseEntityName(
                            /*allowReservedWords*/
                            false);
                            while (token() === 81 /* PrivateIdentifier */) {
                                reScanHashToken();
                                nextTokenJSDoc();
                                entityName = finishNode(factory2.createJSDocMemberName(entityName, parseIdentifier()), p2);
                            }
                            if (hasBrace) {
                                parseExpectedJSDoc(20 /* CloseBraceToken */);
                            }
                            const result = factory2.createJSDocNameReference(entityName);
                            fixupParentReferences(result);
                            return finishNode(result, pos);
                        }
                        JSDocParser2.parseJSDocNameReference = parseJSDocNameReference;
                        function parseIsolatedJSDocComment2(content, start, length2) {
                            initializeState("", content, 99 /* Latest */, 
                            /*syntaxCursor*/
                            void 0, 1 /* JS */, 0 /* ParseAll */);
                            const jsDoc = doInsideOfContext(16777216 /* JSDoc */, () => parseJSDocCommentWorker(start, length2));
                            const sourceFile = { languageVariant: 0 /* Standard */, text: content };
                            const diagnostics = attachFileToDiagnostics(parseDiagnostics, sourceFile);
                            clearState();
                            return jsDoc ? { jsDoc, diagnostics } : void 0;
                        }
                        JSDocParser2.parseIsolatedJSDocComment = parseIsolatedJSDocComment2;
                        function parseJSDocComment(parent2, start, length2) {
                            const saveToken = currentToken;
                            const saveParseDiagnosticsLength = parseDiagnostics.length;
                            const saveParseErrorBeforeNextFinishedNode = parseErrorBeforeNextFinishedNode;
                            const comment = doInsideOfContext(16777216 /* JSDoc */, () => parseJSDocCommentWorker(start, length2));
                            setParent(comment, parent2);
                            if (contextFlags & 524288 /* JavaScriptFile */) {
                                if (!jsDocDiagnostics) {
                                    jsDocDiagnostics = [];
                                }
                                addRange(jsDocDiagnostics, parseDiagnostics, saveParseDiagnosticsLength);
                            }
                            currentToken = saveToken;
                            parseDiagnostics.length = saveParseDiagnosticsLength;
                            parseErrorBeforeNextFinishedNode = saveParseErrorBeforeNextFinishedNode;
                            return comment;
                        }
                        JSDocParser2.parseJSDocComment = parseJSDocComment;
                        let JSDocState;
                        ((JSDocState2) => {
                            JSDocState2[JSDocState2["BeginningOfLine"] = 0] = "BeginningOfLine";
                            JSDocState2[JSDocState2["SawAsterisk"] = 1] = "SawAsterisk";
                            JSDocState2[JSDocState2["SavingComments"] = 2] = "SavingComments";
                            JSDocState2[JSDocState2["SavingBackticks"] = 3] = "SavingBackticks";
                        })(JSDocState || (JSDocState = {}));
                        let PropertyLikeParse;
                        ((PropertyLikeParse2) => {
                            PropertyLikeParse2[PropertyLikeParse2["Property"] = 1] = "Property";
                            PropertyLikeParse2[PropertyLikeParse2["Parameter"] = 2] = "Parameter";
                            PropertyLikeParse2[PropertyLikeParse2["CallbackParameter"] = 4] = "CallbackParameter";
                        })(PropertyLikeParse || (PropertyLikeParse = {}));
                        function parseJSDocCommentWorker(start = 0, length2) {
                            const content = sourceText;
                            const end = length2 === void 0 ? content.length : start + length2;
                            length2 = end - start;
                            Debug.assert(start >= 0);
                            Debug.assert(start <= end);
                            Debug.assert(end <= content.length);
                            if (!isJSDocLikeText(content, start)) {
                                return void 0;
                            }
                            let tags;
                            let tagsPos;
                            let tagsEnd;
                            let linkEnd;
                            let commentsPos;
                            let comments = [];
                            const parts = [];
                            const saveParsingContext = parsingContext;
                            parsingContext |= 1 << 25 /* JSDocComment */;
                            const result = scanner2.scanRange(start + 3, length2 - 5, doJSDocScan);
                            parsingContext = saveParsingContext;
                            return result;
                            function doJSDocScan() {
                                let state = 1 /* SawAsterisk */;
                                let margin;
                                let indent3 = start - (content.lastIndexOf("\n", start) + 1) + 4;
                                function pushComment(text) {
                                    if (!margin) {
                                        margin = indent3;
                                    }
                                    comments.push(text);
                                    indent3 += text.length;
                                }
                                nextTokenJSDoc();
                                while (parseOptionalJsdoc(5 /* WhitespaceTrivia */))
                                    ;
                                if (parseOptionalJsdoc(4 /* NewLineTrivia */)) {
                                    state = 0 /* BeginningOfLine */;
                                    indent3 = 0;
                                }
                                loop: while (true) {
                                    switch (token()) {
                                        case 60 /* AtToken */:
                                            removeTrailingWhitespace(comments);
                                            if (!commentsPos)
                                                commentsPos = getNodePos();
                                            addTag(parseTag(indent3));
                                            state = 0 /* BeginningOfLine */;
                                            margin = void 0;
                                            break;
                                        case 4 /* NewLineTrivia */:
                                            comments.push(scanner2.getTokenText());
                                            state = 0 /* BeginningOfLine */;
                                            indent3 = 0;
                                            break;
                                        case 42 /* AsteriskToken */:
                                            const asterisk = scanner2.getTokenText();
                                            if (state === 1 /* SawAsterisk */) {
                                                state = 2 /* SavingComments */;
                                                pushComment(asterisk);
                                            }
                                            else {
                                                Debug.assert(state === 0 /* BeginningOfLine */);
                                                state = 1 /* SawAsterisk */;
                                                indent3 += asterisk.length;
                                            }
                                            break;
                                        case 5 /* WhitespaceTrivia */:
                                            Debug.assert(state !== 2 /* SavingComments */, "whitespace shouldn't come from the scanner while saving top-level comment text");
                                            const whitespace = scanner2.getTokenText();
                                            if (margin !== void 0 && indent3 + whitespace.length > margin) {
                                                comments.push(whitespace.slice(margin - indent3));
                                            }
                                            indent3 += whitespace.length;
                                            break;
                                        case 1 /* EndOfFileToken */:
                                            break loop;
                                        case 82 /* JSDocCommentTextToken */:
                                            state = 2 /* SavingComments */;
                                            pushComment(scanner2.getTokenValue());
                                            break;
                                        case 19 /* OpenBraceToken */:
                                            state = 2 /* SavingComments */;
                                            const commentEnd = scanner2.getTokenFullStart();
                                            const linkStart = scanner2.getTokenEnd() - 1;
                                            const link = parseJSDocLink(linkStart);
                                            if (link) {
                                                if (!linkEnd) {
                                                    removeLeadingNewlines(comments);
                                                }
                                                parts.push(finishNode(factory2.createJSDocText(comments.join("")), linkEnd ?? start, commentEnd));
                                                parts.push(link);
                                                comments = [];
                                                linkEnd = scanner2.getTokenEnd();
                                                break;
                                            }
                                        default:
                                            state = 2 /* SavingComments */;
                                            pushComment(scanner2.getTokenText());
                                            break;
                                    }
                                    if (state === 2 /* SavingComments */) {
                                        nextJSDocCommentTextToken(
                                        /*inBackticks*/
                                        false);
                                    }
                                    else {
                                        nextTokenJSDoc();
                                    }
                                }
                                const trimmedComments = comments.join("").trimEnd();
                                if (parts.length && trimmedComments.length) {
                                    parts.push(finishNode(factory2.createJSDocText(trimmedComments), linkEnd ?? start, commentsPos));
                                }
                                if (parts.length && tags)
                                    Debug.assertIsDefined(commentsPos, "having parsed tags implies that the end of the comment span should be set");
                                const tagsArray = tags && createNodeArray(tags, tagsPos, tagsEnd);
                                return finishNode(factory2.createJSDocComment(parts.length ? createNodeArray(parts, start, commentsPos) : trimmedComments.length ? trimmedComments : void 0, tagsArray), start, end);
                            }
                            function removeLeadingNewlines(comments2) {
                                while (comments2.length && (comments2[0] === "\n" || comments2[0] === "\r")) {
                                    comments2.shift();
                                }
                            }
                            function removeTrailingWhitespace(comments2) {
                                while (comments2.length) {
                                    const trimmed = comments2[comments2.length - 1].trimEnd();
                                    if (trimmed === "") {
                                        comments2.pop();
                                    }
                                    else if (trimmed.length < comments2[comments2.length - 1].length) {
                                        comments2[comments2.length - 1] = trimmed;
                                        break;
                                    }
                                    else {
                                        break;
                                    }
                                }
                            }
                            function isNextNonwhitespaceTokenEndOfFile() {
                                while (true) {
                                    nextTokenJSDoc();
                                    if (token() === 1 /* EndOfFileToken */) {
                                        return true;
                                    }
                                    if (!(token() === 5 /* WhitespaceTrivia */ || token() === 4 /* NewLineTrivia */)) {
                                        return false;
                                    }
                                }
                            }
                            function skipWhitespace() {
                                if (token() === 5 /* WhitespaceTrivia */ || token() === 4 /* NewLineTrivia */) {
                                    if (lookAhead(isNextNonwhitespaceTokenEndOfFile)) {
                                        return;
                                    }
                                }
                                while (token() === 5 /* WhitespaceTrivia */ || token() === 4 /* NewLineTrivia */) {
                                    nextTokenJSDoc();
                                }
                            }
                            function skipWhitespaceOrAsterisk() {
                                if (token() === 5 /* WhitespaceTrivia */ || token() === 4 /* NewLineTrivia */) {
                                    if (lookAhead(isNextNonwhitespaceTokenEndOfFile)) {
                                        return "";
                                    }
                                }
                                let precedingLineBreak = scanner2.hasPrecedingLineBreak();
                                let seenLineBreak = false;
                                let indentText = "";
                                while (precedingLineBreak && token() === 42 /* AsteriskToken */ || token() === 5 /* WhitespaceTrivia */ || token() === 4 /* NewLineTrivia */) {
                                    indentText += scanner2.getTokenText();
                                    if (token() === 4 /* NewLineTrivia */) {
                                        precedingLineBreak = true;
                                        seenLineBreak = true;
                                        indentText = "";
                                    }
                                    else if (token() === 42 /* AsteriskToken */) {
                                        precedingLineBreak = false;
                                    }
                                    nextTokenJSDoc();
                                }
                                return seenLineBreak ? indentText : "";
                            }
                            function parseTag(margin) {
                                Debug.assert(token() === 60 /* AtToken */);
                                const start2 = scanner2.getTokenStart();
                                nextTokenJSDoc();
                                const tagName = parseJSDocIdentifierName(
                                /*message*/
                                void 0);
                                const indentText = skipWhitespaceOrAsterisk();
                                let tag;
                                switch (tagName.escapedText) {
                                    case "author":
                                        tag = parseAuthorTag(start2, tagName, margin, indentText);
                                        break;
                                    case "implements":
                                        tag = parseImplementsTag(start2, tagName, margin, indentText);
                                        break;
                                    case "augments":
                                    case "extends":
                                        tag = parseAugmentsTag(start2, tagName, margin, indentText);
                                        break;
                                    case "class":
                                    case "constructor":
                                        tag = parseSimpleTag(start2, factory2.createJSDocClassTag, tagName, margin, indentText);
                                        break;
                                    case "public":
                                        tag = parseSimpleTag(start2, factory2.createJSDocPublicTag, tagName, margin, indentText);
                                        break;
                                    case "private":
                                        tag = parseSimpleTag(start2, factory2.createJSDocPrivateTag, tagName, margin, indentText);
                                        break;
                                    case "protected":
                                        tag = parseSimpleTag(start2, factory2.createJSDocProtectedTag, tagName, margin, indentText);
                                        break;
                                    case "readonly":
                                        tag = parseSimpleTag(start2, factory2.createJSDocReadonlyTag, tagName, margin, indentText);
                                        break;
                                    case "override":
                                        tag = parseSimpleTag(start2, factory2.createJSDocOverrideTag, tagName, margin, indentText);
                                        break;
                                    case "deprecated":
                                        hasDeprecatedTag = true;
                                        tag = parseSimpleTag(start2, factory2.createJSDocDeprecatedTag, tagName, margin, indentText);
                                        break;
                                    case "this":
                                        tag = parseThisTag(start2, tagName, margin, indentText);
                                        break;
                                    case "enum":
                                        tag = parseEnumTag(start2, tagName, margin, indentText);
                                        break;
                                    case "arg":
                                    case "argument":
                                    case "param":
                                        return parseParameterOrPropertyTag(start2, tagName, 2 /* Parameter */, margin);
                                    case "return":
                                    case "returns":
                                        tag = parseReturnTag(start2, tagName, margin, indentText);
                                        break;
                                    case "template":
                                        tag = parseTemplateTag(start2, tagName, margin, indentText);
                                        break;
                                    case "type":
                                        tag = parseTypeTag(start2, tagName, margin, indentText);
                                        break;
                                    case "typedef":
                                        tag = parseTypedefTag(start2, tagName, margin, indentText);
                                        break;
                                    case "callback":
                                        tag = parseCallbackTag(start2, tagName, margin, indentText);
                                        break;
                                    case "overload":
                                        tag = parseOverloadTag(start2, tagName, margin, indentText);
                                        break;
                                    case "satisfies":
                                        tag = parseSatisfiesTag(start2, tagName, margin, indentText);
                                        break;
                                    case "see":
                                        tag = parseSeeTag(start2, tagName, margin, indentText);
                                        break;
                                    case "exception":
                                    case "throws":
                                        tag = parseThrowsTag(start2, tagName, margin, indentText);
                                        break;
                                    default:
                                        tag = parseUnknownTag(start2, tagName, margin, indentText);
                                        break;
                                }
                                return tag;
                            }
                            function parseTrailingTagComments(pos, end2, margin, indentText) {
                                if (!indentText) {
                                    margin += end2 - pos;
                                }
                                return parseTagComments(margin, indentText.slice(margin));
                            }
                            function parseTagComments(indent3, initialMargin) {
                                const commentsPos2 = getNodePos();
                                let comments2 = [];
                                const parts2 = [];
                                let linkEnd2;
                                let state = 0 /* BeginningOfLine */;
                                let margin;
                                function pushComment(text) {
                                    if (!margin) {
                                        margin = indent3;
                                    }
                                    comments2.push(text);
                                    indent3 += text.length;
                                }
                                if (initialMargin !== void 0) {
                                    if (initialMargin !== "") {
                                        pushComment(initialMargin);
                                    }
                                    state = 1 /* SawAsterisk */;
                                }
                                let tok = token();
                                loop: while (true) {
                                    switch (tok) {
                                        case 4 /* NewLineTrivia */:
                                            state = 0 /* BeginningOfLine */;
                                            comments2.push(scanner2.getTokenText());
                                            indent3 = 0;
                                            break;
                                        case 60 /* AtToken */:
                                            scanner2.resetTokenState(scanner2.getTokenEnd() - 1);
                                            break loop;
                                        case 1 /* EndOfFileToken */:
                                            break loop;
                                        case 5 /* WhitespaceTrivia */:
                                            Debug.assert(state !== 2 /* SavingComments */ && state !== 3 /* SavingBackticks */, "whitespace shouldn't come from the scanner while saving comment text");
                                            const whitespace = scanner2.getTokenText();
                                            if (margin !== void 0 && indent3 + whitespace.length > margin) {
                                                comments2.push(whitespace.slice(margin - indent3));
                                                state = 2 /* SavingComments */;
                                            }
                                            indent3 += whitespace.length;
                                            break;
                                        case 19 /* OpenBraceToken */:
                                            state = 2 /* SavingComments */;
                                            const commentEnd = scanner2.getTokenFullStart();
                                            const linkStart = scanner2.getTokenEnd() - 1;
                                            const link = parseJSDocLink(linkStart);
                                            if (link) {
                                                parts2.push(finishNode(factory2.createJSDocText(comments2.join("")), linkEnd2 ?? commentsPos2, commentEnd));
                                                parts2.push(link);
                                                comments2 = [];
                                                linkEnd2 = scanner2.getTokenEnd();
                                            }
                                            else {
                                                pushComment(scanner2.getTokenText());
                                            }
                                            break;
                                        case 62 /* BacktickToken */:
                                            if (state === 3 /* SavingBackticks */) {
                                                state = 2 /* SavingComments */;
                                            }
                                            else {
                                                state = 3 /* SavingBackticks */;
                                            }
                                            pushComment(scanner2.getTokenText());
                                            break;
                                        case 82 /* JSDocCommentTextToken */:
                                            if (state !== 3 /* SavingBackticks */) {
                                                state = 2 /* SavingComments */;
                                            }
                                            pushComment(scanner2.getTokenValue());
                                            break;
                                        case 42 /* AsteriskToken */:
                                            if (state === 0 /* BeginningOfLine */) {
                                                state = 1 /* SawAsterisk */;
                                                indent3 += 1;
                                                break;
                                            }
                                        default:
                                            if (state !== 3 /* SavingBackticks */) {
                                                state = 2 /* SavingComments */;
                                            }
                                            pushComment(scanner2.getTokenText());
                                            break;
                                    }
                                    if (state === 2 /* SavingComments */ || state === 3 /* SavingBackticks */) {
                                        tok = nextJSDocCommentTextToken(state === 3 /* SavingBackticks */);
                                    }
                                    else {
                                        tok = nextTokenJSDoc();
                                    }
                                }
                                removeLeadingNewlines(comments2);
                                const trimmedComments = comments2.join("").trimEnd();
                                if (parts2.length) {
                                    if (trimmedComments.length) {
                                        parts2.push(finishNode(factory2.createJSDocText(trimmedComments), linkEnd2 ?? commentsPos2));
                                    }
                                    return createNodeArray(parts2, commentsPos2, scanner2.getTokenEnd());
                                }
                                else if (trimmedComments.length) {
                                    return trimmedComments;
                                }
                            }
                            function parseJSDocLink(start2) {
                                const linkType = tryParse(parseJSDocLinkPrefix);
                                if (!linkType) {
                                    return void 0;
                                }
                                nextTokenJSDoc();
                                skipWhitespace();
                                const name = parseJSDocLinkName();
                                const text = [];
                                while (token() !== 20 /* CloseBraceToken */ && token() !== 4 /* NewLineTrivia */ && token() !== 1 /* EndOfFileToken */) {
                                    text.push(scanner2.getTokenText());
                                    nextTokenJSDoc();
                                }
                                const create = linkType === "link" ? factory2.createJSDocLink : linkType === "linkcode" ? factory2.createJSDocLinkCode : factory2.createJSDocLinkPlain;
                                return finishNode(create(name, text.join("")), start2, scanner2.getTokenEnd());
                            }
                            function parseJSDocLinkName() {
                                if (tokenIsIdentifierOrKeyword(token())) {
                                    const pos = getNodePos();
                                    let name = parseIdentifierName();
                                    while (parseOptional(25 /* DotToken */)) {
                                        name = finishNode(factory2.createQualifiedName(name, token() === 81 /* PrivateIdentifier */ ? createMissingNode(80 /* Identifier */, 
                                        /*reportAtCurrentPosition*/
                                        false) : parseIdentifier()), pos);
                                    }
                                    while (token() === 81 /* PrivateIdentifier */) {
                                        reScanHashToken();
                                        nextTokenJSDoc();
                                        name = finishNode(factory2.createJSDocMemberName(name, parseIdentifier()), pos);
                                    }
                                    return name;
                                }
                                return void 0;
                            }
                            function parseJSDocLinkPrefix() {
                                skipWhitespaceOrAsterisk();
                                if (token() === 19 /* OpenBraceToken */ && nextTokenJSDoc() === 60 /* AtToken */ && tokenIsIdentifierOrKeyword(nextTokenJSDoc())) {
                                    const kind = scanner2.getTokenValue();
                                    if (isJSDocLinkTag(kind))
                                        return kind;
                                }
                            }
                            function isJSDocLinkTag(kind) {
                                return kind === "link" || kind === "linkcode" || kind === "linkplain";
                            }
                            function parseUnknownTag(start2, tagName, indent3, indentText) {
                                return finishNode(factory2.createJSDocUnknownTag(tagName, parseTrailingTagComments(start2, getNodePos(), indent3, indentText)), start2);
                            }
                            function addTag(tag) {
                                if (!tag) {
                                    return;
                                }
                                if (!tags) {
                                    tags = [tag];
                                    tagsPos = tag.pos;
                                }
                                else {
                                    tags.push(tag);
                                }
                                tagsEnd = tag.end;
                            }
                            function tryParseTypeExpression() {
                                skipWhitespaceOrAsterisk();
                                return token() === 19 /* OpenBraceToken */ ? parseJSDocTypeExpression() : void 0;
                            }
                            function parseBracketNameInPropertyAndParamTag() {
                                const isBracketed = parseOptionalJsdoc(23 /* OpenBracketToken */);
                                if (isBracketed) {
                                    skipWhitespace();
                                }
                                const isBackquoted = parseOptionalJsdoc(62 /* BacktickToken */);
                                const name = parseJSDocEntityName();
                                if (isBackquoted) {
                                    parseExpectedTokenJSDoc(62 /* BacktickToken */);
                                }
                                if (isBracketed) {
                                    skipWhitespace();
                                    if (parseOptionalToken(64 /* EqualsToken */)) {
                                        parseExpression();
                                    }
                                    parseExpected(24 /* CloseBracketToken */);
                                }
                                return { name, isBracketed };
                            }
                            function isObjectOrObjectArrayTypeReference(node) {
                                switch (node.kind) {
                                    case 151 /* ObjectKeyword */:
                                        return true;
                                    case 188 /* ArrayType */:
                                        return isObjectOrObjectArrayTypeReference(node.elementType);
                                    default:
                                        return isTypeReferenceNode(node) && isIdentifier(node.typeName) && node.typeName.escapedText === "Object" && !node.typeArguments;
                                }
                            }
                            function parseParameterOrPropertyTag(start2, tagName, target, indent3) {
                                let typeExpression = tryParseTypeExpression();
                                let isNameFirst = !typeExpression;
                                skipWhitespaceOrAsterisk();
                                const { name, isBracketed } = parseBracketNameInPropertyAndParamTag();
                                const indentText = skipWhitespaceOrAsterisk();
                                if (isNameFirst && !lookAhead(parseJSDocLinkPrefix)) {
                                    typeExpression = tryParseTypeExpression();
                                }
                                const comment = parseTrailingTagComments(start2, getNodePos(), indent3, indentText);
                                const nestedTypeLiteral = parseNestedTypeLiteral(typeExpression, name, target, indent3);
                                if (nestedTypeLiteral) {
                                    typeExpression = nestedTypeLiteral;
                                    isNameFirst = true;
                                }
                                const result2 = target === 1 /* Property */ ? factory2.createJSDocPropertyTag(tagName, name, isBracketed, typeExpression, isNameFirst, comment) : factory2.createJSDocParameterTag(tagName, name, isBracketed, typeExpression, isNameFirst, comment);
                                return finishNode(result2, start2);
                            }
                            function parseNestedTypeLiteral(typeExpression, name, target, indent3) {
                                if (typeExpression && isObjectOrObjectArrayTypeReference(typeExpression.type)) {
                                    const pos = getNodePos();
                                    let child;
                                    let children;
                                    while (child = tryParse(() => parseChildParameterOrPropertyTag(target, indent3, name))) {
                                        if (child.kind === 348 /* JSDocParameterTag */ || child.kind === 355 /* JSDocPropertyTag */) {
                                            children = append(children, child);
                                        }
                                        else if (child.kind === 352 /* JSDocTemplateTag */) {
                                            parseErrorAtRange(child.tagName, Diagnostics.A_JSDoc_template_tag_may_not_follow_a_typedef_callback_or_overload_tag);
                                        }
                                    }
                                    if (children) {
                                        const literal = finishNode(factory2.createJSDocTypeLiteral(children, typeExpression.type.kind === 188 /* ArrayType */), pos);
                                        return finishNode(factory2.createJSDocTypeExpression(literal), pos);
                                    }
                                }
                            }
                            function parseReturnTag(start2, tagName, indent3, indentText) {
                                if (some(tags, isJSDocReturnTag)) {
                                    parseErrorAt(tagName.pos, scanner2.getTokenStart(), Diagnostics._0_tag_already_specified, unescapeLeadingUnderscores(tagName.escapedText));
                                }
                                const typeExpression = tryParseTypeExpression();
                                return finishNode(factory2.createJSDocReturnTag(tagName, typeExpression, parseTrailingTagComments(start2, getNodePos(), indent3, indentText)), start2);
                            }
                            function parseTypeTag(start2, tagName, indent3, indentText) {
                                if (some(tags, isJSDocTypeTag)) {
                                    parseErrorAt(tagName.pos, scanner2.getTokenStart(), Diagnostics._0_tag_already_specified, unescapeLeadingUnderscores(tagName.escapedText));
                                }
                                const typeExpression = parseJSDocTypeExpression(
                                /*mayOmitBraces*/
                                true);
                                const comments2 = indent3 !== void 0 && indentText !== void 0 ? parseTrailingTagComments(start2, getNodePos(), indent3, indentText) : void 0;
                                return finishNode(factory2.createJSDocTypeTag(tagName, typeExpression, comments2), start2);
                            }
                            function parseSeeTag(start2, tagName, indent3, indentText) {
                                const isMarkdownOrJSDocLink = token() === 23 /* OpenBracketToken */ || lookAhead(() => nextTokenJSDoc() === 60 /* AtToken */ && tokenIsIdentifierOrKeyword(nextTokenJSDoc()) && isJSDocLinkTag(scanner2.getTokenValue()));
                                const nameExpression = isMarkdownOrJSDocLink ? void 0 : parseJSDocNameReference();
                                const comments2 = indent3 !== void 0 && indentText !== void 0 ? parseTrailingTagComments(start2, getNodePos(), indent3, indentText) : void 0;
                                return finishNode(factory2.createJSDocSeeTag(tagName, nameExpression, comments2), start2);
                            }
                            function parseThrowsTag(start2, tagName, indent3, indentText) {
                                const typeExpression = tryParseTypeExpression();
                                const comment = parseTrailingTagComments(start2, getNodePos(), indent3, indentText);
                                return finishNode(factory2.createJSDocThrowsTag(tagName, typeExpression, comment), start2);
                            }
                            function parseAuthorTag(start2, tagName, indent3, indentText) {
                                const commentStart = getNodePos();
                                const textOnly = parseAuthorNameAndEmail();
                                let commentEnd = scanner2.getTokenFullStart();
                                const comments2 = parseTrailingTagComments(start2, commentEnd, indent3, indentText);
                                if (!comments2) {
                                    commentEnd = scanner2.getTokenFullStart();
                                }
                                const allParts = typeof comments2 !== "string" ? createNodeArray(concatenate([finishNode(textOnly, commentStart, commentEnd)], comments2), commentStart) : textOnly.text + comments2;
                                return finishNode(factory2.createJSDocAuthorTag(tagName, allParts), start2);
                            }
                            function parseAuthorNameAndEmail() {
                                const comments2 = [];
                                let inEmail = false;
                                let token2 = scanner2.getToken();
                                while (token2 !== 1 /* EndOfFileToken */ && token2 !== 4 /* NewLineTrivia */) {
                                    if (token2 === 30 /* LessThanToken */) {
                                        inEmail = true;
                                    }
                                    else if (token2 === 60 /* AtToken */ && !inEmail) {
                                        break;
                                    }
                                    else if (token2 === 32 /* GreaterThanToken */ && inEmail) {
                                        comments2.push(scanner2.getTokenText());
                                        scanner2.resetTokenState(scanner2.getTokenEnd());
                                        break;
                                    }
                                    comments2.push(scanner2.getTokenText());
                                    token2 = nextTokenJSDoc();
                                }
                                return factory2.createJSDocText(comments2.join(""));
                            }
                            function parseImplementsTag(start2, tagName, margin, indentText) {
                                const className = parseExpressionWithTypeArgumentsForAugments();
                                return finishNode(factory2.createJSDocImplementsTag(tagName, className, parseTrailingTagComments(start2, getNodePos(), margin, indentText)), start2);
                            }
                            function parseAugmentsTag(start2, tagName, margin, indentText) {
                                const className = parseExpressionWithTypeArgumentsForAugments();
                                return finishNode(factory2.createJSDocAugmentsTag(tagName, className, parseTrailingTagComments(start2, getNodePos(), margin, indentText)), start2);
                            }
                            function parseSatisfiesTag(start2, tagName, margin, indentText) {
                                const typeExpression = parseJSDocTypeExpression(
                                /*mayOmitBraces*/
                                false);
                                const comments2 = margin !== void 0 && indentText !== void 0 ? parseTrailingTagComments(start2, getNodePos(), margin, indentText) : void 0;
                                return finishNode(factory2.createJSDocSatisfiesTag(tagName, typeExpression, comments2), start2);
                            }
                            function parseExpressionWithTypeArgumentsForAugments() {
                                const usedBrace = parseOptional(19 /* OpenBraceToken */);
                                const pos = getNodePos();
                                const expression = parsePropertyAccessEntityNameExpression();
                                scanner2.setInJSDocType(true);
                                const typeArguments = tryParseTypeArguments();
                                scanner2.setInJSDocType(false);
                                const node = factory2.createExpressionWithTypeArguments(expression, typeArguments);
                                const res = finishNode(node, pos);
                                if (usedBrace) {
                                    parseExpected(20 /* CloseBraceToken */);
                                }
                                return res;
                            }
                            function parsePropertyAccessEntityNameExpression() {
                                const pos = getNodePos();
                                let node = parseJSDocIdentifierName();
                                while (parseOptional(25 /* DotToken */)) {
                                    const name = parseJSDocIdentifierName();
                                    node = finishNode(factoryCreatePropertyAccessExpression(node, name), pos);
                                }
                                return node;
                            }
                            function parseSimpleTag(start2, createTag, tagName, margin, indentText) {
                                return finishNode(createTag(tagName, parseTrailingTagComments(start2, getNodePos(), margin, indentText)), start2);
                            }
                            function parseThisTag(start2, tagName, margin, indentText) {
                                const typeExpression = parseJSDocTypeExpression(
                                /*mayOmitBraces*/
                                true);
                                skipWhitespace();
                                return finishNode(factory2.createJSDocThisTag(tagName, typeExpression, parseTrailingTagComments(start2, getNodePos(), margin, indentText)), start2);
                            }
                            function parseEnumTag(start2, tagName, margin, indentText) {
                                const typeExpression = parseJSDocTypeExpression(
                                /*mayOmitBraces*/
                                true);
                                skipWhitespace();
                                return finishNode(factory2.createJSDocEnumTag(tagName, typeExpression, parseTrailingTagComments(start2, getNodePos(), margin, indentText)), start2);
                            }
                            function parseTypedefTag(start2, tagName, indent3, indentText) {
                                let typeExpression = tryParseTypeExpression();
                                skipWhitespaceOrAsterisk();
                                const fullName = parseJSDocTypeNameWithNamespace();
                                skipWhitespace();
                                let comment = parseTagComments(indent3);
                                let end2;
                                if (!typeExpression || isObjectOrObjectArrayTypeReference(typeExpression.type)) {
                                    let child;
                                    let childTypeTag;
                                    let jsDocPropertyTags;
                                    let hasChildren = false;
                                    while (child = tryParse(() => parseChildPropertyTag(indent3))) {
                                        if (child.kind === 352 /* JSDocTemplateTag */) {
                                            break;
                                        }
                                        hasChildren = true;
                                        if (child.kind === 351 /* JSDocTypeTag */) {
                                            if (childTypeTag) {
                                                const lastError = parseErrorAtCurrentToken(Diagnostics.A_JSDoc_typedef_comment_may_not_contain_multiple_type_tags);
                                                if (lastError) {
                                                    addRelatedInfo(lastError, createDetachedDiagnostic(fileName, sourceText, 0, 0, Diagnostics.The_tag_was_first_specified_here));
                                                }
                                                break;
                                            }
                                            else {
                                                childTypeTag = child;
                                            }
                                        }
                                        else {
                                            jsDocPropertyTags = append(jsDocPropertyTags, child);
                                        }
                                    }
                                    if (hasChildren) {
                                        const isArrayType = typeExpression && typeExpression.type.kind === 188 /* ArrayType */;
                                        const jsdocTypeLiteral = factory2.createJSDocTypeLiteral(jsDocPropertyTags, isArrayType);
                                        typeExpression = childTypeTag && childTypeTag.typeExpression && !isObjectOrObjectArrayTypeReference(childTypeTag.typeExpression.type) ? childTypeTag.typeExpression : finishNode(jsdocTypeLiteral, start2);
                                        end2 = typeExpression.end;
                                    }
                                }
                                end2 = end2 || comment !== void 0 ? getNodePos() : (fullName ?? typeExpression ?? tagName).end;
                                if (!comment) {
                                    comment = parseTrailingTagComments(start2, end2, indent3, indentText);
                                }
                                const typedefTag = factory2.createJSDocTypedefTag(tagName, typeExpression, fullName, comment);
                                return finishNode(typedefTag, start2, end2);
                            }
                            function parseJSDocTypeNameWithNamespace(nested) {
                                const start2 = scanner2.getTokenStart();
                                if (!tokenIsIdentifierOrKeyword(token())) {
                                    return void 0;
                                }
                                const typeNameOrNamespaceName = parseJSDocIdentifierName();
                                if (parseOptional(25 /* DotToken */)) {
                                    const body = parseJSDocTypeNameWithNamespace(
                                    /*nested*/
                                    true);
                                    const jsDocNamespaceNode = factory2.createModuleDeclaration(
                                    /*modifiers*/
                                    void 0, typeNameOrNamespaceName, body, nested ? 8 /* NestedNamespace */ : void 0);
                                    return finishNode(jsDocNamespaceNode, start2);
                                }
                                if (nested) {
                                    typeNameOrNamespaceName.flags |= 4096 /* IdentifierIsInJSDocNamespace */;
                                }
                                return typeNameOrNamespaceName;
                            }
                            function parseCallbackTagParameters(indent3) {
                                const pos = getNodePos();
                                let child;
                                let parameters;
                                while (child = tryParse(() => parseChildParameterOrPropertyTag(4 /* CallbackParameter */, indent3))) {
                                    if (child.kind === 352 /* JSDocTemplateTag */) {
                                        parseErrorAtRange(child.tagName, Diagnostics.A_JSDoc_template_tag_may_not_follow_a_typedef_callback_or_overload_tag);
                                        break;
                                    }
                                    parameters = append(parameters, child);
                                }
                                return createNodeArray(parameters || [], pos);
                            }
                            function parseJSDocSignature(start2, indent3) {
                                const parameters = parseCallbackTagParameters(indent3);
                                const returnTag = tryParse(() => {
                                    if (parseOptionalJsdoc(60 /* AtToken */)) {
                                        const tag = parseTag(indent3);
                                        if (tag && tag.kind === 349 /* JSDocReturnTag */) {
                                            return tag;
                                        }
                                    }
                                });
                                return finishNode(factory2.createJSDocSignature(
                                /*typeParameters*/
                                void 0, parameters, returnTag), start2);
                            }
                            function parseCallbackTag(start2, tagName, indent3, indentText) {
                                const fullName = parseJSDocTypeNameWithNamespace();
                                skipWhitespace();
                                let comment = parseTagComments(indent3);
                                const typeExpression = parseJSDocSignature(start2, indent3);
                                if (!comment) {
                                    comment = parseTrailingTagComments(start2, getNodePos(), indent3, indentText);
                                }
                                const end2 = comment !== void 0 ? getNodePos() : typeExpression.end;
                                return finishNode(factory2.createJSDocCallbackTag(tagName, typeExpression, fullName, comment), start2, end2);
                            }
                            function parseOverloadTag(start2, tagName, indent3, indentText) {
                                skipWhitespace();
                                let comment = parseTagComments(indent3);
                                const typeExpression = parseJSDocSignature(start2, indent3);
                                if (!comment) {
                                    comment = parseTrailingTagComments(start2, getNodePos(), indent3, indentText);
                                }
                                const end2 = comment !== void 0 ? getNodePos() : typeExpression.end;
                                return finishNode(factory2.createJSDocOverloadTag(tagName, typeExpression, comment), start2, end2);
                            }
                            function escapedTextsEqual(a, b) {
                                while (!isIdentifier(a) || !isIdentifier(b)) {
                                    if (!isIdentifier(a) && !isIdentifier(b) && a.right.escapedText === b.right.escapedText) {
                                        a = a.left;
                                        b = b.left;
                                    }
                                    else {
                                        return false;
                                    }
                                }
                                return a.escapedText === b.escapedText;
                            }
                            function parseChildPropertyTag(indent3) {
                                return parseChildParameterOrPropertyTag(1 /* Property */, indent3);
                            }
                            function parseChildParameterOrPropertyTag(target, indent3, name) {
                                let canParseTag = true;
                                let seenAsterisk = false;
                                while (true) {
                                    switch (nextTokenJSDoc()) {
                                        case 60 /* AtToken */:
                                            if (canParseTag) {
                                                const child = tryParseChildTag(target, indent3);
                                                if (child && (child.kind === 348 /* JSDocParameterTag */ || child.kind === 355 /* JSDocPropertyTag */) && name && (isIdentifier(child.name) || !escapedTextsEqual(name, child.name.left))) {
                                                    return false;
                                                }
                                                return child;
                                            }
                                            seenAsterisk = false;
                                            break;
                                        case 4 /* NewLineTrivia */:
                                            canParseTag = true;
                                            seenAsterisk = false;
                                            break;
                                        case 42 /* AsteriskToken */:
                                            if (seenAsterisk) {
                                                canParseTag = false;
                                            }
                                            seenAsterisk = true;
                                            break;
                                        case 80 /* Identifier */:
                                            canParseTag = false;
                                            break;
                                        case 1 /* EndOfFileToken */:
                                            return false;
                                    }
                                }
                            }
                            function tryParseChildTag(target, indent3) {
                                Debug.assert(token() === 60 /* AtToken */);
                                const start2 = scanner2.getTokenFullStart();
                                nextTokenJSDoc();
                                const tagName = parseJSDocIdentifierName();
                                const indentText = skipWhitespaceOrAsterisk();
                                let t;
                                switch (tagName.escapedText) {
                                    case "type":
                                        return target === 1 /* Property */ && parseTypeTag(start2, tagName);
                                    case "prop":
                                    case "property":
                                        t = 1 /* Property */;
                                        break;
                                    case "arg":
                                    case "argument":
                                    case "param":
                                        t = 2 /* Parameter */ | 4 /* CallbackParameter */;
                                        break;
                                    case "template":
                                        return parseTemplateTag(start2, tagName, indent3, indentText);
                                    case "this":
                                        return parseThisTag(start2, tagName, indent3, indentText);
                                    default:
                                        return false;
                                }
                                if (!(target & t)) {
                                    return false;
                                }
                                return parseParameterOrPropertyTag(start2, tagName, target, indent3);
                            }
                            function parseTemplateTagTypeParameter() {
                                const typeParameterPos = getNodePos();
                                const isBracketed = parseOptionalJsdoc(23 /* OpenBracketToken */);
                                if (isBracketed) {
                                    skipWhitespace();
                                }
                                const modifiers = parseModifiers(
                                /*allowDecorators*/
                                false, 
                                /*permitConstAsModifier*/
                                true);
                                const name = parseJSDocIdentifierName(Diagnostics.Unexpected_token_A_type_parameter_name_was_expected_without_curly_braces);
                                let defaultType;
                                if (isBracketed) {
                                    skipWhitespace();
                                    parseExpected(64 /* EqualsToken */);
                                    defaultType = doInsideOfContext(16777216 /* JSDoc */, parseJSDocType);
                                    parseExpected(24 /* CloseBracketToken */);
                                }
                                if (nodeIsMissing(name)) {
                                    return void 0;
                                }
                                return finishNode(factory2.createTypeParameterDeclaration(modifiers, name, 
                                /*constraint*/
                                void 0, defaultType), typeParameterPos);
                            }
                            function parseTemplateTagTypeParameters() {
                                const pos = getNodePos();
                                const typeParameters = [];
                                do {
                                    skipWhitespace();
                                    const node = parseTemplateTagTypeParameter();
                                    if (node !== void 0) {
                                        typeParameters.push(node);
                                    }
                                    skipWhitespaceOrAsterisk();
                                } while (parseOptionalJsdoc(28 /* CommaToken */));
                                return createNodeArray(typeParameters, pos);
                            }
                            function parseTemplateTag(start2, tagName, indent3, indentText) {
                                const constraint = token() === 19 /* OpenBraceToken */ ? parseJSDocTypeExpression() : void 0;
                                const typeParameters = parseTemplateTagTypeParameters();
                                return finishNode(factory2.createJSDocTemplateTag(tagName, constraint, typeParameters, parseTrailingTagComments(start2, getNodePos(), indent3, indentText)), start2);
                            }
                            function parseOptionalJsdoc(t) {
                                if (token() === t) {
                                    nextTokenJSDoc();
                                    return true;
                                }
                                return false;
                            }
                            function parseJSDocEntityName() {
                                let entity = parseJSDocIdentifierName();
                                if (parseOptional(23 /* OpenBracketToken */)) {
                                    parseExpected(24 /* CloseBracketToken */);
                                }
                                while (parseOptional(25 /* DotToken */)) {
                                    const name = parseJSDocIdentifierName();
                                    if (parseOptional(23 /* OpenBracketToken */)) {
                                        parseExpected(24 /* CloseBracketToken */);
                                    }
                                    entity = createQualifiedName(entity, name);
                                }
                                return entity;
                            }
                            function parseJSDocIdentifierName(message) {
                                if (!tokenIsIdentifierOrKeyword(token())) {
                                    return createMissingNode(80 /* Identifier */, 
                                    /*reportAtCurrentPosition*/
                                    !message, message || Diagnostics.Identifier_expected);
                                }
                                identifierCount++;
                                const start2 = scanner2.getTokenStart();
                                const end2 = scanner2.getTokenEnd();
                                const originalKeywordKind = token();
                                const text = internIdentifier(scanner2.getTokenValue());
                                const result2 = finishNode(factoryCreateIdentifier(text, originalKeywordKind), start2, end2);
                                nextTokenJSDoc();
                                return result2;
                            }
                        }
                    })(JSDocParser = Parser2.JSDocParser || (Parser2.JSDocParser = {}));
                })(Parser || (Parser = {}));
                ((IncrementalParser2) => {
                    function updateSourceFile2(sourceFile, newText, textChangeRange, aggressiveChecks) {
                        aggressiveChecks = aggressiveChecks || Debug.shouldAssert(2 /* Aggressive */);
                        checkChangeRange(sourceFile, newText, textChangeRange, aggressiveChecks);
                        if (textChangeRangeIsUnchanged(textChangeRange)) {
                            return sourceFile;
                        }
                        if (sourceFile.statements.length === 0) {
                            return Parser.parseSourceFile(sourceFile.fileName, newText, sourceFile.languageVersion, 
                            /*syntaxCursor*/
                            void 0, 
                            /*setParentNodes*/
                            true, sourceFile.scriptKind, sourceFile.setExternalModuleIndicator, sourceFile.jsDocParsingMode);
                        }
                        const incrementalSourceFile = sourceFile;
                        Debug.assert(!incrementalSourceFile.hasBeenIncrementallyParsed);
                        incrementalSourceFile.hasBeenIncrementallyParsed = true;
                        Parser.fixupParentReferences(incrementalSourceFile);
                        const oldText = sourceFile.text;
                        const syntaxCursor = createSyntaxCursor(sourceFile);
                        const changeRange = extendToAffectedRange(sourceFile, textChangeRange);
                        checkChangeRange(sourceFile, newText, changeRange, aggressiveChecks);
                        Debug.assert(changeRange.span.start <= textChangeRange.span.start);
                        Debug.assert(textSpanEnd(changeRange.span) === textSpanEnd(textChangeRange.span));
                        Debug.assert(textSpanEnd(textChangeRangeNewSpan(changeRange)) === textSpanEnd(textChangeRangeNewSpan(textChangeRange)));
                        const delta = textChangeRangeNewSpan(changeRange).length - changeRange.span.length;
                        updateTokenPositionsAndMarkElements(incrementalSourceFile, changeRange.span.start, textSpanEnd(changeRange.span), textSpanEnd(textChangeRangeNewSpan(changeRange)), delta, oldText, newText, aggressiveChecks);
                        const result = Parser.parseSourceFile(sourceFile.fileName, newText, sourceFile.languageVersion, syntaxCursor, 
                        /*setParentNodes*/
                        true, sourceFile.scriptKind, sourceFile.setExternalModuleIndicator, sourceFile.jsDocParsingMode);
                        result.commentDirectives = getNewCommentDirectives(sourceFile.commentDirectives, result.commentDirectives, changeRange.span.start, textSpanEnd(changeRange.span), delta, oldText, newText, aggressiveChecks);
                        result.impliedNodeFormat = sourceFile.impliedNodeFormat;
                        return result;
                    }
                    IncrementalParser2.updateSourceFile = updateSourceFile2;
                    function getNewCommentDirectives(oldDirectives, newDirectives, changeStart, changeRangeOldEnd, delta, oldText, newText, aggressiveChecks) {
                        if (!oldDirectives)
                            return newDirectives;
                        let commentDirectives;
                        let addedNewlyScannedDirectives = false;
                        for (const directive of oldDirectives) {
                            const { range, type } = directive;
                            if (range.end < changeStart) {
                                commentDirectives = append(commentDirectives, directive);
                            }
                            else if (range.pos > changeRangeOldEnd) {
                                addNewlyScannedDirectives();
                                const updatedDirective = {
                                    range: { pos: range.pos + delta, end: range.end + delta },
                                    type
                                };
                                commentDirectives = append(commentDirectives, updatedDirective);
                                if (aggressiveChecks) {
                                    Debug.assert(oldText.substring(range.pos, range.end) === newText.substring(updatedDirective.range.pos, updatedDirective.range.end));
                                }
                            }
                        }
                        addNewlyScannedDirectives();
                        return commentDirectives;
                        function addNewlyScannedDirectives() {
                            if (addedNewlyScannedDirectives)
                                return;
                            addedNewlyScannedDirectives = true;
                            if (!commentDirectives) {
                                commentDirectives = newDirectives;
                            }
                            else if (newDirectives) {
                                commentDirectives.push(...newDirectives);
                            }
                        }
                    }
                    function moveElementEntirelyPastChangeRange(element, isArray2, delta, oldText, newText, aggressiveChecks) {
                        if (isArray2) {
                            visitArray2(element);
                        }
                        else {
                            visitNode3(element);
                        }
                        return;
                        function visitNode3(node) {
                            let text = "";
                            if (aggressiveChecks && shouldCheckNode(node)) {
                                text = oldText.substring(node.pos, node.end);
                            }
                            if (node._children) {
                                node._children = void 0;
                            }
                            setTextRangePosEnd(node, node.pos + delta, node.end + delta);
                            if (aggressiveChecks && shouldCheckNode(node)) {
                                Debug.assert(text === newText.substring(node.pos, node.end));
                            }
                            forEachChild(node, visitNode3, visitArray2);
                            if (hasJSDocNodes(node)) {
                                for (const jsDocComment of node.jsDoc) {
                                    visitNode3(jsDocComment);
                                }
                            }
                            checkNodePositions(node, aggressiveChecks);
                        }
                        function visitArray2(array) {
                            array._children = void 0;
                            setTextRangePosEnd(array, array.pos + delta, array.end + delta);
                            for (const node of array) {
                                visitNode3(node);
                            }
                        }
                    }
                    function shouldCheckNode(node) {
                        switch (node.kind) {
                            case 11 /* StringLiteral */:
                            case 9 /* NumericLiteral */:
                            case 80 /* Identifier */:
                                return true;
                        }
                        return false;
                    }
                    function adjustIntersectingElement(element, changeStart, changeRangeOldEnd, changeRangeNewEnd, delta) {
                        Debug.assert(element.end >= changeStart, "Adjusting an element that was entirely before the change range");
                        Debug.assert(element.pos <= changeRangeOldEnd, "Adjusting an element that was entirely after the change range");
                        Debug.assert(element.pos <= element.end);
                        const pos = Math.min(element.pos, changeRangeNewEnd);
                        const end = element.end >= changeRangeOldEnd ? (
                        // Element ends after the change range.  Always adjust the end pos.
                        element.end + delta) : (
                        // Element ends in the change range.  The element will keep its position if
                        // possible. Or Move backward to the new-end if it's in the 'Y' range.
                        Math.min(element.end, changeRangeNewEnd));
                        Debug.assert(pos <= end);
                        if (element.parent) {
                            Debug.assertGreaterThanOrEqual(pos, element.parent.pos);
                            Debug.assertLessThanOrEqual(end, element.parent.end);
                        }
                        setTextRangePosEnd(element, pos, end);
                    }
                    function checkNodePositions(node, aggressiveChecks) {
                        if (aggressiveChecks) {
                            let pos = node.pos;
                            const visitNode3 = (child) => {
                                Debug.assert(child.pos >= pos);
                                pos = child.end;
                            };
                            if (hasJSDocNodes(node)) {
                                for (const jsDocComment of node.jsDoc) {
                                    visitNode3(jsDocComment);
                                }
                            }
                            forEachChild(node, visitNode3);
                            Debug.assert(pos <= node.end);
                        }
                    }
                    function updateTokenPositionsAndMarkElements(sourceFile, changeStart, changeRangeOldEnd, changeRangeNewEnd, delta, oldText, newText, aggressiveChecks) {
                        visitNode3(sourceFile);
                        return;
                        function visitNode3(child) {
                            Debug.assert(child.pos <= child.end);
                            if (child.pos > changeRangeOldEnd) {
                                moveElementEntirelyPastChangeRange(child, 
                                /*isArray*/
                                false, delta, oldText, newText, aggressiveChecks);
                                return;
                            }
                            const fullEnd = child.end;
                            if (fullEnd >= changeStart) {
                                child.intersectsChange = true;
                                child._children = void 0;
                                adjustIntersectingElement(child, changeStart, changeRangeOldEnd, changeRangeNewEnd, delta);
                                forEachChild(child, visitNode3, visitArray2);
                                if (hasJSDocNodes(child)) {
                                    for (const jsDocComment of child.jsDoc) {
                                        visitNode3(jsDocComment);
                                    }
                                }
                                checkNodePositions(child, aggressiveChecks);
                                return;
                            }
                            Debug.assert(fullEnd < changeStart);
                        }
                        function visitArray2(array) {
                            Debug.assert(array.pos <= array.end);
                            if (array.pos > changeRangeOldEnd) {
                                moveElementEntirelyPastChangeRange(array, 
                                /*isArray*/
                                true, delta, oldText, newText, aggressiveChecks);
                                return;
                            }
                            const fullEnd = array.end;
                            if (fullEnd >= changeStart) {
                                array.intersectsChange = true;
                                array._children = void 0;
                                adjustIntersectingElement(array, changeStart, changeRangeOldEnd, changeRangeNewEnd, delta);
                                for (const node of array) {
                                    visitNode3(node);
                                }
                                return;
                            }
                            Debug.assert(fullEnd < changeStart);
                        }
                    }
                    function extendToAffectedRange(sourceFile, changeRange) {
                        const maxLookahead = 1;
                        let start = changeRange.span.start;
                        for (let i = 0; start > 0 && i <= maxLookahead; i++) {
                            const nearestNode = findNearestNodeStartingBeforeOrAtPosition(sourceFile, start);
                            Debug.assert(nearestNode.pos <= start);
                            const position = nearestNode.pos;
                            start = Math.max(0, position - 1);
                        }
                        const finalSpan = createTextSpanFromBounds(start, textSpanEnd(changeRange.span));
                        const finalLength = changeRange.newLength + (changeRange.span.start - start);
                        return createTextChangeRange(finalSpan, finalLength);
                    }
                    function findNearestNodeStartingBeforeOrAtPosition(sourceFile, position) {
                        let bestResult = sourceFile;
                        let lastNodeEntirelyBeforePosition;
                        forEachChild(sourceFile, visit);
                        if (lastNodeEntirelyBeforePosition) {
                            const lastChildOfLastEntireNodeBeforePosition = getLastDescendant(lastNodeEntirelyBeforePosition);
                            if (lastChildOfLastEntireNodeBeforePosition.pos > bestResult.pos) {
                                bestResult = lastChildOfLastEntireNodeBeforePosition;
                            }
                        }
                        return bestResult;
                        function getLastDescendant(node) {
                            while (true) {
                                const lastChild = getLastChild(node);
                                if (lastChild) {
                                    node = lastChild;
                                }
                                else {
                                    return node;
                                }
                            }
                        }
                        function visit(child) {
                            if (nodeIsMissing(child)) {
                                return;
                            }
                            if (child.pos <= position) {
                                if (child.pos >= bestResult.pos) {
                                    bestResult = child;
                                }
                                if (position < child.end) {
                                    forEachChild(child, visit);
                                    return true;
                                }
                                else {
                                    Debug.assert(child.end <= position);
                                    lastNodeEntirelyBeforePosition = child;
                                }
                            }
                            else {
                                Debug.assert(child.pos > position);
                                return true;
                            }
                        }
                    }
                    function checkChangeRange(sourceFile, newText, textChangeRange, aggressiveChecks) {
                        const oldText = sourceFile.text;
                        if (textChangeRange) {
                            Debug.assert(oldText.length - textChangeRange.span.length + textChangeRange.newLength === newText.length);
                            if (aggressiveChecks || Debug.shouldAssert(3 /* VeryAggressive */)) {
                                const oldTextPrefix = oldText.substr(0, textChangeRange.span.start);
                                const newTextPrefix = newText.substr(0, textChangeRange.span.start);
                                Debug.assert(oldTextPrefix === newTextPrefix);
                                const oldTextSuffix = oldText.substring(textSpanEnd(textChangeRange.span), oldText.length);
                                const newTextSuffix = newText.substring(textSpanEnd(textChangeRangeNewSpan(textChangeRange)), newText.length);
                                Debug.assert(oldTextSuffix === newTextSuffix);
                            }
                        }
                    }
                    function createSyntaxCursor(sourceFile) {
                        let currentArray = sourceFile.statements;
                        let currentArrayIndex = 0;
                        Debug.assert(currentArrayIndex < currentArray.length);
                        let current = currentArray[currentArrayIndex];
                        let lastQueriedPosition = -1 /* Value */;
                        return {
                            currentNode(position) {
                                if (position !== lastQueriedPosition) {
                                    if (current && current.end === position && currentArrayIndex < currentArray.length - 1) {
                                        currentArrayIndex++;
                                        current = currentArray[currentArrayIndex];
                                    }
                                    if (!current || current.pos !== position) {
                                        findHighestListElementThatStartsAtPosition(position);
                                    }
                                }
                                lastQueriedPosition = position;
                                Debug.assert(!current || current.pos === position);
                                return current;
                            }
                        };
                        function findHighestListElementThatStartsAtPosition(position) {
                            currentArray = void 0;
                            currentArrayIndex = -1 /* Value */;
                            current = void 0;
                            forEachChild(sourceFile, visitNode3, visitArray2);
                            return;
                            function visitNode3(node) {
                                if (position >= node.pos && position < node.end) {
                                    forEachChild(node, visitNode3, visitArray2);
                                    return true;
                                }
                                return false;
                            }
                            function visitArray2(array) {
                                if (position >= array.pos && position < array.end) {
                                    for (let i = 0; i < array.length; i++) {
                                        const child = array[i];
                                        if (child) {
                                            if (child.pos === position) {
                                                currentArray = array;
                                                currentArrayIndex = i;
                                                current = child;
                                                return true;
                                            }
                                            else {
                                                if (child.pos < position && position < child.end) {
                                                    forEachChild(child, visitNode3, visitArray2);
                                                    return true;
                                                }
                                            }
                                        }
                                    }
                                }
                                return false;
                            }
                        }
                    }
                    IncrementalParser2.createSyntaxCursor = createSyntaxCursor;
                    let InvalidPosition;
                    ((InvalidPosition2) => {
                        InvalidPosition2[InvalidPosition2["Value"] = -1] = "Value";
                    })(InvalidPosition || (InvalidPosition = {}));
                })(IncrementalParser || (IncrementalParser = {}));
                namedArgRegExCache = /* @__PURE__ */ new Map();
                tripleSlashXMLCommentStartRegEx = /^\/\/\/\s*<(\S+)\s.*?\/>/im;
                singleLinePragmaRegEx = /^\/\/\/?\s*@([^\s:]+)(.*)\s*$/im;
            }
        });
        // src/compiler/commandLineParser.ts
        function createOptionNameMap(optionDeclarations2) {
            const optionsNameMap = /* @__PURE__ */ new Map();
            const shortOptionNames = /* @__PURE__ */ new Map();
            forEach(optionDeclarations2, (option) => {
                optionsNameMap.set(option.name.toLowerCase(), option);
                if (option.shortName) {
                    shortOptionNames.set(option.shortName, option.name);
                }
            });
            return { optionsNameMap, shortOptionNames };
        }
        function getOptionsNameMap() {
            return optionsNameMapCache || (optionsNameMapCache = createOptionNameMap(optionDeclarations));
        }
        function createCompilerDiagnosticForInvalidCustomType(opt) {
            return createDiagnosticForInvalidCustomType(opt, createCompilerDiagnostic);
        }
        function createDiagnosticForInvalidCustomType(opt, createDiagnostic) {
            const namesOfType = arrayFrom(opt.type.keys());
            const stringNames = (opt.deprecatedKeys ? namesOfType.filter((k) => !opt.deprecatedKeys.has(k)) : namesOfType).map((key) => `'${key}'`).join(", ");
            return createDiagnostic(Diagnostics.Argument_for_0_option_must_be_Colon_1, `--${opt.name}`, stringNames);
        }
        function parseCustomTypeOption(opt, value, errors) {
            return convertJsonOptionOfCustomType(opt, (value ?? "").trim(), errors);
        }
        function parseListTypeOption(opt, value = "", errors) {
            value = value.trim();
            if (startsWith(value, "-")) {
                return void 0;
            }
            if (opt.type === "listOrElement" && !value.includes(",")) {
                return validateJsonOptionValue(opt, value, errors);
            }
            if (value === "") {
                return [];
            }
            const values = value.split(",");
            switch (opt.element.type) {
                case "number":
                    return mapDefined(values, (v) => validateJsonOptionValue(opt.element, parseInt(v), errors));
                case "string":
                    return mapDefined(values, (v) => validateJsonOptionValue(opt.element, v || "", errors));
                case "boolean":
                case "object":
                    return Debug.fail(`List of ${opt.element.type} is not yet supported.`);
                default:
                    return mapDefined(values, (v) => parseCustomTypeOption(opt.element, v, errors));
            }
        }
        function getOptionName(option) {
            return option.name;
        }
        function createUnknownOptionError(unknownOption, diagnostics, unknownOptionErrorText, node, sourceFile) {
            var _a;
            if ((_a = diagnostics.alternateMode) == null ? void 0 : _a.getOptionsNameMap().optionsNameMap.has(unknownOption.toLowerCase())) {
                return createDiagnosticForNodeInSourceFileOrCompilerDiagnostic(sourceFile, node, diagnostics.alternateMode.diagnostic, unknownOption);
            }
            const possibleOption = getSpellingSuggestion(unknownOption, diagnostics.optionDeclarations, getOptionName);
            return possibleOption ? createDiagnosticForNodeInSourceFileOrCompilerDiagnostic(sourceFile, node, diagnostics.unknownDidYouMeanDiagnostic, unknownOptionErrorText || unknownOption, possibleOption.name) : createDiagnosticForNodeInSourceFileOrCompilerDiagnostic(sourceFile, node, diagnostics.unknownOptionDiagnostic, unknownOptionErrorText || unknownOption);
        }
        function parseCommandLineWorker(diagnostics, commandLine, readFile) {
            const options = {};
            let watchOptions;
            const fileNames = [];
            const errors = [];
            parseStrings(commandLine);
            return {
                options,
                watchOptions,
                fileNames,
                errors
            };
            function parseStrings(args) {
                let i = 0;
                while (i < args.length) {
                    const s = args[i];
                    i++;
                    if (s.charCodeAt(0) === 64 /* at */) {
                        parseResponseFile(s.slice(1));
                    }
                    else if (s.charCodeAt(0) === 45 /* minus */) {
                        const inputOptionName = s.slice(s.charCodeAt(1) === 45 /* minus */ ? 2 : 1);
                        const opt = getOptionDeclarationFromName(diagnostics.getOptionsNameMap, inputOptionName, 
                        /*allowShort*/
                        true);
                        if (opt) {
                            i = parseOptionValue(args, i, diagnostics, opt, options, errors);
                        }
                        else {
                            const watchOpt = getOptionDeclarationFromName(watchOptionsDidYouMeanDiagnostics.getOptionsNameMap, inputOptionName, 
                            /*allowShort*/
                            true);
                            if (watchOpt) {
                                i = parseOptionValue(args, i, watchOptionsDidYouMeanDiagnostics, watchOpt, watchOptions || (watchOptions = {}), errors);
                            }
                            else {
                                errors.push(createUnknownOptionError(inputOptionName, diagnostics, s));
                            }
                        }
                    }
                    else {
                        fileNames.push(s);
                    }
                }
            }
            function parseResponseFile(fileName) {
                const text = tryReadFile(fileName, readFile || ((fileName2) => sys.readFile(fileName2)));
                if (!isString(text)) {
                    errors.push(text);
                    return;
                }
                const args = [];
                let pos = 0;
                while (true) {
                    while (pos < text.length && text.charCodeAt(pos) <= 32 /* space */)
                        pos++;
                    if (pos >= text.length)
                        break;
                    const start = pos;
                    if (text.charCodeAt(start) === 34 /* doubleQuote */) {
                        pos++;
                        while (pos < text.length && text.charCodeAt(pos) !== 34 /* doubleQuote */)
                            pos++;
                        if (pos < text.length) {
                            args.push(text.substring(start + 1, pos));
                            pos++;
                        }
                        else {
                            errors.push(createCompilerDiagnostic(Diagnostics.Unterminated_quoted_string_in_response_file_0, fileName));
                        }
                    }
                    else {
                        while (text.charCodeAt(pos) > 32 /* space */)
                            pos++;
                        args.push(text.substring(start, pos));
                    }
                }
                parseStrings(args);
            }
        }
        function parseOptionValue(args, i, diagnostics, opt, options, errors) {
            if (opt.isTSConfigOnly) {
                const optValue = args[i];
                if (optValue === "null") {
                    options[opt.name] = void 0;
                    i++;
                }
                else if (opt.type === "boolean") {
                    if (optValue === "false") {
                        options[opt.name] = validateJsonOptionValue(opt, 
                        /*value*/
                        false, errors);
                        i++;
                    }
                    else {
                        if (optValue === "true")
                            i++;
                        errors.push(createCompilerDiagnostic(Diagnostics.Option_0_can_only_be_specified_in_tsconfig_json_file_or_set_to_false_or_null_on_command_line, opt.name));
                    }
                }
                else {
                    errors.push(createCompilerDiagnostic(Diagnostics.Option_0_can_only_be_specified_in_tsconfig_json_file_or_set_to_null_on_command_line, opt.name));
                    if (optValue && !startsWith(optValue, "-"))
                        i++;
                }
            }
            else {
                if (!args[i] && opt.type !== "boolean") {
                    errors.push(createCompilerDiagnostic(diagnostics.optionTypeMismatchDiagnostic, opt.name, getCompilerOptionValueTypeString(opt)));
                }
                if (args[i] !== "null") {
                    switch (opt.type) {
                        case "number":
                            options[opt.name] = validateJsonOptionValue(opt, parseInt(args[i]), errors);
                            i++;
                            break;
                        case "boolean":
                            const optValue = args[i];
                            options[opt.name] = validateJsonOptionValue(opt, optValue !== "false", errors);
                            if (optValue === "false" || optValue === "true") {
                                i++;
                            }
                            break;
                        case "string":
                            options[opt.name] = validateJsonOptionValue(opt, args[i] || "", errors);
                            i++;
                            break;
                        case "list":
                            const result = parseListTypeOption(opt, args[i], errors);
                            options[opt.name] = result || [];
                            if (result) {
                                i++;
                            }
                            break;
                        case "listOrElement":
                            Debug.fail("listOrElement not supported here");
                            break;
                        default:
                            options[opt.name] = parseCustomTypeOption(opt, args[i], errors);
                            i++;
                            break;
                    }
                }
                else {
                    options[opt.name] = void 0;
                    i++;
                }
            }
            return i;
        }
        function parseCommandLine(commandLine, readFile) {
            return parseCommandLineWorker(compilerOptionsDidYouMeanDiagnostics, commandLine, readFile);
        }
        function getOptionFromName(optionName, allowShort) {
            return getOptionDeclarationFromName(getOptionsNameMap, optionName, allowShort);
        }
        function getOptionDeclarationFromName(getOptionNameMap, optionName, allowShort = false) {
            optionName = optionName.toLowerCase();
            const { optionsNameMap, shortOptionNames } = getOptionNameMap();
            if (allowShort) {
                const short = shortOptionNames.get(optionName);
                if (short !== void 0) {
                    optionName = short;
                }
            }
            return optionsNameMap.get(optionName);
        }
        function getBuildOptionsNameMap() {
            return buildOptionsNameMapCache || (buildOptionsNameMapCache = createOptionNameMap(buildOpts));
        }
        function parseBuildCommand(args) {
            const { options, watchOptions, fileNames: projects, errors } = parseCommandLineWorker(buildOptionsDidYouMeanDiagnostics, args);
            const buildOptions = options;
            if (projects.length === 0) {
                projects.push(".");
            }
            if (buildOptions.clean && buildOptions.force) {
                errors.push(createCompilerDiagnostic(Diagnostics.Options_0_and_1_cannot_be_combined, "clean", "force"));
            }
            if (buildOptions.clean && buildOptions.verbose) {
                errors.push(createCompilerDiagnostic(Diagnostics.Options_0_and_1_cannot_be_combined, "clean", "verbose"));
            }
            if (buildOptions.clean && buildOptions.watch) {
                errors.push(createCompilerDiagnostic(Diagnostics.Options_0_and_1_cannot_be_combined, "clean", "watch"));
            }
            if (buildOptions.watch && buildOptions.dry) {
                errors.push(createCompilerDiagnostic(Diagnostics.Options_0_and_1_cannot_be_combined, "watch", "dry"));
            }
            return { buildOptions, watchOptions, projects, errors };
        }
        function getDiagnosticText(message, ...args) {
            return cast(createCompilerDiagnostic(message, ...args).messageText, isString);
        }
        function getParsedCommandLineOfConfigFile(configFileName, optionsToExtend, host, extendedConfigCache, watchOptionsToExtend, extraFileExtensions) {
            const configFileText = tryReadFile(configFileName, (fileName) => host.readFile(fileName));
            if (!isString(configFileText)) {
                host.onUnRecoverableConfigFileDiagnostic(configFileText);
                return void 0;
            }
            const result = parseJsonText(configFileName, configFileText);
            const cwd = host.getCurrentDirectory();
            result.path = toPath(configFileName, cwd, createGetCanonicalFileName(host.useCaseSensitiveFileNames));
            result.resolvedPath = result.path;
            result.originalFileName = result.fileName;
            return parseJsonSourceFileConfigFileContent(result, host, getNormalizedAbsolutePath(getDirectoryPath(configFileName), cwd), optionsToExtend, getNormalizedAbsolutePath(configFileName, cwd), 
            /*resolutionStack*/
            void 0, extraFileExtensions, extendedConfigCache, watchOptionsToExtend);
        }
        function readConfigFile(fileName, readFile) {
            const textOrDiagnostic = tryReadFile(fileName, readFile);
            return isString(textOrDiagnostic) ? parseConfigFileTextToJson(fileName, textOrDiagnostic) : { config: {}, error: textOrDiagnostic };
        }
        function parseConfigFileTextToJson(fileName, jsonText) {
            const jsonSourceFile = parseJsonText(fileName, jsonText);
            return {
                config: convertConfigFileToObject(jsonSourceFile, jsonSourceFile.parseDiagnostics, 
                /*jsonConversionNotifier*/
                void 0),
                error: jsonSourceFile.parseDiagnostics.length ? jsonSourceFile.parseDiagnostics[0] : void 0
            };
        }
        function readJsonConfigFile(fileName, readFile) {
            const textOrDiagnostic = tryReadFile(fileName, readFile);
            return isString(textOrDiagnostic) ? parseJsonText(fileName, textOrDiagnostic) : { fileName, parseDiagnostics: [textOrDiagnostic] };
        }
        function tryReadFile(fileName, readFile) {
            let text;
            try {
                text = readFile(fileName);
            }
            catch (e) {
                return createCompilerDiagnostic(Diagnostics.Cannot_read_file_0_Colon_1, fileName, e.message);
            }
            return text === void 0 ? createCompilerDiagnostic(Diagnostics.Cannot_read_file_0, fileName) : text;
        }
        function commandLineOptionsToMap(options) {
            return arrayToMap(options, getOptionName);
        }
        function getWatchOptionsNameMap() {
            return watchOptionsNameMapCache || (watchOptionsNameMapCache = createOptionNameMap(optionsForWatch));
        }
        function getCommandLineCompilerOptionsMap() {
            return commandLineCompilerOptionsMapCache || (commandLineCompilerOptionsMapCache = commandLineOptionsToMap(optionDeclarations));
        }
        function getCommandLineWatchOptionsMap() {
            return commandLineWatchOptionsMapCache || (commandLineWatchOptionsMapCache = commandLineOptionsToMap(optionsForWatch));
        }
        function getCommandLineTypeAcquisitionMap() {
            return commandLineTypeAcquisitionMapCache || (commandLineTypeAcquisitionMapCache = commandLineOptionsToMap(typeAcquisitionDeclarations));
        }
        function getTsconfigRootOptionsMap() {
            if (_tsconfigRootOptions === void 0) {
                _tsconfigRootOptions = {
                    name: void 0,
                    // should never be needed since this is root
                    type: "object",
                    elementOptions: commandLineOptionsToMap([
                        compilerOptionsDeclaration,
                        watchOptionsDeclaration,
                        typeAcquisitionDeclaration,
                        extendsOptionDeclaration,
                        {
                            name: "references",
                            type: "list",
                            element: {
                                name: "references",
                                type: "object"
                            },
                            category: Diagnostics.Projects
                        },
                        {
                            name: "files",
                            type: "list",
                            element: {
                                name: "files",
                                type: "string"
                            },
                            category: Diagnostics.File_Management
                        },
                        {
                            name: "include",
                            type: "list",
                            element: {
                                name: "include",
                                type: "string"
                            },
                            category: Diagnostics.File_Management,
                            defaultValueDescription: Diagnostics.if_files_is_specified_otherwise_Asterisk_Asterisk_Slash_Asterisk
                        },
                        {
                            name: "exclude",
                            type: "list",
                            element: {
                                name: "exclude",
                                type: "string"
                            },
                            category: Diagnostics.File_Management,
                            defaultValueDescription: Diagnostics.node_modules_bower_components_jspm_packages_plus_the_value_of_outDir_if_one_is_specified
                        },
                        compileOnSaveCommandLineOption
                    ])
                };
            }
            return _tsconfigRootOptions;
        }
        function convertConfigFileToObject(sourceFile, errors, jsonConversionNotifier) {
            var _a;
            const rootExpression = (_a = sourceFile.statements[0]) == null ? void 0 : _a.expression;
            if (rootExpression && rootExpression.kind !== 210 /* ObjectLiteralExpression */) {
                errors.push(createDiagnosticForNodeInSourceFile(sourceFile, rootExpression, Diagnostics.The_root_value_of_a_0_file_must_be_an_object, getBaseFileName(sourceFile.fileName) === "jsconfig.json" ? "jsconfig.json" : "tsconfig.json"));
                if (isArrayLiteralExpression(rootExpression)) {
                    const firstObject = find(rootExpression.elements, isObjectLiteralExpression);
                    if (firstObject) {
                        return convertToJson(sourceFile, firstObject, errors, 
                        /*returnValue*/
                        true, jsonConversionNotifier);
                    }
                }
                return {};
            }
            return convertToJson(sourceFile, rootExpression, errors, 
            /*returnValue*/
            true, jsonConversionNotifier);
        }
        function convertToObject(sourceFile, errors) {
            var _a;
            return convertToJson(sourceFile, (_a = sourceFile.statements[0]) == null ? void 0 : _a.expression, errors, 
            /*returnValue*/
            true, 
            /*jsonConversionNotifier*/
            void 0);
        }
        function convertToJson(sourceFile, rootExpression, errors, returnValue, jsonConversionNotifier) {
            if (!rootExpression) {
                return returnValue ? {} : void 0;
            }
            return convertPropertyValueToJson(rootExpression, jsonConversionNotifier == null ? void 0 : jsonConversionNotifier.rootOptions);
            function convertObjectLiteralExpressionToJson(node, objectOption) {
                var _a;
                const result = returnValue ? {} : void 0;
                for (const element of node.properties) {
                    if (element.kind !== 303 /* PropertyAssignment */) {
                        errors.push(createDiagnosticForNodeInSourceFile(sourceFile, element, Diagnostics.Property_assignment_expected));
                        continue;
                    }
                    if (element.questionToken) {
                        errors.push(createDiagnosticForNodeInSourceFile(sourceFile, element.questionToken, Diagnostics.The_0_modifier_can_only_be_used_in_TypeScript_files, "?"));
                    }
                    if (!isDoubleQuotedString(element.name)) {
                        errors.push(createDiagnosticForNodeInSourceFile(sourceFile, element.name, Diagnostics.String_literal_with_double_quotes_expected));
                    }
                    const textOfKey = isComputedNonLiteralName(element.name) ? void 0 : getTextOfPropertyName(element.name);
                    const keyText = textOfKey && unescapeLeadingUnderscores(textOfKey);
                    const option = keyText ? (_a = objectOption == null ? void 0 : objectOption.elementOptions) == null ? void 0 : _a.get(keyText) : void 0;
                    const value = convertPropertyValueToJson(element.initializer, option);
                    if (typeof keyText !== "undefined") {
                        if (returnValue) {
                            result[keyText] = value;
                        }
                        jsonConversionNotifier == null ? void 0 : jsonConversionNotifier.onPropertySet(keyText, value, element, objectOption, option);
                    }
                }
                return result;
            }
            function convertArrayLiteralExpressionToJson(elements, elementOption) {
                if (!returnValue) {
                    elements.forEach((element) => convertPropertyValueToJson(element, elementOption));
                    return void 0;
                }
                return filter(elements.map((element) => convertPropertyValueToJson(element, elementOption)), (v) => v !== void 0);
            }
            function convertPropertyValueToJson(valueExpression, option) {
                switch (valueExpression.kind) {
                    case 112 /* TrueKeyword */:
                        return true;
                    case 97 /* FalseKeyword */:
                        return false;
                    case 106 /* NullKeyword */:
                        return null;
                    case 11 /* StringLiteral */:
                        if (!isDoubleQuotedString(valueExpression)) {
                            errors.push(createDiagnosticForNodeInSourceFile(sourceFile, valueExpression, Diagnostics.String_literal_with_double_quotes_expected));
                        }
                        return valueExpression.text;
                    case 9 /* NumericLiteral */:
                        return Number(valueExpression.text);
                    case 224 /* PrefixUnaryExpression */:
                        if (valueExpression.operator !== 41 /* MinusToken */ || valueExpression.operand.kind !== 9 /* NumericLiteral */) {
                            break;
                        }
                        return -Number(valueExpression.operand.text);
                    case 210 /* ObjectLiteralExpression */:
                        const objectLiteralExpression = valueExpression;
                        return convertObjectLiteralExpressionToJson(objectLiteralExpression, option);
                    case 209 /* ArrayLiteralExpression */:
                        return convertArrayLiteralExpressionToJson(valueExpression.elements, option && option.element);
                }
                if (option) {
                    errors.push(createDiagnosticForNodeInSourceFile(sourceFile, valueExpression, Diagnostics.Compiler_option_0_requires_a_value_of_type_1, option.name, getCompilerOptionValueTypeString(option)));
                }
                else {
                    errors.push(createDiagnosticForNodeInSourceFile(sourceFile, valueExpression, Diagnostics.Property_value_can_only_be_string_literal_numeric_literal_true_false_null_object_literal_or_array_literal));
                }
                return void 0;
            }
            function isDoubleQuotedString(node) {
                return isStringLiteral(node) && isStringDoubleQuoted(node, sourceFile);
            }
        }
        function getCompilerOptionValueTypeString(option) {
            return option.type === "listOrElement" ? `${getCompilerOptionValueTypeString(option.element)} or Array` : option.type === "list" ? "Array" : isString(option.type) ? option.type : "string";
        }
        function isCompilerOptionsValue(option, value) {
            if (option) {
                if (isNullOrUndefined(value))
                    return !option.disallowNullOrUndefined;
                if (option.type === "list") {
                    return isArray(value);
                }
                if (option.type === "listOrElement") {
                    return isArray(value) || isCompilerOptionsValue(option.element, value);
                }
                const expectedType = isString(option.type) ? option.type : "string";
                return typeof value === expectedType;
            }
            return false;
        }
        function convertToTSConfig(configParseResult, configFileName, host) {
            var _a, _b, _c;
            const getCanonicalFileName = createGetCanonicalFileName(host.useCaseSensitiveFileNames);
            const files = map(filter(configParseResult.fileNames, !((_b = (_a = configParseResult.options.configFile) == null ? void 0 : _a.configFileSpecs) == null ? void 0 : _b.validatedIncludeSpecs) ? returnTrue : matchesSpecs(configFileName, configParseResult.options.configFile.configFileSpecs.validatedIncludeSpecs, configParseResult.options.configFile.configFileSpecs.validatedExcludeSpecs, host)), (f) => getRelativePathFromFile(getNormalizedAbsolutePath(configFileName, host.getCurrentDirectory()), getNormalizedAbsolutePath(f, host.getCurrentDirectory()), getCanonicalFileName));
            const pathOptions = { configFilePath: getNormalizedAbsolutePath(configFileName, host.getCurrentDirectory()), useCaseSensitiveFileNames: host.useCaseSensitiveFileNames };
            const optionMap = serializeCompilerOptions(configParseResult.options, pathOptions);
            const watchOptionMap = configParseResult.watchOptions && serializeWatchOptions(configParseResult.watchOptions);
            const config = {
                compilerOptions: {
                    ...optionMapToObject(optionMap),
                    showConfig: void 0,
                    configFile: void 0,
                    configFilePath: void 0,
                    help: void 0,
                    init: void 0,
                    listFiles: void 0,
                    listEmittedFiles: void 0,
                    project: void 0,
                    build: void 0,
                    version: void 0
                },
                watchOptions: watchOptionMap && optionMapToObject(watchOptionMap),
                references: map(configParseResult.projectReferences, (r) => ({ ...r, path: r.originalPath ? r.originalPath : "", originalPath: void 0 })),
                files: length(files) ? files : void 0,
                ...((_c = configParseResult.options.configFile) == null ? void 0 : _c.configFileSpecs) ? {
                    include: filterSameAsDefaultInclude(configParseResult.options.configFile.configFileSpecs.validatedIncludeSpecs),
                    exclude: configParseResult.options.configFile.configFileSpecs.validatedExcludeSpecs
                } : {},
                compileOnSave: !!configParseResult.compileOnSave ? true : void 0
            };
            const providedKeys = new Set(optionMap.keys());
            const impliedCompilerOptions = {};
            for (const option in computedOptions) {
                if (!providedKeys.has(option) && some(computedOptions[option].dependencies, (dep) => providedKeys.has(dep))) {
                    const implied = computedOptions[option].computeValue(configParseResult.options);
                    const defaultValue = computedOptions[option].computeValue({});
                    if (implied !== defaultValue) {
                        impliedCompilerOptions[option] = computedOptions[option].computeValue(configParseResult.options);
                    }
                }
            }
            assign(config.compilerOptions, optionMapToObject(serializeCompilerOptions(impliedCompilerOptions, pathOptions)));
            return config;
        }
        function optionMapToObject(optionMap) {
            return {
                ...arrayFrom(optionMap.entries()).reduce((prev, cur) => ({ ...prev, [cur[0]]: cur[1] }), {})
            };
        }
        function filterSameAsDefaultInclude(specs) {
            if (!length(specs))
                return void 0;
            if (length(specs) !== 1)
                return specs;
            if (specs[0] === defaultIncludeSpec)
                return void 0;
            return specs;
        }
        function matchesSpecs(path, includeSpecs, excludeSpecs, host) {
            if (!includeSpecs)
                return returnTrue;
            const patterns = getFileMatcherPatterns(path, excludeSpecs, includeSpecs, host.useCaseSensitiveFileNames, host.getCurrentDirectory());
            const excludeRe = patterns.excludePattern && getRegexFromPattern(patterns.excludePattern, host.useCaseSensitiveFileNames);
            const includeRe = patterns.includeFilePattern && getRegexFromPattern(patterns.includeFilePattern, host.useCaseSensitiveFileNames);
            if (includeRe) {
                if (excludeRe) {
                    return (path2) => !(includeRe.test(path2) && !excludeRe.test(path2));
                }
                return (path2) => !includeRe.test(path2);
            }
            if (excludeRe) {
                return (path2) => excludeRe.test(path2);
            }
            return returnTrue;
        }
        function getCustomTypeMapOfCommandLineOption(optionDefinition) {
            switch (optionDefinition.type) {
                case "string":
                case "number":
                case "boolean":
                case "object":
                    return void 0;
                case "list":
                case "listOrElement":
                    return getCustomTypeMapOfCommandLineOption(optionDefinition.element);
                default:
                    return optionDefinition.type;
            }
        }
        function getNameOfCompilerOptionValue(value, customTypeMap) {
            return forEachEntry(customTypeMap, (mapValue, key) => {
                if (mapValue === value) {
                    return key;
                }
            });
        }
        function serializeCompilerOptions(options, pathOptions) {
            return serializeOptionBaseObject(options, getOptionsNameMap(), pathOptions);
        }
        function serializeWatchOptions(options) {
            return serializeOptionBaseObject(options, getWatchOptionsNameMap());
        }
        function serializeOptionBaseObject(options, { optionsNameMap }, pathOptions) {
            const result = /* @__PURE__ */ new Map();
            const getCanonicalFileName = pathOptions && createGetCanonicalFileName(pathOptions.useCaseSensitiveFileNames);
            for (const name in options) {
                if (hasProperty(options, name)) {
                    if (optionsNameMap.has(name) && (optionsNameMap.get(name).category === Diagnostics.Command_line_Options || optionsNameMap.get(name).category === Diagnostics.Output_Formatting)) {
                        continue;
                    }
                    const value = options[name];
                    const optionDefinition = optionsNameMap.get(name.toLowerCase());
                    if (optionDefinition) {
                        Debug.assert(optionDefinition.type !== "listOrElement");
                        const customTypeMap = getCustomTypeMapOfCommandLineOption(optionDefinition);
                        if (!customTypeMap) {
                            if (pathOptions && optionDefinition.isFilePath) {
                                result.set(name, getRelativePathFromFile(pathOptions.configFilePath, getNormalizedAbsolutePath(value, getDirectoryPath(pathOptions.configFilePath)), getCanonicalFileName));
                            }
                            else {
                                result.set(name, value);
                            }
                        }
                        else {
                            if (optionDefinition.type === "list") {
                                result.set(name, value.map((element) => getNameOfCompilerOptionValue(element, customTypeMap)));
                            }
                            else {
                                result.set(name, getNameOfCompilerOptionValue(value, customTypeMap));
                            }
                        }
                    }
                }
            }
            return result;
        }
        function getCompilerOptionsDiffValue(options, newLine) {
            const compilerOptionsMap = getSerializedCompilerOption(options);
            return getOverwrittenDefaultOptions();
            function makePadding(paddingLength) {
                return Array(paddingLength + 1).join(" ");
            }
            function getOverwrittenDefaultOptions() {
                const result = [];
                const tab = makePadding(2);
                commandOptionsWithoutBuild.forEach((cmd) => {
                    if (!compilerOptionsMap.has(cmd.name)) {
                        return;
                    }
                    const newValue = compilerOptionsMap.get(cmd.name);
                    const defaultValue = getDefaultValueForOption(cmd);
                    if (newValue !== defaultValue) {
                        result.push(`${tab}${cmd.name}: ${newValue}`);
                    }
                    else if (hasProperty(defaultInitCompilerOptions, cmd.name)) {
                        result.push(`${tab}${cmd.name}: ${defaultValue}`);
                    }
                });
                return result.join(newLine) + newLine;
            }
        }
        function getSerializedCompilerOption(options) {
            const compilerOptions = extend(options, defaultInitCompilerOptions);
            return serializeCompilerOptions(compilerOptions);
        }
        function generateTSConfig(options, fileNames, newLine) {
            const compilerOptionsMap = getSerializedCompilerOption(options);
            return writeConfigurations();
            function makePadding(paddingLength) {
                return Array(paddingLength + 1).join(" ");
            }
            function isAllowedOptionForOutput({ category, name, isCommandLineOnly }) {
                const categoriesToSkip = [Diagnostics.Command_line_Options, Diagnostics.Editor_Support, Diagnostics.Compiler_Diagnostics, Diagnostics.Backwards_Compatibility, Diagnostics.Watch_and_Build_Modes, Diagnostics.Output_Formatting];
                return !isCommandLineOnly && category !== void 0 && (!categoriesToSkip.includes(category) || compilerOptionsMap.has(name));
            }
            function writeConfigurations() {
                const categorizedOptions = /* @__PURE__ */ new Map();
                categorizedOptions.set(Diagnostics.Projects, []);
                categorizedOptions.set(Diagnostics.Language_and_Environment, []);
                categorizedOptions.set(Diagnostics.Modules, []);
                categorizedOptions.set(Diagnostics.JavaScript_Support, []);
                categorizedOptions.set(Diagnostics.Emit, []);
                categorizedOptions.set(Diagnostics.Interop_Constraints, []);
                categorizedOptions.set(Diagnostics.Type_Checking, []);
                categorizedOptions.set(Diagnostics.Completeness, []);
                for (const option of optionDeclarations) {
                    if (isAllowedOptionForOutput(option)) {
                        let listForCategory = categorizedOptions.get(option.category);
                        if (!listForCategory)
                            categorizedOptions.set(option.category, listForCategory = []);
                        listForCategory.push(option);
                    }
                }
                let marginLength = 0;
                let seenKnownKeys = 0;
                const entries = [];
                categorizedOptions.forEach((options2, category) => {
                    if (entries.length !== 0) {
                        entries.push({ value: "" });
                    }
                    entries.push({ value: `/* ${getLocaleSpecificMessage(category)} */` });
                    for (const option of options2) {
                        let optionName;
                        if (compilerOptionsMap.has(option.name)) {
                            optionName = `"${option.name}": ${JSON.stringify(compilerOptionsMap.get(option.name))}${(seenKnownKeys += 1) === compilerOptionsMap.size ? "" : ","}`;
                        }
                        else {
                            optionName = `// "${option.name}": ${JSON.stringify(getDefaultValueForOption(option))},`;
                        }
                        entries.push({
                            value: optionName,
                            description: `/* ${option.description && getLocaleSpecificMessage(option.description) || option.name} */`
                        });
                        marginLength = Math.max(optionName.length, marginLength);
                    }
                });
                const tab = makePadding(2);
                const result = [];
                result.push(`{`);
                result.push(`${tab}"compilerOptions": {`);
                result.push(`${tab}${tab}/* ${getLocaleSpecificMessage(Diagnostics.Visit_https_Colon_Slash_Slashaka_ms_Slashtsconfig_to_read_more_about_this_file)} */`);
                result.push("");
                for (const entry of entries) {
                    const { value, description: description3 = "" } = entry;
                    result.push(value && `${tab}${tab}${value}${description3 && makePadding(marginLength - value.length + 2) + description3}`);
                }
                if (fileNames.length) {
                    result.push(`${tab}},`);
                    result.push(`${tab}"files": [`);
                    for (let i = 0; i < fileNames.length; i++) {
                        result.push(`${tab}${tab}${JSON.stringify(fileNames[i])}${i === fileNames.length - 1 ? "" : ","}`);
                    }
                    result.push(`${tab}]`);
                }
                else {
                    result.push(`${tab}}`);
                }
                result.push(`}`);
                return result.join(newLine) + newLine;
            }
        }
        function convertToOptionsWithAbsolutePaths(options, toAbsolutePath) {
            const result = {};
            const optionsNameMap = getOptionsNameMap().optionsNameMap;
            for (const name in options) {
                if (hasProperty(options, name)) {
                    result[name] = convertToOptionValueWithAbsolutePaths(optionsNameMap.get(name.toLowerCase()), options[name], toAbsolutePath);
                }
            }
            if (result.configFilePath) {
                result.configFilePath = toAbsolutePath(result.configFilePath);
            }
            return result;
        }
        function convertToOptionValueWithAbsolutePaths(option, value, toAbsolutePath) {
            if (option && !isNullOrUndefined(value)) {
                if (option.type === "list") {
                    const values = value;
                    if (option.element.isFilePath && values.length) {
                        return values.map(toAbsolutePath);
                    }
                }
                else if (option.isFilePath) {
                    return toAbsolutePath(value);
                }
                Debug.assert(option.type !== "listOrElement");
            }
            return value;
        }
        function parseJsonConfigFileContent(json, host, basePath, existingOptions, configFileName, resolutionStack, extraFileExtensions, extendedConfigCache, existingWatchOptions) {
            return parseJsonConfigFileContentWorker(json, 
            /*sourceFile*/
            void 0, host, basePath, existingOptions, existingWatchOptions, configFileName, resolutionStack, extraFileExtensions, extendedConfigCache);
        }
        function parseJsonSourceFileConfigFileContent(sourceFile, host, basePath, existingOptions, configFileName, resolutionStack, extraFileExtensions, extendedConfigCache, existingWatchOptions) {
            var _a, _b;
            (_a = tracing) == null ? void 0 : _a.push(tracing.Phase.Parse, "parseJsonSourceFileConfigFileContent", { path: sourceFile.fileName });
            const result = parseJsonConfigFileContentWorker(
            /*json*/
            void 0, sourceFile, host, basePath, existingOptions, existingWatchOptions, configFileName, resolutionStack, extraFileExtensions, extendedConfigCache);
            (_b = tracing) == null ? void 0 : _b.pop();
            return result;
        }
        function setConfigFileInOptions(options, configFile) {
            if (configFile) {
                Object.defineProperty(options, "configFile", { enumerable: false, writable: false, value: configFile });
            }
        }
        function isNullOrUndefined(x) {
            return x === void 0 || x === null;
        }
        function directoryOfCombinedPath(fileName, basePath) {
            return getDirectoryPath(getNormalizedAbsolutePath(fileName, basePath));
        }
        function parseJsonConfigFileContentWorker(json, sourceFile, host, basePath, existingOptions = {}, existingWatchOptions, configFileName, resolutionStack = [], extraFileExtensions = [], extendedConfigCache) {
            Debug.assert(json === void 0 && sourceFile !== void 0 || json !== void 0 && sourceFile === void 0);
            const errors = [];
            const parsedConfig = parseConfig(json, sourceFile, host, basePath, configFileName, resolutionStack, errors, extendedConfigCache);
            const { raw } = parsedConfig;
            const options = extend(existingOptions, parsedConfig.options || {});
            const watchOptions = existingWatchOptions && parsedConfig.watchOptions ? extend(existingWatchOptions, parsedConfig.watchOptions) : parsedConfig.watchOptions || existingWatchOptions;
            options.configFilePath = configFileName && normalizeSlashes(configFileName);
            const configFileSpecs = getConfigFileSpecs();
            if (sourceFile)
                sourceFile.configFileSpecs = configFileSpecs;
            setConfigFileInOptions(options, sourceFile);
            const basePathForFileNames = normalizePath(configFileName ? directoryOfCombinedPath(configFileName, basePath) : basePath);
            return {
                options,
                watchOptions,
                fileNames: getFileNames(basePathForFileNames),
                projectReferences: getProjectReferences(basePathForFileNames),
                typeAcquisition: parsedConfig.typeAcquisition || getDefaultTypeAcquisition(),
                raw,
                errors,
                // Wildcard directories (provided as part of a wildcard path) are stored in a
                // file map that marks whether it was a regular wildcard match (with a `*` or `?` token),
                // or a recursive directory. This information is used by filesystem watchers to monitor for
                // new entries in these paths.
                wildcardDirectories: getWildcardDirectories(configFileSpecs, basePathForFileNames, host.useCaseSensitiveFileNames),
                compileOnSave: !!raw.compileOnSave
            };
            function getConfigFileSpecs() {
                const referencesOfRaw = getPropFromRaw("references", (element) => typeof element === "object", "object");
                const filesSpecs = toPropValue(getSpecsFromRaw("files"));
                if (filesSpecs) {
                    const hasZeroOrNoReferences = referencesOfRaw === "no-prop" || isArray(referencesOfRaw) && referencesOfRaw.length === 0;
                    const hasExtends = hasProperty(raw, "extends");
                    if (filesSpecs.length === 0 && hasZeroOrNoReferences && !hasExtends) {
                        if (sourceFile) {
                            const fileName = configFileName || "tsconfig.json";
                            const diagnosticMessage = Diagnostics.The_files_list_in_config_file_0_is_empty;
                            const nodeValue = forEachTsConfigPropArray(sourceFile, "files", (property) => property.initializer);
                            const error2 = createDiagnosticForNodeInSourceFileOrCompilerDiagnostic(sourceFile, nodeValue, diagnosticMessage, fileName);
                            errors.push(error2);
                        }
                        else {
                            createCompilerDiagnosticOnlyIfJson(Diagnostics.The_files_list_in_config_file_0_is_empty, configFileName || "tsconfig.json");
                        }
                    }
                }
                let includeSpecs = toPropValue(getSpecsFromRaw("include"));
                const excludeOfRaw = getSpecsFromRaw("exclude");
                let isDefaultIncludeSpec = false;
                let excludeSpecs = toPropValue(excludeOfRaw);
                if (excludeOfRaw === "no-prop" && raw.compilerOptions) {
                    const outDir = raw.compilerOptions.outDir;
                    const declarationDir = raw.compilerOptions.declarationDir;
                    if (outDir || declarationDir) {
                        excludeSpecs = [outDir, declarationDir].filter((d) => !!d);
                    }
                }
                if (filesSpecs === void 0 && includeSpecs === void 0) {
                    includeSpecs = [defaultIncludeSpec];
                    isDefaultIncludeSpec = true;
                }
                let validatedIncludeSpecs, validatedExcludeSpecs;
                if (includeSpecs) {
                    validatedIncludeSpecs = validateSpecs(includeSpecs, errors, 
                    /*disallowTrailingRecursion*/
                    true, sourceFile, "include");
                }
                if (excludeSpecs) {
                    validatedExcludeSpecs = validateSpecs(excludeSpecs, errors, 
                    /*disallowTrailingRecursion*/
                    false, sourceFile, "exclude");
                }
                return {
                    filesSpecs,
                    includeSpecs,
                    excludeSpecs,
                    validatedFilesSpec: filter(filesSpecs, isString),
                    validatedIncludeSpecs,
                    validatedExcludeSpecs,
                    pathPatterns: void 0,
                    // Initialized on first use
                    isDefaultIncludeSpec
                };
            }
            function getFileNames(basePath2) {
                const fileNames = getFileNamesFromConfigSpecs(configFileSpecs, basePath2, options, host, extraFileExtensions);
                if (shouldReportNoInputFiles(fileNames, canJsonReportNoInputFiles(raw), resolutionStack)) {
                    errors.push(getErrorForNoInputFiles(configFileSpecs, configFileName));
                }
                return fileNames;
            }
            function getProjectReferences(basePath2) {
                let projectReferences;
                const referencesOfRaw = getPropFromRaw("references", (element) => typeof element === "object", "object");
                if (isArray(referencesOfRaw)) {
                    for (const ref of referencesOfRaw) {
                        if (typeof ref.path !== "string") {
                            createCompilerDiagnosticOnlyIfJson(Diagnostics.Compiler_option_0_requires_a_value_of_type_1, "reference.path", "string");
                        }
                        else {
                            (projectReferences || (projectReferences = [])).push({
                                path: getNormalizedAbsolutePath(ref.path, basePath2),
                                originalPath: ref.path,
                                prepend: ref.prepend,
                                circular: ref.circular
                            });
                        }
                    }
                }
                return projectReferences;
            }
            function toPropValue(specResult) {
                return isArray(specResult) ? specResult : void 0;
            }
            function getSpecsFromRaw(prop) {
                return getPropFromRaw(prop, isString, "string");
            }
            function getPropFromRaw(prop, validateElement, elementTypeName) {
                if (hasProperty(raw, prop) && !isNullOrUndefined(raw[prop])) {
                    if (isArray(raw[prop])) {
                        const result = raw[prop];
                        if (!sourceFile && !every(result, validateElement)) {
                            errors.push(createCompilerDiagnostic(Diagnostics.Compiler_option_0_requires_a_value_of_type_1, prop, elementTypeName));
                        }
                        return result;
                    }
                    else {
                        createCompilerDiagnosticOnlyIfJson(Diagnostics.Compiler_option_0_requires_a_value_of_type_1, prop, "Array");
                        return "not-array";
                    }
                }
                return "no-prop";
            }
            function createCompilerDiagnosticOnlyIfJson(message, ...args) {
                if (!sourceFile) {
                    errors.push(createCompilerDiagnostic(message, ...args));
                }
            }
        }
        function isErrorNoInputFiles(error2) {
            return error2.code === Diagnostics.No_inputs_were_found_in_config_file_0_Specified_include_paths_were_1_and_exclude_paths_were_2.code;
        }
        function getErrorForNoInputFiles({ includeSpecs, excludeSpecs }, configFileName) {
            return createCompilerDiagnostic(Diagnostics.No_inputs_were_found_in_config_file_0_Specified_include_paths_were_1_and_exclude_paths_were_2, configFileName || "tsconfig.json", JSON.stringify(includeSpecs || []), JSON.stringify(excludeSpecs || []));
        }
        function shouldReportNoInputFiles(fileNames, canJsonReportNoInutFiles, resolutionStack) {
            return fileNames.length === 0 && canJsonReportNoInutFiles && (!resolutionStack || resolutionStack.length === 0);
        }
        function canJsonReportNoInputFiles(raw) {
            return !hasProperty(raw, "files") && !hasProperty(raw, "references");
        }
        function updateErrorForNoInputFiles(fileNames, configFileName, configFileSpecs, configParseDiagnostics, canJsonReportNoInutFiles) {
            const existingErrors = configParseDiagnostics.length;
            if (shouldReportNoInputFiles(fileNames, canJsonReportNoInutFiles)) {
                configParseDiagnostics.push(getErrorForNoInputFiles(configFileSpecs, configFileName));
            }
            else {
                filterMutate(configParseDiagnostics, (error2) => !isErrorNoInputFiles(error2));
            }
            return existingErrors !== configParseDiagnostics.length;
        }
        function isSuccessfulParsedTsconfig(value) {
            return !!value.options;
        }
        function parseConfig(json, sourceFile, host, basePath, configFileName, resolutionStack, errors, extendedConfigCache) {
            var _a;
            basePath = normalizeSlashes(basePath);
            const resolvedPath = getNormalizedAbsolutePath(configFileName || "", basePath);
            if (resolutionStack.includes(resolvedPath)) {
                errors.push(createCompilerDiagnostic(Diagnostics.Circularity_detected_while_resolving_configuration_Colon_0, [...resolutionStack, resolvedPath].join(" -> ")));
                return { raw: json || convertToObject(sourceFile, errors) };
            }
            const ownConfig = json ? parseOwnConfigOfJson(json, host, basePath, configFileName, errors) : parseOwnConfigOfJsonSourceFile(sourceFile, host, basePath, configFileName, errors);
            if ((_a = ownConfig.options) == null ? void 0 : _a.paths) {
                ownConfig.options.pathsBasePath = basePath;
            }
            if (ownConfig.extendedConfigPath) {
                resolutionStack = resolutionStack.concat([resolvedPath]);
                const result = { options: {} };
                if (isString(ownConfig.extendedConfigPath)) {
                    applyExtendedConfig(result, ownConfig.extendedConfigPath);
                }
                else {
                    ownConfig.extendedConfigPath.forEach((extendedConfigPath) => applyExtendedConfig(result, extendedConfigPath));
                }
                if (!ownConfig.raw.include && result.include)
                    ownConfig.raw.include = result.include;
                if (!ownConfig.raw.exclude && result.exclude)
                    ownConfig.raw.exclude = result.exclude;
                if (!ownConfig.raw.files && result.files)
                    ownConfig.raw.files = result.files;
                if (ownConfig.raw.compileOnSave === void 0 && result.compileOnSave)
                    ownConfig.raw.compileOnSave = result.compileOnSave;
                if (sourceFile && result.extendedSourceFiles)
                    sourceFile.extendedSourceFiles = arrayFrom(result.extendedSourceFiles.keys());
                ownConfig.options = assign(result.options, ownConfig.options);
                ownConfig.watchOptions = ownConfig.watchOptions && result.watchOptions ? assign(result.watchOptions, ownConfig.watchOptions) : ownConfig.watchOptions || result.watchOptions;
            }
            return ownConfig;
            function applyExtendedConfig(result, extendedConfigPath) {
                const extendedConfig = getExtendedConfig(sourceFile, extendedConfigPath, host, resolutionStack, errors, extendedConfigCache, result);
                if (extendedConfig && isSuccessfulParsedTsconfig(extendedConfig)) {
                    const extendsRaw = extendedConfig.raw;
                    let relativeDifference;
                    const setPropertyInResultIfNotUndefined = (propertyName) => {
                        if (extendsRaw[propertyName]) {
                            result[propertyName] = map(extendsRaw[propertyName], (path) => isRootedDiskPath(path) ? path : combinePaths(relativeDifference || (relativeDifference = convertToRelativePath(getDirectoryPath(extendedConfigPath), basePath, createGetCanonicalFileName(host.useCaseSensitiveFileNames))), path));
                        }
                    };
                    setPropertyInResultIfNotUndefined("include");
                    setPropertyInResultIfNotUndefined("exclude");
                    setPropertyInResultIfNotUndefined("files");
                    if (extendsRaw.compileOnSave !== void 0) {
                        result.compileOnSave = extendsRaw.compileOnSave;
                    }
                    assign(result.options, extendedConfig.options);
                    result.watchOptions = result.watchOptions && extendedConfig.watchOptions ? assign({}, result.watchOptions, extendedConfig.watchOptions) : result.watchOptions || extendedConfig.watchOptions;
                }
            }
        }
        function parseOwnConfigOfJson(json, host, basePath, configFileName, errors) {
            if (hasProperty(json, "excludes")) {
                errors.push(createCompilerDiagnostic(Diagnostics.Unknown_option_excludes_Did_you_mean_exclude));
            }
            const options = convertCompilerOptionsFromJsonWorker(json.compilerOptions, basePath, errors, configFileName);
            const typeAcquisition = convertTypeAcquisitionFromJsonWorker(json.typeAcquisition, basePath, errors, configFileName);
            const watchOptions = convertWatchOptionsFromJsonWorker(json.watchOptions, basePath, errors);
            json.compileOnSave = convertCompileOnSaveOptionFromJson(json, basePath, errors);
            const extendedConfigPath = json.extends || json.extends === "" ? getExtendsConfigPathOrArray(json.extends, host, basePath, configFileName, errors) : void 0;
            return { raw: json, options, watchOptions, typeAcquisition, extendedConfigPath };
        }
        function getExtendsConfigPathOrArray(value, host, basePath, configFileName, errors, propertyAssignment, valueExpression, sourceFile) {
            let extendedConfigPath;
            const newBase = configFileName ? directoryOfCombinedPath(configFileName, basePath) : basePath;
            if (isString(value)) {
                extendedConfigPath = getExtendsConfigPath(value, host, newBase, errors, valueExpression, sourceFile);
            }
            else if (isArray(value)) {
                extendedConfigPath = [];
                for (let index = 0; index < value.length; index++) {
                    const fileName = value[index];
                    if (isString(fileName)) {
                        extendedConfigPath = append(extendedConfigPath, getExtendsConfigPath(fileName, host, newBase, errors, valueExpression == null ? void 0 : valueExpression.elements[index], sourceFile));
                    }
                    else {
                        convertJsonOption(extendsOptionDeclaration.element, value, basePath, errors, propertyAssignment, valueExpression == null ? void 0 : valueExpression.elements[index], sourceFile);
                    }
                }
            }
            else {
                convertJsonOption(extendsOptionDeclaration, value, basePath, errors, propertyAssignment, valueExpression, sourceFile);
            }
            return extendedConfigPath;
        }
        function parseOwnConfigOfJsonSourceFile(sourceFile, host, basePath, configFileName, errors) {
            const options = getDefaultCompilerOptions(configFileName);
            let typeAcquisition;
            let watchOptions;
            let extendedConfigPath;
            let rootCompilerOptions;
            const rootOptions = getTsconfigRootOptionsMap();
            const json = convertConfigFileToObject(sourceFile, errors, { rootOptions, onPropertySet });
            if (!typeAcquisition) {
                typeAcquisition = getDefaultTypeAcquisition(configFileName);
            }
            if (rootCompilerOptions && json && json.compilerOptions === void 0) {
                errors.push(createDiagnosticForNodeInSourceFile(sourceFile, rootCompilerOptions[0], Diagnostics._0_should_be_set_inside_the_compilerOptions_object_of_the_config_json_file, getTextOfPropertyName(rootCompilerOptions[0])));
            }
            return { raw: json, options, watchOptions, typeAcquisition, extendedConfigPath };
            function onPropertySet(keyText, value, propertyAssignment, parentOption, option) {
                if (option && option !== extendsOptionDeclaration)
                    value = convertJsonOption(option, value, basePath, errors, propertyAssignment, propertyAssignment.initializer, sourceFile);
                if (parentOption == null ? void 0 : parentOption.name) {
                    if (option) {
                        let currentOption;
                        if (parentOption === compilerOptionsDeclaration)
                            currentOption = options;
                        else if (parentOption === watchOptionsDeclaration)
                            currentOption = watchOptions ?? (watchOptions = {});
                        else if (parentOption === typeAcquisitionDeclaration)
                            currentOption = typeAcquisition ?? (typeAcquisition = getDefaultTypeAcquisition(configFileName));
                        else
                            Debug.fail("Unknown option");
                        currentOption[option.name] = value;
                    }
                    else if (keyText && (parentOption == null ? void 0 : parentOption.extraKeyDiagnostics)) {
                        if (parentOption.elementOptions) {
                            errors.push(createUnknownOptionError(keyText, parentOption.extraKeyDiagnostics, 
                            /*unknownOptionErrorText*/
                            void 0, propertyAssignment.name, sourceFile));
                        }
                        else {
                            errors.push(createDiagnosticForNodeInSourceFile(sourceFile, propertyAssignment.name, parentOption.extraKeyDiagnostics.unknownOptionDiagnostic, keyText));
                        }
                    }
                }
                else if (parentOption === rootOptions) {
                    if (option === extendsOptionDeclaration) {
                        extendedConfigPath = getExtendsConfigPathOrArray(value, host, basePath, configFileName, errors, propertyAssignment, propertyAssignment.initializer, sourceFile);
                    }
                    else if (!option) {
                        if (keyText === "excludes") {
                            errors.push(createDiagnosticForNodeInSourceFile(sourceFile, propertyAssignment.name, Diagnostics.Unknown_option_excludes_Did_you_mean_exclude));
                        }
                        if (find(commandOptionsWithoutBuild, (opt) => opt.name === keyText)) {
                            rootCompilerOptions = append(rootCompilerOptions, propertyAssignment.name);
                        }
                    }
                }
            }
        }
        function getExtendsConfigPath(extendedConfig, host, basePath, errors, valueExpression, sourceFile) {
            extendedConfig = normalizeSlashes(extendedConfig);
            if (isRootedDiskPath(extendedConfig) || startsWith(extendedConfig, "./") || startsWith(extendedConfig, "../")) {
                let extendedConfigPath = getNormalizedAbsolutePath(extendedConfig, basePath);
                if (!host.fileExists(extendedConfigPath) && !endsWith(extendedConfigPath, ".json" /* Json */)) {
                    extendedConfigPath = `${extendedConfigPath}.json`;
                    if (!host.fileExists(extendedConfigPath)) {
                        errors.push(createDiagnosticForNodeInSourceFileOrCompilerDiagnostic(sourceFile, valueExpression, Diagnostics.File_0_not_found, extendedConfig));
                        return void 0;
                    }
                }
                return extendedConfigPath;
            }
            const resolved = nodeNextJsonConfigResolver(extendedConfig, combinePaths(basePath, "tsconfig.json"), host);
            if (resolved.resolvedModule) {
                return resolved.resolvedModule.resolvedFileName;
            }
            if (extendedConfig === "") {
                errors.push(createDiagnosticForNodeInSourceFileOrCompilerDiagnostic(sourceFile, valueExpression, Diagnostics.Compiler_option_0_cannot_be_given_an_empty_string, "extends"));
            }
            else {
                errors.push(createDiagnosticForNodeInSourceFileOrCompilerDiagnostic(sourceFile, valueExpression, Diagnostics.File_0_not_found, extendedConfig));
            }
            return void 0;
        }
        function getExtendedConfig(sourceFile, extendedConfigPath, host, resolutionStack, errors, extendedConfigCache, result) {
            const path = host.useCaseSensitiveFileNames ? extendedConfigPath : toFileNameLowerCase(extendedConfigPath);
            let value;
            let extendedResult;
            let extendedConfig;
            if (extendedConfigCache && (value = extendedConfigCache.get(path))) {
                ({ extendedResult, extendedConfig } = value);
            }
            else {
                extendedResult = readJsonConfigFile(extendedConfigPath, (path2) => host.readFile(path2));
                if (!extendedResult.parseDiagnostics.length) {
                    extendedConfig = parseConfig(
                    /*json*/
                    void 0, extendedResult, host, getDirectoryPath(extendedConfigPath), getBaseFileName(extendedConfigPath), resolutionStack, errors, extendedConfigCache);
                }
                if (extendedConfigCache) {
                    extendedConfigCache.set(path, { extendedResult, extendedConfig });
                }
            }
            if (sourceFile) {
                (result.extendedSourceFiles ?? (result.extendedSourceFiles = /* @__PURE__ */ new Set())).add(extendedResult.fileName);
                if (extendedResult.extendedSourceFiles) {
                    for (const extenedSourceFile of extendedResult.extendedSourceFiles) {
                        result.extendedSourceFiles.add(extenedSourceFile);
                    }
                }
            }
            if (extendedResult.parseDiagnostics.length) {
                errors.push(...extendedResult.parseDiagnostics);
                return void 0;
            }
            return extendedConfig;
        }
        function convertCompileOnSaveOptionFromJson(jsonOption, basePath, errors) {
            if (!hasProperty(jsonOption, compileOnSaveCommandLineOption.name)) {
                return false;
            }
            const result = convertJsonOption(compileOnSaveCommandLineOption, jsonOption.compileOnSave, basePath, errors);
            return typeof result === "boolean" && result;
        }
        function convertCompilerOptionsFromJson(jsonOptions, basePath, configFileName) {
            const errors = [];
            const options = convertCompilerOptionsFromJsonWorker(jsonOptions, basePath, errors, configFileName);
            return { options, errors };
        }
        function convertTypeAcquisitionFromJson(jsonOptions, basePath, configFileName) {
            const errors = [];
            const options = convertTypeAcquisitionFromJsonWorker(jsonOptions, basePath, errors, configFileName);
            return { options, errors };
        }
        function getDefaultCompilerOptions(configFileName) {
            const options = configFileName && getBaseFileName(configFileName) === "jsconfig.json" ? { allowJs: true, maxNodeModuleJsDepth: 2, allowSyntheticDefaultImports: true, skipLibCheck: true, noEmit: true } : {};
            return options;
        }
        function convertCompilerOptionsFromJsonWorker(jsonOptions, basePath, errors, configFileName) {
            const options = getDefaultCompilerOptions(configFileName);
            convertOptionsFromJson(getCommandLineCompilerOptionsMap(), jsonOptions, basePath, options, compilerOptionsDidYouMeanDiagnostics, errors);
            if (configFileName) {
                options.configFilePath = normalizeSlashes(configFileName);
            }
            return options;
        }
        function getDefaultTypeAcquisition(configFileName) {
            return { enable: !!configFileName && getBaseFileName(configFileName) === "jsconfig.json", include: [], exclude: [] };
        }
        function convertTypeAcquisitionFromJsonWorker(jsonOptions, basePath, errors, configFileName) {
            const options = getDefaultTypeAcquisition(configFileName);
            convertOptionsFromJson(getCommandLineTypeAcquisitionMap(), jsonOptions, basePath, options, typeAcquisitionDidYouMeanDiagnostics, errors);
            return options;
        }
        function convertWatchOptionsFromJsonWorker(jsonOptions, basePath, errors) {
            return convertOptionsFromJson(getCommandLineWatchOptionsMap(), jsonOptions, basePath, 
            /*defaultOptions*/
            void 0, watchOptionsDidYouMeanDiagnostics, errors);
        }
        function convertOptionsFromJson(optionsNameMap, jsonOptions, basePath, defaultOptions, diagnostics, errors) {
            if (!jsonOptions) {
                return;
            }
            for (const id in jsonOptions) {
                const opt = optionsNameMap.get(id);
                if (opt) {
                    (defaultOptions || (defaultOptions = {}))[opt.name] = convertJsonOption(opt, jsonOptions[id], basePath, errors);
                }
                else {
                    errors.push(createUnknownOptionError(id, diagnostics));
                }
            }
            return defaultOptions;
        }
        function createDiagnosticForNodeInSourceFileOrCompilerDiagnostic(sourceFile, node, message, ...args) {
            return sourceFile && node ? createDiagnosticForNodeInSourceFile(sourceFile, node, message, ...args) : createCompilerDiagnostic(message, ...args);
        }
        function convertJsonOption(opt, value, basePath, errors, propertyAssignment, valueExpression, sourceFile) {
            if (opt.isCommandLineOnly) {
                errors.push(createDiagnosticForNodeInSourceFileOrCompilerDiagnostic(sourceFile, propertyAssignment == null ? void 0 : propertyAssignment.name, Diagnostics.Option_0_can_only_be_specified_on_command_line, opt.name));
                return void 0;
            }
            if (isCompilerOptionsValue(opt, value)) {
                const optType = opt.type;
                if (optType === "list" && isArray(value)) {
                    return convertJsonOptionOfListType(opt, value, basePath, errors, propertyAssignment, valueExpression, sourceFile);
                }
                else if (optType === "listOrElement") {
                    return isArray(value) ? convertJsonOptionOfListType(opt, value, basePath, errors, propertyAssignment, valueExpression, sourceFile) : convertJsonOption(opt.element, value, basePath, errors, propertyAssignment, valueExpression, sourceFile);
                }
                else if (!isString(opt.type)) {
                    return convertJsonOptionOfCustomType(opt, value, errors, valueExpression, sourceFile);
                }
                const validatedValue = validateJsonOptionValue(opt, value, errors, valueExpression, sourceFile);
                return isNullOrUndefined(validatedValue) ? validatedValue : normalizeNonListOptionValue(opt, basePath, validatedValue);
            }
            else {
                errors.push(createDiagnosticForNodeInSourceFileOrCompilerDiagnostic(sourceFile, valueExpression, Diagnostics.Compiler_option_0_requires_a_value_of_type_1, opt.name, getCompilerOptionValueTypeString(opt)));
            }
        }
        function normalizeNonListOptionValue(option, basePath, value) {
            if (option.isFilePath) {
                value = getNormalizedAbsolutePath(value, basePath);
                if (value === "") {
                    value = ".";
                }
            }
            return value;
        }
        function validateJsonOptionValue(opt, value, errors, valueExpression, sourceFile) {
            var _a;
            if (isNullOrUndefined(value))
                return void 0;
            const d = (_a = opt.extraValidation) == null ? void 0 : _a.call(opt, value);
            if (!d)
                return value;
            errors.push(createDiagnosticForNodeInSourceFileOrCompilerDiagnostic(sourceFile, valueExpression, ...d));
            return void 0;
        }
        function convertJsonOptionOfCustomType(opt, value, errors, valueExpression, sourceFile) {
            if (isNullOrUndefined(value))
                return void 0;
            const key = value.toLowerCase();
            const val = opt.type.get(key);
            if (val !== void 0) {
                return validateJsonOptionValue(opt, val, errors, valueExpression, sourceFile);
            }
            else {
                errors.push(createDiagnosticForInvalidCustomType(opt, (message, ...args) => createDiagnosticForNodeInSourceFileOrCompilerDiagnostic(sourceFile, valueExpression, message, ...args)));
            }
        }
        function convertJsonOptionOfListType(option, values, basePath, errors, propertyAssignment, valueExpression, sourceFile) {
            return filter(map(values, (v, index) => convertJsonOption(option.element, v, basePath, errors, propertyAssignment, valueExpression == null ? void 0 : valueExpression.elements[index], sourceFile)), (v) => option.listPreserveFalsyValues ? true : !!v);
        }
        function getFileNamesFromConfigSpecs(configFileSpecs, basePath, options, host, extraFileExtensions = emptyArray) {
            basePath = normalizePath(basePath);
            const keyMapper = createGetCanonicalFileName(host.useCaseSensitiveFileNames);
            const literalFileMap = /* @__PURE__ */ new Map();
            const wildcardFileMap = /* @__PURE__ */ new Map();
            const wildCardJsonFileMap = /* @__PURE__ */ new Map();
            const { validatedFilesSpec, validatedIncludeSpecs, validatedExcludeSpecs } = configFileSpecs;
            const supportedExtensions = getSupportedExtensions(options, extraFileExtensions);
            const supportedExtensionsWithJsonIfResolveJsonModule = getSupportedExtensionsWithJsonIfResolveJsonModule(options, supportedExtensions);
            if (validatedFilesSpec) {
                for (const fileName of validatedFilesSpec) {
                    const file = getNormalizedAbsolutePath(fileName, basePath);
                    literalFileMap.set(keyMapper(file), file);
                }
            }
            let jsonOnlyIncludeRegexes;
            if (validatedIncludeSpecs && validatedIncludeSpecs.length > 0) {
                for (const file of host.readDirectory(basePath, flatten(supportedExtensionsWithJsonIfResolveJsonModule), validatedExcludeSpecs, validatedIncludeSpecs, 
                /*depth*/
                void 0)) {
                    if (fileExtensionIs(file, ".json" /* Json */)) {
                        if (!jsonOnlyIncludeRegexes) {
                            const includes = validatedIncludeSpecs.filter((s) => endsWith(s, ".json" /* Json */));
                            const includeFilePatterns = map(getRegularExpressionsForWildcards(includes, basePath, "files"), (pattern) => `^${pattern}$`);
                            jsonOnlyIncludeRegexes = includeFilePatterns ? includeFilePatterns.map((pattern) => getRegexFromPattern(pattern, host.useCaseSensitiveFileNames)) : emptyArray;
                        }
                        const includeIndex = findIndex(jsonOnlyIncludeRegexes, (re) => re.test(file));
                        if (includeIndex !== -1) {
                            const key2 = keyMapper(file);
                            if (!literalFileMap.has(key2) && !wildCardJsonFileMap.has(key2)) {
                                wildCardJsonFileMap.set(key2, file);
                            }
                        }
                        continue;
                    }
                    if (hasFileWithHigherPriorityExtension(file, literalFileMap, wildcardFileMap, supportedExtensions, keyMapper)) {
                        continue;
                    }
                    removeWildcardFilesWithLowerPriorityExtension(file, wildcardFileMap, supportedExtensions, keyMapper);
                    const key = keyMapper(file);
                    if (!literalFileMap.has(key) && !wildcardFileMap.has(key)) {
                        wildcardFileMap.set(key, file);
                    }
                }
            }
            const literalFiles = arrayFrom(literalFileMap.values());
            const wildcardFiles = arrayFrom(wildcardFileMap.values());
            return literalFiles.concat(wildcardFiles, arrayFrom(wildCardJsonFileMap.values()));
        }
        function isExcludedFile(pathToCheck, spec, basePath, useCaseSensitiveFileNames2, currentDirectory) {
            const { validatedFilesSpec, validatedIncludeSpecs, validatedExcludeSpecs } = spec;
            if (!length(validatedIncludeSpecs) || !length(validatedExcludeSpecs))
                return false;
            basePath = normalizePath(basePath);
            const keyMapper = createGetCanonicalFileName(useCaseSensitiveFileNames2);
            if (validatedFilesSpec) {
                for (const fileName of validatedFilesSpec) {
                    if (keyMapper(getNormalizedAbsolutePath(fileName, basePath)) === pathToCheck)
                        return false;
                }
            }
            return matchesExcludeWorker(pathToCheck, validatedExcludeSpecs, useCaseSensitiveFileNames2, currentDirectory, basePath);
        }
        function invalidDotDotAfterRecursiveWildcard(s) {
            const wildcardIndex = startsWith(s, "**/") ? 0 : s.indexOf("/**/");
            if (wildcardIndex === -1) {
                return false;
            }
            const lastDotIndex = endsWith(s, "/..") ? s.length : s.lastIndexOf("/../");
            return lastDotIndex > wildcardIndex;
        }
        function matchesExclude(pathToCheck, excludeSpecs, useCaseSensitiveFileNames2, currentDirectory) {
            return matchesExcludeWorker(pathToCheck, filter(excludeSpecs, (spec) => !invalidDotDotAfterRecursiveWildcard(spec)), useCaseSensitiveFileNames2, currentDirectory);
        }
        function matchesExcludeWorker(pathToCheck, excludeSpecs, useCaseSensitiveFileNames2, currentDirectory, basePath) {
            const excludePattern = getRegularExpressionForWildcard(excludeSpecs, combinePaths(normalizePath(currentDirectory), basePath), "exclude");
            const excludeRegex = excludePattern && getRegexFromPattern(excludePattern, useCaseSensitiveFileNames2);
            if (!excludeRegex)
                return false;
            if (excludeRegex.test(pathToCheck))
                return true;
            return !hasExtension(pathToCheck) && excludeRegex.test(ensureTrailingDirectorySeparator(pathToCheck));
        }
        function validateSpecs(specs, errors, disallowTrailingRecursion, jsonSourceFile, specKey) {
            return specs.filter((spec) => {
                if (!isString(spec))
                    return false;
                const diag2 = specToDiagnostic(spec, disallowTrailingRecursion);
                if (diag2 !== void 0) {
                    errors.push(createDiagnostic(...diag2));
                }
                return diag2 === void 0;
            });
            function createDiagnostic(message, spec) {
                const element = getTsConfigPropArrayElementValue(jsonSourceFile, specKey, spec);
                return createDiagnosticForNodeInSourceFileOrCompilerDiagnostic(jsonSourceFile, element, message, spec);
            }
        }
        function specToDiagnostic(spec, disallowTrailingRecursion) {
            Debug.assert(typeof spec === "string");
            if (disallowTrailingRecursion && invalidTrailingRecursionPattern.test(spec)) {
                return [Diagnostics.File_specification_cannot_end_in_a_recursive_directory_wildcard_Asterisk_Asterisk_Colon_0, spec];
            }
            else if (invalidDotDotAfterRecursiveWildcard(spec)) {
                return [Diagnostics.File_specification_cannot_contain_a_parent_directory_that_appears_after_a_recursive_directory_wildcard_Asterisk_Asterisk_Colon_0, spec];
            }
        }
        function getWildcardDirectories({ validatedIncludeSpecs: include, validatedExcludeSpecs: exclude }, basePath, useCaseSensitiveFileNames2) {
            const rawExcludeRegex = getRegularExpressionForWildcard(exclude, basePath, "exclude");
            const excludeRegex = rawExcludeRegex && new RegExp(rawExcludeRegex, useCaseSensitiveFileNames2 ? "" : "i");
            const wildcardDirectories = {};
            const wildCardKeyToPath = /* @__PURE__ */ new Map();
            if (include !== void 0) {
                const recursiveKeys = [];
                for (const file of include) {
                    const spec = normalizePath(combinePaths(basePath, file));
                    if (excludeRegex && excludeRegex.test(spec)) {
                        continue;
                    }
                    const match = getWildcardDirectoryFromSpec(spec, useCaseSensitiveFileNames2);
                    if (match) {
                        const { key, path, flags } = match;
                        const existingPath = wildCardKeyToPath.get(key);
                        const existingFlags = existingPath !== void 0 ? wildcardDirectories[existingPath] : void 0;
                        if (existingFlags === void 0 || existingFlags < flags) {
                            wildcardDirectories[existingPath !== void 0 ? existingPath : path] = flags;
                            if (existingPath === void 0)
                                wildCardKeyToPath.set(key, path);
                            if (flags === 1 /* Recursive */) {
                                recursiveKeys.push(key);
                            }
                        }
                    }
                }
                for (const path in wildcardDirectories) {
                    if (hasProperty(wildcardDirectories, path)) {
                        for (const recursiveKey of recursiveKeys) {
                            const key = toCanonicalKey(path, useCaseSensitiveFileNames2);
                            if (key !== recursiveKey && containsPath(recursiveKey, key, basePath, !useCaseSensitiveFileNames2)) {
                                delete wildcardDirectories[path];
                            }
                        }
                    }
                }
            }
            return wildcardDirectories;
        }
        function toCanonicalKey(path, useCaseSensitiveFileNames2) {
            return useCaseSensitiveFileNames2 ? path : toFileNameLowerCase(path);
        }
        function getWildcardDirectoryFromSpec(spec, useCaseSensitiveFileNames2) {
            const match = wildcardDirectoryPattern.exec(spec);
            if (match) {
                const questionWildcardIndex = spec.indexOf("?");
                const starWildcardIndex = spec.indexOf("*");
                const lastDirectorySeperatorIndex = spec.lastIndexOf(directorySeparator);
                return {
                    key: toCanonicalKey(match[0], useCaseSensitiveFileNames2),
                    path: match[0],
                    flags: questionWildcardIndex !== -1 && questionWildcardIndex < lastDirectorySeperatorIndex || starWildcardIndex !== -1 && starWildcardIndex < lastDirectorySeperatorIndex ? 1 /* Recursive */ : 0 /* None */
                };
            }
            if (isImplicitGlob(spec.substring(spec.lastIndexOf(directorySeparator) + 1))) {
                const path = removeTrailingDirectorySeparator(spec);
                return {
                    key: toCanonicalKey(path, useCaseSensitiveFileNames2),
                    path,
                    flags: 1 /* Recursive */
                };
            }
            return void 0;
        }
        function hasFileWithHigherPriorityExtension(file, literalFiles, wildcardFiles, extensions, keyMapper) {
            const extensionGroup = forEach(extensions, (group2) => fileExtensionIsOneOf(file, group2) ? group2 : void 0);
            if (!extensionGroup) {
                return false;
            }
            for (const ext of extensionGroup) {
                if (fileExtensionIs(file, ext) && (ext !== ".ts" /* Ts */ || !fileExtensionIs(file, ".d.ts" /* Dts */))) {
                    return false;
                }
                const higherPriorityPath = keyMapper(changeExtension(file, ext));
                if (literalFiles.has(higherPriorityPath) || wildcardFiles.has(higherPriorityPath)) {
                    if (ext === ".d.ts" /* Dts */ && (fileExtensionIs(file, ".js" /* Js */) || fileExtensionIs(file, ".jsx" /* Jsx */))) {
                        continue;
                    }
                    return true;
                }
            }
            return false;
        }
        function removeWildcardFilesWithLowerPriorityExtension(file, wildcardFiles, extensions, keyMapper) {
            const extensionGroup = forEach(extensions, (group2) => fileExtensionIsOneOf(file, group2) ? group2 : void 0);
            if (!extensionGroup) {
                return;
            }
            for (let i = extensionGroup.length - 1; i >= 0; i--) {
                const ext = extensionGroup[i];
                if (fileExtensionIs(file, ext)) {
                    return;
                }
                const lowerPriorityPath = keyMapper(changeExtension(file, ext));
                wildcardFiles.delete(lowerPriorityPath);
            }
        }
        function convertCompilerOptionsForTelemetry(opts) {
            const out = {};
            for (const key in opts) {
                if (hasProperty(opts, key)) {
                    const type = getOptionFromName(key);
                    if (type !== void 0) {
                        out[key] = getOptionValueWithEmptyStrings(opts[key], type);
                    }
                }
            }
            return out;
        }
        function getOptionValueWithEmptyStrings(value, option) {
            if (value === void 0)
                return value;
            switch (option.type) {
                case "object":
                    return "";
                case "string":
                    return "";
                case "number":
                    return typeof value === "number" ? value : "";
                case "boolean":
                    return typeof value === "boolean" ? value : "";
                case "listOrElement":
                    if (!isArray(value))
                        return getOptionValueWithEmptyStrings(value, option.element);
                case "list":
                    const elementType = option.element;
                    return isArray(value) ? mapDefined(value, (v) => getOptionValueWithEmptyStrings(v, elementType)) : "";
                default:
                    return forEachEntry(option.type, (optionEnumValue, optionStringValue) => {
                        if (optionEnumValue === value) {
                            return optionStringValue;
                        }
                    });
            }
        }
        function getDefaultValueForOption(option) {
            switch (option.type) {
                case "number":
                    return 1;
                case "boolean":
                    return true;
                case "string":
                    const defaultValue = option.defaultValueDescription;
                    return option.isFilePath ? `./${defaultValue && typeof defaultValue === "string" ? defaultValue : ""}` : "";
                case "list":
                    return [];
                case "listOrElement":
                    return getDefaultValueForOption(option.element);
                case "object":
                    return {};
                default:
                    const value = firstOrUndefinedIterator(option.type.keys());
                    if (value !== void 0)
                        return value;
                    return Debug.fail("Expected 'option.type' to have entries.");
            }
        }
        var compileOnSaveCommandLineOption, jsxOptionMap, inverseJsxOptionMap, libEntries, libs, libMap, optionsForWatch, commonOptionsWithBuild, targetOptionDeclaration, moduleOptionDeclaration, commandOptionsWithoutBuild, optionDeclarations, semanticDiagnosticsOptionDeclarations, affectsEmitOptionDeclarations, affectsDeclarationPathOptionDeclarations, moduleResolutionOptionDeclarations, sourceFileAffectingCompilerOptions, optionsAffectingProgramStructure, transpileOptionValueCompilerOptions, optionsForBuild, buildOpts, typeAcquisitionDeclarations, optionsNameMapCache, compilerOptionsAlternateMode, defaultInitCompilerOptions, compilerOptionsDidYouMeanDiagnostics, buildOptionsNameMapCache, buildOptionsAlternateMode, buildOptionsDidYouMeanDiagnostics, typeAcquisitionDidYouMeanDiagnostics, watchOptionsNameMapCache, watchOptionsDidYouMeanDiagnostics, commandLineCompilerOptionsMapCache, commandLineWatchOptionsMapCache, commandLineTypeAcquisitionMapCache, extendsOptionDeclaration, compilerOptionsDeclaration, watchOptionsDeclaration, typeAcquisitionDeclaration, _tsconfigRootOptions, defaultIncludeSpec, invalidTrailingRecursionPattern, wildcardDirectoryPattern;
        var init_commandLineParser = __esm({
            "src/compiler/commandLineParser.ts"() {
                "use strict";
                init_ts2();
                compileOnSaveCommandLineOption = {
                    name: "compileOnSave",
                    type: "boolean",
                    defaultValueDescription: false
                };
                jsxOptionMap = new Map(Object.entries({
                    "preserve": 1 /* Preserve */,
                    "react-native": 3 /* ReactNative */,
                    "react": 2 /* React */,
                    "react-jsx": 4 /* ReactJSX */,
                    "react-jsxdev": 5 /* ReactJSXDev */
                }));
                inverseJsxOptionMap = new Map(mapIterator(jsxOptionMap.entries(), ([key, value]) => ["" + value, key]));
                libEntries = [
                    // JavaScript only
                    ["es5", "lib.es5.d.ts"],
                    ["es6", "lib.es2015.d.ts"],
                    ["es2015", "lib.es2015.d.ts"],
                    ["es7", "lib.es2016.d.ts"],
                    ["es2016", "lib.es2016.d.ts"],
                    ["es2017", "lib.es2017.d.ts"],
                    ["es2018", "lib.es2018.d.ts"],
                    ["es2019", "lib.es2019.d.ts"],
                    ["es2020", "lib.es2020.d.ts"],
                    ["es2021", "lib.es2021.d.ts"],
                    ["es2022", "lib.es2022.d.ts"],
                    ["es2023", "lib.es2023.d.ts"],
                    ["esnext", "lib.esnext.d.ts"],
                    // Host only
                    ["dom", "lib.dom.d.ts"],
                    ["dom.iterable", "lib.dom.iterable.d.ts"],
                    ["dom.asynciterable", "lib.dom.asynciterable.d.ts"],
                    ["webworker", "lib.webworker.d.ts"],
                    ["webworker.importscripts", "lib.webworker.importscripts.d.ts"],
                    ["webworker.iterable", "lib.webworker.iterable.d.ts"],
                    ["webworker.asynciterable", "lib.webworker.asynciterable.d.ts"],
                    ["scripthost", "lib.scripthost.d.ts"],
                    // ES2015 Or ESNext By-feature options
                    ["es2015.core", "lib.es2015.core.d.ts"],
                    ["es2015.collection", "lib.es2015.collection.d.ts"],
                    ["es2015.generator", "lib.es2015.generator.d.ts"],
                    ["es2015.iterable", "lib.es2015.iterable.d.ts"],
                    ["es2015.promise", "lib.es2015.promise.d.ts"],
                    ["es2015.proxy", "lib.es2015.proxy.d.ts"],
                    ["es2015.reflect", "lib.es2015.reflect.d.ts"],
                    ["es2015.symbol", "lib.es2015.symbol.d.ts"],
                    ["es2015.symbol.wellknown", "lib.es2015.symbol.wellknown.d.ts"],
                    ["es2016.array.include", "lib.es2016.array.include.d.ts"],
                    ["es2016.intl", "lib.es2016.intl.d.ts"],
                    ["es2017.date", "lib.es2017.date.d.ts"],
                    ["es2017.object", "lib.es2017.object.d.ts"],
                    ["es2017.sharedmemory", "lib.es2017.sharedmemory.d.ts"],
                    ["es2017.string", "lib.es2017.string.d.ts"],
                    ["es2017.intl", "lib.es2017.intl.d.ts"],
                    ["es2017.typedarrays", "lib.es2017.typedarrays.d.ts"],
                    ["es2018.asyncgenerator", "lib.es2018.asyncgenerator.d.ts"],
                    ["es2018.asynciterable", "lib.es2018.asynciterable.d.ts"],
                    ["es2018.intl", "lib.es2018.intl.d.ts"],
                    ["es2018.promise", "lib.es2018.promise.d.ts"],
                    ["es2018.regexp", "lib.es2018.regexp.d.ts"],
                    ["es2019.array", "lib.es2019.array.d.ts"],
                    ["es2019.object", "lib.es2019.object.d.ts"],
                    ["es2019.string", "lib.es2019.string.d.ts"],
                    ["es2019.symbol", "lib.es2019.symbol.d.ts"],
                    ["es2019.intl", "lib.es2019.intl.d.ts"],
                    ["es2020.bigint", "lib.es2020.bigint.d.ts"],
                    ["es2020.date", "lib.es2020.date.d.ts"],
                    ["es2020.promise", "lib.es2020.promise.d.ts"],
                    ["es2020.sharedmemory", "lib.es2020.sharedmemory.d.ts"],
                    ["es2020.string", "lib.es2020.string.d.ts"],
                    ["es2020.symbol.wellknown", "lib.es2020.symbol.wellknown.d.ts"],
                    ["es2020.intl", "lib.es2020.intl.d.ts"],
                    ["es2020.number", "lib.es2020.number.d.ts"],
                    ["es2021.promise", "lib.es2021.promise.d.ts"],
                    ["es2021.string", "lib.es2021.string.d.ts"],
                    ["es2021.weakref", "lib.es2021.weakref.d.ts"],
                    ["es2021.intl", "lib.es2021.intl.d.ts"],
                    ["es2022.array", "lib.es2022.array.d.ts"],
                    ["es2022.error", "lib.es2022.error.d.ts"],
                    ["es2022.intl", "lib.es2022.intl.d.ts"],
                    ["es2022.object", "lib.es2022.object.d.ts"],
                    ["es2022.sharedmemory", "lib.es2022.sharedmemory.d.ts"],
                    ["es2022.string", "lib.es2022.string.d.ts"],
                    ["es2022.regexp", "lib.es2022.regexp.d.ts"],
                    ["es2023.array", "lib.es2023.array.d.ts"],
                    ["es2023.collection", "lib.es2023.collection.d.ts"],
                    ["esnext.array", "lib.es2023.array.d.ts"],
                    ["esnext.collection", "lib.esnext.collection.d.ts"],
                    ["esnext.symbol", "lib.es2019.symbol.d.ts"],
                    ["esnext.asynciterable", "lib.es2018.asynciterable.d.ts"],
                    ["esnext.intl", "lib.esnext.intl.d.ts"],
                    ["esnext.disposable", "lib.esnext.disposable.d.ts"],
                    ["esnext.bigint", "lib.es2020.bigint.d.ts"],
                    ["esnext.string", "lib.es2022.string.d.ts"],
                    ["esnext.promise", "lib.esnext.promise.d.ts"],
                    ["esnext.weakref", "lib.es2021.weakref.d.ts"],
                    ["esnext.decorators", "lib.esnext.decorators.d.ts"],
                    ["esnext.object", "lib.esnext.object.d.ts"],
                    ["decorators", "lib.decorators.d.ts"],
                    ["decorators.legacy", "lib.decorators.legacy.d.ts"]
                ];
                libs = libEntries.map((entry) => entry[0]);
                libMap = new Map(libEntries);
                optionsForWatch = [
                    {
                        name: "watchFile",
                        type: new Map(Object.entries({
                            fixedpollinginterval: 0 /* FixedPollingInterval */,
                            prioritypollinginterval: 1 /* PriorityPollingInterval */,
                            dynamicprioritypolling: 2 /* DynamicPriorityPolling */,
                            fixedchunksizepolling: 3 /* FixedChunkSizePolling */,
                            usefsevents: 4 /* UseFsEvents */,
                            usefseventsonparentdirectory: 5 /* UseFsEventsOnParentDirectory */
                        })),
                        category: Diagnostics.Watch_and_Build_Modes,
                        description: Diagnostics.Specify_how_the_TypeScript_watch_mode_works,
                        defaultValueDescription: 4 /* UseFsEvents */
                    },
                    {
                        name: "watchDirectory",
                        type: new Map(Object.entries({
                            usefsevents: 0 /* UseFsEvents */,
                            fixedpollinginterval: 1 /* FixedPollingInterval */,
                            dynamicprioritypolling: 2 /* DynamicPriorityPolling */,
                            fixedchunksizepolling: 3 /* FixedChunkSizePolling */
                        })),
                        category: Diagnostics.Watch_and_Build_Modes,
                        description: Diagnostics.Specify_how_directories_are_watched_on_systems_that_lack_recursive_file_watching_functionality,
                        defaultValueDescription: 0 /* UseFsEvents */
                    },
                    {
                        name: "fallbackPolling",
                        type: new Map(Object.entries({
                            fixedinterval: 0 /* FixedInterval */,
                            priorityinterval: 1 /* PriorityInterval */,
                            dynamicpriority: 2 /* DynamicPriority */,
                            fixedchunksize: 3 /* FixedChunkSize */
                        })),
                        category: Diagnostics.Watch_and_Build_Modes,
                        description: Diagnostics.Specify_what_approach_the_watcher_should_use_if_the_system_runs_out_of_native_file_watchers,
                        defaultValueDescription: 1 /* PriorityInterval */
                    },
                    {
                        name: "synchronousWatchDirectory",
                        type: "boolean",
                        category: Diagnostics.Watch_and_Build_Modes,
                        description: Diagnostics.Synchronously_call_callbacks_and_update_the_state_of_directory_watchers_on_platforms_that_don_t_support_recursive_watching_natively,
                        defaultValueDescription: false
                    },
                    {
                        name: "excludeDirectories",
                        type: "list",
                        element: {
                            name: "excludeDirectory",
                            type: "string",
                            isFilePath: true,
                            extraValidation: specToDiagnostic
                        },
                        category: Diagnostics.Watch_and_Build_Modes,
                        description: Diagnostics.Remove_a_list_of_directories_from_the_watch_process
                    },
                    {
                        name: "excludeFiles",
                        type: "list",
                        element: {
                            name: "excludeFile",
                            type: "string",
                            isFilePath: true,
                            extraValidation: specToDiagnostic
                        },
                        category: Diagnostics.Watch_and_Build_Modes,
                        description: Diagnostics.Remove_a_list_of_files_from_the_watch_mode_s_processing
                    }
                ];
                commonOptionsWithBuild = [
                    {
                        name: "help",
                        shortName: "h",
                        type: "boolean",
                        showInSimplifiedHelpView: true,
                        isCommandLineOnly: true,
                        category: Diagnostics.Command_line_Options,
                        description: Diagnostics.Print_this_message,
                        defaultValueDescription: false
                    },
                    {
                        name: "help",
                        shortName: "?",
                        type: "boolean",
                        isCommandLineOnly: true,
                        category: Diagnostics.Command_line_Options,
                        defaultValueDescription: false
                    },
                    {
                        name: "watch",
                        shortName: "w",
                        type: "boolean",
                        showInSimplifiedHelpView: true,
                        isCommandLineOnly: true,
                        category: Diagnostics.Command_line_Options,
                        description: Diagnostics.Watch_input_files,
                        defaultValueDescription: false
                    },
                    {
                        name: "preserveWatchOutput",
                        type: "boolean",
                        showInSimplifiedHelpView: false,
                        category: Diagnostics.Output_Formatting,
                        description: Diagnostics.Disable_wiping_the_console_in_watch_mode,
                        defaultValueDescription: false
                    },
                    {
                        name: "listFiles",
                        type: "boolean",
                        category: Diagnostics.Compiler_Diagnostics,
                        description: Diagnostics.Print_all_of_the_files_read_during_the_compilation,
                        defaultValueDescription: false
                    },
                    {
                        name: "explainFiles",
                        type: "boolean",
                        category: Diagnostics.Compiler_Diagnostics,
                        description: Diagnostics.Print_files_read_during_the_compilation_including_why_it_was_included,
                        defaultValueDescription: false
                    },
                    {
                        name: "listEmittedFiles",
                        type: "boolean",
                        category: Diagnostics.Compiler_Diagnostics,
                        description: Diagnostics.Print_the_names_of_emitted_files_after_a_compilation,
                        defaultValueDescription: false
                    },
                    {
                        name: "pretty",
                        type: "boolean",
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Output_Formatting,
                        description: Diagnostics.Enable_color_and_formatting_in_TypeScript_s_output_to_make_compiler_errors_easier_to_read,
                        defaultValueDescription: true
                    },
                    {
                        name: "traceResolution",
                        type: "boolean",
                        category: Diagnostics.Compiler_Diagnostics,
                        description: Diagnostics.Log_paths_used_during_the_moduleResolution_process,
                        defaultValueDescription: false
                    },
                    {
                        name: "diagnostics",
                        type: "boolean",
                        category: Diagnostics.Compiler_Diagnostics,
                        description: Diagnostics.Output_compiler_performance_information_after_building,
                        defaultValueDescription: false
                    },
                    {
                        name: "extendedDiagnostics",
                        type: "boolean",
                        category: Diagnostics.Compiler_Diagnostics,
                        description: Diagnostics.Output_more_detailed_compiler_performance_information_after_building,
                        defaultValueDescription: false
                    },
                    {
                        name: "generateCpuProfile",
                        type: "string",
                        isFilePath: true,
                        paramType: Diagnostics.FILE_OR_DIRECTORY,
                        category: Diagnostics.Compiler_Diagnostics,
                        description: Diagnostics.Emit_a_v8_CPU_profile_of_the_compiler_run_for_debugging,
                        defaultValueDescription: "profile.cpuprofile"
                    },
                    {
                        name: "generateTrace",
                        type: "string",
                        isFilePath: true,
                        isCommandLineOnly: true,
                        paramType: Diagnostics.DIRECTORY,
                        category: Diagnostics.Compiler_Diagnostics,
                        description: Diagnostics.Generates_an_event_trace_and_a_list_of_types
                    },
                    {
                        name: "incremental",
                        shortName: "i",
                        type: "boolean",
                        category: Diagnostics.Projects,
                        description: Diagnostics.Save_tsbuildinfo_files_to_allow_for_incremental_compilation_of_projects,
                        transpileOptionValue: void 0,
                        defaultValueDescription: Diagnostics.false_unless_composite_is_set
                    },
                    {
                        name: "declaration",
                        shortName: "d",
                        type: "boolean",
                        // Not setting affectsEmit because we calculate this flag might not affect full emit
                        affectsBuildInfo: true,
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Emit,
                        transpileOptionValue: void 0,
                        description: Diagnostics.Generate_d_ts_files_from_TypeScript_and_JavaScript_files_in_your_project,
                        defaultValueDescription: Diagnostics.false_unless_composite_is_set
                    },
                    {
                        name: "declarationMap",
                        type: "boolean",
                        // Not setting affectsEmit because we calculate this flag might not affect full emit
                        affectsBuildInfo: true,
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Emit,
                        transpileOptionValue: void 0,
                        defaultValueDescription: false,
                        description: Diagnostics.Create_sourcemaps_for_d_ts_files
                    },
                    {
                        name: "emitDeclarationOnly",
                        type: "boolean",
                        // Not setting affectsEmit because we calculate this flag might not affect full emit
                        affectsBuildInfo: true,
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Only_output_d_ts_files_and_not_JavaScript_files,
                        transpileOptionValue: void 0,
                        defaultValueDescription: false
                    },
                    {
                        name: "sourceMap",
                        type: "boolean",
                        // Not setting affectsEmit because we calculate this flag might not affect full emit
                        affectsBuildInfo: true,
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Emit,
                        defaultValueDescription: false,
                        description: Diagnostics.Create_source_map_files_for_emitted_JavaScript_files
                    },
                    {
                        name: "inlineSourceMap",
                        type: "boolean",
                        // Not setting affectsEmit because we calculate this flag might not affect full emit
                        affectsBuildInfo: true,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Include_sourcemap_files_inside_the_emitted_JavaScript,
                        defaultValueDescription: false
                    },
                    {
                        name: "assumeChangesOnlyAffectDirectDependencies",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Watch_and_Build_Modes,
                        description: Diagnostics.Have_recompiles_in_projects_that_use_incremental_and_watch_mode_assume_that_changes_within_a_file_will_only_affect_files_directly_depending_on_it,
                        defaultValueDescription: false
                    },
                    {
                        name: "locale",
                        type: "string",
                        category: Diagnostics.Command_line_Options,
                        isCommandLineOnly: true,
                        description: Diagnostics.Set_the_language_of_the_messaging_from_TypeScript_This_does_not_affect_emit,
                        defaultValueDescription: Diagnostics.Platform_specific
                    }
                ];
                targetOptionDeclaration = {
                    name: "target",
                    shortName: "t",
                    type: new Map(Object.entries({
                        es3: 0 /* ES3 */,
                        es5: 1 /* ES5 */,
                        es6: 2 /* ES2015 */,
                        es2015: 2 /* ES2015 */,
                        es2016: 3 /* ES2016 */,
                        es2017: 4 /* ES2017 */,
                        es2018: 5 /* ES2018 */,
                        es2019: 6 /* ES2019 */,
                        es2020: 7 /* ES2020 */,
                        es2021: 8 /* ES2021 */,
                        es2022: 9 /* ES2022 */,
                        esnext: 99 /* ESNext */
                    })),
                    affectsSourceFile: true,
                    affectsModuleResolution: true,
                    affectsEmit: true,
                    affectsBuildInfo: true,
                    deprecatedKeys: /* @__PURE__ */ new Set(["es3"]),
                    paramType: Diagnostics.VERSION,
                    showInSimplifiedHelpView: true,
                    category: Diagnostics.Language_and_Environment,
                    description: Diagnostics.Set_the_JavaScript_language_version_for_emitted_JavaScript_and_include_compatible_library_declarations,
                    defaultValueDescription: 1 /* ES5 */
                };
                moduleOptionDeclaration = {
                    name: "module",
                    shortName: "m",
                    type: new Map(Object.entries({
                        none: 0 /* None */,
                        commonjs: 1 /* CommonJS */,
                        amd: 2 /* AMD */,
                        system: 4 /* System */,
                        umd: 3 /* UMD */,
                        es6: 5 /* ES2015 */,
                        es2015: 5 /* ES2015 */,
                        es2020: 6 /* ES2020 */,
                        es2022: 7 /* ES2022 */,
                        esnext: 99 /* ESNext */,
                        node16: 100 /* Node16 */,
                        nodenext: 199 /* NodeNext */,
                        preserve: 200 /* Preserve */
                    })),
                    affectsSourceFile: true,
                    affectsModuleResolution: true,
                    affectsEmit: true,
                    affectsBuildInfo: true,
                    paramType: Diagnostics.KIND,
                    showInSimplifiedHelpView: true,
                    category: Diagnostics.Modules,
                    description: Diagnostics.Specify_what_module_code_is_generated,
                    defaultValueDescription: void 0
                };
                commandOptionsWithoutBuild = [
                    // CommandLine only options
                    {
                        name: "all",
                        type: "boolean",
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Command_line_Options,
                        description: Diagnostics.Show_all_compiler_options,
                        defaultValueDescription: false
                    },
                    {
                        name: "version",
                        shortName: "v",
                        type: "boolean",
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Command_line_Options,
                        description: Diagnostics.Print_the_compiler_s_version,
                        defaultValueDescription: false
                    },
                    {
                        name: "init",
                        type: "boolean",
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Command_line_Options,
                        description: Diagnostics.Initializes_a_TypeScript_project_and_creates_a_tsconfig_json_file,
                        defaultValueDescription: false
                    },
                    {
                        name: "project",
                        shortName: "p",
                        type: "string",
                        isFilePath: true,
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Command_line_Options,
                        paramType: Diagnostics.FILE_OR_DIRECTORY,
                        description: Diagnostics.Compile_the_project_given_the_path_to_its_configuration_file_or_to_a_folder_with_a_tsconfig_json
                    },
                    {
                        name: "build",
                        type: "boolean",
                        shortName: "b",
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Command_line_Options,
                        description: Diagnostics.Build_one_or_more_projects_and_their_dependencies_if_out_of_date,
                        defaultValueDescription: false
                    },
                    {
                        name: "showConfig",
                        type: "boolean",
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Command_line_Options,
                        isCommandLineOnly: true,
                        description: Diagnostics.Print_the_final_configuration_instead_of_building,
                        defaultValueDescription: false
                    },
                    {
                        name: "listFilesOnly",
                        type: "boolean",
                        category: Diagnostics.Command_line_Options,
                        isCommandLineOnly: true,
                        description: Diagnostics.Print_names_of_files_that_are_part_of_the_compilation_and_then_stop_processing,
                        defaultValueDescription: false
                    },
                    // Basic
                    targetOptionDeclaration,
                    moduleOptionDeclaration,
                    {
                        name: "lib",
                        type: "list",
                        element: {
                            name: "lib",
                            type: libMap,
                            defaultValueDescription: void 0
                        },
                        affectsProgramStructure: true,
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Language_and_Environment,
                        description: Diagnostics.Specify_a_set_of_bundled_library_declaration_files_that_describe_the_target_runtime_environment,
                        transpileOptionValue: void 0
                    },
                    {
                        name: "allowJs",
                        type: "boolean",
                        allowJsFlag: true,
                        affectsBuildInfo: true,
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.JavaScript_Support,
                        description: Diagnostics.Allow_JavaScript_files_to_be_a_part_of_your_program_Use_the_checkJS_option_to_get_errors_from_these_files,
                        defaultValueDescription: false
                    },
                    {
                        name: "checkJs",
                        type: "boolean",
                        affectsModuleResolution: true,
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.JavaScript_Support,
                        description: Diagnostics.Enable_error_reporting_in_type_checked_JavaScript_files,
                        defaultValueDescription: false
                    },
                    {
                        name: "jsx",
                        type: jsxOptionMap,
                        affectsSourceFile: true,
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        affectsModuleResolution: true,
                        // The checker emits an error when it sees JSX but this option is not set in compilerOptions.
                        // This is effectively a semantic error, so mark this option as affecting semantic diagnostics
                        // so we know to refresh errors when this option is changed.
                        affectsSemanticDiagnostics: true,
                        paramType: Diagnostics.KIND,
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Language_and_Environment,
                        description: Diagnostics.Specify_what_JSX_code_is_generated,
                        defaultValueDescription: void 0
                    },
                    {
                        name: "outFile",
                        type: "string",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        affectsDeclarationPath: true,
                        isFilePath: true,
                        paramType: Diagnostics.FILE,
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Specify_a_file_that_bundles_all_outputs_into_one_JavaScript_file_If_declaration_is_true_also_designates_a_file_that_bundles_all_d_ts_output,
                        transpileOptionValue: void 0
                    },
                    {
                        name: "outDir",
                        type: "string",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        affectsDeclarationPath: true,
                        isFilePath: true,
                        paramType: Diagnostics.DIRECTORY,
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Specify_an_output_folder_for_all_emitted_files
                    },
                    {
                        name: "rootDir",
                        type: "string",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        affectsDeclarationPath: true,
                        isFilePath: true,
                        paramType: Diagnostics.LOCATION,
                        category: Diagnostics.Modules,
                        description: Diagnostics.Specify_the_root_folder_within_your_source_files,
                        defaultValueDescription: Diagnostics.Computed_from_the_list_of_input_files
                    },
                    {
                        name: "composite",
                        type: "boolean",
                        // Not setting affectsEmit because we calculate this flag might not affect full emit
                        affectsBuildInfo: true,
                        isTSConfigOnly: true,
                        category: Diagnostics.Projects,
                        transpileOptionValue: void 0,
                        defaultValueDescription: false,
                        description: Diagnostics.Enable_constraints_that_allow_a_TypeScript_project_to_be_used_with_project_references
                    },
                    {
                        name: "tsBuildInfoFile",
                        type: "string",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        isFilePath: true,
                        paramType: Diagnostics.FILE,
                        category: Diagnostics.Projects,
                        transpileOptionValue: void 0,
                        defaultValueDescription: ".tsbuildinfo",
                        description: Diagnostics.Specify_the_path_to_tsbuildinfo_incremental_compilation_file
                    },
                    {
                        name: "removeComments",
                        type: "boolean",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Emit,
                        defaultValueDescription: false,
                        description: Diagnostics.Disable_emitting_comments
                    },
                    {
                        name: "noEmit",
                        type: "boolean",
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Disable_emitting_files_from_a_compilation,
                        transpileOptionValue: void 0,
                        defaultValueDescription: false
                    },
                    {
                        name: "importHelpers",
                        type: "boolean",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Allow_importing_helper_functions_from_tslib_once_per_project_instead_of_including_them_per_file,
                        defaultValueDescription: false
                    },
                    {
                        name: "importsNotUsedAsValues",
                        type: new Map(Object.entries({
                            remove: 0 /* Remove */,
                            preserve: 1 /* Preserve */,
                            error: 2 /* Error */
                        })),
                        affectsEmit: true,
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Specify_emit_Slashchecking_behavior_for_imports_that_are_only_used_for_types,
                        defaultValueDescription: 0 /* Remove */
                    },
                    {
                        name: "downlevelIteration",
                        type: "boolean",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Emit_more_compliant_but_verbose_and_less_performant_JavaScript_for_iteration,
                        defaultValueDescription: false
                    },
                    {
                        name: "isolatedModules",
                        type: "boolean",
                        category: Diagnostics.Interop_Constraints,
                        description: Diagnostics.Ensure_that_each_file_can_be_safely_transpiled_without_relying_on_other_imports,
                        transpileOptionValue: true,
                        defaultValueDescription: false
                    },
                    {
                        name: "verbatimModuleSyntax",
                        type: "boolean",
                        category: Diagnostics.Interop_Constraints,
                        description: Diagnostics.Do_not_transform_or_elide_any_imports_or_exports_not_marked_as_type_only_ensuring_they_are_written_in_the_output_file_s_format_based_on_the_module_setting,
                        defaultValueDescription: false
                    },
                    // Strict Type Checks
                    {
                        name: "strict",
                        type: "boolean",
                        // Though this affects semantic diagnostics, affectsSemanticDiagnostics is not set here
                        // The value of each strictFlag depends on own strictFlag value or this and never accessed directly.
                        // But we need to store `strict` in builf info, even though it won't be examined directly, so that the
                        // flags it controls (e.g. `strictNullChecks`) will be retrieved correctly
                        affectsBuildInfo: true,
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Enable_all_strict_type_checking_options,
                        defaultValueDescription: false
                    },
                    {
                        name: "noImplicitAny",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        strictFlag: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Enable_error_reporting_for_expressions_and_declarations_with_an_implied_any_type,
                        defaultValueDescription: Diagnostics.false_unless_strict_is_set
                    },
                    {
                        name: "strictNullChecks",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        strictFlag: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.When_type_checking_take_into_account_null_and_undefined,
                        defaultValueDescription: Diagnostics.false_unless_strict_is_set
                    },
                    {
                        name: "strictFunctionTypes",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        strictFlag: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.When_assigning_functions_check_to_ensure_parameters_and_the_return_values_are_subtype_compatible,
                        defaultValueDescription: Diagnostics.false_unless_strict_is_set
                    },
                    {
                        name: "strictBindCallApply",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        strictFlag: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Check_that_the_arguments_for_bind_call_and_apply_methods_match_the_original_function,
                        defaultValueDescription: Diagnostics.false_unless_strict_is_set
                    },
                    {
                        name: "strictPropertyInitialization",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        strictFlag: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Check_for_class_properties_that_are_declared_but_not_set_in_the_constructor,
                        defaultValueDescription: Diagnostics.false_unless_strict_is_set
                    },
                    {
                        name: "noImplicitThis",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        strictFlag: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Enable_error_reporting_when_this_is_given_the_type_any,
                        defaultValueDescription: Diagnostics.false_unless_strict_is_set
                    },
                    {
                        name: "useUnknownInCatchVariables",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        strictFlag: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Default_catch_clause_variables_as_unknown_instead_of_any,
                        defaultValueDescription: Diagnostics.false_unless_strict_is_set
                    },
                    {
                        name: "alwaysStrict",
                        type: "boolean",
                        affectsSourceFile: true,
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        strictFlag: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Ensure_use_strict_is_always_emitted,
                        defaultValueDescription: Diagnostics.false_unless_strict_is_set
                    },
                    // Additional Checks
                    {
                        name: "noUnusedLocals",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Enable_error_reporting_when_local_variables_aren_t_read,
                        defaultValueDescription: false
                    },
                    {
                        name: "noUnusedParameters",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Raise_an_error_when_a_function_parameter_isn_t_read,
                        defaultValueDescription: false
                    },
                    {
                        name: "exactOptionalPropertyTypes",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Interpret_optional_property_types_as_written_rather_than_adding_undefined,
                        defaultValueDescription: false
                    },
                    {
                        name: "noImplicitReturns",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Enable_error_reporting_for_codepaths_that_do_not_explicitly_return_in_a_function,
                        defaultValueDescription: false
                    },
                    {
                        name: "noFallthroughCasesInSwitch",
                        type: "boolean",
                        affectsBindDiagnostics: true,
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Enable_error_reporting_for_fallthrough_cases_in_switch_statements,
                        defaultValueDescription: false
                    },
                    {
                        name: "noUncheckedIndexedAccess",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Add_undefined_to_a_type_when_accessed_using_an_index,
                        defaultValueDescription: false
                    },
                    {
                        name: "noImplicitOverride",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Ensure_overriding_members_in_derived_classes_are_marked_with_an_override_modifier,
                        defaultValueDescription: false
                    },
                    {
                        name: "noPropertyAccessFromIndexSignature",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        showInSimplifiedHelpView: false,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Enforces_using_indexed_accessors_for_keys_declared_using_an_indexed_type,
                        defaultValueDescription: false
                    },
                    // Module Resolution
                    {
                        name: "moduleResolution",
                        type: new Map(Object.entries({
                            // N.B. The first entry specifies the value shown in `tsc --init`
                            node10: 2 /* Node10 */,
                            node: 2 /* Node10 */,
                            classic: 1 /* Classic */,
                            node16: 3 /* Node16 */,
                            nodenext: 99 /* NodeNext */,
                            bundler: 100 /* Bundler */
                        })),
                        deprecatedKeys: /* @__PURE__ */ new Set(["node"]),
                        affectsSourceFile: true,
                        affectsModuleResolution: true,
                        paramType: Diagnostics.STRATEGY,
                        category: Diagnostics.Modules,
                        description: Diagnostics.Specify_how_TypeScript_looks_up_a_file_from_a_given_module_specifier,
                        defaultValueDescription: Diagnostics.module_AMD_or_UMD_or_System_or_ES6_then_Classic_Otherwise_Node
                    },
                    {
                        name: "baseUrl",
                        type: "string",
                        affectsModuleResolution: true,
                        isFilePath: true,
                        category: Diagnostics.Modules,
                        description: Diagnostics.Specify_the_base_directory_to_resolve_non_relative_module_names
                    },
                    {
                        // this option can only be specified in tsconfig.json
                        // use type = object to copy the value as-is
                        name: "paths",
                        type: "object",
                        affectsModuleResolution: true,
                        isTSConfigOnly: true,
                        category: Diagnostics.Modules,
                        description: Diagnostics.Specify_a_set_of_entries_that_re_map_imports_to_additional_lookup_locations,
                        transpileOptionValue: void 0
                    },
                    {
                        // this option can only be specified in tsconfig.json
                        // use type = object to copy the value as-is
                        name: "rootDirs",
                        type: "list",
                        isTSConfigOnly: true,
                        element: {
                            name: "rootDirs",
                            type: "string",
                            isFilePath: true
                        },
                        affectsModuleResolution: true,
                        category: Diagnostics.Modules,
                        description: Diagnostics.Allow_multiple_folders_to_be_treated_as_one_when_resolving_modules,
                        transpileOptionValue: void 0,
                        defaultValueDescription: Diagnostics.Computed_from_the_list_of_input_files
                    },
                    {
                        name: "typeRoots",
                        type: "list",
                        element: {
                            name: "typeRoots",
                            type: "string",
                            isFilePath: true
                        },
                        affectsModuleResolution: true,
                        category: Diagnostics.Modules,
                        description: Diagnostics.Specify_multiple_folders_that_act_like_Slashnode_modules_Slash_types
                    },
                    {
                        name: "types",
                        type: "list",
                        element: {
                            name: "types",
                            type: "string"
                        },
                        affectsProgramStructure: true,
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Modules,
                        description: Diagnostics.Specify_type_package_names_to_be_included_without_being_referenced_in_a_source_file,
                        transpileOptionValue: void 0
                    },
                    {
                        name: "allowSyntheticDefaultImports",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Interop_Constraints,
                        description: Diagnostics.Allow_import_x_from_y_when_a_module_doesn_t_have_a_default_export,
                        defaultValueDescription: Diagnostics.module_system_or_esModuleInterop
                    },
                    {
                        name: "esModuleInterop",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        showInSimplifiedHelpView: true,
                        category: Diagnostics.Interop_Constraints,
                        description: Diagnostics.Emit_additional_JavaScript_to_ease_support_for_importing_CommonJS_modules_This_enables_allowSyntheticDefaultImports_for_type_compatibility,
                        defaultValueDescription: false
                    },
                    {
                        name: "preserveSymlinks",
                        type: "boolean",
                        category: Diagnostics.Interop_Constraints,
                        description: Diagnostics.Disable_resolving_symlinks_to_their_realpath_This_correlates_to_the_same_flag_in_node,
                        defaultValueDescription: false
                    },
                    {
                        name: "allowUmdGlobalAccess",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Modules,
                        description: Diagnostics.Allow_accessing_UMD_globals_from_modules,
                        defaultValueDescription: false
                    },
                    {
                        name: "moduleSuffixes",
                        type: "list",
                        element: {
                            name: "suffix",
                            type: "string"
                        },
                        listPreserveFalsyValues: true,
                        affectsModuleResolution: true,
                        category: Diagnostics.Modules,
                        description: Diagnostics.List_of_file_name_suffixes_to_search_when_resolving_a_module
                    },
                    {
                        name: "allowImportingTsExtensions",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Modules,
                        description: Diagnostics.Allow_imports_to_include_TypeScript_file_extensions_Requires_moduleResolution_bundler_and_either_noEmit_or_emitDeclarationOnly_to_be_set,
                        defaultValueDescription: false,
                        transpileOptionValue: void 0
                    },
                    {
                        name: "resolvePackageJsonExports",
                        type: "boolean",
                        affectsModuleResolution: true,
                        category: Diagnostics.Modules,
                        description: Diagnostics.Use_the_package_json_exports_field_when_resolving_package_imports,
                        defaultValueDescription: Diagnostics.true_when_moduleResolution_is_node16_nodenext_or_bundler_otherwise_false
                    },
                    {
                        name: "resolvePackageJsonImports",
                        type: "boolean",
                        affectsModuleResolution: true,
                        category: Diagnostics.Modules,
                        description: Diagnostics.Use_the_package_json_imports_field_when_resolving_imports,
                        defaultValueDescription: Diagnostics.true_when_moduleResolution_is_node16_nodenext_or_bundler_otherwise_false
                    },
                    {
                        name: "customConditions",
                        type: "list",
                        element: {
                            name: "condition",
                            type: "string"
                        },
                        affectsModuleResolution: true,
                        category: Diagnostics.Modules,
                        description: Diagnostics.Conditions_to_set_in_addition_to_the_resolver_specific_defaults_when_resolving_imports
                    },
                    // Source Maps
                    {
                        name: "sourceRoot",
                        type: "string",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        paramType: Diagnostics.LOCATION,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Specify_the_root_path_for_debuggers_to_find_the_reference_source_code
                    },
                    {
                        name: "mapRoot",
                        type: "string",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        paramType: Diagnostics.LOCATION,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Specify_the_location_where_debugger_should_locate_map_files_instead_of_generated_locations
                    },
                    {
                        name: "inlineSources",
                        type: "boolean",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Include_source_code_in_the_sourcemaps_inside_the_emitted_JavaScript,
                        defaultValueDescription: false
                    },
                    // Experimental
                    {
                        name: "experimentalDecorators",
                        type: "boolean",
                        affectsEmit: true,
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Language_and_Environment,
                        description: Diagnostics.Enable_experimental_support_for_legacy_experimental_decorators,
                        defaultValueDescription: false
                    },
                    {
                        name: "emitDecoratorMetadata",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Language_and_Environment,
                        description: Diagnostics.Emit_design_type_metadata_for_decorated_declarations_in_source_files,
                        defaultValueDescription: false
                    },
                    // Advanced
                    {
                        name: "jsxFactory",
                        type: "string",
                        category: Diagnostics.Language_and_Environment,
                        description: Diagnostics.Specify_the_JSX_factory_function_used_when_targeting_React_JSX_emit_e_g_React_createElement_or_h,
                        defaultValueDescription: "`React.createElement`"
                    },
                    {
                        name: "jsxFragmentFactory",
                        type: "string",
                        category: Diagnostics.Language_and_Environment,
                        description: Diagnostics.Specify_the_JSX_Fragment_reference_used_for_fragments_when_targeting_React_JSX_emit_e_g_React_Fragment_or_Fragment,
                        defaultValueDescription: "React.Fragment"
                    },
                    {
                        name: "jsxImportSource",
                        type: "string",
                        affectsSemanticDiagnostics: true,
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        affectsModuleResolution: true,
                        category: Diagnostics.Language_and_Environment,
                        description: Diagnostics.Specify_module_specifier_used_to_import_the_JSX_factory_functions_when_using_jsx_Colon_react_jsx_Asterisk,
                        defaultValueDescription: "react"
                    },
                    {
                        name: "resolveJsonModule",
                        type: "boolean",
                        affectsModuleResolution: true,
                        category: Diagnostics.Modules,
                        description: Diagnostics.Enable_importing_json_files,
                        defaultValueDescription: false
                    },
                    {
                        name: "allowArbitraryExtensions",
                        type: "boolean",
                        affectsProgramStructure: true,
                        category: Diagnostics.Modules,
                        description: Diagnostics.Enable_importing_files_with_any_extension_provided_a_declaration_file_is_present,
                        defaultValueDescription: false
                    },
                    {
                        name: "out",
                        type: "string",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        affectsDeclarationPath: true,
                        isFilePath: false,
                        // This is intentionally broken to support compatibility with existing tsconfig files
                        // for correct behaviour, please use outFile
                        category: Diagnostics.Backwards_Compatibility,
                        paramType: Diagnostics.FILE,
                        transpileOptionValue: void 0,
                        description: Diagnostics.Deprecated_setting_Use_outFile_instead
                    },
                    {
                        name: "reactNamespace",
                        type: "string",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Language_and_Environment,
                        description: Diagnostics.Specify_the_object_invoked_for_createElement_This_only_applies_when_targeting_react_JSX_emit,
                        defaultValueDescription: "`React`"
                    },
                    {
                        name: "skipDefaultLibCheck",
                        type: "boolean",
                        // We need to store these to determine whether `lib` files need to be rechecked
                        affectsBuildInfo: true,
                        category: Diagnostics.Completeness,
                        description: Diagnostics.Skip_type_checking_d_ts_files_that_are_included_with_TypeScript,
                        defaultValueDescription: false
                    },
                    {
                        name: "charset",
                        type: "string",
                        category: Diagnostics.Backwards_Compatibility,
                        description: Diagnostics.No_longer_supported_In_early_versions_manually_set_the_text_encoding_for_reading_files,
                        defaultValueDescription: "utf8"
                    },
                    {
                        name: "emitBOM",
                        type: "boolean",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Emit_a_UTF_8_Byte_Order_Mark_BOM_in_the_beginning_of_output_files,
                        defaultValueDescription: false
                    },
                    {
                        name: "newLine",
                        type: new Map(Object.entries({
                            crlf: 0 /* CarriageReturnLineFeed */,
                            lf: 1 /* LineFeed */
                        })),
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        paramType: Diagnostics.NEWLINE,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Set_the_newline_character_for_emitting_files,
                        defaultValueDescription: "lf"
                    },
                    {
                        name: "noErrorTruncation",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Output_Formatting,
                        description: Diagnostics.Disable_truncating_types_in_error_messages,
                        defaultValueDescription: false
                    },
                    {
                        name: "noLib",
                        type: "boolean",
                        category: Diagnostics.Language_and_Environment,
                        affectsProgramStructure: true,
                        description: Diagnostics.Disable_including_any_library_files_including_the_default_lib_d_ts,
                        // We are not returning a sourceFile for lib file when asked by the program,
                        // so pass --noLib to avoid reporting a file not found error.
                        transpileOptionValue: true,
                        defaultValueDescription: false
                    },
                    {
                        name: "noResolve",
                        type: "boolean",
                        affectsModuleResolution: true,
                        category: Diagnostics.Modules,
                        description: Diagnostics.Disallow_import_s_require_s_or_reference_s_from_expanding_the_number_of_files_TypeScript_should_add_to_a_project,
                        // We are not doing a full typecheck, we are not resolving the whole context,
                        // so pass --noResolve to avoid reporting missing file errors.
                        transpileOptionValue: true,
                        defaultValueDescription: false
                    },
                    {
                        name: "stripInternal",
                        type: "boolean",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Disable_emitting_declarations_that_have_internal_in_their_JSDoc_comments,
                        defaultValueDescription: false
                    },
                    {
                        name: "disableSizeLimit",
                        type: "boolean",
                        affectsProgramStructure: true,
                        category: Diagnostics.Editor_Support,
                        description: Diagnostics.Remove_the_20mb_cap_on_total_source_code_size_for_JavaScript_files_in_the_TypeScript_language_server,
                        defaultValueDescription: false
                    },
                    {
                        name: "disableSourceOfProjectReferenceRedirect",
                        type: "boolean",
                        isTSConfigOnly: true,
                        category: Diagnostics.Projects,
                        description: Diagnostics.Disable_preferring_source_files_instead_of_declaration_files_when_referencing_composite_projects,
                        defaultValueDescription: false
                    },
                    {
                        name: "disableSolutionSearching",
                        type: "boolean",
                        isTSConfigOnly: true,
                        category: Diagnostics.Projects,
                        description: Diagnostics.Opt_a_project_out_of_multi_project_reference_checking_when_editing,
                        defaultValueDescription: false
                    },
                    {
                        name: "disableReferencedProjectLoad",
                        type: "boolean",
                        isTSConfigOnly: true,
                        category: Diagnostics.Projects,
                        description: Diagnostics.Reduce_the_number_of_projects_loaded_automatically_by_TypeScript,
                        defaultValueDescription: false
                    },
                    {
                        name: "noImplicitUseStrict",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Backwards_Compatibility,
                        description: Diagnostics.Disable_adding_use_strict_directives_in_emitted_JavaScript_files,
                        defaultValueDescription: false
                    },
                    {
                        name: "noEmitHelpers",
                        type: "boolean",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Disable_generating_custom_helper_functions_like_extends_in_compiled_output,
                        defaultValueDescription: false
                    },
                    {
                        name: "noEmitOnError",
                        type: "boolean",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Emit,
                        transpileOptionValue: void 0,
                        description: Diagnostics.Disable_emitting_files_if_any_type_checking_errors_are_reported,
                        defaultValueDescription: false
                    },
                    {
                        name: "preserveConstEnums",
                        type: "boolean",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Disable_erasing_const_enum_declarations_in_generated_code,
                        defaultValueDescription: false
                    },
                    {
                        name: "declarationDir",
                        type: "string",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        affectsDeclarationPath: true,
                        isFilePath: true,
                        paramType: Diagnostics.DIRECTORY,
                        category: Diagnostics.Emit,
                        transpileOptionValue: void 0,
                        description: Diagnostics.Specify_the_output_directory_for_generated_declaration_files
                    },
                    {
                        name: "skipLibCheck",
                        type: "boolean",
                        // We need to store these to determine whether `lib` files need to be rechecked
                        affectsBuildInfo: true,
                        category: Diagnostics.Completeness,
                        description: Diagnostics.Skip_type_checking_all_d_ts_files,
                        defaultValueDescription: false
                    },
                    {
                        name: "allowUnusedLabels",
                        type: "boolean",
                        affectsBindDiagnostics: true,
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Disable_error_reporting_for_unused_labels,
                        defaultValueDescription: void 0
                    },
                    {
                        name: "allowUnreachableCode",
                        type: "boolean",
                        affectsBindDiagnostics: true,
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Type_Checking,
                        description: Diagnostics.Disable_error_reporting_for_unreachable_code,
                        defaultValueDescription: void 0
                    },
                    {
                        name: "suppressExcessPropertyErrors",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Backwards_Compatibility,
                        description: Diagnostics.Disable_reporting_of_excess_property_errors_during_the_creation_of_object_literals,
                        defaultValueDescription: false
                    },
                    {
                        name: "suppressImplicitAnyIndexErrors",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Backwards_Compatibility,
                        description: Diagnostics.Suppress_noImplicitAny_errors_when_indexing_objects_that_lack_index_signatures,
                        defaultValueDescription: false
                    },
                    {
                        name: "forceConsistentCasingInFileNames",
                        type: "boolean",
                        affectsModuleResolution: true,
                        category: Diagnostics.Interop_Constraints,
                        description: Diagnostics.Ensure_that_casing_is_correct_in_imports,
                        defaultValueDescription: true
                    },
                    {
                        name: "maxNodeModuleJsDepth",
                        type: "number",
                        affectsModuleResolution: true,
                        category: Diagnostics.JavaScript_Support,
                        description: Diagnostics.Specify_the_maximum_folder_depth_used_for_checking_JavaScript_files_from_node_modules_Only_applicable_with_allowJs,
                        defaultValueDescription: 0
                    },
                    {
                        name: "noStrictGenericChecks",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Backwards_Compatibility,
                        description: Diagnostics.Disable_strict_checking_of_generic_signatures_in_function_types,
                        defaultValueDescription: false
                    },
                    {
                        name: "useDefineForClassFields",
                        type: "boolean",
                        affectsSemanticDiagnostics: true,
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Language_and_Environment,
                        description: Diagnostics.Emit_ECMAScript_standard_compliant_class_fields,
                        defaultValueDescription: Diagnostics.true_for_ES2022_and_above_including_ESNext
                    },
                    {
                        name: "preserveValueImports",
                        type: "boolean",
                        affectsEmit: true,
                        affectsBuildInfo: true,
                        category: Diagnostics.Emit,
                        description: Diagnostics.Preserve_unused_imported_values_in_the_JavaScript_output_that_would_otherwise_be_removed,
                        defaultValueDescription: false
                    },
                    {
                        name: "keyofStringsOnly",
                        type: "boolean",
                        category: Diagnostics.Backwards_Compatibility,
                        description: Diagnostics.Make_keyof_only_return_strings_instead_of_string_numbers_or_symbols_Legacy_option,
                        defaultValueDescription: false
                    },
                    {
                        // A list of plugins to load in the language service
                        name: "plugins",
                        type: "list",
                        isTSConfigOnly: true,
                        element: {
                            name: "plugin",
                            type: "object"
                        },
                        description: Diagnostics.Specify_a_list_of_language_service_plugins_to_include,
                        category: Diagnostics.Editor_Support
                    },
                    {
                        name: "moduleDetection",
                        type: new Map(Object.entries({
                            auto: 2 /* Auto */,
                            legacy: 1 /* Legacy */,
                            force: 3 /* Force */
                        })),
                        affectsSourceFile: true,
                        affectsModuleResolution: true,
                        description: Diagnostics.Control_what_method_is_used_to_detect_module_format_JS_files,
                        category: Diagnostics.Language_and_Environment,
                        defaultValueDescription: Diagnostics.auto_Colon_Treat_files_with_imports_exports_import_meta_jsx_with_jsx_Colon_react_jsx_or_esm_format_with_module_Colon_node16_as_modules
                    },
                    {
                        name: "ignoreDeprecations",
                        type: "string",
                        defaultValueDescription: void 0
                    }
                ];
                optionDeclarations = [
                    ...commonOptionsWithBuild,
                    ...commandOptionsWithoutBuild
                ];
                semanticDiagnosticsOptionDeclarations = optionDeclarations.filter((option) => !!option.affectsSemanticDiagnostics);
                affectsEmitOptionDeclarations = optionDeclarations.filter((option) => !!option.affectsEmit);
                affectsDeclarationPathOptionDeclarations = optionDeclarations.filter((option) => !!option.affectsDeclarationPath);
                moduleResolutionOptionDeclarations = optionDeclarations.filter((option) => !!option.affectsModuleResolution);
                sourceFileAffectingCompilerOptions = optionDeclarations.filter((option) => !!option.affectsSourceFile || !!option.affectsBindDiagnostics);
                optionsAffectingProgramStructure = optionDeclarations.filter((option) => !!option.affectsProgramStructure);
                transpileOptionValueCompilerOptions = optionDeclarations.filter((option) => hasProperty(option, "transpileOptionValue"));
                optionsForBuild = [
                    {
                        name: "verbose",
                        shortName: "v",
                        category: Diagnostics.Command_line_Options,
                        description: Diagnostics.Enable_verbose_logging,
                        type: "boolean",
                        defaultValueDescription: false
                    },
                    {
                        name: "dry",
                        shortName: "d",
                        category: Diagnostics.Command_line_Options,
                        description: Diagnostics.Show_what_would_be_built_or_deleted_if_specified_with_clean,
                        type: "boolean",
                        defaultValueDescription: false
                    },
                    {
                        name: "force",
                        shortName: "f",
                        category: Diagnostics.Command_line_Options,
                        description: Diagnostics.Build_all_projects_including_those_that_appear_to_be_up_to_date,
                        type: "boolean",
                        defaultValueDescription: false
                    },
                    {
                        name: "clean",
                        category: Diagnostics.Command_line_Options,
                        description: Diagnostics.Delete_the_outputs_of_all_projects,
                        type: "boolean",
                        defaultValueDescription: false
                    }
                ];
                buildOpts = [
                    ...commonOptionsWithBuild,
                    ...optionsForBuild
                ];
                typeAcquisitionDeclarations = [
                    {
                        name: "enable",
                        type: "boolean",
                        defaultValueDescription: false
                    },
                    {
                        name: "include",
                        type: "list",
                        element: {
                            name: "include",
                            type: "string"
                        }
                    },
                    {
                        name: "exclude",
                        type: "list",
                        element: {
                            name: "exclude",
                            type: "string"
                        }
                    },
                    {
                        name: "disableFilenameBasedTypeAcquisition",
                        type: "boolean",
                        defaultValueDescription: false
                    }
                ];
                compilerOptionsAlternateMode = {
                    diagnostic: Diagnostics.Compiler_option_0_may_only_be_used_with_build,
                    getOptionsNameMap: getBuildOptionsNameMap
                };
                defaultInitCompilerOptions = {
                    module: 1 /* CommonJS */,
                    target: 3 /* ES2016 */,
                    strict: true,
                    esModuleInterop: true,
                    forceConsistentCasingInFileNames: true,
                    skipLibCheck: true
                };
                compilerOptionsDidYouMeanDiagnostics = {
                    alternateMode: compilerOptionsAlternateMode,
                    getOptionsNameMap,
                    optionDeclarations,
                    unknownOptionDiagnostic: Diagnostics.Unknown_compiler_option_0,
                    unknownDidYouMeanDiagnostic: Diagnostics.Unknown_compiler_option_0_Did_you_mean_1,
                    optionTypeMismatchDiagnostic: Diagnostics.Compiler_option_0_expects_an_argument
                };
                buildOptionsAlternateMode = {
                    diagnostic: Diagnostics.Compiler_option_0_may_not_be_used_with_build,
                    getOptionsNameMap
                };
                buildOptionsDidYouMeanDiagnostics = {
                    alternateMode: buildOptionsAlternateMode,
                    getOptionsNameMap: getBuildOptionsNameMap,
                    optionDeclarations: buildOpts,
                    unknownOptionDiagnostic: Diagnostics.Unknown_build_option_0,
                    unknownDidYouMeanDiagnostic: Diagnostics.Unknown_build_option_0_Did_you_mean_1,
                    optionTypeMismatchDiagnostic: Diagnostics.Build_option_0_requires_a_value_of_type_1
                };
                typeAcquisitionDidYouMeanDiagnostics = {
                    optionDeclarations: typeAcquisitionDeclarations,
                    unknownOptionDiagnostic: Diagnostics.Unknown_type_acquisition_option_0,
                    unknownDidYouMeanDiagnostic: Diagnostics.Unknown_type_acquisition_option_0_Did_you_mean_1
                };
                watchOptionsDidYouMeanDiagnostics = {
                    getOptionsNameMap: getWatchOptionsNameMap,
                    optionDeclarations: optionsForWatch,
                    unknownOptionDiagnostic: Diagnostics.Unknown_watch_option_0,
                    unknownDidYouMeanDiagnostic: Diagnostics.Unknown_watch_option_0_Did_you_mean_1,
                    optionTypeMismatchDiagnostic: Diagnostics.Watch_option_0_requires_a_value_of_type_1
                };
                extendsOptionDeclaration = {
                    name: "extends",
                    type: "listOrElement",
                    element: {
                        name: "extends",
                        type: "string"
                    },
                    category: Diagnostics.File_Management,
                    disallowNullOrUndefined: true
                };
                compilerOptionsDeclaration = {
                    name: "compilerOptions",
                    type: "object",
                    elementOptions: getCommandLineCompilerOptionsMap(),
                    extraKeyDiagnostics: compilerOptionsDidYouMeanDiagnostics
                };
                watchOptionsDeclaration = {
                    name: "watchOptions",
                    type: "object",
                    elementOptions: getCommandLineWatchOptionsMap(),
                    extraKeyDiagnostics: watchOptionsDidYouMeanDiagnostics
                };
                typeAcquisitionDeclaration = {
                    name: "typeAcquisition",
                    type: "object",
                    elementOptions: getCommandLineTypeAcquisitionMap(),
                    extraKeyDiagnostics: typeAcquisitionDidYouMeanDiagnostics
                };
                defaultIncludeSpec = "**/*";
                invalidTrailingRecursionPattern = /(^|\/)\*\*\/?$/;
                wildcardDirectoryPattern = /^[^*?]*(?=\/[^/]*[*?])/;
            }
        });
        // src/compiler/moduleNameResolver.ts
        function trace(host, message, ...args) {
            host.trace(formatMessage(message, ...args));
        }
        function isTraceEnabled(compilerOptions, host) {
            return !!compilerOptions.traceResolution && host.trace !== void 0;
        }
        function withPackageId(packageInfo, r) {
            let packageId;
            if (r && packageInfo) {
                const packageJsonContent = packageInfo.contents.packageJsonContent;
                if (typeof packageJsonContent.name === "string" && typeof packageJsonContent.version === "string") {
                    packageId = {
                        name: packageJsonContent.name,
                        subModuleName: r.path.slice(packageInfo.packageDirectory.length + directorySeparator.length),
                        version: packageJsonContent.version
                    };
                }
            }
            return r && { path: r.path, extension: r.ext, packageId, resolvedUsingTsExtension: r.resolvedUsingTsExtension };
        }
        function noPackageId(r) {
            return withPackageId(
            /*packageInfo*/
            void 0, r);
        }
        function removeIgnoredPackageId(r) {
            if (r) {
                Debug.assert(r.packageId === void 0);
                return { path: r.path, ext: r.extension, resolvedUsingTsExtension: r.resolvedUsingTsExtension };
            }
        }
        function formatExtensions(extensions) {
            const result = [];
            if (extensions & 1 /* TypeScript */)
                result.push("TypeScript");
            if (extensions & 2 /* JavaScript */)
                result.push("JavaScript");
            if (extensions & 4 /* Declaration */)
                result.push("Declaration");
            if (extensions & 8 /* Json */)
                result.push("JSON");
            return result.join(", ");
        }
        function extensionsToExtensionsArray(extensions) {
            const result = [];
            if (extensions & 1 /* TypeScript */)
                result.push(...supportedTSImplementationExtensions);
            if (extensions & 2 /* JavaScript */)
                result.push(...supportedJSExtensionsFlat);
            if (extensions & 4 /* Declaration */)
                result.push(...supportedDeclarationExtensions);
            if (extensions & 8 /* Json */)
                result.push(".json" /* Json */);
            return result;
        }
        function resolvedTypeScriptOnly(resolved) {
            if (!resolved) {
                return void 0;
            }
            Debug.assert(extensionIsTS(resolved.extension));
            return { fileName: resolved.path, packageId: resolved.packageId };
        }
        function createResolvedModuleWithFailedLookupLocationsHandlingSymlink(moduleName, resolved, isExternalLibraryImport, failedLookupLocations, affectingLocations, diagnostics, state, cache, alternateResult) {
            if (!state.resultFromCache && !state.compilerOptions.preserveSymlinks && resolved && isExternalLibraryImport && !resolved.originalPath && !isExternalModuleNameRelative(moduleName)) {
                const { resolvedFileName, originalPath } = getOriginalAndResolvedFileName(resolved.path, state.host, state.traceEnabled);
                if (originalPath)
                    resolved = { ...resolved, path: resolvedFileName, originalPath };
            }
            return createResolvedModuleWithFailedLookupLocations(resolved, isExternalLibraryImport, failedLookupLocations, affectingLocations, diagnostics, state.resultFromCache, cache, alternateResult);
        }
        function createResolvedModuleWithFailedLookupLocations(resolved, isExternalLibraryImport, failedLookupLocations, affectingLocations, diagnostics, resultFromCache, cache, alternateResult) {
            if (resultFromCache) {
                if (!(cache == null ? void 0 : cache.isReadonly)) {
                    resultFromCache.failedLookupLocations = updateResolutionField(resultFromCache.failedLookupLocations, failedLookupLocations);
                    resultFromCache.affectingLocations = updateResolutionField(resultFromCache.affectingLocations, affectingLocations);
                    resultFromCache.resolutionDiagnostics = updateResolutionField(resultFromCache.resolutionDiagnostics, diagnostics);
                    return resultFromCache;
                }
                else {
                    return {
                        ...resultFromCache,
                        failedLookupLocations: initializeResolutionFieldForReadonlyCache(resultFromCache.failedLookupLocations, failedLookupLocations),
                        affectingLocations: initializeResolutionFieldForReadonlyCache(resultFromCache.affectingLocations, affectingLocations),
                        resolutionDiagnostics: initializeResolutionFieldForReadonlyCache(resultFromCache.resolutionDiagnostics, diagnostics)
                    };
                }
            }
            return {
                resolvedModule: resolved && {
                    resolvedFileName: resolved.path,
                    originalPath: resolved.originalPath === true ? void 0 : resolved.originalPath,
                    extension: resolved.extension,
                    isExternalLibraryImport,
                    packageId: resolved.packageId,
                    resolvedUsingTsExtension: !!resolved.resolvedUsingTsExtension
                },
                failedLookupLocations: initializeResolutionField(failedLookupLocations),
                affectingLocations: initializeResolutionField(affectingLocations),
                resolutionDiagnostics: initializeResolutionField(diagnostics),
                alternateResult
            };
        }
        function initializeResolutionField(value) {
            return value.length ? value : void 0;
        }
        function updateResolutionField(to, value) {
            if (!(value == null ? void 0 : value.length))
                return to;
            if (!(to == null ? void 0 : to.length))
                return value;
            to.push(...value);
            return to;
        }
        function initializeResolutionFieldForReadonlyCache(fromCache, value) {
            if (!(fromCache == null ? void 0 : fromCache.length))
                return initializeResolutionField(value);
            if (!value.length)
                return fromCache.slice();
            return [...fromCache, ...value];
        }
        function readPackageJsonField(jsonContent, fieldName, typeOfTag, state) {
            if (!hasProperty(jsonContent, fieldName)) {
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.package_json_does_not_have_a_0_field, fieldName);
                }
                return;
            }
            const value = jsonContent[fieldName];
            if (typeof value !== typeOfTag || value === null) {
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.Expected_type_of_0_field_in_package_json_to_be_1_got_2, fieldName, typeOfTag, value === null ? "null" : typeof value);
                }
                return;
            }
            return value;
        }
        function readPackageJsonPathField(jsonContent, fieldName, baseDirectory, state) {
            const fileName = readPackageJsonField(jsonContent, fieldName, "string", state);
            if (fileName === void 0) {
                return;
            }
            if (!fileName) {
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.package_json_had_a_falsy_0_field, fieldName);
                }
                return;
            }
            const path = normalizePath(combinePaths(baseDirectory, fileName));
            if (state.traceEnabled) {
                trace(state.host, Diagnostics.package_json_has_0_field_1_that_references_2, fieldName, fileName, path);
            }
            return path;
        }
        function readPackageJsonTypesFields(jsonContent, baseDirectory, state) {
            return readPackageJsonPathField(jsonContent, "typings", baseDirectory, state) || readPackageJsonPathField(jsonContent, "types", baseDirectory, state);
        }
        function readPackageJsonTSConfigField(jsonContent, baseDirectory, state) {
            return readPackageJsonPathField(jsonContent, "tsconfig", baseDirectory, state);
        }
        function readPackageJsonMainField(jsonContent, baseDirectory, state) {
            return readPackageJsonPathField(jsonContent, "main", baseDirectory, state);
        }
        function readPackageJsonTypesVersionsField(jsonContent, state) {
            const typesVersions = readPackageJsonField(jsonContent, "typesVersions", "object", state);
            if (typesVersions === void 0)
                return;
            if (state.traceEnabled) {
                trace(state.host, Diagnostics.package_json_has_a_typesVersions_field_with_version_specific_path_mappings);
            }
            return typesVersions;
        }
        function readPackageJsonTypesVersionPaths(jsonContent, state) {
            const typesVersions = readPackageJsonTypesVersionsField(jsonContent, state);
            if (typesVersions === void 0)
                return;
            if (state.traceEnabled) {
                for (const key in typesVersions) {
                    if (hasProperty(typesVersions, key) && !VersionRange.tryParse(key)) {
                        trace(state.host, Diagnostics.package_json_has_a_typesVersions_entry_0_that_is_not_a_valid_semver_range, key);
                    }
                }
            }
            const result = getPackageJsonTypesVersionsPaths(typesVersions);
            if (!result) {
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.package_json_does_not_have_a_typesVersions_entry_that_matches_version_0, versionMajorMinor);
                }
                return;
            }
            const { version: bestVersionKey, paths: bestVersionPaths } = result;
            if (typeof bestVersionPaths !== "object") {
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.Expected_type_of_0_field_in_package_json_to_be_1_got_2, `typesVersions['${bestVersionKey}']`, "object", typeof bestVersionPaths);
                }
                return;
            }
            return result;
        }
        function getPackageJsonTypesVersionsPaths(typesVersions) {
            if (!typeScriptVersion)
                typeScriptVersion = new Version(version);
            for (const key in typesVersions) {
                if (!hasProperty(typesVersions, key))
                    continue;
                const keyRange = VersionRange.tryParse(key);
                if (keyRange === void 0) {
                    continue;
                }
                if (keyRange.test(typeScriptVersion)) {
                    return { version: key, paths: typesVersions[key] };
                }
            }
        }
        function getEffectiveTypeRoots(options, host) {
            if (options.typeRoots) {
                return options.typeRoots;
            }
            let currentDirectory;
            if (options.configFilePath) {
                currentDirectory = getDirectoryPath(options.configFilePath);
            }
            else if (host.getCurrentDirectory) {
                currentDirectory = host.getCurrentDirectory();
            }
            if (currentDirectory !== void 0) {
                return getDefaultTypeRoots(currentDirectory);
            }
        }
        function getDefaultTypeRoots(currentDirectory) {
            let typeRoots;
            forEachAncestorDirectory(normalizePath(currentDirectory), (directory) => {
                const atTypes = combinePaths(directory, nodeModulesAtTypes);
                (typeRoots ?? (typeRoots = [])).push(atTypes);
            });
            return typeRoots;
        }
        function arePathsEqual(path1, path2, host) {
            const useCaseSensitiveFileNames2 = typeof host.useCaseSensitiveFileNames === "function" ? host.useCaseSensitiveFileNames() : host.useCaseSensitiveFileNames;
            return comparePaths(path1, path2, !useCaseSensitiveFileNames2) === 0 /* EqualTo */;
        }
        function getOriginalAndResolvedFileName(fileName, host, traceEnabled) {
            const resolvedFileName = realPath(fileName, host, traceEnabled);
            const pathsAreEqual = arePathsEqual(fileName, resolvedFileName, host);
            return {
                // If the fileName and realpath are differing only in casing prefer fileName so that we can issue correct errors for casing under forceConsistentCasingInFileNames
                resolvedFileName: pathsAreEqual ? fileName : resolvedFileName,
                originalPath: pathsAreEqual ? void 0 : fileName
            };
        }
        function getCandidateFromTypeRoot(typeRoot, typeReferenceDirectiveName, moduleResolutionState) {
            const nameForLookup = endsWith(typeRoot, "/node_modules/@types") || endsWith(typeRoot, "/node_modules/@types/") ? mangleScopedPackageNameWithTrace(typeReferenceDirectiveName, moduleResolutionState) : typeReferenceDirectiveName;
            return combinePaths(typeRoot, nameForLookup);
        }
        function resolveTypeReferenceDirective(typeReferenceDirectiveName, containingFile, options, host, redirectedReference, cache, resolutionMode) {
            Debug.assert(typeof typeReferenceDirectiveName === "string", "Non-string value passed to `ts.resolveTypeReferenceDirective`, likely by a wrapping package working with an outdated `resolveTypeReferenceDirectives` signature. This is probably not a problem in TS itself.");
            const traceEnabled = isTraceEnabled(options, host);
            if (redirectedReference) {
                options = redirectedReference.commandLine.options;
            }
            const containingDirectory = containingFile ? getDirectoryPath(containingFile) : void 0;
            let result = containingDirectory ? cache == null ? void 0 : cache.getFromDirectoryCache(typeReferenceDirectiveName, resolutionMode, containingDirectory, redirectedReference) : void 0;
            if (!result && containingDirectory && !isExternalModuleNameRelative(typeReferenceDirectiveName)) {
                result = cache == null ? void 0 : cache.getFromNonRelativeNameCache(typeReferenceDirectiveName, resolutionMode, containingDirectory, redirectedReference);
            }
            if (result) {
                if (traceEnabled) {
                    trace(host, Diagnostics.Resolving_type_reference_directive_0_containing_file_1, typeReferenceDirectiveName, containingFile);
                    if (redirectedReference)
                        trace(host, Diagnostics.Using_compiler_options_of_project_reference_redirect_0, redirectedReference.sourceFile.fileName);
                    trace(host, Diagnostics.Resolution_for_type_reference_directive_0_was_found_in_cache_from_location_1, typeReferenceDirectiveName, containingDirectory);
                    traceResult(result);
                }
                return result;
            }
            const typeRoots = getEffectiveTypeRoots(options, host);
            if (traceEnabled) {
                if (containingFile === void 0) {
                    if (typeRoots === void 0) {
                        trace(host, Diagnostics.Resolving_type_reference_directive_0_containing_file_not_set_root_directory_not_set, typeReferenceDirectiveName);
                    }
                    else {
                        trace(host, Diagnostics.Resolving_type_reference_directive_0_containing_file_not_set_root_directory_1, typeReferenceDirectiveName, typeRoots);
                    }
                }
                else {
                    if (typeRoots === void 0) {
                        trace(host, Diagnostics.Resolving_type_reference_directive_0_containing_file_1_root_directory_not_set, typeReferenceDirectiveName, containingFile);
                    }
                    else {
                        trace(host, Diagnostics.Resolving_type_reference_directive_0_containing_file_1_root_directory_2, typeReferenceDirectiveName, containingFile, typeRoots);
                    }
                }
                if (redirectedReference) {
                    trace(host, Diagnostics.Using_compiler_options_of_project_reference_redirect_0, redirectedReference.sourceFile.fileName);
                }
            }
            const failedLookupLocations = [];
            const affectingLocations = [];
            let features = getNodeResolutionFeatures(options);
            if (resolutionMode !== void 0) {
                features |= 30 /* AllFeatures */;
            }
            const moduleResolution = getEmitModuleResolutionKind(options);
            if (resolutionMode === 99 /* ESNext */ && (3 /* Node16 */ <= moduleResolution && moduleResolution <= 99 /* NodeNext */)) {
                features |= 32 /* EsmMode */;
            }
            const conditions = features & 8 /* Exports */ ? getConditions(options, resolutionMode) : [];
            const diagnostics = [];
            const moduleResolutionState = {
                compilerOptions: options,
                host,
                traceEnabled,
                failedLookupLocations,
                affectingLocations,
                packageJsonInfoCache: cache,
                features,
                conditions,
                requestContainingDirectory: containingDirectory,
                reportDiagnostic: (diag2) => void diagnostics.push(diag2),
                isConfigLookup: false,
                candidateIsFromPackageJsonField: false,
                resolvedPackageDirectory: false
            };
            let resolved = primaryLookup();
            let primary = true;
            if (!resolved) {
                resolved = secondaryLookup();
                primary = false;
            }
            let resolvedTypeReferenceDirective;
            if (resolved) {
                const { fileName, packageId } = resolved;
                let resolvedFileName = fileName, originalPath;
                if (!options.preserveSymlinks)
                    ({ resolvedFileName, originalPath } = getOriginalAndResolvedFileName(fileName, host, traceEnabled));
                resolvedTypeReferenceDirective = {
                    primary,
                    resolvedFileName,
                    originalPath,
                    packageId,
                    isExternalLibraryImport: pathContainsNodeModules(fileName)
                };
            }
            result = {
                resolvedTypeReferenceDirective,
                failedLookupLocations: initializeResolutionField(failedLookupLocations),
                affectingLocations: initializeResolutionField(affectingLocations),
                resolutionDiagnostics: initializeResolutionField(diagnostics)
            };
            if (containingDirectory && cache && !cache.isReadonly) {
                cache.getOrCreateCacheForDirectory(containingDirectory, redirectedReference).set(typeReferenceDirectiveName, 
                /*mode*/
                resolutionMode, result);
                if (!isExternalModuleNameRelative(typeReferenceDirectiveName)) {
                    cache.getOrCreateCacheForNonRelativeName(typeReferenceDirectiveName, resolutionMode, redirectedReference).set(containingDirectory, result);
                }
            }
            if (traceEnabled)
                traceResult(result);
            return result;
            function traceResult(result2) {
                var _a;
                if (!((_a = result2.resolvedTypeReferenceDirective) == null ? void 0 : _a.resolvedFileName)) {
                    trace(host, Diagnostics.Type_reference_directive_0_was_not_resolved, typeReferenceDirectiveName);
                }
                else if (result2.resolvedTypeReferenceDirective.packageId) {
                    trace(host, Diagnostics.Type_reference_directive_0_was_successfully_resolved_to_1_with_Package_ID_2_primary_Colon_3, typeReferenceDirectiveName, result2.resolvedTypeReferenceDirective.resolvedFileName, packageIdToString(result2.resolvedTypeReferenceDirective.packageId), result2.resolvedTypeReferenceDirective.primary);
                }
                else {
                    trace(host, Diagnostics.Type_reference_directive_0_was_successfully_resolved_to_1_primary_Colon_2, typeReferenceDirectiveName, result2.resolvedTypeReferenceDirective.resolvedFileName, result2.resolvedTypeReferenceDirective.primary);
                }
            }
            function primaryLookup() {
                if (typeRoots && typeRoots.length) {
                    if (traceEnabled) {
                        trace(host, Diagnostics.Resolving_with_primary_search_path_0, typeRoots.join(", "));
                    }
                    return firstDefined(typeRoots, (typeRoot) => {
                        const candidate = getCandidateFromTypeRoot(typeRoot, typeReferenceDirectiveName, moduleResolutionState);
                        const directoryExists = directoryProbablyExists(typeRoot, host);
                        if (!directoryExists && traceEnabled) {
                            trace(host, Diagnostics.Directory_0_does_not_exist_skipping_all_lookups_in_it, typeRoot);
                        }
                        if (options.typeRoots) {
                            const resolvedFromFile = loadModuleFromFile(4 /* Declaration */, candidate, !directoryExists, moduleResolutionState);
                            if (resolvedFromFile) {
                                const packageDirectory = parseNodeModuleFromPath(resolvedFromFile.path);
                                const packageInfo = packageDirectory ? getPackageJsonInfo(packageDirectory, 
                                /*onlyRecordFailures*/
                                false, moduleResolutionState) : void 0;
                                return resolvedTypeScriptOnly(withPackageId(packageInfo, resolvedFromFile));
                            }
                        }
                        return resolvedTypeScriptOnly(loadNodeModuleFromDirectory(4 /* Declaration */, candidate, !directoryExists, moduleResolutionState));
                    });
                }
                else {
                    if (traceEnabled) {
                        trace(host, Diagnostics.Root_directory_cannot_be_determined_skipping_primary_search_paths);
                    }
                }
            }
            function secondaryLookup() {
                const initialLocationForSecondaryLookup = containingFile && getDirectoryPath(containingFile);
                if (initialLocationForSecondaryLookup !== void 0) {
                    let result2;
                    if (!options.typeRoots || !endsWith(containingFile, inferredTypesContainingFile)) {
                        if (traceEnabled) {
                            trace(host, Diagnostics.Looking_up_in_node_modules_folder_initial_location_0, initialLocationForSecondaryLookup);
                        }
                        if (!isExternalModuleNameRelative(typeReferenceDirectiveName)) {
                            const searchResult = loadModuleFromNearestNodeModulesDirectory(4 /* Declaration */, typeReferenceDirectiveName, initialLocationForSecondaryLookup, moduleResolutionState, 
                            /*cache*/
                            void 0, 
                            /*redirectedReference*/
                            void 0);
                            result2 = searchResult && searchResult.value;
                        }
                        else {
                            const { path: candidate } = normalizePathForCJSResolution(initialLocationForSecondaryLookup, typeReferenceDirectiveName);
                            result2 = nodeLoadModuleByRelativeName(4 /* Declaration */, candidate, 
                            /*onlyRecordFailures*/
                            false, moduleResolutionState, 
                            /*considerPackageJson*/
                            true);
                        }
                    }
                    else if (traceEnabled) {
                        trace(host, Diagnostics.Resolving_type_reference_directive_for_program_that_specifies_custom_typeRoots_skipping_lookup_in_node_modules_folder);
                    }
                    return resolvedTypeScriptOnly(result2);
                }
                else {
                    if (traceEnabled) {
                        trace(host, Diagnostics.Containing_file_is_not_specified_and_root_directory_cannot_be_determined_skipping_lookup_in_node_modules_folder);
                    }
                }
            }
        }
        function getNodeResolutionFeatures(options) {
            let features = 0 /* None */;
            switch (getEmitModuleResolutionKind(options)) {
                case 3 /* Node16 */:
                    features = 30 /* Node16Default */;
                    break;
                case 99 /* NodeNext */:
                    features = 30 /* NodeNextDefault */;
                    break;
                case 100 /* Bundler */:
                    features = 30 /* BundlerDefault */;
                    break;
            }
            if (options.resolvePackageJsonExports) {
                features |= 8 /* Exports */;
            }
            else if (options.resolvePackageJsonExports === false) {
                features &= ~8 /* Exports */;
            }
            if (options.resolvePackageJsonImports) {
                features |= 2 /* Imports */;
            }
            else if (options.resolvePackageJsonImports === false) {
                features &= ~2 /* Imports */;
            }
            return features;
        }
        function getConditions(options, resolutionMode) {
            const moduleResolution = getEmitModuleResolutionKind(options);
            if (resolutionMode === void 0) {
                if (moduleResolution === 100 /* Bundler */) {
                    resolutionMode = 99 /* ESNext */;
                }
                else if (moduleResolution === 2 /* Node10 */) {
                    return [];
                }
            }
            const conditions = resolutionMode === 99 /* ESNext */ ? ["import"] : ["require"];
            if (!options.noDtsResolution) {
                conditions.push("types");
            }
            if (moduleResolution !== 100 /* Bundler */) {
                conditions.push("node");
            }
            return concatenate(conditions, options.customConditions);
        }
        function resolvePackageNameToPackageJson(packageName, containingDirectory, options, host, cache) {
            const moduleResolutionState = getTemporaryModuleResolutionState(cache == null ? void 0 : cache.getPackageJsonInfoCache(), host, options);
            return forEachAncestorDirectory(containingDirectory, (ancestorDirectory) => {
                if (getBaseFileName(ancestorDirectory) !== "node_modules") {
                    const nodeModulesFolder = combinePaths(ancestorDirectory, "node_modules");
                    const candidate = combinePaths(nodeModulesFolder, packageName);
                    return getPackageJsonInfo(candidate, 
                    /*onlyRecordFailures*/
                    false, moduleResolutionState);
                }
            });
        }
        function getAutomaticTypeDirectiveNames(options, host) {
            if (options.types) {
                return options.types;
            }
            const result = [];
            if (host.directoryExists && host.getDirectories) {
                const typeRoots = getEffectiveTypeRoots(options, host);
                if (typeRoots) {
                    for (const root of typeRoots) {
                        if (host.directoryExists(root)) {
                            for (const typeDirectivePath of host.getDirectories(root)) {
                                const normalized = normalizePath(typeDirectivePath);
                                const packageJsonPath = combinePaths(root, normalized, "package.json");
                                const isNotNeededPackage = host.fileExists(packageJsonPath) && readJson(packageJsonPath, host).typings === null;
                                if (!isNotNeededPackage) {
                                    const baseFileName = getBaseFileName(normalized);
                                    if (baseFileName.charCodeAt(0) !== 46 /* dot */) {
                                        result.push(baseFileName);
                                    }
                                }
                            }
                        }
                    }
                }
            }
            return result;
        }
        function isPackageJsonInfo(entry) {
            return !!(entry == null ? void 0 : entry.contents);
        }
        function isMissingPackageJsonInfo(entry) {
            return !!entry && !entry.contents;
        }
        function compilerOptionValueToString(value) {
            var _a;
            if (value === null || typeof value !== "object") {
                return "" + value;
            }
            if (isArray(value)) {
                return `[${(_a = value.map((e) => compilerOptionValueToString(e))) == null ? void 0 : _a.join(",")}]`;
            }
            let str = "{";
            for (const key in value) {
                if (hasProperty(value, key)) {
                    str += `${key}: ${compilerOptionValueToString(value[key])}`;
                }
            }
            return str + "}";
        }
        function getKeyForCompilerOptions(options, affectingOptionDeclarations) {
            return affectingOptionDeclarations.map((option) => compilerOptionValueToString(getCompilerOptionValue(options, option))).join("|") + `|${options.pathsBasePath}`;
        }
        function createCacheWithRedirects(ownOptions, optionsToRedirectsKey) {
            const redirectsMap = /* @__PURE__ */ new Map();
            const redirectsKeyToMap = /* @__PURE__ */ new Map();
            let ownMap = /* @__PURE__ */ new Map();
            if (ownOptions)
                redirectsMap.set(ownOptions, ownMap);
            return {
                getMapOfCacheRedirects,
                getOrCreateMapOfCacheRedirects,
                update,
                clear: clear2,
                getOwnMap: () => ownMap
            };
            function getMapOfCacheRedirects(redirectedReference) {
                return redirectedReference ? getOrCreateMap(redirectedReference.commandLine.options, 
                /*create*/
                false) : ownMap;
            }
            function getOrCreateMapOfCacheRedirects(redirectedReference) {
                return redirectedReference ? getOrCreateMap(redirectedReference.commandLine.options, 
                /*create*/
                true) : ownMap;
            }
            function update(newOptions) {
                if (ownOptions !== newOptions) {
                    if (ownOptions)
                        ownMap = getOrCreateMap(newOptions, 
                        /*create*/
                        true);
                    else
                        redirectsMap.set(newOptions, ownMap);
                    ownOptions = newOptions;
                }
            }
            function getOrCreateMap(redirectOptions, create) {
                let result = redirectsMap.get(redirectOptions);
                if (result)
                    return result;
                const key = getRedirectsCacheKey(redirectOptions);
                result = redirectsKeyToMap.get(key);
                if (!result) {
                    if (ownOptions) {
                        const ownKey = getRedirectsCacheKey(ownOptions);
                        if (ownKey === key)
                            result = ownMap;
                        else if (!redirectsKeyToMap.has(ownKey))
                            redirectsKeyToMap.set(ownKey, ownMap);
                    }
                    if (create)
                        result ?? (result = /* @__PURE__ */ new Map());
                    if (result)
                        redirectsKeyToMap.set(key, result);
                }
                if (result)
                    redirectsMap.set(redirectOptions, result);
                return result;
            }
            function clear2() {
                const ownKey = ownOptions && optionsToRedirectsKey.get(ownOptions);
                ownMap.clear();
                redirectsMap.clear();
                optionsToRedirectsKey.clear();
                redirectsKeyToMap.clear();
                if (ownOptions) {
                    if (ownKey)
                        optionsToRedirectsKey.set(ownOptions, ownKey);
                    redirectsMap.set(ownOptions, ownMap);
                }
            }
            function getRedirectsCacheKey(options) {
                let result = optionsToRedirectsKey.get(options);
                if (!result) {
                    optionsToRedirectsKey.set(options, result = getKeyForCompilerOptions(options, moduleResolutionOptionDeclarations));
                }
                return result;
            }
        }
        function createPackageJsonInfoCache(currentDirectory, getCanonicalFileName) {
            let cache;
            return { getPackageJsonInfo: getPackageJsonInfo2, setPackageJsonInfo, clear: clear2, getInternalMap };
            function getPackageJsonInfo2(packageJsonPath) {
                return cache == null ? void 0 : cache.get(toPath(packageJsonPath, currentDirectory, getCanonicalFileName));
            }
            function setPackageJsonInfo(packageJsonPath, info) {
                (cache || (cache = /* @__PURE__ */ new Map())).set(toPath(packageJsonPath, currentDirectory, getCanonicalFileName), info);
            }
            function clear2() {
                cache = void 0;
            }
            function getInternalMap() {
                return cache;
            }
        }
        function getOrCreateCache(cacheWithRedirects, redirectedReference, key, create) {
            const cache = cacheWithRedirects.getOrCreateMapOfCacheRedirects(redirectedReference);
            let result = cache.get(key);
            if (!result) {
                result = create();
                cache.set(key, result);
            }
            return result;
        }
        function createPerDirectoryResolutionCache(currentDirectory, getCanonicalFileName, options, optionsToRedirectsKey) {
            const directoryToModuleNameMap = createCacheWithRedirects(options, optionsToRedirectsKey);
            return {
                getFromDirectoryCache,
                getOrCreateCacheForDirectory,
                clear: clear2,
                update,
                directoryToModuleNameMap
            };
            function clear2() {
                directoryToModuleNameMap.clear();
            }
            function update(options2) {
                directoryToModuleNameMap.update(options2);
            }
            function getOrCreateCacheForDirectory(directoryName, redirectedReference) {
                const path = toPath(directoryName, currentDirectory, getCanonicalFileName);
                return getOrCreateCache(directoryToModuleNameMap, redirectedReference, path, () => createModeAwareCache());
            }
            function getFromDirectoryCache(name, mode, directoryName, redirectedReference) {
                var _a, _b;
                const path = toPath(directoryName, currentDirectory, getCanonicalFileName);
                return (_b = (_a = directoryToModuleNameMap.getMapOfCacheRedirects(redirectedReference)) == null ? void 0 : _a.get(path)) == null ? void 0 : _b.get(name, mode);
            }
        }
        function createModeAwareCacheKey(specifier, mode) {
            return mode === void 0 ? specifier : `${mode}|${specifier}`;
        }
        function createModeAwareCache() {
            const underlying = /* @__PURE__ */ new Map();
            const memoizedReverseKeys = /* @__PURE__ */ new Map();
            const cache = {
                get(specifier, mode) {
                    return underlying.get(getUnderlyingCacheKey(specifier, mode));
                },
                set(specifier, mode, value) {
                    underlying.set(getUnderlyingCacheKey(specifier, mode), value);
                    return cache;
                },
                delete(specifier, mode) {
                    underlying.delete(getUnderlyingCacheKey(specifier, mode));
                    return cache;
                },
                has(specifier, mode) {
                    return underlying.has(getUnderlyingCacheKey(specifier, mode));
                },
                forEach(cb) {
                    return underlying.forEach((elem, key) => {
                        const [specifier, mode] = memoizedReverseKeys.get(key);
                        return cb(elem, specifier, mode);
                    });
                },
                size() {
                    return underlying.size;
                }
            };
            return cache;
            function getUnderlyingCacheKey(specifier, mode) {
                const result = createModeAwareCacheKey(specifier, mode);
                memoizedReverseKeys.set(result, [specifier, mode]);
                return result;
            }
        }
        function getOriginalOrResolvedModuleFileName(result) {
            return result.resolvedModule && (result.resolvedModule.originalPath || result.resolvedModule.resolvedFileName);
        }
        function getOriginalOrResolvedTypeReferenceFileName(result) {
            return result.resolvedTypeReferenceDirective && (result.resolvedTypeReferenceDirective.originalPath || result.resolvedTypeReferenceDirective.resolvedFileName);
        }
        function createNonRelativeNameResolutionCache(currentDirectory, getCanonicalFileName, options, getResolvedFileName, optionsToRedirectsKey) {
            const moduleNameToDirectoryMap = createCacheWithRedirects(options, optionsToRedirectsKey);
            return {
                getFromNonRelativeNameCache,
                getOrCreateCacheForNonRelativeName,
                clear: clear2,
                update
            };
            function clear2() {
                moduleNameToDirectoryMap.clear();
            }
            function update(options2) {
                moduleNameToDirectoryMap.update(options2);
            }
            function getFromNonRelativeNameCache(nonRelativeModuleName, mode, directoryName, redirectedReference) {
                var _a, _b;
                Debug.assert(!isExternalModuleNameRelative(nonRelativeModuleName));
                return (_b = (_a = moduleNameToDirectoryMap.getMapOfCacheRedirects(redirectedReference)) == null ? void 0 : _a.get(createModeAwareCacheKey(nonRelativeModuleName, mode))) == null ? void 0 : _b.get(directoryName);
            }
            function getOrCreateCacheForNonRelativeName(nonRelativeModuleName, mode, redirectedReference) {
                Debug.assert(!isExternalModuleNameRelative(nonRelativeModuleName));
                return getOrCreateCache(moduleNameToDirectoryMap, redirectedReference, createModeAwareCacheKey(nonRelativeModuleName, mode), createPerModuleNameCache);
            }
            function createPerModuleNameCache() {
                const directoryPathMap = /* @__PURE__ */ new Map();
                return { get, set };
                function get(directory) {
                    return directoryPathMap.get(toPath(directory, currentDirectory, getCanonicalFileName));
                }
                function set(directory, result) {
                    const path = toPath(directory, currentDirectory, getCanonicalFileName);
                    if (directoryPathMap.has(path)) {
                        return;
                    }
                    directoryPathMap.set(path, result);
                    const resolvedFileName = getResolvedFileName(result);
                    const commonPrefix = resolvedFileName && getCommonPrefix(path, resolvedFileName);
                    let current = path;
                    while (current !== commonPrefix) {
                        const parent2 = getDirectoryPath(current);
                        if (parent2 === current || directoryPathMap.has(parent2)) {
                            break;
                        }
                        directoryPathMap.set(parent2, result);
                        current = parent2;
                    }
                }
                function getCommonPrefix(directory, resolution) {
                    const resolutionDirectory = toPath(getDirectoryPath(resolution), currentDirectory, getCanonicalFileName);
                    let i = 0;
                    const limit = Math.min(directory.length, resolutionDirectory.length);
                    while (i < limit && directory.charCodeAt(i) === resolutionDirectory.charCodeAt(i)) {
                        i++;
                    }
                    if (i === directory.length && (resolutionDirectory.length === i || resolutionDirectory[i] === directorySeparator)) {
                        return directory;
                    }
                    const rootLength = getRootLength(directory);
                    if (i < rootLength) {
                        return void 0;
                    }
                    const sep = directory.lastIndexOf(directorySeparator, i - 1);
                    if (sep === -1) {
                        return void 0;
                    }
                    return directory.substr(0, Math.max(sep, rootLength));
                }
            }
        }
        function createModuleOrTypeReferenceResolutionCache(currentDirectory, getCanonicalFileName, options, packageJsonInfoCache, getResolvedFileName, optionsToRedirectsKey) {
            optionsToRedirectsKey ?? (optionsToRedirectsKey = /* @__PURE__ */ new Map());
            const perDirectoryResolutionCache = createPerDirectoryResolutionCache(currentDirectory, getCanonicalFileName, options, optionsToRedirectsKey);
            const nonRelativeNameResolutionCache = createNonRelativeNameResolutionCache(currentDirectory, getCanonicalFileName, options, getResolvedFileName, optionsToRedirectsKey);
            packageJsonInfoCache ?? (packageJsonInfoCache = createPackageJsonInfoCache(currentDirectory, getCanonicalFileName));
            return {
                ...packageJsonInfoCache,
                ...perDirectoryResolutionCache,
                ...nonRelativeNameResolutionCache,
                clear: clear2,
                update,
                getPackageJsonInfoCache: () => packageJsonInfoCache,
                clearAllExceptPackageJsonInfoCache,
                optionsToRedirectsKey
            };
            function clear2() {
                clearAllExceptPackageJsonInfoCache();
                packageJsonInfoCache.clear();
            }
            function clearAllExceptPackageJsonInfoCache() {
                perDirectoryResolutionCache.clear();
                nonRelativeNameResolutionCache.clear();
            }
            function update(options2) {
                perDirectoryResolutionCache.update(options2);
                nonRelativeNameResolutionCache.update(options2);
            }
        }
        function createModuleResolutionCache(currentDirectory, getCanonicalFileName, options, packageJsonInfoCache, optionsToRedirectsKey) {
            const result = createModuleOrTypeReferenceResolutionCache(currentDirectory, getCanonicalFileName, options, packageJsonInfoCache, getOriginalOrResolvedModuleFileName, optionsToRedirectsKey);
            result.getOrCreateCacheForModuleName = (nonRelativeName, mode, redirectedReference) => result.getOrCreateCacheForNonRelativeName(nonRelativeName, mode, redirectedReference);
            return result;
        }
        function createTypeReferenceDirectiveResolutionCache(currentDirectory, getCanonicalFileName, options, packageJsonInfoCache, optionsToRedirectsKey) {
            return createModuleOrTypeReferenceResolutionCache(currentDirectory, getCanonicalFileName, options, packageJsonInfoCache, getOriginalOrResolvedTypeReferenceFileName, optionsToRedirectsKey);
        }
        function getOptionsForLibraryResolution(options) {
            return { moduleResolution: 2 /* Node10 */, traceResolution: options.traceResolution };
        }
        function resolveLibrary(libraryName, resolveFrom, compilerOptions, host, cache) {
            return resolveModuleName(libraryName, resolveFrom, getOptionsForLibraryResolution(compilerOptions), host, cache);
        }
        function resolveModuleNameFromCache(moduleName, containingFile, cache, mode) {
            const containingDirectory = getDirectoryPath(containingFile);
            return cache.getFromDirectoryCache(moduleName, mode, containingDirectory, 
            /*redirectedReference*/
            void 0);
        }
        function resolveModuleName(moduleName, containingFile, compilerOptions, host, cache, redirectedReference, resolutionMode) {
            var _a, _b, _c;
            const traceEnabled = isTraceEnabled(compilerOptions, host);
            if (redirectedReference) {
                compilerOptions = redirectedReference.commandLine.options;
            }
            if (traceEnabled) {
                trace(host, Diagnostics.Resolving_module_0_from_1, moduleName, containingFile);
                if (redirectedReference) {
                    trace(host, Diagnostics.Using_compiler_options_of_project_reference_redirect_0, redirectedReference.sourceFile.fileName);
                }
            }
            const containingDirectory = getDirectoryPath(containingFile);
            let result = cache == null ? void 0 : cache.getFromDirectoryCache(moduleName, resolutionMode, containingDirectory, redirectedReference);
            if (result) {
                if (traceEnabled) {
                    trace(host, Diagnostics.Resolution_for_module_0_was_found_in_cache_from_location_1, moduleName, containingDirectory);
                }
            }
            else {
                let moduleResolution = compilerOptions.moduleResolution;
                if (moduleResolution === void 0) {
                    moduleResolution = getEmitModuleResolutionKind(compilerOptions);
                    if (traceEnabled) {
                        trace(host, Diagnostics.Module_resolution_kind_is_not_specified_using_0, ModuleResolutionKind[moduleResolution]);
                    }
                }
                else {
                    if (traceEnabled) {
                        trace(host, Diagnostics.Explicitly_specified_module_resolution_kind_Colon_0, ModuleResolutionKind[moduleResolution]);
                    }
                }
                (_a = perfLogger) == null ? void 0 : _a.logStartResolveModule(moduleName);
                switch (moduleResolution) {
                    case 3 /* Node16 */:
                        result = node16ModuleNameResolver(moduleName, containingFile, compilerOptions, host, cache, redirectedReference, resolutionMode);
                        break;
                    case 99 /* NodeNext */:
                        result = nodeNextModuleNameResolver(moduleName, containingFile, compilerOptions, host, cache, redirectedReference, resolutionMode);
                        break;
                    case 2 /* Node10 */:
                        result = nodeModuleNameResolver(moduleName, containingFile, compilerOptions, host, cache, redirectedReference, resolutionMode ? getConditions(compilerOptions, resolutionMode) : void 0);
                        break;
                    case 1 /* Classic */:
                        result = classicNameResolver(moduleName, containingFile, compilerOptions, host, cache, redirectedReference);
                        break;
                    case 100 /* Bundler */:
                        result = bundlerModuleNameResolver(moduleName, containingFile, compilerOptions, host, cache, redirectedReference, resolutionMode ? getConditions(compilerOptions, resolutionMode) : void 0);
                        break;
                    default:
                        return Debug.fail(`Unexpected moduleResolution: ${moduleResolution}`);
                }
                if (result && result.resolvedModule)
                    (_b = perfLogger) == null ? void 0 : _b.logInfoEvent(`Module "${moduleName}" resolved to "${result.resolvedModule.resolvedFileName}"`);
                (_c = perfLogger) == null ? void 0 : _c.logStopResolveModule(result && result.resolvedModule ? "" + result.resolvedModule.resolvedFileName : "null");
                if (cache && !cache.isReadonly) {
                    cache.getOrCreateCacheForDirectory(containingDirectory, redirectedReference).set(moduleName, resolutionMode, result);
                    if (!isExternalModuleNameRelative(moduleName)) {
                        cache.getOrCreateCacheForNonRelativeName(moduleName, resolutionMode, redirectedReference).set(containingDirectory, result);
                    }
                }
            }
            if (traceEnabled) {
                if (result.resolvedModule) {
                    if (result.resolvedModule.packageId) {
                        trace(host, Diagnostics.Module_name_0_was_successfully_resolved_to_1_with_Package_ID_2, moduleName, result.resolvedModule.resolvedFileName, packageIdToString(result.resolvedModule.packageId));
                    }
                    else {
                        trace(host, Diagnostics.Module_name_0_was_successfully_resolved_to_1, moduleName, result.resolvedModule.resolvedFileName);
                    }
                }
                else {
                    trace(host, Diagnostics.Module_name_0_was_not_resolved, moduleName);
                }
            }
            return result;
        }
        function tryLoadModuleUsingOptionalResolutionSettings(extensions, moduleName, containingDirectory, loader, state) {
            const resolved = tryLoadModuleUsingPathsIfEligible(extensions, moduleName, loader, state);
            if (resolved)
                return resolved.value;
            if (!isExternalModuleNameRelative(moduleName)) {
                return tryLoadModuleUsingBaseUrl(extensions, moduleName, loader, state);
            }
            else {
                return tryLoadModuleUsingRootDirs(extensions, moduleName, containingDirectory, loader, state);
            }
        }
        function tryLoadModuleUsingPathsIfEligible(extensions, moduleName, loader, state) {
            var _a;
            const { baseUrl, paths, configFile } = state.compilerOptions;
            if (paths && !pathIsRelative(moduleName)) {
                if (state.traceEnabled) {
                    if (baseUrl) {
                        trace(state.host, Diagnostics.baseUrl_option_is_set_to_0_using_this_value_to_resolve_non_relative_module_name_1, baseUrl, moduleName);
                    }
                    trace(state.host, Diagnostics.paths_option_is_specified_looking_for_a_pattern_to_match_module_name_0, moduleName);
                }
                const baseDirectory = getPathsBasePath(state.compilerOptions, state.host);
                const pathPatterns = (configFile == null ? void 0 : configFile.configFileSpecs) ? (_a = configFile.configFileSpecs).pathPatterns || (_a.pathPatterns = tryParsePatterns(paths)) : void 0;
                return tryLoadModuleUsingPaths(extensions, moduleName, baseDirectory, paths, pathPatterns, loader, 
                /*onlyRecordFailures*/
                false, state);
            }
        }
        function tryLoadModuleUsingRootDirs(extensions, moduleName, containingDirectory, loader, state) {
            if (!state.compilerOptions.rootDirs) {
                return void 0;
            }
            if (state.traceEnabled) {
                trace(state.host, Diagnostics.rootDirs_option_is_set_using_it_to_resolve_relative_module_name_0, moduleName);
            }
            const candidate = normalizePath(combinePaths(containingDirectory, moduleName));
            let matchedRootDir;
            let matchedNormalizedPrefix;
            for (const rootDir of state.compilerOptions.rootDirs) {
                let normalizedRoot = normalizePath(rootDir);
                if (!endsWith(normalizedRoot, directorySeparator)) {
                    normalizedRoot += directorySeparator;
                }
                const isLongestMatchingPrefix = startsWith(candidate, normalizedRoot) && (matchedNormalizedPrefix === void 0 || matchedNormalizedPrefix.length < normalizedRoot.length);
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.Checking_if_0_is_the_longest_matching_prefix_for_1_2, normalizedRoot, candidate, isLongestMatchingPrefix);
                }
                if (isLongestMatchingPrefix) {
                    matchedNormalizedPrefix = normalizedRoot;
                    matchedRootDir = rootDir;
                }
            }
            if (matchedNormalizedPrefix) {
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.Longest_matching_prefix_for_0_is_1, candidate, matchedNormalizedPrefix);
                }
                const suffix = candidate.substr(matchedNormalizedPrefix.length);
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.Loading_0_from_the_root_dir_1_candidate_location_2, suffix, matchedNormalizedPrefix, candidate);
                }
                const resolvedFileName = loader(extensions, candidate, !directoryProbablyExists(containingDirectory, state.host), state);
                if (resolvedFileName) {
                    return resolvedFileName;
                }
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.Trying_other_entries_in_rootDirs);
                }
                for (const rootDir of state.compilerOptions.rootDirs) {
                    if (rootDir === matchedRootDir) {
                        continue;
                    }
                    const candidate2 = combinePaths(normalizePath(rootDir), suffix);
                    if (state.traceEnabled) {
                        trace(state.host, Diagnostics.Loading_0_from_the_root_dir_1_candidate_location_2, suffix, rootDir, candidate2);
                    }
                    const baseDirectory = getDirectoryPath(candidate2);
                    const resolvedFileName2 = loader(extensions, candidate2, !directoryProbablyExists(baseDirectory, state.host), state);
                    if (resolvedFileName2) {
                        return resolvedFileName2;
                    }
                }
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.Module_resolution_using_rootDirs_has_failed);
                }
            }
            return void 0;
        }
        function tryLoadModuleUsingBaseUrl(extensions, moduleName, loader, state) {
            const { baseUrl } = state.compilerOptions;
            if (!baseUrl) {
                return void 0;
            }
            if (state.traceEnabled) {
                trace(state.host, Diagnostics.baseUrl_option_is_set_to_0_using_this_value_to_resolve_non_relative_module_name_1, baseUrl, moduleName);
            }
            const candidate = normalizePath(combinePaths(baseUrl, moduleName));
            if (state.traceEnabled) {
                trace(state.host, Diagnostics.Resolving_module_name_0_relative_to_base_url_1_2, moduleName, baseUrl, candidate);
            }
            return loader(extensions, candidate, !directoryProbablyExists(getDirectoryPath(candidate), state.host), state);
        }
        function resolveJSModule(moduleName, initialDir, host) {
            const { resolvedModule, failedLookupLocations } = tryResolveJSModuleWorker(moduleName, initialDir, host);
            if (!resolvedModule) {
                throw new Error(`Could not resolve JS module '${moduleName}' starting at '${initialDir}'. Looked in: ${failedLookupLocations == null ? void 0 : failedLookupLocations.join(", ")}`);
            }
            return resolvedModule.resolvedFileName;
        }
        function node16ModuleNameResolver(moduleName, containingFile, compilerOptions, host, cache, redirectedReference, resolutionMode) {
            return nodeNextModuleNameResolverWorker(30 /* Node16Default */, moduleName, containingFile, compilerOptions, host, cache, redirectedReference, resolutionMode);
        }
        function nodeNextModuleNameResolver(moduleName, containingFile, compilerOptions, host, cache, redirectedReference, resolutionMode) {
            return nodeNextModuleNameResolverWorker(30 /* NodeNextDefault */, moduleName, containingFile, compilerOptions, host, cache, redirectedReference, resolutionMode);
        }
        function nodeNextModuleNameResolverWorker(features, moduleName, containingFile, compilerOptions, host, cache, redirectedReference, resolutionMode, conditions) {
            const containingDirectory = getDirectoryPath(containingFile);
            const esmMode = resolutionMode === 99 /* ESNext */ ? 32 /* EsmMode */ : 0;
            let extensions = compilerOptions.noDtsResolution ? 3 /* ImplementationFiles */ : 1 /* TypeScript */ | 2 /* JavaScript */ | 4 /* Declaration */;
            if (getResolveJsonModule(compilerOptions)) {
                extensions |= 8 /* Json */;
            }
            return nodeModuleNameResolverWorker(features | esmMode, moduleName, containingDirectory, compilerOptions, host, cache, extensions, 
            /*isConfigLookup*/
            false, redirectedReference, conditions);
        }
        function tryResolveJSModuleWorker(moduleName, initialDir, host) {
            return nodeModuleNameResolverWorker(0 /* None */, moduleName, initialDir, { moduleResolution: 2 /* Node10 */, allowJs: true }, host, 
            /*cache*/
            void 0, 2 /* JavaScript */, 
            /*isConfigLookup*/
            false, 
            /*redirectedReference*/
            void 0, 
            /*conditions*/
            void 0);
        }
        function bundlerModuleNameResolver(moduleName, containingFile, compilerOptions, host, cache, redirectedReference, conditions) {
            const containingDirectory = getDirectoryPath(containingFile);
            let extensions = compilerOptions.noDtsResolution ? 3 /* ImplementationFiles */ : 1 /* TypeScript */ | 2 /* JavaScript */ | 4 /* Declaration */;
            if (getResolveJsonModule(compilerOptions)) {
                extensions |= 8 /* Json */;
            }
            return nodeModuleNameResolverWorker(getNodeResolutionFeatures(compilerOptions), moduleName, containingDirectory, compilerOptions, host, cache, extensions, 
            /*isConfigLookup*/
            false, redirectedReference, conditions);
        }
        function nodeModuleNameResolver(moduleName, containingFile, compilerOptions, host, cache, redirectedReference, conditions, isConfigLookup) {
            let extensions;
            if (isConfigLookup) {
                extensions = 8 /* Json */;
            }
            else if (compilerOptions.noDtsResolution) {
                extensions = 3 /* ImplementationFiles */;
                if (getResolveJsonModule(compilerOptions))
                    extensions |= 8 /* Json */;
            }
            else {
                extensions = getResolveJsonModule(compilerOptions) ? 1 /* TypeScript */ | 2 /* JavaScript */ | 4 /* Declaration */ | 8 /* Json */ : 1 /* TypeScript */ | 2 /* JavaScript */ | 4 /* Declaration */;
            }
            return nodeModuleNameResolverWorker(conditions ? 30 /* AllFeatures */ : 0 /* None */, moduleName, getDirectoryPath(containingFile), compilerOptions, host, cache, extensions, !!isConfigLookup, redirectedReference, conditions);
        }
        function nodeNextJsonConfigResolver(moduleName, containingFile, host) {
            return nodeModuleNameResolverWorker(30 /* NodeNextDefault */, moduleName, getDirectoryPath(containingFile), { moduleResolution: 99 /* NodeNext */ }, host, 
            /*cache*/
            void 0, 8 /* Json */, 
            /*isConfigLookup*/
            true, 
            /*redirectedReference*/
            void 0, 
            /*conditions*/
            void 0);
        }
        function nodeModuleNameResolverWorker(features, moduleName, containingDirectory, compilerOptions, host, cache, extensions, isConfigLookup, redirectedReference, conditions) {
            var _a, _b, _c, _d, _e;
            const traceEnabled = isTraceEnabled(compilerOptions, host);
            const failedLookupLocations = [];
            const affectingLocations = [];
            const moduleResolution = getEmitModuleResolutionKind(compilerOptions);
            conditions ?? (conditions = getConditions(compilerOptions, moduleResolution === 100 /* Bundler */ || moduleResolution === 2 /* Node10 */ ? void 0 : features & 32 /* EsmMode */ ? 99 /* ESNext */ : 1 /* CommonJS */));
            const diagnostics = [];
            const state = {
                compilerOptions,
                host,
                traceEnabled,
                failedLookupLocations,
                affectingLocations,
                packageJsonInfoCache: cache,
                features,
                conditions: conditions ?? emptyArray,
                requestContainingDirectory: containingDirectory,
                reportDiagnostic: (diag2) => void diagnostics.push(diag2),
                isConfigLookup,
                candidateIsFromPackageJsonField: false,
                resolvedPackageDirectory: false
            };
            if (traceEnabled && moduleResolutionSupportsPackageJsonExportsAndImports(moduleResolution)) {
                trace(host, Diagnostics.Resolving_in_0_mode_with_conditions_1, features & 32 /* EsmMode */ ? "ESM" : "CJS", state.conditions.map((c) => `'${c}'`).join(", "));
            }
            let result;
            if (moduleResolution === 2 /* Node10 */) {
                const priorityExtensions = extensions & (1 /* TypeScript */ | 4 /* Declaration */);
                const secondaryExtensions = extensions & ~(1 /* TypeScript */ | 4 /* Declaration */);
                result = priorityExtensions && tryResolve(priorityExtensions, state) || secondaryExtensions && tryResolve(secondaryExtensions, state) || void 0;
            }
            else {
                result = tryResolve(extensions, state);
            }
            let alternateResult;
            if (state.resolvedPackageDirectory && !isConfigLookup && !isExternalModuleNameRelative(moduleName)) {
                const wantedTypesButGotJs = (result == null ? void 0 : result.value) && extensions & (1 /* TypeScript */ | 4 /* Declaration */) && !extensionIsOk(1 /* TypeScript */ | 4 /* Declaration */, result.value.resolved.extension);
                if (((_a = result == null ? void 0 : result.value) == null ? void 0 : _a.isExternalLibraryImport) && wantedTypesButGotJs && features & 8 /* Exports */ && (conditions == null ? void 0 : conditions.includes("import"))) {
                    traceIfEnabled(state, Diagnostics.Resolution_of_non_relative_name_failed_trying_with_modern_Node_resolution_features_disabled_to_see_if_npm_library_needs_configuration_update);
                    const diagnosticState = {
                        ...state,
                        features: state.features & ~8 /* Exports */,
                        reportDiagnostic: noop
                    };
                    const diagnosticResult = tryResolve(extensions & (1 /* TypeScript */ | 4 /* Declaration */), diagnosticState);
                    if ((_b = diagnosticResult == null ? void 0 : diagnosticResult.value) == null ? void 0 : _b.isExternalLibraryImport) {
                        alternateResult = diagnosticResult.value.resolved.path;
                    }
                }
                else if ((!(result == null ? void 0 : result.value) || wantedTypesButGotJs) && moduleResolution === 2 /* Node10 */) {
                    traceIfEnabled(state, Diagnostics.Resolution_of_non_relative_name_failed_trying_with_moduleResolution_bundler_to_see_if_project_may_need_configuration_update);
                    const diagnosticsCompilerOptions = { ...state.compilerOptions, moduleResolution: 100 /* Bundler */ };
                    const diagnosticState = {
                        ...state,
                        compilerOptions: diagnosticsCompilerOptions,
                        features: 30 /* BundlerDefault */,
                        conditions: getConditions(diagnosticsCompilerOptions),
                        reportDiagnostic: noop
                    };
                    const diagnosticResult = tryResolve(extensions & (1 /* TypeScript */ | 4 /* Declaration */), diagnosticState);
                    if ((_c = diagnosticResult == null ? void 0 : diagnosticResult.value) == null ? void 0 : _c.isExternalLibraryImport) {
                        alternateResult = diagnosticResult.value.resolved.path;
                    }
                }
            }
            return createResolvedModuleWithFailedLookupLocationsHandlingSymlink(moduleName, (_d = result == null ? void 0 : result.value) == null ? void 0 : _d.resolved, (_e = result == null ? void 0 : result.value) == null ? void 0 : _e.isExternalLibraryImport, failedLookupLocations, affectingLocations, diagnostics, state, cache, alternateResult);
            function tryResolve(extensions2, state2) {
                const loader = (extensions3, candidate, onlyRecordFailures, state3) => nodeLoadModuleByRelativeName(extensions3, candidate, onlyRecordFailures, state3, 
                /*considerPackageJson*/
                true);
                const resolved = tryLoadModuleUsingOptionalResolutionSettings(extensions2, moduleName, containingDirectory, loader, state2);
                if (resolved) {
                    return toSearchResult({ resolved, isExternalLibraryImport: pathContainsNodeModules(resolved.path) });
                }
                if (!isExternalModuleNameRelative(moduleName)) {
                    let resolved2;
                    if (features & 2 /* Imports */ && startsWith(moduleName, "#")) {
                        resolved2 = loadModuleFromImports(extensions2, moduleName, containingDirectory, state2, cache, redirectedReference);
                    }
                    if (!resolved2 && features & 4 /* SelfName */) {
                        resolved2 = loadModuleFromSelfNameReference(extensions2, moduleName, containingDirectory, state2, cache, redirectedReference);
                    }
                    if (!resolved2) {
                        if (moduleName.includes(":")) {
                            if (traceEnabled) {
                                trace(host, Diagnostics.Skipping_module_0_that_looks_like_an_absolute_URI_target_file_types_Colon_1, moduleName, formatExtensions(extensions2));
                            }
                            return void 0;
                        }
                        if (traceEnabled) {
                            trace(host, Diagnostics.Loading_module_0_from_node_modules_folder_target_file_types_Colon_1, moduleName, formatExtensions(extensions2));
                        }
                        resolved2 = loadModuleFromNearestNodeModulesDirectory(extensions2, moduleName, containingDirectory, state2, cache, redirectedReference);
                    }
                    if (extensions2 & 4 /* Declaration */) {
                        resolved2 ?? (resolved2 = resolveFromTypeRoot(moduleName, state2));
                    }
                    return resolved2 && { value: resolved2.value && { resolved: resolved2.value, isExternalLibraryImport: true } };
                }
                else {
                    const { path: candidate, parts } = normalizePathForCJSResolution(containingDirectory, moduleName);
                    const resolved2 = nodeLoadModuleByRelativeName(extensions2, candidate, 
                    /*onlyRecordFailures*/
                    false, state2, 
                    /*considerPackageJson*/
                    true);
                    return resolved2 && toSearchResult({ resolved: resolved2, isExternalLibraryImport: contains(parts, "node_modules") });
                }
            }
        }
        function normalizePathForCJSResolution(containingDirectory, moduleName) {
            const combined = combinePaths(containingDirectory, moduleName);
            const parts = getPathComponents(combined);
            const lastPart = lastOrUndefined(parts);
            const path = lastPart === "." || lastPart === ".." ? ensureTrailingDirectorySeparator(normalizePath(combined)) : normalizePath(combined);
            return { path, parts };
        }
        function realPath(path, host, traceEnabled) {
            if (!host.realpath) {
                return path;
            }
            const real = normalizePath(host.realpath(path));
            if (traceEnabled) {
                trace(host, Diagnostics.Resolving_real_path_for_0_result_1, path, real);
            }
            return real;
        }
        function nodeLoadModuleByRelativeName(extensions, candidate, onlyRecordFailures, state, considerPackageJson) {
            if (state.traceEnabled) {
                trace(state.host, Diagnostics.Loading_module_as_file_Slash_folder_candidate_module_location_0_target_file_types_Colon_1, candidate, formatExtensions(extensions));
            }
            if (!hasTrailingDirectorySeparator(candidate)) {
                if (!onlyRecordFailures) {
                    const parentOfCandidate = getDirectoryPath(candidate);
                    if (!directoryProbablyExists(parentOfCandidate, state.host)) {
                        if (state.traceEnabled) {
                            trace(state.host, Diagnostics.Directory_0_does_not_exist_skipping_all_lookups_in_it, parentOfCandidate);
                        }
                        onlyRecordFailures = true;
                    }
                }
                const resolvedFromFile = loadModuleFromFile(extensions, candidate, onlyRecordFailures, state);
                if (resolvedFromFile) {
                    const packageDirectory = considerPackageJson ? parseNodeModuleFromPath(resolvedFromFile.path) : void 0;
                    const packageInfo = packageDirectory ? getPackageJsonInfo(packageDirectory, 
                    /*onlyRecordFailures*/
                    false, state) : void 0;
                    return withPackageId(packageInfo, resolvedFromFile);
                }
            }
            if (!onlyRecordFailures) {
                const candidateExists = directoryProbablyExists(candidate, state.host);
                if (!candidateExists) {
                    if (state.traceEnabled) {
                        trace(state.host, Diagnostics.Directory_0_does_not_exist_skipping_all_lookups_in_it, candidate);
                    }
                    onlyRecordFailures = true;
                }
            }
            if (!(state.features & 32 /* EsmMode */)) {
                return loadNodeModuleFromDirectory(extensions, candidate, onlyRecordFailures, state, considerPackageJson);
            }
            return void 0;
        }
        function pathContainsNodeModules(path) {
            return path.includes(nodeModulesPathPart);
        }
        function parseNodeModuleFromPath(resolved, isFolder) {
            const path = normalizePath(resolved);
            const idx = path.lastIndexOf(nodeModulesPathPart);
            if (idx === -1) {
                return void 0;
            }
            const indexAfterNodeModules = idx + nodeModulesPathPart.length;
            let indexAfterPackageName = moveToNextDirectorySeparatorIfAvailable(path, indexAfterNodeModules, isFolder);
            if (path.charCodeAt(indexAfterNodeModules) === 64 /* at */) {
                indexAfterPackageName = moveToNextDirectorySeparatorIfAvailable(path, indexAfterPackageName, isFolder);
            }
            return path.slice(0, indexAfterPackageName);
        }
        function moveToNextDirectorySeparatorIfAvailable(path, prevSeparatorIndex, isFolder) {
            const nextSeparatorIndex = path.indexOf(directorySeparator, prevSeparatorIndex + 1);
            return nextSeparatorIndex === -1 ? isFolder ? path.length : prevSeparatorIndex : nextSeparatorIndex;
        }
        function loadModuleFromFileNoPackageId(extensions, candidate, onlyRecordFailures, state) {
            return noPackageId(loadModuleFromFile(extensions, candidate, onlyRecordFailures, state));
        }
        function loadModuleFromFile(extensions, candidate, onlyRecordFailures, state) {
            const resolvedByReplacingExtension = loadModuleFromFileNoImplicitExtensions(extensions, candidate, onlyRecordFailures, state);
            if (resolvedByReplacingExtension) {
                return resolvedByReplacingExtension;
            }
            if (!(state.features & 32 /* EsmMode */)) {
                const resolvedByAddingExtension = tryAddingExtensions(candidate, extensions, "", onlyRecordFailures, state);
                if (resolvedByAddingExtension) {
                    return resolvedByAddingExtension;
                }
            }
        }
        function loadModuleFromFileNoImplicitExtensions(extensions, candidate, onlyRecordFailures, state) {
            const filename = getBaseFileName(candidate);
            if (!filename.includes(".")) {
                return void 0;
            }
            let extensionless = removeFileExtension(candidate);
            if (extensionless === candidate) {
                extensionless = candidate.substring(0, candidate.lastIndexOf("."));
            }
            const extension = candidate.substring(extensionless.length);
            if (state.traceEnabled) {
                trace(state.host, Diagnostics.File_name_0_has_a_1_extension_stripping_it, candidate, extension);
            }
            return tryAddingExtensions(extensionless, extensions, extension, onlyRecordFailures, state);
        }
        function loadFileNameFromPackageJsonField(extensions, candidate, onlyRecordFailures, state) {
            if (extensions & 1 /* TypeScript */ && fileExtensionIsOneOf(candidate, supportedTSImplementationExtensions) || extensions & 4 /* Declaration */ && fileExtensionIsOneOf(candidate, supportedDeclarationExtensions)) {
                const result = tryFile(candidate, onlyRecordFailures, state);
                return result !== void 0 ? { path: candidate, ext: tryExtractTSExtension(candidate), resolvedUsingTsExtension: void 0 } : void 0;
            }
            if (state.isConfigLookup && extensions === 8 /* Json */ && fileExtensionIs(candidate, ".json" /* Json */)) {
                const result = tryFile(candidate, onlyRecordFailures, state);
                return result !== void 0 ? { path: candidate, ext: ".json" /* Json */, resolvedUsingTsExtension: void 0 } : void 0;
            }
            return loadModuleFromFileNoImplicitExtensions(extensions, candidate, onlyRecordFailures, state);
        }
        function tryAddingExtensions(candidate, extensions, originalExtension, onlyRecordFailures, state) {
            if (!onlyRecordFailures) {
                const directory = getDirectoryPath(candidate);
                if (directory) {
                    onlyRecordFailures = !directoryProbablyExists(directory, state.host);
                }
            }
            switch (originalExtension) {
                case ".mjs" /* Mjs */:
                case ".mts" /* Mts */:
                case ".d.mts" /* Dmts */:
                    return extensions & 1 /* TypeScript */ && tryExtension(".mts" /* Mts */, originalExtension === ".mts" /* Mts */ || originalExtension === ".d.mts" /* Dmts */) || extensions & 4 /* Declaration */ && tryExtension(".d.mts" /* Dmts */, originalExtension === ".mts" /* Mts */ || originalExtension === ".d.mts" /* Dmts */) || extensions & 2 /* JavaScript */ && tryExtension(".mjs" /* Mjs */) || void 0;
                case ".cjs" /* Cjs */:
                case ".cts" /* Cts */:
                case ".d.cts" /* Dcts */:
                    return extensions & 1 /* TypeScript */ && tryExtension(".cts" /* Cts */, originalExtension === ".cts" /* Cts */ || originalExtension === ".d.cts" /* Dcts */) || extensions & 4 /* Declaration */ && tryExtension(".d.cts" /* Dcts */, originalExtension === ".cts" /* Cts */ || originalExtension === ".d.cts" /* Dcts */) || extensions & 2 /* JavaScript */ && tryExtension(".cjs" /* Cjs */) || void 0;
                case ".json" /* Json */:
                    return extensions & 4 /* Declaration */ && tryExtension(".d.json.ts") || extensions & 8 /* Json */ && tryExtension(".json" /* Json */) || void 0;
                case ".tsx" /* Tsx */:
                case ".jsx" /* Jsx */:
                    return extensions & 1 /* TypeScript */ && (tryExtension(".tsx" /* Tsx */, originalExtension === ".tsx" /* Tsx */) || tryExtension(".ts" /* Ts */, originalExtension === ".tsx" /* Tsx */)) || extensions & 4 /* Declaration */ && tryExtension(".d.ts" /* Dts */, originalExtension === ".tsx" /* Tsx */) || extensions & 2 /* JavaScript */ && (tryExtension(".jsx" /* Jsx */) || tryExtension(".js" /* Js */)) || void 0;
                case ".ts" /* Ts */:
                case ".d.ts" /* Dts */:
                case ".js" /* Js */:
                case "":
                    return extensions & 1 /* TypeScript */ && (tryExtension(".ts" /* Ts */, originalExtension === ".ts" /* Ts */ || originalExtension === ".d.ts" /* Dts */) || tryExtension(".tsx" /* Tsx */, originalExtension === ".ts" /* Ts */ || originalExtension === ".d.ts" /* Dts */)) || extensions & 4 /* Declaration */ && tryExtension(".d.ts" /* Dts */, originalExtension === ".ts" /* Ts */ || originalExtension === ".d.ts" /* Dts */) || extensions & 2 /* JavaScript */ && (tryExtension(".js" /* Js */) || tryExtension(".jsx" /* Jsx */)) || state.isConfigLookup && tryExtension(".json" /* Json */) || void 0;
                default:
                    return extensions & 4 /* Declaration */ && !isDeclarationFileName(candidate + originalExtension) && tryExtension(`.d${originalExtension}.ts`) || void 0;
            }
            function tryExtension(ext, resolvedUsingTsExtension) {
                const path = tryFile(candidate + ext, onlyRecordFailures, state);
                return path === void 0 ? void 0 : { path, ext, resolvedUsingTsExtension: !state.candidateIsFromPackageJsonField && resolvedUsingTsExtension };
            }
        }
        function tryFile(fileName, onlyRecordFailures, state) {
            var _a;
            if (!((_a = state.compilerOptions.moduleSuffixes) == null ? void 0 : _a.length)) {
                return tryFileLookup(fileName, onlyRecordFailures, state);
            }
            const ext = tryGetExtensionFromPath2(fileName) ?? "";
            const fileNameNoExtension = ext ? removeExtension(fileName, ext) : fileName;
            return forEach(state.compilerOptions.moduleSuffixes, (suffix) => tryFileLookup(fileNameNoExtension + suffix + ext, onlyRecordFailures, state));
        }
        function tryFileLookup(fileName, onlyRecordFailures, state) {
            var _a;
            if (!onlyRecordFailures) {
                if (state.host.fileExists(fileName)) {
                    if (state.traceEnabled) {
                        trace(state.host, Diagnostics.File_0_exists_use_it_as_a_name_resolution_result, fileName);
                    }
                    return fileName;
                }
                else {
                    if (state.traceEnabled) {
                        trace(state.host, Diagnostics.File_0_does_not_exist, fileName);
                    }
                }
            }
            (_a = state.failedLookupLocations) == null ? void 0 : _a.push(fileName);
            return void 0;
        }
        function loadNodeModuleFromDirectory(extensions, candidate, onlyRecordFailures, state, considerPackageJson = true) {
            const packageInfo = considerPackageJson ? getPackageJsonInfo(candidate, onlyRecordFailures, state) : void 0;
            const packageJsonContent = packageInfo && packageInfo.contents.packageJsonContent;
            const versionPaths = packageInfo && getVersionPathsOfPackageJsonInfo(packageInfo, state);
            return withPackageId(packageInfo, loadNodeModuleFromDirectoryWorker(extensions, candidate, onlyRecordFailures, state, packageJsonContent, versionPaths));
        }
        function getEntrypointsFromPackageJsonInfo(packageJsonInfo, options, host, cache, resolveJs) {
            if (!resolveJs && packageJsonInfo.contents.resolvedEntrypoints !== void 0) {
                return packageJsonInfo.contents.resolvedEntrypoints;
            }
            let entrypoints;
            const extensions = 1 /* TypeScript */ | 4 /* Declaration */ | (resolveJs ? 2 /* JavaScript */ : 0);
            const features = getNodeResolutionFeatures(options);
            const loadPackageJsonMainState = getTemporaryModuleResolutionState(cache == null ? void 0 : cache.getPackageJsonInfoCache(), host, options);
            loadPackageJsonMainState.conditions = getConditions(options);
            loadPackageJsonMainState.requestContainingDirectory = packageJsonInfo.packageDirectory;
            const mainResolution = loadNodeModuleFromDirectoryWorker(extensions, packageJsonInfo.packageDirectory, 
            /*onlyRecordFailures*/
            false, loadPackageJsonMainState, packageJsonInfo.contents.packageJsonContent, getVersionPathsOfPackageJsonInfo(packageJsonInfo, loadPackageJsonMainState));
            entrypoints = append(entrypoints, mainResolution == null ? void 0 : mainResolution.path);
            if (features & 8 /* Exports */ && packageJsonInfo.contents.packageJsonContent.exports) {
                const conditionSets = deduplicate([getConditions(options, 99 /* ESNext */), getConditions(options, 1 /* CommonJS */)], arrayIsEqualTo);
                for (const conditions of conditionSets) {
                    const loadPackageJsonExportsState = { ...loadPackageJsonMainState, failedLookupLocations: [], conditions, host };
                    const exportResolutions = loadEntrypointsFromExportMap(packageJsonInfo, packageJsonInfo.contents.packageJsonContent.exports, loadPackageJsonExportsState, extensions);
                    if (exportResolutions) {
                        for (const resolution of exportResolutions) {
                            entrypoints = appendIfUnique(entrypoints, resolution.path);
                        }
                    }
                }
            }
            return packageJsonInfo.contents.resolvedEntrypoints = entrypoints || false;
        }
        function loadEntrypointsFromExportMap(scope, exports, state, extensions) {
            let entrypoints;
            if (isArray(exports)) {
                for (const target of exports) {
                    loadEntrypointsFromTargetExports(target);
                }
            }
            else if (typeof exports === "object" && exports !== null && allKeysStartWithDot(exports)) {
                for (const key in exports) {
                    loadEntrypointsFromTargetExports(exports[key]);
                }
            }
            else {
                loadEntrypointsFromTargetExports(exports);
            }
            return entrypoints;
            function loadEntrypointsFromTargetExports(target) {
                var _a, _b;
                if (typeof target === "string" && startsWith(target, "./")) {
                    if (target.includes("*") && state.host.readDirectory) {
                        if (target.indexOf("*") !== target.lastIndexOf("*")) {
                            return false;
                        }
                        state.host.readDirectory(scope.packageDirectory, extensionsToExtensionsArray(extensions), 
                        /*excludes*/
                        void 0, [
                            changeFullExtension(replaceFirstStar(target, "**/*"), ".*")
                        ]).forEach((entry) => {
                            entrypoints = appendIfUnique(entrypoints, {
                                path: entry,
                                ext: getAnyExtensionFromPath(entry),
                                resolvedUsingTsExtension: void 0
                            });
                        });
                    }
                    else {
                        const partsAfterFirst = getPathComponents(target).slice(2);
                        if (partsAfterFirst.includes("..") || partsAfterFirst.includes(".") || partsAfterFirst.includes("node_modules")) {
                            return false;
                        }
                        const resolvedTarget = combinePaths(scope.packageDirectory, target);
                        const finalPath = getNormalizedAbsolutePath(resolvedTarget, (_b = (_a = state.host).getCurrentDirectory) == null ? void 0 : _b.call(_a));
                        const result = loadFileNameFromPackageJsonField(extensions, finalPath, 
                        /*onlyRecordFailures*/
                        false, state);
                        if (result) {
                            entrypoints = appendIfUnique(entrypoints, result, (a, b) => a.path === b.path);
                            return true;
                        }
                    }
                }
                else if (Array.isArray(target)) {
                    for (const t of target) {
                        const success = loadEntrypointsFromTargetExports(t);
                        if (success) {
                            return true;
                        }
                    }
                }
                else if (typeof target === "object" && target !== null) {
                    return forEach(getOwnKeys(target), (key) => {
                        if (key === "default" || contains(state.conditions, key) || isApplicableVersionedTypesKey(state.conditions, key)) {
                            loadEntrypointsFromTargetExports(target[key]);
                            return true;
                        }
                    });
                }
            }
        }
        function getTemporaryModuleResolutionState(packageJsonInfoCache, host, options) {
            return {
                host,
                compilerOptions: options,
                traceEnabled: isTraceEnabled(options, host),
                failedLookupLocations: void 0,
                affectingLocations: void 0,
                packageJsonInfoCache,
                features: 0 /* None */,
                conditions: emptyArray,
                requestContainingDirectory: void 0,
                reportDiagnostic: noop,
                isConfigLookup: false,
                candidateIsFromPackageJsonField: false,
                resolvedPackageDirectory: false
            };
        }
        function getPackageScopeForPath(fileName, state) {
            const parts = getPathComponents(fileName);
            parts.pop();
            while (parts.length > 0) {
                const pkg = getPackageJsonInfo(getPathFromPathComponents(parts), 
                /*onlyRecordFailures*/
                false, state);
                if (pkg) {
                    return pkg;
                }
                parts.pop();
            }
            return void 0;
        }
        function getVersionPathsOfPackageJsonInfo(packageJsonInfo, state) {
            if (packageJsonInfo.contents.versionPaths === void 0) {
                packageJsonInfo.contents.versionPaths = readPackageJsonTypesVersionPaths(packageJsonInfo.contents.packageJsonContent, state) || false;
            }
            return packageJsonInfo.contents.versionPaths || void 0;
        }
        function getPackageJsonInfo(packageDirectory, onlyRecordFailures, state) {
            var _a, _b, _c, _d, _e, _f;
            const { host, traceEnabled } = state;
            const packageJsonPath = combinePaths(packageDirectory, "package.json");
            if (onlyRecordFailures) {
                (_a = state.failedLookupLocations) == null ? void 0 : _a.push(packageJsonPath);
                return void 0;
            }
            const existing = (_b = state.packageJsonInfoCache) == null ? void 0 : _b.getPackageJsonInfo(packageJsonPath);
            if (existing !== void 0) {
                if (isPackageJsonInfo(existing)) {
                    if (traceEnabled)
                        trace(host, Diagnostics.File_0_exists_according_to_earlier_cached_lookups, packageJsonPath);
                    (_c = state.affectingLocations) == null ? void 0 : _c.push(packageJsonPath);
                    return existing.packageDirectory === packageDirectory ? existing : { packageDirectory, contents: existing.contents };
                }
                else {
                    if (existing.directoryExists && traceEnabled)
                        trace(host, Diagnostics.File_0_does_not_exist_according_to_earlier_cached_lookups, packageJsonPath);
                    (_d = state.failedLookupLocations) == null ? void 0 : _d.push(packageJsonPath);
                    return void 0;
                }
            }
            const directoryExists = directoryProbablyExists(packageDirectory, host);
            if (directoryExists && host.fileExists(packageJsonPath)) {
                const packageJsonContent = readJson(packageJsonPath, host);
                if (traceEnabled) {
                    trace(host, Diagnostics.Found_package_json_at_0, packageJsonPath);
                }
                const result = { packageDirectory, contents: { packageJsonContent, versionPaths: void 0, resolvedEntrypoints: void 0 } };
                if (state.packageJsonInfoCache && !state.packageJsonInfoCache.isReadonly)
                    state.packageJsonInfoCache.setPackageJsonInfo(packageJsonPath, result);
                (_e = state.affectingLocations) == null ? void 0 : _e.push(packageJsonPath);
                return result;
            }
            else {
                if (directoryExists && traceEnabled) {
                    trace(host, Diagnostics.File_0_does_not_exist, packageJsonPath);
                }
                if (state.packageJsonInfoCache && !state.packageJsonInfoCache.isReadonly)
                    state.packageJsonInfoCache.setPackageJsonInfo(packageJsonPath, { packageDirectory, directoryExists });
                (_f = state.failedLookupLocations) == null ? void 0 : _f.push(packageJsonPath);
            }
        }
        function loadNodeModuleFromDirectoryWorker(extensions, candidate, onlyRecordFailures, state, jsonContent, versionPaths) {
            let packageFile;
            if (jsonContent) {
                if (state.isConfigLookup) {
                    packageFile = readPackageJsonTSConfigField(jsonContent, candidate, state);
                }
                else {
                    packageFile = extensions & 4 /* Declaration */ && readPackageJsonTypesFields(jsonContent, candidate, state) || extensions & (3 /* ImplementationFiles */ | 4 /* Declaration */) && readPackageJsonMainField(jsonContent, candidate, state) || void 0;
                }
            }
            const loader = (extensions2, candidate2, onlyRecordFailures2, state2) => {
                const fromFile = loadFileNameFromPackageJsonField(extensions2, candidate2, onlyRecordFailures2, state2);
                if (fromFile) {
                    return noPackageId(fromFile);
                }
                const expandedExtensions = extensions2 === 4 /* Declaration */ ? 1 /* TypeScript */ | 4 /* Declaration */ : extensions2;
                const features = state2.features;
                const candidateIsFromPackageJsonField = state2.candidateIsFromPackageJsonField;
                state2.candidateIsFromPackageJsonField = true;
                if ((jsonContent == null ? void 0 : jsonContent.type) !== "module") {
                    state2.features &= ~32 /* EsmMode */;
                }
                const result = nodeLoadModuleByRelativeName(expandedExtensions, candidate2, onlyRecordFailures2, state2, 
                /*considerPackageJson*/
                false);
                state2.features = features;
                state2.candidateIsFromPackageJsonField = candidateIsFromPackageJsonField;
                return result;
            };
            const onlyRecordFailuresForPackageFile = packageFile ? !directoryProbablyExists(getDirectoryPath(packageFile), state.host) : void 0;
            const onlyRecordFailuresForIndex = onlyRecordFailures || !directoryProbablyExists(candidate, state.host);
            const indexPath = combinePaths(candidate, state.isConfigLookup ? "tsconfig" : "index");
            if (versionPaths && (!packageFile || containsPath(candidate, packageFile))) {
                const moduleName = getRelativePathFromDirectory(candidate, packageFile || indexPath, 
                /*ignoreCase*/
                false);
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.package_json_has_a_typesVersions_entry_0_that_matches_compiler_version_1_looking_for_a_pattern_to_match_module_name_2, versionPaths.version, version, moduleName);
                }
                const result = tryLoadModuleUsingPaths(extensions, moduleName, candidate, versionPaths.paths, 
                /*pathPatterns*/
                void 0, loader, onlyRecordFailuresForPackageFile || onlyRecordFailuresForIndex, state);
                if (result) {
                    return removeIgnoredPackageId(result.value);
                }
            }
            const packageFileResult = packageFile && removeIgnoredPackageId(loader(extensions, packageFile, onlyRecordFailuresForPackageFile, state));
            if (packageFileResult)
                return packageFileResult;
            if (!(state.features & 32 /* EsmMode */)) {
                return loadModuleFromFile(extensions, indexPath, onlyRecordFailuresForIndex, state);
            }
        }
        function extensionIsOk(extensions, extension) {
            return extensions & 2 /* JavaScript */ && (extension === ".js" /* Js */ || extension === ".jsx" /* Jsx */ || extension === ".mjs" /* Mjs */ || extension === ".cjs" /* Cjs */) || extensions & 1 /* TypeScript */ && (extension === ".ts" /* Ts */ || extension === ".tsx" /* Tsx */ || extension === ".mts" /* Mts */ || extension === ".cts" /* Cts */) || extensions & 4 /* Declaration */ && (extension === ".d.ts" /* Dts */ || extension === ".d.mts" /* Dmts */ || extension === ".d.cts" /* Dcts */) || extensions & 8 /* Json */ && extension === ".json" /* Json */ || false;
        }
        function parsePackageName(moduleName) {
            let idx = moduleName.indexOf(directorySeparator);
            if (moduleName[0] === "@") {
                idx = moduleName.indexOf(directorySeparator, idx + 1);
            }
            return idx === -1 ? { packageName: moduleName, rest: "" } : { packageName: moduleName.slice(0, idx), rest: moduleName.slice(idx + 1) };
        }
        function allKeysStartWithDot(obj) {
            return every(getOwnKeys(obj), (k) => startsWith(k, "."));
        }
        function noKeyStartsWithDot(obj) {
            return !some(getOwnKeys(obj), (k) => startsWith(k, "."));
        }
        function loadModuleFromSelfNameReference(extensions, moduleName, directory, state, cache, redirectedReference) {
            var _a, _b;
            const directoryPath = getNormalizedAbsolutePath(combinePaths(directory, "dummy"), (_b = (_a = state.host).getCurrentDirectory) == null ? void 0 : _b.call(_a));
            const scope = getPackageScopeForPath(directoryPath, state);
            if (!scope || !scope.contents.packageJsonContent.exports) {
                return void 0;
            }
            if (typeof scope.contents.packageJsonContent.name !== "string") {
                return void 0;
            }
            const parts = getPathComponents(moduleName);
            const nameParts = getPathComponents(scope.contents.packageJsonContent.name);
            if (!every(nameParts, (p, i) => parts[i] === p)) {
                return void 0;
            }
            const trailingParts = parts.slice(nameParts.length);
            const subpath = !length(trailingParts) ? "." : `.${directorySeparator}${trailingParts.join(directorySeparator)}`;
            if (getAllowJSCompilerOption(state.compilerOptions) && !pathContainsNodeModules(directory)) {
                return loadModuleFromExports(scope, extensions, subpath, state, cache, redirectedReference);
            }
            const priorityExtensions = extensions & (1 /* TypeScript */ | 4 /* Declaration */);
            const secondaryExtensions = extensions & ~(1 /* TypeScript */ | 4 /* Declaration */);
            return loadModuleFromExports(scope, priorityExtensions, subpath, state, cache, redirectedReference) || loadModuleFromExports(scope, secondaryExtensions, subpath, state, cache, redirectedReference);
        }
        function loadModuleFromExports(scope, extensions, subpath, state, cache, redirectedReference) {
            if (!scope.contents.packageJsonContent.exports) {
                return void 0;
            }
            if (subpath === ".") {
                let mainExport;
                if (typeof scope.contents.packageJsonContent.exports === "string" || Array.isArray(scope.contents.packageJsonContent.exports) || typeof scope.contents.packageJsonContent.exports === "object" && noKeyStartsWithDot(scope.contents.packageJsonContent.exports)) {
                    mainExport = scope.contents.packageJsonContent.exports;
                }
                else if (hasProperty(scope.contents.packageJsonContent.exports, ".")) {
                    mainExport = scope.contents.packageJsonContent.exports["."];
                }
                if (mainExport) {
                    const loadModuleFromTargetImportOrExport = getLoadModuleFromTargetImportOrExport(extensions, state, cache, redirectedReference, subpath, scope, 
                    /*isImports*/
                    false);
                    return loadModuleFromTargetImportOrExport(mainExport, "", 
                    /*pattern*/
                    false, ".");
                }
            }
            else if (allKeysStartWithDot(scope.contents.packageJsonContent.exports)) {
                if (typeof scope.contents.packageJsonContent.exports !== "object") {
                    if (state.traceEnabled) {
                        trace(state.host, Diagnostics.Export_specifier_0_does_not_exist_in_package_json_scope_at_path_1, subpath, scope.packageDirectory);
                    }
                    return toSearchResult(
                    /*value*/
                    void 0);
                }
                const result = loadModuleFromImportsOrExports(extensions, state, cache, redirectedReference, subpath, scope.contents.packageJsonContent.exports, scope, 
                /*isImports*/
                false);
                if (result) {
                    return result;
                }
            }
            if (state.traceEnabled) {
                trace(state.host, Diagnostics.Export_specifier_0_does_not_exist_in_package_json_scope_at_path_1, subpath, scope.packageDirectory);
            }
            return toSearchResult(
            /*value*/
            void 0);
        }
        function loadModuleFromImports(extensions, moduleName, directory, state, cache, redirectedReference) {
            var _a, _b;
            if (moduleName === "#" || startsWith(moduleName, "#/")) {
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.Invalid_import_specifier_0_has_no_possible_resolutions, moduleName);
                }
                return toSearchResult(
                /*value*/
                void 0);
            }
            const directoryPath = getNormalizedAbsolutePath(combinePaths(directory, "dummy"), (_b = (_a = state.host).getCurrentDirectory) == null ? void 0 : _b.call(_a));
            const scope = getPackageScopeForPath(directoryPath, state);
            if (!scope) {
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.Directory_0_has_no_containing_package_json_scope_Imports_will_not_resolve, directoryPath);
                }
                return toSearchResult(
                /*value*/
                void 0);
            }
            if (!scope.contents.packageJsonContent.imports) {
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.package_json_scope_0_has_no_imports_defined, scope.packageDirectory);
                }
                return toSearchResult(
                /*value*/
                void 0);
            }
            const result = loadModuleFromImportsOrExports(extensions, state, cache, redirectedReference, moduleName, scope.contents.packageJsonContent.imports, scope, 
            /*isImports*/
            true);
            if (result) {
                return result;
            }
            if (state.traceEnabled) {
                trace(state.host, Diagnostics.Import_specifier_0_does_not_exist_in_package_json_scope_at_path_1, moduleName, scope.packageDirectory);
            }
            return toSearchResult(
            /*value*/
            void 0);
        }
        function comparePatternKeys(a, b) {
            const aPatternIndex = a.indexOf("*");
            const bPatternIndex = b.indexOf("*");
            const baseLenA = aPatternIndex === -1 ? a.length : aPatternIndex + 1;
            const baseLenB = bPatternIndex === -1 ? b.length : bPatternIndex + 1;
            if (baseLenA > baseLenB)
                return -1;
            if (baseLenB > baseLenA)
                return 1;
            if (aPatternIndex === -1)
                return 1;
            if (bPatternIndex === -1)
                return -1;
            if (a.length > b.length)
                return -1;
            if (b.length > a.length)
                return 1;
            return 0;
        }
        function loadModuleFromImportsOrExports(extensions, state, cache, redirectedReference, moduleName, lookupTable, scope, isImports) {
            const loadModuleFromTargetImportOrExport = getLoadModuleFromTargetImportOrExport(extensions, state, cache, redirectedReference, moduleName, scope, isImports);
            if (!endsWith(moduleName, directorySeparator) && !moduleName.includes("*") && hasProperty(lookupTable, moduleName)) {
                const target = lookupTable[moduleName];
                return loadModuleFromTargetImportOrExport(target, 
                /*subpath*/
                "", 
                /*pattern*/
                false, moduleName);
            }
            const expandingKeys = sort(filter(getOwnKeys(lookupTable), (k) => k.includes("*") || endsWith(k, "/")), comparePatternKeys);
            for (const potentialTarget of expandingKeys) {
                if (state.features & 16 /* ExportsPatternTrailers */ && matchesPatternWithTrailer(potentialTarget, moduleName)) {
                    const target = lookupTable[potentialTarget];
                    const starPos = potentialTarget.indexOf("*");
                    const subpath = moduleName.substring(potentialTarget.substring(0, starPos).length, moduleName.length - (potentialTarget.length - 1 - starPos));
                    return loadModuleFromTargetImportOrExport(target, subpath, 
                    /*pattern*/
                    true, potentialTarget);
                }
                else if (endsWith(potentialTarget, "*") && startsWith(moduleName, potentialTarget.substring(0, potentialTarget.length - 1))) {
                    const target = lookupTable[potentialTarget];
                    const subpath = moduleName.substring(potentialTarget.length - 1);
                    return loadModuleFromTargetImportOrExport(target, subpath, 
                    /*pattern*/
                    true, potentialTarget);
                }
                else if (startsWith(moduleName, potentialTarget)) {
                    const target = lookupTable[potentialTarget];
                    const subpath = moduleName.substring(potentialTarget.length);
                    return loadModuleFromTargetImportOrExport(target, subpath, 
                    /*pattern*/
                    false, potentialTarget);
                }
            }
            function matchesPatternWithTrailer(target, name) {
                if (endsWith(target, "*"))
                    return false;
                const starPos = target.indexOf("*");
                if (starPos === -1)
                    return false;
                return startsWith(name, target.substring(0, starPos)) && endsWith(name, target.substring(starPos + 1));
            }
        }
        function getLoadModuleFromTargetImportOrExport(extensions, state, cache, redirectedReference, moduleName, scope, isImports) {
            return loadModuleFromTargetImportOrExport;
            function loadModuleFromTargetImportOrExport(target, subpath, pattern, key) {
                if (typeof target === "string") {
                    if (!pattern && subpath.length > 0 && !endsWith(target, "/")) {
                        if (state.traceEnabled) {
                            trace(state.host, Diagnostics.package_json_scope_0_has_invalid_type_for_target_of_specifier_1, scope.packageDirectory, moduleName);
                        }
                        return toSearchResult(
                        /*value*/
                        void 0);
                    }
                    if (!startsWith(target, "./")) {
                        if (isImports && !startsWith(target, "../") && !startsWith(target, "/") && !isRootedDiskPath(target)) {
                            const combinedLookup = pattern ? target.replace(/\*/g, subpath) : target + subpath;
                            traceIfEnabled(state, Diagnostics.Using_0_subpath_1_with_target_2, "imports", key, combinedLookup);
                            traceIfEnabled(state, Diagnostics.Resolving_module_0_from_1, combinedLookup, scope.packageDirectory + "/");
                            const result = nodeModuleNameResolverWorker(state.features, combinedLookup, scope.packageDirectory + "/", state.compilerOptions, state.host, cache, extensions, 
                            /*isConfigLookup*/
                            false, redirectedReference, state.conditions);
                            return toSearchResult(result.resolvedModule ? {
                                path: result.resolvedModule.resolvedFileName,
                                extension: result.resolvedModule.extension,
                                packageId: result.resolvedModule.packageId,
                                originalPath: result.resolvedModule.originalPath,
                                resolvedUsingTsExtension: result.resolvedModule.resolvedUsingTsExtension
                            } : void 0);
                        }
                        if (state.traceEnabled) {
                            trace(state.host, Diagnostics.package_json_scope_0_has_invalid_type_for_target_of_specifier_1, scope.packageDirectory, moduleName);
                        }
                        return toSearchResult(
                        /*value*/
                        void 0);
                    }
                    const parts = pathIsRelative(target) ? getPathComponents(target).slice(1) : getPathComponents(target);
                    const partsAfterFirst = parts.slice(1);
                    if (partsAfterFirst.includes("..") || partsAfterFirst.includes(".") || partsAfterFirst.includes("node_modules")) {
                        if (state.traceEnabled) {
                            trace(state.host, Diagnostics.package_json_scope_0_has_invalid_type_for_target_of_specifier_1, scope.packageDirectory, moduleName);
                        }
                        return toSearchResult(
                        /*value*/
                        void 0);
                    }
                    const resolvedTarget = combinePaths(scope.packageDirectory, target);
                    const subpathParts = getPathComponents(subpath);
                    if (subpathParts.includes("..") || subpathParts.includes(".") || subpathParts.includes("node_modules")) {
                        if (state.traceEnabled) {
                            trace(state.host, Diagnostics.package_json_scope_0_has_invalid_type_for_target_of_specifier_1, scope.packageDirectory, moduleName);
                        }
                        return toSearchResult(
                        /*value*/
                        void 0);
                    }
                    if (state.traceEnabled) {
                        trace(state.host, Diagnostics.Using_0_subpath_1_with_target_2, isImports ? "imports" : "exports", key, pattern ? target.replace(/\*/g, subpath) : target + subpath);
                    }
                    const finalPath = toAbsolutePath(pattern ? resolvedTarget.replace(/\*/g, subpath) : resolvedTarget + subpath);
                    const inputLink = tryLoadInputFileForPath(finalPath, subpath, combinePaths(scope.packageDirectory, "package.json"), isImports);
                    if (inputLink)
                        return inputLink;
                    return toSearchResult(withPackageId(scope, loadFileNameFromPackageJsonField(extensions, finalPath, 
                    /*onlyRecordFailures*/
                    false, state)));
                }
                else if (typeof target === "object" && target !== null) {
                    if (!Array.isArray(target)) {
                        traceIfEnabled(state, Diagnostics.Entering_conditional_exports);
                        for (const condition of getOwnKeys(target)) {
                            if (condition === "default" || state.conditions.includes(condition) || isApplicableVersionedTypesKey(state.conditions, condition)) {
                                traceIfEnabled(state, Diagnostics.Matched_0_condition_1, isImports ? "imports" : "exports", condition);
                                const subTarget = target[condition];
                                const result = loadModuleFromTargetImportOrExport(subTarget, subpath, pattern, key);
                                if (result) {
                                    traceIfEnabled(state, Diagnostics.Resolved_under_condition_0, condition);
                                    traceIfEnabled(state, Diagnostics.Exiting_conditional_exports);
                                    return result;
                                }
                                else {
                                    traceIfEnabled(state, Diagnostics.Failed_to_resolve_under_condition_0, condition);
                                }
                            }
                            else {
                                traceIfEnabled(state, Diagnostics.Saw_non_matching_condition_0, condition);
                            }
                        }
                        traceIfEnabled(state, Diagnostics.Exiting_conditional_exports);
                        return void 0;
                    }
                    else {
                        if (!length(target)) {
                            if (state.traceEnabled) {
                                trace(state.host, Diagnostics.package_json_scope_0_has_invalid_type_for_target_of_specifier_1, scope.packageDirectory, moduleName);
                            }
                            return toSearchResult(
                            /*value*/
                            void 0);
                        }
                        for (const elem of target) {
                            const result = loadModuleFromTargetImportOrExport(elem, subpath, pattern, key);
                            if (result) {
                                return result;
                            }
                        }
                    }
                }
                else if (target === null) {
                    if (state.traceEnabled) {
                        trace(state.host, Diagnostics.package_json_scope_0_explicitly_maps_specifier_1_to_null, scope.packageDirectory, moduleName);
                    }
                    return toSearchResult(
                    /*value*/
                    void 0);
                }
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.package_json_scope_0_has_invalid_type_for_target_of_specifier_1, scope.packageDirectory, moduleName);
                }
                return toSearchResult(
                /*value*/
                void 0);
                function toAbsolutePath(path) {
                    var _a, _b;
                    if (path === void 0)
                        return path;
                    return getNormalizedAbsolutePath(path, (_b = (_a = state.host).getCurrentDirectory) == null ? void 0 : _b.call(_a));
                }
                function combineDirectoryPath(root, dir) {
                    return ensureTrailingDirectorySeparator(combinePaths(root, dir));
                }
                function tryLoadInputFileForPath(finalPath, entry, packagePath, isImports2) {
                    var _a, _b, _c, _d;
                    if (!state.isConfigLookup && (state.compilerOptions.declarationDir || state.compilerOptions.outDir) && !finalPath.includes("/node_modules/") && (state.compilerOptions.configFile ? containsPath(scope.packageDirectory, toAbsolutePath(state.compilerOptions.configFile.fileName), !useCaseSensitiveFileNames(state)) : true)) {
                        const getCanonicalFileName = hostGetCanonicalFileName({ useCaseSensitiveFileNames: () => useCaseSensitiveFileNames(state) });
                        const commonSourceDirGuesses = [];
                        if (state.compilerOptions.rootDir || state.compilerOptions.composite && state.compilerOptions.configFilePath) {
                            const commonDir = toAbsolutePath(getCommonSourceDirectory(state.compilerOptions, () => [], ((_b = (_a = state.host).getCurrentDirectory) == null ? void 0 : _b.call(_a)) || "", getCanonicalFileName));
                            commonSourceDirGuesses.push(commonDir);
                        }
                        else if (state.requestContainingDirectory) {
                            const requestingFile = toAbsolutePath(combinePaths(state.requestContainingDirectory, "index.ts"));
                            const commonDir = toAbsolutePath(getCommonSourceDirectory(state.compilerOptions, () => [requestingFile, toAbsolutePath(packagePath)], ((_d = (_c = state.host).getCurrentDirectory) == null ? void 0 : _d.call(_c)) || "", getCanonicalFileName));
                            commonSourceDirGuesses.push(commonDir);
                            let fragment = ensureTrailingDirectorySeparator(commonDir);
                            while (fragment && fragment.length > 1) {
                                const parts = getPathComponents(fragment);
                                parts.pop();
                                const commonDir2 = getPathFromPathComponents(parts);
                                commonSourceDirGuesses.unshift(commonDir2);
                                fragment = ensureTrailingDirectorySeparator(commonDir2);
                            }
                        }
                        if (commonSourceDirGuesses.length > 1) {
                            state.reportDiagnostic(createCompilerDiagnostic(isImports2 ? Diagnostics.The_project_root_is_ambiguous_but_is_required_to_resolve_import_map_entry_0_in_file_1_Supply_the_rootDir_compiler_option_to_disambiguate : Diagnostics.The_project_root_is_ambiguous_but_is_required_to_resolve_export_map_entry_0_in_file_1_Supply_the_rootDir_compiler_option_to_disambiguate, entry === "" ? "." : entry, 
                            // replace empty string with `.` - the reverse of the operation done when entries are built - so main entrypoint errors don't look weird
                            packagePath));
                        }
                        for (const commonSourceDirGuess of commonSourceDirGuesses) {
                            const candidateDirectories = getOutputDirectoriesForBaseDirectory(commonSourceDirGuess);
                            for (const candidateDir of candidateDirectories) {
                                if (containsPath(candidateDir, finalPath, !useCaseSensitiveFileNames(state))) {
                                    const pathFragment = finalPath.slice(candidateDir.length + 1);
                                    const possibleInputBase = combinePaths(commonSourceDirGuess, pathFragment);
                                    const jsAndDtsExtensions = [".mjs" /* Mjs */, ".cjs" /* Cjs */, ".js" /* Js */, ".json" /* Json */, ".d.mts" /* Dmts */, ".d.cts" /* Dcts */, ".d.ts" /* Dts */];
                                    for (const ext of jsAndDtsExtensions) {
                                        if (fileExtensionIs(possibleInputBase, ext)) {
                                            const inputExts = getPossibleOriginalInputExtensionForExtension(possibleInputBase);
                                            for (const possibleExt of inputExts) {
                                                if (!extensionIsOk(extensions, possibleExt))
                                                    continue;
                                                const possibleInputWithInputExtension = changeAnyExtension(possibleInputBase, possibleExt, ext, !useCaseSensitiveFileNames(state));
                                                if (state.host.fileExists(possibleInputWithInputExtension)) {
                                                    return toSearchResult(withPackageId(scope, loadFileNameFromPackageJsonField(extensions, possibleInputWithInputExtension, 
                                                    /*onlyRecordFailures*/
                                                    false, state)));
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                    return void 0;
                    function getOutputDirectoriesForBaseDirectory(commonSourceDirGuess) {
                        var _a2, _b2;
                        const currentDir = state.compilerOptions.configFile ? ((_b2 = (_a2 = state.host).getCurrentDirectory) == null ? void 0 : _b2.call(_a2)) || "" : commonSourceDirGuess;
                        const candidateDirectories = [];
                        if (state.compilerOptions.declarationDir) {
                            candidateDirectories.push(toAbsolutePath(combineDirectoryPath(currentDir, state.compilerOptions.declarationDir)));
                        }
                        if (state.compilerOptions.outDir && state.compilerOptions.outDir !== state.compilerOptions.declarationDir) {
                            candidateDirectories.push(toAbsolutePath(combineDirectoryPath(currentDir, state.compilerOptions.outDir)));
                        }
                        return candidateDirectories;
                    }
                }
            }
        }
        function isApplicableVersionedTypesKey(conditions, key) {
            if (!conditions.includes("types"))
                return false;
            if (!startsWith(key, "types@"))
                return false;
            const range = VersionRange.tryParse(key.substring("types@".length));
            if (!range)
                return false;
            return range.test(version);
        }
        function loadModuleFromNearestNodeModulesDirectory(extensions, moduleName, directory, state, cache, redirectedReference) {
            return loadModuleFromNearestNodeModulesDirectoryWorker(extensions, moduleName, directory, state, 
            /*typesScopeOnly*/
            false, cache, redirectedReference);
        }
        function loadModuleFromNearestNodeModulesDirectoryTypesScope(moduleName, directory, state) {
            return loadModuleFromNearestNodeModulesDirectoryWorker(4 /* Declaration */, moduleName, directory, state, 
            /*typesScopeOnly*/
            true, 
            /*cache*/
            void 0, 
            /*redirectedReference*/
            void 0);
        }
        function loadModuleFromNearestNodeModulesDirectoryWorker(extensions, moduleName, directory, state, typesScopeOnly, cache, redirectedReference) {
            const mode = state.features === 0 ? void 0 : state.features & 32 /* EsmMode */ ? 99 /* ESNext */ : 1 /* CommonJS */;
            const priorityExtensions = extensions & (1 /* TypeScript */ | 4 /* Declaration */);
            const secondaryExtensions = extensions & ~(1 /* TypeScript */ | 4 /* Declaration */);
            if (priorityExtensions) {
                traceIfEnabled(state, Diagnostics.Searching_all_ancestor_node_modules_directories_for_preferred_extensions_Colon_0, formatExtensions(priorityExtensions));
                const result = lookup(priorityExtensions);
                if (result)
                    return result;
            }
            if (secondaryExtensions && !typesScopeOnly) {
                traceIfEnabled(state, Diagnostics.Searching_all_ancestor_node_modules_directories_for_fallback_extensions_Colon_0, formatExtensions(secondaryExtensions));
                return lookup(secondaryExtensions);
            }
            function lookup(extensions2) {
                return forEachAncestorDirectory(normalizeSlashes(directory), (ancestorDirectory) => {
                    if (getBaseFileName(ancestorDirectory) !== "node_modules") {
                        const resolutionFromCache = tryFindNonRelativeModuleNameInCache(cache, moduleName, mode, ancestorDirectory, redirectedReference, state);
                        if (resolutionFromCache) {
                            return resolutionFromCache;
                        }
                        return toSearchResult(loadModuleFromImmediateNodeModulesDirectory(extensions2, moduleName, ancestorDirectory, state, typesScopeOnly, cache, redirectedReference));
                    }
                });
            }
        }
        function loadModuleFromImmediateNodeModulesDirectory(extensions, moduleName, directory, state, typesScopeOnly, cache, redirectedReference) {
            const nodeModulesFolder = combinePaths(directory, "node_modules");
            const nodeModulesFolderExists = directoryProbablyExists(nodeModulesFolder, state.host);
            if (!nodeModulesFolderExists && state.traceEnabled) {
                trace(state.host, Diagnostics.Directory_0_does_not_exist_skipping_all_lookups_in_it, nodeModulesFolder);
            }
            if (!typesScopeOnly) {
                const packageResult = loadModuleFromSpecificNodeModulesDirectory(extensions, moduleName, nodeModulesFolder, nodeModulesFolderExists, state, cache, redirectedReference);
                if (packageResult) {
                    return packageResult;
                }
            }
            if (extensions & 4 /* Declaration */) {
                const nodeModulesAtTypes2 = combinePaths(nodeModulesFolder, "@types");
                let nodeModulesAtTypesExists = nodeModulesFolderExists;
                if (nodeModulesFolderExists && !directoryProbablyExists(nodeModulesAtTypes2, state.host)) {
                    if (state.traceEnabled) {
                        trace(state.host, Diagnostics.Directory_0_does_not_exist_skipping_all_lookups_in_it, nodeModulesAtTypes2);
                    }
                    nodeModulesAtTypesExists = false;
                }
                return loadModuleFromSpecificNodeModulesDirectory(4 /* Declaration */, mangleScopedPackageNameWithTrace(moduleName, state), nodeModulesAtTypes2, nodeModulesAtTypesExists, state, cache, redirectedReference);
            }
        }
        function loadModuleFromSpecificNodeModulesDirectory(extensions, moduleName, nodeModulesDirectory, nodeModulesDirectoryExists, state, cache, redirectedReference) {
            var _a, _b;
            const candidate = normalizePath(combinePaths(nodeModulesDirectory, moduleName));
            const { packageName, rest } = parsePackageName(moduleName);
            const packageDirectory = combinePaths(nodeModulesDirectory, packageName);
            let rootPackageInfo;
            let packageInfo = getPackageJsonInfo(candidate, !nodeModulesDirectoryExists, state);
            if (rest !== "" && packageInfo && (!(state.features & 8 /* Exports */) || !hasProperty(((_a = rootPackageInfo = getPackageJsonInfo(packageDirectory, !nodeModulesDirectoryExists, state)) == null ? void 0 : _a.contents.packageJsonContent) ?? emptyArray, "exports"))) {
                const fromFile = loadModuleFromFile(extensions, candidate, !nodeModulesDirectoryExists, state);
                if (fromFile) {
                    return noPackageId(fromFile);
                }
                const fromDirectory = loadNodeModuleFromDirectoryWorker(extensions, candidate, !nodeModulesDirectoryExists, state, packageInfo.contents.packageJsonContent, getVersionPathsOfPackageJsonInfo(packageInfo, state));
                return withPackageId(packageInfo, fromDirectory);
            }
            const loader = (extensions2, candidate2, onlyRecordFailures, state2) => {
                let pathAndExtension = (rest || !(state2.features & 32 /* EsmMode */)) && loadModuleFromFile(extensions2, candidate2, onlyRecordFailures, state2) || loadNodeModuleFromDirectoryWorker(extensions2, candidate2, onlyRecordFailures, state2, packageInfo && packageInfo.contents.packageJsonContent, packageInfo && getVersionPathsOfPackageJsonInfo(packageInfo, state2));
                if (!pathAndExtension && packageInfo && (packageInfo.contents.packageJsonContent.exports === void 0 || packageInfo.contents.packageJsonContent.exports === null) && state2.features & 32 /* EsmMode */) {
                    pathAndExtension = loadModuleFromFile(extensions2, combinePaths(candidate2, "index.js"), onlyRecordFailures, state2);
                }
                return withPackageId(packageInfo, pathAndExtension);
            };
            if (rest !== "") {
                packageInfo = rootPackageInfo ?? getPackageJsonInfo(packageDirectory, !nodeModulesDirectoryExists, state);
            }
            if (packageInfo) {
                state.resolvedPackageDirectory = true;
            }
            if (packageInfo && packageInfo.contents.packageJsonContent.exports && state.features & 8 /* Exports */) {
                return (_b = loadModuleFromExports(packageInfo, extensions, combinePaths(".", rest), state, cache, redirectedReference)) == null ? void 0 : _b.value;
            }
            const versionPaths = rest !== "" && packageInfo ? getVersionPathsOfPackageJsonInfo(packageInfo, state) : void 0;
            if (versionPaths) {
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.package_json_has_a_typesVersions_entry_0_that_matches_compiler_version_1_looking_for_a_pattern_to_match_module_name_2, versionPaths.version, version, rest);
                }
                const packageDirectoryExists = nodeModulesDirectoryExists && directoryProbablyExists(packageDirectory, state.host);
                const fromPaths = tryLoadModuleUsingPaths(extensions, rest, packageDirectory, versionPaths.paths, 
                /*pathPatterns*/
                void 0, loader, !packageDirectoryExists, state);
                if (fromPaths) {
                    return fromPaths.value;
                }
            }
            return loader(extensions, candidate, !nodeModulesDirectoryExists, state);
        }
        function tryLoadModuleUsingPaths(extensions, moduleName, baseDirectory, paths, pathPatterns, loader, onlyRecordFailures, state) {
            pathPatterns || (pathPatterns = tryParsePatterns(paths));
            const matchedPattern = matchPatternOrExact(pathPatterns, moduleName);
            if (matchedPattern) {
                const matchedStar = isString(matchedPattern) ? void 0 : matchedText(matchedPattern, moduleName);
                const matchedPatternText = isString(matchedPattern) ? matchedPattern : patternText(matchedPattern);
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.Module_name_0_matched_pattern_1, moduleName, matchedPatternText);
                }
                const resolved = forEach(paths[matchedPatternText], (subst) => {
                    const path = matchedStar ? replaceFirstStar(subst, matchedStar) : subst;
                    const candidate = normalizePath(combinePaths(baseDirectory, path));
                    if (state.traceEnabled) {
                        trace(state.host, Diagnostics.Trying_substitution_0_candidate_module_location_Colon_1, subst, path);
                    }
                    const extension = tryGetExtensionFromPath2(subst);
                    if (extension !== void 0) {
                        const path2 = tryFile(candidate, onlyRecordFailures, state);
                        if (path2 !== void 0) {
                            return noPackageId({ path: path2, ext: extension, resolvedUsingTsExtension: void 0 });
                        }
                    }
                    return loader(extensions, candidate, onlyRecordFailures || !directoryProbablyExists(getDirectoryPath(candidate), state.host), state);
                });
                return { value: resolved };
            }
        }
        function mangleScopedPackageNameWithTrace(packageName, state) {
            const mangled = mangleScopedPackageName(packageName);
            if (state.traceEnabled && mangled !== packageName) {
                trace(state.host, Diagnostics.Scoped_package_detected_looking_in_0, mangled);
            }
            return mangled;
        }
        function getTypesPackageName(packageName) {
            return `@types/${mangleScopedPackageName(packageName)}`;
        }
        function mangleScopedPackageName(packageName) {
            if (startsWith(packageName, "@")) {
                const replaceSlash = packageName.replace(directorySeparator, mangledScopedPackageSeparator);
                if (replaceSlash !== packageName) {
                    return replaceSlash.slice(1);
                }
            }
            return packageName;
        }
        function getPackageNameFromTypesPackageName(mangledName) {
            const withoutAtTypePrefix = removePrefix(mangledName, "@types/");
            if (withoutAtTypePrefix !== mangledName) {
                return unmangleScopedPackageName(withoutAtTypePrefix);
            }
            return mangledName;
        }
        function unmangleScopedPackageName(typesPackageName) {
            return typesPackageName.includes(mangledScopedPackageSeparator) ? "@" + typesPackageName.replace(mangledScopedPackageSeparator, directorySeparator) : typesPackageName;
        }
        function tryFindNonRelativeModuleNameInCache(cache, moduleName, mode, containingDirectory, redirectedReference, state) {
            const result = cache && cache.getFromNonRelativeNameCache(moduleName, mode, containingDirectory, redirectedReference);
            if (result) {
                if (state.traceEnabled) {
                    trace(state.host, Diagnostics.Resolution_for_module_0_was_found_in_cache_from_location_1, moduleName, containingDirectory);
                }
                state.resultFromCache = result;
                return {
                    value: result.resolvedModule && {
                        path: result.resolvedModule.resolvedFileName,
                        originalPath: result.resolvedModule.originalPath || true,
                        extension: result.resolvedModule.extension,
                        packageId: result.resolvedModule.packageId,
                        resolvedUsingTsExtension: result.resolvedModule.resolvedUsingTsExtension
                    }
                };
            }
        }
        function classicNameResolver(moduleName, containingFile, compilerOptions, host, cache, redirectedReference) {
            const traceEnabled = isTraceEnabled(compilerOptions, host);
            const failedLookupLocations = [];
            const affectingLocations = [];
            const containingDirectory = getDirectoryPath(containingFile);
            const diagnostics = [];
            const state = {
                compilerOptions,
                host,
                traceEnabled,
                failedLookupLocations,
                affectingLocations,
                packageJsonInfoCache: cache,
                features: 0 /* None */,
                conditions: [],
                requestContainingDirectory: containingDirectory,
                reportDiagnostic: (diag2) => void diagnostics.push(diag2),
                isConfigLookup: false,
                candidateIsFromPackageJsonField: false,
                resolvedPackageDirectory: false
            };
            const resolved = tryResolve(1 /* TypeScript */ | 4 /* Declaration */) || tryResolve(2 /* JavaScript */ | (compilerOptions.resolveJsonModule ? 8 /* Json */ : 0));
            return createResolvedModuleWithFailedLookupLocationsHandlingSymlink(moduleName, resolved && resolved.value, (resolved == null ? void 0 : resolved.value) && pathContainsNodeModules(resolved.value.path), failedLookupLocations, affectingLocations, diagnostics, state, cache);
            function tryResolve(extensions) {
                const resolvedUsingSettings = tryLoadModuleUsingOptionalResolutionSettings(extensions, moduleName, containingDirectory, loadModuleFromFileNoPackageId, state);
                if (resolvedUsingSettings) {
                    return { value: resolvedUsingSettings };
                }
                if (!isExternalModuleNameRelative(moduleName)) {
                    const resolved2 = forEachAncestorDirectory(containingDirectory, (directory) => {
                        const resolutionFromCache = tryFindNonRelativeModuleNameInCache(cache, moduleName, 
                        /*mode*/
                        void 0, directory, redirectedReference, state);
                        if (resolutionFromCache) {
                            return resolutionFromCache;
                        }
                        const searchName = normalizePath(combinePaths(directory, moduleName));
                        return toSearchResult(loadModuleFromFileNoPackageId(extensions, searchName, 
                        /*onlyRecordFailures*/
                        false, state));
                    });
                    if (resolved2)
                        return resolved2;
                    if (extensions & (1 /* TypeScript */ | 4 /* Declaration */)) {
                        let resolved3 = loadModuleFromNearestNodeModulesDirectoryTypesScope(moduleName, containingDirectory, state);
                        if (extensions & 4 /* Declaration */)
                            resolved3 ?? (resolved3 = resolveFromTypeRoot(moduleName, state));
                        return resolved3;
                    }
                }
                else {
                    const candidate = normalizePath(combinePaths(containingDirectory, moduleName));
                    return toSearchResult(loadModuleFromFileNoPackageId(extensions, candidate, 
                    /*onlyRecordFailures*/
                    false, state));
                }
            }
        }
        function resolveFromTypeRoot(moduleName, state) {
            if (!state.compilerOptions.typeRoots)
                return;
            for (const typeRoot of state.compilerOptions.typeRoots) {
                const candidate = getCandidateFromTypeRoot(typeRoot, moduleName, state);
                const directoryExists = directoryProbablyExists(typeRoot, state.host);
                if (!directoryExists && state.traceEnabled) {
                    trace(state.host, Diagnostics.Directory_0_does_not_exist_skipping_all_lookups_in_it, typeRoot);
                }
                const resolvedFromFile = loadModuleFromFile(4 /* Declaration */, candidate, !directoryExists, state);
                if (resolvedFromFile) {
                    const packageDirectory = parseNodeModuleFromPath(resolvedFromFile.path);
                    const packageInfo = packageDirectory ? getPackageJsonInfo(packageDirectory, 
                    /*onlyRecordFailures*/
                    false, state) : void 0;
                    return toSearchResult(withPackageId(packageInfo, resolvedFromFile));
                }
                const resolved = loadNodeModuleFromDirectory(4 /* Declaration */, candidate, !directoryExists, state);
                if (resolved)
                    return toSearchResult(resolved);
            }
        }
        function shouldAllowImportingTsExtension(compilerOptions, fromFileName) {
            return !!compilerOptions.allowImportingTsExtensions || fromFileName && isDeclarationFileName(fromFileName);
        }
        function loadModuleFromGlobalCache(moduleName, projectName, compilerOptions, host, globalCache, packageJsonInfoCache) {
            const traceEnabled = isTraceEnabled(compilerOptions, host);
            if (traceEnabled) {
                trace(host, Diagnostics.Auto_discovery_for_typings_is_enabled_in_project_0_Running_extra_resolution_pass_for_module_1_using_cache_location_2, projectName, moduleName, globalCache);
            }
            const failedLookupLocations = [];
            const affectingLocations = [];
            const diagnostics = [];
            const state = {
                compilerOptions,
                host,
                traceEnabled,
                failedLookupLocations,
                affectingLocations,
                packageJsonInfoCache,
                features: 0 /* None */,
                conditions: [],
                requestContainingDirectory: void 0,
                reportDiagnostic: (diag2) => void diagnostics.push(diag2),
                isConfigLookup: false,
                candidateIsFromPackageJsonField: false,
                resolvedPackageDirectory: false
            };
            const resolved = loadModuleFromImmediateNodeModulesDirectory(4 /* Declaration */, moduleName, globalCache, state, 
            /*typesScopeOnly*/
            false, 
            /*cache*/
            void 0, 
            /*redirectedReference*/
            void 0);
            return createResolvedModuleWithFailedLookupLocations(resolved, 
            /*isExternalLibraryImport*/
            true, failedLookupLocations, affectingLocations, diagnostics, state.resultFromCache, 
            /*cache*/
            void 0);
        }
        function toSearchResult(value) {
            return value !== void 0 ? { value } : void 0;
        }
        function traceIfEnabled(state, diagnostic, ...args) {
            if (state.traceEnabled) {
                trace(state.host, diagnostic, ...args);
            }
        }
        function useCaseSensitiveFileNames(state) {
            return !state.host.useCaseSensitiveFileNames ? true : typeof state.host.useCaseSensitiveFileNames === "boolean" ? state.host.useCaseSensitiveFileNames : state.host.useCaseSensitiveFileNames();
        }
        var typeScriptVersion, nodeModulesAtTypes, NodeResolutionFeatures, nodeModulesPathPart, mangledScopedPackageSeparator;
        var init_moduleNameResolver = __esm({
            "src/compiler/moduleNameResolver.ts"() {
                "use strict";
                init_ts2();
                nodeModulesAtTypes = combinePaths("node_modules", "@types");
                NodeResolutionFeatures = /* @__PURE__ */ ((NodeResolutionFeatures2) => {
                    NodeResolutionFeatures2[NodeResolutionFeatures2["None"] = 0] = "None";
                    NodeResolutionFeatures2[NodeResolutionFeatures2["Imports"] = 2] = "Imports";
                    NodeResolutionFeatures2[NodeResolutionFeatures2["SelfName"] = 4] = "SelfName";
                    NodeResolutionFeatures2[NodeResolutionFeatures2["Exports"] = 8] = "Exports";
                    NodeResolutionFeatures2[NodeResolutionFeatures2["ExportsPatternTrailers"] = 16] = "ExportsPatternTrailers";
                    NodeResolutionFeatures2[NodeResolutionFeatures2["AllFeatures"] = 30] = "AllFeatures";
                    NodeResolutionFeatures2[NodeResolutionFeatures2["Node16Default"] = 30] = "Node16Default";
                    NodeResolutionFeatures2[NodeResolutionFeatures2["NodeNextDefault"] = 30 /* AllFeatures */] = "NodeNextDefault";
                    NodeResolutionFeatures2[NodeResolutionFeatures2["BundlerDefault"] = 30] = "BundlerDefault";
                    NodeResolutionFeatures2[NodeResolutionFeatures2["EsmMode"] = 32] = "EsmMode";
                    return NodeResolutionFeatures2;
                })(NodeResolutionFeatures || {});
                nodeModulesPathPart = "/node_modules/";
                mangledScopedPackageSeparator = "__";
            }
        });
        // src/compiler/binder.ts
        function getModuleInstanceState(node, visited) {
            if (node.body && !node.body.parent) {
                setParent(node.body, node);
                setParentRecursive(node.body, 
                /*incremental*/
                false);
            }
            return node.body ? getModuleInstanceStateCached(node.body, visited) : 1 /* Instantiated */;
        }
        function getModuleInstanceStateCached(node, visited = /* @__PURE__ */ new Map()) {
            const nodeId = getNodeId(node);
            if (visited.has(nodeId)) {
                return visited.get(nodeId) || 0 /* NonInstantiated */;
            }
            visited.set(nodeId, void 0);
            const result = getModuleInstanceStateWorker(node, visited);
            visited.set(nodeId, result);
            return result;
        }
        function getModuleInstanceStateWorker(node, visited) {
            switch (node.kind) {
                case 264 /* InterfaceDeclaration */:
                case 265 /* TypeAliasDeclaration */:
                    return 0 /* NonInstantiated */;
                case 266 /* EnumDeclaration */:
                    if (isEnumConst(node)) {
                        return 2 /* ConstEnumOnly */;
                    }
                    break;
                case 272 /* ImportDeclaration */:
                case 271 /* ImportEqualsDeclaration */:
                    if (!hasSyntacticModifier(node, 32 /* Export */)) {
                        return 0 /* NonInstantiated */;
                    }
                    break;
                case 278 /* ExportDeclaration */:
                    const exportDeclaration = node;
                    if (!exportDeclaration.moduleSpecifier && exportDeclaration.exportClause && exportDeclaration.exportClause.kind === 279 /* NamedExports */) {
                        let state = 0 /* NonInstantiated */;
                        for (const specifier of exportDeclaration.exportClause.elements) {
                            const specifierState = getModuleInstanceStateForAliasTarget(specifier, visited);
                            if (specifierState > state) {
                                state = specifierState;
                            }
                            if (state === 1 /* Instantiated */) {
                                return state;
                            }
                        }
                        return state;
                    }
                    break;
                case 268 /* ModuleBlock */: {
                    let state = 0 /* NonInstantiated */;
                    forEachChild(node, (n) => {
                        const childState = getModuleInstanceStateCached(n, visited);
                        switch (childState) {
                            case 0 /* NonInstantiated */:
                                return;
                            case 2 /* ConstEnumOnly */:
                                state = 2 /* ConstEnumOnly */;
                                return;
                            case 1 /* Instantiated */:
                                state = 1 /* Instantiated */;
                                return true;
                            default:
                                Debug.assertNever(childState);
                        }
                    });
                    return state;
                }
                case 267 /* ModuleDeclaration */:
                    return getModuleInstanceState(node, visited);
                case 80 /* Identifier */:
                    if (node.flags & 4096 /* IdentifierIsInJSDocNamespace */) {
                        return 0 /* NonInstantiated */;
                    }
            }
            return 1 /* Instantiated */;
        }
        function getModuleInstanceStateForAliasTarget(specifier, visited) {
            const name = specifier.propertyName || specifier.name;
            let p = specifier.parent;
            while (p) {
                if (isBlock(p) || isModuleBlock(p) || isSourceFile(p)) {
                    const statements = p.statements;
                    let found;
                    for (const statement of statements) {
                        if (nodeHasName(statement, name)) {
                            if (!statement.parent) {
                                setParent(statement, p);
                                setParentRecursive(statement, 
                                /*incremental*/
                                false);
                            }
                            const state = getModuleInstanceStateCached(statement, visited);
                            if (found === void 0 || state > found) {
                                found = state;
                            }
                            if (found === 1 /* Instantiated */) {
                                return found;
                            }
                            if (statement.kind === 271 /* ImportEqualsDeclaration */) {
                                found = 1 /* Instantiated */;
                            }
                        }
                    }
                    if (found !== void 0) {
                        return found;
                    }
                }
                p = p.parent;
            }
            return 1 /* Instantiated */;
        }
        function initFlowNode(node) {
            Debug.attachFlowNodeDebugInfo(node);
            return node;
        }
        function bindSourceFile(file, options) {
            var _a, _b;
            mark("beforeBind");
            (_a = perfLogger) == null ? void 0 : _a.logStartBindFile("" + file.fileName);
            binder(file, options);
            (_b = perfLogger) == null ? void 0 : _b.logStopBindFile();
            mark("afterBind");
            measure("Bind", "beforeBind", "afterBind");
        }
        function createBinder() {
            var file;
            var options;
            var languageVersion;
            var parent2;
            var container;
            var thisParentContainer;
            var blockScopeContainer;
            var lastContainer;
            var delayedTypeAliases;
            var seenThisKeyword;
            var currentFlow;
            var currentBreakTarget;
            var currentContinueTarget;
            var currentReturnTarget;
            var currentTrueTarget;
            var currentFalseTarget;
            var currentExceptionTarget;
            var preSwitchCaseFlow;
            var activeLabelList;
            var hasExplicitReturn;
            var emitFlags;
            var inStrictMode;
            var inAssignmentPattern = false;
            var symbolCount = 0;
            var Symbol47;
            var classifiableNames;
            var unreachableFlow = { flags: 1 /* Unreachable */ };
            var reportedUnreachableFlow = { flags: 1 /* Unreachable */ };
            var bindBinaryExpressionFlow = createBindBinaryExpressionFlow();
            return bindSourceFile2;
            function createDiagnosticForNode2(node, message, ...args) {
                return createDiagnosticForNodeInSourceFile(getSourceFileOfNode(node) || file, node, message, ...args);
            }
            function bindSourceFile2(f, opts) {
                var _a, _b;
                file = f;
                options = opts;
                languageVersion = getEmitScriptTarget(options);
                inStrictMode = bindInStrictMode(file, opts);
                classifiableNames = /* @__PURE__ */ new Set();
                symbolCount = 0;
                Symbol47 = objectAllocator.getSymbolConstructor();
                Debug.attachFlowNodeDebugInfo(unreachableFlow);
                Debug.attachFlowNodeDebugInfo(reportedUnreachableFlow);
                if (!file.locals) {
                    (_a = tracing) == null ? void 0 : _a.push(tracing.Phase.Bind, "bindSourceFile", { path: file.path }, 
                    /*separateBeginAndEnd*/
                    true);
                    bind(file);
                    (_b = tracing) == null ? void 0 : _b.pop();
                    file.symbolCount = symbolCount;
                    file.classifiableNames = classifiableNames;
                    delayedBindJSDocTypedefTag();
                }
                file = void 0;
                options = void 0;
                languageVersion = void 0;
                parent2 = void 0;
                container = void 0;
                thisParentContainer = void 0;
                blockScopeContainer = void 0;
                lastContainer = void 0;
                delayedTypeAliases = void 0;
                seenThisKeyword = false;
                currentFlow = void 0;
                currentBreakTarget = void 0;
                currentContinueTarget = void 0;
                currentReturnTarget = void 0;
                currentTrueTarget = void 0;
                currentFalseTarget = void 0;
                currentExceptionTarget = void 0;
                activeLabelList = void 0;
                hasExplicitReturn = false;
                inAssignmentPattern = false;
                emitFlags = 0 /* None */;
            }
            function bindInStrictMode(file2, opts) {
                if (getStrictOptionValue(opts, "alwaysStrict") && !file2.isDeclarationFile) {
                    return true;
                }
                else {
                    return !!file2.externalModuleIndicator;
                }
            }
            function createSymbol(flags, name) {
                symbolCount++;
                return new Symbol47(flags, name);
            }
            function addDeclarationToSymbol(symbol, node, symbolFlags) {
                symbol.flags |= symbolFlags;
                node.symbol = symbol;
                symbol.declarations = appendIfUnique(symbol.declarations, node);
                if (symbolFlags & (32 /* Class */ | 384 /* Enum */ | 1536 /* Module */ | 3 /* Variable */) && !symbol.exports) {
                    symbol.exports = createSymbolTable();
                }
                if (symbolFlags & (32 /* Class */ | 64 /* Interface */ | 2048 /* TypeLiteral */ | 4096 /* ObjectLiteral */) && !symbol.members) {
                    symbol.members = createSymbolTable();
                }
                if (symbol.constEnumOnlyModule && symbol.flags & (16 /* Function */ | 32 /* Class */ | 256 /* RegularEnum */)) {
                    symbol.constEnumOnlyModule = false;
                }
                if (symbolFlags & 111551 /* Value */) {
                    setValueDeclaration(symbol, node);
                }
            }
            function getDeclarationName(node) {
                if (node.kind === 277 /* ExportAssignment */) {
                    return node.isExportEquals ? "export=" /* ExportEquals */ : "default" /* Default */;
                }
                const name = getNameOfDeclaration(node);
                if (name) {
                    if (isAmbientModule(node)) {
                        const moduleName = getTextOfIdentifierOrLiteral(name);
                        return isGlobalScopeAugmentation(node) ? "__global" : `"${moduleName}"`;
                    }
                    if (name.kind === 167 /* ComputedPropertyName */) {
                        const nameExpression = name.expression;
                        if (isStringOrNumericLiteralLike(nameExpression)) {
                            return escapeLeadingUnderscores(nameExpression.text);
                        }
                        if (isSignedNumericLiteral(nameExpression)) {
                            return tokenToString(nameExpression.operator) + nameExpression.operand.text;
                        }
                        else {
                            Debug.fail("Only computed properties with literal names have declaration names");
                        }
                    }
                    if (isPrivateIdentifier(name)) {
                        const containingClass = getContainingClass(node);
                        if (!containingClass) {
                            return void 0;
                        }
                        const containingClassSymbol = containingClass.symbol;
                        return getSymbolNameForPrivateIdentifier(containingClassSymbol, name.escapedText);
                    }
                    if (isJsxNamespacedName(name)) {
                        return getEscapedTextOfJsxNamespacedName(name);
                    }
                    return isPropertyNameLiteral(name) ? getEscapedTextOfIdentifierOrLiteral(name) : void 0;
                }
                switch (node.kind) {
                    case 176 /* Constructor */:
                        return "__constructor" /* Constructor */;
                    case 184 /* FunctionType */:
                    case 179 /* CallSignature */:
                    case 330 /* JSDocSignature */:
                        return "__call" /* Call */;
                    case 185 /* ConstructorType */:
                    case 180 /* ConstructSignature */:
                        return "__new" /* New */;
                    case 181 /* IndexSignature */:
                        return "__index" /* Index */;
                    case 278 /* ExportDeclaration */:
                        return "__export" /* ExportStar */;
                    case 312 /* SourceFile */:
                        return "export=" /* ExportEquals */;
                    case 226 /* BinaryExpression */:
                        if (getAssignmentDeclarationKind(node) === 2 /* ModuleExports */) {
                            return "export=" /* ExportEquals */;
                        }
                        Debug.fail("Unknown binary declaration kind");
                        break;
                    case 324 /* JSDocFunctionType */:
                        return isJSDocConstructSignature(node) ? "__new" /* New */ : "__call" /* Call */;
                    case 169 /* Parameter */:
                        Debug.assert(node.parent.kind === 324 /* JSDocFunctionType */, "Impossible parameter parent kind", () => `parent is: ${Debug.formatSyntaxKind(node.parent.kind)}, expected JSDocFunctionType`);
                        const functionType = node.parent;
                        const index = functionType.parameters.indexOf(node);
                        return "arg" + index;
                }
            }
            function getDisplayName(node) {
                return isNamedDeclaration(node) ? declarationNameToString(node.name) : unescapeLeadingUnderscores(Debug.checkDefined(getDeclarationName(node)));
            }
            function declareSymbol(symbolTable, parent3, node, includes, excludes, isReplaceableByMethod, isComputedName) {
                Debug.assert(isComputedName || !hasDynamicName(node));
                const isDefaultExport = hasSyntacticModifier(node, 2048 /* Default */) || isExportSpecifier(node) && node.name.escapedText === "default";
                const name = isComputedName ? "__computed" /* Computed */ : isDefaultExport && parent3 ? "default" /* Default */ : getDeclarationName(node);
                let symbol;
                if (name === void 0) {
                    symbol = createSymbol(0 /* None */, "__missing" /* Missing */);
                }
                else {
                    symbol = symbolTable.get(name);
                    if (includes & 2885600 /* Classifiable */) {
                        classifiableNames.add(name);
                    }
                    if (!symbol) {
                        symbolTable.set(name, symbol = createSymbol(0 /* None */, name));
                        if (isReplaceableByMethod)
                            symbol.isReplaceableByMethod = true;
                    }
                    else if (isReplaceableByMethod && !symbol.isReplaceableByMethod) {
                        return symbol;
                    }
                    else if (symbol.flags & excludes) {
                        if (symbol.isReplaceableByMethod) {
                            symbolTable.set(name, symbol = createSymbol(0 /* None */, name));
                        }
                        else if (!(includes & 3 /* Variable */ && symbol.flags & 67108864 /* Assignment */)) {
                            if (isNamedDeclaration(node)) {
                                setParent(node.name, node);
                            }
                            let message = symbol.flags & 2 /* BlockScopedVariable */ ? Diagnostics.Cannot_redeclare_block_scoped_variable_0 : Diagnostics.Duplicate_identifier_0;
                            let messageNeedsName = true;
                            if (symbol.flags & 384 /* Enum */ || includes & 384 /* Enum */) {
                                message = Diagnostics.Enum_declarations_can_only_merge_with_namespace_or_other_enum_declarations;
                                messageNeedsName = false;
                            }
                            let multipleDefaultExports = false;
                            if (length(symbol.declarations)) {
                                if (isDefaultExport) {
                                    message = Diagnostics.A_module_cannot_have_multiple_default_exports;
                                    messageNeedsName = false;
                                    multipleDefaultExports = true;
                                }
                                else {
                                    if (symbol.declarations && symbol.declarations.length && (node.kind === 277 /* ExportAssignment */ && !node.isExportEquals)) {
                                        message = Diagnostics.A_module_cannot_have_multiple_default_exports;
                                        messageNeedsName = false;
                                        multipleDefaultExports = true;
                                    }
                                }
                            }
                            const relatedInformation = [];
                            if (isTypeAliasDeclaration(node) && nodeIsMissing(node.type) && hasSyntacticModifier(node, 32 /* Export */) && symbol.flags & (2097152 /* Alias */ | 788968 /* Type */ | 1920 /* Namespace */)) {
                                relatedInformation.push(createDiagnosticForNode2(node, Diagnostics.Did_you_mean_0, `export type { ${unescapeLeadingUnderscores(node.name.escapedText)} }`));
                            }
                            const declarationName = getNameOfDeclaration(node) || node;
                            forEach(symbol.declarations, (declaration, index) => {
                                const decl = getNameOfDeclaration(declaration) || declaration;
                                const diag3 = messageNeedsName ? createDiagnosticForNode2(decl, message, getDisplayName(declaration)) : createDiagnosticForNode2(decl, message);
                                file.bindDiagnostics.push(multipleDefaultExports ? addRelatedInfo(diag3, createDiagnosticForNode2(declarationName, index === 0 ? Diagnostics.Another_export_default_is_here : Diagnostics.and_here)) : diag3);
                                if (multipleDefaultExports) {
                                    relatedInformation.push(createDiagnosticForNode2(decl, Diagnostics.The_first_export_default_is_here));
                                }
                            });
                            const diag2 = messageNeedsName ? createDiagnosticForNode2(declarationName, message, getDisplayName(node)) : createDiagnosticForNode2(declarationName, message);
                            file.bindDiagnostics.push(addRelatedInfo(diag2, ...relatedInformation));
                            symbol = createSymbol(0 /* None */, name);
                        }
                    }
                }
                addDeclarationToSymbol(symbol, node, includes);
                if (symbol.parent) {
                    Debug.assert(symbol.parent === parent3, "Existing symbol parent should match new one");
                }
                else {
                    symbol.parent = parent3;
                }
                return symbol;
            }
            function declareModuleMember(node, symbolFlags, symbolExcludes) {
                const hasExportModifier = !!(getCombinedModifierFlags(node) & 32 /* Export */) || jsdocTreatAsExported(node);
                if (symbolFlags & 2097152 /* Alias */) {
                    if (node.kind === 281 /* ExportSpecifier */ || node.kind === 271 /* ImportEqualsDeclaration */ && hasExportModifier) {
                        return declareSymbol(container.symbol.exports, container.symbol, node, symbolFlags, symbolExcludes);
                    }
                    else {
                        Debug.assertNode(container, canHaveLocals);
                        return declareSymbol(container.locals, 
                        /*parent*/
                        void 0, node, symbolFlags, symbolExcludes);
                    }
                }
                else {
                    if (isJSDocTypeAlias(node))
                        Debug.assert(isInJSFile(node));
                    if (!isAmbientModule(node) && (hasExportModifier || container.flags & 128 /* ExportContext */)) {
                        if (!canHaveLocals(container) || !container.locals || hasSyntacticModifier(node, 2048 /* Default */) && !getDeclarationName(node)) {
                            return declareSymbol(container.symbol.exports, container.symbol, node, symbolFlags, symbolExcludes);
                        }
                        const exportKind = symbolFlags & 111551 /* Value */ ? 1048576 /* ExportValue */ : 0;
                        const local = declareSymbol(container.locals, 
                        /*parent*/
                        void 0, node, exportKind, symbolExcludes);
                        local.exportSymbol = declareSymbol(container.symbol.exports, container.symbol, node, symbolFlags, symbolExcludes);
                        node.localSymbol = local;
                        return local;
                    }
                    else {
                        Debug.assertNode(container, canHaveLocals);
                        return declareSymbol(container.locals, 
                        /*parent*/
                        void 0, node, symbolFlags, symbolExcludes);
                    }
                }
            }
            function jsdocTreatAsExported(node) {
                if (node.parent && isModuleDeclaration(node)) {
                    node = node.parent;
                }
                if (!isJSDocTypeAlias(node))
                    return false;
                if (!isJSDocEnumTag(node) && !!node.fullName)
                    return true;
                const declName = getNameOfDeclaration(node);
                if (!declName)
                    return false;
                if (isPropertyAccessEntityNameExpression(declName.parent) && isTopLevelNamespaceAssignment(declName.parent))
                    return true;
                if (isDeclaration(declName.parent) && getCombinedModifierFlags(declName.parent) & 32 /* Export */)
                    return true;
                return false;
            }
            function bindContainer(node, containerFlags) {
                const saveContainer = container;
                const saveThisParentContainer = thisParentContainer;
                const savedBlockScopeContainer = blockScopeContainer;
                if (containerFlags & 1 /* IsContainer */) {
                    if (node.kind !== 219 /* ArrowFunction */) {
                        thisParentContainer = container;
                    }
                    container = blockScopeContainer = node;
                    if (containerFlags & 32 /* HasLocals */) {
                        container.locals = createSymbolTable();
                        addToContainerChain(container);
                    }
                }
                else if (containerFlags & 2 /* IsBlockScopedContainer */) {
                    blockScopeContainer = node;
                    if (containerFlags & 32 /* HasLocals */) {
                        blockScopeContainer.locals = void 0;
                    }
                }
                if (containerFlags & 4 /* IsControlFlowContainer */) {
                    const saveCurrentFlow = currentFlow;
                    const saveBreakTarget = currentBreakTarget;
                    const saveContinueTarget = currentContinueTarget;
                    const saveReturnTarget = currentReturnTarget;
                    const saveExceptionTarget = currentExceptionTarget;
                    const saveActiveLabelList = activeLabelList;
                    const saveHasExplicitReturn = hasExplicitReturn;
                    const isImmediatelyInvoked = containerFlags & 16 /* IsFunctionExpression */ && !hasSyntacticModifier(node, 1024 /* Async */) && !node.asteriskToken && !!getImmediatelyInvokedFunctionExpression(node) || node.kind === 175 /* ClassStaticBlockDeclaration */;
                    if (!isImmediatelyInvoked) {
                        currentFlow = initFlowNode({ flags: 2 /* Start */ });
                        if (containerFlags & (16 /* IsFunctionExpression */ | 128 /* IsObjectLiteralOrClassExpressionMethodOrAccessor */)) {
                            currentFlow.node = node;
                        }
                    }
                    currentReturnTarget = isImmediatelyInvoked || node.kind === 176 /* Constructor */ || isInJSFile(node) && (node.kind === 262 /* FunctionDeclaration */ || node.kind === 218 /* FunctionExpression */) ? createBranchLabel() : void 0;
                    currentExceptionTarget = void 0;
                    currentBreakTarget = void 0;
                    currentContinueTarget = void 0;
                    activeLabelList = void 0;
                    hasExplicitReturn = false;
                    bindChildren(node);
                    node.flags &= ~5632 /* ReachabilityAndEmitFlags */;
                    if (!(currentFlow.flags & 1 /* Unreachable */) && containerFlags & 8 /* IsFunctionLike */ && nodeIsPresent(node.body)) {
                        node.flags |= 512 /* HasImplicitReturn */;
                        if (hasExplicitReturn)
                            node.flags |= 1024 /* HasExplicitReturn */;
                        node.endFlowNode = currentFlow;
                    }
                    if (node.kind === 312 /* SourceFile */) {
                        node.flags |= emitFlags;
                        node.endFlowNode = currentFlow;
                    }
                    if (currentReturnTarget) {
                        addAntecedent(currentReturnTarget, currentFlow);
                        currentFlow = finishFlowLabel(currentReturnTarget);
                        if (node.kind === 176 /* Constructor */ || node.kind === 175 /* ClassStaticBlockDeclaration */ || isInJSFile(node) && (node.kind === 262 /* FunctionDeclaration */ || node.kind === 218 /* FunctionExpression */)) {
                            node.returnFlowNode = currentFlow;
                        }
                    }
                    if (!isImmediatelyInvoked) {
                        currentFlow = saveCurrentFlow;
                    }
                    currentBreakTarget = saveBreakTarget;
                    currentContinueTarget = saveContinueTarget;
                    currentReturnTarget = saveReturnTarget;
                    currentExceptionTarget = saveExceptionTarget;
                    activeLabelList = saveActiveLabelList;
                    hasExplicitReturn = saveHasExplicitReturn;
                }
                else if (containerFlags & 64 /* IsInterface */) {
                    seenThisKeyword = false;
                    bindChildren(node);
                    Debug.assertNotNode(node, isIdentifier);
                    node.flags = seenThisKeyword ? node.flags | 256 /* ContainsThis */ : node.flags & ~256 /* ContainsThis */;
                }
                else {
                    bindChildren(node);
                }
                container = saveContainer;
                thisParentContainer = saveThisParentContainer;
                blockScopeContainer = savedBlockScopeContainer;
            }
            function bindEachFunctionsFirst(nodes) {
                bindEach(nodes, (n) => n.kind === 262 /* FunctionDeclaration */ ? bind(n) : void 0);
                bindEach(nodes, (n) => n.kind !== 262 /* FunctionDeclaration */ ? bind(n) : void 0);
            }
            function bindEach(nodes, bindFunction = bind) {
                if (nodes === void 0) {
                    return;
                }
                forEach(nodes, bindFunction);
            }
            function bindEachChild(node) {
                forEachChild(node, bind, bindEach);
            }
            function bindChildren(node) {
                const saveInAssignmentPattern = inAssignmentPattern;
                inAssignmentPattern = false;
                if (checkUnreachable(node)) {
                    bindEachChild(node);
                    bindJSDoc(node);
                    inAssignmentPattern = saveInAssignmentPattern;
                    return;
                }
                if (node.kind >= 243 /* FirstStatement */ && node.kind <= 259 /* LastStatement */ && !options.allowUnreachableCode) {
                    node.flowNode = currentFlow;
                }
                switch (node.kind) {
                    case 247 /* WhileStatement */:
                        bindWhileStatement(node);
                        break;
                    case 246 /* DoStatement */:
                        bindDoStatement(node);
                        break;
                    case 248 /* ForStatement */:
                        bindForStatement(node);
                        break;
                    case 249 /* ForInStatement */:
                    case 250 /* ForOfStatement */:
                        bindForInOrForOfStatement(node);
                        break;
                    case 245 /* IfStatement */:
                        bindIfStatement(node);
                        break;
                    case 253 /* ReturnStatement */:
                    case 257 /* ThrowStatement */:
                        bindReturnOrThrow(node);
                        break;
                    case 252 /* BreakStatement */:
                    case 251 /* ContinueStatement */:
                        bindBreakOrContinueStatement(node);
                        break;
                    case 258 /* TryStatement */:
                        bindTryStatement(node);
                        break;
                    case 255 /* SwitchStatement */:
                        bindSwitchStatement(node);
                        break;
                    case 269 /* CaseBlock */:
                        bindCaseBlock(node);
                        break;
                    case 296 /* CaseClause */:
                        bindCaseClause(node);
                        break;
                    case 244 /* ExpressionStatement */:
                        bindExpressionStatement(node);
                        break;
                    case 256 /* LabeledStatement */:
                        bindLabeledStatement(node);
                        break;
                    case 224 /* PrefixUnaryExpression */:
                        bindPrefixUnaryExpressionFlow(node);
                        break;
                    case 225 /* PostfixUnaryExpression */:
                        bindPostfixUnaryExpressionFlow(node);
                        break;
                    case 226 /* BinaryExpression */:
                        if (isDestructuringAssignment(node)) {
                            inAssignmentPattern = saveInAssignmentPattern;
                            bindDestructuringAssignmentFlow(node);
                            return;
                        }
                        bindBinaryExpressionFlow(node);
                        break;
                    case 220 /* DeleteExpression */:
                        bindDeleteExpressionFlow(node);
                        break;
                    case 227 /* ConditionalExpression */:
                        bindConditionalExpressionFlow(node);
                        break;
                    case 260 /* VariableDeclaration */:
                        bindVariableDeclarationFlow(node);
                        break;
                    case 211 /* PropertyAccessExpression */:
                    case 212 /* ElementAccessExpression */:
                        bindAccessExpressionFlow(node);
                        break;
                    case 213 /* CallExpression */:
                        bindCallExpressionFlow(node);
                        break;
                    case 235 /* NonNullExpression */:
                        bindNonNullExpressionFlow(node);
                        break;
                    case 353 /* JSDocTypedefTag */:
                    case 345 /* JSDocCallbackTag */:
                    case 347 /* JSDocEnumTag */:
                        bindJSDocTypeAlias(node);
                        break;
                    case 312 /* SourceFile */: {
                        bindEachFunctionsFirst(node.statements);
                        bind(node.endOfFileToken);
                        break;
                    }
                    case 241 /* Block */:
                    case 268 /* ModuleBlock */:
                        bindEachFunctionsFirst(node.statements);
                        break;
                    case 208 /* BindingElement */:
                        bindBindingElementFlow(node);
                        break;
                    case 169 /* Parameter */:
                        bindParameterFlow(node);
                        break;
                    case 210 /* ObjectLiteralExpression */:
                    case 209 /* ArrayLiteralExpression */:
                    case 303 /* PropertyAssignment */:
                    case 230 /* SpreadElement */:
                        inAssignmentPattern = saveInAssignmentPattern;
                    default:
                        bindEachChild(node);
                        break;
                }
                bindJSDoc(node);
                inAssignmentPattern = saveInAssignmentPattern;
            }
            function isNarrowingExpression(expr) {
                switch (expr.kind) {
                    case 80 /* Identifier */:
                    case 81 /* PrivateIdentifier */:
                    case 110 /* ThisKeyword */:
                    case 211 /* PropertyAccessExpression */:
                    case 212 /* ElementAccessExpression */:
                        return containsNarrowableReference(expr);
                    case 213 /* CallExpression */:
                        return hasNarrowableArgument(expr);
                    case 217 /* ParenthesizedExpression */:
                        if (isJSDocTypeAssertion(expr)) {
                            return false;
                        }
                    case 235 /* NonNullExpression */:
                        return isNarrowingExpression(expr.expression);
                    case 226 /* BinaryExpression */:
                        return isNarrowingBinaryExpression(expr);
                    case 224 /* PrefixUnaryExpression */:
                        return expr.operator === 54 /* ExclamationToken */ && isNarrowingExpression(expr.operand);
                    case 221 /* TypeOfExpression */:
                        return isNarrowingExpression(expr.expression);
                }
                return false;
            }
            function isNarrowableReference(expr) {
                return isDottedName(expr) || (isPropertyAccessExpression(expr) || isNonNullExpression(expr) || isParenthesizedExpression(expr)) && isNarrowableReference(expr.expression) || isBinaryExpression(expr) && expr.operatorToken.kind === 28 /* CommaToken */ && isNarrowableReference(expr.right) || isElementAccessExpression(expr) && (isStringOrNumericLiteralLike(expr.argumentExpression) || isEntityNameExpression(expr.argumentExpression)) && isNarrowableReference(expr.expression) || isAssignmentExpression(expr) && isNarrowableReference(expr.left);
            }
            function containsNarrowableReference(expr) {
                return isNarrowableReference(expr) || isOptionalChain(expr) && containsNarrowableReference(expr.expression);
            }
            function hasNarrowableArgument(expr) {
                if (expr.arguments) {
                    for (const argument of expr.arguments) {
                        if (containsNarrowableReference(argument)) {
                            return true;
                        }
                    }
                }
                if (expr.expression.kind === 211 /* PropertyAccessExpression */ && containsNarrowableReference(expr.expression.expression)) {
                    return true;
                }
                return false;
            }
            function isNarrowingTypeofOperands(expr1, expr2) {
                return isTypeOfExpression(expr1) && isNarrowableOperand(expr1.expression) && isStringLiteralLike(expr2);
            }
            function isNarrowingBinaryExpression(expr) {
                switch (expr.operatorToken.kind) {
                    case 64 /* EqualsToken */:
                    case 76 /* BarBarEqualsToken */:
                    case 77 /* AmpersandAmpersandEqualsToken */:
                    case 78 /* QuestionQuestionEqualsToken */:
                        return containsNarrowableReference(expr.left);
                    case 35 /* EqualsEqualsToken */:
                    case 36 /* ExclamationEqualsToken */:
                    case 37 /* EqualsEqualsEqualsToken */:
                    case 38 /* ExclamationEqualsEqualsToken */:
                        return isNarrowableOperand(expr.left) || isNarrowableOperand(expr.right) || isNarrowingTypeofOperands(expr.right, expr.left) || isNarrowingTypeofOperands(expr.left, expr.right) || (isBooleanLiteral(expr.right) && isNarrowingExpression(expr.left) || isBooleanLiteral(expr.left) && isNarrowingExpression(expr.right));
                    case 104 /* InstanceOfKeyword */:
                        return isNarrowableOperand(expr.left);
                    case 103 /* InKeyword */:
                        return isNarrowingExpression(expr.right);
                    case 28 /* CommaToken */:
                        return isNarrowingExpression(expr.right);
                }
                return false;
            }
            function isNarrowableOperand(expr) {
                switch (expr.kind) {
                    case 217 /* ParenthesizedExpression */:
                        return isNarrowableOperand(expr.expression);
                    case 226 /* BinaryExpression */:
                        switch (expr.operatorToken.kind) {
                            case 64 /* EqualsToken */:
                                return isNarrowableOperand(expr.left);
                            case 28 /* CommaToken */:
                                return isNarrowableOperand(expr.right);
                        }
                }
                return containsNarrowableReference(expr);
            }
            function createBranchLabel() {
                return initFlowNode({ flags: 4 /* BranchLabel */, antecedents: void 0 });
            }
            function createLoopLabel() {
                return initFlowNode({ flags: 8 /* LoopLabel */, antecedents: void 0 });
            }
            function createReduceLabel(target, antecedents, antecedent) {
                return initFlowNode({ flags: 1024 /* ReduceLabel */, target, antecedents, antecedent });
            }
            function setFlowNodeReferenced(flow) {
                flow.flags |= flow.flags & 2048 /* Referenced */ ? 4096 /* Shared */ : 2048 /* Referenced */;
            }
            function addAntecedent(label, antecedent) {
                if (!(antecedent.flags & 1 /* Unreachable */) && !contains(label.antecedents, antecedent)) {
                    (label.antecedents || (label.antecedents = [])).push(antecedent);
                    setFlowNodeReferenced(antecedent);
                }
            }
            function createFlowCondition(flags, antecedent, expression) {
                if (antecedent.flags & 1 /* Unreachable */) {
                    return antecedent;
                }
                if (!expression) {
                    return flags & 32 /* TrueCondition */ ? antecedent : unreachableFlow;
                }
                if ((expression.kind === 112 /* TrueKeyword */ && flags & 64 /* FalseCondition */ || expression.kind === 97 /* FalseKeyword */ && flags & 32 /* TrueCondition */) && !isExpressionOfOptionalChainRoot(expression) && !isNullishCoalesce(expression.parent)) {
                    return unreachableFlow;
                }
                if (!isNarrowingExpression(expression)) {
                    return antecedent;
                }
                setFlowNodeReferenced(antecedent);
                return initFlowNode({ flags, antecedent, node: expression });
            }
            function createFlowSwitchClause(antecedent, switchStatement, clauseStart, clauseEnd) {
                setFlowNodeReferenced(antecedent);
                return initFlowNode({ flags: 128 /* SwitchClause */, antecedent, switchStatement, clauseStart, clauseEnd });
            }
            function createFlowMutation(flags, antecedent, node) {
                setFlowNodeReferenced(antecedent);
                const result = initFlowNode({ flags, antecedent, node });
                if (currentExceptionTarget) {
                    addAntecedent(currentExceptionTarget, result);
                }
                return result;
            }
            function createFlowCall(antecedent, node) {
                setFlowNodeReferenced(antecedent);
                return initFlowNode({ flags: 512 /* Call */, antecedent, node });
            }
            function finishFlowLabel(flow) {
                const antecedents = flow.antecedents;
                if (!antecedents) {
                    return unreachableFlow;
                }
                if (antecedents.length === 1) {
                    return antecedents[0];
                }
                return flow;
            }
            function isStatementCondition(node) {
                const parent3 = node.parent;
                switch (parent3.kind) {
                    case 245 /* IfStatement */:
                    case 247 /* WhileStatement */:
                    case 246 /* DoStatement */:
                        return parent3.expression === node;
                    case 248 /* ForStatement */:
                    case 227 /* ConditionalExpression */:
                        return parent3.condition === node;
                }
                return false;
            }
            function isLogicalExpression(node) {
                while (true) {
                    if (node.kind === 217 /* ParenthesizedExpression */) {
                        node = node.expression;
                    }
                    else if (node.kind === 224 /* PrefixUnaryExpression */ && node.operator === 54 /* ExclamationToken */) {
                        node = node.operand;
                    }
                    else {
                        return isLogicalOrCoalescingBinaryExpression(node);
                    }
                }
            }
            function isLogicalAssignmentExpression(node) {
                return isLogicalOrCoalescingAssignmentExpression(skipParentheses(node));
            }
            function isTopLevelLogicalExpression(node) {
                while (isParenthesizedExpression(node.parent) || isPrefixUnaryExpression(node.parent) && node.parent.operator === 54 /* ExclamationToken */) {
                    node = node.parent;
                }
                return !isStatementCondition(node) && !isLogicalExpression(node.parent) && !(isOptionalChain(node.parent) && node.parent.expression === node);
            }
            function doWithConditionalBranches(action, value, trueTarget, falseTarget) {
                const savedTrueTarget = currentTrueTarget;
                const savedFalseTarget = currentFalseTarget;
                currentTrueTarget = trueTarget;
                currentFalseTarget = falseTarget;
                action(value);
                currentTrueTarget = savedTrueTarget;
                currentFalseTarget = savedFalseTarget;
            }
            function bindCondition(node, trueTarget, falseTarget) {
                doWithConditionalBranches(bind, node, trueTarget, falseTarget);
                if (!node || !isLogicalAssignmentExpression(node) && !isLogicalExpression(node) && !(isOptionalChain(node) && isOutermostOptionalChain(node))) {
                    addAntecedent(trueTarget, createFlowCondition(32 /* TrueCondition */, currentFlow, node));
                    addAntecedent(falseTarget, createFlowCondition(64 /* FalseCondition */, currentFlow, node));
                }
            }
            function bindIterativeStatement(node, breakTarget, continueTarget) {
                const saveBreakTarget = currentBreakTarget;
                const saveContinueTarget = currentContinueTarget;
                currentBreakTarget = breakTarget;
                currentContinueTarget = continueTarget;
                bind(node);
                currentBreakTarget = saveBreakTarget;
                currentContinueTarget = saveContinueTarget;
            }
            function setContinueTarget(node, target) {
                let label = activeLabelList;
                while (label && node.parent.kind === 256 /* LabeledStatement */) {
                    label.continueTarget = target;
                    label = label.next;
                    node = node.parent;
                }
                return target;
            }
            function bindWhileStatement(node) {
                const preWhileLabel = setContinueTarget(node, createLoopLabel());
                const preBodyLabel = createBranchLabel();
                const postWhileLabel = createBranchLabel();
                addAntecedent(preWhileLabel, currentFlow);
                currentFlow = preWhileLabel;
                bindCondition(node.expression, preBodyLabel, postWhileLabel);
                currentFlow = finishFlowLabel(preBodyLabel);
                bindIterativeStatement(node.statement, postWhileLabel, preWhileLabel);
                addAntecedent(preWhileLabel, currentFlow);
                currentFlow = finishFlowLabel(postWhileLabel);
            }
            function bindDoStatement(node) {
                const preDoLabel = createLoopLabel();
                const preConditionLabel = setContinueTarget(node, createBranchLabel());
                const postDoLabel = createBranchLabel();
                addAntecedent(preDoLabel, currentFlow);
                currentFlow = preDoLabel;
                bindIterativeStatement(node.statement, postDoLabel, preConditionLabel);
                addAntecedent(preConditionLabel, currentFlow);
                currentFlow = finishFlowLabel(preConditionLabel);
                bindCondition(node.expression, preDoLabel, postDoLabel);
                currentFlow = finishFlowLabel(postDoLabel);
            }
            function bindForStatement(node) {
                const preLoopLabel = setContinueTarget(node, createLoopLabel());
                const preBodyLabel = createBranchLabel();
                const postLoopLabel = createBranchLabel();
                bind(node.initializer);
                addAntecedent(preLoopLabel, currentFlow);
                currentFlow = preLoopLabel;
                bindCondition(node.condition, preBodyLabel, postLoopLabel);
                currentFlow = finishFlowLabel(preBodyLabel);
                bindIterativeStatement(node.statement, postLoopLabel, preLoopLabel);
                bind(node.incrementor);
                addAntecedent(preLoopLabel, currentFlow);
                currentFlow = finishFlowLabel(postLoopLabel);
            }
            function bindForInOrForOfStatement(node) {
                const preLoopLabel = setContinueTarget(node, createLoopLabel());
                const postLoopLabel = createBranchLabel();
                bind(node.expression);
                addAntecedent(preLoopLabel, currentFlow);
                currentFlow = preLoopLabel;
                if (node.kind === 250 /* ForOfStatement */) {
                    bind(node.awaitModifier);
                }
                addAntecedent(postLoopLabel, currentFlow);
                bind(node.initializer);
                if (node.initializer.kind !== 261 /* VariableDeclarationList */) {
                    bindAssignmentTargetFlow(node.initializer);
                }
                bindIterativeStatement(node.statement, postLoopLabel, preLoopLabel);
                addAntecedent(preLoopLabel, currentFlow);
                currentFlow = finishFlowLabel(postLoopLabel);
            }
            function bindIfStatement(node) {
                const thenLabel = createBranchLabel();
                const elseLabel = createBranchLabel();
                const postIfLabel = createBranchLabel();
                bindCondition(node.expression, thenLabel, elseLabel);
                currentFlow = finishFlowLabel(thenLabel);
                bind(node.thenStatement);
                addAntecedent(postIfLabel, currentFlow);
                currentFlow = finishFlowLabel(elseLabel);
                bind(node.elseStatement);
                addAntecedent(postIfLabel, currentFlow);
                currentFlow = finishFlowLabel(postIfLabel);
            }
            function bindReturnOrThrow(node) {
                bind(node.expression);
                if (node.kind === 253 /* ReturnStatement */) {
                    hasExplicitReturn = true;
                    if (currentReturnTarget) {
                        addAntecedent(currentReturnTarget, currentFlow);
                    }
                }
                currentFlow = unreachableFlow;
            }
            function findActiveLabel(name) {
                for (let label = activeLabelList; label; label = label.next) {
                    if (label.name === name) {
                        return label;
                    }
                }
                return void 0;
            }
            function bindBreakOrContinueFlow(node, breakTarget, continueTarget) {
                const flowLabel = node.kind === 252 /* BreakStatement */ ? breakTarget : continueTarget;
                if (flowLabel) {
                    addAntecedent(flowLabel, currentFlow);
                    currentFlow = unreachableFlow;
                }
            }
            function bindBreakOrContinueStatement(node) {
                bind(node.label);
                if (node.label) {
                    const activeLabel = findActiveLabel(node.label.escapedText);
                    if (activeLabel) {
                        activeLabel.referenced = true;
                        bindBreakOrContinueFlow(node, activeLabel.breakTarget, activeLabel.continueTarget);
                    }
                }
                else {
                    bindBreakOrContinueFlow(node, currentBreakTarget, currentContinueTarget);
                }
            }
            function bindTryStatement(node) {
                const saveReturnTarget = currentReturnTarget;
                const saveExceptionTarget = currentExceptionTarget;
                const normalExitLabel = createBranchLabel();
                const returnLabel = createBranchLabel();
                let exceptionLabel = createBranchLabel();
                if (node.finallyBlock) {
                    currentReturnTarget = returnLabel;
                }
                addAntecedent(exceptionLabel, currentFlow);
                currentExceptionTarget = exceptionLabel;
                bind(node.tryBlock);
                addAntecedent(normalExitLabel, currentFlow);
                if (node.catchClause) {
                    currentFlow = finishFlowLabel(exceptionLabel);
                    exceptionLabel = createBranchLabel();
                    addAntecedent(exceptionLabel, currentFlow);
                    currentExceptionTarget = exceptionLabel;
                    bind(node.catchClause);
                    addAntecedent(normalExitLabel, currentFlow);
                }
                currentReturnTarget = saveReturnTarget;
                currentExceptionTarget = saveExceptionTarget;
                if (node.finallyBlock) {
                    const finallyLabel = createBranchLabel();
                    finallyLabel.antecedents = concatenate(concatenate(normalExitLabel.antecedents, exceptionLabel.antecedents), returnLabel.antecedents);
                    currentFlow = finallyLabel;
                    bind(node.finallyBlock);
                    if (currentFlow.flags & 1 /* Unreachable */) {
                        currentFlow = unreachableFlow;
                    }
                    else {
                        if (currentReturnTarget && returnLabel.antecedents) {
                            addAntecedent(currentReturnTarget, createReduceLabel(finallyLabel, returnLabel.antecedents, currentFlow));
                        }
                        if (currentExceptionTarget && exceptionLabel.antecedents) {
                            addAntecedent(currentExceptionTarget, createReduceLabel(finallyLabel, exceptionLabel.antecedents, currentFlow));
                        }
                        currentFlow = normalExitLabel.antecedents ? createReduceLabel(finallyLabel, normalExitLabel.antecedents, currentFlow) : unreachableFlow;
                    }
                }
                else {
                    currentFlow = finishFlowLabel(normalExitLabel);
                }
            }
            function bindSwitchStatement(node) {
                const postSwitchLabel = createBranchLabel();
                bind(node.expression);
                const saveBreakTarget = currentBreakTarget;
                const savePreSwitchCaseFlow = preSwitchCaseFlow;
                currentBreakTarget = postSwitchLabel;
                preSwitchCaseFlow = currentFlow;
                bind(node.caseBlock);
                addAntecedent(postSwitchLabel, currentFlow);
                const hasDefault = forEach(node.caseBlock.clauses, (c) => c.kind === 297 /* DefaultClause */);
                node.possiblyExhaustive = !hasDefault && !postSwitchLabel.antecedents;
                if (!hasDefault) {
                    addAntecedent(postSwitchLabel, createFlowSwitchClause(preSwitchCaseFlow, node, 0, 0));
                }
                currentBreakTarget = saveBreakTarget;
                preSwitchCaseFlow = savePreSwitchCaseFlow;
                currentFlow = finishFlowLabel(postSwitchLabel);
            }
            function bindCaseBlock(node) {
                const clauses = node.clauses;
                const isNarrowingSwitch = node.parent.expression.kind === 112 /* TrueKeyword */ || isNarrowingExpression(node.parent.expression);
                let fallthroughFlow = unreachableFlow;
                for (let i = 0; i < clauses.length; i++) {
                    const clauseStart = i;
                    while (!clauses[i].statements.length && i + 1 < clauses.length) {
                        if (fallthroughFlow === unreachableFlow) {
                            currentFlow = preSwitchCaseFlow;
                        }
                        bind(clauses[i]);
                        i++;
                    }
                    const preCaseLabel = createBranchLabel();
                    addAntecedent(preCaseLabel, isNarrowingSwitch ? createFlowSwitchClause(preSwitchCaseFlow, node.parent, clauseStart, i + 1) : preSwitchCaseFlow);
                    addAntecedent(preCaseLabel, fallthroughFlow);
                    currentFlow = finishFlowLabel(preCaseLabel);
                    const clause = clauses[i];
                    bind(clause);
                    fallthroughFlow = currentFlow;
                    if (!(currentFlow.flags & 1 /* Unreachable */) && i !== clauses.length - 1 && options.noFallthroughCasesInSwitch) {
                        clause.fallthroughFlowNode = currentFlow;
                    }
                }
            }
            function bindCaseClause(node) {
                const saveCurrentFlow = currentFlow;
                currentFlow = preSwitchCaseFlow;
                bind(node.expression);
                currentFlow = saveCurrentFlow;
                bindEach(node.statements);
            }
            function bindExpressionStatement(node) {
                bind(node.expression);
                maybeBindExpressionFlowIfCall(node.expression);
            }
            function maybeBindExpressionFlowIfCall(node) {
                if (node.kind === 213 /* CallExpression */) {
                    const call = node;
                    if (call.expression.kind !== 108 /* SuperKeyword */ && isDottedName(call.expression)) {
                        currentFlow = createFlowCall(currentFlow, call);
                    }
                }
            }
            function bindLabeledStatement(node) {
                const postStatementLabel = createBranchLabel();
                activeLabelList = {
                    next: activeLabelList,
                    name: node.label.escapedText,
                    breakTarget: postStatementLabel,
                    continueTarget: void 0,
                    referenced: false
                };
                bind(node.label);
                bind(node.statement);
                if (!activeLabelList.referenced && !options.allowUnusedLabels) {
                    errorOrSuggestionOnNode(unusedLabelIsError(options), node.label, Diagnostics.Unused_label);
                }
                activeLabelList = activeLabelList.next;
                addAntecedent(postStatementLabel, currentFlow);
                currentFlow = finishFlowLabel(postStatementLabel);
            }
            function bindDestructuringTargetFlow(node) {
                if (node.kind === 226 /* BinaryExpression */ && node.operatorToken.kind === 64 /* EqualsToken */) {
                    bindAssignmentTargetFlow(node.left);
                }
                else {
                    bindAssignmentTargetFlow(node);
                }
            }
            function bindAssignmentTargetFlow(node) {
                if (isNarrowableReference(node)) {
                    currentFlow = createFlowMutation(16 /* Assignment */, currentFlow, node);
                }
                else if (node.kind === 209 /* ArrayLiteralExpression */) {
                    for (const e of node.elements) {
                        if (e.kind === 230 /* SpreadElement */) {
                            bindAssignmentTargetFlow(e.expression);
                        }
                        else {
                            bindDestructuringTargetFlow(e);
                        }
                    }
                }
                else if (node.kind === 210 /* ObjectLiteralExpression */) {
                    for (const p of node.properties) {
                        if (p.kind === 303 /* PropertyAssignment */) {
                            bindDestructuringTargetFlow(p.initializer);
                        }
                        else if (p.kind === 304 /* ShorthandPropertyAssignment */) {
                            bindAssignmentTargetFlow(p.name);
                        }
                        else if (p.kind === 305 /* SpreadAssignment */) {
                            bindAssignmentTargetFlow(p.expression);
                        }
                    }
                }
            }
            function bindLogicalLikeExpression(node, trueTarget, falseTarget) {
                const preRightLabel = createBranchLabel();
                if (node.operatorToken.kind === 56 /* AmpersandAmpersandToken */ || node.operatorToken.kind === 77 /* AmpersandAmpersandEqualsToken */) {
                    bindCondition(node.left, preRightLabel, falseTarget);
                }
                else {
                    bindCondition(node.left, trueTarget, preRightLabel);
                }
                currentFlow = finishFlowLabel(preRightLabel);
                bind(node.operatorToken);
                if (isLogicalOrCoalescingAssignmentOperator(node.operatorToken.kind)) {
                    doWithConditionalBranches(bind, node.right, trueTarget, falseTarget);
                    bindAssignmentTargetFlow(node.left);
                    addAntecedent(trueTarget, createFlowCondition(32 /* TrueCondition */, currentFlow, node));
                    addAntecedent(falseTarget, createFlowCondition(64 /* FalseCondition */, currentFlow, node));
                }
                else {
                    bindCondition(node.right, trueTarget, falseTarget);
                }
            }
            function bindPrefixUnaryExpressionFlow(node) {
                if (node.operator === 54 /* ExclamationToken */) {
                    const saveTrueTarget = currentTrueTarget;
                    currentTrueTarget = currentFalseTarget;
                    currentFalseTarget = saveTrueTarget;
                    bindEachChild(node);
                    currentFalseTarget = currentTrueTarget;
                    currentTrueTarget = saveTrueTarget;
                }
                else {
                    bindEachChild(node);
                    if (node.operator === 46 /* PlusPlusToken */ || node.operator === 47 /* MinusMinusToken */) {
                        bindAssignmentTargetFlow(node.operand);
                    }
                }
            }
            function bindPostfixUnaryExpressionFlow(node) {
                bindEachChild(node);
                if (node.operator === 46 /* PlusPlusToken */ || node.operator === 47 /* MinusMinusToken */) {
                    bindAssignmentTargetFlow(node.operand);
                }
            }
            function bindDestructuringAssignmentFlow(node) {
                if (inAssignmentPattern) {
                    inAssignmentPattern = false;
                    bind(node.operatorToken);
                    bind(node.right);
                    inAssignmentPattern = true;
                    bind(node.left);
                }
                else {
                    inAssignmentPattern = true;
                    bind(node.left);
                    inAssignmentPattern = false;
                    bind(node.operatorToken);
                    bind(node.right);
                }
                bindAssignmentTargetFlow(node.left);
            }
            function createBindBinaryExpressionFlow() {
                return createBinaryExpressionTrampoline(onEnter, onLeft, onOperator, onRight, onExit, 
                /*foldState*/
                void 0);
                function onEnter(node, state) {
                    if (state) {
                        state.stackIndex++;
                        setParent(node, parent2);
                        const saveInStrictMode = inStrictMode;
                        bindWorker(node);
                        const saveParent = parent2;
                        parent2 = node;
                        state.skip = false;
                        state.inStrictModeStack[state.stackIndex] = saveInStrictMode;
                        state.parentStack[state.stackIndex] = saveParent;
                    }
                    else {
                        state = {
                            stackIndex: 0,
                            skip: false,
                            inStrictModeStack: [void 0],
                            parentStack: [void 0]
                        };
                    }
                    const operator = node.operatorToken.kind;
                    if (isLogicalOrCoalescingBinaryOperator(operator) || isLogicalOrCoalescingAssignmentOperator(operator)) {
                        if (isTopLevelLogicalExpression(node)) {
                            const postExpressionLabel = createBranchLabel();
                            bindLogicalLikeExpression(node, postExpressionLabel, postExpressionLabel);
                            currentFlow = finishFlowLabel(postExpressionLabel);
                        }
                        else {
                            bindLogicalLikeExpression(node, currentTrueTarget, currentFalseTarget);
                        }
                        state.skip = true;
                    }
                    return state;
                }
                function onLeft(left, state, node) {
                    if (!state.skip) {
                        const maybeBound = maybeBind2(left);
                        if (node.operatorToken.kind === 28 /* CommaToken */) {
                            maybeBindExpressionFlowIfCall(left);
                        }
                        return maybeBound;
                    }
                }
                function onOperator(operatorToken, state, _node) {
                    if (!state.skip) {
                        bind(operatorToken);
                    }
                }
                function onRight(right, state, node) {
                    if (!state.skip) {
                        const maybeBound = maybeBind2(right);
                        if (node.operatorToken.kind === 28 /* CommaToken */) {
                            maybeBindExpressionFlowIfCall(right);
                        }
                        return maybeBound;
                    }
                }
                function onExit(node, state) {
                    if (!state.skip) {
                        const operator = node.operatorToken.kind;
                        if (isAssignmentOperator(operator) && !isAssignmentTarget(node)) {
                            bindAssignmentTargetFlow(node.left);
                            if (operator === 64 /* EqualsToken */ && node.left.kind === 212 /* ElementAccessExpression */) {
                                const elementAccess = node.left;
                                if (isNarrowableOperand(elementAccess.expression)) {
                                    currentFlow = createFlowMutation(256 /* ArrayMutation */, currentFlow, node);
                                }
                            }
                        }
                    }
                    const savedInStrictMode = state.inStrictModeStack[state.stackIndex];
                    const savedParent = state.parentStack[state.stackIndex];
                    if (savedInStrictMode !== void 0) {
                        inStrictMode = savedInStrictMode;
                    }
                    if (savedParent !== void 0) {
                        parent2 = savedParent;
                    }
                    state.skip = false;
                    state.stackIndex--;
                }
                function maybeBind2(node) {
                    if (node && isBinaryExpression(node) && !isDestructuringAssignment(node)) {
                        return node;
                    }
                    bind(node);
                }
            }
            function bindDeleteExpressionFlow(node) {
                bindEachChild(node);
                if (node.expression.kind === 211 /* PropertyAccessExpression */) {
                    bindAssignmentTargetFlow(node.expression);
                }
            }
            function bindConditionalExpressionFlow(node) {
                const trueLabel = createBranchLabel();
                const falseLabel = createBranchLabel();
                const postExpressionLabel = createBranchLabel();
                bindCondition(node.condition, trueLabel, falseLabel);
                currentFlow = finishFlowLabel(trueLabel);
                bind(node.questionToken);
                bind(node.whenTrue);
                addAntecedent(postExpressionLabel, currentFlow);
                currentFlow = finishFlowLabel(falseLabel);
                bind(node.colonToken);
                bind(node.whenFalse);
                addAntecedent(postExpressionLabel, currentFlow);
                currentFlow = finishFlowLabel(postExpressionLabel);
            }
            function bindInitializedVariableFlow(node) {
                const name = !isOmittedExpression(node) ? node.name : void 0;
                if (isBindingPattern(name)) {
                    for (const child of name.elements) {
                        bindInitializedVariableFlow(child);
                    }
                }
                else {
                    currentFlow = createFlowMutation(16 /* Assignment */, currentFlow, node);
                }
            }
            function bindVariableDeclarationFlow(node) {
                bindEachChild(node);
                if (node.initializer || isForInOrOfStatement(node.parent.parent)) {
                    bindInitializedVariableFlow(node);
                }
            }
            function bindBindingElementFlow(node) {
                bind(node.dotDotDotToken);
                bind(node.propertyName);
                bindInitializer(node.initializer);
                bind(node.name);
            }
            function bindParameterFlow(node) {
                bindEach(node.modifiers);
                bind(node.dotDotDotToken);
                bind(node.questionToken);
                bind(node.type);
                bindInitializer(node.initializer);
                bind(node.name);
            }
            function bindInitializer(node) {
                if (!node) {
                    return;
                }
                const entryFlow = currentFlow;
                bind(node);
                if (entryFlow === unreachableFlow || entryFlow === currentFlow) {
                    return;
                }
                const exitFlow = createBranchLabel();
                addAntecedent(exitFlow, entryFlow);
                addAntecedent(exitFlow, currentFlow);
                currentFlow = finishFlowLabel(exitFlow);
            }
            function bindJSDocTypeAlias(node) {
                bind(node.tagName);
                if (node.kind !== 347 /* JSDocEnumTag */ && node.fullName) {
                    setParent(node.fullName, node);
                    setParentRecursive(node.fullName, 
                    /*incremental*/
                    false);
                }
                if (typeof node.comment !== "string") {
                    bindEach(node.comment);
                }
            }
            function bindJSDocClassTag(node) {
                bindEachChild(node);
                const host = getHostSignatureFromJSDoc(node);
                if (host && host.kind !== 174 /* MethodDeclaration */) {
                    addDeclarationToSymbol(host.symbol, host, 32 /* Class */);
                }
            }
            function bindOptionalExpression(node, trueTarget, falseTarget) {
                doWithConditionalBranches(bind, node, trueTarget, falseTarget);
                if (!isOptionalChain(node) || isOutermostOptionalChain(node)) {
                    addAntecedent(trueTarget, createFlowCondition(32 /* TrueCondition */, currentFlow, node));
                    addAntecedent(falseTarget, createFlowCondition(64 /* FalseCondition */, currentFlow, node));
                }
            }
            function bindOptionalChainRest(node) {
                switch (node.kind) {
                    case 211 /* PropertyAccessExpression */:
                        bind(node.questionDotToken);
                        bind(node.name);
                        break;
                    case 212 /* ElementAccessExpression */:
                        bind(node.questionDotToken);
                        bind(node.argumentExpression);
                        break;
                    case 213 /* CallExpression */:
                        bind(node.questionDotToken);
                        bindEach(node.typeArguments);
                        bindEach(node.arguments);
                        break;
                }
            }
            function bindOptionalChain(node, trueTarget, falseTarget) {
                const preChainLabel = isOptionalChainRoot(node) ? createBranchLabel() : void 0;
                bindOptionalExpression(node.expression, preChainLabel || trueTarget, falseTarget);
                if (preChainLabel) {
                    currentFlow = finishFlowLabel(preChainLabel);
                }
                doWithConditionalBranches(bindOptionalChainRest, node, trueTarget, falseTarget);
                if (isOutermostOptionalChain(node)) {
                    addAntecedent(trueTarget, createFlowCondition(32 /* TrueCondition */, currentFlow, node));
                    addAntecedent(falseTarget, createFlowCondition(64 /* FalseCondition */, currentFlow, node));
                }
            }
            function bindOptionalChainFlow(node) {
                if (isTopLevelLogicalExpression(node)) {
                    const postExpressionLabel = createBranchLabel();
                    bindOptionalChain(node, postExpressionLabel, postExpressionLabel);
                    currentFlow = finishFlowLabel(postExpressionLabel);
                }
                else {
                    bindOptionalChain(node, currentTrueTarget, currentFalseTarget);
                }
            }
            function bindNonNullExpressionFlow(node) {
                if (isOptionalChain(node)) {
                    bindOptionalChainFlow(node);
                }
                else {
                    bindEachChild(node);
                }
            }
            function bindAccessExpressionFlow(node) {
                if (isOptionalChain(node)) {
                    bindOptionalChainFlow(node);
                }
                else {
                    bindEachChild(node);
                }
            }
            function bindCallExpressionFlow(node) {
                if (isOptionalChain(node)) {
                    bindOptionalChainFlow(node);
                }
                else {
                    const expr = skipParentheses(node.expression);
                    if (expr.kind === 218 /* FunctionExpression */ || expr.kind === 219 /* ArrowFunction */) {
                        bindEach(node.typeArguments);
                        bindEach(node.arguments);
                        bind(node.expression);
                    }
                    else {
                        bindEachChild(node);
                        if (node.expression.kind === 108 /* SuperKeyword */) {
                            currentFlow = createFlowCall(currentFlow, node);
                        }
                    }
                }
                if (node.expression.kind === 211 /* PropertyAccessExpression */) {
                    const propertyAccess = node.expression;
                    if (isIdentifier(propertyAccess.name) && isNarrowableOperand(propertyAccess.expression) && isPushOrUnshiftIdentifier(propertyAccess.name)) {
                        currentFlow = createFlowMutation(256 /* ArrayMutation */, currentFlow, node);
                    }
                }
            }
            function addToContainerChain(next) {
                if (lastContainer) {
                    lastContainer.nextContainer = next;
                }
                lastContainer = next;
            }
            function declareSymbolAndAddToSymbolTable(node, symbolFlags, symbolExcludes) {
                switch (container.kind) {
                    case 267 /* ModuleDeclaration */:
                        return declareModuleMember(node, symbolFlags, symbolExcludes);
                    case 312 /* SourceFile */:
                        return declareSourceFileMember(node, symbolFlags, symbolExcludes);
                    case 231 /* ClassExpression */:
                    case 263 /* ClassDeclaration */:
                        return declareClassMember(node, symbolFlags, symbolExcludes);
                    case 266 /* EnumDeclaration */:
                        return declareSymbol(container.symbol.exports, container.symbol, node, symbolFlags, symbolExcludes);
                    case 187 /* TypeLiteral */:
                    case 329 /* JSDocTypeLiteral */:
                    case 210 /* ObjectLiteralExpression */:
                    case 264 /* InterfaceDeclaration */:
                    case 292 /* JsxAttributes */:
                        return declareSymbol(container.symbol.members, container.symbol, node, symbolFlags, symbolExcludes);
                    case 184 /* FunctionType */:
                    case 185 /* ConstructorType */:
                    case 179 /* CallSignature */:
                    case 180 /* ConstructSignature */:
                    case 330 /* JSDocSignature */:
                    case 181 /* IndexSignature */:
                    case 174 /* MethodDeclaration */:
                    case 173 /* MethodSignature */:
                    case 176 /* Constructor */:
                    case 177 /* GetAccessor */:
                    case 178 /* SetAccessor */:
                    case 262 /* FunctionDeclaration */:
                    case 218 /* FunctionExpression */:
                    case 219 /* ArrowFunction */:
                    case 324 /* JSDocFunctionType */:
                    case 175 /* ClassStaticBlockDeclaration */:
                    case 265 /* TypeAliasDeclaration */:
                    case 200 /* MappedType */:
                        if (container.locals)
                            Debug.assertNode(container, canHaveLocals);
                        return declareSymbol(container.locals, 
                        /*parent*/
                        void 0, node, symbolFlags, symbolExcludes);
                }
            }
            function declareClassMember(node, symbolFlags, symbolExcludes) {
                return isStatic(node) ? declareSymbol(container.symbol.exports, container.symbol, node, symbolFlags, symbolExcludes) : declareSymbol(container.symbol.members, container.symbol, node, symbolFlags, symbolExcludes);
            }
            function declareSourceFileMember(node, symbolFlags, symbolExcludes) {
                return isExternalModule(file) ? declareModuleMember(node, symbolFlags, symbolExcludes) : declareSymbol(file.locals, 
                /*parent*/
                void 0, node, symbolFlags, symbolExcludes);
            }
            function hasExportDeclarations(node) {
                const body = isSourceFile(node) ? node : tryCast(node.body, isModuleBlock);
                return !!body && body.statements.some((s) => isExportDeclaration(s) || isExportAssignment(s));
            }
            function setExportContextFlag(node) {
                if (node.flags & 33554432 /* Ambient */ && !hasExportDeclarations(node)) {
                    node.flags |= 128 /* ExportContext */;
                }
                else {
                    node.flags &= ~128 /* ExportContext */;
                }
            }
            function bindModuleDeclaration(node) {
                setExportContextFlag(node);
                if (isAmbientModule(node)) {
                    if (hasSyntacticModifier(node, 32 /* Export */)) {
                        errorOnFirstToken(node, Diagnostics.export_modifier_cannot_be_applied_to_ambient_modules_and_module_augmentations_since_they_are_always_visible);
                    }
                    if (isModuleAugmentationExternal(node)) {
                        declareModuleSymbol(node);
                    }
                    else {
                        let pattern;
                        if (node.name.kind === 11 /* StringLiteral */) {
                            const { text } = node.name;
                            pattern = tryParsePattern(text);
                            if (pattern === void 0) {
                                errorOnFirstToken(node.name, Diagnostics.Pattern_0_can_have_at_most_one_Asterisk_character, text);
                            }
                        }
                        const symbol = declareSymbolAndAddToSymbolTable(node, 512 /* ValueModule */, 110735 /* ValueModuleExcludes */);
                        file.patternAmbientModules = append(file.patternAmbientModules, pattern && !isString(pattern) ? { pattern, symbol } : void 0);
                    }
                }
                else {
                    const state = declareModuleSymbol(node);
                    if (state !== 0 /* NonInstantiated */) {
                        const { symbol } = node;
                        symbol.constEnumOnlyModule = !(symbol.flags & (16 /* Function */ | 32 /* Class */ | 256 /* RegularEnum */)) && state === 2 /* ConstEnumOnly */ && symbol.constEnumOnlyModule !== false;
                    }
                }
            }
            function declareModuleSymbol(node) {
                const state = getModuleInstanceState(node);
                const instantiated = state !== 0 /* NonInstantiated */;
                declareSymbolAndAddToSymbolTable(node, instantiated ? 512 /* ValueModule */ : 1024 /* NamespaceModule */, instantiated ? 110735 /* ValueModuleExcludes */ : 0 /* NamespaceModuleExcludes */);
                return state;
            }
            function bindFunctionOrConstructorType(node) {
                const symbol = createSymbol(131072 /* Signature */, getDeclarationName(node));
                addDeclarationToSymbol(symbol, node, 131072 /* Signature */);
                const typeLiteralSymbol = createSymbol(2048 /* TypeLiteral */, "__type" /* Type */);
                addDeclarationToSymbol(typeLiteralSymbol, node, 2048 /* TypeLiteral */);
                typeLiteralSymbol.members = createSymbolTable();
                typeLiteralSymbol.members.set(symbol.escapedName, symbol);
            }
            function bindObjectLiteralExpression(node) {
                return bindAnonymousDeclaration(node, 4096 /* ObjectLiteral */, "__object" /* Object */);
            }
            function bindJsxAttributes(node) {
                return bindAnonymousDeclaration(node, 4096 /* ObjectLiteral */, "__jsxAttributes" /* JSXAttributes */);
            }
            function bindJsxAttribute(node, symbolFlags, symbolExcludes) {
                return declareSymbolAndAddToSymbolTable(node, symbolFlags, symbolExcludes);
            }
            function bindAnonymousDeclaration(node, symbolFlags, name) {
                const symbol = createSymbol(symbolFlags, name);
                if (symbolFlags & (8 /* EnumMember */ | 106500 /* ClassMember */)) {
                    symbol.parent = container.symbol;
                }
                addDeclarationToSymbol(symbol, node, symbolFlags);
                return symbol;
            }
            function bindBlockScopedDeclaration(node, symbolFlags, symbolExcludes) {
                switch (blockScopeContainer.kind) {
                    case 267 /* ModuleDeclaration */:
                        declareModuleMember(node, symbolFlags, symbolExcludes);
                        break;
                    case 312 /* SourceFile */:
                        if (isExternalOrCommonJsModule(container)) {
                            declareModuleMember(node, symbolFlags, symbolExcludes);
                            break;
                        }
                    default:
                        Debug.assertNode(blockScopeContainer, canHaveLocals);
                        if (!blockScopeContainer.locals) {
                            blockScopeContainer.locals = createSymbolTable();
                            addToContainerChain(blockScopeContainer);
                        }
                        declareSymbol(blockScopeContainer.locals, 
                        /*parent*/
                        void 0, node, symbolFlags, symbolExcludes);
                }
            }
            function delayedBindJSDocTypedefTag() {
                if (!delayedTypeAliases) {
                    return;
                }
                const saveContainer = container;
                const saveLastContainer = lastContainer;
                const saveBlockScopeContainer = blockScopeContainer;
                const saveParent = parent2;
                const saveCurrentFlow = currentFlow;
                for (const typeAlias of delayedTypeAliases) {
                    const host = typeAlias.parent.parent;
                    container = getEnclosingContainer(host) || file;
                    blockScopeContainer = getEnclosingBlockScopeContainer(host) || file;
                    currentFlow = initFlowNode({ flags: 2 /* Start */ });
                    parent2 = typeAlias;
                    bind(typeAlias.typeExpression);
                    const declName = getNameOfDeclaration(typeAlias);
                    if ((isJSDocEnumTag(typeAlias) || !typeAlias.fullName) && declName && isPropertyAccessEntityNameExpression(declName.parent)) {
                        const isTopLevel = isTopLevelNamespaceAssignment(declName.parent);
                        if (isTopLevel) {
                            bindPotentiallyMissingNamespaces(file.symbol, declName.parent, isTopLevel, !!findAncestor(declName, (d) => isPropertyAccessExpression(d) && d.name.escapedText === "prototype"), 
                            /*containerIsClass*/
                            false);
                            const oldContainer = container;
                            switch (getAssignmentDeclarationPropertyAccessKind(declName.parent)) {
                                case 1 /* ExportsProperty */:
                                case 2 /* ModuleExports */:
                                    if (!isExternalOrCommonJsModule(file)) {
                                        container = void 0;
                                    }
                                    else {
                                        container = file;
                                    }
                                    break;
                                case 4 /* ThisProperty */:
                                    container = declName.parent.expression;
                                    break;
                                case 3 /* PrototypeProperty */:
                                    container = declName.parent.expression.name;
                                    break;
                                case 5 /* Property */:
                                    container = isExportsOrModuleExportsOrAlias(file, declName.parent.expression) ? file : isPropertyAccessExpression(declName.parent.expression) ? declName.parent.expression.name : declName.parent.expression;
                                    break;
                                case 0 /* None */:
                                    return Debug.fail("Shouldn't have detected typedef or enum on non-assignment declaration");
                            }
                            if (container) {
                                declareModuleMember(typeAlias, 524288 /* TypeAlias */, 788968 /* TypeAliasExcludes */);
                            }
                            container = oldContainer;
                        }
                    }
                    else if (isJSDocEnumTag(typeAlias) || !typeAlias.fullName || typeAlias.fullName.kind === 80 /* Identifier */) {
                        parent2 = typeAlias.parent;
                        bindBlockScopedDeclaration(typeAlias, 524288 /* TypeAlias */, 788968 /* TypeAliasExcludes */);
                    }
                    else {
                        bind(typeAlias.fullName);
                    }
                }
                container = saveContainer;
                lastContainer = saveLastContainer;
                blockScopeContainer = saveBlockScopeContainer;
                parent2 = saveParent;
                currentFlow = saveCurrentFlow;
            }
            function checkContextualIdentifier(node) {
                if (!file.parseDiagnostics.length && !(node.flags & 33554432 /* Ambient */) && !(node.flags & 16777216 /* JSDoc */) && !isIdentifierName(node)) {
                    const originalKeywordKind = identifierToKeywordKind(node);
                    if (originalKeywordKind === void 0) {
                        return;
                    }
                    if (inStrictMode && originalKeywordKind >= 119 /* FirstFutureReservedWord */ && originalKeywordKind <= 127 /* LastFutureReservedWord */) {
                        file.bindDiagnostics.push(createDiagnosticForNode2(node, getStrictModeIdentifierMessage(node), declarationNameToString(node)));
                    }
                    else if (originalKeywordKind === 135 /* AwaitKeyword */) {
                        if (isExternalModule(file) && isInTopLevelContext(node)) {
                            file.bindDiagnostics.push(createDiagnosticForNode2(node, Diagnostics.Identifier_expected_0_is_a_reserved_word_at_the_top_level_of_a_module, declarationNameToString(node)));
                        }
                        else if (node.flags & 65536 /* AwaitContext */) {
                            file.bindDiagnostics.push(createDiagnosticForNode2(node, Diagnostics.Identifier_expected_0_is_a_reserved_word_that_cannot_be_used_here, declarationNameToString(node)));
                        }
                    }
                    else if (originalKeywordKind === 127 /* YieldKeyword */ && node.flags & 16384 /* YieldContext */) {
                        file.bindDiagnostics.push(createDiagnosticForNode2(node, Diagnostics.Identifier_expected_0_is_a_reserved_word_that_cannot_be_used_here, declarationNameToString(node)));
                    }
                }
            }
            function getStrictModeIdentifierMessage(node) {
                if (getContainingClass(node)) {
                    return Diagnostics.Identifier_expected_0_is_a_reserved_word_in_strict_mode_Class_definitions_are_automatically_in_strict_mode;
                }
                if (file.externalModuleIndicator) {
                    return Diagnostics.Identifier_expected_0_is_a_reserved_word_in_strict_mode_Modules_are_automatically_in_strict_mode;
                }
                return Diagnostics.Identifier_expected_0_is_a_reserved_word_in_strict_mode;
            }
            function checkPrivateIdentifier(node) {
                if (node.escapedText === "#constructor") {
                    if (!file.parseDiagnostics.length) {
                        file.bindDiagnostics.push(createDiagnosticForNode2(node, Diagnostics.constructor_is_a_reserved_word, declarationNameToString(node)));
                    }
                }
            }
            function checkStrictModeBinaryExpression(node) {
                if (inStrictMode && isLeftHandSideExpression(node.left) && isAssignmentOperator(node.operatorToken.kind)) {
                    checkStrictModeEvalOrArguments(node, node.left);
                }
            }
            function checkStrictModeCatchClause(node) {
                if (inStrictMode && node.variableDeclaration) {
                    checkStrictModeEvalOrArguments(node, node.variableDeclaration.name);
                }
            }
            function checkStrictModeDeleteExpression(node) {
                if (inStrictMode && node.expression.kind === 80 /* Identifier */) {
                    const span = getErrorSpanForNode(file, node.expression);
                    file.bindDiagnostics.push(createFileDiagnostic(file, span.start, span.length, Diagnostics.delete_cannot_be_called_on_an_identifier_in_strict_mode));
                }
            }
            function isEvalOrArgumentsIdentifier(node) {
                return isIdentifier(node) && (node.escapedText === "eval" || node.escapedText === "arguments");
            }
            function checkStrictModeEvalOrArguments(contextNode, name) {
                if (name && name.kind === 80 /* Identifier */) {
                    const identifier = name;
                    if (isEvalOrArgumentsIdentifier(identifier)) {
                        const span = getErrorSpanForNode(file, name);
                        file.bindDiagnostics.push(createFileDiagnostic(file, span.start, span.length, getStrictModeEvalOrArgumentsMessage(contextNode), idText(identifier)));
                    }
                }
            }
            function getStrictModeEvalOrArgumentsMessage(node) {
                if (getContainingClass(node)) {
                    return Diagnostics.Code_contained_in_a_class_is_evaluated_in_JavaScript_s_strict_mode_which_does_not_allow_this_use_of_0_For_more_information_see_https_Colon_Slash_Slashdeveloper_mozilla_org_Slashen_US_Slashdocs_SlashWeb_SlashJavaScript_SlashReference_SlashStrict_mode;
                }
                if (file.externalModuleIndicator) {
                    return Diagnostics.Invalid_use_of_0_Modules_are_automatically_in_strict_mode;
                }
                return Diagnostics.Invalid_use_of_0_in_strict_mode;
            }
            function checkStrictModeFunctionName(node) {
                if (inStrictMode) {
                    checkStrictModeEvalOrArguments(node, node.name);
                }
            }
            function getStrictModeBlockScopeFunctionDeclarationMessage(node) {
                if (getContainingClass(node)) {
                    return Diagnostics.Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5_Class_definitions_are_automatically_in_strict_mode;
                }
                if (file.externalModuleIndicator) {
                    return Diagnostics.Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5_Modules_are_automatically_in_strict_mode;
                }
                return Diagnostics.Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5;
            }
            function checkStrictModeFunctionDeclaration(node) {
                if (languageVersion < 2 /* ES2015 */) {
                    if (blockScopeContainer.kind !== 312 /* SourceFile */ && blockScopeContainer.kind !== 267 /* ModuleDeclaration */ && !isFunctionLikeOrClassStaticBlockDeclaration(blockScopeContainer)) {
                        const errorSpan = getErrorSpanForNode(file, node);
                        file.bindDiagnostics.push(createFileDiagnostic(file, errorSpan.start, errorSpan.length, getStrictModeBlockScopeFunctionDeclarationMessage(node)));
                    }
                }
            }
            function checkStrictModePostfixUnaryExpression(node) {
                if (inStrictMode) {
                    checkStrictModeEvalOrArguments(node, node.operand);
                }
            }
            function checkStrictModePrefixUnaryExpression(node) {
                if (inStrictMode) {
                    if (node.operator === 46 /* PlusPlusToken */ || node.operator === 47 /* MinusMinusToken */) {
                        checkStrictModeEvalOrArguments(node, node.operand);
                    }
                }
            }
            function checkStrictModeWithStatement(node) {
                if (inStrictMode) {
                    errorOnFirstToken(node, Diagnostics.with_statements_are_not_allowed_in_strict_mode);
                }
            }
            function checkStrictModeLabeledStatement(node) {
                if (inStrictMode && getEmitScriptTarget(options) >= 2 /* ES2015 */) {
                    if (isDeclarationStatement(node.statement) || isVariableStatement(node.statement)) {
                        errorOnFirstToken(node.label, Diagnostics.A_label_is_not_allowed_here);
                    }
                }
            }
            function errorOnFirstToken(node, message, ...args) {
                const span = getSpanOfTokenAtPosition(file, node.pos);
                file.bindDiagnostics.push(createFileDiagnostic(file, span.start, span.length, message, ...args));
            }
            function errorOrSuggestionOnNode(isError, node, message) {
                errorOrSuggestionOnRange(isError, node, node, message);
            }
            function errorOrSuggestionOnRange(isError, startNode2, endNode2, message) {
                addErrorOrSuggestionDiagnostic(isError, { pos: getTokenPosOfNode(startNode2, file), end: endNode2.end }, message);
            }
            function addErrorOrSuggestionDiagnostic(isError, range, message) {
                const diag2 = createFileDiagnostic(file, range.pos, range.end - range.pos, message);
                if (isError) {
                    file.bindDiagnostics.push(diag2);
                }
                else {
                    file.bindSuggestionDiagnostics = append(file.bindSuggestionDiagnostics, { ...diag2, category: 2 /* Suggestion */ });
                }
            }
            function bind(node) {
                if (!node) {
                    return;
                }
                setParent(node, parent2);
                if (tracing)
                    node.tracingPath = file.path;
                const saveInStrictMode = inStrictMode;
                bindWorker(node);
                if (node.kind > 165 /* LastToken */) {
                    const saveParent = parent2;
                    parent2 = node;
                    const containerFlags = getContainerFlags(node);
                    if (containerFlags === 0 /* None */) {
                        bindChildren(node);
                    }
                    else {
                        bindContainer(node, containerFlags);
                    }
                    parent2 = saveParent;
                }
                else {
                    const saveParent = parent2;
                    if (node.kind === 1 /* EndOfFileToken */)
                        parent2 = node;
                    bindJSDoc(node);
                    parent2 = saveParent;
                }
                inStrictMode = saveInStrictMode;
            }
            function bindJSDoc(node) {
                if (hasJSDocNodes(node)) {
                    if (isInJSFile(node)) {
                        for (const j of node.jsDoc) {
                            bind(j);
                        }
                    }
                    else {
                        for (const j of node.jsDoc) {
                            setParent(j, node);
                            setParentRecursive(j, 
                            /*incremental*/
                            false);
                        }
                    }
                }
            }
            function updateStrictModeStatementList(statements) {
                if (!inStrictMode) {
                    for (const statement of statements) {
                        if (!isPrologueDirective(statement)) {
                            return;
                        }
                        if (isUseStrictPrologueDirective(statement)) {
                            inStrictMode = true;
                            return;
                        }
                    }
                }
            }
            function isUseStrictPrologueDirective(node) {
                const nodeText2 = getSourceTextOfNodeFromSourceFile(file, node.expression);
                return nodeText2 === '"use strict"' || nodeText2 === "'use strict'";
            }
            function bindWorker(node) {
                switch (node.kind) {
                    case 80 /* Identifier */:
                        if (node.flags & 4096 /* IdentifierIsInJSDocNamespace */) {
                            let parentNode = node.parent;
                            while (parentNode && !isJSDocTypeAlias(parentNode)) {
                                parentNode = parentNode.parent;
                            }
                            bindBlockScopedDeclaration(parentNode, 524288 /* TypeAlias */, 788968 /* TypeAliasExcludes */);
                            break;
                        }
                    case 110 /* ThisKeyword */:
                        if (currentFlow && (isExpression(node) || parent2.kind === 304 /* ShorthandPropertyAssignment */)) {
                            node.flowNode = currentFlow;
                        }
                        return checkContextualIdentifier(node);
                    case 166 /* QualifiedName */:
                        if (currentFlow && isPartOfTypeQuery(node)) {
                            node.flowNode = currentFlow;
                        }
                        break;
                    case 236 /* MetaProperty */:
                    case 108 /* SuperKeyword */:
                        node.flowNode = currentFlow;
                        break;
                    case 81 /* PrivateIdentifier */:
                        return checkPrivateIdentifier(node);
                    case 211 /* PropertyAccessExpression */:
                    case 212 /* ElementAccessExpression */:
                        const expr = node;
                        if (currentFlow && isNarrowableReference(expr)) {
                            expr.flowNode = currentFlow;
                        }
                        if (isSpecialPropertyDeclaration(expr)) {
                            bindSpecialPropertyDeclaration(expr);
                        }
                        if (isInJSFile(expr) && file.commonJsModuleIndicator && isModuleExportsAccessExpression(expr) && !lookupSymbolForName(blockScopeContainer, "module")) {
                            declareSymbol(file.locals, 
                            /*parent*/
                            void 0, expr.expression, 1 /* FunctionScopedVariable */ | 134217728 /* ModuleExports */, 111550 /* FunctionScopedVariableExcludes */);
                        }
                        break;
                    case 226 /* BinaryExpression */:
                        const specialKind = getAssignmentDeclarationKind(node);
                        switch (specialKind) {
                            case 1 /* ExportsProperty */:
                                bindExportsPropertyAssignment(node);
                                break;
                            case 2 /* ModuleExports */:
                                bindModuleExportsAssignment(node);
                                break;
                            case 3 /* PrototypeProperty */:
                                bindPrototypePropertyAssignment(node.left, node);
                                break;
                            case 6 /* Prototype */:
                                bindPrototypeAssignment(node);
                                break;
                            case 4 /* ThisProperty */:
                                bindThisPropertyAssignment(node);
                                break;
                            case 5 /* Property */:
                                const expression = node.left.expression;
                                if (isInJSFile(node) && isIdentifier(expression)) {
                                    const symbol = lookupSymbolForName(blockScopeContainer, expression.escapedText);
                                    if (isThisInitializedDeclaration(symbol == null ? void 0 : symbol.valueDeclaration)) {
                                        bindThisPropertyAssignment(node);
                                        break;
                                    }
                                }
                                bindSpecialPropertyAssignment(node);
                                break;
                            case 0 /* None */:
                                break;
                            default:
                                Debug.fail("Unknown binary expression special property assignment kind");
                        }
                        return checkStrictModeBinaryExpression(node);
                    case 299 /* CatchClause */:
                        return checkStrictModeCatchClause(node);
                    case 220 /* DeleteExpression */:
                        return checkStrictModeDeleteExpression(node);
                    case 225 /* PostfixUnaryExpression */:
                        return checkStrictModePostfixUnaryExpression(node);
                    case 224 /* PrefixUnaryExpression */:
                        return checkStrictModePrefixUnaryExpression(node);
                    case 254 /* WithStatement */:
                        return checkStrictModeWithStatement(node);
                    case 256 /* LabeledStatement */:
                        return checkStrictModeLabeledStatement(node);
                    case 197 /* ThisType */:
                        seenThisKeyword = true;
                        return;
                    case 182 /* TypePredicate */:
                        break;
                    case 168 /* TypeParameter */:
                        return bindTypeParameter(node);
                    case 169 /* Parameter */:
                        return bindParameter(node);
                    case 260 /* VariableDeclaration */:
                        return bindVariableDeclarationOrBindingElement(node);
                    case 208 /* BindingElement */:
                        node.flowNode = currentFlow;
                        return bindVariableDeclarationOrBindingElement(node);
                    case 172 /* PropertyDeclaration */:
                    case 171 /* PropertySignature */:
                        return bindPropertyWorker(node);
                    case 303 /* PropertyAssignment */:
                    case 304 /* ShorthandPropertyAssignment */:
                        return bindPropertyOrMethodOrAccessor(node, 4 /* Property */, 0 /* PropertyExcludes */);
                    case 306 /* EnumMember */:
                        return bindPropertyOrMethodOrAccessor(node, 8 /* EnumMember */, 900095 /* EnumMemberExcludes */);
                    case 179 /* CallSignature */:
                    case 180 /* ConstructSignature */:
                    case 181 /* IndexSignature */:
                        return declareSymbolAndAddToSymbolTable(node, 131072 /* Signature */, 0 /* None */);
                    case 174 /* MethodDeclaration */:
                    case 173 /* MethodSignature */:
                        return bindPropertyOrMethodOrAccessor(node, 8192 /* Method */ | (node.questionToken ? 16777216 /* Optional */ : 0 /* None */), isObjectLiteralMethod(node) ? 0 /* PropertyExcludes */ : 103359 /* MethodExcludes */);
                    case 262 /* FunctionDeclaration */:
                        return bindFunctionDeclaration(node);
                    case 176 /* Constructor */:
                        return declareSymbolAndAddToSymbolTable(node, 16384 /* Constructor */, 
                        /*symbolExcludes:*/
                        0 /* None */);
                    case 177 /* GetAccessor */:
                        return bindPropertyOrMethodOrAccessor(node, 32768 /* GetAccessor */, 46015 /* GetAccessorExcludes */);
                    case 178 /* SetAccessor */:
                        return bindPropertyOrMethodOrAccessor(node, 65536 /* SetAccessor */, 78783 /* SetAccessorExcludes */);
                    case 184 /* FunctionType */:
                    case 324 /* JSDocFunctionType */:
                    case 330 /* JSDocSignature */:
                    case 185 /* ConstructorType */:
                        return bindFunctionOrConstructorType(node);
                    case 187 /* TypeLiteral */:
                    case 329 /* JSDocTypeLiteral */:
                    case 200 /* MappedType */:
                        return bindAnonymousTypeWorker(node);
                    case 339 /* JSDocClassTag */:
                        return bindJSDocClassTag(node);
                    case 210 /* ObjectLiteralExpression */:
                        return bindObjectLiteralExpression(node);
                    case 218 /* FunctionExpression */:
                    case 219 /* ArrowFunction */:
                        return bindFunctionExpression(node);
                    case 213 /* CallExpression */:
                        const assignmentKind = getAssignmentDeclarationKind(node);
                        switch (assignmentKind) {
                            case 7 /* ObjectDefinePropertyValue */:
                                return bindObjectDefinePropertyAssignment(node);
                            case 8 /* ObjectDefinePropertyExports */:
                                return bindObjectDefinePropertyExport(node);
                            case 9 /* ObjectDefinePrototypeProperty */:
                                return bindObjectDefinePrototypeProperty(node);
                            case 0 /* None */:
                                break;
                            default:
                                return Debug.fail("Unknown call expression assignment declaration kind");
                        }
                        if (isInJSFile(node)) {
                            bindCallExpression(node);
                        }
                        break;
                    case 231 /* ClassExpression */:
                    case 263 /* ClassDeclaration */:
                        inStrictMode = true;
                        return bindClassLikeDeclaration(node);
                    case 264 /* InterfaceDeclaration */:
                        return bindBlockScopedDeclaration(node, 64 /* Interface */, 788872 /* InterfaceExcludes */);
                    case 265 /* TypeAliasDeclaration */:
                        return bindBlockScopedDeclaration(node, 524288 /* TypeAlias */, 788968 /* TypeAliasExcludes */);
                    case 266 /* EnumDeclaration */:
                        return bindEnumDeclaration(node);
                    case 267 /* ModuleDeclaration */:
                        return bindModuleDeclaration(node);
                    case 292 /* JsxAttributes */:
                        return bindJsxAttributes(node);
                    case 291 /* JsxAttribute */:
                        return bindJsxAttribute(node, 4 /* Property */, 0 /* PropertyExcludes */);
                    case 271 /* ImportEqualsDeclaration */:
                    case 274 /* NamespaceImport */:
                    case 276 /* ImportSpecifier */:
                    case 281 /* ExportSpecifier */:
                        return declareSymbolAndAddToSymbolTable(node, 2097152 /* Alias */, 2097152 /* AliasExcludes */);
                    case 270 /* NamespaceExportDeclaration */:
                        return bindNamespaceExportDeclaration(node);
                    case 273 /* ImportClause */:
                        return bindImportClause(node);
                    case 278 /* ExportDeclaration */:
                        return bindExportDeclaration(node);
                    case 277 /* ExportAssignment */:
                        return bindExportAssignment(node);
                    case 312 /* SourceFile */:
                        updateStrictModeStatementList(node.statements);
                        return bindSourceFileIfExternalModule();
                    case 241 /* Block */:
                        if (!isFunctionLikeOrClassStaticBlockDeclaration(node.parent)) {
                            return;
                        }
                    case 268 /* ModuleBlock */:
                        return updateStrictModeStatementList(node.statements);
                    case 348 /* JSDocParameterTag */:
                        if (node.parent.kind === 330 /* JSDocSignature */) {
                            return bindParameter(node);
                        }
                        if (node.parent.kind !== 329 /* JSDocTypeLiteral */) {
                            break;
                        }
                    case 355 /* JSDocPropertyTag */:
                        const propTag = node;
                        const flags = propTag.isBracketed || propTag.typeExpression && propTag.typeExpression.type.kind === 323 /* JSDocOptionalType */ ? 4 /* Property */ | 16777216 /* Optional */ : 4 /* Property */;
                        return declareSymbolAndAddToSymbolTable(propTag, flags, 0 /* PropertyExcludes */);
                    case 353 /* JSDocTypedefTag */:
                    case 345 /* JSDocCallbackTag */:
                    case 347 /* JSDocEnumTag */:
                        return (delayedTypeAliases || (delayedTypeAliases = [])).push(node);
                    case 346 /* JSDocOverloadTag */:
                        return bind(node.typeExpression);
                }
            }
            function bindPropertyWorker(node) {
                const isAutoAccessor = isAutoAccessorPropertyDeclaration(node);
                const includes = isAutoAccessor ? 98304 /* Accessor */ : 4 /* Property */;
                const excludes = isAutoAccessor ? 13247 /* AccessorExcludes */ : 0 /* PropertyExcludes */;
                return bindPropertyOrMethodOrAccessor(node, includes | (node.questionToken ? 16777216 /* Optional */ : 0 /* None */), excludes);
            }
            function bindAnonymousTypeWorker(node) {
                return bindAnonymousDeclaration(node, 2048 /* TypeLiteral */, "__type" /* Type */);
            }
            function bindSourceFileIfExternalModule() {
                setExportContextFlag(file);
                if (isExternalModule(file)) {
                    bindSourceFileAsExternalModule();
                }
                else if (isJsonSourceFile(file)) {
                    bindSourceFileAsExternalModule();
                    const originalSymbol = file.symbol;
                    declareSymbol(file.symbol.exports, file.symbol, file, 4 /* Property */, -1 /* All */);
                    file.symbol = originalSymbol;
                }
            }
            function bindSourceFileAsExternalModule() {
                bindAnonymousDeclaration(file, 512 /* ValueModule */, `"${removeFileExtension(file.fileName)}"`);
            }
            function bindExportAssignment(node) {
                if (!container.symbol || !container.symbol.exports) {
                    bindAnonymousDeclaration(node, 111551 /* Value */, getDeclarationName(node));
                }
                else {
                    const flags = exportAssignmentIsAlias(node) ? 2097152 /* Alias */ : 4 /* Property */;
                    const symbol = declareSymbol(container.symbol.exports, container.symbol, node, flags, -1 /* All */);
                    if (node.isExportEquals) {
                        setValueDeclaration(symbol, node);
                    }
                }
            }
            function bindNamespaceExportDeclaration(node) {
                if (some(node.modifiers)) {
                    file.bindDiagnostics.push(createDiagnosticForNode2(node, Diagnostics.Modifiers_cannot_appear_here));
                }
                const diag2 = !isSourceFile(node.parent) ? Diagnostics.Global_module_exports_may_only_appear_at_top_level : !isExternalModule(node.parent) ? Diagnostics.Global_module_exports_may_only_appear_in_module_files : !node.parent.isDeclarationFile ? Diagnostics.Global_module_exports_may_only_appear_in_declaration_files : void 0;
                if (diag2) {
                    file.bindDiagnostics.push(createDiagnosticForNode2(node, diag2));
                }
                else {
                    file.symbol.globalExports = file.symbol.globalExports || createSymbolTable();
                    declareSymbol(file.symbol.globalExports, file.symbol, node, 2097152 /* Alias */, 2097152 /* AliasExcludes */);
                }
            }
            function bindExportDeclaration(node) {
                if (!container.symbol || !container.symbol.exports) {
                    bindAnonymousDeclaration(node, 8388608 /* ExportStar */, getDeclarationName(node));
                }
                else if (!node.exportClause) {
                    declareSymbol(container.symbol.exports, container.symbol, node, 8388608 /* ExportStar */, 0 /* None */);
                }
                else if (isNamespaceExport(node.exportClause)) {
                    setParent(node.exportClause, node);
                    declareSymbol(container.symbol.exports, container.symbol, node.exportClause, 2097152 /* Alias */, 2097152 /* AliasExcludes */);
                }
            }
            function bindImportClause(node) {
                if (node.name) {
                    declareSymbolAndAddToSymbolTable(node, 2097152 /* Alias */, 2097152 /* AliasExcludes */);
                }
            }
            function setCommonJsModuleIndicator(node) {
                if (file.externalModuleIndicator && file.externalModuleIndicator !== true) {
                    return false;
                }
                if (!file.commonJsModuleIndicator) {
                    file.commonJsModuleIndicator = node;
                    if (!file.externalModuleIndicator) {
                        bindSourceFileAsExternalModule();
                    }
                }
                return true;
            }
            function bindObjectDefinePropertyExport(node) {
                if (!setCommonJsModuleIndicator(node)) {
                    return;
                }
                const symbol = forEachIdentifierInEntityName(node.arguments[0], 
                /*parent*/
                void 0, (id, symbol2) => {
                    if (symbol2) {
                        addDeclarationToSymbol(symbol2, id, 1536 /* Module */ | 67108864 /* Assignment */);
                    }
                    return symbol2;
                });
                if (symbol) {
                    const flags = 4 /* Property */ | 1048576 /* ExportValue */;
                    declareSymbol(symbol.exports, symbol, node, flags, 0 /* None */);
                }
            }
            function bindExportsPropertyAssignment(node) {
                if (!setCommonJsModuleIndicator(node)) {
                    return;
                }
                const symbol = forEachIdentifierInEntityName(node.left.expression, 
                /*parent*/
                void 0, (id, symbol2) => {
                    if (symbol2) {
                        addDeclarationToSymbol(symbol2, id, 1536 /* Module */ | 67108864 /* Assignment */);
                    }
                    return symbol2;
                });
                if (symbol) {
                    const isAlias = isAliasableExpression(node.right) && (isExportsIdentifier(node.left.expression) || isModuleExportsAccessExpression(node.left.expression));
                    const flags = isAlias ? 2097152 /* Alias */ : 4 /* Property */ | 1048576 /* ExportValue */;
                    setParent(node.left, node);
                    declareSymbol(symbol.exports, symbol, node.left, flags, 0 /* None */);
                }
            }
            function bindModuleExportsAssignment(node) {
                if (!setCommonJsModuleIndicator(node)) {
                    return;
                }
                const assignedExpression = getRightMostAssignedExpression(node.right);
                if (isEmptyObjectLiteral(assignedExpression) || container === file && isExportsOrModuleExportsOrAlias(file, assignedExpression)) {
                    return;
                }
                if (isObjectLiteralExpression(assignedExpression) && every(assignedExpression.properties, isShorthandPropertyAssignment)) {
                    forEach(assignedExpression.properties, bindExportAssignedObjectMemberAlias);
                    return;
                }
                const flags = exportAssignmentIsAlias(node) ? 2097152 /* Alias */ : 4 /* Property */ | 1048576 /* ExportValue */ | 512 /* ValueModule */;
                const symbol = declareSymbol(file.symbol.exports, file.symbol, node, flags | 67108864 /* Assignment */, 0 /* None */);
                setValueDeclaration(symbol, node);
            }
            function bindExportAssignedObjectMemberAlias(node) {
                declareSymbol(file.symbol.exports, file.symbol, node, 2097152 /* Alias */ | 67108864 /* Assignment */, 0 /* None */);
            }
            function bindThisPropertyAssignment(node) {
                Debug.assert(isInJSFile(node));
                const hasPrivateIdentifier = isBinaryExpression(node) && isPropertyAccessExpression(node.left) && isPrivateIdentifier(node.left.name) || isPropertyAccessExpression(node) && isPrivateIdentifier(node.name);
                if (hasPrivateIdentifier) {
                    return;
                }
                const thisContainer = getThisContainer(node, 
                /*includeArrowFunctions*/
                false, 
                /*includeClassComputedPropertyName*/
                false);
                switch (thisContainer.kind) {
                    case 262 /* FunctionDeclaration */:
                    case 218 /* FunctionExpression */:
                        let constructorSymbol = thisContainer.symbol;
                        if (isBinaryExpression(thisContainer.parent) && thisContainer.parent.operatorToken.kind === 64 /* EqualsToken */) {
                            const l = thisContainer.parent.left;
                            if (isBindableStaticAccessExpression(l) && isPrototypeAccess(l.expression)) {
                                constructorSymbol = lookupSymbolForPropertyAccess(l.expression.expression, thisParentContainer);
                            }
                        }
                        if (constructorSymbol && constructorSymbol.valueDeclaration) {
                            constructorSymbol.members = constructorSymbol.members || createSymbolTable();
                            if (hasDynamicName(node)) {
                                bindDynamicallyNamedThisPropertyAssignment(node, constructorSymbol, constructorSymbol.members);
                            }
                            else {
                                declareSymbol(constructorSymbol.members, constructorSymbol, node, 4 /* Property */ | 67108864 /* Assignment */, 0 /* PropertyExcludes */ & ~4 /* Property */);
                            }
                            addDeclarationToSymbol(constructorSymbol, constructorSymbol.valueDeclaration, 32 /* Class */);
                        }
                        break;
                    case 176 /* Constructor */:
                    case 172 /* PropertyDeclaration */:
                    case 174 /* MethodDeclaration */:
                    case 177 /* GetAccessor */:
                    case 178 /* SetAccessor */:
                    case 175 /* ClassStaticBlockDeclaration */:
                        const containingClass = thisContainer.parent;
                        const symbolTable = isStatic(thisContainer) ? containingClass.symbol.exports : containingClass.symbol.members;
                        if (hasDynamicName(node)) {
                            bindDynamicallyNamedThisPropertyAssignment(node, containingClass.symbol, symbolTable);
                        }
                        else {
                            declareSymbol(symbolTable, containingClass.symbol, node, 4 /* Property */ | 67108864 /* Assignment */, 0 /* None */, 
                            /*isReplaceableByMethod*/
                            true);
                        }
                        break;
                    case 312 /* SourceFile */:
                        if (hasDynamicName(node)) {
                            break;
                        }
                        else if (thisContainer.commonJsModuleIndicator) {
                            declareSymbol(thisContainer.symbol.exports, thisContainer.symbol, node, 4 /* Property */ | 1048576 /* ExportValue */, 0 /* None */);
                        }
                        else {
                            declareSymbolAndAddToSymbolTable(node, 1 /* FunctionScopedVariable */, 111550 /* FunctionScopedVariableExcludes */);
                        }
                        break;
                    case 267 /* ModuleDeclaration */:
                        break;
                    default:
                        Debug.failBadSyntaxKind(thisContainer);
                }
            }
            function bindDynamicallyNamedThisPropertyAssignment(node, symbol, symbolTable) {
                declareSymbol(symbolTable, symbol, node, 4 /* Property */, 0 /* None */, 
                /*isReplaceableByMethod*/
                true, 
                /*isComputedName*/
                true);
                addLateBoundAssignmentDeclarationToSymbol(node, symbol);
            }
            function addLateBoundAssignmentDeclarationToSymbol(node, symbol) {
                if (symbol) {
                    (symbol.assignmentDeclarationMembers || (symbol.assignmentDeclarationMembers = /* @__PURE__ */ new Map())).set(getNodeId(node), node);
                }
            }
            function bindSpecialPropertyDeclaration(node) {
                if (node.expression.kind === 110 /* ThisKeyword */) {
                    bindThisPropertyAssignment(node);
                }
                else if (isBindableStaticAccessExpression(node) && node.parent.parent.kind === 312 /* SourceFile */) {
                    if (isPrototypeAccess(node.expression)) {
                        bindPrototypePropertyAssignment(node, node.parent);
                    }
                    else {
                        bindStaticPropertyAssignment(node);
                    }
                }
            }
            function bindPrototypeAssignment(node) {
                setParent(node.left, node);
                setParent(node.right, node);
                bindPropertyAssignment(node.left.expression, node.left, 
                /*isPrototypeProperty*/
                false, 
                /*containerIsClass*/
                true);
            }
            function bindObjectDefinePrototypeProperty(node) {
                const namespaceSymbol = lookupSymbolForPropertyAccess(node.arguments[0].expression);
                if (namespaceSymbol && namespaceSymbol.valueDeclaration) {
                    addDeclarationToSymbol(namespaceSymbol, namespaceSymbol.valueDeclaration, 32 /* Class */);
                }
                bindPotentiallyNewExpandoMemberToNamespace(node, namespaceSymbol, 
                /*isPrototypeProperty*/
                true);
            }
            function bindPrototypePropertyAssignment(lhs, parent3) {
                const classPrototype = lhs.expression;
                const constructorFunction = classPrototype.expression;
                setParent(constructorFunction, classPrototype);
                setParent(classPrototype, lhs);
                setParent(lhs, parent3);
                bindPropertyAssignment(constructorFunction, lhs, 
                /*isPrototypeProperty*/
                true, 
                /*containerIsClass*/
                true);
            }
            function bindObjectDefinePropertyAssignment(node) {
                let namespaceSymbol = lookupSymbolForPropertyAccess(node.arguments[0]);
                const isToplevel = node.parent.parent.kind === 312 /* SourceFile */;
                namespaceSymbol = bindPotentiallyMissingNamespaces(namespaceSymbol, node.arguments[0], isToplevel, 
                /*isPrototypeProperty*/
                false, 
                /*containerIsClass*/
                false);
                bindPotentiallyNewExpandoMemberToNamespace(node, namespaceSymbol, 
                /*isPrototypeProperty*/
                false);
            }
            function bindSpecialPropertyAssignment(node) {
                var _a;
                const parentSymbol = lookupSymbolForPropertyAccess(node.left.expression, blockScopeContainer) || lookupSymbolForPropertyAccess(node.left.expression, container);
                if (!isInJSFile(node) && !isFunctionSymbol(parentSymbol)) {
                    return;
                }
                const rootExpr = getLeftmostAccessExpression(node.left);
                if (isIdentifier(rootExpr) && ((_a = lookupSymbolForName(container, rootExpr.escapedText)) == null ? void 0 : _a.flags) & 2097152 /* Alias */) {
                    return;
                }
                setParent(node.left, node);
                setParent(node.right, node);
                if (isIdentifier(node.left.expression) && container === file && isExportsOrModuleExportsOrAlias(file, node.left.expression)) {
                    bindExportsPropertyAssignment(node);
                }
                else if (hasDynamicName(node)) {
                    bindAnonymousDeclaration(node, 4 /* Property */ | 67108864 /* Assignment */, "__computed" /* Computed */);
                    const sym = bindPotentiallyMissingNamespaces(parentSymbol, node.left.expression, isTopLevelNamespaceAssignment(node.left), 
                    /*isPrototypeProperty*/
                    false, 
                    /*containerIsClass*/
                    false);
                    addLateBoundAssignmentDeclarationToSymbol(node, sym);
                }
                else {
                    bindStaticPropertyAssignment(cast(node.left, isBindableStaticNameExpression));
                }
            }
            function bindStaticPropertyAssignment(node) {
                Debug.assert(!isIdentifier(node));
                setParent(node.expression, node);
                bindPropertyAssignment(node.expression, node, 
                /*isPrototypeProperty*/
                false, 
                /*containerIsClass*/
                false);
            }
            function bindPotentiallyMissingNamespaces(namespaceSymbol, entityName, isToplevel, isPrototypeProperty, containerIsClass) {
                if ((namespaceSymbol == null ? void 0 : namespaceSymbol.flags) & 2097152 /* Alias */) {
                    return namespaceSymbol;
                }
                if (isToplevel && !isPrototypeProperty) {
                    const flags = 1536 /* Module */ | 67108864 /* Assignment */;
                    const excludeFlags = 110735 /* ValueModuleExcludes */ & ~67108864 /* Assignment */;
                    namespaceSymbol = forEachIdentifierInEntityName(entityName, namespaceSymbol, (id, symbol, parent3) => {
                        if (symbol) {
                            addDeclarationToSymbol(symbol, id, flags);
                            return symbol;
                        }
                        else {
                            const table = parent3 ? parent3.exports : file.jsGlobalAugmentations || (file.jsGlobalAugmentations = createSymbolTable());
                            return declareSymbol(table, parent3, id, flags, excludeFlags);
                        }
                    });
                }
                if (containerIsClass && namespaceSymbol && namespaceSymbol.valueDeclaration) {
                    addDeclarationToSymbol(namespaceSymbol, namespaceSymbol.valueDeclaration, 32 /* Class */);
                }
                return namespaceSymbol;
            }
            function bindPotentiallyNewExpandoMemberToNamespace(declaration, namespaceSymbol, isPrototypeProperty) {
                if (!namespaceSymbol || !isExpandoSymbol(namespaceSymbol)) {
                    return;
                }
                const symbolTable = isPrototypeProperty ? namespaceSymbol.members || (namespaceSymbol.members = createSymbolTable()) : namespaceSymbol.exports || (namespaceSymbol.exports = createSymbolTable());
                let includes = 0 /* None */;
                let excludes = 0 /* None */;
                if (isFunctionLikeDeclaration(getAssignedExpandoInitializer(declaration))) {
                    includes = 8192 /* Method */;
                    excludes = 103359 /* MethodExcludes */;
                }
                else if (isCallExpression(declaration) && isBindableObjectDefinePropertyCall(declaration)) {
                    if (some(declaration.arguments[2].properties, (p) => {
                        const id = getNameOfDeclaration(p);
                        return !!id && isIdentifier(id) && idText(id) === "set";
                    })) {
                        includes |= 65536 /* SetAccessor */ | 4 /* Property */;
                        excludes |= 78783 /* SetAccessorExcludes */;
                    }
                    if (some(declaration.arguments[2].properties, (p) => {
                        const id = getNameOfDeclaration(p);
                        return !!id && isIdentifier(id) && idText(id) === "get";
                    })) {
                        includes |= 32768 /* GetAccessor */ | 4 /* Property */;
                        excludes |= 46015 /* GetAccessorExcludes */;
                    }
                }
                if (includes === 0 /* None */) {
                    includes = 4 /* Property */;
                    excludes = 0 /* PropertyExcludes */;
                }
                declareSymbol(symbolTable, namespaceSymbol, declaration, includes | 67108864 /* Assignment */, excludes & ~67108864 /* Assignment */);
            }
            function isTopLevelNamespaceAssignment(propertyAccess) {
                return isBinaryExpression(propertyAccess.parent) ? getParentOfBinaryExpression(propertyAccess.parent).parent.kind === 312 /* SourceFile */ : propertyAccess.parent.parent.kind === 312 /* SourceFile */;
            }
            function bindPropertyAssignment(name, propertyAccess, isPrototypeProperty, containerIsClass) {
                let namespaceSymbol = lookupSymbolForPropertyAccess(name, blockScopeContainer) || lookupSymbolForPropertyAccess(name, container);
                const isToplevel = isTopLevelNamespaceAssignment(propertyAccess);
                namespaceSymbol = bindPotentiallyMissingNamespaces(namespaceSymbol, propertyAccess.expression, isToplevel, isPrototypeProperty, containerIsClass);
                bindPotentiallyNewExpandoMemberToNamespace(propertyAccess, namespaceSymbol, isPrototypeProperty);
            }
            function isExpandoSymbol(symbol) {
                if (symbol.flags & (16 /* Function */ | 32 /* Class */ | 1024 /* NamespaceModule */)) {
                    return true;
                }
                const node = symbol.valueDeclaration;
                if (node && isCallExpression(node)) {
                    return !!getAssignedExpandoInitializer(node);
                }
                let init = !node ? void 0 : isVariableDeclaration(node) ? node.initializer : isBinaryExpression(node) ? node.right : isPropertyAccessExpression(node) && isBinaryExpression(node.parent) ? node.parent.right : void 0;
                init = init && getRightMostAssignedExpression(init);
                if (init) {
                    const isPrototypeAssignment = isPrototypeAccess(isVariableDeclaration(node) ? node.name : isBinaryExpression(node) ? node.left : node);
                    return !!getExpandoInitializer(isBinaryExpression(init) && (init.operatorToken.kind === 57 /* BarBarToken */ || init.operatorToken.kind === 61 /* QuestionQuestionToken */) ? init.right : init, isPrototypeAssignment);
                }
                return false;
            }
            function getParentOfBinaryExpression(expr) {
                while (isBinaryExpression(expr.parent)) {
                    expr = expr.parent;
                }
                return expr.parent;
            }
            function lookupSymbolForPropertyAccess(node, lookupContainer = container) {
                if (isIdentifier(node)) {
                    return lookupSymbolForName(lookupContainer, node.escapedText);
                }
                else {
                    const symbol = lookupSymbolForPropertyAccess(node.expression);
                    return symbol && symbol.exports && symbol.exports.get(getElementOrPropertyAccessName(node));
                }
            }
            function forEachIdentifierInEntityName(e, parent3, action) {
                if (isExportsOrModuleExportsOrAlias(file, e)) {
                    return file.symbol;
                }
                else if (isIdentifier(e)) {
                    return action(e, lookupSymbolForPropertyAccess(e), parent3);
                }
                else {
                    const s = forEachIdentifierInEntityName(e.expression, parent3, action);
                    const name = getNameOrArgument(e);
                    if (isPrivateIdentifier(name)) {
                        Debug.fail("unexpected PrivateIdentifier");
                    }
                    return action(name, s && s.exports && s.exports.get(getElementOrPropertyAccessName(e)), s);
                }
            }
            function bindCallExpression(node) {
                if (!file.commonJsModuleIndicator && isRequireCall(node, 
                /*requireStringLiteralLikeArgument*/
                false)) {
                    setCommonJsModuleIndicator(node);
                }
            }
            function bindClassLikeDeclaration(node) {
                if (node.kind === 263 /* ClassDeclaration */) {
                    bindBlockScopedDeclaration(node, 32 /* Class */, 899503 /* ClassExcludes */);
                }
                else {
                    const bindingName = node.name ? node.name.escapedText : "__class" /* Class */;
                    bindAnonymousDeclaration(node, 32 /* Class */, bindingName);
                    if (node.name) {
                        classifiableNames.add(node.name.escapedText);
                    }
                }
                const { symbol } = node;
                const prototypeSymbol = createSymbol(4 /* Property */ | 4194304 /* Prototype */, "prototype");
                const symbolExport = symbol.exports.get(prototypeSymbol.escapedName);
                if (symbolExport) {
                    if (node.name) {
                        setParent(node.name, node);
                    }
                    file.bindDiagnostics.push(createDiagnosticForNode2(symbolExport.declarations[0], Diagnostics.Duplicate_identifier_0, symbolName(prototypeSymbol)));
                }
                symbol.exports.set(prototypeSymbol.escapedName, prototypeSymbol);
                prototypeSymbol.parent = symbol;
            }
            function bindEnumDeclaration(node) {
                return isEnumConst(node) ? bindBlockScopedDeclaration(node, 128 /* ConstEnum */, 899967 /* ConstEnumExcludes */) : bindBlockScopedDeclaration(node, 256 /* RegularEnum */, 899327 /* RegularEnumExcludes */);
            }
            function bindVariableDeclarationOrBindingElement(node) {
                if (inStrictMode) {
                    checkStrictModeEvalOrArguments(node, node.name);
                }
                if (!isBindingPattern(node.name)) {
                    const possibleVariableDecl = node.kind === 260 /* VariableDeclaration */ ? node : node.parent.parent;
                    if (isInJSFile(node) && isVariableDeclarationInitializedToBareOrAccessedRequire(possibleVariableDecl) && !getJSDocTypeTag(node) && !(getCombinedModifierFlags(node) & 32 /* Export */)) {
                        declareSymbolAndAddToSymbolTable(node, 2097152 /* Alias */, 2097152 /* AliasExcludes */);
                    }
                    else if (isBlockOrCatchScoped(node)) {
                        bindBlockScopedDeclaration(node, 2 /* BlockScopedVariable */, 111551 /* BlockScopedVariableExcludes */);
                    }
                    else if (isParameterDeclaration(node)) {
                        declareSymbolAndAddToSymbolTable(node, 1 /* FunctionScopedVariable */, 111551 /* ParameterExcludes */);
                    }
                    else {
                        declareSymbolAndAddToSymbolTable(node, 1 /* FunctionScopedVariable */, 111550 /* FunctionScopedVariableExcludes */);
                    }
                }
            }
            function bindParameter(node) {
                if (node.kind === 348 /* JSDocParameterTag */ && container.kind !== 330 /* JSDocSignature */) {
                    return;
                }
                if (inStrictMode && !(node.flags & 33554432 /* Ambient */)) {
                    checkStrictModeEvalOrArguments(node, node.name);
                }
                if (isBindingPattern(node.name)) {
                    bindAnonymousDeclaration(node, 1 /* FunctionScopedVariable */, "__" + node.parent.parameters.indexOf(node));
                }
                else {
                    declareSymbolAndAddToSymbolTable(node, 1 /* FunctionScopedVariable */, 111551 /* ParameterExcludes */);
                }
                if (isParameterPropertyDeclaration(node, node.parent)) {
                    const classDeclaration = node.parent.parent;
                    declareSymbol(classDeclaration.symbol.members, classDeclaration.symbol, node, 4 /* Property */ | (node.questionToken ? 16777216 /* Optional */ : 0 /* None */), 0 /* PropertyExcludes */);
                }
            }
            function bindFunctionDeclaration(node) {
                if (!file.isDeclarationFile && !(node.flags & 33554432 /* Ambient */)) {
                    if (isAsyncFunction(node)) {
                        emitFlags |= 4096 /* HasAsyncFunctions */;
                    }
                }
                checkStrictModeFunctionName(node);
                if (inStrictMode) {
                    checkStrictModeFunctionDeclaration(node);
                    bindBlockScopedDeclaration(node, 16 /* Function */, 110991 /* FunctionExcludes */);
                }
                else {
                    declareSymbolAndAddToSymbolTable(node, 16 /* Function */, 110991 /* FunctionExcludes */);
                }
            }
            function bindFunctionExpression(node) {
                if (!file.isDeclarationFile && !(node.flags & 33554432 /* Ambient */)) {
                    if (isAsyncFunction(node)) {
                        emitFlags |= 4096 /* HasAsyncFunctions */;
                    }
                }
                if (currentFlow) {
                    node.flowNode = currentFlow;
                }
                checkStrictModeFunctionName(node);
                const bindingName = node.name ? node.name.escapedText : "__function" /* Function */;
                return bindAnonymousDeclaration(node, 16 /* Function */, bindingName);
            }
            function bindPropertyOrMethodOrAccessor(node, symbolFlags, symbolExcludes) {
                if (!file.isDeclarationFile && !(node.flags & 33554432 /* Ambient */) && isAsyncFunction(node)) {
                    emitFlags |= 4096 /* HasAsyncFunctions */;
                }
                if (currentFlow && isObjectLiteralOrClassExpressionMethodOrAccessor(node)) {
                    node.flowNode = currentFlow;
                }
                return hasDynamicName(node) ? bindAnonymousDeclaration(node, symbolFlags, "__computed" /* Computed */) : declareSymbolAndAddToSymbolTable(node, symbolFlags, symbolExcludes);
            }
            function getInferTypeContainer(node) {
                const extendsType = findAncestor(node, (n) => n.parent && isConditionalTypeNode(n.parent) && n.parent.extendsType === n);
                return extendsType && extendsType.parent;
            }
            function bindTypeParameter(node) {
                if (isJSDocTemplateTag(node.parent)) {
                    const container2 = getEffectiveContainerForJSDocTemplateTag(node.parent);
                    if (container2) {
                        Debug.assertNode(container2, canHaveLocals);
                        container2.locals ?? (container2.locals = createSymbolTable());
                        declareSymbol(container2.locals, 
                        /*parent*/
                        void 0, node, 262144 /* TypeParameter */, 526824 /* TypeParameterExcludes */);
                    }
                    else {
                        declareSymbolAndAddToSymbolTable(node, 262144 /* TypeParameter */, 526824 /* TypeParameterExcludes */);
                    }
                }
                else if (node.parent.kind === 195 /* InferType */) {
                    const container2 = getInferTypeContainer(node.parent);
                    if (container2) {
                        Debug.assertNode(container2, canHaveLocals);
                        container2.locals ?? (container2.locals = createSymbolTable());
                        declareSymbol(container2.locals, 
                        /*parent*/
                        void 0, node, 262144 /* TypeParameter */, 526824 /* TypeParameterExcludes */);
                    }
                    else {
                        bindAnonymousDeclaration(node, 262144 /* TypeParameter */, getDeclarationName(node));
                    }
                }
                else {
                    declareSymbolAndAddToSymbolTable(node, 262144 /* TypeParameter */, 526824 /* TypeParameterExcludes */);
                }
            }
            function shouldReportErrorOnModuleDeclaration(node) {
                const instanceState = getModuleInstanceState(node);
                return instanceState === 1 /* Instantiated */ || instanceState === 2 /* ConstEnumOnly */ && shouldPreserveConstEnums(options);
            }
            function checkUnreachable(node) {
                if (!(currentFlow.flags & 1 /* Unreachable */)) {
                    return false;
                }
                if (currentFlow === unreachableFlow) {
                    const reportError = (
                    // report error on all statements except empty ones
                    isStatementButNotDeclaration(node) && node.kind !== 242 /* EmptyStatement */ || // report error on class declarations
                        node.kind === 263 /* ClassDeclaration */ || // report error on instantiated modules or const-enums only modules if preserveConstEnums is set
                        node.kind === 267 /* ModuleDeclaration */ && shouldReportErrorOnModuleDeclaration(node));
                    if (reportError) {
                        currentFlow = reportedUnreachableFlow;
                        if (!options.allowUnreachableCode) {
                            const isError = unreachableCodeIsError(options) && !(node.flags & 33554432 /* Ambient */) && (!isVariableStatement(node) || !!(getCombinedNodeFlags(node.declarationList) & 7 /* BlockScoped */) || node.declarationList.declarations.some((d) => !!d.initializer));
                            eachUnreachableRange(node, (start, end) => errorOrSuggestionOnRange(isError, start, end, Diagnostics.Unreachable_code_detected));
                        }
                    }
                }
                return true;
            }
        }
        function eachUnreachableRange(node, cb) {
            if (isStatement(node) && isExecutableStatement(node) && isBlock(node.parent)) {
                const { statements } = node.parent;
                const slice = sliceAfter(statements, node);
                getRangesWhere(slice, isExecutableStatement, (start, afterEnd) => cb(slice[start], slice[afterEnd - 1]));
            }
            else {
                cb(node, node);
            }
        }
        function isExecutableStatement(s) {
            return !isFunctionDeclaration(s) && !isPurelyTypeDeclaration(s) && !isEnumDeclaration(s) && // `var x;` may declare a variable used above
                !(isVariableStatement(s) && !(getCombinedNodeFlags(s) & 7 /* BlockScoped */) && s.declarationList.declarations.some((d) => !d.initializer));
        }
        function isPurelyTypeDeclaration(s) {
            switch (s.kind) {
                case 264 /* InterfaceDeclaration */:
                case 265 /* TypeAliasDeclaration */:
                    return true;
                case 267 /* ModuleDeclaration */:
                    return getModuleInstanceState(s) !== 1 /* Instantiated */;
                case 266 /* EnumDeclaration */:
                    return hasSyntacticModifier(s, 4096 /* Const */);
                default:
                    return false;
            }
        }
        function isExportsOrModuleExportsOrAlias(sourceFile, node) {
            let i = 0;
            const q = createQueue();
            q.enqueue(node);
            while (!q.isEmpty() && i < 100) {
                i++;
                node = q.dequeue();
                if (isExportsIdentifier(node) || isModuleExportsAccessExpression(node)) {
                    return true;
                }
                else if (isIdentifier(node)) {
                    const symbol = lookupSymbolForName(sourceFile, node.escapedText);
                    if (!!symbol && !!symbol.valueDeclaration && isVariableDeclaration(symbol.valueDeclaration) && !!symbol.valueDeclaration.initializer) {
                        const init = symbol.valueDeclaration.initializer;
                        q.enqueue(init);
                        if (isAssignmentExpression(init, 
                        /*excludeCompoundAssignment*/
                        true)) {
                            q.enqueue(init.left);
                            q.enqueue(init.right);
                        }
                    }
                }
            }
            return false;
        }
        function getContainerFlags(node) {
            switch (node.kind) {
                case 231 /* ClassExpression */:
                case 263 /* ClassDeclaration */:
                case 266 /* EnumDeclaration */:
                case 210 /* ObjectLiteralExpression */:
                case 187 /* TypeLiteral */:
                case 329 /* JSDocTypeLiteral */:
                case 292 /* JsxAttributes */:
                    return 1 /* IsContainer */;
                case 264 /* InterfaceDeclaration */:
                    return 1 /* IsContainer */ | 64 /* IsInterface */;
                case 267 /* ModuleDeclaration */:
                case 265 /* TypeAliasDeclaration */:
                case 200 /* MappedType */:
                case 181 /* IndexSignature */:
                    return 1 /* IsContainer */ | 32 /* HasLocals */;
                case 312 /* SourceFile */:
                    return 1 /* IsContainer */ | 4 /* IsControlFlowContainer */ | 32 /* HasLocals */;
                case 177 /* GetAccessor */:
                case 178 /* SetAccessor */:
                case 174 /* MethodDeclaration */:
                    if (isObjectLiteralOrClassExpressionMethodOrAccessor(node)) {
                        return 1 /* IsContainer */ | 4 /* IsControlFlowContainer */ | 32 /* HasLocals */ | 8 /* IsFunctionLike */ | 128 /* IsObjectLiteralOrClassExpressionMethodOrAccessor */;
                    }
                case 176 /* Constructor */:
                case 262 /* FunctionDeclaration */:
                case 173 /* MethodSignature */:
                case 179 /* CallSignature */:
                case 330 /* JSDocSignature */:
                case 324 /* JSDocFunctionType */:
                case 184 /* FunctionType */:
                case 180 /* ConstructSignature */:
                case 185 /* ConstructorType */:
                case 175 /* ClassStaticBlockDeclaration */:
                    return 1 /* IsContainer */ | 4 /* IsControlFlowContainer */ | 32 /* HasLocals */ | 8 /* IsFunctionLike */;
                case 218 /* FunctionExpression */:
                case 219 /* ArrowFunction */:
                    return 1 /* IsContainer */ | 4 /* IsControlFlowContainer */ | 32 /* HasLocals */ | 8 /* IsFunctionLike */ | 16 /* IsFunctionExpression */;
                case 268 /* ModuleBlock */:
                    return 4 /* IsControlFlowContainer */;
                case 172 /* PropertyDeclaration */:
                    return node.initializer ? 4 /* IsControlFlowContainer */ : 0;
                case 299 /* CatchClause */:
                case 248 /* ForStatement */:
                case 249 /* ForInStatement */:
                case 250 /* ForOfStatement */:
                case 269 /* CaseBlock */:
                    return 2 /* IsBlockScopedContainer */ | 32 /* HasLocals */;
                case 241 /* Block */:
                    return isFunctionLike(node.parent) || isClassStaticBlockDeclaration(node.parent) ? 0 /* None */ : 2 /* IsBlockScopedContainer */ | 32 /* HasLocals */;
            }
            return 0 /* None */;
        }
        function lookupSymbolForName(container, name) {
            var _a, _b, _c, _d;
            const local = (_b = (_a = tryCast(container, canHaveLocals)) == null ? void 0 : _a.locals) == null ? void 0 : _b.get(name);
            if (local) {
                return local.exportSymbol ?? local;
            }
            if (isSourceFile(container) && container.jsGlobalAugmentations && container.jsGlobalAugmentations.has(name)) {
                return container.jsGlobalAugmentations.get(name);
            }
            if (canHaveSymbol(container)) {
                return (_d = (_c = container.symbol) == null ? void 0 : _c.exports) == null ? void 0 : _d.get(name);
            }
        }
        var ModuleInstanceState, ContainerFlags, binder;
        var init_binder = __esm({
            "src/compiler/binder.ts"() {
                "use strict";
                init_ts2();
                init_ts_performance();
                ModuleInstanceState = /* @__PURE__ */ ((ModuleInstanceState2) => {
                    ModuleInstanceState2[ModuleInstanceState2["NonInstantiated"] = 0] = "NonInstantiated";
                    ModuleInstanceState2[ModuleInstanceState2["Instantiated"] = 1] = "Instantiated";
                    ModuleInstanceState2[ModuleInstanceState2["ConstEnumOnly"] = 2] = "ConstEnumOnly";
                    return ModuleInstanceState2;
                })(ModuleInstanceState || {});
                ContainerFlags = /* @__PURE__ */ ((ContainerFlags2) => {
                    ContainerFlags2[ContainerFlags2["None"] = 0] = "None";
                    ContainerFlags2[ContainerFlags2["IsContainer"] = 1] = "IsContainer";
                    ContainerFlags2[ContainerFlags2["IsBlockScopedContainer"] = 2] = "IsBlockScopedContainer";
                    ContainerFlags2[ContainerFlags2["IsControlFlowContainer"] = 4] = "IsControlFlowContainer";
                    ContainerFlags2[ContainerFlags2["IsFunctionLike"] = 8] = "IsFunctionLike";
                    ContainerFlags2[ContainerFlags2["IsFunctionExpression"] = 16] = "IsFunctionExpression";
                    ContainerFlags2[ContainerFlags2["HasLocals"] = 32] = "HasLocals";
                    ContainerFlags2[ContainerFlags2["IsInterface"] = 64] = "IsInterface";
                    ContainerFlags2[ContainerFlags2["IsObjectLiteralOrClassExpressionMethodOrAccessor"] = 128] = "IsObjectLiteralOrClassExpressionMethodOrAccessor";
                    return ContainerFlags2;
                })(ContainerFlags || {});
                binder = /* @__PURE__ */ createBinder();
            }
        });
        // src/compiler/symbolWalker.ts
        function createGetSymbolWalker(getRestTypeOfSignature, getTypePredicateOfSignature, getReturnTypeOfSignature, getBaseTypes, resolveStructuredTypeMembers, getTypeOfSymbol, getResolvedSymbol, getConstraintOfTypeParameter, getFirstIdentifier2, getTypeArguments) {
            return getSymbolWalker;
            function getSymbolWalker(accept = () => true) {
                const visitedTypes = [];
                const visitedSymbols = [];
                return {
                    walkType: (type) => {
                        try {
                            visitType(type);
                            return { visitedTypes: getOwnValues(visitedTypes), visitedSymbols: getOwnValues(visitedSymbols) };
                        }
                        finally {
                            clear(visitedTypes);
                            clear(visitedSymbols);
                        }
                    },
                    walkSymbol: (symbol) => {
                        try {
                            visitSymbol(symbol);
                            return { visitedTypes: getOwnValues(visitedTypes), visitedSymbols: getOwnValues(visitedSymbols) };
                        }
                        finally {
                            clear(visitedTypes);
                            clear(visitedSymbols);
                        }
                    }
                };
                function visitType(type) {
                    if (!type) {
                        return;
                    }
                    if (visitedTypes[type.id]) {
                        return;
                    }
                    visitedTypes[type.id] = type;
                    const shouldBail = visitSymbol(type.symbol);
                    if (shouldBail)
                        return;
                    if (type.flags & 524288 /* Object */) {
                        const objectType = type;
                        const objectFlags = objectType.objectFlags;
                        if (objectFlags & 4 /* Reference */) {
                            visitTypeReference(type);
                        }
                        if (objectFlags & 32 /* Mapped */) {
                            visitMappedType(type);
                        }
                        if (objectFlags & (1 /* Class */ | 2 /* Interface */)) {
                            visitInterfaceType(type);
                        }
                        if (objectFlags & (8 /* Tuple */ | 16 /* Anonymous */)) {
                            visitObjectType(objectType);
                        }
                    }
                    if (type.flags & 262144 /* TypeParameter */) {
                        visitTypeParameter(type);
                    }
                    if (type.flags & 3145728 /* UnionOrIntersection */) {
                        visitUnionOrIntersectionType(type);
                    }
                    if (type.flags & 4194304 /* Index */) {
                        visitIndexType(type);
                    }
                    if (type.flags & 8388608 /* IndexedAccess */) {
                        visitIndexedAccessType(type);
                    }
                }
                function visitTypeReference(type) {
                    visitType(type.target);
                    forEach(getTypeArguments(type), visitType);
                }
                function visitTypeParameter(type) {
                    visitType(getConstraintOfTypeParameter(type));
                }
                function visitUnionOrIntersectionType(type) {
                    forEach(type.types, visitType);
                }
                function visitIndexType(type) {
                    visitType(type.type);
                }
                function visitIndexedAccessType(type) {
                    visitType(type.objectType);
                    visitType(type.indexType);
                    visitType(type.constraint);
                }
                function visitMappedType(type) {
                    visitType(type.typeParameter);
                    visitType(type.constraintType);
                    visitType(type.templateType);
                    visitType(type.modifiersType);
                }
                function visitSignature(signature) {
                    const typePredicate = getTypePredicateOfSignature(signature);
                    if (typePredicate) {
                        visitType(typePredicate.type);
                    }
                    forEach(signature.typeParameters, visitType);
                    for (const parameter of signature.parameters) {
                        visitSymbol(parameter);
                    }
                    visitType(getRestTypeOfSignature(signature));
                    visitType(getReturnTypeOfSignature(signature));
                }
                function visitInterfaceType(interfaceT) {
                    visitObjectType(interfaceT);
                    forEach(interfaceT.typeParameters, visitType);
                    forEach(getBaseTypes(interfaceT), visitType);
                    visitType(interfaceT.thisType);
                }
                function visitObjectType(type) {
                    const resolved = resolveStructuredTypeMembers(type);
                    for (const info of resolved.indexInfos) {
                        visitType(info.keyType);
                        visitType(info.type);
                    }
                    for (const signature of resolved.callSignatures) {
                        visitSignature(signature);
                    }
                    for (const signature of resolved.constructSignatures) {
                        visitSignature(signature);
                    }
                    for (const p of resolved.properties) {
                        visitSymbol(p);
                    }
                }
                function visitSymbol(symbol) {
                    if (!symbol) {
                        return false;
                    }
                    const symbolId = getSymbolId(symbol);
                    if (visitedSymbols[symbolId]) {
                        return false;
                    }
                    visitedSymbols[symbolId] = symbol;
                    if (!accept(symbol)) {
                        return true;
                    }
                    const t = getTypeOfSymbol(symbol);
                    visitType(t);
                    if (symbol.exports) {
                        symbol.exports.forEach(visitSymbol);
                    }
                    forEach(symbol.declarations, (d) => {
                        if (d.type && d.type.kind === 186 /* TypeQuery */) {
                            const query = d.type;
                            const entity = getResolvedSymbol(getFirstIdentifier2(query.exprName));
                            visitSymbol(entity);
                        }
                    });
                    return false;
                }
            }
        }
        var init_symbolWalker = __esm({
            "src/compiler/symbolWalker.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/moduleSpecifiers.ts
        function getModuleSpecifierPreferences({ importModuleSpecifierPreference, importModuleSpecifierEnding }, compilerOptions, importingSourceFile, oldImportSpecifier) {
            const filePreferredEnding = getPreferredEnding();
            return {
                relativePreference: oldImportSpecifier !== void 0 ? isExternalModuleNameRelative(oldImportSpecifier) ? 0 /* Relative */ : 1 /* NonRelative */ : importModuleSpecifierPreference === "relative" ? 0 /* Relative */ : importModuleSpecifierPreference === "non-relative" ? 1 /* NonRelative */ : importModuleSpecifierPreference === "project-relative" ? 3 /* ExternalNonRelative */ : 2 /* Shortest */,
                getAllowedEndingsInPreferredOrder: (syntaxImpliedNodeFormat) => {
                    const preferredEnding = syntaxImpliedNodeFormat !== importingSourceFile.impliedNodeFormat ? getPreferredEnding(syntaxImpliedNodeFormat) : filePreferredEnding;
                    if ((syntaxImpliedNodeFormat ?? importingSourceFile.impliedNodeFormat) === 99 /* ESNext */) {
                        if (shouldAllowImportingTsExtension(compilerOptions, importingSourceFile.fileName)) {
                            return [3 /* TsExtension */, 2 /* JsExtension */];
                        }
                        return [2 /* JsExtension */];
                    }
                    if (getEmitModuleResolutionKind(compilerOptions) === 1 /* Classic */) {
                        return preferredEnding === 2 /* JsExtension */ ? [2 /* JsExtension */, 1 /* Index */] : [1 /* Index */, 2 /* JsExtension */];
                    }
                    const allowImportingTsExtension = shouldAllowImportingTsExtension(compilerOptions, importingSourceFile.fileName);
                    switch (preferredEnding) {
                        case 2 /* JsExtension */:
                            return allowImportingTsExtension ? [2 /* JsExtension */, 3 /* TsExtension */, 0 /* Minimal */, 1 /* Index */] : [2 /* JsExtension */, 0 /* Minimal */, 1 /* Index */];
                        case 3 /* TsExtension */:
                            return [3 /* TsExtension */, 0 /* Minimal */, 2 /* JsExtension */, 1 /* Index */];
                        case 1 /* Index */:
                            return allowImportingTsExtension ? [1 /* Index */, 0 /* Minimal */, 3 /* TsExtension */, 2 /* JsExtension */] : [1 /* Index */, 0 /* Minimal */, 2 /* JsExtension */];
                        case 0 /* Minimal */:
                            return allowImportingTsExtension ? [0 /* Minimal */, 1 /* Index */, 3 /* TsExtension */, 2 /* JsExtension */] : [0 /* Minimal */, 1 /* Index */, 2 /* JsExtension */];
                        default:
                            Debug.assertNever(preferredEnding);
                    }
                }
            };
            function getPreferredEnding(resolutionMode) {
                if (oldImportSpecifier !== void 0) {
                    if (hasJSFileExtension(oldImportSpecifier))
                        return 2 /* JsExtension */;
                    if (endsWith(oldImportSpecifier, "/index"))
                        return 1 /* Index */;
                }
                return getModuleSpecifierEndingPreference(importModuleSpecifierEnding, resolutionMode ?? importingSourceFile.impliedNodeFormat, compilerOptions, importingSourceFile);
            }
        }
        function updateModuleSpecifier(compilerOptions, importingSourceFile, importingSourceFileName, toFileName2, host, oldImportSpecifier, options = {}) {
            const res = getModuleSpecifierWorker(compilerOptions, importingSourceFile, importingSourceFileName, toFileName2, host, getModuleSpecifierPreferences({}, compilerOptions, importingSourceFile, oldImportSpecifier), {}, options);
            if (res === oldImportSpecifier)
                return void 0;
            return res;
        }
        function getModuleSpecifier(compilerOptions, importingSourceFile, importingSourceFileName, toFileName2, host, options = {}) {
            return getModuleSpecifierWorker(compilerOptions, importingSourceFile, importingSourceFileName, toFileName2, host, getModuleSpecifierPreferences({}, compilerOptions, importingSourceFile), {}, options);
        }
        function getNodeModulesPackageName(compilerOptions, importingSourceFile, nodeModulesFileName, host, preferences, options = {}) {
            const info = getInfo(importingSourceFile.fileName, host);
            const modulePaths = getAllModulePaths(info, nodeModulesFileName, host, preferences, options);
            return firstDefined(modulePaths, (modulePath) => tryGetModuleNameAsNodeModule(modulePath, info, importingSourceFile, host, compilerOptions, preferences, 
            /*packageNameOnly*/
            true, options.overrideImportMode));
        }
        function getModuleSpecifierWorker(compilerOptions, importingSourceFile, importingSourceFileName, toFileName2, host, preferences, userPreferences, options = {}) {
            const info = getInfo(importingSourceFileName, host);
            const modulePaths = getAllModulePaths(info, toFileName2, host, userPreferences, options);
            return firstDefined(modulePaths, (modulePath) => tryGetModuleNameAsNodeModule(modulePath, info, importingSourceFile, host, compilerOptions, userPreferences, 
            /*packageNameOnly*/
            void 0, options.overrideImportMode)) || getLocalModuleSpecifier(toFileName2, info, compilerOptions, host, options.overrideImportMode || importingSourceFile.impliedNodeFormat, preferences);
        }
        function tryGetModuleSpecifiersFromCache(moduleSymbol, importingSourceFile, host, userPreferences, options = {}) {
            return tryGetModuleSpecifiersFromCacheWorker(moduleSymbol, importingSourceFile, host, userPreferences, options)[0];
        }
        function tryGetModuleSpecifiersFromCacheWorker(moduleSymbol, importingSourceFile, host, userPreferences, options = {}) {
            var _a;
            const moduleSourceFile = getSourceFileOfModule(moduleSymbol);
            if (!moduleSourceFile) {
                return emptyArray;
            }
            const cache = (_a = host.getModuleSpecifierCache) == null ? void 0 : _a.call(host);
            const cached = cache == null ? void 0 : cache.get(importingSourceFile.path, moduleSourceFile.path, userPreferences, options);
            return [cached == null ? void 0 : cached.moduleSpecifiers, moduleSourceFile, cached == null ? void 0 : cached.modulePaths, cache];
        }
        function getModuleSpecifiers(moduleSymbol, checker, compilerOptions, importingSourceFile, host, userPreferences, options = {}) {
            return getModuleSpecifiersWithCacheInfo(moduleSymbol, checker, compilerOptions, importingSourceFile, host, userPreferences, options, 
            /*forAutoImport*/
            false).moduleSpecifiers;
        }
        function getModuleSpecifiersWithCacheInfo(moduleSymbol, checker, compilerOptions, importingSourceFile, host, userPreferences, options = {}, forAutoImport) {
            let computedWithoutCache = false;
            const ambient = tryGetModuleNameFromAmbientModule(moduleSymbol, checker);
            if (ambient)
                return { moduleSpecifiers: [ambient], computedWithoutCache };
            let [specifiers, moduleSourceFile, modulePaths, cache] = tryGetModuleSpecifiersFromCacheWorker(moduleSymbol, importingSourceFile, host, userPreferences, options);
            if (specifiers)
                return { moduleSpecifiers: specifiers, computedWithoutCache };
            if (!moduleSourceFile)
                return { moduleSpecifiers: emptyArray, computedWithoutCache };
            computedWithoutCache = true;
            modulePaths || (modulePaths = getAllModulePathsWorker(getInfo(importingSourceFile.fileName, host), moduleSourceFile.originalFileName, host));
            const result = computeModuleSpecifiers(modulePaths, compilerOptions, importingSourceFile, host, userPreferences, options, forAutoImport);
            cache == null ? void 0 : cache.set(importingSourceFile.path, moduleSourceFile.path, userPreferences, options, modulePaths, result);
            return { moduleSpecifiers: result, computedWithoutCache };
        }
        function computeModuleSpecifiers(modulePaths, compilerOptions, importingSourceFile, host, userPreferences, options = {}, forAutoImport) {
            const info = getInfo(importingSourceFile.fileName, host);
            const preferences = getModuleSpecifierPreferences(userPreferences, compilerOptions, importingSourceFile);
            const existingSpecifier = forEach(modulePaths, (modulePath) => forEach(host.getFileIncludeReasons().get(toPath(modulePath.path, host.getCurrentDirectory(), info.getCanonicalFileName)), (reason) => {
                if (reason.kind !== 3 /* Import */ || reason.file !== importingSourceFile.path)
                    return void 0;
                if (importingSourceFile.impliedNodeFormat && importingSourceFile.impliedNodeFormat !== getModeForResolutionAtIndex(importingSourceFile, reason.index, compilerOptions))
                    return void 0;
                const specifier = getModuleNameStringLiteralAt(importingSourceFile, reason.index).text;
                return preferences.relativePreference !== 1 /* NonRelative */ || !pathIsRelative(specifier) ? specifier : void 0;
            }));
            if (existingSpecifier) {
                const moduleSpecifiers = [existingSpecifier];
                return moduleSpecifiers;
            }
            const importedFileIsInNodeModules = some(modulePaths, (p) => p.isInNodeModules);
            let nodeModulesSpecifiers;
            let pathsSpecifiers;
            let redirectPathsSpecifiers;
            let relativeSpecifiers;
            for (const modulePath of modulePaths) {
                const specifier = modulePath.isInNodeModules ? tryGetModuleNameAsNodeModule(modulePath, info, importingSourceFile, host, compilerOptions, userPreferences, 
                /*packageNameOnly*/
                void 0, options.overrideImportMode) : void 0;
                nodeModulesSpecifiers = append(nodeModulesSpecifiers, specifier);
                if (specifier && modulePath.isRedirect) {
                    return nodeModulesSpecifiers;
                }
                if (!specifier) {
                    const local = getLocalModuleSpecifier(modulePath.path, info, compilerOptions, host, options.overrideImportMode || importingSourceFile.impliedNodeFormat, preferences, 
                    /*pathsOnly*/
                    modulePath.isRedirect);
                    if (!local) {
                        continue;
                    }
                    if (modulePath.isRedirect) {
                        redirectPathsSpecifiers = append(redirectPathsSpecifiers, local);
                    }
                    else if (pathIsBareSpecifier(local)) {
                        if (pathContainsNodeModules(local)) {
                            relativeSpecifiers = append(relativeSpecifiers, local);
                        }
                        else {
                            pathsSpecifiers = append(pathsSpecifiers, local);
                        }
                    }
                    else if (forAutoImport || !importedFileIsInNodeModules || modulePath.isInNodeModules) {
                        relativeSpecifiers = append(relativeSpecifiers, local);
                    }
                }
            }
            return (pathsSpecifiers == null ? void 0 : pathsSpecifiers.length) ? pathsSpecifiers : (redirectPathsSpecifiers == null ? void 0 : redirectPathsSpecifiers.length) ? redirectPathsSpecifiers : (nodeModulesSpecifiers == null ? void 0 : nodeModulesSpecifiers.length) ? nodeModulesSpecifiers : Debug.checkDefined(relativeSpecifiers);
        }
        function getInfo(importingSourceFileName, host) {
            importingSourceFileName = getNormalizedAbsolutePath(importingSourceFileName, host.getCurrentDirectory());
            const getCanonicalFileName = createGetCanonicalFileName(host.useCaseSensitiveFileNames ? host.useCaseSensitiveFileNames() : true);
            const sourceDirectory = getDirectoryPath(importingSourceFileName);
            return {
                getCanonicalFileName,
                importingSourceFileName,
                sourceDirectory,
                canonicalSourceDirectory: getCanonicalFileName(sourceDirectory)
            };
        }
        function getLocalModuleSpecifier(moduleFileName, info, compilerOptions, host, importMode, { getAllowedEndingsInPreferredOrder: getAllowedEndingsInPrefererredOrder, relativePreference }, pathsOnly) {
            const { baseUrl, paths, rootDirs } = compilerOptions;
            if (pathsOnly && !paths) {
                return void 0;
            }
            const { sourceDirectory, canonicalSourceDirectory, getCanonicalFileName } = info;
            const allowedEndings = getAllowedEndingsInPrefererredOrder(importMode);
            const relativePath = rootDirs && tryGetModuleNameFromRootDirs(rootDirs, moduleFileName, sourceDirectory, getCanonicalFileName, allowedEndings, compilerOptions) || processEnding(ensurePathIsNonModuleName(getRelativePathFromDirectory(sourceDirectory, moduleFileName, getCanonicalFileName)), allowedEndings, compilerOptions);
            if (!baseUrl && !paths && !getResolvePackageJsonImports(compilerOptions) || relativePreference === 0 /* Relative */) {
                return pathsOnly ? void 0 : relativePath;
            }
            const baseDirectory = getNormalizedAbsolutePath(getPathsBasePath(compilerOptions, host) || baseUrl, host.getCurrentDirectory());
            const relativeToBaseUrl = getRelativePathIfInSameVolume(moduleFileName, baseDirectory, getCanonicalFileName);
            if (!relativeToBaseUrl) {
                return pathsOnly ? void 0 : relativePath;
            }
            const fromPackageJsonImports = pathsOnly ? void 0 : tryGetModuleNameFromPackageJsonImports(moduleFileName, sourceDirectory, compilerOptions, host, importMode);
            const fromPaths = pathsOnly || fromPackageJsonImports === void 0 ? paths && tryGetModuleNameFromPaths(relativeToBaseUrl, paths, allowedEndings, host, compilerOptions) : void 0;
            if (pathsOnly) {
                return fromPaths;
            }
            const maybeNonRelative = fromPackageJsonImports ?? (fromPaths === void 0 && baseUrl !== void 0 ? processEnding(relativeToBaseUrl, allowedEndings, compilerOptions) : fromPaths);
            if (!maybeNonRelative) {
                return relativePath;
            }
            if (relativePreference === 1 /* NonRelative */ && !pathIsRelative(maybeNonRelative)) {
                return maybeNonRelative;
            }
            if (relativePreference === 3 /* ExternalNonRelative */ && !pathIsRelative(maybeNonRelative)) {
                const projectDirectory = compilerOptions.configFilePath ? toPath(getDirectoryPath(compilerOptions.configFilePath), host.getCurrentDirectory(), info.getCanonicalFileName) : info.getCanonicalFileName(host.getCurrentDirectory());
                const modulePath = toPath(moduleFileName, projectDirectory, getCanonicalFileName);
                const sourceIsInternal = startsWith(canonicalSourceDirectory, projectDirectory);
                const targetIsInternal = startsWith(modulePath, projectDirectory);
                if (sourceIsInternal && !targetIsInternal || !sourceIsInternal && targetIsInternal) {
                    return maybeNonRelative;
                }
                const nearestTargetPackageJson = getNearestAncestorDirectoryWithPackageJson(host, getDirectoryPath(modulePath));
                const nearestSourcePackageJson = getNearestAncestorDirectoryWithPackageJson(host, sourceDirectory);
                if (nearestSourcePackageJson !== nearestTargetPackageJson) {
                    return maybeNonRelative;
                }
                return relativePath;
            }
            return isPathRelativeToParent(maybeNonRelative) || countPathComponents(relativePath) < countPathComponents(maybeNonRelative) ? relativePath : maybeNonRelative;
        }
        function countPathComponents(path) {
            let count = 0;
            for (let i = startsWith(path, "./") ? 2 : 0; i < path.length; i++) {
                if (path.charCodeAt(i) === 47 /* slash */)
                    count++;
            }
            return count;
        }
        function comparePathsByRedirectAndNumberOfDirectorySeparators(a, b) {
            return compareBooleans(b.isRedirect, a.isRedirect) || compareNumberOfDirectorySeparators(a.path, b.path);
        }
        function getNearestAncestorDirectoryWithPackageJson(host, fileName) {
            if (host.getNearestAncestorDirectoryWithPackageJson) {
                return host.getNearestAncestorDirectoryWithPackageJson(fileName);
            }
            return forEachAncestorDirectory(fileName, (directory) => {
                return host.fileExists(combinePaths(directory, "package.json")) ? directory : void 0;
            });
        }
        function forEachFileNameOfModule(importingFileName, importedFileName, host, preferSymlinks, cb) {
            var _a;
            const getCanonicalFileName = hostGetCanonicalFileName(host);
            const cwd = host.getCurrentDirectory();
            const referenceRedirect = host.isSourceOfProjectReferenceRedirect(importedFileName) ? host.getProjectReferenceRedirect(importedFileName) : void 0;
            const importedPath = toPath(importedFileName, cwd, getCanonicalFileName);
            const redirects = host.redirectTargetsMap.get(importedPath) || emptyArray;
            const importedFileNames = [...referenceRedirect ? [referenceRedirect] : emptyArray, importedFileName, ...redirects];
            const targets = importedFileNames.map((f) => getNormalizedAbsolutePath(f, cwd));
            let shouldFilterIgnoredPaths = !every(targets, containsIgnoredPath);
            if (!preferSymlinks) {
                const result2 = forEach(targets, (p) => !(shouldFilterIgnoredPaths && containsIgnoredPath(p)) && cb(p, referenceRedirect === p));
                if (result2)
                    return result2;
            }
            const symlinkedDirectories = (_a = host.getSymlinkCache) == null ? void 0 : _a.call(host).getSymlinkedDirectoriesByRealpath();
            const fullImportedFileName = getNormalizedAbsolutePath(importedFileName, cwd);
            const result = symlinkedDirectories && forEachAncestorDirectory(getDirectoryPath(fullImportedFileName), (realPathDirectory) => {
                const symlinkDirectories = symlinkedDirectories.get(ensureTrailingDirectorySeparator(toPath(realPathDirectory, cwd, getCanonicalFileName)));
                if (!symlinkDirectories)
                    return void 0;
                if (startsWithDirectory(importingFileName, realPathDirectory, getCanonicalFileName)) {
                    return false;
                }
                return forEach(targets, (target) => {
                    if (!startsWithDirectory(target, realPathDirectory, getCanonicalFileName)) {
                        return;
                    }
                    const relative = getRelativePathFromDirectory(realPathDirectory, target, getCanonicalFileName);
                    for (const symlinkDirectory of symlinkDirectories) {
                        const option = resolvePath(symlinkDirectory, relative);
                        const result2 = cb(option, target === referenceRedirect);
                        shouldFilterIgnoredPaths = true;
                        if (result2)
                            return result2;
                    }
                });
            });
            return result || (preferSymlinks ? forEach(targets, (p) => shouldFilterIgnoredPaths && containsIgnoredPath(p) ? void 0 : cb(p, p === referenceRedirect)) : void 0);
        }
        function getAllModulePaths(info, importedFileName, host, preferences, options = {}) {
            var _a;
            const importingFilePath = toPath(info.importingSourceFileName, host.getCurrentDirectory(), hostGetCanonicalFileName(host));
            const importedFilePath = toPath(importedFileName, host.getCurrentDirectory(), hostGetCanonicalFileName(host));
            const cache = (_a = host.getModuleSpecifierCache) == null ? void 0 : _a.call(host);
            if (cache) {
                const cached = cache.get(importingFilePath, importedFilePath, preferences, options);
                if (cached == null ? void 0 : cached.modulePaths)
                    return cached.modulePaths;
            }
            const modulePaths = getAllModulePathsWorker(info, importedFileName, host);
            if (cache) {
                cache.setModulePaths(importingFilePath, importedFilePath, preferences, options, modulePaths);
            }
            return modulePaths;
        }
        function getAllModulePathsWorker(info, importedFileName, host) {
            const allFileNames = /* @__PURE__ */ new Map();
            let importedFileFromNodeModules = false;
            forEachFileNameOfModule(info.importingSourceFileName, importedFileName, host, 
            /*preferSymlinks*/
            true, (path, isRedirect) => {
                const isInNodeModules = pathContainsNodeModules(path);
                allFileNames.set(path, { path: info.getCanonicalFileName(path), isRedirect, isInNodeModules });
                importedFileFromNodeModules = importedFileFromNodeModules || isInNodeModules;
            });
            const sortedPaths = [];
            for (let directory = info.canonicalSourceDirectory; allFileNames.size !== 0;) {
                const directoryStart = ensureTrailingDirectorySeparator(directory);
                let pathsInDirectory;
                allFileNames.forEach(({ path, isRedirect, isInNodeModules }, fileName) => {
                    if (startsWith(path, directoryStart)) {
                        (pathsInDirectory || (pathsInDirectory = [])).push({ path: fileName, isRedirect, isInNodeModules });
                        allFileNames.delete(fileName);
                    }
                });
                if (pathsInDirectory) {
                    if (pathsInDirectory.length > 1) {
                        pathsInDirectory.sort(comparePathsByRedirectAndNumberOfDirectorySeparators);
                    }
                    sortedPaths.push(...pathsInDirectory);
                }
                const newDirectory = getDirectoryPath(directory);
                if (newDirectory === directory)
                    break;
                directory = newDirectory;
            }
            if (allFileNames.size) {
                const remainingPaths = arrayFrom(allFileNames.entries(), ([fileName, { isRedirect, isInNodeModules }]) => ({ path: fileName, isRedirect, isInNodeModules }));
                if (remainingPaths.length > 1)
                    remainingPaths.sort(comparePathsByRedirectAndNumberOfDirectorySeparators);
                sortedPaths.push(...remainingPaths);
            }
            return sortedPaths;
        }
        function tryGetModuleNameFromAmbientModule(moduleSymbol, checker) {
            var _a;
            const decl = (_a = moduleSymbol.declarations) == null ? void 0 : _a.find((d) => isNonGlobalAmbientModule(d) && (!isExternalModuleAugmentation(d) || !isExternalModuleNameRelative(getTextOfIdentifierOrLiteral(d.name))));
            if (decl) {
                return decl.name.text;
            }
            const ambientModuleDeclareCandidates = mapDefined(moduleSymbol.declarations, (d) => {
                var _a2, _b, _c, _d;
                if (!isModuleDeclaration(d))
                    return;
                const topNamespace = getTopNamespace(d);
                if (!(((_a2 = topNamespace == null ? void 0 : topNamespace.parent) == null ? void 0 : _a2.parent) && isModuleBlock(topNamespace.parent) && isAmbientModule(topNamespace.parent.parent) && isSourceFile(topNamespace.parent.parent.parent)))
                    return;
                const exportAssignment = (_d = (_c = (_b = topNamespace.parent.parent.symbol.exports) == null ? void 0 : _b.get("export=")) == null ? void 0 : _c.valueDeclaration) == null ? void 0 : _d.expression;
                if (!exportAssignment)
                    return;
                const exportSymbol = checker.getSymbolAtLocation(exportAssignment);
                if (!exportSymbol)
                    return;
                const originalExportSymbol = (exportSymbol == null ? void 0 : exportSymbol.flags) & 2097152 /* Alias */ ? checker.getAliasedSymbol(exportSymbol) : exportSymbol;
                if (originalExportSymbol === d.symbol)
                    return topNamespace.parent.parent;
                function getTopNamespace(namespaceDeclaration) {
                    while (namespaceDeclaration.flags & 8 /* NestedNamespace */) {
                        namespaceDeclaration = namespaceDeclaration.parent;
                    }
                    return namespaceDeclaration;
                }
            });
            const ambientModuleDeclare = ambientModuleDeclareCandidates[0];
            if (ambientModuleDeclare) {
                return ambientModuleDeclare.name.text;
            }
        }
        function tryGetModuleNameFromPaths(relativeToBaseUrl, paths, allowedEndings, host, compilerOptions) {
            for (const key in paths) {
                for (const patternText2 of paths[key]) {
                    const pattern = normalizePath(patternText2);
                    const indexOfStar = pattern.indexOf("*");
                    const candidates = allowedEndings.map((ending) => ({
                        ending,
                        value: processEnding(relativeToBaseUrl, [ending], compilerOptions)
                    }));
                    if (tryGetExtensionFromPath2(pattern)) {
                        candidates.push({ ending: void 0, value: relativeToBaseUrl });
                    }
                    if (indexOfStar !== -1) {
                        const prefix = pattern.substring(0, indexOfStar);
                        const suffix = pattern.substring(indexOfStar + 1);
                        for (const { ending, value } of candidates) {
                            if (value.length >= prefix.length + suffix.length && startsWith(value, prefix) && endsWith(value, suffix) && validateEnding({ ending, value })) {
                                const matchedStar = value.substring(prefix.length, value.length - suffix.length);
                                if (!pathIsRelative(matchedStar)) {
                                    return replaceFirstStar(key, matchedStar);
                                }
                            }
                        }
                    }
                    else if (some(candidates, (c) => c.ending !== 0 /* Minimal */ && pattern === c.value) || some(candidates, (c) => c.ending === 0 /* Minimal */ && pattern === c.value && validateEnding(c))) {
                        return key;
                    }
                }
            }
            function validateEnding({ ending, value }) {
                return ending !== 0 /* Minimal */ || value === processEnding(relativeToBaseUrl, [ending], compilerOptions, host);
            }
        }
        function tryGetModuleNameFromExportsOrImports(options, host, targetFilePath, packageDirectory, packageName, exports, conditions, mode, isImports) {
            if (typeof exports === "string") {
                const ignoreCase = !hostUsesCaseSensitiveFileNames(host);
                const getCommonSourceDirectory2 = () => host.getCommonSourceDirectory();
                const outputFile = isImports && getOutputJSFileNameWorker(targetFilePath, options, ignoreCase, getCommonSourceDirectory2);
                const declarationFile = isImports && getOutputDeclarationFileNameWorker(targetFilePath, options, ignoreCase, getCommonSourceDirectory2);
                const pathOrPattern = getNormalizedAbsolutePath(combinePaths(packageDirectory, exports), 
                /*currentDirectory*/
                void 0);
                const extensionSwappedTarget = hasTSFileExtension(targetFilePath) ? removeFileExtension(targetFilePath) + tryGetJSExtensionForFile(targetFilePath, options) : void 0;
                switch (mode) {
                    case 0 /* Exact */:
                        if (extensionSwappedTarget && comparePaths(extensionSwappedTarget, pathOrPattern, ignoreCase) === 0 /* EqualTo */ || comparePaths(targetFilePath, pathOrPattern, ignoreCase) === 0 /* EqualTo */ || outputFile && comparePaths(outputFile, pathOrPattern, ignoreCase) === 0 /* EqualTo */ || declarationFile && comparePaths(declarationFile, pathOrPattern, ignoreCase) === 0 /* EqualTo */) {
                            return { moduleFileToTry: packageName };
                        }
                        break;
                    case 1 /* Directory */:
                        if (extensionSwappedTarget && containsPath(pathOrPattern, extensionSwappedTarget, ignoreCase)) {
                            const fragment = getRelativePathFromDirectory(pathOrPattern, extensionSwappedTarget, 
                            /*ignoreCase*/
                            false);
                            return { moduleFileToTry: getNormalizedAbsolutePath(combinePaths(combinePaths(packageName, exports), fragment), 
                                /*currentDirectory*/
                                void 0) };
                        }
                        if (containsPath(pathOrPattern, targetFilePath, ignoreCase)) {
                            const fragment = getRelativePathFromDirectory(pathOrPattern, targetFilePath, 
                            /*ignoreCase*/
                            false);
                            return { moduleFileToTry: getNormalizedAbsolutePath(combinePaths(combinePaths(packageName, exports), fragment), 
                                /*currentDirectory*/
                                void 0) };
                        }
                        if (outputFile && containsPath(pathOrPattern, outputFile, ignoreCase)) {
                            const fragment = getRelativePathFromDirectory(pathOrPattern, outputFile, 
                            /*ignoreCase*/
                            false);
                            return { moduleFileToTry: combinePaths(packageName, fragment) };
                        }
                        if (declarationFile && containsPath(pathOrPattern, declarationFile, ignoreCase)) {
                            const fragment = getRelativePathFromDirectory(pathOrPattern, declarationFile, 
                            /*ignoreCase*/
                            false);
                            return { moduleFileToTry: combinePaths(packageName, fragment) };
                        }
                        break;
                    case 2 /* Pattern */:
                        const starPos = pathOrPattern.indexOf("*");
                        const leadingSlice = pathOrPattern.slice(0, starPos);
                        const trailingSlice = pathOrPattern.slice(starPos + 1);
                        if (extensionSwappedTarget && startsWith(extensionSwappedTarget, leadingSlice, ignoreCase) && endsWith(extensionSwappedTarget, trailingSlice, ignoreCase)) {
                            const starReplacement = extensionSwappedTarget.slice(leadingSlice.length, extensionSwappedTarget.length - trailingSlice.length);
                            return { moduleFileToTry: replaceFirstStar(packageName, starReplacement) };
                        }
                        if (startsWith(targetFilePath, leadingSlice, ignoreCase) && endsWith(targetFilePath, trailingSlice, ignoreCase)) {
                            const starReplacement = targetFilePath.slice(leadingSlice.length, targetFilePath.length - trailingSlice.length);
                            return { moduleFileToTry: replaceFirstStar(packageName, starReplacement) };
                        }
                        if (outputFile && startsWith(outputFile, leadingSlice, ignoreCase) && endsWith(outputFile, trailingSlice, ignoreCase)) {
                            const starReplacement = outputFile.slice(leadingSlice.length, outputFile.length - trailingSlice.length);
                            return { moduleFileToTry: replaceFirstStar(packageName, starReplacement) };
                        }
                        if (declarationFile && startsWith(declarationFile, leadingSlice, ignoreCase) && endsWith(declarationFile, trailingSlice, ignoreCase)) {
                            const starReplacement = declarationFile.slice(leadingSlice.length, declarationFile.length - trailingSlice.length);
                            return { moduleFileToTry: replaceFirstStar(packageName, starReplacement) };
                        }
                        break;
                }
            }
            else if (Array.isArray(exports)) {
                return forEach(exports, (e) => tryGetModuleNameFromExportsOrImports(options, host, targetFilePath, packageDirectory, packageName, e, conditions, mode, isImports));
            }
            else if (typeof exports === "object" && exports !== null) {
                for (const key of getOwnKeys(exports)) {
                    if (key === "default" || conditions.indexOf(key) >= 0 || isApplicableVersionedTypesKey(conditions, key)) {
                        const subTarget = exports[key];
                        const result = tryGetModuleNameFromExportsOrImports(options, host, targetFilePath, packageDirectory, packageName, subTarget, conditions, mode, isImports);
                        if (result) {
                            return result;
                        }
                    }
                }
            }
            return void 0;
        }
        function tryGetModuleNameFromExports(options, host, targetFilePath, packageDirectory, packageName, exports, conditions) {
            if (typeof exports === "object" && exports !== null && !Array.isArray(exports) && allKeysStartWithDot(exports)) {
                return forEach(getOwnKeys(exports), (k) => {
                    const subPackageName = getNormalizedAbsolutePath(combinePaths(packageName, k), 
                    /*currentDirectory*/
                    void 0);
                    const mode = endsWith(k, "/") ? 1 /* Directory */ : k.includes("*") ? 2 /* Pattern */ : 0 /* Exact */;
                    return tryGetModuleNameFromExportsOrImports(options, host, targetFilePath, packageDirectory, subPackageName, exports[k], conditions, mode, 
                    /*isImports*/
                    false);
                });
            }
            return tryGetModuleNameFromExportsOrImports(options, host, targetFilePath, packageDirectory, packageName, exports, conditions, 0 /* Exact */, 
            /*isImports*/
            false);
        }
        function tryGetModuleNameFromPackageJsonImports(moduleFileName, sourceDirectory, options, host, importMode) {
            var _a, _b, _c;
            if (!host.readFile || !getResolvePackageJsonImports(options)) {
                return void 0;
            }
            const ancestorDirectoryWithPackageJson = getNearestAncestorDirectoryWithPackageJson(host, sourceDirectory);
            if (!ancestorDirectoryWithPackageJson) {
                return void 0;
            }
            const packageJsonPath = combinePaths(ancestorDirectoryWithPackageJson, "package.json");
            const cachedPackageJson = (_b = (_a = host.getPackageJsonInfoCache) == null ? void 0 : _a.call(host)) == null ? void 0 : _b.getPackageJsonInfo(packageJsonPath);
            if (isMissingPackageJsonInfo(cachedPackageJson) || !host.fileExists(packageJsonPath)) {
                return void 0;
            }
            const packageJsonContent = (cachedPackageJson == null ? void 0 : cachedPackageJson.contents.packageJsonContent) || tryParseJson(host.readFile(packageJsonPath));
            const imports = packageJsonContent == null ? void 0 : packageJsonContent.imports;
            if (!imports) {
                return void 0;
            }
            const conditions = getConditions(options, importMode);
            return (_c = forEach(getOwnKeys(imports), (k) => {
                if (!startsWith(k, "#") || k === "#" || startsWith(k, "#/"))
                    return void 0;
                const mode = endsWith(k, "/") ? 1 /* Directory */ : k.includes("*") ? 2 /* Pattern */ : 0 /* Exact */;
                return tryGetModuleNameFromExportsOrImports(options, host, moduleFileName, ancestorDirectoryWithPackageJson, k, imports[k], conditions, mode, 
                /*isImports*/
                true);
            })) == null ? void 0 : _c.moduleFileToTry;
        }
        function tryGetModuleNameFromRootDirs(rootDirs, moduleFileName, sourceDirectory, getCanonicalFileName, allowedEndings, compilerOptions) {
            const normalizedTargetPaths = getPathsRelativeToRootDirs(moduleFileName, rootDirs, getCanonicalFileName);
            if (normalizedTargetPaths === void 0) {
                return void 0;
            }
            const normalizedSourcePaths = getPathsRelativeToRootDirs(sourceDirectory, rootDirs, getCanonicalFileName);
            const relativePaths = flatMap(normalizedSourcePaths, (sourcePath) => {
                return map(normalizedTargetPaths, (targetPath) => ensurePathIsNonModuleName(getRelativePathFromDirectory(sourcePath, targetPath, getCanonicalFileName)));
            });
            const shortest = min(relativePaths, compareNumberOfDirectorySeparators);
            if (!shortest) {
                return void 0;
            }
            return processEnding(shortest, allowedEndings, compilerOptions);
        }
        function tryGetModuleNameAsNodeModule({ path, isRedirect }, { getCanonicalFileName, canonicalSourceDirectory }, importingSourceFile, host, options, userPreferences, packageNameOnly, overrideMode) {
            if (!host.fileExists || !host.readFile) {
                return void 0;
            }
            const parts = getNodeModulePathParts(path);
            if (!parts) {
                return void 0;
            }
            const preferences = getModuleSpecifierPreferences(userPreferences, options, importingSourceFile);
            const allowedEndings = preferences.getAllowedEndingsInPreferredOrder();
            let moduleSpecifier = path;
            let isPackageRootPath = false;
            if (!packageNameOnly) {
                let packageRootIndex = parts.packageRootIndex;
                let moduleFileName;
                while (true) {
                    const { moduleFileToTry, packageRootPath, blockedByExports, verbatimFromExports } = tryDirectoryWithPackageJson(packageRootIndex);
                    if (getEmitModuleResolutionKind(options) !== 1 /* Classic */) {
                        if (blockedByExports) {
                            return void 0;
                        }
                        if (verbatimFromExports) {
                            return moduleFileToTry;
                        }
                    }
                    if (packageRootPath) {
                        moduleSpecifier = packageRootPath;
                        isPackageRootPath = true;
                        break;
                    }
                    if (!moduleFileName)
                        moduleFileName = moduleFileToTry;
                    packageRootIndex = path.indexOf(directorySeparator, packageRootIndex + 1);
                    if (packageRootIndex === -1) {
                        moduleSpecifier = processEnding(moduleFileName, allowedEndings, options, host);
                        break;
                    }
                }
            }
            if (isRedirect && !isPackageRootPath) {
                return void 0;
            }
            const globalTypingsCacheLocation = host.getGlobalTypingsCacheLocation && host.getGlobalTypingsCacheLocation();
            const pathToTopLevelNodeModules = getCanonicalFileName(moduleSpecifier.substring(0, parts.topLevelNodeModulesIndex));
            if (!(startsWith(canonicalSourceDirectory, pathToTopLevelNodeModules) || globalTypingsCacheLocation && startsWith(getCanonicalFileName(globalTypingsCacheLocation), pathToTopLevelNodeModules))) {
                return void 0;
            }
            const nodeModulesDirectoryName = moduleSpecifier.substring(parts.topLevelPackageNameIndex + 1);
            const packageName = getPackageNameFromTypesPackageName(nodeModulesDirectoryName);
            return getEmitModuleResolutionKind(options) === 1 /* Classic */ && packageName === nodeModulesDirectoryName ? void 0 : packageName;
            function tryDirectoryWithPackageJson(packageRootIndex) {
                var _a, _b;
                const packageRootPath = path.substring(0, packageRootIndex);
                const packageJsonPath = combinePaths(packageRootPath, "package.json");
                let moduleFileToTry = path;
                let maybeBlockedByTypesVersions = false;
                const cachedPackageJson = (_b = (_a = host.getPackageJsonInfoCache) == null ? void 0 : _a.call(host)) == null ? void 0 : _b.getPackageJsonInfo(packageJsonPath);
                if (isPackageJsonInfo(cachedPackageJson) || cachedPackageJson === void 0 && host.fileExists(packageJsonPath)) {
                    const packageJsonContent = (cachedPackageJson == null ? void 0 : cachedPackageJson.contents.packageJsonContent) || tryParseJson(host.readFile(packageJsonPath));
                    const importMode = overrideMode || importingSourceFile.impliedNodeFormat;
                    if (getResolvePackageJsonExports(options)) {
                        const nodeModulesDirectoryName2 = packageRootPath.substring(parts.topLevelPackageNameIndex + 1);
                        const packageName2 = getPackageNameFromTypesPackageName(nodeModulesDirectoryName2);
                        const conditions = getConditions(options, importMode);
                        const fromExports = (packageJsonContent == null ? void 0 : packageJsonContent.exports) ? tryGetModuleNameFromExports(options, host, path, packageRootPath, packageName2, packageJsonContent.exports, conditions) : void 0;
                        if (fromExports) {
                            return { ...fromExports, verbatimFromExports: true };
                        }
                        if (packageJsonContent == null ? void 0 : packageJsonContent.exports) {
                            return { moduleFileToTry: path, blockedByExports: true };
                        }
                    }
                    const versionPaths = (packageJsonContent == null ? void 0 : packageJsonContent.typesVersions) ? getPackageJsonTypesVersionsPaths(packageJsonContent.typesVersions) : void 0;
                    if (versionPaths) {
                        const subModuleName = path.slice(packageRootPath.length + 1);
                        const fromPaths = tryGetModuleNameFromPaths(subModuleName, versionPaths.paths, allowedEndings, host, options);
                        if (fromPaths === void 0) {
                            maybeBlockedByTypesVersions = true;
                        }
                        else {
                            moduleFileToTry = combinePaths(packageRootPath, fromPaths);
                        }
                    }
                    const mainFileRelative = (packageJsonContent == null ? void 0 : packageJsonContent.typings) || (packageJsonContent == null ? void 0 : packageJsonContent.types) || (packageJsonContent == null ? void 0 : packageJsonContent.main) || "index.js";
                    if (isString(mainFileRelative) && !(maybeBlockedByTypesVersions && matchPatternOrExact(tryParsePatterns(versionPaths.paths), mainFileRelative))) {
                        const mainExportFile = toPath(mainFileRelative, packageRootPath, getCanonicalFileName);
                        const canonicalModuleFileToTry = getCanonicalFileName(moduleFileToTry);
                        if (removeFileExtension(mainExportFile) === removeFileExtension(canonicalModuleFileToTry)) {
                            return { packageRootPath, moduleFileToTry };
                        }
                        else if ((packageJsonContent == null ? void 0 : packageJsonContent.type) !== "module" && !fileExtensionIsOneOf(canonicalModuleFileToTry, extensionsNotSupportingExtensionlessResolution) && startsWith(canonicalModuleFileToTry, mainExportFile) && getDirectoryPath(canonicalModuleFileToTry) === removeTrailingDirectorySeparator(mainExportFile) && removeFileExtension(getBaseFileName(canonicalModuleFileToTry)) === "index") {
                            return { packageRootPath, moduleFileToTry };
                        }
                    }
                }
                else {
                    const fileName = getCanonicalFileName(moduleFileToTry.substring(parts.packageRootIndex + 1));
                    if (fileName === "index.d.ts" || fileName === "index.js" || fileName === "index.ts" || fileName === "index.tsx") {
                        return { moduleFileToTry, packageRootPath };
                    }
                }
                return { moduleFileToTry };
            }
        }
        function tryGetAnyFileFromPath(host, path) {
            if (!host.fileExists)
                return;
            const extensions = flatten(getSupportedExtensions({ allowJs: true }, [{ extension: "node", isMixedContent: false }, { extension: "json", isMixedContent: false, scriptKind: 6 /* JSON */ }]));
            for (const e of extensions) {
                const fullPath = path + e;
                if (host.fileExists(fullPath)) {
                    return fullPath;
                }
            }
        }
        function getPathsRelativeToRootDirs(path, rootDirs, getCanonicalFileName) {
            return mapDefined(rootDirs, (rootDir) => {
                const relativePath = getRelativePathIfInSameVolume(path, rootDir, getCanonicalFileName);
                return relativePath !== void 0 && isPathRelativeToParent(relativePath) ? void 0 : relativePath;
            });
        }
        function processEnding(fileName, allowedEndings, options, host) {
            if (fileExtensionIsOneOf(fileName, [".json" /* Json */, ".mjs" /* Mjs */, ".cjs" /* Cjs */])) {
                return fileName;
            }
            const noExtension = removeFileExtension(fileName);
            if (fileName === noExtension) {
                return fileName;
            }
            const jsPriority = allowedEndings.indexOf(2 /* JsExtension */);
            const tsPriority = allowedEndings.indexOf(3 /* TsExtension */);
            if (fileExtensionIsOneOf(fileName, [".mts" /* Mts */, ".cts" /* Cts */]) && tsPriority !== -1 && tsPriority < jsPriority) {
                return fileName;
            }
            else if (fileExtensionIsOneOf(fileName, [".d.mts" /* Dmts */, ".mts" /* Mts */, ".d.cts" /* Dcts */, ".cts" /* Cts */])) {
                return noExtension + getJSExtensionForFile(fileName, options);
            }
            else if (!fileExtensionIsOneOf(fileName, [".d.ts" /* Dts */]) && fileExtensionIsOneOf(fileName, [".ts" /* Ts */]) && fileName.includes(".d.")) {
                return tryGetRealFileNameForNonJsDeclarationFileName(fileName);
            }
            switch (allowedEndings[0]) {
                case 0 /* Minimal */:
                    const withoutIndex = removeSuffix(noExtension, "/index");
                    if (host && withoutIndex !== noExtension && tryGetAnyFileFromPath(host, withoutIndex)) {
                        return noExtension;
                    }
                    return withoutIndex;
                case 1 /* Index */:
                    return noExtension;
                case 2 /* JsExtension */:
                    return noExtension + getJSExtensionForFile(fileName, options);
                case 3 /* TsExtension */:
                    if (isDeclarationFileName(fileName)) {
                        const extensionlessPriority = allowedEndings.findIndex((e) => e === 0 /* Minimal */ || e === 1 /* Index */);
                        return extensionlessPriority !== -1 && extensionlessPriority < jsPriority ? noExtension : noExtension + getJSExtensionForFile(fileName, options);
                    }
                    return fileName;
                default:
                    return Debug.assertNever(allowedEndings[0]);
            }
        }
        function tryGetRealFileNameForNonJsDeclarationFileName(fileName) {
            const baseName = getBaseFileName(fileName);
            if (!endsWith(fileName, ".ts" /* Ts */) || !baseName.includes(".d.") || fileExtensionIsOneOf(baseName, [".d.ts" /* Dts */]))
                return void 0;
            const noExtension = removeExtension(fileName, ".ts" /* Ts */);
            const ext = noExtension.substring(noExtension.lastIndexOf("."));
            return noExtension.substring(0, noExtension.indexOf(".d.")) + ext;
        }
        function getJSExtensionForFile(fileName, options) {
            return tryGetJSExtensionForFile(fileName, options) ?? Debug.fail(`Extension ${extensionFromPath(fileName)} is unsupported:: FileName:: ${fileName}`);
        }
        function tryGetJSExtensionForFile(fileName, options) {
            const ext = tryGetExtensionFromPath2(fileName);
            switch (ext) {
                case ".ts" /* Ts */:
                case ".d.ts" /* Dts */:
                    return ".js" /* Js */;
                case ".tsx" /* Tsx */:
                    return options.jsx === 1 /* Preserve */ ? ".jsx" /* Jsx */ : ".js" /* Js */;
                case ".js" /* Js */:
                case ".jsx" /* Jsx */:
                case ".json" /* Json */:
                    return ext;
                case ".d.mts" /* Dmts */:
                case ".mts" /* Mts */:
                case ".mjs" /* Mjs */:
                    return ".mjs" /* Mjs */;
                case ".d.cts" /* Dcts */:
                case ".cts" /* Cts */:
                case ".cjs" /* Cjs */:
                    return ".cjs" /* Cjs */;
                default:
                    return void 0;
            }
        }
        function getRelativePathIfInSameVolume(path, directoryPath, getCanonicalFileName) {
            const relativePath = getRelativePathToDirectoryOrUrl(directoryPath, path, directoryPath, getCanonicalFileName, 
            /*isAbsolutePathAnUrl*/
            false);
            return isRootedDiskPath(relativePath) ? void 0 : relativePath;
        }
        function isPathRelativeToParent(path) {
            return startsWith(path, "..");
        }
        var RelativePreference;
        var init_moduleSpecifiers = __esm({
            "src/compiler/moduleSpecifiers.ts"() {
                "use strict";
                init_ts2();
                RelativePreference = /* @__PURE__ */ ((RelativePreference2) => {
                    RelativePreference2[RelativePreference2["Relative"] = 0] = "Relative";
                    RelativePreference2[RelativePreference2["NonRelative"] = 1] = "NonRelative";
                    RelativePreference2[RelativePreference2["Shortest"] = 2] = "Shortest";
                    RelativePreference2[RelativePreference2["ExternalNonRelative"] = 3] = "ExternalNonRelative";
                    return RelativePreference2;
                })(RelativePreference || {});
            }
        });
        // src/compiler/_namespaces/ts.moduleSpecifiers.ts
        var ts_moduleSpecifiers_exports = {};
        __export(ts_moduleSpecifiers_exports, {
            RelativePreference: () => RelativePreference,
            countPathComponents: () => countPathComponents,
            forEachFileNameOfModule: () => forEachFileNameOfModule,
            getModuleSpecifier: () => getModuleSpecifier,
            getModuleSpecifierPreferences: () => getModuleSpecifierPreferences,
            getModuleSpecifiers: () => getModuleSpecifiers,
            getModuleSpecifiersWithCacheInfo: () => getModuleSpecifiersWithCacheInfo,
            getNodeModulesPackageName: () => getNodeModulesPackageName,
            tryGetJSExtensionForFile: () => tryGetJSExtensionForFile,
            tryGetModuleSpecifiersFromCache: () => tryGetModuleSpecifiersFromCache,
            tryGetRealFileNameForNonJsDeclarationFileName: () => tryGetRealFileNameForNonJsDeclarationFileName,
            updateModuleSpecifier: () => updateModuleSpecifier
        });
        var init_ts_moduleSpecifiers = __esm({
            "src/compiler/_namespaces/ts.moduleSpecifiers.ts"() {
                "use strict";
                init_moduleSpecifiers();
            }
        });
        // src/compiler/checker.ts
        function NodeLinks() {
            this.flags = 0 /* None */;
        }
        function getNodeId(node) {
            if (!node.id) {
                node.id = nextNodeId;
                nextNodeId++;
            }
            return node.id;
        }
        function getSymbolId(symbol) {
            if (!symbol.id) {
                symbol.id = nextSymbolId;
                nextSymbolId++;
            }
            return symbol.id;
        }
        function isInstantiatedModule(node, preserveConstEnums) {
            const moduleState = getModuleInstanceState(node);
            return moduleState === 1 /* Instantiated */ || preserveConstEnums && moduleState === 2 /* ConstEnumOnly */;
        }
        function createTypeChecker(host) {
            var deferredDiagnosticsCallbacks = [];
            var addLazyDiagnostic = (arg) => {
                deferredDiagnosticsCallbacks.push(arg);
            };
            var cancellationToken;
            var requestedExternalEmitHelperNames = /* @__PURE__ */ new Set();
            var requestedExternalEmitHelpers;
            var externalHelpersModule;
            var Symbol47 = objectAllocator.getSymbolConstructor();
            var Type28 = objectAllocator.getTypeConstructor();
            var Signature14 = objectAllocator.getSignatureConstructor();
            var typeCount = 0;
            var symbolCount = 0;
            var totalInstantiationCount = 0;
            var instantiationCount = 0;
            var instantiationDepth = 0;
            var inlineLevel = 0;
            var currentNode;
            var varianceTypeParameter;
            var isInferencePartiallyBlocked = false;
            var emptySymbols = createSymbolTable();
            var arrayVariances = [1 /* Covariant */];
            var compilerOptions = host.getCompilerOptions();
            var languageVersion = getEmitScriptTarget(compilerOptions);
            var moduleKind = getEmitModuleKind(compilerOptions);
            var legacyDecorators = !!compilerOptions.experimentalDecorators;
            var useDefineForClassFields = getUseDefineForClassFields(compilerOptions);
            var emitStandardClassFields = getEmitStandardClassFields(compilerOptions);
            var allowSyntheticDefaultImports = getAllowSyntheticDefaultImports(compilerOptions);
            var strictNullChecks = getStrictOptionValue(compilerOptions, "strictNullChecks");
            var strictFunctionTypes = getStrictOptionValue(compilerOptions, "strictFunctionTypes");
            var strictBindCallApply = getStrictOptionValue(compilerOptions, "strictBindCallApply");
            var strictPropertyInitialization = getStrictOptionValue(compilerOptions, "strictPropertyInitialization");
            var noImplicitAny = getStrictOptionValue(compilerOptions, "noImplicitAny");
            var noImplicitThis = getStrictOptionValue(compilerOptions, "noImplicitThis");
            var useUnknownInCatchVariables = getStrictOptionValue(compilerOptions, "useUnknownInCatchVariables");
            var keyofStringsOnly = !!compilerOptions.keyofStringsOnly;
            var defaultIndexFlags = keyofStringsOnly ? 1 /* StringsOnly */ : 0 /* None */;
            var freshObjectLiteralFlag = compilerOptions.suppressExcessPropertyErrors ? 0 : 8192 /* FreshLiteral */;
            var exactOptionalPropertyTypes = compilerOptions.exactOptionalPropertyTypes;
            var checkBinaryExpression = createCheckBinaryExpression();
            var emitResolver = createResolver();
            var nodeBuilder = createNodeBuilder();
            var globals = createSymbolTable();
            var undefinedSymbol = createSymbol(4 /* Property */, "undefined");
            undefinedSymbol.declarations = [];
            var globalThisSymbol = createSymbol(1536 /* Module */, "globalThis", 8 /* Readonly */);
            globalThisSymbol.exports = globals;
            globalThisSymbol.declarations = [];
            globals.set(globalThisSymbol.escapedName, globalThisSymbol);
            var argumentsSymbol = createSymbol(4 /* Property */, "arguments");
            var requireSymbol = createSymbol(4 /* Property */, "require");
            var isolatedModulesLikeFlagName = compilerOptions.verbatimModuleSyntax ? "verbatimModuleSyntax" : "isolatedModules";
            var canCollectSymbolAliasAccessabilityData = !compilerOptions.verbatimModuleSyntax || !!compilerOptions.importsNotUsedAsValues;
            var apparentArgumentCount;
            var lastGetCombinedNodeFlagsNode;
            var lastGetCombinedNodeFlagsResult = 0 /* None */;
            var lastGetCombinedModifierFlagsNode;
            var lastGetCombinedModifierFlagsResult = 0 /* None */;
            const checker = {
                getNodeCount: () => reduceLeft(host.getSourceFiles(), (n, s) => n + s.nodeCount, 0),
                getIdentifierCount: () => reduceLeft(host.getSourceFiles(), (n, s) => n + s.identifierCount, 0),
                getSymbolCount: () => reduceLeft(host.getSourceFiles(), (n, s) => n + s.symbolCount, symbolCount),
                getTypeCount: () => typeCount,
                getInstantiationCount: () => totalInstantiationCount,
                getRelationCacheSizes: () => ({
                    assignable: assignableRelation.size,
                    identity: identityRelation.size,
                    subtype: subtypeRelation.size,
                    strictSubtype: strictSubtypeRelation.size
                }),
                isUndefinedSymbol: (symbol) => symbol === undefinedSymbol,
                isArgumentsSymbol: (symbol) => symbol === argumentsSymbol,
                isUnknownSymbol: (symbol) => symbol === unknownSymbol,
                getMergedSymbol,
                getDiagnostics: getDiagnostics2,
                getGlobalDiagnostics,
                getRecursionIdentity,
                getUnmatchedProperties,
                getTypeOfSymbolAtLocation: (symbol, locationIn) => {
                    const location = getParseTreeNode(locationIn);
                    return location ? getTypeOfSymbolAtLocation(symbol, location) : errorType;
                },
                getTypeOfSymbol,
                getSymbolsOfParameterPropertyDeclaration: (parameterIn, parameterName) => {
                    const parameter = getParseTreeNode(parameterIn, isParameter);
                    if (parameter === void 0)
                        return Debug.fail("Cannot get symbols of a synthetic parameter that cannot be resolved to a parse-tree node.");
                    Debug.assert(isParameterPropertyDeclaration(parameter, parameter.parent));
                    return getSymbolsOfParameterPropertyDeclaration(parameter, escapeLeadingUnderscores(parameterName));
                },
                getDeclaredTypeOfSymbol,
                getPropertiesOfType,
                getPropertyOfType: (type, name) => getPropertyOfType(type, escapeLeadingUnderscores(name)),
                getPrivateIdentifierPropertyOfType: (leftType, name, location) => {
                    const node = getParseTreeNode(location);
                    if (!node) {
                        return void 0;
                    }
                    const propName = escapeLeadingUnderscores(name);
                    const lexicallyScopedIdentifier = lookupSymbolForPrivateIdentifierDeclaration(propName, node);
                    return lexicallyScopedIdentifier ? getPrivateIdentifierPropertyOfType(leftType, lexicallyScopedIdentifier) : void 0;
                },
                getTypeOfPropertyOfType: (type, name) => getTypeOfPropertyOfType(type, escapeLeadingUnderscores(name)),
                getIndexInfoOfType: (type, kind) => getIndexInfoOfType(type, kind === 0 /* String */ ? stringType : numberType),
                getIndexInfosOfType,
                getIndexInfosOfIndexSymbol,
                getSignaturesOfType,
                getIndexTypeOfType: (type, kind) => getIndexTypeOfType(type, kind === 0 /* String */ ? stringType : numberType),
                getIndexType: (type) => getIndexType(type),
                getBaseTypes,
                getBaseTypeOfLiteralType,
                getWidenedType,
                getTypeFromTypeNode: (nodeIn) => {
                    const node = getParseTreeNode(nodeIn, isTypeNode);
                    return node ? getTypeFromTypeNode(node) : errorType;
                },
                getParameterType: getTypeAtPosition,
                getParameterIdentifierInfoAtPosition,
                getPromisedTypeOfPromise,
                getAwaitedType: (type) => getAwaitedType(type),
                getReturnTypeOfSignature,
                isNullableType,
                getNullableType,
                getNonNullableType,
                getNonOptionalType: removeOptionalTypeMarker,
                getTypeArguments,
                typeToTypeNode: nodeBuilder.typeToTypeNode,
                indexInfoToIndexSignatureDeclaration: nodeBuilder.indexInfoToIndexSignatureDeclaration,
                signatureToSignatureDeclaration: nodeBuilder.signatureToSignatureDeclaration,
                symbolToEntityName: nodeBuilder.symbolToEntityName,
                symbolToExpression: nodeBuilder.symbolToExpression,
                symbolToNode: nodeBuilder.symbolToNode,
                symbolToTypeParameterDeclarations: nodeBuilder.symbolToTypeParameterDeclarations,
                symbolToParameterDeclaration: nodeBuilder.symbolToParameterDeclaration,
                typeParameterToDeclaration: nodeBuilder.typeParameterToDeclaration,
                getSymbolsInScope: (locationIn, meaning) => {
                    const location = getParseTreeNode(locationIn);
                    return location ? getSymbolsInScope(location, meaning) : [];
                },
                getSymbolAtLocation: (nodeIn) => {
                    const node = getParseTreeNode(nodeIn);
                    return node ? getSymbolAtLocation(node, 
                    /*ignoreErrors*/
                    true) : void 0;
                },
                getIndexInfosAtLocation: (nodeIn) => {
                    const node = getParseTreeNode(nodeIn);
                    return node ? getIndexInfosAtLocation(node) : void 0;
                },
                getShorthandAssignmentValueSymbol: (nodeIn) => {
                    const node = getParseTreeNode(nodeIn);
                    return node ? getShorthandAssignmentValueSymbol(node) : void 0;
                },
                getExportSpecifierLocalTargetSymbol: (nodeIn) => {
                    const node = getParseTreeNode(nodeIn, isExportSpecifier);
                    return node ? getExportSpecifierLocalTargetSymbol(node) : void 0;
                },
                getExportSymbolOfSymbol(symbol) {
                    return getMergedSymbol(symbol.exportSymbol || symbol);
                },
                getTypeAtLocation: (nodeIn) => {
                    const node = getParseTreeNode(nodeIn);
                    return node ? getTypeOfNode(node) : errorType;
                },
                getTypeOfAssignmentPattern: (nodeIn) => {
                    const node = getParseTreeNode(nodeIn, isAssignmentPattern);
                    return node && getTypeOfAssignmentPattern(node) || errorType;
                },
                getPropertySymbolOfDestructuringAssignment: (locationIn) => {
                    const location = getParseTreeNode(locationIn, isIdentifier);
                    return location ? getPropertySymbolOfDestructuringAssignment(location) : void 0;
                },
                signatureToString: (signature, enclosingDeclaration, flags, kind) => {
                    return signatureToString(signature, getParseTreeNode(enclosingDeclaration), flags, kind);
                },
                typeToString: (type, enclosingDeclaration, flags) => {
                    return typeToString(type, getParseTreeNode(enclosingDeclaration), flags);
                },
                symbolToString: (symbol, enclosingDeclaration, meaning, flags) => {
                    return symbolToString(symbol, getParseTreeNode(enclosingDeclaration), meaning, flags);
                },
                typePredicateToString: (predicate, enclosingDeclaration, flags) => {
                    return typePredicateToString(predicate, getParseTreeNode(enclosingDeclaration), flags);
                },
                writeSignature: (signature, enclosingDeclaration, flags, kind, writer) => {
                    return signatureToString(signature, getParseTreeNode(enclosingDeclaration), flags, kind, writer);
                },
                writeType: (type, enclosingDeclaration, flags, writer) => {
                    return typeToString(type, getParseTreeNode(enclosingDeclaration), flags, writer);
                },
                writeSymbol: (symbol, enclosingDeclaration, meaning, flags, writer) => {
                    return symbolToString(symbol, getParseTreeNode(enclosingDeclaration), meaning, flags, writer);
                },
                writeTypePredicate: (predicate, enclosingDeclaration, flags, writer) => {
                    return typePredicateToString(predicate, getParseTreeNode(enclosingDeclaration), flags, writer);
                },
                getAugmentedPropertiesOfType,
                getRootSymbols,
                getSymbolOfExpando,
                getContextualType: (nodeIn, contextFlags) => {
                    const node = getParseTreeNode(nodeIn, isExpression);
                    if (!node) {
                        return void 0;
                    }
                    if (contextFlags & 4 /* Completions */) {
                        return runWithInferenceBlockedFromSourceNode(node, () => getContextualType2(node, contextFlags));
                    }
                    return getContextualType2(node, contextFlags);
                },
                getContextualTypeForObjectLiteralElement: (nodeIn) => {
                    const node = getParseTreeNode(nodeIn, isObjectLiteralElementLike);
                    return node ? getContextualTypeForObjectLiteralElement(node, 
                    /*contextFlags*/
                    void 0) : void 0;
                },
                getContextualTypeForArgumentAtIndex: (nodeIn, argIndex) => {
                    const node = getParseTreeNode(nodeIn, isCallLikeExpression);
                    return node && getContextualTypeForArgumentAtIndex(node, argIndex);
                },
                getContextualTypeForJsxAttribute: (nodeIn) => {
                    const node = getParseTreeNode(nodeIn, isJsxAttributeLike);
                    return node && getContextualTypeForJsxAttribute(node, 
                    /*contextFlags*/
                    void 0);
                },
                isContextSensitive,
                getTypeOfPropertyOfContextualType,
                getFullyQualifiedName,
                getResolvedSignature: (node, candidatesOutArray, argumentCount) => getResolvedSignatureWorker(node, candidatesOutArray, argumentCount, 0 /* Normal */),
                getCandidateSignaturesForStringLiteralCompletions,
                getResolvedSignatureForSignatureHelp: (node, candidatesOutArray, argumentCount) => runWithoutResolvedSignatureCaching(node, () => getResolvedSignatureWorker(node, candidatesOutArray, argumentCount, 16 /* IsForSignatureHelp */)),
                getExpandedParameters,
                hasEffectiveRestParameter,
                containsArgumentsReference,
                getConstantValue: (nodeIn) => {
                    const node = getParseTreeNode(nodeIn, canHaveConstantValue);
                    return node ? getConstantValue2(node) : void 0;
                },
                isValidPropertyAccess: (nodeIn, propertyName) => {
                    const node = getParseTreeNode(nodeIn, isPropertyAccessOrQualifiedNameOrImportTypeNode);
                    return !!node && isValidPropertyAccess(node, escapeLeadingUnderscores(propertyName));
                },
                isValidPropertyAccessForCompletions: (nodeIn, type, property) => {
                    const node = getParseTreeNode(nodeIn, isPropertyAccessExpression);
                    return !!node && isValidPropertyAccessForCompletions(node, type, property);
                },
                getSignatureFromDeclaration: (declarationIn) => {
                    const declaration = getParseTreeNode(declarationIn, isFunctionLike);
                    return declaration ? getSignatureFromDeclaration(declaration) : void 0;
                },
                isImplementationOfOverload: (nodeIn) => {
                    const node = getParseTreeNode(nodeIn, isFunctionLike);
                    return node ? isImplementationOfOverload(node) : void 0;
                },
                getImmediateAliasedSymbol,
                getAliasedSymbol: resolveAlias,
                getEmitResolver,
                getExportsOfModule: getExportsOfModuleAsArray,
                getExportsAndPropertiesOfModule,
                forEachExportAndPropertyOfModule,
                getSymbolWalker: createGetSymbolWalker(getRestTypeOfSignature, getTypePredicateOfSignature, getReturnTypeOfSignature, getBaseTypes, resolveStructuredTypeMembers, getTypeOfSymbol, getResolvedSymbol, getConstraintOfTypeParameter, getFirstIdentifier, getTypeArguments),
                getAmbientModules,
                getJsxIntrinsicTagNamesAt,
                isOptionalParameter: (nodeIn) => {
                    const node = getParseTreeNode(nodeIn, isParameter);
                    return node ? isOptionalParameter(node) : false;
                },
                tryGetMemberInModuleExports: (name, symbol) => tryGetMemberInModuleExports(escapeLeadingUnderscores(name), symbol),
                tryGetMemberInModuleExportsAndProperties: (name, symbol) => tryGetMemberInModuleExportsAndProperties(escapeLeadingUnderscores(name), symbol),
                tryFindAmbientModule: (moduleName) => tryFindAmbientModule(moduleName, 
                /*withAugmentations*/
                true),
                tryFindAmbientModuleWithoutAugmentations: (moduleName) => {
                    return tryFindAmbientModule(moduleName, 
                    /*withAugmentations*/
                    false);
                },
                getApparentType,
                getUnionType,
                isTypeAssignableTo,
                createAnonymousType,
                createSignature,
                createSymbol,
                createIndexInfo,
                getAnyType: () => anyType,
                getStringType: () => stringType,
                getStringLiteralType,
                getNumberType: () => numberType,
                getNumberLiteralType,
                getBigIntType: () => bigintType,
                createPromiseType,
                createArrayType,
                getElementTypeOfArrayType,
                getBooleanType: () => booleanType,
                getFalseType: (fresh) => fresh ? falseType : regularFalseType,
                getTrueType: (fresh) => fresh ? trueType : regularTrueType,
                getVoidType: () => voidType,
                getUndefinedType: () => undefinedType,
                getNullType: () => nullType,
                getESSymbolType: () => esSymbolType,
                getNeverType: () => neverType,
                getOptionalType: () => optionalType,
                getPromiseType: () => getGlobalPromiseType(
                /*reportErrors*/
                false),
                getPromiseLikeType: () => getGlobalPromiseLikeType(
                /*reportErrors*/
                false),
                getAsyncIterableType: () => {
                    const type = getGlobalAsyncIterableType(
                    /*reportErrors*/
                    false);
                    if (type === emptyGenericType)
                        return void 0;
                    return type;
                },
                isSymbolAccessible,
                isArrayType,
                isTupleType,
                isArrayLikeType,
                isEmptyAnonymousObjectType,
                isTypeInvalidDueToUnionDiscriminant,
                getExactOptionalProperties,
                getAllPossiblePropertiesOfTypes,
                getSuggestedSymbolForNonexistentProperty,
                getSuggestionForNonexistentProperty,
                getSuggestedSymbolForNonexistentJSXAttribute,
                getSuggestedSymbolForNonexistentSymbol: (location, name, meaning) => getSuggestedSymbolForNonexistentSymbol(location, escapeLeadingUnderscores(name), meaning),
                getSuggestionForNonexistentSymbol: (location, name, meaning) => getSuggestionForNonexistentSymbol(location, escapeLeadingUnderscores(name), meaning),
                getSuggestedSymbolForNonexistentModule,
                getSuggestionForNonexistentExport,
                getSuggestedSymbolForNonexistentClassMember,
                getBaseConstraintOfType,
                getDefaultFromTypeParameter: (type) => type && type.flags & 262144 /* TypeParameter */ ? getDefaultFromTypeParameter(type) : void 0,
                resolveName(name, location, meaning, excludeGlobals) {
                    return resolveName(location, escapeLeadingUnderscores(name), meaning, 
                    /*nameNotFoundMessage*/
                    void 0, 
                    /*nameArg*/
                    void 0, 
                    /*isUse*/
                    false, excludeGlobals);
                },
                getJsxNamespace: (n) => unescapeLeadingUnderscores(getJsxNamespace(n)),
                getJsxFragmentFactory: (n) => {
                    const jsxFragmentFactory = getJsxFragmentFactoryEntity(n);
                    return jsxFragmentFactory && unescapeLeadingUnderscores(getFirstIdentifier(jsxFragmentFactory).escapedText);
                },
                getAccessibleSymbolChain,
                getTypePredicateOfSignature,
                resolveExternalModuleName: (moduleSpecifierIn) => {
                    const moduleSpecifier = getParseTreeNode(moduleSpecifierIn, isExpression);
                    return moduleSpecifier && resolveExternalModuleName(moduleSpecifier, moduleSpecifier, 
                    /*ignoreErrors*/
                    true);
                },
                resolveExternalModuleSymbol,
                tryGetThisTypeAt: (nodeIn, includeGlobalThis, container) => {
                    const node = getParseTreeNode(nodeIn);
                    return node && tryGetThisTypeAt(node, includeGlobalThis, container);
                },
                getTypeArgumentConstraint: (nodeIn) => {
                    const node = getParseTreeNode(nodeIn, isTypeNode);
                    return node && getTypeArgumentConstraint(node);
                },
                getSuggestionDiagnostics: (fileIn, ct) => {
                    const file = getParseTreeNode(fileIn, isSourceFile) || Debug.fail("Could not determine parsed source file.");
                    if (skipTypeChecking(file, compilerOptions, host)) {
                        return emptyArray;
                    }
                    let diagnostics2;
                    try {
                        cancellationToken = ct;
                        checkSourceFileWithEagerDiagnostics(file);
                        Debug.assert(!!(getNodeLinks(file).flags & 1 /* TypeChecked */));
                        diagnostics2 = addRange(diagnostics2, suggestionDiagnostics.getDiagnostics(file.fileName));
                        checkUnusedIdentifiers(getPotentiallyUnusedIdentifiers(file), (containingNode, kind, diag2) => {
                            if (!containsParseError(containingNode) && !unusedIsError(kind, !!(containingNode.flags & 33554432 /* Ambient */))) {
                                (diagnostics2 || (diagnostics2 = [])).push({ ...diag2, category: 2 /* Suggestion */ });
                            }
                        });
                        return diagnostics2 || emptyArray;
                    }
                    finally {
                        cancellationToken = void 0;
                    }
                },
                runWithCancellationToken: (token, callback) => {
                    try {
                        cancellationToken = token;
                        return callback(checker);
                    }
                    finally {
                        cancellationToken = void 0;
                    }
                },
                getLocalTypeParametersOfClassOrInterfaceOrTypeAlias,
                isDeclarationVisible,
                isPropertyAccessible,
                getTypeOnlyAliasDeclaration,
                getMemberOverrideModifierStatus,
                isTypeParameterPossiblyReferenced,
                typeHasCallOrConstructSignatures
            };
            function getCandidateSignaturesForStringLiteralCompletions(call, editingArgument) {
                const candidatesSet = /* @__PURE__ */ new Set();
                const candidates = [];
                runWithInferenceBlockedFromSourceNode(editingArgument, () => getResolvedSignatureWorker(call, candidates, 
                /*argumentCount*/
                void 0, 0 /* Normal */));
                for (const candidate of candidates) {
                    candidatesSet.add(candidate);
                }
                candidates.length = 0;
                runWithoutResolvedSignatureCaching(editingArgument, () => getResolvedSignatureWorker(call, candidates, 
                /*argumentCount*/
                void 0, 0 /* Normal */));
                for (const candidate of candidates) {
                    candidatesSet.add(candidate);
                }
                return arrayFrom(candidatesSet);
            }
            function runWithoutResolvedSignatureCaching(node, fn) {
                node = findAncestor(node, isCallLikeOrFunctionLikeExpression);
                if (node) {
                    const cachedResolvedSignatures = [];
                    const cachedTypes2 = [];
                    while (node) {
                        const nodeLinks2 = getNodeLinks(node);
                        cachedResolvedSignatures.push([nodeLinks2, nodeLinks2.resolvedSignature]);
                        nodeLinks2.resolvedSignature = void 0;
                        if (isFunctionExpressionOrArrowFunction(node)) {
                            const symbolLinks2 = getSymbolLinks(getSymbolOfDeclaration(node));
                            const type = symbolLinks2.type;
                            cachedTypes2.push([symbolLinks2, type]);
                            symbolLinks2.type = void 0;
                        }
                        node = findAncestor(node.parent, isCallLikeOrFunctionLikeExpression);
                    }
                    const result = fn();
                    for (const [nodeLinks2, resolvedSignature] of cachedResolvedSignatures) {
                        nodeLinks2.resolvedSignature = resolvedSignature;
                    }
                    for (const [symbolLinks2, type] of cachedTypes2) {
                        symbolLinks2.type = type;
                    }
                    return result;
                }
                return fn();
            }
            function runWithInferenceBlockedFromSourceNode(node, fn) {
                const containingCall = findAncestor(node, isCallLikeExpression);
                if (containingCall) {
                    let toMarkSkip = node;
                    do {
                        getNodeLinks(toMarkSkip).skipDirectInference = true;
                        toMarkSkip = toMarkSkip.parent;
                    } while (toMarkSkip && toMarkSkip !== containingCall);
                }
                isInferencePartiallyBlocked = true;
                const result = runWithoutResolvedSignatureCaching(node, fn);
                isInferencePartiallyBlocked = false;
                if (containingCall) {
                    let toMarkSkip = node;
                    do {
                        getNodeLinks(toMarkSkip).skipDirectInference = void 0;
                        toMarkSkip = toMarkSkip.parent;
                    } while (toMarkSkip && toMarkSkip !== containingCall);
                }
                return result;
            }
            function getResolvedSignatureWorker(nodeIn, candidatesOutArray, argumentCount, checkMode) {
                const node = getParseTreeNode(nodeIn, isCallLikeExpression);
                apparentArgumentCount = argumentCount;
                const res = !node ? void 0 : getResolvedSignature(node, candidatesOutArray, checkMode);
                apparentArgumentCount = void 0;
                return res;
            }
            var tupleTypes = /* @__PURE__ */ new Map();
            var unionTypes = /* @__PURE__ */ new Map();
            var unionOfUnionTypes = /* @__PURE__ */ new Map();
            var intersectionTypes = /* @__PURE__ */ new Map();
            var stringLiteralTypes = /* @__PURE__ */ new Map();
            var numberLiteralTypes = /* @__PURE__ */ new Map();
            var bigIntLiteralTypes = /* @__PURE__ */ new Map();
            var enumLiteralTypes = /* @__PURE__ */ new Map();
            var indexedAccessTypes = /* @__PURE__ */ new Map();
            var templateLiteralTypes = /* @__PURE__ */ new Map();
            var stringMappingTypes = /* @__PURE__ */ new Map();
            var substitutionTypes = /* @__PURE__ */ new Map();
            var subtypeReductionCache = /* @__PURE__ */ new Map();
            var decoratorContextOverrideTypeCache = /* @__PURE__ */ new Map();
            var cachedTypes = /* @__PURE__ */ new Map();
            var evolvingArrayTypes = [];
            var undefinedProperties = /* @__PURE__ */ new Map();
            var markerTypes = /* @__PURE__ */ new Set();
            var unknownSymbol = createSymbol(4 /* Property */, "unknown");
            var resolvingSymbol = createSymbol(0, "__resolving__" /* Resolving */);
            var unresolvedSymbols = /* @__PURE__ */ new Map();
            var errorTypes = /* @__PURE__ */ new Map();
            var seenIntrinsicNames = /* @__PURE__ */ new Set();
            var anyType = createIntrinsicType(1 /* Any */, "any");
            var autoType = createIntrinsicType(1 /* Any */, "any", 262144 /* NonInferrableType */, "auto");
            var wildcardType = createIntrinsicType(1 /* Any */, "any", 
            /*objectFlags*/
            void 0, "wildcard");
            var blockedStringType = createIntrinsicType(1 /* Any */, "any", 
            /*objectFlags*/
            void 0, "blocked string");
            var errorType = createIntrinsicType(1 /* Any */, "error");
            var unresolvedType = createIntrinsicType(1 /* Any */, "unresolved");
            var nonInferrableAnyType = createIntrinsicType(1 /* Any */, "any", 65536 /* ContainsWideningType */, "non-inferrable");
            var intrinsicMarkerType = createIntrinsicType(1 /* Any */, "intrinsic");
            var unknownType = createIntrinsicType(2 /* Unknown */, "unknown");
            var nonNullUnknownType = createIntrinsicType(2 /* Unknown */, "unknown", 
            /*objectFlags*/
            void 0, "non-null");
            var undefinedType = createIntrinsicType(32768 /* Undefined */, "undefined");
            var undefinedWideningType = strictNullChecks ? undefinedType : createIntrinsicType(32768 /* Undefined */, "undefined", 65536 /* ContainsWideningType */, "widening");
            var missingType = createIntrinsicType(32768 /* Undefined */, "undefined", 
            /*objectFlags*/
            void 0, "missing");
            var undefinedOrMissingType = exactOptionalPropertyTypes ? missingType : undefinedType;
            var optionalType = createIntrinsicType(32768 /* Undefined */, "undefined", 
            /*objectFlags*/
            void 0, "optional");
            var nullType = createIntrinsicType(65536 /* Null */, "null");
            var nullWideningType = strictNullChecks ? nullType : createIntrinsicType(65536 /* Null */, "null", 65536 /* ContainsWideningType */, "widening");
            var stringType = createIntrinsicType(4 /* String */, "string");
            var numberType = createIntrinsicType(8 /* Number */, "number");
            var bigintType = createIntrinsicType(64 /* BigInt */, "bigint");
            var falseType = createIntrinsicType(512 /* BooleanLiteral */, "false", 
            /*objectFlags*/
            void 0, "fresh");
            var regularFalseType = createIntrinsicType(512 /* BooleanLiteral */, "false");
            var trueType = createIntrinsicType(512 /* BooleanLiteral */, "true", 
            /*objectFlags*/
            void 0, "fresh");
            var regularTrueType = createIntrinsicType(512 /* BooleanLiteral */, "true");
            trueType.regularType = regularTrueType;
            trueType.freshType = trueType;
            regularTrueType.regularType = regularTrueType;
            regularTrueType.freshType = trueType;
            falseType.regularType = regularFalseType;
            falseType.freshType = falseType;
            regularFalseType.regularType = regularFalseType;
            regularFalseType.freshType = falseType;
            var booleanType = getUnionType([regularFalseType, regularTrueType]);
            var esSymbolType = createIntrinsicType(4096 /* ESSymbol */, "symbol");
            var voidType = createIntrinsicType(16384 /* Void */, "void");
            var neverType = createIntrinsicType(131072 /* Never */, "never");
            var silentNeverType = createIntrinsicType(131072 /* Never */, "never", 262144 /* NonInferrableType */, "silent");
            var implicitNeverType = createIntrinsicType(131072 /* Never */, "never", 
            /*objectFlags*/
            void 0, "implicit");
            var unreachableNeverType = createIntrinsicType(131072 /* Never */, "never", 
            /*objectFlags*/
            void 0, "unreachable");
            var nonPrimitiveType = createIntrinsicType(67108864 /* NonPrimitive */, "object");
            var stringOrNumberType = getUnionType([stringType, numberType]);
            var stringNumberSymbolType = getUnionType([stringType, numberType, esSymbolType]);
            var keyofConstraintType = keyofStringsOnly ? stringType : stringNumberSymbolType;
            var numberOrBigIntType = getUnionType([numberType, bigintType]);
            var templateConstraintType = getUnionType([stringType, numberType, booleanType, bigintType, nullType, undefinedType]);
            var numericStringType = getTemplateLiteralType(["", ""], [numberType]);
            var restrictiveMapper = makeFunctionTypeMapper((t) => t.flags & 262144 /* TypeParameter */ ? getRestrictiveTypeParameter(t) : t, () => "(restrictive mapper)");
            var permissiveMapper = makeFunctionTypeMapper((t) => t.flags & 262144 /* TypeParameter */ ? wildcardType : t, () => "(permissive mapper)");
            var uniqueLiteralType = createIntrinsicType(131072 /* Never */, "never", 
            /*objectFlags*/
            void 0, "unique literal");
            var uniqueLiteralMapper = makeFunctionTypeMapper((t) => t.flags & 262144 /* TypeParameter */ ? uniqueLiteralType : t, () => "(unique literal mapper)");
            var outofbandVarianceMarkerHandler;
            var reportUnreliableMapper = makeFunctionTypeMapper((t) => {
                if (outofbandVarianceMarkerHandler && (t === markerSuperType || t === markerSubType || t === markerOtherType)) {
                    outofbandVarianceMarkerHandler(
                    /*onlyUnreliable*/
                    true);
                }
                return t;
            }, () => "(unmeasurable reporter)");
            var reportUnmeasurableMapper = makeFunctionTypeMapper((t) => {
                if (outofbandVarianceMarkerHandler && (t === markerSuperType || t === markerSubType || t === markerOtherType)) {
                    outofbandVarianceMarkerHandler(
                    /*onlyUnreliable*/
                    false);
                }
                return t;
            }, () => "(unreliable reporter)");
            var emptyObjectType = createAnonymousType(
            /*symbol*/
            void 0, emptySymbols, emptyArray, emptyArray, emptyArray);
            var emptyJsxObjectType = createAnonymousType(
            /*symbol*/
            void 0, emptySymbols, emptyArray, emptyArray, emptyArray);
            emptyJsxObjectType.objectFlags |= 2048 /* JsxAttributes */;
            var emptyTypeLiteralSymbol = createSymbol(2048 /* TypeLiteral */, "__type" /* Type */);
            emptyTypeLiteralSymbol.members = createSymbolTable();
            var emptyTypeLiteralType = createAnonymousType(emptyTypeLiteralSymbol, emptySymbols, emptyArray, emptyArray, emptyArray);
            var unknownEmptyObjectType = createAnonymousType(
            /*symbol*/
            void 0, emptySymbols, emptyArray, emptyArray, emptyArray);
            var unknownUnionType = strictNullChecks ? getUnionType([undefinedType, nullType, unknownEmptyObjectType]) : unknownType;
            var emptyGenericType = createAnonymousType(
            /*symbol*/
            void 0, emptySymbols, emptyArray, emptyArray, emptyArray);
            emptyGenericType.instantiations = /* @__PURE__ */ new Map();
            var anyFunctionType = createAnonymousType(
            /*symbol*/
            void 0, emptySymbols, emptyArray, emptyArray, emptyArray);
            anyFunctionType.objectFlags |= 262144 /* NonInferrableType */;
            var noConstraintType = createAnonymousType(
            /*symbol*/
            void 0, emptySymbols, emptyArray, emptyArray, emptyArray);
            var circularConstraintType = createAnonymousType(
            /*symbol*/
            void 0, emptySymbols, emptyArray, emptyArray, emptyArray);
            var resolvingDefaultType = createAnonymousType(
            /*symbol*/
            void 0, emptySymbols, emptyArray, emptyArray, emptyArray);
            var markerSuperType = createTypeParameter();
            var markerSubType = createTypeParameter();
            markerSubType.constraint = markerSuperType;
            var markerOtherType = createTypeParameter();
            var markerSuperTypeForCheck = createTypeParameter();
            var markerSubTypeForCheck = createTypeParameter();
            markerSubTypeForCheck.constraint = markerSuperTypeForCheck;
            var noTypePredicate = createTypePredicate(1 /* Identifier */, "<<unresolved>>", 0, anyType);
            var anySignature = createSignature(
            /*declaration*/
            void 0, 
            /*typeParameters*/
            void 0, 
            /*thisParameter*/
            void 0, emptyArray, anyType, 
            /*resolvedTypePredicate*/
            void 0, 0, 0 /* None */);
            var unknownSignature = createSignature(
            /*declaration*/
            void 0, 
            /*typeParameters*/
            void 0, 
            /*thisParameter*/
            void 0, emptyArray, errorType, 
            /*resolvedTypePredicate*/
            void 0, 0, 0 /* None */);
            var resolvingSignature = createSignature(
            /*declaration*/
            void 0, 
            /*typeParameters*/
            void 0, 
            /*thisParameter*/
            void 0, emptyArray, anyType, 
            /*resolvedTypePredicate*/
            void 0, 0, 0 /* None */);
            var silentNeverSignature = createSignature(
            /*declaration*/
            void 0, 
            /*typeParameters*/
            void 0, 
            /*thisParameter*/
            void 0, emptyArray, silentNeverType, 
            /*resolvedTypePredicate*/
            void 0, 0, 0 /* None */);
            var enumNumberIndexInfo = createIndexInfo(numberType, stringType, 
            /*isReadonly*/
            true);
            var iterationTypesCache = /* @__PURE__ */ new Map();
            var noIterationTypes = {
                get yieldType() {
                    return Debug.fail("Not supported");
                },
                get returnType() {
                    return Debug.fail("Not supported");
                },
                get nextType() {
                    return Debug.fail("Not supported");
                }
            };
            var anyIterationTypes = createIterationTypes(anyType, anyType, anyType);
            var anyIterationTypesExceptNext = createIterationTypes(anyType, anyType, unknownType);
            var defaultIterationTypes = createIterationTypes(neverType, anyType, undefinedType);
            var asyncIterationTypesResolver = {
                iterableCacheKey: "iterationTypesOfAsyncIterable",
                iteratorCacheKey: "iterationTypesOfAsyncIterator",
                iteratorSymbolName: "asyncIterator",
                getGlobalIteratorType: getGlobalAsyncIteratorType,
                getGlobalIterableType: getGlobalAsyncIterableType,
                getGlobalIterableIteratorType: getGlobalAsyncIterableIteratorType,
                getGlobalGeneratorType: getGlobalAsyncGeneratorType,
                resolveIterationType: (type, errorNode) => getAwaitedType(type, errorNode, Diagnostics.Type_of_await_operand_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member),
                mustHaveANextMethodDiagnostic: Diagnostics.An_async_iterator_must_have_a_next_method,
                mustBeAMethodDiagnostic: Diagnostics.The_0_property_of_an_async_iterator_must_be_a_method,
                mustHaveAValueDiagnostic: Diagnostics.The_type_returned_by_the_0_method_of_an_async_iterator_must_be_a_promise_for_a_type_with_a_value_property
            };
            var syncIterationTypesResolver = {
                iterableCacheKey: "iterationTypesOfIterable",
                iteratorCacheKey: "iterationTypesOfIterator",
                iteratorSymbolName: "iterator",
                getGlobalIteratorType,
                getGlobalIterableType,
                getGlobalIterableIteratorType,
                getGlobalGeneratorType,
                resolveIterationType: (type, _errorNode) => type,
                mustHaveANextMethodDiagnostic: Diagnostics.An_iterator_must_have_a_next_method,
                mustBeAMethodDiagnostic: Diagnostics.The_0_property_of_an_iterator_must_be_a_method,
                mustHaveAValueDiagnostic: Diagnostics.The_type_returned_by_the_0_method_of_an_iterator_must_have_a_value_property
            };
            var amalgamatedDuplicates;
            var reverseMappedCache = /* @__PURE__ */ new Map();
            var homomorphicMappedTypeInferenceStack = [];
            var ambientModulesCache;
            var patternAmbientModules;
            var patternAmbientModuleAugmentations;
            var globalObjectType;
            var globalFunctionType;
            var globalCallableFunctionType;
            var globalNewableFunctionType;
            var globalArrayType;
            var globalReadonlyArrayType;
            var globalStringType;
            var globalNumberType;
            var globalBooleanType;
            var globalRegExpType;
            var globalThisType;
            var anyArrayType;
            var autoArrayType;
            var anyReadonlyArrayType;
            var deferredGlobalNonNullableTypeAlias;
            var deferredGlobalESSymbolConstructorSymbol;
            var deferredGlobalESSymbolConstructorTypeSymbol;
            var deferredGlobalESSymbolType;
            var deferredGlobalTypedPropertyDescriptorType;
            var deferredGlobalPromiseType;
            var deferredGlobalPromiseLikeType;
            var deferredGlobalPromiseConstructorSymbol;
            var deferredGlobalPromiseConstructorLikeType;
            var deferredGlobalIterableType;
            var deferredGlobalIteratorType;
            var deferredGlobalIterableIteratorType;
            var deferredGlobalGeneratorType;
            var deferredGlobalIteratorYieldResultType;
            var deferredGlobalIteratorReturnResultType;
            var deferredGlobalAsyncIterableType;
            var deferredGlobalAsyncIteratorType;
            var deferredGlobalAsyncIterableIteratorType;
            var deferredGlobalAsyncGeneratorType;
            var deferredGlobalTemplateStringsArrayType;
            var deferredGlobalImportMetaType;
            var deferredGlobalImportMetaExpressionType;
            var deferredGlobalImportCallOptionsType;
            var deferredGlobalImportAttributesType;
            var deferredGlobalDisposableType;
            var deferredGlobalAsyncDisposableType;
            var deferredGlobalExtractSymbol;
            var deferredGlobalOmitSymbol;
            var deferredGlobalAwaitedSymbol;
            var deferredGlobalBigIntType;
            var deferredGlobalNaNSymbol;
            var deferredGlobalRecordSymbol;
            var deferredGlobalClassDecoratorContextType;
            var deferredGlobalClassMethodDecoratorContextType;
            var deferredGlobalClassGetterDecoratorContextType;
            var deferredGlobalClassSetterDecoratorContextType;
            var deferredGlobalClassAccessorDecoratorContextType;
            var deferredGlobalClassAccessorDecoratorTargetType;
            var deferredGlobalClassAccessorDecoratorResultType;
            var deferredGlobalClassFieldDecoratorContextType;
            var allPotentiallyUnusedIdentifiers = /* @__PURE__ */ new Map();
            var flowLoopStart = 0;
            var flowLoopCount = 0;
            var sharedFlowCount = 0;
            var flowAnalysisDisabled = false;
            var flowInvocationCount = 0;
            var lastFlowNode;
            var lastFlowNodeReachable;
            var flowTypeCache;
            var contextualTypeNodes = [];
            var contextualTypes = [];
            var contextualIsCache = [];
            var contextualTypeCount = 0;
            var inferenceContextNodes = [];
            var inferenceContexts = [];
            var inferenceContextCount = 0;
            var emptyStringType = getStringLiteralType("");
            var zeroType = getNumberLiteralType(0);
            var zeroBigIntType = getBigIntLiteralType({ negative: false, base10Value: "0" });
            var resolutionTargets = [];
            var resolutionResults = [];
            var resolutionPropertyNames = [];
            var resolutionStart = 0;
            var inVarianceComputation = false;
            var suggestionCount = 0;
            var maximumSuggestionCount = 10;
            var mergedSymbols = [];
            var symbolLinks = [];
            var nodeLinks = [];
            var flowLoopCaches = [];
            var flowLoopNodes = [];
            var flowLoopKeys = [];
            var flowLoopTypes = [];
            var sharedFlowNodes = [];
            var sharedFlowTypes = [];
            var flowNodeReachable = [];
            var flowNodePostSuper = [];
            var potentialThisCollisions = [];
            var potentialNewTargetCollisions = [];
            var potentialWeakMapSetCollisions = [];
            var potentialReflectCollisions = [];
            var potentialUnusedRenamedBindingElementsInTypes = [];
            var awaitedTypeStack = [];
            var diagnostics = createDiagnosticCollection();
            var suggestionDiagnostics = createDiagnosticCollection();
            var typeofType = createTypeofType();
            var _jsxNamespace;
            var _jsxFactoryEntity;
            var subtypeRelation = /* @__PURE__ */ new Map();
            var strictSubtypeRelation = /* @__PURE__ */ new Map();
            var assignableRelation = /* @__PURE__ */ new Map();
            var comparableRelation = /* @__PURE__ */ new Map();
            var identityRelation = /* @__PURE__ */ new Map();
            var enumRelation = /* @__PURE__ */ new Map();
            var builtinGlobals = createSymbolTable();
            builtinGlobals.set(undefinedSymbol.escapedName, undefinedSymbol);
            var suggestedExtensions = [
                [".mts", ".mjs"],
                [".ts", ".js"],
                [".cts", ".cjs"],
                [".mjs", ".mjs"],
                [".js", ".js"],
                [".cjs", ".cjs"],
                [".tsx", compilerOptions.jsx === 1 /* Preserve */ ? ".jsx" : ".js"],
                [".jsx", ".jsx"],
                [".json", ".json"]
            ];
            initializeTypeChecker();
            return checker;
            function getCachedType(key) {
                return key ? cachedTypes.get(key) : void 0;
            }
            function setCachedType(key, type) {
                if (key)
                    cachedTypes.set(key, type);
                return type;
            }
            function getJsxNamespace(location) {
                if (location) {
                    const file = getSourceFileOfNode(location);
                    if (file) {
                        if (isJsxOpeningFragment(location)) {
                            if (file.localJsxFragmentNamespace) {
                                return file.localJsxFragmentNamespace;
                            }
                            const jsxFragmentPragma = file.pragmas.get("jsxfrag");
                            if (jsxFragmentPragma) {
                                const chosenPragma = isArray(jsxFragmentPragma) ? jsxFragmentPragma[0] : jsxFragmentPragma;
                                file.localJsxFragmentFactory = parseIsolatedEntityName(chosenPragma.arguments.factory, languageVersion);
                                visitNode(file.localJsxFragmentFactory, markAsSynthetic, isEntityName);
                                if (file.localJsxFragmentFactory) {
                                    return file.localJsxFragmentNamespace = getFirstIdentifier(file.localJsxFragmentFactory).escapedText;
                                }
                            }
                            const entity = getJsxFragmentFactoryEntity(location);
                            if (entity) {
                                file.localJsxFragmentFactory = entity;
                                return file.localJsxFragmentNamespace = getFirstIdentifier(entity).escapedText;
                            }
                        }
                        else {
                            const localJsxNamespace = getLocalJsxNamespace(file);
                            if (localJsxNamespace) {
                                return file.localJsxNamespace = localJsxNamespace;
                            }
                        }
                    }
                }
                if (!_jsxNamespace) {
                    _jsxNamespace = "React";
                    if (compilerOptions.jsxFactory) {
                        _jsxFactoryEntity = parseIsolatedEntityName(compilerOptions.jsxFactory, languageVersion);
                        visitNode(_jsxFactoryEntity, markAsSynthetic);
                        if (_jsxFactoryEntity) {
                            _jsxNamespace = getFirstIdentifier(_jsxFactoryEntity).escapedText;
                        }
                    }
                    else if (compilerOptions.reactNamespace) {
                        _jsxNamespace = escapeLeadingUnderscores(compilerOptions.reactNamespace);
                    }
                }
                if (!_jsxFactoryEntity) {
                    _jsxFactoryEntity = factory.createQualifiedName(factory.createIdentifier(unescapeLeadingUnderscores(_jsxNamespace)), "createElement");
                }
                return _jsxNamespace;
            }
            function getLocalJsxNamespace(file) {
                if (file.localJsxNamespace) {
                    return file.localJsxNamespace;
                }
                const jsxPragma = file.pragmas.get("jsx");
                if (jsxPragma) {
                    const chosenPragma = isArray(jsxPragma) ? jsxPragma[0] : jsxPragma;
                    file.localJsxFactory = parseIsolatedEntityName(chosenPragma.arguments.factory, languageVersion);
                    visitNode(file.localJsxFactory, markAsSynthetic, isEntityName);
                    if (file.localJsxFactory) {
                        return file.localJsxNamespace = getFirstIdentifier(file.localJsxFactory).escapedText;
                    }
                }
            }
            function markAsSynthetic(node) {
                setTextRangePosEnd(node, -1, -1);
                return visitEachChild(node, markAsSynthetic, 
                /*context*/
                void 0);
            }
            function getEmitResolver(sourceFile, cancellationToken2) {
                getDiagnostics2(sourceFile, cancellationToken2);
                return emitResolver;
            }
            function lookupOrIssueError(location, message, ...args) {
                const diagnostic = location ? createDiagnosticForNode(location, message, ...args) : createCompilerDiagnostic(message, ...args);
                const existing = diagnostics.lookup(diagnostic);
                if (existing) {
                    return existing;
                }
                else {
                    diagnostics.add(diagnostic);
                    return diagnostic;
                }
            }
            function errorSkippedOn(key, location, message, ...args) {
                const diagnostic = error2(location, message, ...args);
                diagnostic.skippedOn = key;
                return diagnostic;
            }
            function createError(location, message, ...args) {
                return location ? createDiagnosticForNode(location, message, ...args) : createCompilerDiagnostic(message, ...args);
            }
            function error2(location, message, ...args) {
                const diagnostic = createError(location, message, ...args);
                diagnostics.add(diagnostic);
                return diagnostic;
            }
            function addErrorOrSuggestion(isError, diagnostic) {
                if (isError) {
                    diagnostics.add(diagnostic);
                }
                else {
                    suggestionDiagnostics.add({ ...diagnostic, category: 2 /* Suggestion */ });
                }
            }
            function errorOrSuggestion(isError, location, message, ...args) {
                if (location.pos < 0 || location.end < 0) {
                    if (!isError) {
                        return;
                    }
                    const file = getSourceFileOfNode(location);
                    addErrorOrSuggestion(isError, "message" in message ? createFileDiagnostic(file, 0, 0, message, ...args) : createDiagnosticForFileFromMessageChain(file, message));
                    return;
                }
                addErrorOrSuggestion(isError, "message" in message ? createDiagnosticForNode(location, message, ...args) : createDiagnosticForNodeFromMessageChain(getSourceFileOfNode(location), location, message));
            }
            function errorAndMaybeSuggestAwait(location, maybeMissingAwait, message, ...args) {
                const diagnostic = error2(location, message, ...args);
                if (maybeMissingAwait) {
                    const related = createDiagnosticForNode(location, Diagnostics.Did_you_forget_to_use_await);
                    addRelatedInfo(diagnostic, related);
                }
                return diagnostic;
            }
            function addDeprecatedSuggestionWorker(declarations, diagnostic) {
                const deprecatedTag = Array.isArray(declarations) ? forEach(declarations, getJSDocDeprecatedTag) : getJSDocDeprecatedTag(declarations);
                if (deprecatedTag) {
                    addRelatedInfo(diagnostic, createDiagnosticForNode(deprecatedTag, Diagnostics.The_declaration_was_marked_as_deprecated_here));
                }
                suggestionDiagnostics.add(diagnostic);
                return diagnostic;
            }
            function isDeprecatedSymbol(symbol) {
                const parentSymbol = getParentOfSymbol(symbol);
                if (parentSymbol && length(symbol.declarations) > 1) {
                    return parentSymbol.flags & 64 /* Interface */ ? some(symbol.declarations, isDeprecatedDeclaration2) : every(symbol.declarations, isDeprecatedDeclaration2);
                }
                return !!symbol.valueDeclaration && isDeprecatedDeclaration2(symbol.valueDeclaration) || length(symbol.declarations) && every(symbol.declarations, isDeprecatedDeclaration2);
            }
            function isDeprecatedDeclaration2(declaration) {
                return !!(getCombinedNodeFlagsCached(declaration) & 536870912 /* Deprecated */);
            }
            function addDeprecatedSuggestion(location, declarations, deprecatedEntity) {
                const diagnostic = createDiagnosticForNode(location, Diagnostics._0_is_deprecated, deprecatedEntity);
                return addDeprecatedSuggestionWorker(declarations, diagnostic);
            }
            function addDeprecatedSuggestionWithSignature(location, declaration, deprecatedEntity, signatureString) {
                const diagnostic = deprecatedEntity ? createDiagnosticForNode(location, Diagnostics.The_signature_0_of_1_is_deprecated, signatureString, deprecatedEntity) : createDiagnosticForNode(location, Diagnostics._0_is_deprecated, signatureString);
                return addDeprecatedSuggestionWorker(declaration, diagnostic);
            }
            function createSymbol(flags, name, checkFlags) {
                symbolCount++;
                const symbol = new Symbol47(flags | 33554432 /* Transient */, name);
                symbol.links = new SymbolLinks();
                symbol.links.checkFlags = checkFlags || 0 /* None */;
                return symbol;
            }
            function createParameter2(name, type) {
                const symbol = createSymbol(1 /* FunctionScopedVariable */, name);
                symbol.links.type = type;
                return symbol;
            }
            function createProperty(name, type) {
                const symbol = createSymbol(4 /* Property */, name);
                symbol.links.type = type;
                return symbol;
            }
            function getExcludedSymbolFlags(flags) {
                let result = 0;
                if (flags & 2 /* BlockScopedVariable */)
                    result |= 111551 /* BlockScopedVariableExcludes */;
                if (flags & 1 /* FunctionScopedVariable */)
                    result |= 111550 /* FunctionScopedVariableExcludes */;
                if (flags & 4 /* Property */)
                    result |= 0 /* PropertyExcludes */;
                if (flags & 8 /* EnumMember */)
                    result |= 900095 /* EnumMemberExcludes */;
                if (flags & 16 /* Function */)
                    result |= 110991 /* FunctionExcludes */;
                if (flags & 32 /* Class */)
                    result |= 899503 /* ClassExcludes */;
                if (flags & 64 /* Interface */)
                    result |= 788872 /* InterfaceExcludes */;
                if (flags & 256 /* RegularEnum */)
                    result |= 899327 /* RegularEnumExcludes */;
                if (flags & 128 /* ConstEnum */)
                    result |= 899967 /* ConstEnumExcludes */;
                if (flags & 512 /* ValueModule */)
                    result |= 110735 /* ValueModuleExcludes */;
                if (flags & 8192 /* Method */)
                    result |= 103359 /* MethodExcludes */;
                if (flags & 32768 /* GetAccessor */)
                    result |= 46015 /* GetAccessorExcludes */;
                if (flags & 65536 /* SetAccessor */)
                    result |= 78783 /* SetAccessorExcludes */;
                if (flags & 262144 /* TypeParameter */)
                    result |= 526824 /* TypeParameterExcludes */;
                if (flags & 524288 /* TypeAlias */)
                    result |= 788968 /* TypeAliasExcludes */;
                if (flags & 2097152 /* Alias */)
                    result |= 2097152 /* AliasExcludes */;
                return result;
            }
            function recordMergedSymbol(target, source) {
                if (!source.mergeId) {
                    source.mergeId = nextMergeId;
                    nextMergeId++;
                }
                mergedSymbols[source.mergeId] = target;
            }
            function cloneSymbol(symbol) {
                const result = createSymbol(symbol.flags, symbol.escapedName);
                result.declarations = symbol.declarations ? symbol.declarations.slice() : [];
                result.parent = symbol.parent;
                if (symbol.valueDeclaration)
                    result.valueDeclaration = symbol.valueDeclaration;
                if (symbol.constEnumOnlyModule)
                    result.constEnumOnlyModule = true;
                if (symbol.members)
                    result.members = new Map(symbol.members);
                if (symbol.exports)
                    result.exports = new Map(symbol.exports);
                recordMergedSymbol(result, symbol);
                return result;
            }
            function mergeSymbol(target, source, unidirectional = false) {
                if (!(target.flags & getExcludedSymbolFlags(source.flags)) || (source.flags | target.flags) & 67108864 /* Assignment */) {
                    if (source === target) {
                        return target;
                    }
                    if (!(target.flags & 33554432 /* Transient */)) {
                        const resolvedTarget = resolveSymbol(target);
                        if (resolvedTarget === unknownSymbol) {
                            return source;
                        }
                        target = cloneSymbol(resolvedTarget);
                    }
                    if (source.flags & 512 /* ValueModule */ && target.flags & 512 /* ValueModule */ && target.constEnumOnlyModule && !source.constEnumOnlyModule) {
                        target.constEnumOnlyModule = false;
                    }
                    target.flags |= source.flags;
                    if (source.valueDeclaration) {
                        setValueDeclaration(target, source.valueDeclaration);
                    }
                    addRange(target.declarations, source.declarations);
                    if (source.members) {
                        if (!target.members)
                            target.members = createSymbolTable();
                        mergeSymbolTable(target.members, source.members, unidirectional);
                    }
                    if (source.exports) {
                        if (!target.exports)
                            target.exports = createSymbolTable();
                        mergeSymbolTable(target.exports, source.exports, unidirectional);
                    }
                    if (!unidirectional) {
                        recordMergedSymbol(target, source);
                    }
                }
                else if (target.flags & 1024 /* NamespaceModule */) {
                    if (target !== globalThisSymbol) {
                        error2(source.declarations && getNameOfDeclaration(source.declarations[0]), Diagnostics.Cannot_augment_module_0_with_value_exports_because_it_resolves_to_a_non_module_entity, symbolToString(target));
                    }
                }
                else {
                    const isEitherEnum = !!(target.flags & 384 /* Enum */ || source.flags & 384 /* Enum */);
                    const isEitherBlockScoped = !!(target.flags & 2 /* BlockScopedVariable */ || source.flags & 2 /* BlockScopedVariable */);
                    const message = isEitherEnum ? Diagnostics.Enum_declarations_can_only_merge_with_namespace_or_other_enum_declarations : isEitherBlockScoped ? Diagnostics.Cannot_redeclare_block_scoped_variable_0 : Diagnostics.Duplicate_identifier_0;
                    const sourceSymbolFile = source.declarations && getSourceFileOfNode(source.declarations[0]);
                    const targetSymbolFile = target.declarations && getSourceFileOfNode(target.declarations[0]);
                    const isSourcePlainJs = isPlainJsFile(sourceSymbolFile, compilerOptions.checkJs);
                    const isTargetPlainJs = isPlainJsFile(targetSymbolFile, compilerOptions.checkJs);
                    const symbolName2 = symbolToString(source);
                    if (sourceSymbolFile && targetSymbolFile && amalgamatedDuplicates && !isEitherEnum && sourceSymbolFile !== targetSymbolFile) {
                        const firstFile = comparePaths(sourceSymbolFile.path, targetSymbolFile.path) === -1 /* LessThan */ ? sourceSymbolFile : targetSymbolFile;
                        const secondFile = firstFile === sourceSymbolFile ? targetSymbolFile : sourceSymbolFile;
                        const filesDuplicates = getOrUpdate(amalgamatedDuplicates, `${firstFile.path}|${secondFile.path}`, () => ({ firstFile, secondFile, conflictingSymbols: /* @__PURE__ */ new Map() }));
                        const conflictingSymbolInfo = getOrUpdate(filesDuplicates.conflictingSymbols, symbolName2, () => ({ isBlockScoped: isEitherBlockScoped, firstFileLocations: [], secondFileLocations: [] }));
                        if (!isSourcePlainJs)
                            addDuplicateLocations(conflictingSymbolInfo.firstFileLocations, source);
                        if (!isTargetPlainJs)
                            addDuplicateLocations(conflictingSymbolInfo.secondFileLocations, target);
                    }
                    else {
                        if (!isSourcePlainJs)
                            addDuplicateDeclarationErrorsForSymbols(source, message, symbolName2, target);
                        if (!isTargetPlainJs)
                            addDuplicateDeclarationErrorsForSymbols(target, message, symbolName2, source);
                    }
                }
                return target;
                function addDuplicateLocations(locs, symbol) {
                    if (symbol.declarations) {
                        for (const decl of symbol.declarations) {
                            pushIfUnique(locs, decl);
                        }
                    }
                }
            }
            function addDuplicateDeclarationErrorsForSymbols(target, message, symbolName2, source) {
                forEach(target.declarations, (node) => {
                    addDuplicateDeclarationError(node, message, symbolName2, source.declarations);
                });
            }
            function addDuplicateDeclarationError(node, message, symbolName2, relatedNodes) {
                const errorNode = (getExpandoInitializer(node, 
                /*isPrototypeAssignment*/
                false) ? getNameOfExpando(node) : getNameOfDeclaration(node)) || node;
                const err = lookupOrIssueError(errorNode, message, symbolName2);
                for (const relatedNode of relatedNodes || emptyArray) {
                    const adjustedNode = (getExpandoInitializer(relatedNode, 
                    /*isPrototypeAssignment*/
                    false) ? getNameOfExpando(relatedNode) : getNameOfDeclaration(relatedNode)) || relatedNode;
                    if (adjustedNode === errorNode)
                        continue;
                    err.relatedInformation = err.relatedInformation || [];
                    const leadingMessage = createDiagnosticForNode(adjustedNode, Diagnostics._0_was_also_declared_here, symbolName2);
                    const followOnMessage = createDiagnosticForNode(adjustedNode, Diagnostics.and_here);
                    if (length(err.relatedInformation) >= 5 || some(err.relatedInformation, (r) => compareDiagnostics(r, followOnMessage) === 0 /* EqualTo */ || compareDiagnostics(r, leadingMessage) === 0 /* EqualTo */))
                        continue;
                    addRelatedInfo(err, !length(err.relatedInformation) ? leadingMessage : followOnMessage);
                }
            }
            function combineSymbolTables(first2, second) {
                if (!(first2 == null ? void 0 : first2.size))
                    return second;
                if (!(second == null ? void 0 : second.size))
                    return first2;
                const combined = createSymbolTable();
                mergeSymbolTable(combined, first2);
                mergeSymbolTable(combined, second);
                return combined;
            }
            function mergeSymbolTable(target, source, unidirectional = false) {
                source.forEach((sourceSymbol, id) => {
                    const targetSymbol = target.get(id);
                    target.set(id, targetSymbol ? mergeSymbol(targetSymbol, sourceSymbol, unidirectional) : getMergedSymbol(sourceSymbol));
                });
            }
            function mergeModuleAugmentation(moduleName) {
                var _a, _b, _c;
                const moduleAugmentation = moduleName.parent;
                if (((_a = moduleAugmentation.symbol.declarations) == null ? void 0 : _a[0]) !== moduleAugmentation) {
                    Debug.assert(moduleAugmentation.symbol.declarations.length > 1);
                    return;
                }
                if (isGlobalScopeAugmentation(moduleAugmentation)) {
                    mergeSymbolTable(globals, moduleAugmentation.symbol.exports);
                }
                else {
                    const moduleNotFoundError = !(moduleName.parent.parent.flags & 33554432 /* Ambient */) ? Diagnostics.Invalid_module_name_in_augmentation_module_0_cannot_be_found : void 0;
                    let mainModule = resolveExternalModuleNameWorker(moduleName, moduleName, moduleNotFoundError, 
                    /*isForAugmentation*/
                    true);
                    if (!mainModule) {
                        return;
                    }
                    mainModule = resolveExternalModuleSymbol(mainModule);
                    if (mainModule.flags & 1920 /* Namespace */) {
                        if (some(patternAmbientModules, (module2) => mainModule === module2.symbol)) {
                            const merged = mergeSymbol(moduleAugmentation.symbol, mainModule, 
                            /*unidirectional*/
                            true);
                            if (!patternAmbientModuleAugmentations) {
                                patternAmbientModuleAugmentations = /* @__PURE__ */ new Map();
                            }
                            patternAmbientModuleAugmentations.set(moduleName.text, merged);
                        }
                        else {
                            if (((_b = mainModule.exports) == null ? void 0 : _b.get("__export" /* ExportStar */)) && ((_c = moduleAugmentation.symbol.exports) == null ? void 0 : _c.size)) {
                                const resolvedExports = getResolvedMembersOrExportsOfSymbol(mainModule, "resolvedExports" /* resolvedExports */);
                                for (const [key, value] of arrayFrom(moduleAugmentation.symbol.exports.entries())) {
                                    if (resolvedExports.has(key) && !mainModule.exports.has(key)) {
                                        mergeSymbol(resolvedExports.get(key), value);
                                    }
                                }
                            }
                            mergeSymbol(mainModule, moduleAugmentation.symbol);
                        }
                    }
                    else {
                        error2(moduleName, Diagnostics.Cannot_augment_module_0_because_it_resolves_to_a_non_module_entity, moduleName.text);
                    }
                }
            }
            function addToSymbolTable(target, source, message) {
                source.forEach((sourceSymbol, id) => {
                    const targetSymbol = target.get(id);
                    if (targetSymbol) {
                        forEach(targetSymbol.declarations, addDeclarationDiagnostic(unescapeLeadingUnderscores(id), message));
                    }
                    else {
                        target.set(id, sourceSymbol);
                    }
                });
                function addDeclarationDiagnostic(id, message2) {
                    return (declaration) => diagnostics.add(createDiagnosticForNode(declaration, message2, id));
                }
            }
            function getSymbolLinks(symbol) {
                if (symbol.flags & 33554432 /* Transient */)
                    return symbol.links;
                const id = getSymbolId(symbol);
                return symbolLinks[id] ?? (symbolLinks[id] = new SymbolLinks());
            }
            function getNodeLinks(node) {
                const nodeId = getNodeId(node);
                return nodeLinks[nodeId] || (nodeLinks[nodeId] = new NodeLinks());
            }
            function isGlobalSourceFile(node) {
                return node.kind === 312 /* SourceFile */ && !isExternalOrCommonJsModule(node);
            }
            function getSymbol2(symbols, name, meaning) {
                if (meaning) {
                    const symbol = getMergedSymbol(symbols.get(name));
                    if (symbol) {
                        Debug.assert((getCheckFlags(symbol) & 1 /* Instantiated */) === 0, "Should never get an instantiated symbol here.");
                        if (symbol.flags & meaning) {
                            return symbol;
                        }
                        if (symbol.flags & 2097152 /* Alias */) {
                            const targetFlags = getSymbolFlags(symbol);
                            if (targetFlags & meaning) {
                                return symbol;
                            }
                        }
                    }
                }
            }
            function getSymbolsOfParameterPropertyDeclaration(parameter, parameterName) {
                const constructorDeclaration = parameter.parent;
                const classDeclaration = parameter.parent.parent;
                const parameterSymbol = getSymbol2(constructorDeclaration.locals, parameterName, 111551 /* Value */);
                const propertySymbol = getSymbol2(getMembersOfSymbol(classDeclaration.symbol), parameterName, 111551 /* Value */);
                if (parameterSymbol && propertySymbol) {
                    return [parameterSymbol, propertySymbol];
                }
                return Debug.fail("There should exist two symbols, one as property declaration and one as parameter declaration");
            }
            function isBlockScopedNameDeclaredBeforeUse(declaration, usage) {
                const declarationFile = getSourceFileOfNode(declaration);
                const useFile = getSourceFileOfNode(usage);
                const declContainer = getEnclosingBlockScopeContainer(declaration);
                if (declarationFile !== useFile) {
                    if (moduleKind && (declarationFile.externalModuleIndicator || useFile.externalModuleIndicator) || !outFile(compilerOptions) || isInTypeQuery(usage) || declaration.flags & 33554432 /* Ambient */) {
                        return true;
                    }
                    if (isUsedInFunctionOrInstanceProperty(usage, declaration)) {
                        return true;
                    }
                    const sourceFiles = host.getSourceFiles();
                    return sourceFiles.indexOf(declarationFile) <= sourceFiles.indexOf(useFile);
                }
                if (!!(usage.flags & 16777216 /* JSDoc */) || isInTypeQuery(usage) || isInAmbientOrTypeNode(usage)) {
                    return true;
                }
                if (declaration.pos <= usage.pos && !(isPropertyDeclaration(declaration) && isThisProperty(usage.parent) && !declaration.initializer && !declaration.exclamationToken)) {
                    if (declaration.kind === 208 /* BindingElement */) {
                        const errorBindingElement = getAncestor(usage, 208 /* BindingElement */);
                        if (errorBindingElement) {
                            return findAncestor(errorBindingElement, isBindingElement) !== findAncestor(declaration, isBindingElement) || declaration.pos < errorBindingElement.pos;
                        }
                        return isBlockScopedNameDeclaredBeforeUse(getAncestor(declaration, 260 /* VariableDeclaration */), usage);
                    }
                    else if (declaration.kind === 260 /* VariableDeclaration */) {
                        return !isImmediatelyUsedInInitializerOfBlockScopedVariable(declaration, usage);
                    }
                    else if (isClassLike(declaration)) {
                        return !findAncestor(usage, (n) => isComputedPropertyName(n) && n.parent.parent === declaration);
                    }
                    else if (isPropertyDeclaration(declaration)) {
                        return !isPropertyImmediatelyReferencedWithinDeclaration(declaration, usage, 
                        /*stopAtAnyPropertyDeclaration*/
                        false);
                    }
                    else if (isParameterPropertyDeclaration(declaration, declaration.parent)) {
                        return !(emitStandardClassFields && getContainingClass(declaration) === getContainingClass(usage) && isUsedInFunctionOrInstanceProperty(usage, declaration));
                    }
                    return true;
                }
                if (usage.parent.kind === 281 /* ExportSpecifier */ || usage.parent.kind === 277 /* ExportAssignment */ && usage.parent.isExportEquals) {
                    return true;
                }
                if (usage.kind === 277 /* ExportAssignment */ && usage.isExportEquals) {
                    return true;
                }
                if (isUsedInFunctionOrInstanceProperty(usage, declaration)) {
                    if (emitStandardClassFields && getContainingClass(declaration) && (isPropertyDeclaration(declaration) || isParameterPropertyDeclaration(declaration, declaration.parent))) {
                        return !isPropertyImmediatelyReferencedWithinDeclaration(declaration, usage, 
                        /*stopAtAnyPropertyDeclaration*/
                        true);
                    }
                    else {
                        return true;
                    }
                }
                return false;
                function isImmediatelyUsedInInitializerOfBlockScopedVariable(declaration2, usage2) {
                    switch (declaration2.parent.parent.kind) {
                        case 243 /* VariableStatement */:
                        case 248 /* ForStatement */:
                        case 250 /* ForOfStatement */:
                            if (isSameScopeDescendentOf(usage2, declaration2, declContainer)) {
                                return true;
                            }
                            break;
                    }
                    const grandparent = declaration2.parent.parent;
                    return isForInOrOfStatement(grandparent) && isSameScopeDescendentOf(usage2, grandparent.expression, declContainer);
                }
                function isUsedInFunctionOrInstanceProperty(usage2, declaration2) {
                    return !!findAncestor(usage2, (current) => {
                        if (current === declContainer) {
                            return "quit";
                        }
                        if (isFunctionLike(current)) {
                            return true;
                        }
                        if (isClassStaticBlockDeclaration(current)) {
                            return declaration2.pos < usage2.pos;
                        }
                        const propertyDeclaration = tryCast(current.parent, isPropertyDeclaration);
                        if (propertyDeclaration) {
                            const initializerOfProperty = propertyDeclaration.initializer === current;
                            if (initializerOfProperty) {
                                if (isStatic(current.parent)) {
                                    if (declaration2.kind === 174 /* MethodDeclaration */) {
                                        return true;
                                    }
                                    if (isPropertyDeclaration(declaration2) && getContainingClass(usage2) === getContainingClass(declaration2)) {
                                        const propName = declaration2.name;
                                        if (isIdentifier(propName) || isPrivateIdentifier(propName)) {
                                            const type = getTypeOfSymbol(getSymbolOfDeclaration(declaration2));
                                            const staticBlocks = filter(declaration2.parent.members, isClassStaticBlockDeclaration);
                                            if (isPropertyInitializedInStaticBlocks(propName, type, staticBlocks, declaration2.parent.pos, current.pos)) {
                                                return true;
                                            }
                                        }
                                    }
                                }
                                else {
                                    const isDeclarationInstanceProperty = declaration2.kind === 172 /* PropertyDeclaration */ && !isStatic(declaration2);
                                    if (!isDeclarationInstanceProperty || getContainingClass(usage2) !== getContainingClass(declaration2)) {
                                        return true;
                                    }
                                }
                            }
                        }
                        return false;
                    });
                }
                function isPropertyImmediatelyReferencedWithinDeclaration(declaration2, usage2, stopAtAnyPropertyDeclaration) {
                    if (usage2.end > declaration2.end) {
                        return false;
                    }
                    const ancestorChangingReferenceScope = findAncestor(usage2, (node) => {
                        if (node === declaration2) {
                            return "quit";
                        }
                        switch (node.kind) {
                            case 219 /* ArrowFunction */:
                                return true;
                            case 172 /* PropertyDeclaration */:
                                return stopAtAnyPropertyDeclaration && (isPropertyDeclaration(declaration2) && node.parent === declaration2.parent || isParameterPropertyDeclaration(declaration2, declaration2.parent) && node.parent === declaration2.parent.parent) ? "quit" : true;
                            case 241 /* Block */:
                                switch (node.parent.kind) {
                                    case 177 /* GetAccessor */:
                                    case 174 /* MethodDeclaration */:
                                    case 178 /* SetAccessor */:
                                        return true;
                                    default:
                                        return false;
                                }
                            default:
                                return false;
                        }
                    });
                    return ancestorChangingReferenceScope === void 0;
                }
            }
            function useOuterVariableScopeInParameter(result, location, lastLocation) {
                const target = getEmitScriptTarget(compilerOptions);
                const functionLocation = location;
                if (isParameter(lastLocation) && functionLocation.body && result.valueDeclaration && result.valueDeclaration.pos >= functionLocation.body.pos && result.valueDeclaration.end <= functionLocation.body.end) {
                    if (target >= 2 /* ES2015 */) {
                        const links = getNodeLinks(functionLocation);
                        if (links.declarationRequiresScopeChange === void 0) {
                            links.declarationRequiresScopeChange = forEach(functionLocation.parameters, requiresScopeChange) || false;
                        }
                        return !links.declarationRequiresScopeChange;
                    }
                }
                return false;
                function requiresScopeChange(node) {
                    return requiresScopeChangeWorker(node.name) || !!node.initializer && requiresScopeChangeWorker(node.initializer);
                }
                function requiresScopeChangeWorker(node) {
                    switch (node.kind) {
                        case 219 /* ArrowFunction */:
                        case 218 /* FunctionExpression */:
                        case 262 /* FunctionDeclaration */:
                        case 176 /* Constructor */:
                            return false;
                        case 174 /* MethodDeclaration */:
                        case 177 /* GetAccessor */:
                        case 178 /* SetAccessor */:
                        case 303 /* PropertyAssignment */:
                            return requiresScopeChangeWorker(node.name);
                        case 172 /* PropertyDeclaration */:
                            if (hasStaticModifier(node)) {
                                return !emitStandardClassFields;
                            }
                            return requiresScopeChangeWorker(node.name);
                        default:
                            if (isNullishCoalesce(node) || isOptionalChain(node)) {
                                return target < 7 /* ES2020 */;
                            }
                            if (isBindingElement(node) && node.dotDotDotToken && isObjectBindingPattern(node.parent)) {
                                return target < 4 /* ES2017 */;
                            }
                            if (isTypeNode(node))
                                return false;
                            return forEachChild(node, requiresScopeChangeWorker) || false;
                    }
                }
            }
            function isConstAssertion(location) {
                return isAssertionExpression(location) && isConstTypeReference(location.type) || isJSDocTypeTag(location) && isConstTypeReference(location.typeExpression);
            }
            function resolveName(location, name, meaning, nameNotFoundMessage, nameArg, isUse, excludeGlobals = false, getSpellingSuggestions = true) {
                return resolveNameHelper(location, name, meaning, nameNotFoundMessage, nameArg, isUse, excludeGlobals, getSpellingSuggestions, getSymbol2);
            }
            function resolveNameHelper(location, name, meaning, nameNotFoundMessage, nameArg, isUse, excludeGlobals, getSpellingSuggestions, lookup) {
                var _a, _b, _c;
                const originalLocation = location;
                let result;
                let lastLocation;
                let lastSelfReferenceLocation;
                let propertyWithInvalidInitializer;
                let associatedDeclarationForContainingInitializerOrBindingName;
                let withinDeferredContext = false;
                const errorLocation = location;
                let grandparent;
                let isInExternalModule = false;
                loop: while (location) {
                    if (name === "const" && isConstAssertion(location)) {
                        return void 0;
                    }
                    if (isModuleOrEnumDeclaration(location) && lastLocation && location.name === lastLocation) {
                        lastLocation = location;
                        location = location.parent;
                    }
                    if (canHaveLocals(location) && location.locals && !isGlobalSourceFile(location)) {
                        if (result = lookup(location.locals, name, meaning)) {
                            let useResult = true;
                            if (isFunctionLike(location) && lastLocation && lastLocation !== location.body) {
                                if (meaning & result.flags & 788968 /* Type */ && lastLocation.kind !== 327 /* JSDoc */) {
                                    useResult = result.flags & 262144 /* TypeParameter */ ? lastLocation === location.type || lastLocation.kind === 169 /* Parameter */ || lastLocation.kind === 348 /* JSDocParameterTag */ || lastLocation.kind === 349 /* JSDocReturnTag */ || lastLocation.kind === 168 /* TypeParameter */ : false;
                                }
                                if (meaning & result.flags & 3 /* Variable */) {
                                    if (useOuterVariableScopeInParameter(result, location, lastLocation)) {
                                        useResult = false;
                                    }
                                    else if (result.flags & 1 /* FunctionScopedVariable */) {
                                        useResult = lastLocation.kind === 169 /* Parameter */ || lastLocation === location.type && !!findAncestor(result.valueDeclaration, isParameter);
                                    }
                                }
                            }
                            else if (location.kind === 194 /* ConditionalType */) {
                                useResult = lastLocation === location.trueType;
                            }
                            if (useResult) {
                                break loop;
                            }
                            else {
                                result = void 0;
                            }
                        }
                    }
                    withinDeferredContext = withinDeferredContext || getIsDeferredContext(location, lastLocation);
                    switch (location.kind) {
                        case 312 /* SourceFile */:
                            if (!isExternalOrCommonJsModule(location))
                                break;
                            isInExternalModule = true;
                        case 267 /* ModuleDeclaration */:
                            const moduleExports = ((_a = getSymbolOfDeclaration(location)) == null ? void 0 : _a.exports) || emptySymbols;
                            if (location.kind === 312 /* SourceFile */ || isModuleDeclaration(location) && location.flags & 33554432 /* Ambient */ && !isGlobalScopeAugmentation(location)) {
                                if (result = moduleExports.get("default" /* Default */)) {
                                    const localSymbol = getLocalSymbolForExportDefault(result);
                                    if (localSymbol && result.flags & meaning && localSymbol.escapedName === name) {
                                        break loop;
                                    }
                                    result = void 0;
                                }
                                const moduleExport = moduleExports.get(name);
                                if (moduleExport && moduleExport.flags === 2097152 /* Alias */ && (getDeclarationOfKind(moduleExport, 281 /* ExportSpecifier */) || getDeclarationOfKind(moduleExport, 280 /* NamespaceExport */))) {
                                    break;
                                }
                            }
                            if (name !== "default" /* Default */ && (result = lookup(moduleExports, name, meaning & 2623475 /* ModuleMember */))) {
                                if (isSourceFile(location) && location.commonJsModuleIndicator && !((_b = result.declarations) == null ? void 0 : _b.some(isJSDocTypeAlias))) {
                                    result = void 0;
                                }
                                else {
                                    break loop;
                                }
                            }
                            break;
                        case 266 /* EnumDeclaration */:
                            if (result = lookup(((_c = getSymbolOfDeclaration(location)) == null ? void 0 : _c.exports) || emptySymbols, name, meaning & 8 /* EnumMember */)) {
                                if (nameNotFoundMessage && getIsolatedModules(compilerOptions) && !(location.flags & 33554432 /* Ambient */) && getSourceFileOfNode(location) !== getSourceFileOfNode(result.valueDeclaration)) {
                                    error2(errorLocation, Diagnostics.Cannot_access_0_from_another_file_without_qualification_when_1_is_enabled_Use_2_instead, unescapeLeadingUnderscores(name), isolatedModulesLikeFlagName, `${unescapeLeadingUnderscores(getSymbolOfNode(location).escapedName)}.${unescapeLeadingUnderscores(name)}`);
                                }
                                break loop;
                            }
                            break;
                        case 172 /* PropertyDeclaration */:
                            if (!isStatic(location)) {
                                const ctor = findConstructorDeclaration(location.parent);
                                if (ctor && ctor.locals) {
                                    if (lookup(ctor.locals, name, meaning & 111551 /* Value */)) {
                                        Debug.assertNode(location, isPropertyDeclaration);
                                        propertyWithInvalidInitializer = location;
                                    }
                                }
                            }
                            break;
                        case 263 /* ClassDeclaration */:
                        case 231 /* ClassExpression */:
                        case 264 /* InterfaceDeclaration */:
                            if (result = lookup(getSymbolOfDeclaration(location).members || emptySymbols, name, meaning & 788968 /* Type */)) {
                                if (!isTypeParameterSymbolDeclaredInContainer(result, location)) {
                                    result = void 0;
                                    break;
                                }
                                if (lastLocation && isStatic(lastLocation)) {
                                    if (nameNotFoundMessage) {
                                        error2(errorLocation, Diagnostics.Static_members_cannot_reference_class_type_parameters);
                                    }
                                    return void 0;
                                }
                                break loop;
                            }
                            if (isClassExpression(location) && meaning & 32 /* Class */) {
                                const className = location.name;
                                if (className && name === className.escapedText) {
                                    result = location.symbol;
                                    break loop;
                                }
                            }
                            break;
                        case 233 /* ExpressionWithTypeArguments */:
                            if (lastLocation === location.expression && location.parent.token === 96 /* ExtendsKeyword */) {
                                const container = location.parent.parent;
                                if (isClassLike(container) && (result = lookup(getSymbolOfDeclaration(container).members, name, meaning & 788968 /* Type */))) {
                                    if (nameNotFoundMessage) {
                                        error2(errorLocation, Diagnostics.Base_class_expressions_cannot_reference_class_type_parameters);
                                    }
                                    return void 0;
                                }
                            }
                            break;
                        case 167 /* ComputedPropertyName */:
                            grandparent = location.parent.parent;
                            if (isClassLike(grandparent) || grandparent.kind === 264 /* InterfaceDeclaration */) {
                                if (result = lookup(getSymbolOfDeclaration(grandparent).members, name, meaning & 788968 /* Type */)) {
                                    if (nameNotFoundMessage) {
                                        error2(errorLocation, Diagnostics.A_computed_property_name_cannot_reference_a_type_parameter_from_its_containing_type);
                                    }
                                    return void 0;
                                }
                            }
                            break;
                        case 219 /* ArrowFunction */:
                            if (getEmitScriptTarget(compilerOptions) >= 2 /* ES2015 */) {
                                break;
                            }
                        case 174 /* MethodDeclaration */:
                        case 176 /* Constructor */:
                        case 177 /* GetAccessor */:
                        case 178 /* SetAccessor */:
                        case 262 /* FunctionDeclaration */:
                            if (meaning & 3 /* Variable */ && name === "arguments") {
                                result = argumentsSymbol;
                                break loop;
                            }
                            break;
                        case 218 /* FunctionExpression */:
                            if (meaning & 3 /* Variable */ && name === "arguments") {
                                result = argumentsSymbol;
                                break loop;
                            }
                            if (meaning & 16 /* Function */) {
                                const functionName = location.name;
                                if (functionName && name === functionName.escapedText) {
                                    result = location.symbol;
                                    break loop;
                                }
                            }
                            break;
                        case 170 /* Decorator */:
                            if (location.parent && location.parent.kind === 169 /* Parameter */) {
                                location = location.parent;
                            }
                            if (location.parent && (isClassElement(location.parent) || location.parent.kind === 263 /* ClassDeclaration */)) {
                                location = location.parent;
                            }
                            break;
                        case 353 /* JSDocTypedefTag */:
                        case 345 /* JSDocCallbackTag */:
                        case 347 /* JSDocEnumTag */:
                            const root = getJSDocRoot(location);
                            if (root) {
                                location = root.parent;
                            }
                            break;
                        case 169 /* Parameter */:
                            if (lastLocation && (lastLocation === location.initializer || lastLocation === location.name && isBindingPattern(lastLocation))) {
                                if (!associatedDeclarationForContainingInitializerOrBindingName) {
                                    associatedDeclarationForContainingInitializerOrBindingName = location;
                                }
                            }
                            break;
                        case 208 /* BindingElement */:
                            if (lastLocation && (lastLocation === location.initializer || lastLocation === location.name && isBindingPattern(lastLocation))) {
                                if (isParameterDeclaration(location) && !associatedDeclarationForContainingInitializerOrBindingName) {
                                    associatedDeclarationForContainingInitializerOrBindingName = location;
                                }
                            }
                            break;
                        case 195 /* InferType */:
                            if (meaning & 262144 /* TypeParameter */) {
                                const parameterName = location.typeParameter.name;
                                if (parameterName && name === parameterName.escapedText) {
                                    result = location.typeParameter.symbol;
                                    break loop;
                                }
                            }
                            break;
                        case 281 /* ExportSpecifier */:
                            if (lastLocation && lastLocation === location.propertyName && location.parent.parent.moduleSpecifier) {
                                location = location.parent.parent.parent;
                            }
                            break;
                    }
                    if (isSelfReferenceLocation(location)) {
                        lastSelfReferenceLocation = location;
                    }
                    lastLocation = location;
                    location = isJSDocTemplateTag(location) ? getEffectiveContainerForJSDocTemplateTag(location) || location.parent : isJSDocParameterTag(location) || isJSDocReturnTag(location) ? getHostSignatureFromJSDoc(location) || location.parent : location.parent;
                }
                if (isUse && result && (!lastSelfReferenceLocation || result !== lastSelfReferenceLocation.symbol)) {
                    result.isReferenced |= meaning;
                }
                if (!result) {
                    if (lastLocation) {
                        Debug.assertNode(lastLocation, isSourceFile);
                        if (lastLocation.commonJsModuleIndicator && name === "exports" && meaning & lastLocation.symbol.flags) {
                            return lastLocation.symbol;
                        }
                    }
                    if (!excludeGlobals) {
                        result = lookup(globals, name, meaning);
                    }
                }
                if (!result) {
                    if (originalLocation && isInJSFile(originalLocation) && originalLocation.parent) {
                        if (isRequireCall(originalLocation.parent, 
                        /*requireStringLiteralLikeArgument*/
                        false)) {
                            return requireSymbol;
                        }
                    }
                }
                function checkAndReportErrorForInvalidInitializer() {
                    if (propertyWithInvalidInitializer && !emitStandardClassFields) {
                        error2(errorLocation, errorLocation && propertyWithInvalidInitializer.type && textRangeContainsPositionInclusive(propertyWithInvalidInitializer.type, errorLocation.pos) ? Diagnostics.Type_of_instance_member_variable_0_cannot_reference_identifier_1_declared_in_the_constructor : Diagnostics.Initializer_of_instance_member_variable_0_cannot_reference_identifier_1_declared_in_the_constructor, declarationNameToString(propertyWithInvalidInitializer.name), diagnosticName(nameArg));
                        return true;
                    }
                    return false;
                }
                if (!result) {
                    if (nameNotFoundMessage) {
                        addLazyDiagnostic(() => {
                            if (!errorLocation || errorLocation.parent.kind !== 331 /* JSDocLink */ && !checkAndReportErrorForMissingPrefix(errorLocation, name, nameArg) && // TODO: GH#18217
                                !checkAndReportErrorForInvalidInitializer() && !checkAndReportErrorForExtendingInterface(errorLocation) && !checkAndReportErrorForUsingTypeAsNamespace(errorLocation, name, meaning) && !checkAndReportErrorForExportingPrimitiveType(errorLocation, name) && !checkAndReportErrorForUsingNamespaceAsTypeOrValue(errorLocation, name, meaning) && !checkAndReportErrorForUsingTypeAsValue(errorLocation, name, meaning) && !checkAndReportErrorForUsingValueAsType(errorLocation, name, meaning)) {
                                let suggestion;
                                let suggestedLib;
                                if (nameArg) {
                                    suggestedLib = getSuggestedLibForNonExistentName(nameArg);
                                    if (suggestedLib) {
                                        error2(errorLocation, nameNotFoundMessage, diagnosticName(nameArg), suggestedLib);
                                    }
                                }
                                if (!suggestedLib && getSpellingSuggestions && suggestionCount < maximumSuggestionCount) {
                                    suggestion = getSuggestedSymbolForNonexistentSymbol(originalLocation, name, meaning);
                                    const isGlobalScopeAugmentationDeclaration = (suggestion == null ? void 0 : suggestion.valueDeclaration) && isAmbientModule(suggestion.valueDeclaration) && isGlobalScopeAugmentation(suggestion.valueDeclaration);
                                    if (isGlobalScopeAugmentationDeclaration) {
                                        suggestion = void 0;
                                    }
                                    if (suggestion) {
                                        const suggestionName = symbolToString(suggestion);
                                        const isUncheckedJS = isUncheckedJSSuggestion(originalLocation, suggestion, 
                                        /*excludeClasses*/
                                        false);
                                        const message = meaning === 1920 /* Namespace */ || nameArg && typeof nameArg !== "string" && nodeIsSynthesized(nameArg) ? Diagnostics.Cannot_find_namespace_0_Did_you_mean_1 : isUncheckedJS ? Diagnostics.Could_not_find_name_0_Did_you_mean_1 : Diagnostics.Cannot_find_name_0_Did_you_mean_1;
                                        const diagnostic = createError(errorLocation, message, diagnosticName(nameArg), suggestionName);
                                        addErrorOrSuggestion(!isUncheckedJS, diagnostic);
                                        if (suggestion.valueDeclaration) {
                                            addRelatedInfo(diagnostic, createDiagnosticForNode(suggestion.valueDeclaration, Diagnostics._0_is_declared_here, suggestionName));
                                        }
                                    }
                                }
                                if (!suggestion && !suggestedLib && nameArg) {
                                    error2(errorLocation, nameNotFoundMessage, diagnosticName(nameArg));
                                }
                                suggestionCount++;
                            }
                        });
                    }
                    return void 0;
                }
                else if (nameNotFoundMessage && checkAndReportErrorForInvalidInitializer()) {
                    return void 0;
                }
                if (nameNotFoundMessage) {
                    addLazyDiagnostic(() => {
                        var _a2;
                        if (errorLocation && (meaning & 2 /* BlockScopedVariable */ || (meaning & 32 /* Class */ || meaning & 384 /* Enum */) && (meaning & 111551 /* Value */) === 111551 /* Value */)) {
                            const exportOrLocalSymbol = getExportSymbolOfValueSymbolIfExported(result);
                            if (exportOrLocalSymbol.flags & 2 /* BlockScopedVariable */ || exportOrLocalSymbol.flags & 32 /* Class */ || exportOrLocalSymbol.flags & 384 /* Enum */) {
                                checkResolvedBlockScopedVariable(exportOrLocalSymbol, errorLocation);
                            }
                        }
                        if (result && isInExternalModule && (meaning & 111551 /* Value */) === 111551 /* Value */ && !(originalLocation.flags & 16777216 /* JSDoc */)) {
                            const merged = getMergedSymbol(result);
                            if (length(merged.declarations) && every(merged.declarations, (d) => isNamespaceExportDeclaration(d) || isSourceFile(d) && !!d.symbol.globalExports)) {
                                errorOrSuggestion(!compilerOptions.allowUmdGlobalAccess, errorLocation, Diagnostics._0_refers_to_a_UMD_global_but_the_current_file_is_a_module_Consider_adding_an_import_instead, unescapeLeadingUnderscores(name));
                            }
                        }
                        if (result && associatedDeclarationForContainingInitializerOrBindingName && !withinDeferredContext && (meaning & 111551 /* Value */) === 111551 /* Value */) {
                            const candidate = getMergedSymbol(getLateBoundSymbol(result));
                            const root = getRootDeclaration(associatedDeclarationForContainingInitializerOrBindingName);
                            if (candidate === getSymbolOfDeclaration(associatedDeclarationForContainingInitializerOrBindingName)) {
                                error2(errorLocation, Diagnostics.Parameter_0_cannot_reference_itself, declarationNameToString(associatedDeclarationForContainingInitializerOrBindingName.name));
                            }
                            else if (candidate.valueDeclaration && candidate.valueDeclaration.pos > associatedDeclarationForContainingInitializerOrBindingName.pos && root.parent.locals && lookup(root.parent.locals, candidate.escapedName, meaning) === candidate) {
                                error2(errorLocation, Diagnostics.Parameter_0_cannot_reference_identifier_1_declared_after_it, declarationNameToString(associatedDeclarationForContainingInitializerOrBindingName.name), declarationNameToString(errorLocation));
                            }
                        }
                        if (result && errorLocation && meaning & 111551 /* Value */ && result.flags & 2097152 /* Alias */ && !(result.flags & 111551 /* Value */) && !isValidTypeOnlyAliasUseSite(errorLocation)) {
                            const typeOnlyDeclaration = getTypeOnlyAliasDeclaration(result, 111551 /* Value */);
                            if (typeOnlyDeclaration) {
                                const message = typeOnlyDeclaration.kind === 281 /* ExportSpecifier */ || typeOnlyDeclaration.kind === 278 /* ExportDeclaration */ || typeOnlyDeclaration.kind === 280 /* NamespaceExport */ ? Diagnostics._0_cannot_be_used_as_a_value_because_it_was_exported_using_export_type : Diagnostics._0_cannot_be_used_as_a_value_because_it_was_imported_using_import_type;
                                const unescapedName = unescapeLeadingUnderscores(name);
                                addTypeOnlyDeclarationRelatedInfo(error2(errorLocation, message, unescapedName), typeOnlyDeclaration, unescapedName);
                            }
                        }
                        if (compilerOptions.isolatedModules && result && isInExternalModule && (meaning & 111551 /* Value */) === 111551 /* Value */) {
                            const isGlobal = lookup(globals, name, meaning) === result;
                            const nonValueSymbol = isGlobal && isSourceFile(lastLocation) && lastLocation.locals && lookup(lastLocation.locals, name, ~111551 /* Value */);
                            if (nonValueSymbol) {
                                const importDecl = (_a2 = nonValueSymbol.declarations) == null ? void 0 : _a2.find((d) => d.kind === 276 /* ImportSpecifier */ || d.kind === 273 /* ImportClause */ || d.kind === 274 /* NamespaceImport */ || d.kind === 271 /* ImportEqualsDeclaration */);
                                if (importDecl && !isTypeOnlyImportDeclaration(importDecl)) {
                                    error2(importDecl, Diagnostics.Import_0_conflicts_with_global_value_used_in_this_file_so_must_be_declared_with_a_type_only_import_when_isolatedModules_is_enabled, unescapeLeadingUnderscores(name));
                                }
                            }
                        }
                    });
                }
                return result;
            }
            function addTypeOnlyDeclarationRelatedInfo(diagnostic, typeOnlyDeclaration, unescapedName) {
                if (!typeOnlyDeclaration)
                    return diagnostic;
                return addRelatedInfo(diagnostic, createDiagnosticForNode(typeOnlyDeclaration, typeOnlyDeclaration.kind === 281 /* ExportSpecifier */ || typeOnlyDeclaration.kind === 278 /* ExportDeclaration */ || typeOnlyDeclaration.kind === 280 /* NamespaceExport */ ? Diagnostics._0_was_exported_here : Diagnostics._0_was_imported_here, unescapedName));
            }
            function getIsDeferredContext(location, lastLocation) {
                if (location.kind !== 219 /* ArrowFunction */ && location.kind !== 218 /* FunctionExpression */) {
                    return isTypeQueryNode(location) || (isFunctionLikeDeclaration(location) || location.kind === 172 /* PropertyDeclaration */ && !isStatic(location)) && (!lastLocation || lastLocation !== location.name);
                }
                if (lastLocation && lastLocation === location.name) {
                    return false;
                }
                if (location.asteriskToken || hasSyntacticModifier(location, 1024 /* Async */)) {
                    return true;
                }
                return !getImmediatelyInvokedFunctionExpression(location);
            }
            function isSelfReferenceLocation(node) {
                switch (node.kind) {
                    case 262 /* FunctionDeclaration */:
                    case 263 /* ClassDeclaration */:
                    case 264 /* InterfaceDeclaration */:
                    case 266 /* EnumDeclaration */:
                    case 265 /* TypeAliasDeclaration */:
                    case 267 /* ModuleDeclaration */:
                        return true;
                    default:
                        return false;
                }
            }
            function diagnosticName(nameArg) {
                return isString(nameArg) ? unescapeLeadingUnderscores(nameArg) : declarationNameToString(nameArg);
            }
            function isTypeParameterSymbolDeclaredInContainer(symbol, container) {
                if (symbol.declarations) {
                    for (const decl of symbol.declarations) {
                        if (decl.kind === 168 /* TypeParameter */) {
                            const parent2 = isJSDocTemplateTag(decl.parent) ? getJSDocHost(decl.parent) : decl.parent;
                            if (parent2 === container) {
                                return !(isJSDocTemplateTag(decl.parent) && find(decl.parent.parent.tags, isJSDocTypeAlias));
                            }
                        }
                    }
                }
                return false;
            }
            function checkAndReportErrorForMissingPrefix(errorLocation, name, nameArg) {
                if (!isIdentifier(errorLocation) || errorLocation.escapedText !== name || isTypeReferenceIdentifier(errorLocation) || isInTypeQuery(errorLocation)) {
                    return false;
                }
                const container = getThisContainer(errorLocation, 
                /*includeArrowFunctions*/
                false, 
                /*includeClassComputedPropertyName*/
                false);
                let location = container;
                while (location) {
                    if (isClassLike(location.parent)) {
                        const classSymbol = getSymbolOfDeclaration(location.parent);
                        if (!classSymbol) {
                            break;
                        }
                        const constructorType = getTypeOfSymbol(classSymbol);
                        if (getPropertyOfType(constructorType, name)) {
                            error2(errorLocation, Diagnostics.Cannot_find_name_0_Did_you_mean_the_static_member_1_0, diagnosticName(nameArg), symbolToString(classSymbol));
                            return true;
                        }
                        if (location === container && !isStatic(location)) {
                            const instanceType = getDeclaredTypeOfSymbol(classSymbol).thisType;
                            if (getPropertyOfType(instanceType, name)) {
                                error2(errorLocation, Diagnostics.Cannot_find_name_0_Did_you_mean_the_instance_member_this_0, diagnosticName(nameArg));
                                return true;
                            }
                        }
                    }
                    location = location.parent;
                }
                return false;
            }
            function checkAndReportErrorForExtendingInterface(errorLocation) {
                const expression = getEntityNameForExtendingInterface(errorLocation);
                if (expression && resolveEntityName(expression, 64 /* Interface */, 
                /*ignoreErrors*/
                true)) {
                    error2(errorLocation, Diagnostics.Cannot_extend_an_interface_0_Did_you_mean_implements, getTextOfNode(expression));
                    return true;
                }
                return false;
            }
            function getEntityNameForExtendingInterface(node) {
                switch (node.kind) {
                    case 80 /* Identifier */:
                    case 211 /* PropertyAccessExpression */:
                        return node.parent ? getEntityNameForExtendingInterface(node.parent) : void 0;
                    case 233 /* ExpressionWithTypeArguments */:
                        if (isEntityNameExpression(node.expression)) {
                            return node.expression;
                        }
                    default:
                        return void 0;
                }
            }
            function checkAndReportErrorForUsingTypeAsNamespace(errorLocation, name, meaning) {
                const namespaceMeaning = 1920 /* Namespace */ | (isInJSFile(errorLocation) ? 111551 /* Value */ : 0);
                if (meaning === namespaceMeaning) {
                    const symbol = resolveSymbol(resolveName(errorLocation, name, 788968 /* Type */ & ~namespaceMeaning, 
                    /*nameNotFoundMessage*/
                    void 0, 
                    /*nameArg*/
                    void 0, 
                    /*isUse*/
                    false));
                    const parent2 = errorLocation.parent;
                    if (symbol) {
                        if (isQualifiedName(parent2)) {
                            Debug.assert(parent2.left === errorLocation, "Should only be resolving left side of qualified name as a namespace");
                            const propName = parent2.right.escapedText;
                            const propType = getPropertyOfType(getDeclaredTypeOfSymbol(symbol), propName);
                            if (propType) {
                                error2(parent2, Diagnostics.Cannot_access_0_1_because_0_is_a_type_but_not_a_namespace_Did_you_mean_to_retrieve_the_type_of_the_property_1_in_0_with_0_1, unescapeLeadingUnderscores(name), unescapeLeadingUnderscores(propName));
                                return true;
                            }
                        }
                        error2(errorLocation, Diagnostics._0_only_refers_to_a_type_but_is_being_used_as_a_namespace_here, unescapeLeadingUnderscores(name));
                        return true;
                    }
                }
                return false;
            }
            function checkAndReportErrorForUsingValueAsType(errorLocation, name, meaning) {
                if (meaning & (788968 /* Type */ & ~1920 /* Namespace */)) {
                    const symbol = resolveSymbol(resolveName(errorLocation, name, ~788968 /* Type */ & 111551 /* Value */, 
                    /*nameNotFoundMessage*/
                    void 0, 
                    /*nameArg*/
                    void 0, 
                    /*isUse*/
                    false));
                    if (symbol && !(symbol.flags & 1920 /* Namespace */)) {
                        error2(errorLocation, Diagnostics._0_refers_to_a_value_but_is_being_used_as_a_type_here_Did_you_mean_typeof_0, unescapeLeadingUnderscores(name));
                        return true;
                    }
                }
                return false;
            }
            function isPrimitiveTypeName(name) {
                return name === "any" || name === "string" || name === "number" || name === "boolean" || name === "never" || name === "unknown";
            }
            function checkAndReportErrorForExportingPrimitiveType(errorLocation, name) {
                if (isPrimitiveTypeName(name) && errorLocation.parent.kind === 281 /* ExportSpecifier */) {
                    error2(errorLocation, Diagnostics.Cannot_export_0_Only_local_declarations_can_be_exported_from_a_module, name);
                    return true;
                }
                return false;
            }
            function checkAndReportErrorForUsingTypeAsValue(errorLocation, name, meaning) {
                if (meaning & 111551 /* Value */) {
                    if (isPrimitiveTypeName(name)) {
                        const grandparent = errorLocation.parent.parent;
                        if (grandparent && grandparent.parent && isHeritageClause(grandparent)) {
                            const heritageKind = grandparent.token;
                            const containerKind = grandparent.parent.kind;
                            if (containerKind === 264 /* InterfaceDeclaration */ && heritageKind === 96 /* ExtendsKeyword */) {
                                error2(errorLocation, Diagnostics.An_interface_cannot_extend_a_primitive_type_like_0_It_can_only_extend_other_named_object_types, unescapeLeadingUnderscores(name));
                            }
                            else if (containerKind === 263 /* ClassDeclaration */ && heritageKind === 96 /* ExtendsKeyword */) {
                                error2(errorLocation, Diagnostics.A_class_cannot_extend_a_primitive_type_like_0_Classes_can_only_extend_constructable_values, unescapeLeadingUnderscores(name));
                            }
                            else if (containerKind === 263 /* ClassDeclaration */ && heritageKind === 119 /* ImplementsKeyword */) {
                                error2(errorLocation, Diagnostics.A_class_cannot_implement_a_primitive_type_like_0_It_can_only_implement_other_named_object_types, unescapeLeadingUnderscores(name));
                            }
                        }
                        else {
                            error2(errorLocation, Diagnostics._0_only_refers_to_a_type_but_is_being_used_as_a_value_here, unescapeLeadingUnderscores(name));
                        }
                        return true;
                    }
                    const symbol = resolveSymbol(resolveName(errorLocation, name, 788968 /* Type */ & ~111551 /* Value */, 
                    /*nameNotFoundMessage*/
                    void 0, 
                    /*nameArg*/
                    void 0, 
                    /*isUse*/
                    false));
                    const allFlags = symbol && getSymbolFlags(symbol);
                    if (symbol && allFlags !== void 0 && !(allFlags & 111551 /* Value */)) {
                        const rawName = unescapeLeadingUnderscores(name);
                        if (isES2015OrLaterConstructorName(name)) {
                            error2(errorLocation, Diagnostics._0_only_refers_to_a_type_but_is_being_used_as_a_value_here_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_es2015_or_later, rawName);
                        }
                        else if (maybeMappedType(errorLocation, symbol)) {
                            error2(errorLocation, Diagnostics._0_only_refers_to_a_type_but_is_being_used_as_a_value_here_Did_you_mean_to_use_1_in_0, rawName, rawName === "K" ? "P" : "K");
                        }
                        else {
                            error2(errorLocation, Diagnostics._0_only_refers_to_a_type_but_is_being_used_as_a_value_here, rawName);
                        }
                        return true;
                    }
                }
                return false;
            }
            function maybeMappedType(node, symbol) {
                const container = findAncestor(node.parent, (n) => isComputedPropertyName(n) || isPropertySignature(n) ? false : isTypeLiteralNode(n) || "quit");
                if (container && container.members.length === 1) {
                    const type = getDeclaredTypeOfSymbol(symbol);
                    return !!(type.flags & 1048576 /* Union */) && allTypesAssignableToKind(type, 384 /* StringOrNumberLiteral */, 
                    /*strict*/
                    true);
                }
                return false;
            }
            function isES2015OrLaterConstructorName(n) {
                switch (n) {
                    case "Promise":
                    case "Symbol":
                    case "Map":
                    case "WeakMap":
                    case "Set":
                    case "WeakSet":
                        return true;
                }
                return false;
            }
            function checkAndReportErrorForUsingNamespaceAsTypeOrValue(errorLocation, name, meaning) {
                if (meaning & (111551 /* Value */ & ~788968 /* Type */)) {
                    const symbol = resolveSymbol(resolveName(errorLocation, name, 1024 /* NamespaceModule */, 
                    /*nameNotFoundMessage*/
                    void 0, 
                    /*nameArg*/
                    void 0, 
                    /*isUse*/
                    false));
                    if (symbol) {
                        error2(errorLocation, Diagnostics.Cannot_use_namespace_0_as_a_value, unescapeLeadingUnderscores(name));
                        return true;
                    }
                }
                else if (meaning & (788968 /* Type */ & ~111551 /* Value */)) {
                    const symbol = resolveSymbol(resolveName(errorLocation, name, 1536 /* Module */, 
                    /*nameNotFoundMessage*/
                    void 0, 
                    /*nameArg*/
                    void 0, 
                    /*isUse*/
                    false));
                    if (symbol) {
                        error2(errorLocation, Diagnostics.Cannot_use_namespace_0_as_a_type, unescapeLeadingUnderscores(name));
                        return true;
                    }
                }
                return false;
            }
            function checkResolvedBlockScopedVariable(result, errorLocation) {
                var _a;
                Debug.assert(!!(result.flags & 2 /* BlockScopedVariable */ || result.flags & 32 /* Class */ || result.flags & 384 /* Enum */));
                if (result.flags & (16 /* Function */ | 1 /* FunctionScopedVariable */ | 67108864 /* Assignment */) && result.flags & 32 /* Class */) {
                    return;
                }
                const declaration = (_a = result.declarations) == null ? void 0 : _a.find((d) => isBlockOrCatchScoped(d) || isClassLike(d) || d.kind === 266 /* EnumDeclaration */);
                if (declaration === void 0)
                    return Debug.fail("checkResolvedBlockScopedVariable could not find block-scoped declaration");
                if (!(declaration.flags & 33554432 /* Ambient */) && !isBlockScopedNameDeclaredBeforeUse(declaration, errorLocation)) {
                    let diagnosticMessage;
                    const declarationName = declarationNameToString(getNameOfDeclaration(declaration));
                    if (result.flags & 2 /* BlockScopedVariable */) {
                        diagnosticMessage = error2(errorLocation, Diagnostics.Block_scoped_variable_0_used_before_its_declaration, declarationName);
                    }
                    else if (result.flags & 32 /* Class */) {
                        diagnosticMessage = error2(errorLocation, Diagnostics.Class_0_used_before_its_declaration, declarationName);
                    }
                    else if (result.flags & 256 /* RegularEnum */) {
                        diagnosticMessage = error2(errorLocation, Diagnostics.Enum_0_used_before_its_declaration, declarationName);
                    }
                    else {
                        Debug.assert(!!(result.flags & 128 /* ConstEnum */));
                        if (getIsolatedModules(compilerOptions)) {
                            diagnosticMessage = error2(errorLocation, Diagnostics.Enum_0_used_before_its_declaration, declarationName);
                        }
                    }
                    if (diagnosticMessage) {
                        addRelatedInfo(diagnosticMessage, createDiagnosticForNode(declaration, Diagnostics._0_is_declared_here, declarationName));
                    }
                }
            }
            function isSameScopeDescendentOf(initial, parent2, stopAt) {
                return !!parent2 && !!findAncestor(initial, (n) => n === parent2 || (n === stopAt || isFunctionLike(n) && (!getImmediatelyInvokedFunctionExpression(n) || getFunctionFlags(n) & 3 /* AsyncGenerator */) ? "quit" : false));
            }
            function getAnyImportSyntax(node) {
                switch (node.kind) {
                    case 271 /* ImportEqualsDeclaration */:
                        return node;
                    case 273 /* ImportClause */:
                        return node.parent;
                    case 274 /* NamespaceImport */:
                        return node.parent.parent;
                    case 276 /* ImportSpecifier */:
                        return node.parent.parent.parent;
                    default:
                        return void 0;
                }
            }
            function getDeclarationOfAliasSymbol(symbol) {
                return symbol.declarations && findLast(symbol.declarations, isAliasSymbolDeclaration2);
            }
            function isAliasSymbolDeclaration2(node) {
                return node.kind === 271 /* ImportEqualsDeclaration */ || node.kind === 270 /* NamespaceExportDeclaration */ || node.kind === 273 /* ImportClause */ && !!node.name || node.kind === 274 /* NamespaceImport */ || node.kind === 280 /* NamespaceExport */ || node.kind === 276 /* ImportSpecifier */ || node.kind === 281 /* ExportSpecifier */ || node.kind === 277 /* ExportAssignment */ && exportAssignmentIsAlias(node) || isBinaryExpression(node) && getAssignmentDeclarationKind(node) === 2 /* ModuleExports */ && exportAssignmentIsAlias(node) || isAccessExpression(node) && isBinaryExpression(node.parent) && node.parent.left === node && node.parent.operatorToken.kind === 64 /* EqualsToken */ && isAliasableOrJsExpression(node.parent.right) || node.kind === 304 /* ShorthandPropertyAssignment */ || node.kind === 303 /* PropertyAssignment */ && isAliasableOrJsExpression(node.initializer) || node.kind === 260 /* VariableDeclaration */ && isVariableDeclarationInitializedToBareOrAccessedRequire(node) || node.kind === 208 /* BindingElement */ && isVariableDeclarationInitializedToBareOrAccessedRequire(node.parent.parent);
            }
            function isAliasableOrJsExpression(e) {
                return isAliasableExpression(e) || isFunctionExpression(e) && isJSConstructor(e);
            }
            function getTargetOfImportEqualsDeclaration(node, dontResolveAlias) {
                const commonJSPropertyAccess = getCommonJSPropertyAccess(node);
                if (commonJSPropertyAccess) {
                    const name = getLeftmostAccessExpression(commonJSPropertyAccess.expression).arguments[0];
                    return isIdentifier(commonJSPropertyAccess.name) ? resolveSymbol(getPropertyOfType(resolveExternalModuleTypeByLiteral(name), commonJSPropertyAccess.name.escapedText)) : void 0;
                }
                if (isVariableDeclaration(node) || node.moduleReference.kind === 283 /* ExternalModuleReference */) {
                    const immediate = resolveExternalModuleName(node, getExternalModuleRequireArgument(node) || getExternalModuleImportEqualsDeclarationExpression(node));
                    const resolved2 = resolveExternalModuleSymbol(immediate);
                    markSymbolOfAliasDeclarationIfTypeOnly(node, immediate, resolved2, 
                    /*overwriteEmpty*/
                    false);
                    return resolved2;
                }
                const resolved = getSymbolOfPartOfRightHandSideOfImportEquals(node.moduleReference, dontResolveAlias);
                checkAndReportErrorForResolvingImportAliasToTypeOnlySymbol(node, resolved);
                return resolved;
            }
            function checkAndReportErrorForResolvingImportAliasToTypeOnlySymbol(node, resolved) {
                if (markSymbolOfAliasDeclarationIfTypeOnly(node, 
                /*immediateTarget*/
                void 0, resolved, 
                /*overwriteEmpty*/
                false) && !node.isTypeOnly) {
                    const typeOnlyDeclaration = getTypeOnlyAliasDeclaration(getSymbolOfDeclaration(node));
                    const isExport = typeOnlyDeclaration.kind === 281 /* ExportSpecifier */ || typeOnlyDeclaration.kind === 278 /* ExportDeclaration */;
                    const message = isExport ? Diagnostics.An_import_alias_cannot_reference_a_declaration_that_was_exported_using_export_type : Diagnostics.An_import_alias_cannot_reference_a_declaration_that_was_imported_using_import_type;
                    const relatedMessage = isExport ? Diagnostics._0_was_exported_here : Diagnostics._0_was_imported_here;
                    const name = typeOnlyDeclaration.kind === 278 /* ExportDeclaration */ ? "*" : unescapeLeadingUnderscores(typeOnlyDeclaration.name.escapedText);
                    addRelatedInfo(error2(node.moduleReference, message), createDiagnosticForNode(typeOnlyDeclaration, relatedMessage, name));
                }
            }
            function resolveExportByName(moduleSymbol, name, sourceNode, dontResolveAlias) {
                const exportValue = moduleSymbol.exports.get("export=" /* ExportEquals */);
                const exportSymbol = exportValue ? getPropertyOfType(getTypeOfSymbol(exportValue), name, 
                /*skipObjectFunctionPropertyAugment*/
                true) : moduleSymbol.exports.get(name);
                const resolved = resolveSymbol(exportSymbol, dontResolveAlias);
                markSymbolOfAliasDeclarationIfTypeOnly(sourceNode, exportSymbol, resolved, 
                /*overwriteEmpty*/
                false);
                return resolved;
            }
            function isSyntacticDefault(node) {
                return isExportAssignment(node) && !node.isExportEquals || hasSyntacticModifier(node, 2048 /* Default */) || isExportSpecifier(node) || isNamespaceExport(node);
            }
            function getUsageModeForExpression(usage) {
                return isStringLiteralLike(usage) ? host.getModeForUsageLocation(getSourceFileOfNode(usage), usage) : void 0;
            }
            function isESMFormatImportImportingCommonjsFormatFile(usageMode, targetMode) {
                return usageMode === 99 /* ESNext */ && targetMode === 1 /* CommonJS */;
            }
            function isOnlyImportedAsDefault(usage) {
                const usageMode = getUsageModeForExpression(usage);
                return usageMode === 99 /* ESNext */ && endsWith(usage.text, ".json" /* Json */);
            }
            function canHaveSyntheticDefault(file, moduleSymbol, dontResolveAlias, usage) {
                const usageMode = file && getUsageModeForExpression(usage);
                if (file && usageMode !== void 0 && 100 /* Node16 */ <= moduleKind && moduleKind <= 199 /* NodeNext */) {
                    const result = isESMFormatImportImportingCommonjsFormatFile(usageMode, file.impliedNodeFormat);
                    if (usageMode === 99 /* ESNext */ || result) {
                        return result;
                    }
                }
                if (!allowSyntheticDefaultImports) {
                    return false;
                }
                if (!file || file.isDeclarationFile) {
                    const defaultExportSymbol = resolveExportByName(moduleSymbol, "default" /* Default */, 
                    /*sourceNode*/
                    void 0, 
                    /*dontResolveAlias*/
                    true);
                    if (defaultExportSymbol && some(defaultExportSymbol.declarations, isSyntacticDefault)) {
                        return false;
                    }
                    if (resolveExportByName(moduleSymbol, escapeLeadingUnderscores("__esModule"), 
                    /*sourceNode*/
                    void 0, dontResolveAlias)) {
                        return false;
                    }
                    return true;
                }
                if (!isSourceFileJS(file)) {
                    return hasExportAssignmentSymbol(moduleSymbol);
                }
                return typeof file.externalModuleIndicator !== "object" && !resolveExportByName(moduleSymbol, escapeLeadingUnderscores("__esModule"), 
                /*sourceNode*/
                void 0, dontResolveAlias);
            }
            function getTargetOfImportClause(node, dontResolveAlias) {
                const moduleSymbol = resolveExternalModuleName(node, node.parent.moduleSpecifier);
                if (moduleSymbol) {
                    return getTargetofModuleDefault(moduleSymbol, node, dontResolveAlias);
                }
            }
            function getTargetofModuleDefault(moduleSymbol, node, dontResolveAlias) {
                var _a;
                let exportDefaultSymbol;
                if (isShorthandAmbientModuleSymbol(moduleSymbol)) {
                    exportDefaultSymbol = moduleSymbol;
                }
                else {
                    exportDefaultSymbol = resolveExportByName(moduleSymbol, "default" /* Default */, node, dontResolveAlias);
                }
                const file = (_a = moduleSymbol.declarations) == null ? void 0 : _a.find(isSourceFile);
                const specifier = getModuleSpecifierForImportOrExport(node);
                if (!specifier) {
                    return exportDefaultSymbol;
                }
                const hasDefaultOnly = isOnlyImportedAsDefault(specifier);
                const hasSyntheticDefault = canHaveSyntheticDefault(file, moduleSymbol, dontResolveAlias, specifier);
                if (!exportDefaultSymbol && !hasSyntheticDefault && !hasDefaultOnly) {
                    if (hasExportAssignmentSymbol(moduleSymbol) && !allowSyntheticDefaultImports) {
                        const compilerOptionName = moduleKind >= 5 /* ES2015 */ ? "allowSyntheticDefaultImports" : "esModuleInterop";
                        const exportEqualsSymbol = moduleSymbol.exports.get("export=" /* ExportEquals */);
                        const exportAssignment = exportEqualsSymbol.valueDeclaration;
                        const err = error2(node.name, Diagnostics.Module_0_can_only_be_default_imported_using_the_1_flag, symbolToString(moduleSymbol), compilerOptionName);
                        if (exportAssignment) {
                            addRelatedInfo(err, createDiagnosticForNode(exportAssignment, Diagnostics.This_module_is_declared_with_export_and_can_only_be_used_with_a_default_import_when_using_the_0_flag, compilerOptionName));
                        }
                    }
                    else if (isImportClause(node)) {
                        reportNonDefaultExport(moduleSymbol, node);
                    }
                    else {
                        errorNoModuleMemberSymbol(moduleSymbol, moduleSymbol, node, isImportOrExportSpecifier(node) && node.propertyName || node.name);
                    }
                }
                else if (hasSyntheticDefault || hasDefaultOnly) {
                    const resolved = resolveExternalModuleSymbol(moduleSymbol, dontResolveAlias) || resolveSymbol(moduleSymbol, dontResolveAlias);
                    markSymbolOfAliasDeclarationIfTypeOnly(node, moduleSymbol, resolved, 
                    /*overwriteEmpty*/
                    false);
                    return resolved;
                }
                markSymbolOfAliasDeclarationIfTypeOnly(node, exportDefaultSymbol, 
                /*finalTarget*/
                void 0, 
                /*overwriteEmpty*/
                false);
                return exportDefaultSymbol;
            }
            function getModuleSpecifierForImportOrExport(node) {
                switch (node.kind) {
                    case 273 /* ImportClause */:
                        return node.parent.moduleSpecifier;
                    case 271 /* ImportEqualsDeclaration */:
                        return isExternalModuleReference(node.moduleReference) ? node.moduleReference.expression : void 0;
                    case 274 /* NamespaceImport */:
                        return node.parent.parent.moduleSpecifier;
                    case 276 /* ImportSpecifier */:
                        return node.parent.parent.parent.moduleSpecifier;
                    case 281 /* ExportSpecifier */:
                        return node.parent.parent.moduleSpecifier;
                    default:
                        return Debug.assertNever(node);
                }
            }
            function reportNonDefaultExport(moduleSymbol, node) {
                var _a, _b, _c;
                if ((_a = moduleSymbol.exports) == null ? void 0 : _a.has(node.symbol.escapedName)) {
                    error2(node.name, Diagnostics.Module_0_has_no_default_export_Did_you_mean_to_use_import_1_from_0_instead, symbolToString(moduleSymbol), symbolToString(node.symbol));
                }
                else {
                    const diagnostic = error2(node.name, Diagnostics.Module_0_has_no_default_export, symbolToString(moduleSymbol));
                    const exportStar = (_b = moduleSymbol.exports) == null ? void 0 : _b.get("__export" /* ExportStar */);
                    if (exportStar) {
                        const defaultExport = (_c = exportStar.declarations) == null ? void 0 : _c.find((decl) => {
                            var _a2, _b2;
                            return !!(isExportDeclaration(decl) && decl.moduleSpecifier && ((_b2 = (_a2 = resolveExternalModuleName(decl, decl.moduleSpecifier)) == null ? void 0 : _a2.exports) == null ? void 0 : _b2.has("default" /* Default */)));
                        });
                        if (defaultExport) {
                            addRelatedInfo(diagnostic, createDiagnosticForNode(defaultExport, Diagnostics.export_Asterisk_does_not_re_export_a_default));
                        }
                    }
                }
            }
            function getTargetOfNamespaceImport(node, dontResolveAlias) {
                const moduleSpecifier = node.parent.parent.moduleSpecifier;
                const immediate = resolveExternalModuleName(node, moduleSpecifier);
                const resolved = resolveESModuleSymbol(immediate, moduleSpecifier, dontResolveAlias, 
                /*suppressInteropError*/
                false);
                markSymbolOfAliasDeclarationIfTypeOnly(node, immediate, resolved, 
                /*overwriteEmpty*/
                false);
                return resolved;
            }
            function getTargetOfNamespaceExport(node, dontResolveAlias) {
                const moduleSpecifier = node.parent.moduleSpecifier;
                const immediate = moduleSpecifier && resolveExternalModuleName(node, moduleSpecifier);
                const resolved = moduleSpecifier && resolveESModuleSymbol(immediate, moduleSpecifier, dontResolveAlias, 
                /*suppressInteropError*/
                false);
                markSymbolOfAliasDeclarationIfTypeOnly(node, immediate, resolved, 
                /*overwriteEmpty*/
                false);
                return resolved;
            }
            function combineValueAndTypeSymbols(valueSymbol, typeSymbol) {
                if (valueSymbol === unknownSymbol && typeSymbol === unknownSymbol) {
                    return unknownSymbol;
                }
                if (valueSymbol.flags & (788968 /* Type */ | 1920 /* Namespace */)) {
                    return valueSymbol;
                }
                const result = createSymbol(valueSymbol.flags | typeSymbol.flags, valueSymbol.escapedName);
                Debug.assert(valueSymbol.declarations || typeSymbol.declarations);
                result.declarations = deduplicate(concatenate(valueSymbol.declarations, typeSymbol.declarations), equateValues);
                result.parent = valueSymbol.parent || typeSymbol.parent;
                if (valueSymbol.valueDeclaration)
                    result.valueDeclaration = valueSymbol.valueDeclaration;
                if (typeSymbol.members)
                    result.members = new Map(typeSymbol.members);
                if (valueSymbol.exports)
                    result.exports = new Map(valueSymbol.exports);
                return result;
            }
            function getExportOfModule(symbol, name, specifier, dontResolveAlias) {
                var _a;
                if (symbol.flags & 1536 /* Module */) {
                    const exportSymbol = getExportsOfSymbol(symbol).get(name.escapedText);
                    const resolved = resolveSymbol(exportSymbol, dontResolveAlias);
                    const exportStarDeclaration = (_a = getSymbolLinks(symbol).typeOnlyExportStarMap) == null ? void 0 : _a.get(name.escapedText);
                    markSymbolOfAliasDeclarationIfTypeOnly(specifier, exportSymbol, resolved, 
                    /*overwriteEmpty*/
                    false, exportStarDeclaration, name.escapedText);
                    return resolved;
                }
            }
            function getPropertyOfVariable(symbol, name) {
                if (symbol.flags & 3 /* Variable */) {
                    const typeAnnotation = symbol.valueDeclaration.type;
                    if (typeAnnotation) {
                        return resolveSymbol(getPropertyOfType(getTypeFromTypeNode(typeAnnotation), name));
                    }
                }
            }
            function getExternalModuleMember(node, specifier, dontResolveAlias = false) {
                var _a;
                const moduleSpecifier = getExternalModuleRequireArgument(node) || node.moduleSpecifier;
                const moduleSymbol = resolveExternalModuleName(node, moduleSpecifier);
                const name = !isPropertyAccessExpression(specifier) && specifier.propertyName || specifier.name;
                if (!isIdentifier(name)) {
                    return void 0;
                }
                const suppressInteropError = name.escapedText === "default" /* Default */ && allowSyntheticDefaultImports;
                const targetSymbol = resolveESModuleSymbol(moduleSymbol, moduleSpecifier, 
                /*dontResolveAlias*/
                false, suppressInteropError);
                if (targetSymbol) {
                    if (name.escapedText) {
                        if (isShorthandAmbientModuleSymbol(moduleSymbol)) {
                            return moduleSymbol;
                        }
                        let symbolFromVariable;
                        if (moduleSymbol && moduleSymbol.exports && moduleSymbol.exports.get("export=" /* ExportEquals */)) {
                            symbolFromVariable = getPropertyOfType(getTypeOfSymbol(targetSymbol), name.escapedText, 
                            /*skipObjectFunctionPropertyAugment*/
                            true);
                        }
                        else {
                            symbolFromVariable = getPropertyOfVariable(targetSymbol, name.escapedText);
                        }
                        symbolFromVariable = resolveSymbol(symbolFromVariable, dontResolveAlias);
                        let symbolFromModule = getExportOfModule(targetSymbol, name, specifier, dontResolveAlias);
                        if (symbolFromModule === void 0 && name.escapedText === "default" /* Default */) {
                            const file = (_a = moduleSymbol.declarations) == null ? void 0 : _a.find(isSourceFile);
                            if (isOnlyImportedAsDefault(moduleSpecifier) || canHaveSyntheticDefault(file, moduleSymbol, dontResolveAlias, moduleSpecifier)) {
                                symbolFromModule = resolveExternalModuleSymbol(moduleSymbol, dontResolveAlias) || resolveSymbol(moduleSymbol, dontResolveAlias);
                            }
                        }
                        const symbol = symbolFromModule && symbolFromVariable && symbolFromModule !== symbolFromVariable ? combineValueAndTypeSymbols(symbolFromVariable, symbolFromModule) : symbolFromModule || symbolFromVariable;
                        if (!symbol) {
                            errorNoModuleMemberSymbol(moduleSymbol, targetSymbol, node, name);
                        }
                        return symbol;
                    }
                }
            }
            function errorNoModuleMemberSymbol(moduleSymbol, targetSymbol, node, name) {
                var _a;
                const moduleName = getFullyQualifiedName(moduleSymbol, node);
                const declarationName = declarationNameToString(name);
                const suggestion = getSuggestedSymbolForNonexistentModule(name, targetSymbol);
                if (suggestion !== void 0) {
                    const suggestionName = symbolToString(suggestion);
                    const diagnostic = error2(name, Diagnostics._0_has_no_exported_member_named_1_Did_you_mean_2, moduleName, declarationName, suggestionName);
                    if (suggestion.valueDeclaration) {
                        addRelatedInfo(diagnostic, createDiagnosticForNode(suggestion.valueDeclaration, Diagnostics._0_is_declared_here, suggestionName));
                    }
                }
                else {
                    if ((_a = moduleSymbol.exports) == null ? void 0 : _a.has("default" /* Default */)) {
                        error2(name, Diagnostics.Module_0_has_no_exported_member_1_Did_you_mean_to_use_import_1_from_0_instead, moduleName, declarationName);
                    }
                    else {
                        reportNonExportedMember(node, name, declarationName, moduleSymbol, moduleName);
                    }
                }
            }
            function reportNonExportedMember(node, name, declarationName, moduleSymbol, moduleName) {
                var _a, _b;
                const localSymbol = (_b = (_a = tryCast(moduleSymbol.valueDeclaration, canHaveLocals)) == null ? void 0 : _a.locals) == null ? void 0 : _b.get(name.escapedText);
                const exports = moduleSymbol.exports;
                if (localSymbol) {
                    const exportedEqualsSymbol = exports == null ? void 0 : exports.get("export=" /* ExportEquals */);
                    if (exportedEqualsSymbol) {
                        getSymbolIfSameReference(exportedEqualsSymbol, localSymbol) ? reportInvalidImportEqualsExportMember(node, name, declarationName, moduleName) : error2(name, Diagnostics.Module_0_has_no_exported_member_1, moduleName, declarationName);
                    }
                    else {
                        const exportedSymbol = exports ? find(symbolsToArray(exports), (symbol) => !!getSymbolIfSameReference(symbol, localSymbol)) : void 0;
                        const diagnostic = exportedSymbol ? error2(name, Diagnostics.Module_0_declares_1_locally_but_it_is_exported_as_2, moduleName, declarationName, symbolToString(exportedSymbol)) : error2(name, Diagnostics.Module_0_declares_1_locally_but_it_is_not_exported, moduleName, declarationName);
                        if (localSymbol.declarations) {
                            addRelatedInfo(diagnostic, ...map(localSymbol.declarations, (decl, index) => createDiagnosticForNode(decl, index === 0 ? Diagnostics._0_is_declared_here : Diagnostics.and_here, declarationName)));
                        }
                    }
                }
                else {
                    error2(name, Diagnostics.Module_0_has_no_exported_member_1, moduleName, declarationName);
                }
            }
            function reportInvalidImportEqualsExportMember(node, name, declarationName, moduleName) {
                if (moduleKind >= 5 /* ES2015 */) {
                    const message = getESModuleInterop(compilerOptions) ? Diagnostics._0_can_only_be_imported_by_using_a_default_import : Diagnostics._0_can_only_be_imported_by_turning_on_the_esModuleInterop_flag_and_using_a_default_import;
                    error2(name, message, declarationName);
                }
                else {
                    if (isInJSFile(node)) {
                        const message = getESModuleInterop(compilerOptions) ? Diagnostics._0_can_only_be_imported_by_using_a_require_call_or_by_using_a_default_import : Diagnostics._0_can_only_be_imported_by_using_a_require_call_or_by_turning_on_the_esModuleInterop_flag_and_using_a_default_import;
                        error2(name, message, declarationName);
                    }
                    else {
                        const message = getESModuleInterop(compilerOptions) ? Diagnostics._0_can_only_be_imported_by_using_import_1_require_2_or_a_default_import : Diagnostics._0_can_only_be_imported_by_using_import_1_require_2_or_by_turning_on_the_esModuleInterop_flag_and_using_a_default_import;
                        error2(name, message, declarationName, declarationName, moduleName);
                    }
                }
            }
            function getTargetOfImportSpecifier(node, dontResolveAlias) {
                if (isImportSpecifier(node) && idText(node.propertyName || node.name) === "default" /* Default */) {
                    const specifier = getModuleSpecifierForImportOrExport(node);
                    const moduleSymbol = specifier && resolveExternalModuleName(node, specifier);
                    if (moduleSymbol) {
                        return getTargetofModuleDefault(moduleSymbol, node, dontResolveAlias);
                    }
                }
                const root = isBindingElement(node) ? getRootDeclaration(node) : node.parent.parent.parent;
                const commonJSPropertyAccess = getCommonJSPropertyAccess(root);
                const resolved = getExternalModuleMember(root, commonJSPropertyAccess || node, dontResolveAlias);
                const name = node.propertyName || node.name;
                if (commonJSPropertyAccess && resolved && isIdentifier(name)) {
                    return resolveSymbol(getPropertyOfType(getTypeOfSymbol(resolved), name.escapedText), dontResolveAlias);
                }
                markSymbolOfAliasDeclarationIfTypeOnly(node, 
                /*immediateTarget*/
                void 0, resolved, 
                /*overwriteEmpty*/
                false);
                return resolved;
            }
            function getCommonJSPropertyAccess(node) {
                if (isVariableDeclaration(node) && node.initializer && isPropertyAccessExpression(node.initializer)) {
                    return node.initializer;
                }
            }
            function getTargetOfNamespaceExportDeclaration(node, dontResolveAlias) {
                if (canHaveSymbol(node.parent)) {
                    const resolved = resolveExternalModuleSymbol(node.parent.symbol, dontResolveAlias);
                    markSymbolOfAliasDeclarationIfTypeOnly(node, 
                    /*immediateTarget*/
                    void 0, resolved, 
                    /*overwriteEmpty*/
                    false);
                    return resolved;
                }
            }
            function getTargetOfExportSpecifier(node, meaning, dontResolveAlias) {
                if (idText(node.propertyName || node.name) === "default" /* Default */) {
                    const specifier = getModuleSpecifierForImportOrExport(node);
                    const moduleSymbol = specifier && resolveExternalModuleName(node, specifier);
                    if (moduleSymbol) {
                        return getTargetofModuleDefault(moduleSymbol, node, !!dontResolveAlias);
                    }
                }
                const resolved = node.parent.parent.moduleSpecifier ? getExternalModuleMember(node.parent.parent, node, dontResolveAlias) : resolveEntityName(node.propertyName || node.name, meaning, 
                /*ignoreErrors*/
                false, dontResolveAlias);
                markSymbolOfAliasDeclarationIfTypeOnly(node, 
                /*immediateTarget*/
                void 0, resolved, 
                /*overwriteEmpty*/
                false);
                return resolved;
            }
            function getTargetOfExportAssignment(node, dontResolveAlias) {
                const expression = isExportAssignment(node) ? node.expression : node.right;
                const resolved = getTargetOfAliasLikeExpression(expression, dontResolveAlias);
                markSymbolOfAliasDeclarationIfTypeOnly(node, 
                /*immediateTarget*/
                void 0, resolved, 
                /*overwriteEmpty*/
                false);
                return resolved;
            }
            function getTargetOfAliasLikeExpression(expression, dontResolveAlias) {
                if (isClassExpression(expression)) {
                    return checkExpressionCached(expression).symbol;
                }
                if (!isEntityName(expression) && !isEntityNameExpression(expression)) {
                    return void 0;
                }
                const aliasLike = resolveEntityName(expression, 111551 /* Value */ | 788968 /* Type */ | 1920 /* Namespace */, 
                /*ignoreErrors*/
                true, dontResolveAlias);
                if (aliasLike) {
                    return aliasLike;
                }
                checkExpressionCached(expression);
                return getNodeLinks(expression).resolvedSymbol;
            }
            function getTargetOfAccessExpression(node, dontRecursivelyResolve) {
                if (!(isBinaryExpression(node.parent) && node.parent.left === node && node.parent.operatorToken.kind === 64 /* EqualsToken */)) {
                    return void 0;
                }
                return getTargetOfAliasLikeExpression(node.parent.right, dontRecursivelyResolve);
            }
            function getTargetOfAliasDeclaration(node, dontRecursivelyResolve = false) {
                switch (node.kind) {
                    case 271 /* ImportEqualsDeclaration */:
                    case 260 /* VariableDeclaration */:
                        return getTargetOfImportEqualsDeclaration(node, dontRecursivelyResolve);
                    case 273 /* ImportClause */:
                        return getTargetOfImportClause(node, dontRecursivelyResolve);
                    case 274 /* NamespaceImport */:
                        return getTargetOfNamespaceImport(node, dontRecursivelyResolve);
                    case 280 /* NamespaceExport */:
                        return getTargetOfNamespaceExport(node, dontRecursivelyResolve);
                    case 276 /* ImportSpecifier */:
                    case 208 /* BindingElement */:
                        return getTargetOfImportSpecifier(node, dontRecursivelyResolve);
                    case 281 /* ExportSpecifier */:
                        return getTargetOfExportSpecifier(node, 111551 /* Value */ | 788968 /* Type */ | 1920 /* Namespace */, dontRecursivelyResolve);
                    case 277 /* ExportAssignment */:
                    case 226 /* BinaryExpression */:
                        return getTargetOfExportAssignment(node, dontRecursivelyResolve);
                    case 270 /* NamespaceExportDeclaration */:
                        return getTargetOfNamespaceExportDeclaration(node, dontRecursivelyResolve);
                    case 304 /* ShorthandPropertyAssignment */:
                        return resolveEntityName(node.name, 111551 /* Value */ | 788968 /* Type */ | 1920 /* Namespace */, 
                        /*ignoreErrors*/
                        true, dontRecursivelyResolve);
                    case 303 /* PropertyAssignment */:
                        return getTargetOfAliasLikeExpression(node.initializer, dontRecursivelyResolve);
                    case 212 /* ElementAccessExpression */:
                    case 211 /* PropertyAccessExpression */:
                        return getTargetOfAccessExpression(node, dontRecursivelyResolve);
                    default:
                        return Debug.fail();
                }
            }
            function isNonLocalAlias(symbol, excludes = 111551 /* Value */ | 788968 /* Type */ | 1920 /* Namespace */) {
                if (!symbol)
                    return false;
                return (symbol.flags & (2097152 /* Alias */ | excludes)) === 2097152 /* Alias */ || !!(symbol.flags & 2097152 /* Alias */ && symbol.flags & 67108864 /* Assignment */);
            }
            function resolveSymbol(symbol, dontResolveAlias) {
                return !dontResolveAlias && isNonLocalAlias(symbol) ? resolveAlias(symbol) : symbol;
            }
            function resolveAlias(symbol) {
                Debug.assert((symbol.flags & 2097152 /* Alias */) !== 0, "Should only get Alias here.");
                const links = getSymbolLinks(symbol);
                if (!links.aliasTarget) {
                    links.aliasTarget = resolvingSymbol;
                    const node = getDeclarationOfAliasSymbol(symbol);
                    if (!node)
                        return Debug.fail();
                    const target = getTargetOfAliasDeclaration(node);
                    if (links.aliasTarget === resolvingSymbol) {
                        links.aliasTarget = target || unknownSymbol;
                    }
                    else {
                        error2(node, Diagnostics.Circular_definition_of_import_alias_0, symbolToString(symbol));
                    }
                }
                else if (links.aliasTarget === resolvingSymbol) {
                    links.aliasTarget = unknownSymbol;
                }
                return links.aliasTarget;
            }
            function tryResolveAlias(symbol) {
                const links = getSymbolLinks(symbol);
                if (links.aliasTarget !== resolvingSymbol) {
                    return resolveAlias(symbol);
                }
                return void 0;
            }
            function getSymbolFlags(symbol, excludeTypeOnlyMeanings, excludeLocalMeanings) {
                const typeOnlyDeclaration = excludeTypeOnlyMeanings && getTypeOnlyAliasDeclaration(symbol);
                const typeOnlyDeclarationIsExportStar = typeOnlyDeclaration && isExportDeclaration(typeOnlyDeclaration);
                const typeOnlyResolution = typeOnlyDeclaration && (typeOnlyDeclarationIsExportStar ? resolveExternalModuleName(typeOnlyDeclaration.moduleSpecifier, typeOnlyDeclaration.moduleSpecifier, 
                /*ignoreErrors*/
                true) : resolveAlias(typeOnlyDeclaration.symbol));
                const typeOnlyExportStarTargets = typeOnlyDeclarationIsExportStar && typeOnlyResolution ? getExportsOfModule(typeOnlyResolution) : void 0;
                let flags = excludeLocalMeanings ? 0 /* None */ : symbol.flags;
                let seenSymbols;
                while (symbol.flags & 2097152 /* Alias */) {
                    const target = getExportSymbolOfValueSymbolIfExported(resolveAlias(symbol));
                    if (!typeOnlyDeclarationIsExportStar && target === typeOnlyResolution || (typeOnlyExportStarTargets == null ? void 0 : typeOnlyExportStarTargets.get(target.escapedName)) === target) {
                        break;
                    }
                    if (target === unknownSymbol) {
                        return -1 /* All */;
                    }
                    if (target === symbol || (seenSymbols == null ? void 0 : seenSymbols.has(target))) {
                        break;
                    }
                    if (target.flags & 2097152 /* Alias */) {
                        if (seenSymbols) {
                            seenSymbols.add(target);
                        }
                        else {
                            seenSymbols = /* @__PURE__ */ new Set([symbol, target]);
                        }
                    }
                    flags |= target.flags;
                    symbol = target;
                }
                return flags;
            }
            function markSymbolOfAliasDeclarationIfTypeOnly(aliasDeclaration, immediateTarget, finalTarget, overwriteEmpty, exportStarDeclaration, exportStarName) {
                if (!aliasDeclaration || isPropertyAccessExpression(aliasDeclaration))
                    return false;
                const sourceSymbol = getSymbolOfDeclaration(aliasDeclaration);
                if (isTypeOnlyImportOrExportDeclaration(aliasDeclaration)) {
                    const links2 = getSymbolLinks(sourceSymbol);
                    links2.typeOnlyDeclaration = aliasDeclaration;
                    return true;
                }
                if (exportStarDeclaration) {
                    const links2 = getSymbolLinks(sourceSymbol);
                    links2.typeOnlyDeclaration = exportStarDeclaration;
                    if (sourceSymbol.escapedName !== exportStarName) {
                        links2.typeOnlyExportStarName = exportStarName;
                    }
                    return true;
                }
                const links = getSymbolLinks(sourceSymbol);
                return markSymbolOfAliasDeclarationIfTypeOnlyWorker(links, immediateTarget, overwriteEmpty) || markSymbolOfAliasDeclarationIfTypeOnlyWorker(links, finalTarget, overwriteEmpty);
            }
            function markSymbolOfAliasDeclarationIfTypeOnlyWorker(aliasDeclarationLinks, target, overwriteEmpty) {
                var _a;
                if (target && (aliasDeclarationLinks.typeOnlyDeclaration === void 0 || overwriteEmpty && aliasDeclarationLinks.typeOnlyDeclaration === false)) {
                    const exportSymbol = ((_a = target.exports) == null ? void 0 : _a.get("export=" /* ExportEquals */)) ?? target;
                    const typeOnly = exportSymbol.declarations && find(exportSymbol.declarations, isTypeOnlyImportOrExportDeclaration);
                    aliasDeclarationLinks.typeOnlyDeclaration = typeOnly ?? getSymbolLinks(exportSymbol).typeOnlyDeclaration ?? false;
                }
                return !!aliasDeclarationLinks.typeOnlyDeclaration;
            }
            function getTypeOnlyAliasDeclaration(symbol, include) {
                if (!(symbol.flags & 2097152 /* Alias */)) {
                    return void 0;
                }
                const links = getSymbolLinks(symbol);
                if (include === void 0) {
                    return links.typeOnlyDeclaration || void 0;
                }
                if (links.typeOnlyDeclaration) {
                    const resolved = links.typeOnlyDeclaration.kind === 278 /* ExportDeclaration */ ? resolveSymbol(getExportsOfModule(links.typeOnlyDeclaration.symbol.parent).get(links.typeOnlyExportStarName || symbol.escapedName)) : resolveAlias(links.typeOnlyDeclaration.symbol);
                    return getSymbolFlags(resolved) & include ? links.typeOnlyDeclaration : void 0;
                }
                return void 0;
            }
            function markExportAsReferenced(node) {
                if (!canCollectSymbolAliasAccessabilityData) {
                    return;
                }
                const symbol = getSymbolOfDeclaration(node);
                const target = resolveAlias(symbol);
                if (target) {
                    const markAlias = target === unknownSymbol || getSymbolFlags(symbol, 
                    /*excludeTypeOnlyMeanings*/
                    true) & 111551 /* Value */ && !isConstEnumOrConstEnumOnlyModule(target);
                    if (markAlias) {
                        markAliasSymbolAsReferenced(symbol);
                    }
                }
            }
            function markAliasSymbolAsReferenced(symbol) {
                Debug.assert(canCollectSymbolAliasAccessabilityData);
                const links = getSymbolLinks(symbol);
                if (!links.referenced) {
                    links.referenced = true;
                    const node = getDeclarationOfAliasSymbol(symbol);
                    if (!node)
                        return Debug.fail();
                    if (isInternalModuleImportEqualsDeclaration(node)) {
                        if (getSymbolFlags(resolveSymbol(symbol)) & 111551 /* Value */) {
                            checkExpressionCached(node.moduleReference);
                        }
                    }
                }
            }
            function markConstEnumAliasAsReferenced(symbol) {
                const links = getSymbolLinks(symbol);
                if (!links.constEnumReferenced) {
                    links.constEnumReferenced = true;
                }
            }
            function getSymbolOfPartOfRightHandSideOfImportEquals(entityName, dontResolveAlias) {
                if (entityName.kind === 80 /* Identifier */ && isRightSideOfQualifiedNameOrPropertyAccess(entityName)) {
                    entityName = entityName.parent;
                }
                if (entityName.kind === 80 /* Identifier */ || entityName.parent.kind === 166 /* QualifiedName */) {
                    return resolveEntityName(entityName, 1920 /* Namespace */, 
                    /*ignoreErrors*/
                    false, dontResolveAlias);
                }
                else {
                    Debug.assert(entityName.parent.kind === 271 /* ImportEqualsDeclaration */);
                    return resolveEntityName(entityName, 111551 /* Value */ | 788968 /* Type */ | 1920 /* Namespace */, 
                    /*ignoreErrors*/
                    false, dontResolveAlias);
                }
            }
            function getFullyQualifiedName(symbol, containingLocation) {
                return symbol.parent ? getFullyQualifiedName(symbol.parent, containingLocation) + "." + symbolToString(symbol) : symbolToString(symbol, containingLocation, 
                /*meaning*/
                void 0, 32 /* DoNotIncludeSymbolChain */ | 4 /* AllowAnyNodeKind */);
            }
            function getContainingQualifiedNameNode(node) {
                while (isQualifiedName(node.parent)) {
                    node = node.parent;
                }
                return node;
            }
            function tryGetQualifiedNameAsValue(node) {
                let left = getFirstIdentifier(node);
                let symbol = resolveName(left, left.escapedText, 111551 /* Value */, 
                /*nameNotFoundMessage*/
                void 0, left, 
                /*isUse*/
                true);
                if (!symbol) {
                    return void 0;
                }
                while (isQualifiedName(left.parent)) {
                    const type = getTypeOfSymbol(symbol);
                    symbol = getPropertyOfType(type, left.parent.right.escapedText);
                    if (!symbol) {
                        return void 0;
                    }
                    left = left.parent;
                }
                return symbol;
            }
            function resolveEntityName(name, meaning, ignoreErrors, dontResolveAlias, location) {
                if (nodeIsMissing(name)) {
                    return void 0;
                }
                const namespaceMeaning = 1920 /* Namespace */ | (isInJSFile(name) ? meaning & 111551 /* Value */ : 0);
                let symbol;
                if (name.kind === 80 /* Identifier */) {
                    const message = meaning === namespaceMeaning || nodeIsSynthesized(name) ? Diagnostics.Cannot_find_namespace_0 : getCannotFindNameDiagnosticForName(getFirstIdentifier(name));
                    const symbolFromJSPrototype = isInJSFile(name) && !nodeIsSynthesized(name) ? resolveEntityNameFromAssignmentDeclaration(name, meaning) : void 0;
                    symbol = getMergedSymbol(resolveName(location || name, name.escapedText, meaning, ignoreErrors || symbolFromJSPrototype ? void 0 : message, name, 
                    /*isUse*/
                    true, 
                    /*excludeGlobals*/
                    false));
                    if (!symbol) {
                        return getMergedSymbol(symbolFromJSPrototype);
                    }
                }
                else if (name.kind === 166 /* QualifiedName */ || name.kind === 211 /* PropertyAccessExpression */) {
                    const left = name.kind === 166 /* QualifiedName */ ? name.left : name.expression;
                    const right = name.kind === 166 /* QualifiedName */ ? name.right : name.name;
                    let namespace = resolveEntityName(left, namespaceMeaning, ignoreErrors, 
                    /*dontResolveAlias*/
                    false, location);
                    if (!namespace || nodeIsMissing(right)) {
                        return void 0;
                    }
                    else if (namespace === unknownSymbol) {
                        return namespace;
                    }
                    if (namespace.valueDeclaration && isInJSFile(namespace.valueDeclaration) && getEmitModuleResolutionKind(compilerOptions) !== 100 /* Bundler */ && isVariableDeclaration(namespace.valueDeclaration) && namespace.valueDeclaration.initializer && isCommonJsRequire(namespace.valueDeclaration.initializer)) {
                        const moduleName = namespace.valueDeclaration.initializer.arguments[0];
                        const moduleSym = resolveExternalModuleName(moduleName, moduleName);
                        if (moduleSym) {
                            const resolvedModuleSymbol = resolveExternalModuleSymbol(moduleSym);
                            if (resolvedModuleSymbol) {
                                namespace = resolvedModuleSymbol;
                            }
                        }
                    }
                    symbol = getMergedSymbol(getSymbol2(getExportsOfSymbol(namespace), right.escapedText, meaning));
                    if (!symbol && namespace.flags & 2097152 /* Alias */) {
                        symbol = getMergedSymbol(getSymbol2(getExportsOfSymbol(resolveAlias(namespace)), right.escapedText, meaning));
                    }
                    if (!symbol) {
                        if (!ignoreErrors) {
                            const namespaceName = getFullyQualifiedName(namespace);
                            const declarationName = declarationNameToString(right);
                            const suggestionForNonexistentModule = getSuggestedSymbolForNonexistentModule(right, namespace);
                            if (suggestionForNonexistentModule) {
                                error2(right, Diagnostics._0_has_no_exported_member_named_1_Did_you_mean_2, namespaceName, declarationName, symbolToString(suggestionForNonexistentModule));
                                return void 0;
                            }
                            const containingQualifiedName = isQualifiedName(name) && getContainingQualifiedNameNode(name);
                            const canSuggestTypeof = globalObjectType && meaning & 788968 /* Type */ && containingQualifiedName && !isTypeOfExpression(containingQualifiedName.parent) && tryGetQualifiedNameAsValue(containingQualifiedName);
                            if (canSuggestTypeof) {
                                error2(containingQualifiedName, Diagnostics._0_refers_to_a_value_but_is_being_used_as_a_type_here_Did_you_mean_typeof_0, entityNameToString(containingQualifiedName));
                                return void 0;
                            }
                            if (meaning & 1920 /* Namespace */ && isQualifiedName(name.parent)) {
                                const exportedTypeSymbol = getMergedSymbol(getSymbol2(getExportsOfSymbol(namespace), right.escapedText, 788968 /* Type */));
                                if (exportedTypeSymbol) {
                                    error2(name.parent.right, Diagnostics.Cannot_access_0_1_because_0_is_a_type_but_not_a_namespace_Did_you_mean_to_retrieve_the_type_of_the_property_1_in_0_with_0_1, symbolToString(exportedTypeSymbol), unescapeLeadingUnderscores(name.parent.right.escapedText));
                                    return void 0;
                                }
                            }
                            error2(right, Diagnostics.Namespace_0_has_no_exported_member_1, namespaceName, declarationName);
                        }
                        return void 0;
                    }
                }
                else {
                    Debug.assertNever(name, "Unknown entity name kind.");
                }
                Debug.assert((getCheckFlags(symbol) & 1 /* Instantiated */) === 0, "Should never get an instantiated symbol here.");
                if (!nodeIsSynthesized(name) && isEntityName(name) && (symbol.flags & 2097152 /* Alias */ || name.parent.kind === 277 /* ExportAssignment */)) {
                    markSymbolOfAliasDeclarationIfTypeOnly(getAliasDeclarationFromName(name), symbol, 
                    /*finalTarget*/
                    void 0, 
                    /*overwriteEmpty*/
                    true);
                }
                return symbol.flags & meaning || dontResolveAlias ? symbol : resolveAlias(symbol);
            }
            function resolveEntityNameFromAssignmentDeclaration(name, meaning) {
                if (isJSDocTypeReference(name.parent)) {
                    const secondaryLocation = getAssignmentDeclarationLocation(name.parent);
                    if (secondaryLocation) {
                        return resolveName(secondaryLocation, name.escapedText, meaning, 
                        /*nameNotFoundMessage*/
                        void 0, name, 
                        /*isUse*/
                        true);
                    }
                }
            }
            function getAssignmentDeclarationLocation(node) {
                const typeAlias = findAncestor(node, (node2) => !(isJSDocNode(node2) || node2.flags & 16777216 /* JSDoc */) ? "quit" : isJSDocTypeAlias(node2));
                if (typeAlias) {
                    return;
                }
                const host2 = getJSDocHost(node);
                if (host2 && isExpressionStatement(host2) && isPrototypePropertyAssignment(host2.expression)) {
                    const symbol = getSymbolOfDeclaration(host2.expression.left);
                    if (symbol) {
                        return getDeclarationOfJSPrototypeContainer(symbol);
                    }
                }
                if (host2 && isFunctionExpression(host2) && isPrototypePropertyAssignment(host2.parent) && isExpressionStatement(host2.parent.parent)) {
                    const symbol = getSymbolOfDeclaration(host2.parent.left);
                    if (symbol) {
                        return getDeclarationOfJSPrototypeContainer(symbol);
                    }
                }
                if (host2 && (isObjectLiteralMethod(host2) || isPropertyAssignment(host2)) && isBinaryExpression(host2.parent.parent) && getAssignmentDeclarationKind(host2.parent.parent) === 6 /* Prototype */) {
                    const symbol = getSymbolOfDeclaration(host2.parent.parent.left);
                    if (symbol) {
                        return getDeclarationOfJSPrototypeContainer(symbol);
                    }
                }
                const sig = getEffectiveJSDocHost(node);
                if (sig && isFunctionLike(sig)) {
                    const symbol = getSymbolOfDeclaration(sig);
                    return symbol && symbol.valueDeclaration;
                }
            }
            function getDeclarationOfJSPrototypeContainer(symbol) {
                const decl = symbol.parent.valueDeclaration;
                if (!decl) {
                    return void 0;
                }
                const initializer = isAssignmentDeclaration(decl) ? getAssignedExpandoInitializer(decl) : hasOnlyExpressionInitializer(decl) ? getDeclaredExpandoInitializer(decl) : void 0;
                return initializer || decl;
            }
            function getExpandoSymbol(symbol) {
                const decl = symbol.valueDeclaration;
                if (!decl || !isInJSFile(decl) || symbol.flags & 524288 /* TypeAlias */ || getExpandoInitializer(decl, 
                /*isPrototypeAssignment*/
                false)) {
                    return void 0;
                }
                const init = isVariableDeclaration(decl) ? getDeclaredExpandoInitializer(decl) : getAssignedExpandoInitializer(decl);
                if (init) {
                    const initSymbol = getSymbolOfNode(init);
                    if (initSymbol) {
                        return mergeJSSymbols(initSymbol, symbol);
                    }
                }
            }
            function resolveExternalModuleName(location, moduleReferenceExpression, ignoreErrors) {
                const isClassic = getEmitModuleResolutionKind(compilerOptions) === 1 /* Classic */;
                const errorMessage = isClassic ? Diagnostics.Cannot_find_module_0_Did_you_mean_to_set_the_moduleResolution_option_to_nodenext_or_to_add_aliases_to_the_paths_option : Diagnostics.Cannot_find_module_0_or_its_corresponding_type_declarations;
                return resolveExternalModuleNameWorker(location, moduleReferenceExpression, ignoreErrors ? void 0 : errorMessage);
            }
            function resolveExternalModuleNameWorker(location, moduleReferenceExpression, moduleNotFoundError, isForAugmentation = false) {
                return isStringLiteralLike(moduleReferenceExpression) ? resolveExternalModule(location, moduleReferenceExpression.text, moduleNotFoundError, moduleReferenceExpression, isForAugmentation) : void 0;
            }
            function resolveExternalModule(location, moduleReference, moduleNotFoundError, errorNode, isForAugmentation = false) {
                var _a, _b, _c, _d, _e, _f, _g, _h, _i, _j, _k;
                if (startsWith(moduleReference, "@types/")) {
                    const diag2 = Diagnostics.Cannot_import_type_declaration_files_Consider_importing_0_instead_of_1;
                    const withoutAtTypePrefix = removePrefix(moduleReference, "@types/");
                    error2(errorNode, diag2, withoutAtTypePrefix, moduleReference);
                }
                const ambientModule = tryFindAmbientModule(moduleReference, 
                /*withAugmentations*/
                true);
                if (ambientModule) {
                    return ambientModule;
                }
                const currentSourceFile = getSourceFileOfNode(location);
                const contextSpecifier = isStringLiteralLike(location) ? location : ((_a = isModuleDeclaration(location) ? location : location.parent && isModuleDeclaration(location.parent) && location.parent.name === location ? location.parent : void 0) == null ? void 0 : _a.name) || ((_b = isLiteralImportTypeNode(location) ? location : void 0) == null ? void 0 : _b.argument.literal) || (isVariableDeclaration(location) && location.initializer && isRequireCall(location.initializer, 
                /*requireStringLiteralLikeArgument*/
                true) ? location.initializer.arguments[0] : void 0) || ((_c = findAncestor(location, isImportCall)) == null ? void 0 : _c.arguments[0]) || ((_d = findAncestor(location, isImportDeclaration)) == null ? void 0 : _d.moduleSpecifier) || ((_e = findAncestor(location, isExternalModuleImportEqualsDeclaration)) == null ? void 0 : _e.moduleReference.expression) || ((_f = findAncestor(location, isExportDeclaration)) == null ? void 0 : _f.moduleSpecifier);
                const mode = contextSpecifier && isStringLiteralLike(contextSpecifier) ? host.getModeForUsageLocation(currentSourceFile, contextSpecifier) : currentSourceFile.impliedNodeFormat;
                const moduleResolutionKind = getEmitModuleResolutionKind(compilerOptions);
                const resolvedModule = (_g = host.getResolvedModule(currentSourceFile, moduleReference, mode)) == null ? void 0 : _g.resolvedModule;
                const resolutionDiagnostic = resolvedModule && getResolutionDiagnostic(compilerOptions, resolvedModule, currentSourceFile);
                const sourceFile = resolvedModule && (!resolutionDiagnostic || resolutionDiagnostic === Diagnostics.Module_0_was_resolved_to_1_but_jsx_is_not_set) && host.getSourceFile(resolvedModule.resolvedFileName);
                if (sourceFile) {
                    if (resolutionDiagnostic) {
                        error2(errorNode, resolutionDiagnostic, moduleReference, resolvedModule.resolvedFileName);
                    }
                    if (resolvedModule.resolvedUsingTsExtension && isDeclarationFileName(moduleReference)) {
                        const importOrExport = ((_h = findAncestor(location, isImportDeclaration)) == null ? void 0 : _h.importClause) || findAncestor(location, or(isImportEqualsDeclaration, isExportDeclaration));
                        if (importOrExport && !importOrExport.isTypeOnly || findAncestor(location, isImportCall)) {
                            error2(errorNode, Diagnostics.A_declaration_file_cannot_be_imported_without_import_type_Did_you_mean_to_import_an_implementation_file_0_instead, getSuggestedImportSource(Debug.checkDefined(tryExtractTSExtension(moduleReference))));
                        }
                    }
                    else if (resolvedModule.resolvedUsingTsExtension && !shouldAllowImportingTsExtension(compilerOptions, currentSourceFile.fileName)) {
                        const importOrExport = ((_i = findAncestor(location, isImportDeclaration)) == null ? void 0 : _i.importClause) || findAncestor(location, or(isImportEqualsDeclaration, isExportDeclaration));
                        if (!((importOrExport == null ? void 0 : importOrExport.isTypeOnly) || findAncestor(location, isImportTypeNode))) {
                            const tsExtension = Debug.checkDefined(tryExtractTSExtension(moduleReference));
                            error2(errorNode, Diagnostics.An_import_path_can_only_end_with_a_0_extension_when_allowImportingTsExtensions_is_enabled, tsExtension);
                        }
                    }
                    if (sourceFile.symbol) {
                        if (resolvedModule.isExternalLibraryImport && !resolutionExtensionIsTSOrJson(resolvedModule.extension)) {
                            errorOnImplicitAnyModule(
                            /*isError*/
                            false, errorNode, currentSourceFile, mode, resolvedModule, moduleReference);
                        }
                        if (moduleResolutionKind === 3 /* Node16 */ || moduleResolutionKind === 99 /* NodeNext */) {
                            const isSyncImport = currentSourceFile.impliedNodeFormat === 1 /* CommonJS */ && !findAncestor(location, isImportCall) || !!findAncestor(location, isImportEqualsDeclaration);
                            const overrideHost = findAncestor(location, (l) => isImportTypeNode(l) || isExportDeclaration(l) || isImportDeclaration(l));
                            if (isSyncImport && sourceFile.impliedNodeFormat === 99 /* ESNext */ && !hasResolutionModeOverride(overrideHost)) {
                                if (findAncestor(location, isImportEqualsDeclaration)) {
                                    error2(errorNode, Diagnostics.Module_0_cannot_be_imported_using_this_construct_The_specifier_only_resolves_to_an_ES_module_which_cannot_be_imported_with_require_Use_an_ECMAScript_import_instead, moduleReference);
                                }
                                else {
                                    let diagnosticDetails;
                                    const ext = tryGetExtensionFromPath2(currentSourceFile.fileName);
                                    if (ext === ".ts" /* Ts */ || ext === ".js" /* Js */ || ext === ".tsx" /* Tsx */ || ext === ".jsx" /* Jsx */) {
                                        const scope = currentSourceFile.packageJsonScope;
                                        const targetExt = ext === ".ts" /* Ts */ ? ".mts" /* Mts */ : ext === ".js" /* Js */ ? ".mjs" /* Mjs */ : void 0;
                                        if (scope && !scope.contents.packageJsonContent.type) {
                                            if (targetExt) {
                                                diagnosticDetails = chainDiagnosticMessages(
                                                /*details*/
                                                void 0, Diagnostics.To_convert_this_file_to_an_ECMAScript_module_change_its_file_extension_to_0_or_add_the_field_type_Colon_module_to_1, targetExt, combinePaths(scope.packageDirectory, "package.json"));
                                            }
                                            else {
                                                diagnosticDetails = chainDiagnosticMessages(
                                                /*details*/
                                                void 0, Diagnostics.To_convert_this_file_to_an_ECMAScript_module_add_the_field_type_Colon_module_to_0, combinePaths(scope.packageDirectory, "package.json"));
                                            }
                                        }
                                        else {
                                            if (targetExt) {
                                                diagnosticDetails = chainDiagnosticMessages(
                                                /*details*/
                                                void 0, Diagnostics.To_convert_this_file_to_an_ECMAScript_module_change_its_file_extension_to_0_or_create_a_local_package_json_file_with_type_Colon_module, targetExt);
                                            }
                                            else {
                                                diagnosticDetails = chainDiagnosticMessages(
                                                /*details*/
                                                void 0, Diagnostics.To_convert_this_file_to_an_ECMAScript_module_create_a_local_package_json_file_with_type_Colon_module);
                                            }
                                        }
                                    }
                                    diagnostics.add(createDiagnosticForNodeFromMessageChain(getSourceFileOfNode(errorNode), errorNode, chainDiagnosticMessages(diagnosticDetails, Diagnostics.The_current_file_is_a_CommonJS_module_whose_imports_will_produce_require_calls_however_the_referenced_file_is_an_ECMAScript_module_and_cannot_be_imported_with_require_Consider_writing_a_dynamic_import_0_call_instead, moduleReference)));
                                }
                            }
                        }
                        return getMergedSymbol(sourceFile.symbol);
                    }
                    if (moduleNotFoundError) {
                        error2(errorNode, Diagnostics.File_0_is_not_a_module, sourceFile.fileName);
                    }
                    return void 0;
                }
                if (patternAmbientModules) {
                    const pattern = findBestPatternMatch(patternAmbientModules, (_) => _.pattern, moduleReference);
                    if (pattern) {
                        const augmentation = patternAmbientModuleAugmentations && patternAmbientModuleAugmentations.get(moduleReference);
                        if (augmentation) {
                            return getMergedSymbol(augmentation);
                        }
                        return getMergedSymbol(pattern.symbol);
                    }
                }
                if (resolvedModule && !resolutionExtensionIsTSOrJson(resolvedModule.extension) && resolutionDiagnostic === void 0 || resolutionDiagnostic === Diagnostics.Could_not_find_a_declaration_file_for_module_0_1_implicitly_has_an_any_type) {
                    if (isForAugmentation) {
                        const diag2 = Diagnostics.Invalid_module_name_in_augmentation_Module_0_resolves_to_an_untyped_module_at_1_which_cannot_be_augmented;
                        error2(errorNode, diag2, moduleReference, resolvedModule.resolvedFileName);
                    }
                    else {
                        errorOnImplicitAnyModule(
                        /*isError*/
                        noImplicitAny && !!moduleNotFoundError, errorNode, currentSourceFile, mode, resolvedModule, moduleReference);
                    }
                    return void 0;
                }
                if (moduleNotFoundError) {
                    if (resolvedModule) {
                        const redirect = host.getProjectReferenceRedirect(resolvedModule.resolvedFileName);
                        if (redirect) {
                            error2(errorNode, Diagnostics.Output_file_0_has_not_been_built_from_source_file_1, redirect, resolvedModule.resolvedFileName);
                            return void 0;
                        }
                    }
                    if (resolutionDiagnostic) {
                        error2(errorNode, resolutionDiagnostic, moduleReference, resolvedModule.resolvedFileName);
                    }
                    else {
                        const isExtensionlessRelativePathImport = pathIsRelative(moduleReference) && !hasExtension(moduleReference);
                        const resolutionIsNode16OrNext = moduleResolutionKind === 3 /* Node16 */ || moduleResolutionKind === 99 /* NodeNext */;
                        if (!getResolveJsonModule(compilerOptions) && fileExtensionIs(moduleReference, ".json" /* Json */) && moduleResolutionKind !== 1 /* Classic */ && hasJsonModuleEmitEnabled(compilerOptions)) {
                            error2(errorNode, Diagnostics.Cannot_find_module_0_Consider_using_resolveJsonModule_to_import_module_with_json_extension, moduleReference);
                        }
                        else if (mode === 99 /* ESNext */ && resolutionIsNode16OrNext && isExtensionlessRelativePathImport) {
                            const absoluteRef = getNormalizedAbsolutePath(moduleReference, getDirectoryPath(currentSourceFile.path));
                            const suggestedExt = (_j = suggestedExtensions.find(([actualExt, _importExt]) => host.fileExists(absoluteRef + actualExt))) == null ? void 0 : _j[1];
                            if (suggestedExt) {
                                error2(errorNode, Diagnostics.Relative_import_paths_need_explicit_file_extensions_in_ECMAScript_imports_when_moduleResolution_is_node16_or_nodenext_Did_you_mean_0, moduleReference + suggestedExt);
                            }
                            else {
                                error2(errorNode, Diagnostics.Relative_import_paths_need_explicit_file_extensions_in_ECMAScript_imports_when_moduleResolution_is_node16_or_nodenext_Consider_adding_an_extension_to_the_import_path);
                            }
                        }
                        else {
                            if ((_k = host.getResolvedModule(currentSourceFile, moduleReference, mode)) == null ? void 0 : _k.alternateResult) {
                                const errorInfo = createModuleNotFoundChain(currentSourceFile, host, moduleReference, mode, moduleReference);
                                errorOrSuggestion(
                                /*isError*/
                                true, errorNode, chainDiagnosticMessages(errorInfo, moduleNotFoundError, moduleReference));
                            }
                            else {
                                error2(errorNode, moduleNotFoundError, moduleReference);
                            }
                        }
                    }
                }
                return void 0;
                function getSuggestedImportSource(tsExtension) {
                    const importSourceWithoutExtension = removeExtension(moduleReference, tsExtension);
                    if (emitModuleKindIsNonNodeESM(moduleKind) || mode === 99 /* ESNext */) {
                        const preferTs = isDeclarationFileName(moduleReference) && shouldAllowImportingTsExtension(compilerOptions);
                        const ext = tsExtension === ".mts" /* Mts */ || tsExtension === ".d.mts" /* Dmts */ ? preferTs ? ".mts" : ".mjs" : tsExtension === ".cts" /* Cts */ || tsExtension === ".d.mts" /* Dmts */ ? preferTs ? ".cts" : ".cjs" : preferTs ? ".ts" : ".js";
                        return importSourceWithoutExtension + ext;
                    }
                    return importSourceWithoutExtension;
                }
            }
            function errorOnImplicitAnyModule(isError, errorNode, sourceFile, mode, { packageId, resolvedFileName }, moduleReference) {
                let errorInfo;
                if (!isExternalModuleNameRelative(moduleReference) && packageId) {
                    errorInfo = createModuleNotFoundChain(sourceFile, host, moduleReference, mode, packageId.name);
                }
                errorOrSuggestion(isError, errorNode, chainDiagnosticMessages(errorInfo, Diagnostics.Could_not_find_a_declaration_file_for_module_0_1_implicitly_has_an_any_type, moduleReference, resolvedFileName));
            }
            function resolveExternalModuleSymbol(moduleSymbol, dontResolveAlias) {
                if (moduleSymbol == null ? void 0 : moduleSymbol.exports) {
                    const exportEquals = resolveSymbol(moduleSymbol.exports.get("export=" /* ExportEquals */), dontResolveAlias);
                    const exported = getCommonJsExportEquals(getMergedSymbol(exportEquals), getMergedSymbol(moduleSymbol));
                    return getMergedSymbol(exported) || moduleSymbol;
                }
                return void 0;
            }
            function getCommonJsExportEquals(exported, moduleSymbol) {
                if (!exported || exported === unknownSymbol || exported === moduleSymbol || moduleSymbol.exports.size === 1 || exported.flags & 2097152 /* Alias */) {
                    return exported;
                }
                const links = getSymbolLinks(exported);
                if (links.cjsExportMerged) {
                    return links.cjsExportMerged;
                }
                const merged = exported.flags & 33554432 /* Transient */ ? exported : cloneSymbol(exported);
                merged.flags = merged.flags | 512 /* ValueModule */;
                if (merged.exports === void 0) {
                    merged.exports = createSymbolTable();
                }
                moduleSymbol.exports.forEach((s, name) => {
                    if (name === "export=" /* ExportEquals */)
                        return;
                    merged.exports.set(name, merged.exports.has(name) ? mergeSymbol(merged.exports.get(name), s) : s);
                });
                if (merged === exported) {
                    getSymbolLinks(merged).resolvedExports = void 0;
                    getSymbolLinks(merged).resolvedMembers = void 0;
                }
                getSymbolLinks(merged).cjsExportMerged = merged;
                return links.cjsExportMerged = merged;
            }
            function resolveESModuleSymbol(moduleSymbol, referencingLocation, dontResolveAlias, suppressInteropError) {
                var _a;
                const symbol = resolveExternalModuleSymbol(moduleSymbol, dontResolveAlias);
                if (!dontResolveAlias && symbol) {
                    if (!suppressInteropError && !(symbol.flags & (1536 /* Module */ | 3 /* Variable */)) && !getDeclarationOfKind(symbol, 312 /* SourceFile */)) {
                        const compilerOptionName = moduleKind >= 5 /* ES2015 */ ? "allowSyntheticDefaultImports" : "esModuleInterop";
                        error2(referencingLocation, Diagnostics.This_module_can_only_be_referenced_with_ECMAScript_imports_Slashexports_by_turning_on_the_0_flag_and_referencing_its_default_export, compilerOptionName);
                        return symbol;
                    }
                    const referenceParent = referencingLocation.parent;
                    if (isImportDeclaration(referenceParent) && getNamespaceDeclarationNode(referenceParent) || isImportCall(referenceParent)) {
                        const reference = isImportCall(referenceParent) ? referenceParent.arguments[0] : referenceParent.moduleSpecifier;
                        const type = getTypeOfSymbol(symbol);
                        const defaultOnlyType = getTypeWithSyntheticDefaultOnly(type, symbol, moduleSymbol, reference);
                        if (defaultOnlyType) {
                            return cloneTypeAsModuleType(symbol, defaultOnlyType, referenceParent);
                        }
                        const targetFile = (_a = moduleSymbol == null ? void 0 : moduleSymbol.declarations) == null ? void 0 : _a.find(isSourceFile);
                        const isEsmCjsRef = targetFile && isESMFormatImportImportingCommonjsFormatFile(getUsageModeForExpression(reference), targetFile.impliedNodeFormat);
                        if (getESModuleInterop(compilerOptions) || isEsmCjsRef) {
                            let sigs = getSignaturesOfStructuredType(type, 0 /* Call */);
                            if (!sigs || !sigs.length) {
                                sigs = getSignaturesOfStructuredType(type, 1 /* Construct */);
                            }
                            if (sigs && sigs.length || getPropertyOfType(type, "default" /* Default */, 
                            /*skipObjectFunctionPropertyAugment*/
                            true) || isEsmCjsRef) {
                                const moduleType = type.flags & 3670016 /* StructuredType */ ? getTypeWithSyntheticDefaultImportType(type, symbol, moduleSymbol, reference) : createDefaultPropertyWrapperForModule(symbol, symbol.parent);
                                return cloneTypeAsModuleType(symbol, moduleType, referenceParent);
                            }
                        }
                    }
                }
                return symbol;
            }
            function cloneTypeAsModuleType(symbol, moduleType, referenceParent) {
                const result = createSymbol(symbol.flags, symbol.escapedName);
                result.declarations = symbol.declarations ? symbol.declarations.slice() : [];
                result.parent = symbol.parent;
                result.links.target = symbol;
                result.links.originatingImport = referenceParent;
                if (symbol.valueDeclaration)
                    result.valueDeclaration = symbol.valueDeclaration;
                if (symbol.constEnumOnlyModule)
                    result.constEnumOnlyModule = true;
                if (symbol.members)
                    result.members = new Map(symbol.members);
                if (symbol.exports)
                    result.exports = new Map(symbol.exports);
                const resolvedModuleType = resolveStructuredTypeMembers(moduleType);
                result.links.type = createAnonymousType(result, resolvedModuleType.members, emptyArray, emptyArray, resolvedModuleType.indexInfos);
                return result;
            }
            function hasExportAssignmentSymbol(moduleSymbol) {
                return moduleSymbol.exports.get("export=" /* ExportEquals */) !== void 0;
            }
            function getExportsOfModuleAsArray(moduleSymbol) {
                return symbolsToArray(getExportsOfModule(moduleSymbol));
            }
            function getExportsAndPropertiesOfModule(moduleSymbol) {
                const exports = getExportsOfModuleAsArray(moduleSymbol);
                const exportEquals = resolveExternalModuleSymbol(moduleSymbol);
                if (exportEquals !== moduleSymbol) {
                    const type = getTypeOfSymbol(exportEquals);
                    if (shouldTreatPropertiesOfExternalModuleAsExports(type)) {
                        addRange(exports, getPropertiesOfType(type));
                    }
                }
                return exports;
            }
            function forEachExportAndPropertyOfModule(moduleSymbol, cb) {
                const exports = getExportsOfModule(moduleSymbol);
                exports.forEach((symbol, key) => {
                    if (!isReservedMemberName(key)) {
                        cb(symbol, key);
                    }
                });
                const exportEquals = resolveExternalModuleSymbol(moduleSymbol);
                if (exportEquals !== moduleSymbol) {
                    const type = getTypeOfSymbol(exportEquals);
                    if (shouldTreatPropertiesOfExternalModuleAsExports(type)) {
                        forEachPropertyOfType(type, (symbol, escapedName) => {
                            cb(symbol, escapedName);
                        });
                    }
                }
            }
            function tryGetMemberInModuleExports(memberName, moduleSymbol) {
                const symbolTable = getExportsOfModule(moduleSymbol);
                if (symbolTable) {
                    return symbolTable.get(memberName);
                }
            }
            function tryGetMemberInModuleExportsAndProperties(memberName, moduleSymbol) {
                const symbol = tryGetMemberInModuleExports(memberName, moduleSymbol);
                if (symbol) {
                    return symbol;
                }
                const exportEquals = resolveExternalModuleSymbol(moduleSymbol);
                if (exportEquals === moduleSymbol) {
                    return void 0;
                }
                const type = getTypeOfSymbol(exportEquals);
                return shouldTreatPropertiesOfExternalModuleAsExports(type) ? getPropertyOfType(type, memberName) : void 0;
            }
            function shouldTreatPropertiesOfExternalModuleAsExports(resolvedExternalModuleType) {
                return !(resolvedExternalModuleType.flags & 402784252 /* Primitive */ || getObjectFlags(resolvedExternalModuleType) & 1 /* Class */ || // `isArrayOrTupleLikeType` is too expensive to use in this auto-imports hot path
                    isArrayType(resolvedExternalModuleType) || isTupleType(resolvedExternalModuleType));
            }
            function getExportsOfSymbol(symbol) {
                return symbol.flags & 6256 /* LateBindingContainer */ ? getResolvedMembersOrExportsOfSymbol(symbol, "resolvedExports" /* resolvedExports */) : symbol.flags & 1536 /* Module */ ? getExportsOfModule(symbol) : symbol.exports || emptySymbols;
            }
            function getExportsOfModule(moduleSymbol) {
                const links = getSymbolLinks(moduleSymbol);
                if (!links.resolvedExports) {
                    const { exports, typeOnlyExportStarMap } = getExportsOfModuleWorker(moduleSymbol);
                    links.resolvedExports = exports;
                    links.typeOnlyExportStarMap = typeOnlyExportStarMap;
                }
                return links.resolvedExports;
            }
            function extendExportSymbols(target, source, lookupTable, exportNode) {
                if (!source)
                    return;
                source.forEach((sourceSymbol, id) => {
                    if (id === "default" /* Default */)
                        return;
                    const targetSymbol = target.get(id);
                    if (!targetSymbol) {
                        target.set(id, sourceSymbol);
                        if (lookupTable && exportNode) {
                            lookupTable.set(id, {
                                specifierText: getTextOfNode(exportNode.moduleSpecifier)
                            });
                        }
                    }
                    else if (lookupTable && exportNode && targetSymbol && resolveSymbol(targetSymbol) !== resolveSymbol(sourceSymbol)) {
                        const collisionTracker = lookupTable.get(id);
                        if (!collisionTracker.exportsWithDuplicate) {
                            collisionTracker.exportsWithDuplicate = [exportNode];
                        }
                        else {
                            collisionTracker.exportsWithDuplicate.push(exportNode);
                        }
                    }
                });
            }
            function getExportsOfModuleWorker(moduleSymbol) {
                const visitedSymbols = [];
                let typeOnlyExportStarMap;
                const nonTypeOnlyNames = /* @__PURE__ */ new Set();
                moduleSymbol = resolveExternalModuleSymbol(moduleSymbol);
                const exports = visit(moduleSymbol) || emptySymbols;
                if (typeOnlyExportStarMap) {
                    nonTypeOnlyNames.forEach((name) => typeOnlyExportStarMap.delete(name));
                }
                return {
                    exports,
                    typeOnlyExportStarMap
                };
                function visit(symbol, exportStar, isTypeOnly) {
                    if (!isTypeOnly && (symbol == null ? void 0 : symbol.exports)) {
                        symbol.exports.forEach((_, name) => nonTypeOnlyNames.add(name));
                    }
                    if (!(symbol && symbol.exports && pushIfUnique(visitedSymbols, symbol))) {
                        return;
                    }
                    const symbols = new Map(symbol.exports);
                    const exportStars = symbol.exports.get("__export" /* ExportStar */);
                    if (exportStars) {
                        const nestedSymbols = createSymbolTable();
                        const lookupTable = /* @__PURE__ */ new Map();
                        if (exportStars.declarations) {
                            for (const node of exportStars.declarations) {
                                const resolvedModule = resolveExternalModuleName(node, node.moduleSpecifier);
                                const exportedSymbols = visit(resolvedModule, node, isTypeOnly || node.isTypeOnly);
                                extendExportSymbols(nestedSymbols, exportedSymbols, lookupTable, node);
                            }
                        }
                        lookupTable.forEach(({ exportsWithDuplicate }, id) => {
                            if (id === "export=" || !(exportsWithDuplicate && exportsWithDuplicate.length) || symbols.has(id)) {
                                return;
                            }
                            for (const node of exportsWithDuplicate) {
                                diagnostics.add(createDiagnosticForNode(node, Diagnostics.Module_0_has_already_exported_a_member_named_1_Consider_explicitly_re_exporting_to_resolve_the_ambiguity, lookupTable.get(id).specifierText, unescapeLeadingUnderscores(id)));
                            }
                        });
                        extendExportSymbols(symbols, nestedSymbols);
                    }
                    if (exportStar == null ? void 0 : exportStar.isTypeOnly) {
                        typeOnlyExportStarMap ?? (typeOnlyExportStarMap = /* @__PURE__ */ new Map());
                        symbols.forEach((_, escapedName) => typeOnlyExportStarMap.set(escapedName, exportStar));
                    }
                    return symbols;
                }
            }
            function getMergedSymbol(symbol) {
                let merged;
                return symbol && symbol.mergeId && (merged = mergedSymbols[symbol.mergeId]) ? merged : symbol;
            }
            function getSymbolOfDeclaration(node) {
                return getMergedSymbol(node.symbol && getLateBoundSymbol(node.symbol));
            }
            function getSymbolOfNode(node) {
                return canHaveSymbol(node) ? getSymbolOfDeclaration(node) : void 0;
            }
            function getParentOfSymbol(symbol) {
                return getMergedSymbol(symbol.parent && getLateBoundSymbol(symbol.parent));
            }
            function getFunctionExpressionParentSymbolOrSymbol(symbol) {
                var _a, _b;
                return ((_a = symbol.valueDeclaration) == null ? void 0 : _a.kind) === 219 /* ArrowFunction */ || ((_b = symbol.valueDeclaration) == null ? void 0 : _b.kind) === 218 /* FunctionExpression */ ? getSymbolOfNode(symbol.valueDeclaration.parent) || symbol : symbol;
            }
            function getAlternativeContainingModules(symbol, enclosingDeclaration) {
                const containingFile = getSourceFileOfNode(enclosingDeclaration);
                const id = getNodeId(containingFile);
                const links = getSymbolLinks(symbol);
                let results;
                if (links.extendedContainersByFile && (results = links.extendedContainersByFile.get(id))) {
                    return results;
                }
                if (containingFile && containingFile.imports) {
                    for (const importRef of containingFile.imports) {
                        if (nodeIsSynthesized(importRef))
                            continue;
                        const resolvedModule = resolveExternalModuleName(enclosingDeclaration, importRef, 
                        /*ignoreErrors*/
                        true);
                        if (!resolvedModule)
                            continue;
                        const ref = getAliasForSymbolInContainer(resolvedModule, symbol);
                        if (!ref)
                            continue;
                        results = append(results, resolvedModule);
                    }
                    if (length(results)) {
                        (links.extendedContainersByFile || (links.extendedContainersByFile = /* @__PURE__ */ new Map())).set(id, results);
                        return results;
                    }
                }
                if (links.extendedContainers) {
                    return links.extendedContainers;
                }
                const otherFiles = host.getSourceFiles();
                for (const file of otherFiles) {
                    if (!isExternalModule(file))
                        continue;
                    const sym = getSymbolOfDeclaration(file);
                    const ref = getAliasForSymbolInContainer(sym, symbol);
                    if (!ref)
                        continue;
                    results = append(results, sym);
                }
                return links.extendedContainers = results || emptyArray;
            }
            function getContainersOfSymbol(symbol, enclosingDeclaration, meaning) {
                const container = getParentOfSymbol(symbol);
                if (container && !(symbol.flags & 262144 /* TypeParameter */)) {
                    return getWithAlternativeContainers(container);
                }
                const candidates = mapDefined(symbol.declarations, (d) => {
                    if (!isAmbientModule(d) && d.parent) {
                        if (hasNonGlobalAugmentationExternalModuleSymbol(d.parent)) {
                            return getSymbolOfDeclaration(d.parent);
                        }
                        if (isModuleBlock(d.parent) && d.parent.parent && resolveExternalModuleSymbol(getSymbolOfDeclaration(d.parent.parent)) === symbol) {
                            return getSymbolOfDeclaration(d.parent.parent);
                        }
                    }
                    if (isClassExpression(d) && isBinaryExpression(d.parent) && d.parent.operatorToken.kind === 64 /* EqualsToken */ && isAccessExpression(d.parent.left) && isEntityNameExpression(d.parent.left.expression)) {
                        if (isModuleExportsAccessExpression(d.parent.left) || isExportsIdentifier(d.parent.left.expression)) {
                            return getSymbolOfDeclaration(getSourceFileOfNode(d));
                        }
                        checkExpressionCached(d.parent.left.expression);
                        return getNodeLinks(d.parent.left.expression).resolvedSymbol;
                    }
                });
                if (!length(candidates)) {
                    return void 0;
                }
                const containers = mapDefined(candidates, (candidate) => getAliasForSymbolInContainer(candidate, symbol) ? candidate : void 0);
                let bestContainers = [];
                let alternativeContainers = [];
                for (const container2 of containers) {
                    const [bestMatch, ...rest] = getWithAlternativeContainers(container2);
                    bestContainers = append(bestContainers, bestMatch);
                    alternativeContainers = addRange(alternativeContainers, rest);
                }
                return concatenate(bestContainers, alternativeContainers);
                function getWithAlternativeContainers(container2) {
                    const additionalContainers = mapDefined(container2.declarations, fileSymbolIfFileSymbolExportEqualsContainer);
                    const reexportContainers = enclosingDeclaration && getAlternativeContainingModules(symbol, enclosingDeclaration);
                    const objectLiteralContainer = getVariableDeclarationOfObjectLiteral(container2, meaning);
                    if (enclosingDeclaration && container2.flags & getQualifiedLeftMeaning(meaning) && getAccessibleSymbolChain(container2, enclosingDeclaration, 1920 /* Namespace */, 
                    /*useOnlyExternalAliasing*/
                    false)) {
                        return append(concatenate(concatenate([container2], additionalContainers), reexportContainers), objectLiteralContainer);
                    }
                    const firstVariableMatch = !(container2.flags & getQualifiedLeftMeaning(meaning)) && container2.flags & 788968 /* Type */ && getDeclaredTypeOfSymbol(container2).flags & 524288 /* Object */ && meaning === 111551 /* Value */ ? forEachSymbolTableInScope(enclosingDeclaration, (t) => {
                        return forEachEntry(t, (s) => {
                            if (s.flags & getQualifiedLeftMeaning(meaning) && getTypeOfSymbol(s) === getDeclaredTypeOfSymbol(container2)) {
                                return s;
                            }
                        });
                    }) : void 0;
                    let res = firstVariableMatch ? [firstVariableMatch, ...additionalContainers, container2] : [...additionalContainers, container2];
                    res = append(res, objectLiteralContainer);
                    res = addRange(res, reexportContainers);
                    return res;
                }
                function fileSymbolIfFileSymbolExportEqualsContainer(d) {
                    return container && getFileSymbolIfFileSymbolExportEqualsContainer(d, container);
                }
            }
            function getVariableDeclarationOfObjectLiteral(symbol, meaning) {
                const firstDecl = !!length(symbol.declarations) && first(symbol.declarations);
                if (meaning & 111551 /* Value */ && firstDecl && firstDecl.parent && isVariableDeclaration(firstDecl.parent)) {
                    if (isObjectLiteralExpression(firstDecl) && firstDecl === firstDecl.parent.initializer || isTypeLiteralNode(firstDecl) && firstDecl === firstDecl.parent.type) {
                        return getSymbolOfDeclaration(firstDecl.parent);
                    }
                }
            }
            function getFileSymbolIfFileSymbolExportEqualsContainer(d, container) {
                const fileSymbol = getExternalModuleContainer(d);
                const exported = fileSymbol && fileSymbol.exports && fileSymbol.exports.get("export=" /* ExportEquals */);
                return exported && getSymbolIfSameReference(exported, container) ? fileSymbol : void 0;
            }
            function getAliasForSymbolInContainer(container, symbol) {
                if (container === getParentOfSymbol(symbol)) {
                    return symbol;
                }
                const exportEquals = container.exports && container.exports.get("export=" /* ExportEquals */);
                if (exportEquals && getSymbolIfSameReference(exportEquals, symbol)) {
                    return container;
                }
                const exports = getExportsOfSymbol(container);
                const quick = exports.get(symbol.escapedName);
                if (quick && getSymbolIfSameReference(quick, symbol)) {
                    return quick;
                }
                return forEachEntry(exports, (exported) => {
                    if (getSymbolIfSameReference(exported, symbol)) {
                        return exported;
                    }
                });
            }
            function getSymbolIfSameReference(s1, s2) {
                if (getMergedSymbol(resolveSymbol(getMergedSymbol(s1))) === getMergedSymbol(resolveSymbol(getMergedSymbol(s2)))) {
                    return s1;
                }
            }
            function getExportSymbolOfValueSymbolIfExported(symbol) {
                return getMergedSymbol(symbol && (symbol.flags & 1048576 /* ExportValue */) !== 0 && symbol.exportSymbol || symbol);
            }
            function symbolIsValue(symbol, includeTypeOnlyMembers) {
                return !!(symbol.flags & 111551 /* Value */ || symbol.flags & 2097152 /* Alias */ && getSymbolFlags(symbol, !includeTypeOnlyMembers) & 111551 /* Value */);
            }
            function findConstructorDeclaration(node) {
                const members = node.members;
                for (const member of members) {
                    if (member.kind === 176 /* Constructor */ && nodeIsPresent(member.body)) {
                        return member;
                    }
                }
            }
            function createType(flags) {
                var _a;
                const result = new Type28(checker, flags);
                typeCount++;
                result.id = typeCount;
                (_a = tracing) == null ? void 0 : _a.recordType(result);
                return result;
            }
            function createTypeWithSymbol(flags, symbol) {
                const result = createType(flags);
                result.symbol = symbol;
                return result;
            }
            function createOriginType(flags) {
                return new Type28(checker, flags);
            }
            function createIntrinsicType(kind, intrinsicName, objectFlags = 0 /* None */, debugIntrinsicName) {
                checkIntrinsicName(intrinsicName, debugIntrinsicName);
                const type = createType(kind);
                type.intrinsicName = intrinsicName;
                type.debugIntrinsicName = debugIntrinsicName;
                type.objectFlags = objectFlags | 524288 /* CouldContainTypeVariablesComputed */ | 2097152 /* IsGenericTypeComputed */ | 33554432 /* IsUnknownLikeUnionComputed */ | 16777216 /* IsNeverIntersectionComputed */;
                return type;
            }
            function checkIntrinsicName(name, debug) {
                const key = `${name},${debug ?? ""}`;
                if (seenIntrinsicNames.has(key)) {
                    Debug.fail(`Duplicate intrinsic type name ${name}${debug ? ` (${debug})` : ""}; you may need to pass a name to createIntrinsicType.`);
                }
                seenIntrinsicNames.add(key);
            }
            function createObjectType(objectFlags, symbol) {
                const type = createTypeWithSymbol(524288 /* Object */, symbol);
                type.objectFlags = objectFlags;
                type.members = void 0;
                type.properties = void 0;
                type.callSignatures = void 0;
                type.constructSignatures = void 0;
                type.indexInfos = void 0;
                return type;
            }
            function createTypeofType() {
                return getUnionType(arrayFrom(typeofNEFacts.keys(), getStringLiteralType));
            }
            function createTypeParameter(symbol) {
                return createTypeWithSymbol(262144 /* TypeParameter */, symbol);
            }
            function isReservedMemberName(name) {
                return name.charCodeAt(0) === 95 /* _ */ && name.charCodeAt(1) === 95 /* _ */ && name.charCodeAt(2) !== 95 /* _ */ && name.charCodeAt(2) !== 64 /* at */ && name.charCodeAt(2) !== 35 /* hash */;
            }
            function getNamedMembers(members) {
                let result;
                members.forEach((symbol, id) => {
                    if (isNamedMember(symbol, id)) {
                        (result || (result = [])).push(symbol);
                    }
                });
                return result || emptyArray;
            }
            function isNamedMember(member, escapedName) {
                return !isReservedMemberName(escapedName) && symbolIsValue(member);
            }
            function getNamedOrIndexSignatureMembers(members) {
                const result = getNamedMembers(members);
                const index = getIndexSymbolFromSymbolTable(members);
                return index ? concatenate(result, [index]) : result;
            }
            function setStructuredTypeMembers(type, members, callSignatures, constructSignatures, indexInfos) {
                const resolved = type;
                resolved.members = members;
                resolved.properties = emptyArray;
                resolved.callSignatures = callSignatures;
                resolved.constructSignatures = constructSignatures;
                resolved.indexInfos = indexInfos;
                if (members !== emptySymbols)
                    resolved.properties = getNamedMembers(members);
                return resolved;
            }
            function createAnonymousType(symbol, members, callSignatures, constructSignatures, indexInfos) {
                return setStructuredTypeMembers(createObjectType(16 /* Anonymous */, symbol), members, callSignatures, constructSignatures, indexInfos);
            }
            function getResolvedTypeWithoutAbstractConstructSignatures(type) {
                if (type.constructSignatures.length === 0)
                    return type;
                if (type.objectTypeWithoutAbstractConstructSignatures)
                    return type.objectTypeWithoutAbstractConstructSignatures;
                const constructSignatures = filter(type.constructSignatures, (signature) => !(signature.flags & 4 /* Abstract */));
                if (type.constructSignatures === constructSignatures)
                    return type;
                const typeCopy = createAnonymousType(type.symbol, type.members, type.callSignatures, some(constructSignatures) ? constructSignatures : emptyArray, type.indexInfos);
                type.objectTypeWithoutAbstractConstructSignatures = typeCopy;
                typeCopy.objectTypeWithoutAbstractConstructSignatures = typeCopy;
                return typeCopy;
            }
            function forEachSymbolTableInScope(enclosingDeclaration, callback) {
                let result;
                for (let location = enclosingDeclaration; location; location = location.parent) {
                    if (canHaveLocals(location) && location.locals && !isGlobalSourceFile(location)) {
                        if (result = callback(location.locals, 
                        /*ignoreQualification*/
                        void 0, 
                        /*isLocalNameLookup*/
                        true, location)) {
                            return result;
                        }
                    }
                    switch (location.kind) {
                        case 312 /* SourceFile */:
                            if (!isExternalOrCommonJsModule(location)) {
                                break;
                            }
                        case 267 /* ModuleDeclaration */:
                            const sym = getSymbolOfDeclaration(location);
                            if (result = callback((sym == null ? void 0 : sym.exports) || emptySymbols, 
                            /*ignoreQualification*/
                            void 0, 
                            /*isLocalNameLookup*/
                            true, location)) {
                                return result;
                            }
                            break;
                        case 263 /* ClassDeclaration */:
                        case 231 /* ClassExpression */:
                        case 264 /* InterfaceDeclaration */:
                            let table;
                            (getSymbolOfDeclaration(location).members || emptySymbols).forEach((memberSymbol, key) => {
                                if (memberSymbol.flags & (788968 /* Type */ & ~67108864 /* Assignment */)) {
                                    (table || (table = createSymbolTable())).set(key, memberSymbol);
                                }
                            });
                            if (table && (result = callback(table, 
                            /*ignoreQualification*/
                            void 0, 
                            /*isLocalNameLookup*/
                            false, location))) {
                                return result;
                            }
                            break;
                    }
                }
                return callback(globals, 
                /*ignoreQualification*/
                void 0, 
                /*isLocalNameLookup*/
                true);
            }
            function getQualifiedLeftMeaning(rightMeaning) {
                return rightMeaning === 111551 /* Value */ ? 111551 /* Value */ : 1920 /* Namespace */;
            }
            function getAccessibleSymbolChain(symbol, enclosingDeclaration, meaning, useOnlyExternalAliasing, visitedSymbolTablesMap = /* @__PURE__ */ new Map()) {
                if (!(symbol && !isPropertyOrMethodDeclarationSymbol(symbol))) {
                    return void 0;
                }
                const links = getSymbolLinks(symbol);
                const cache = links.accessibleChainCache || (links.accessibleChainCache = /* @__PURE__ */ new Map());
                const firstRelevantLocation = forEachSymbolTableInScope(enclosingDeclaration, (_, __, ___, node) => node);
                const key = `${useOnlyExternalAliasing ? 0 : 1}|${firstRelevantLocation && getNodeId(firstRelevantLocation)}|${meaning}`;
                if (cache.has(key)) {
                    return cache.get(key);
                }
                const id = getSymbolId(symbol);
                let visitedSymbolTables = visitedSymbolTablesMap.get(id);
                if (!visitedSymbolTables) {
                    visitedSymbolTablesMap.set(id, visitedSymbolTables = []);
                }
                const result = forEachSymbolTableInScope(enclosingDeclaration, getAccessibleSymbolChainFromSymbolTable);
                cache.set(key, result);
                return result;
                function getAccessibleSymbolChainFromSymbolTable(symbols, ignoreQualification, isLocalNameLookup) {
                    if (!pushIfUnique(visitedSymbolTables, symbols)) {
                        return void 0;
                    }
                    const result2 = trySymbolTable(symbols, ignoreQualification, isLocalNameLookup);
                    visitedSymbolTables.pop();
                    return result2;
                }
                function canQualifySymbol(symbolFromSymbolTable, meaning2) {
                    return !needsQualification(symbolFromSymbolTable, enclosingDeclaration, meaning2) || // If symbol needs qualification, make sure that parent is accessible, if it is then this symbol is accessible too
                        !!getAccessibleSymbolChain(symbolFromSymbolTable.parent, enclosingDeclaration, getQualifiedLeftMeaning(meaning2), useOnlyExternalAliasing, visitedSymbolTablesMap);
                }
                function isAccessible(symbolFromSymbolTable, resolvedAliasSymbol, ignoreQualification) {
                    return (symbol === (resolvedAliasSymbol || symbolFromSymbolTable) || getMergedSymbol(symbol) === getMergedSymbol(resolvedAliasSymbol || symbolFromSymbolTable)) && // if the symbolFromSymbolTable is not external module (it could be if it was determined as ambient external module and would be in globals table)
                        // and if symbolFromSymbolTable or alias resolution matches the symbol,
                        // check the symbol can be qualified, it is only then this symbol is accessible
                        !some(symbolFromSymbolTable.declarations, hasNonGlobalAugmentationExternalModuleSymbol) && (ignoreQualification || canQualifySymbol(getMergedSymbol(symbolFromSymbolTable), meaning));
                }
                function trySymbolTable(symbols, ignoreQualification, isLocalNameLookup) {
                    if (isAccessible(symbols.get(symbol.escapedName), 
                    /*resolvedAliasSymbol*/
                    void 0, ignoreQualification)) {
                        return [symbol];
                    }
                    const result2 = forEachEntry(symbols, (symbolFromSymbolTable) => {
                        if (symbolFromSymbolTable.flags & 2097152 /* Alias */ && symbolFromSymbolTable.escapedName !== "export=" /* ExportEquals */ && symbolFromSymbolTable.escapedName !== "default" /* Default */ && !(isUMDExportSymbol(symbolFromSymbolTable) && enclosingDeclaration && isExternalModule(getSourceFileOfNode(enclosingDeclaration))) && (!useOnlyExternalAliasing || some(symbolFromSymbolTable.declarations, isExternalModuleImportEqualsDeclaration)) && (isLocalNameLookup ? !some(symbolFromSymbolTable.declarations, isNamespaceReexportDeclaration) : true) && (ignoreQualification || !getDeclarationOfKind(symbolFromSymbolTable, 281 /* ExportSpecifier */))) {
                            const resolvedImportedSymbol = resolveAlias(symbolFromSymbolTable);
                            const candidate = getCandidateListForSymbol(symbolFromSymbolTable, resolvedImportedSymbol, ignoreQualification);
                            if (candidate) {
                                return candidate;
                            }
                        }
                        if (symbolFromSymbolTable.escapedName === symbol.escapedName && symbolFromSymbolTable.exportSymbol) {
                            if (isAccessible(getMergedSymbol(symbolFromSymbolTable.exportSymbol), 
                            /*resolvedAliasSymbol*/
                            void 0, ignoreQualification)) {
                                return [symbol];
                            }
                        }
                    });
                    return result2 || (symbols === globals ? getCandidateListForSymbol(globalThisSymbol, globalThisSymbol, ignoreQualification) : void 0);
                }
                function getCandidateListForSymbol(symbolFromSymbolTable, resolvedImportedSymbol, ignoreQualification) {
                    if (isAccessible(symbolFromSymbolTable, resolvedImportedSymbol, ignoreQualification)) {
                        return [symbolFromSymbolTable];
                    }
                    const candidateTable = getExportsOfSymbol(resolvedImportedSymbol);
                    const accessibleSymbolsFromExports = candidateTable && getAccessibleSymbolChainFromSymbolTable(candidateTable, 
                    /*ignoreQualification*/
                    true);
                    if (accessibleSymbolsFromExports && canQualifySymbol(symbolFromSymbolTable, getQualifiedLeftMeaning(meaning))) {
                        return [symbolFromSymbolTable].concat(accessibleSymbolsFromExports);
                    }
                }
            }
            function needsQualification(symbol, enclosingDeclaration, meaning) {
                let qualify = false;
                forEachSymbolTableInScope(enclosingDeclaration, (symbolTable) => {
                    let symbolFromSymbolTable = getMergedSymbol(symbolTable.get(symbol.escapedName));
                    if (!symbolFromSymbolTable) {
                        return false;
                    }
                    if (symbolFromSymbolTable === symbol) {
                        return true;
                    }
                    const shouldResolveAlias = symbolFromSymbolTable.flags & 2097152 /* Alias */ && !getDeclarationOfKind(symbolFromSymbolTable, 281 /* ExportSpecifier */);
                    symbolFromSymbolTable = shouldResolveAlias ? resolveAlias(symbolFromSymbolTable) : symbolFromSymbolTable;
                    const flags = shouldResolveAlias ? getSymbolFlags(symbolFromSymbolTable) : symbolFromSymbolTable.flags;
                    if (flags & meaning) {
                        qualify = true;
                        return true;
                    }
                    return false;
                });
                return qualify;
            }
            function isPropertyOrMethodDeclarationSymbol(symbol) {
                if (symbol.declarations && symbol.declarations.length) {
                    for (const declaration of symbol.declarations) {
                        switch (declaration.kind) {
                            case 172 /* PropertyDeclaration */:
                            case 174 /* MethodDeclaration */:
                            case 177 /* GetAccessor */:
                            case 178 /* SetAccessor */:
                                continue;
                            default:
                                return false;
                        }
                    }
                    return true;
                }
                return false;
            }
            function isTypeSymbolAccessible(typeSymbol, enclosingDeclaration) {
                const access = isSymbolAccessibleWorker(typeSymbol, enclosingDeclaration, 788968 /* Type */, 
                /*shouldComputeAliasesToMakeVisible*/
                false, 
                /*allowModules*/
                true);
                return access.accessibility === 0 /* Accessible */;
            }
            function isValueSymbolAccessible(typeSymbol, enclosingDeclaration) {
                const access = isSymbolAccessibleWorker(typeSymbol, enclosingDeclaration, 111551 /* Value */, 
                /*shouldComputeAliasesToMakeVisible*/
                false, 
                /*allowModules*/
                true);
                return access.accessibility === 0 /* Accessible */;
            }
            function isSymbolAccessibleByFlags(typeSymbol, enclosingDeclaration, flags) {
                const access = isSymbolAccessibleWorker(typeSymbol, enclosingDeclaration, flags, 
                /*shouldComputeAliasesToMakeVisible*/
                false, 
                /*allowModules*/
                false);
                return access.accessibility === 0 /* Accessible */;
            }
            function isAnySymbolAccessible(symbols, enclosingDeclaration, initialSymbol, meaning, shouldComputeAliasesToMakeVisible, allowModules) {
                if (!length(symbols))
                    return;
                let hadAccessibleChain;
                let earlyModuleBail = false;
                for (const symbol of symbols) {
                    const accessibleSymbolChain = getAccessibleSymbolChain(symbol, enclosingDeclaration, meaning, 
                    /*useOnlyExternalAliasing*/
                    false);
                    if (accessibleSymbolChain) {
                        hadAccessibleChain = symbol;
                        const hasAccessibleDeclarations = hasVisibleDeclarations(accessibleSymbolChain[0], shouldComputeAliasesToMakeVisible);
                        if (hasAccessibleDeclarations) {
                            return hasAccessibleDeclarations;
                        }
                    }
                    if (allowModules) {
                        if (some(symbol.declarations, hasNonGlobalAugmentationExternalModuleSymbol)) {
                            if (shouldComputeAliasesToMakeVisible) {
                                earlyModuleBail = true;
                                continue;
                            }
                            return {
                                accessibility: 0 /* Accessible */
                            };
                        }
                    }
                    const containers = getContainersOfSymbol(symbol, enclosingDeclaration, meaning);
                    const parentResult = isAnySymbolAccessible(containers, enclosingDeclaration, initialSymbol, initialSymbol === symbol ? getQualifiedLeftMeaning(meaning) : meaning, shouldComputeAliasesToMakeVisible, allowModules);
                    if (parentResult) {
                        return parentResult;
                    }
                }
                if (earlyModuleBail) {
                    return {
                        accessibility: 0 /* Accessible */
                    };
                }
                if (hadAccessibleChain) {
                    return {
                        accessibility: 1 /* NotAccessible */,
                        errorSymbolName: symbolToString(initialSymbol, enclosingDeclaration, meaning),
                        errorModuleName: hadAccessibleChain !== initialSymbol ? symbolToString(hadAccessibleChain, enclosingDeclaration, 1920 /* Namespace */) : void 0
                    };
                }
            }
            function isSymbolAccessible(symbol, enclosingDeclaration, meaning, shouldComputeAliasesToMakeVisible) {
                return isSymbolAccessibleWorker(symbol, enclosingDeclaration, meaning, shouldComputeAliasesToMakeVisible, 
                /*allowModules*/
                true);
            }
            function isSymbolAccessibleWorker(symbol, enclosingDeclaration, meaning, shouldComputeAliasesToMakeVisible, allowModules) {
                if (symbol && enclosingDeclaration) {
                    const result = isAnySymbolAccessible([symbol], enclosingDeclaration, symbol, meaning, shouldComputeAliasesToMakeVisible, allowModules);
                    if (result) {
                        return result;
                    }
                    const symbolExternalModule = forEach(symbol.declarations, getExternalModuleContainer);
                    if (symbolExternalModule) {
                        const enclosingExternalModule = getExternalModuleContainer(enclosingDeclaration);
                        if (symbolExternalModule !== enclosingExternalModule) {
                            return {
                                accessibility: 2 /* CannotBeNamed */,
                                errorSymbolName: symbolToString(symbol, enclosingDeclaration, meaning),
                                errorModuleName: symbolToString(symbolExternalModule),
                                errorNode: isInJSFile(enclosingDeclaration) ? enclosingDeclaration : void 0
                            };
                        }
                    }
                    return {
                        accessibility: 1 /* NotAccessible */,
                        errorSymbolName: symbolToString(symbol, enclosingDeclaration, meaning)
                    };
                }
                return { accessibility: 0 /* Accessible */ };
            }
            function getExternalModuleContainer(declaration) {
                const node = findAncestor(declaration, hasExternalModuleSymbol);
                return node && getSymbolOfDeclaration(node);
            }
            function hasExternalModuleSymbol(declaration) {
                return isAmbientModule(declaration) || declaration.kind === 312 /* SourceFile */ && isExternalOrCommonJsModule(declaration);
            }
            function hasNonGlobalAugmentationExternalModuleSymbol(declaration) {
                return isModuleWithStringLiteralName(declaration) || declaration.kind === 312 /* SourceFile */ && isExternalOrCommonJsModule(declaration);
            }
            function hasVisibleDeclarations(symbol, shouldComputeAliasToMakeVisible) {
                let aliasesToMakeVisible;
                if (!every(filter(symbol.declarations, (d) => d.kind !== 80 /* Identifier */), getIsDeclarationVisible)) {
                    return void 0;
                }
                return { accessibility: 0 /* Accessible */, aliasesToMakeVisible };
                function getIsDeclarationVisible(declaration) {
                    var _a, _b;
                    if (!isDeclarationVisible(declaration)) {
                        const anyImportSyntax = getAnyImportSyntax(declaration);
                        if (anyImportSyntax && !hasSyntacticModifier(anyImportSyntax, 32 /* Export */) && // import clause without export
                            isDeclarationVisible(anyImportSyntax.parent)) {
                            return addVisibleAlias(declaration, anyImportSyntax);
                        }
                        else if (isVariableDeclaration(declaration) && isVariableStatement(declaration.parent.parent) && !hasSyntacticModifier(declaration.parent.parent, 32 /* Export */) && // unexported variable statement
                            isDeclarationVisible(declaration.parent.parent.parent)) {
                            return addVisibleAlias(declaration, declaration.parent.parent);
                        }
                        else if (isLateVisibilityPaintedStatement(declaration) && !hasSyntacticModifier(declaration, 32 /* Export */) && isDeclarationVisible(declaration.parent)) {
                            return addVisibleAlias(declaration, declaration);
                        }
                        else if (isBindingElement(declaration)) {
                            if (symbol.flags & 2097152 /* Alias */ && isInJSFile(declaration) && ((_a = declaration.parent) == null ? void 0 : _a.parent) && isVariableDeclaration(declaration.parent.parent) && ((_b = declaration.parent.parent.parent) == null ? void 0 : _b.parent) && isVariableStatement(declaration.parent.parent.parent.parent) && !hasSyntacticModifier(declaration.parent.parent.parent.parent, 32 /* Export */) && declaration.parent.parent.parent.parent.parent && isDeclarationVisible(declaration.parent.parent.parent.parent.parent)) {
                                return addVisibleAlias(declaration, declaration.parent.parent.parent.parent);
                            }
                            else if (symbol.flags & 2 /* BlockScopedVariable */) {
                                const variableStatement = findAncestor(declaration, isVariableStatement);
                                if (hasSyntacticModifier(variableStatement, 32 /* Export */)) {
                                    return true;
                                }
                                if (!isDeclarationVisible(variableStatement.parent)) {
                                    return false;
                                }
                                return addVisibleAlias(declaration, variableStatement);
                            }
                        }
                        return false;
                    }
                    return true;
                }
                function addVisibleAlias(declaration, aliasingStatement) {
                    if (shouldComputeAliasToMakeVisible) {
                        getNodeLinks(declaration).isVisible = true;
                        aliasesToMakeVisible = appendIfUnique(aliasesToMakeVisible, aliasingStatement);
                    }
                    return true;
                }
            }
            function isEntityNameVisible(entityName, enclosingDeclaration) {
                let meaning;
                if (entityName.parent.kind === 186 /* TypeQuery */ || entityName.parent.kind === 233 /* ExpressionWithTypeArguments */ && !isPartOfTypeNode(entityName.parent) || entityName.parent.kind === 167 /* ComputedPropertyName */) {
                    meaning = 111551 /* Value */ | 1048576 /* ExportValue */;
                }
                else if (entityName.kind === 166 /* QualifiedName */ || entityName.kind === 211 /* PropertyAccessExpression */ || entityName.parent.kind === 271 /* ImportEqualsDeclaration */) {
                    meaning = 1920 /* Namespace */;
                }
                else {
                    meaning = 788968 /* Type */;
                }
                const firstIdentifier = getFirstIdentifier(entityName);
                const symbol = resolveName(enclosingDeclaration, firstIdentifier.escapedText, meaning, 
                /*nameNotFoundMessage*/
                void 0, 
                /*nameArg*/
                void 0, 
                /*isUse*/
                false);
                if (symbol && symbol.flags & 262144 /* TypeParameter */ && meaning & 788968 /* Type */) {
                    return { accessibility: 0 /* Accessible */ };
                }
                if (!symbol && isThisIdentifier(firstIdentifier) && isSymbolAccessible(getSymbolOfDeclaration(getThisContainer(firstIdentifier, 
                /*includeArrowFunctions*/
                false, 
                /*includeClassComputedPropertyName*/
                false)), firstIdentifier, meaning, 
                /*shouldComputeAliasesToMakeVisible*/
                false).accessibility === 0 /* Accessible */) {
                    return { accessibility: 0 /* Accessible */ };
                }
                return symbol && hasVisibleDeclarations(symbol, 
                /*shouldComputeAliasToMakeVisible*/
                true) || {
                    accessibility: 1 /* NotAccessible */,
                    errorSymbolName: getTextOfNode(firstIdentifier),
                    errorNode: firstIdentifier
                };
            }
            function symbolToString(symbol, enclosingDeclaration, meaning, flags = 4 /* AllowAnyNodeKind */, writer) {
                let nodeFlags = 70221824 /* IgnoreErrors */;
                if (flags & 2 /* UseOnlyExternalAliasing */) {
                    nodeFlags |= 128 /* UseOnlyExternalAliasing */;
                }
                if (flags & 1 /* WriteTypeParametersOrArguments */) {
                    nodeFlags |= 512 /* WriteTypeParametersInQualifiedName */;
                }
                if (flags & 8 /* UseAliasDefinedOutsideCurrentScope */) {
                    nodeFlags |= 16384 /* UseAliasDefinedOutsideCurrentScope */;
                }
                if (flags & 32 /* DoNotIncludeSymbolChain */) {
                    nodeFlags |= 134217728 /* DoNotIncludeSymbolChain */;
                }
                if (flags & 16 /* WriteComputedProps */) {
                    nodeFlags |= 1073741824 /* WriteComputedProps */;
                }
                const builder = flags & 4 /* AllowAnyNodeKind */ ? nodeBuilder.symbolToNode : nodeBuilder.symbolToEntityName;
                return writer ? symbolToStringWorker(writer).getText() : usingSingleLineStringWriter(symbolToStringWorker);
                function symbolToStringWorker(writer2) {
                    const entity = builder(symbol, meaning, enclosingDeclaration, nodeFlags);
                    const printer = (enclosingDeclaration == null ? void 0 : enclosingDeclaration.kind) === 312 /* SourceFile */ ? createPrinterWithRemoveCommentsNeverAsciiEscape() : createPrinterWithRemoveComments();
                    const sourceFile = enclosingDeclaration && getSourceFileOfNode(enclosingDeclaration);
                    printer.writeNode(4 /* Unspecified */, entity, 
                    /*sourceFile*/
                    sourceFile, writer2);
                    return writer2;
                }
            }
            function signatureToString(signature, enclosingDeclaration, flags = 0 /* None */, kind, writer) {
                return writer ? signatureToStringWorker(writer).getText() : usingSingleLineStringWriter(signatureToStringWorker);
                function signatureToStringWorker(writer2) {
                    let sigOutput;
                    if (flags & 262144 /* WriteArrowStyleSignature */) {
                        sigOutput = kind === 1 /* Construct */ ? 185 /* ConstructorType */ : 184 /* FunctionType */;
                    }
                    else {
                        sigOutput = kind === 1 /* Construct */ ? 180 /* ConstructSignature */ : 179 /* CallSignature */;
                    }
                    const sig = nodeBuilder.signatureToSignatureDeclaration(signature, sigOutput, enclosingDeclaration, toNodeBuilderFlags(flags) | 70221824 /* IgnoreErrors */ | 512 /* WriteTypeParametersInQualifiedName */);
                    const printer = createPrinterWithRemoveCommentsOmitTrailingSemicolon();
                    const sourceFile = enclosingDeclaration && getSourceFileOfNode(enclosingDeclaration);
                    printer.writeNode(4 /* Unspecified */, sig, 
                    /*sourceFile*/
                    sourceFile, getTrailingSemicolonDeferringWriter(writer2));
                    return writer2;
                }
            }
            function typeToString(type, enclosingDeclaration, flags = 1048576 /* AllowUniqueESSymbolType */ | 16384 /* UseAliasDefinedOutsideCurrentScope */, writer = createTextWriter("")) {
                const noTruncation = compilerOptions.noErrorTruncation || flags & 1 /* NoTruncation */;
                const typeNode = nodeBuilder.typeToTypeNode(type, enclosingDeclaration, toNodeBuilderFlags(flags) | 70221824 /* IgnoreErrors */ | (noTruncation ? 1 /* NoTruncation */ : 0));
                if (typeNode === void 0)
                    return Debug.fail("should always get typenode");
                const printer = type !== unresolvedType ? createPrinterWithRemoveComments() : createPrinterWithDefaults();
                const sourceFile = enclosingDeclaration && getSourceFileOfNode(enclosingDeclaration);
                printer.writeNode(4 /* Unspecified */, typeNode, 
                /*sourceFile*/
                sourceFile, writer);
                const result = writer.getText();
                const maxLength2 = noTruncation ? noTruncationMaximumTruncationLength * 2 : defaultMaximumTruncationLength * 2;
                if (maxLength2 && result && result.length >= maxLength2) {
                    return result.substr(0, maxLength2 - "...".length) + "...";
                }
                return result;
            }
            function getTypeNamesForErrorDisplay(left, right) {
                let leftStr = symbolValueDeclarationIsContextSensitive(left.symbol) ? typeToString(left, left.symbol.valueDeclaration) : typeToString(left);
                let rightStr = symbolValueDeclarationIsContextSensitive(right.symbol) ? typeToString(right, right.symbol.valueDeclaration) : typeToString(right);
                if (leftStr === rightStr) {
                    leftStr = getTypeNameForErrorDisplay(left);
                    rightStr = getTypeNameForErrorDisplay(right);
                }
                return [leftStr, rightStr];
            }
            function getTypeNameForErrorDisplay(type) {
                return typeToString(type, 
                /*enclosingDeclaration*/
                void 0, 64 /* UseFullyQualifiedType */);
            }
            function symbolValueDeclarationIsContextSensitive(symbol) {
                return symbol && !!symbol.valueDeclaration && isExpression(symbol.valueDeclaration) && !isContextSensitive(symbol.valueDeclaration);
            }
            function toNodeBuilderFlags(flags = 0 /* None */) {
                return flags & 848330095 /* NodeBuilderFlagsMask */;
            }
            function isClassInstanceSide(type) {
                return !!type.symbol && !!(type.symbol.flags & 32 /* Class */) && (type === getDeclaredTypeOfClassOrInterface(type.symbol) || !!(type.flags & 524288 /* Object */) && !!(getObjectFlags(type) & 16777216 /* IsClassInstanceClone */));
            }
            function createNodeBuilder() {
                return {
                    typeToTypeNode: (type, enclosingDeclaration, flags, tracker) => withContext(enclosingDeclaration, flags, tracker, (context) => typeToTypeNodeHelper(type, context)),
                    indexInfoToIndexSignatureDeclaration: (indexInfo, enclosingDeclaration, flags, tracker) => withContext(enclosingDeclaration, flags, tracker, (context) => indexInfoToIndexSignatureDeclarationHelper(indexInfo, context, 
                    /*typeNode*/
                    void 0)),
                    signatureToSignatureDeclaration: (signature, kind, enclosingDeclaration, flags, tracker) => withContext(enclosingDeclaration, flags, tracker, (context) => signatureToSignatureDeclarationHelper(signature, kind, context)),
                    symbolToEntityName: (symbol, meaning, enclosingDeclaration, flags, tracker) => withContext(enclosingDeclaration, flags, tracker, (context) => symbolToName(symbol, context, meaning, 
                    /*expectsIdentifier*/
                    false)),
                    symbolToExpression: (symbol, meaning, enclosingDeclaration, flags, tracker) => withContext(enclosingDeclaration, flags, tracker, (context) => symbolToExpression(symbol, context, meaning)),
                    symbolToTypeParameterDeclarations: (symbol, enclosingDeclaration, flags, tracker) => withContext(enclosingDeclaration, flags, tracker, (context) => typeParametersToTypeParameterDeclarations(symbol, context)),
                    symbolToParameterDeclaration: (symbol, enclosingDeclaration, flags, tracker) => withContext(enclosingDeclaration, flags, tracker, (context) => symbolToParameterDeclaration(symbol, context)),
                    typeParameterToDeclaration: (parameter, enclosingDeclaration, flags, tracker) => withContext(enclosingDeclaration, flags, tracker, (context) => typeParameterToDeclaration(parameter, context)),
                    symbolTableToDeclarationStatements: (symbolTable, enclosingDeclaration, flags, tracker, bundled) => withContext(enclosingDeclaration, flags, tracker, (context) => symbolTableToDeclarationStatements(symbolTable, context, bundled)),
                    symbolToNode: (symbol, meaning, enclosingDeclaration, flags, tracker) => withContext(enclosingDeclaration, flags, tracker, (context) => symbolToNode(symbol, context, meaning))
                };
                function symbolToNode(symbol, context, meaning) {
                    if (context.flags & 1073741824 /* WriteComputedProps */) {
                        if (symbol.valueDeclaration) {
                            const name = getNameOfDeclaration(symbol.valueDeclaration);
                            if (name && isComputedPropertyName(name))
                                return name;
                        }
                        const nameType = getSymbolLinks(symbol).nameType;
                        if (nameType && nameType.flags & (1024 /* EnumLiteral */ | 8192 /* UniqueESSymbol */)) {
                            context.enclosingDeclaration = nameType.symbol.valueDeclaration;
                            return factory.createComputedPropertyName(symbolToExpression(nameType.symbol, context, meaning));
                        }
                    }
                    return symbolToExpression(symbol, context, meaning);
                }
                function withContext(enclosingDeclaration, flags, tracker, cb) {
                    Debug.assert(enclosingDeclaration === void 0 || (enclosingDeclaration.flags & 16 /* Synthesized */) === 0);
                    const moduleResolverHost = (tracker == null ? void 0 : tracker.trackSymbol) ? tracker.moduleResolverHost : flags & 134217728 /* DoNotIncludeSymbolChain */ ? createBasicNodeBuilderModuleSpecifierResolutionHost(host) : void 0;
                    const context = {
                        enclosingDeclaration,
                        flags: flags || 0 /* None */,
                        tracker: void 0,
                        encounteredError: false,
                        reportedDiagnostic: false,
                        visitedTypes: void 0,
                        symbolDepth: void 0,
                        inferTypeParameters: void 0,
                        approximateLength: 0,
                        trackedSymbols: void 0
                    };
                    context.tracker = new SymbolTrackerImpl(context, tracker, moduleResolverHost);
                    const resultingNode = cb(context);
                    if (context.truncating && context.flags & 1 /* NoTruncation */) {
                        context.tracker.reportTruncationError();
                    }
                    return context.encounteredError ? void 0 : resultingNode;
                }
                function checkTruncationLength(context) {
                    if (context.truncating)
                        return context.truncating;
                    return context.truncating = context.approximateLength > (context.flags & 1 /* NoTruncation */ ? noTruncationMaximumTruncationLength : defaultMaximumTruncationLength);
                }
                function typeToTypeNodeHelper(type, context) {
                    const savedFlags = context.flags;
                    const typeNode = typeToTypeNodeWorker(type, context);
                    context.flags = savedFlags;
                    return typeNode;
                }
                function typeToTypeNodeWorker(type, context) {
                    var _a, _b;
                    if (cancellationToken && cancellationToken.throwIfCancellationRequested) {
                        cancellationToken.throwIfCancellationRequested();
                    }
                    const inTypeAlias = context.flags & 8388608 /* InTypeAlias */;
                    context.flags &= ~8388608 /* InTypeAlias */;
                    if (!type) {
                        if (!(context.flags & 262144 /* AllowEmptyUnionOrIntersection */)) {
                            context.encounteredError = true;
                            return void 0;
                        }
                        context.approximateLength += 3;
                        return factory.createKeywordTypeNode(133 /* AnyKeyword */);
                    }
                    if (!(context.flags & 536870912 /* NoTypeReduction */)) {
                        type = getReducedType(type);
                    }
                    if (type.flags & 1 /* Any */) {
                        if (type.aliasSymbol) {
                            return factory.createTypeReferenceNode(symbolToEntityNameNode(type.aliasSymbol), mapToTypeNodes(type.aliasTypeArguments, context));
                        }
                        if (type === unresolvedType) {
                            return addSyntheticLeadingComment(factory.createKeywordTypeNode(133 /* AnyKeyword */), 3 /* MultiLineCommentTrivia */, "unresolved");
                        }
                        context.approximateLength += 3;
                        return factory.createKeywordTypeNode(type === intrinsicMarkerType ? 141 /* IntrinsicKeyword */ : 133 /* AnyKeyword */);
                    }
                    if (type.flags & 2 /* Unknown */) {
                        return factory.createKeywordTypeNode(159 /* UnknownKeyword */);
                    }
                    if (type.flags & 4 /* String */) {
                        context.approximateLength += 6;
                        return factory.createKeywordTypeNode(154 /* StringKeyword */);
                    }
                    if (type.flags & 8 /* Number */) {
                        context.approximateLength += 6;
                        return factory.createKeywordTypeNode(150 /* NumberKeyword */);
                    }
                    if (type.flags & 64 /* BigInt */) {
                        context.approximateLength += 6;
                        return factory.createKeywordTypeNode(163 /* BigIntKeyword */);
                    }
                    if (type.flags & 16 /* Boolean */ && !type.aliasSymbol) {
                        context.approximateLength += 7;
                        return factory.createKeywordTypeNode(136 /* BooleanKeyword */);
                    }
                    if (type.flags & 1056 /* EnumLike */) {
                        if (type.symbol.flags & 8 /* EnumMember */) {
                            const parentSymbol = getParentOfSymbol(type.symbol);
                            const parentName = symbolToTypeNode(parentSymbol, context, 788968 /* Type */);
                            if (getDeclaredTypeOfSymbol(parentSymbol) === type) {
                                return parentName;
                            }
                            const memberName = symbolName(type.symbol);
                            if (isIdentifierText(memberName, 0 /* ES3 */)) {
                                return appendReferenceToType(parentName, factory.createTypeReferenceNode(memberName, 
                                /*typeArguments*/
                                void 0));
                            }
                            if (isImportTypeNode(parentName)) {
                                parentName.isTypeOf = true;
                                return factory.createIndexedAccessTypeNode(parentName, factory.createLiteralTypeNode(factory.createStringLiteral(memberName)));
                            }
                            else if (isTypeReferenceNode(parentName)) {
                                return factory.createIndexedAccessTypeNode(factory.createTypeQueryNode(parentName.typeName), factory.createLiteralTypeNode(factory.createStringLiteral(memberName)));
                            }
                            else {
                                return Debug.fail("Unhandled type node kind returned from `symbolToTypeNode`.");
                            }
                        }
                        return symbolToTypeNode(type.symbol, context, 788968 /* Type */);
                    }
                    if (type.flags & 128 /* StringLiteral */) {
                        context.approximateLength += type.value.length + 2;
                        return factory.createLiteralTypeNode(setEmitFlags(factory.createStringLiteral(type.value, !!(context.flags & 268435456 /* UseSingleQuotesForStringLiteralType */)), 16777216 /* NoAsciiEscaping */));
                    }
                    if (type.flags & 256 /* NumberLiteral */) {
                        const value = type.value;
                        context.approximateLength += ("" + value).length;
                        return factory.createLiteralTypeNode(value < 0 ? factory.createPrefixUnaryExpression(41 /* MinusToken */, factory.createNumericLiteral(-value)) : factory.createNumericLiteral(value));
                    }
                    if (type.flags & 2048 /* BigIntLiteral */) {
                        context.approximateLength += pseudoBigIntToString(type.value).length + 1;
                        return factory.createLiteralTypeNode(factory.createBigIntLiteral(type.value));
                    }
                    if (type.flags & 512 /* BooleanLiteral */) {
                        context.approximateLength += type.intrinsicName.length;
                        return factory.createLiteralTypeNode(type.intrinsicName === "true" ? factory.createTrue() : factory.createFalse());
                    }
                    if (type.flags & 8192 /* UniqueESSymbol */) {
                        if (!(context.flags & 1048576 /* AllowUniqueESSymbolType */)) {
                            if (isValueSymbolAccessible(type.symbol, context.enclosingDeclaration)) {
                                context.approximateLength += 6;
                                return symbolToTypeNode(type.symbol, context, 111551 /* Value */);
                            }
                            if (context.tracker.reportInaccessibleUniqueSymbolError) {
                                context.tracker.reportInaccessibleUniqueSymbolError();
                            }
                        }
                        context.approximateLength += 13;
                        return factory.createTypeOperatorNode(158 /* UniqueKeyword */, factory.createKeywordTypeNode(155 /* SymbolKeyword */));
                    }
                    if (type.flags & 16384 /* Void */) {
                        context.approximateLength += 4;
                        return factory.createKeywordTypeNode(116 /* VoidKeyword */);
                    }
                    if (type.flags & 32768 /* Undefined */) {
                        context.approximateLength += 9;
                        return factory.createKeywordTypeNode(157 /* UndefinedKeyword */);
                    }
                    if (type.flags & 65536 /* Null */) {
                        context.approximateLength += 4;
                        return factory.createLiteralTypeNode(factory.createNull());
                    }
                    if (type.flags & 131072 /* Never */) {
                        context.approximateLength += 5;
                        return factory.createKeywordTypeNode(146 /* NeverKeyword */);
                    }
                    if (type.flags & 4096 /* ESSymbol */) {
                        context.approximateLength += 6;
                        return factory.createKeywordTypeNode(155 /* SymbolKeyword */);
                    }
                    if (type.flags & 67108864 /* NonPrimitive */) {
                        context.approximateLength += 6;
                        return factory.createKeywordTypeNode(151 /* ObjectKeyword */);
                    }
                    if (isThisTypeParameter(type)) {
                        if (context.flags & 4194304 /* InObjectTypeLiteral */) {
                            if (!context.encounteredError && !(context.flags & 32768 /* AllowThisInObjectLiteral */)) {
                                context.encounteredError = true;
                            }
                            (_b = (_a = context.tracker).reportInaccessibleThisError) == null ? void 0 : _b.call(_a);
                        }
                        context.approximateLength += 4;
                        return factory.createThisTypeNode();
                    }
                    if (!inTypeAlias && type.aliasSymbol && (context.flags & 16384 /* UseAliasDefinedOutsideCurrentScope */ || isTypeSymbolAccessible(type.aliasSymbol, context.enclosingDeclaration))) {
                        const typeArgumentNodes = mapToTypeNodes(type.aliasTypeArguments, context);
                        if (isReservedMemberName(type.aliasSymbol.escapedName) && !(type.aliasSymbol.flags & 32 /* Class */))
                            return factory.createTypeReferenceNode(factory.createIdentifier(""), typeArgumentNodes);
                        if (length(typeArgumentNodes) === 1 && type.aliasSymbol === globalArrayType.symbol) {
                            return factory.createArrayTypeNode(typeArgumentNodes[0]);
                        }
                        return symbolToTypeNode(type.aliasSymbol, context, 788968 /* Type */, typeArgumentNodes);
                    }
                    const objectFlags = getObjectFlags(type);
                    if (objectFlags & 4 /* Reference */) {
                        Debug.assert(!!(type.flags & 524288 /* Object */));
                        return type.node ? visitAndTransformType(type, typeReferenceToTypeNode) : typeReferenceToTypeNode(type);
                    }
                    if (type.flags & 262144 /* TypeParameter */ || objectFlags & 3 /* ClassOrInterface */) {
                        if (type.flags & 262144 /* TypeParameter */ && contains(context.inferTypeParameters, type)) {
                            context.approximateLength += symbolName(type.symbol).length + 6;
                            let constraintNode;
                            const constraint = getConstraintOfTypeParameter(type);
                            if (constraint) {
                                const inferredConstraint = getInferredTypeParameterConstraint(type, 
                                /*omitTypeReferences*/
                                true);
                                if (!(inferredConstraint && isTypeIdenticalTo(constraint, inferredConstraint))) {
                                    context.approximateLength += 9;
                                    constraintNode = constraint && typeToTypeNodeHelper(constraint, context);
                                }
                            }
                            return factory.createInferTypeNode(typeParameterToDeclarationWithConstraint(type, context, constraintNode));
                        }
                        if (context.flags & 4 /* GenerateNamesForShadowedTypeParams */ && type.flags & 262144 /* TypeParameter */) {
                            const name2 = typeParameterToName(type, context);
                            context.approximateLength += idText(name2).length;
                            return factory.createTypeReferenceNode(factory.createIdentifier(idText(name2)), 
                            /*typeArguments*/
                            void 0);
                        }
                        if (type.symbol) {
                            return symbolToTypeNode(type.symbol, context, 788968 /* Type */);
                        }
                        const name = (type === markerSuperTypeForCheck || type === markerSubTypeForCheck) && varianceTypeParameter && varianceTypeParameter.symbol ? (type === markerSubTypeForCheck ? "sub-" : "super-") + symbolName(varianceTypeParameter.symbol) : "?";
                        return factory.createTypeReferenceNode(factory.createIdentifier(name), 
                        /*typeArguments*/
                        void 0);
                    }
                    if (type.flags & 1048576 /* Union */ && type.origin) {
                        type = type.origin;
                    }
                    if (type.flags & (1048576 /* Union */ | 2097152 /* Intersection */)) {
                        const types = type.flags & 1048576 /* Union */ ? formatUnionTypes(type.types) : type.types;
                        if (length(types) === 1) {
                            return typeToTypeNodeHelper(types[0], context);
                        }
                        const typeNodes = mapToTypeNodes(types, context, 
                        /*isBareList*/
                        true);
                        if (typeNodes && typeNodes.length > 0) {
                            return type.flags & 1048576 /* Union */ ? factory.createUnionTypeNode(typeNodes) : factory.createIntersectionTypeNode(typeNodes);
                        }
                        else {
                            if (!context.encounteredError && !(context.flags & 262144 /* AllowEmptyUnionOrIntersection */)) {
                                context.encounteredError = true;
                            }
                            return void 0;
                        }
                    }
                    if (objectFlags & (16 /* Anonymous */ | 32 /* Mapped */)) {
                        Debug.assert(!!(type.flags & 524288 /* Object */));
                        return createAnonymousTypeNode(type);
                    }
                    if (type.flags & 4194304 /* Index */) {
                        const indexedType = type.type;
                        context.approximateLength += 6;
                        const indexTypeNode = typeToTypeNodeHelper(indexedType, context);
                        return factory.createTypeOperatorNode(143 /* KeyOfKeyword */, indexTypeNode);
                    }
                    if (type.flags & 134217728 /* TemplateLiteral */) {
                        const texts = type.texts;
                        const types = type.types;
                        const templateHead = factory.createTemplateHead(texts[0]);
                        const templateSpans = factory.createNodeArray(map(types, (t, i) => factory.createTemplateLiteralTypeSpan(typeToTypeNodeHelper(t, context), (i < types.length - 1 ? factory.createTemplateMiddle : factory.createTemplateTail)(texts[i + 1]))));
                        context.approximateLength += 2;
                        return factory.createTemplateLiteralType(templateHead, templateSpans);
                    }
                    if (type.flags & 268435456 /* StringMapping */) {
                        const typeNode = typeToTypeNodeHelper(type.type, context);
                        return symbolToTypeNode(type.symbol, context, 788968 /* Type */, [typeNode]);
                    }
                    if (type.flags & 8388608 /* IndexedAccess */) {
                        const objectTypeNode = typeToTypeNodeHelper(type.objectType, context);
                        const indexTypeNode = typeToTypeNodeHelper(type.indexType, context);
                        context.approximateLength += 2;
                        return factory.createIndexedAccessTypeNode(objectTypeNode, indexTypeNode);
                    }
                    if (type.flags & 16777216 /* Conditional */) {
                        return visitAndTransformType(type, (type2) => conditionalTypeToTypeNode(type2));
                    }
                    if (type.flags & 33554432 /* Substitution */) {
                        const typeNode = typeToTypeNodeHelper(type.baseType, context);
                        const noInferSymbol = isNoInferType(type) && getGlobalTypeSymbol("NoInfer", 
                        /*reportErrors*/
                        false);
                        return noInferSymbol ? symbolToTypeNode(noInferSymbol, context, 788968 /* Type */, [typeNode]) : typeNode;
                    }
                    return Debug.fail("Should be unreachable.");
                    function conditionalTypeToTypeNode(type2) {
                        const checkTypeNode = typeToTypeNodeHelper(type2.checkType, context);
                        context.approximateLength += 15;
                        if (context.flags & 4 /* GenerateNamesForShadowedTypeParams */ && type2.root.isDistributive && !(type2.checkType.flags & 262144 /* TypeParameter */)) {
                            const newParam = createTypeParameter(createSymbol(262144 /* TypeParameter */, "T"));
                            const name = typeParameterToName(newParam, context);
                            const newTypeVariable = factory.createTypeReferenceNode(name);
                            context.approximateLength += 37;
                            const newMapper = prependTypeMapping(type2.root.checkType, newParam, type2.mapper);
                            const saveInferTypeParameters2 = context.inferTypeParameters;
                            context.inferTypeParameters = type2.root.inferTypeParameters;
                            const extendsTypeNode2 = typeToTypeNodeHelper(instantiateType(type2.root.extendsType, newMapper), context);
                            context.inferTypeParameters = saveInferTypeParameters2;
                            const trueTypeNode2 = typeToTypeNodeOrCircularityElision(instantiateType(getTypeFromTypeNode(type2.root.node.trueType), newMapper));
                            const falseTypeNode2 = typeToTypeNodeOrCircularityElision(instantiateType(getTypeFromTypeNode(type2.root.node.falseType), newMapper));
                            return factory.createConditionalTypeNode(checkTypeNode, factory.createInferTypeNode(factory.createTypeParameterDeclaration(
                            /*modifiers*/
                            void 0, factory.cloneNode(newTypeVariable.typeName))), factory.createConditionalTypeNode(factory.createTypeReferenceNode(factory.cloneNode(name)), typeToTypeNodeHelper(type2.checkType, context), factory.createConditionalTypeNode(newTypeVariable, extendsTypeNode2, trueTypeNode2, falseTypeNode2), factory.createKeywordTypeNode(146 /* NeverKeyword */)), factory.createKeywordTypeNode(146 /* NeverKeyword */));
                        }
                        const saveInferTypeParameters = context.inferTypeParameters;
                        context.inferTypeParameters = type2.root.inferTypeParameters;
                        const extendsTypeNode = typeToTypeNodeHelper(type2.extendsType, context);
                        context.inferTypeParameters = saveInferTypeParameters;
                        const trueTypeNode = typeToTypeNodeOrCircularityElision(getTrueTypeFromConditionalType(type2));
                        const falseTypeNode = typeToTypeNodeOrCircularityElision(getFalseTypeFromConditionalType(type2));
                        return factory.createConditionalTypeNode(checkTypeNode, extendsTypeNode, trueTypeNode, falseTypeNode);
                    }
                    function typeToTypeNodeOrCircularityElision(type2) {
                        var _a2, _b2, _c;
                        if (type2.flags & 1048576 /* Union */) {
                            if ((_a2 = context.visitedTypes) == null ? void 0 : _a2.has(getTypeId(type2))) {
                                if (!(context.flags & 131072 /* AllowAnonymousIdentifier */)) {
                                    context.encounteredError = true;
                                    (_c = (_b2 = context.tracker) == null ? void 0 : _b2.reportCyclicStructureError) == null ? void 0 : _c.call(_b2);
                                }
                                return createElidedInformationPlaceholder(context);
                            }
                            return visitAndTransformType(type2, (type3) => typeToTypeNodeHelper(type3, context));
                        }
                        return typeToTypeNodeHelper(type2, context);
                    }
                    function isMappedTypeHomomorphic(type2) {
                        return !!getHomomorphicTypeVariable(type2);
                    }
                    function isHomomorphicMappedTypeWithNonHomomorphicInstantiation(type2) {
                        return !!type2.target && isMappedTypeHomomorphic(type2.target) && !isMappedTypeHomomorphic(type2);
                    }
                    function createMappedTypeNodeFromType(type2) {
                        var _a2;
                        Debug.assert(!!(type2.flags & 524288 /* Object */));
                        const readonlyToken = type2.declaration.readonlyToken ? factory.createToken(type2.declaration.readonlyToken.kind) : void 0;
                        const questionToken = type2.declaration.questionToken ? factory.createToken(type2.declaration.questionToken.kind) : void 0;
                        let appropriateConstraintTypeNode;
                        let newTypeVariable;
                        const needsModifierPreservingWrapper = !isMappedTypeWithKeyofConstraintDeclaration(type2) && !(getModifiersTypeFromMappedType(type2).flags & 2 /* Unknown */) && context.flags & 4 /* GenerateNamesForShadowedTypeParams */ && !(getConstraintTypeFromMappedType(type2).flags & 262144 /* TypeParameter */ && ((_a2 = getConstraintOfTypeParameter(getConstraintTypeFromMappedType(type2))) == null ? void 0 : _a2.flags) & 4194304 /* Index */);
                        if (isMappedTypeWithKeyofConstraintDeclaration(type2)) {
                            if (isHomomorphicMappedTypeWithNonHomomorphicInstantiation(type2) && context.flags & 4 /* GenerateNamesForShadowedTypeParams */) {
                                const newParam = createTypeParameter(createSymbol(262144 /* TypeParameter */, "T"));
                                const name = typeParameterToName(newParam, context);
                                newTypeVariable = factory.createTypeReferenceNode(name);
                            }
                            appropriateConstraintTypeNode = factory.createTypeOperatorNode(143 /* KeyOfKeyword */, newTypeVariable || typeToTypeNodeHelper(getModifiersTypeFromMappedType(type2), context));
                        }
                        else if (needsModifierPreservingWrapper) {
                            const newParam = createTypeParameter(createSymbol(262144 /* TypeParameter */, "T"));
                            const name = typeParameterToName(newParam, context);
                            newTypeVariable = factory.createTypeReferenceNode(name);
                            appropriateConstraintTypeNode = newTypeVariable;
                        }
                        else {
                            appropriateConstraintTypeNode = typeToTypeNodeHelper(getConstraintTypeFromMappedType(type2), context);
                        }
                        const typeParameterNode = typeParameterToDeclarationWithConstraint(getTypeParameterFromMappedType(type2), context, appropriateConstraintTypeNode);
                        const nameTypeNode = type2.declaration.nameType ? typeToTypeNodeHelper(getNameTypeFromMappedType(type2), context) : void 0;
                        const templateTypeNode = typeToTypeNodeHelper(removeMissingType(getTemplateTypeFromMappedType(type2), !!(getMappedTypeModifiers(type2) & 4 /* IncludeOptional */)), context);
                        const mappedTypeNode = factory.createMappedTypeNode(readonlyToken, typeParameterNode, nameTypeNode, questionToken, templateTypeNode, 
                        /*members*/
                        void 0);
                        context.approximateLength += 10;
                        const result = setEmitFlags(mappedTypeNode, 1 /* SingleLine */);
                        if (isHomomorphicMappedTypeWithNonHomomorphicInstantiation(type2) && context.flags & 4 /* GenerateNamesForShadowedTypeParams */) {
                            const originalConstraint = instantiateType(getConstraintOfTypeParameter(getTypeFromTypeNode(type2.declaration.typeParameter.constraint.type)) || unknownType, type2.mapper);
                            return factory.createConditionalTypeNode(typeToTypeNodeHelper(getModifiersTypeFromMappedType(type2), context), factory.createInferTypeNode(factory.createTypeParameterDeclaration(
                            /*modifiers*/
                            void 0, factory.cloneNode(newTypeVariable.typeName), originalConstraint.flags & 2 /* Unknown */ ? void 0 : typeToTypeNodeHelper(originalConstraint, context))), result, factory.createKeywordTypeNode(146 /* NeverKeyword */));
                        }
                        else if (needsModifierPreservingWrapper) {
                            return factory.createConditionalTypeNode(typeToTypeNodeHelper(getConstraintTypeFromMappedType(type2), context), factory.createInferTypeNode(factory.createTypeParameterDeclaration(
                            /*modifiers*/
                            void 0, factory.cloneNode(newTypeVariable.typeName), factory.createTypeOperatorNode(143 /* KeyOfKeyword */, typeToTypeNodeHelper(getModifiersTypeFromMappedType(type2), context)))), result, factory.createKeywordTypeNode(146 /* NeverKeyword */));
                        }
                        return result;
                    }
                    function createAnonymousTypeNode(type2) {
                        var _a2, _b2;
                        const typeId = type2.id;
                        const symbol = type2.symbol;
                        if (symbol) {
                            const isInstantiationExpressionType = !!(getObjectFlags(type2) & 8388608 /* InstantiationExpressionType */);
                            if (isInstantiationExpressionType) {
                                const instantiationExpressionType = type2;
                                const existing = instantiationExpressionType.node;
                                if (isTypeQueryNode(existing) && getTypeFromTypeNode(existing) === type2) {
                                    const typeNode = serializeExistingTypeNode(context, existing);
                                    if (typeNode) {
                                        return typeNode;
                                    }
                                }
                                if ((_a2 = context.visitedTypes) == null ? void 0 : _a2.has(typeId)) {
                                    return createElidedInformationPlaceholder(context);
                                }
                                return visitAndTransformType(type2, createTypeNodeFromObjectType);
                            }
                            const isInstanceType = isClassInstanceSide(type2) ? 788968 /* Type */ : 111551 /* Value */;
                            if (isJSConstructor(symbol.valueDeclaration)) {
                                return symbolToTypeNode(symbol, context, isInstanceType);
                            }
                            else if (symbol.flags & 32 /* Class */ && !getBaseTypeVariableOfClass(symbol) && !(symbol.valueDeclaration && isClassLike(symbol.valueDeclaration) && context.flags & 2048 /* WriteClassExpressionAsTypeLiteral */ && (!isClassDeclaration(symbol.valueDeclaration) || isSymbolAccessible(symbol, context.enclosingDeclaration, isInstanceType, 
                            /*shouldComputeAliasesToMakeVisible*/
                            false).accessibility !== 0 /* Accessible */)) || symbol.flags & (384 /* Enum */ | 512 /* ValueModule */) || shouldWriteTypeOfFunctionSymbol()) {
                                return symbolToTypeNode(symbol, context, isInstanceType);
                            }
                            else if ((_b2 = context.visitedTypes) == null ? void 0 : _b2.has(typeId)) {
                                const typeAlias = getTypeAliasForTypeLiteral(type2);
                                if (typeAlias) {
                                    return symbolToTypeNode(typeAlias, context, 788968 /* Type */);
                                }
                                else {
                                    return createElidedInformationPlaceholder(context);
                                }
                            }
                            else {
                                return visitAndTransformType(type2, createTypeNodeFromObjectType);
                            }
                        }
                        else {
                            return createTypeNodeFromObjectType(type2);
                        }
                        function shouldWriteTypeOfFunctionSymbol() {
                            var _a3;
                            const isStaticMethodSymbol = !!(symbol.flags & 8192 /* Method */) && // typeof static method
                                some(symbol.declarations, (declaration) => isStatic(declaration));
                            const isNonLocalFunctionSymbol = !!(symbol.flags & 16 /* Function */) && (symbol.parent || // is exported function symbol
                                forEach(symbol.declarations, (declaration) => declaration.parent.kind === 312 /* SourceFile */ || declaration.parent.kind === 268 /* ModuleBlock */));
                            if (isStaticMethodSymbol || isNonLocalFunctionSymbol) {
                                return (!!(context.flags & 4096 /* UseTypeOfFunction */) || ((_a3 = context.visitedTypes) == null ? void 0 : _a3.has(typeId))) && // it is type of the symbol uses itself recursively
                                    (!(context.flags & 8 /* UseStructuralFallback */) || isValueSymbolAccessible(symbol, context.enclosingDeclaration));
                            }
                        }
                    }
                    function visitAndTransformType(type2, transform2) {
                        var _a2, _b2, _c;
                        const typeId = type2.id;
                        const isConstructorObject = getObjectFlags(type2) & 16 /* Anonymous */ && type2.symbol && type2.symbol.flags & 32 /* Class */;
                        const id = getObjectFlags(type2) & 4 /* Reference */ && type2.node ? "N" + getNodeId(type2.node) : type2.flags & 16777216 /* Conditional */ ? "N" + getNodeId(type2.root.node) : type2.symbol ? (isConstructorObject ? "+" : "") + getSymbolId(type2.symbol) : void 0;
                        if (!context.visitedTypes) {
                            context.visitedTypes = /* @__PURE__ */ new Set();
                        }
                        if (id && !context.symbolDepth) {
                            context.symbolDepth = /* @__PURE__ */ new Map();
                        }
                        const links = context.enclosingDeclaration && getNodeLinks(context.enclosingDeclaration);
                        const key = `${getTypeId(type2)}|${context.flags}`;
                        if (links) {
                            links.serializedTypes || (links.serializedTypes = /* @__PURE__ */ new Map());
                        }
                        const cachedResult = (_a2 = links == null ? void 0 : links.serializedTypes) == null ? void 0 : _a2.get(key);
                        if (cachedResult) {
                            (_b2 = cachedResult.trackedSymbols) == null ? void 0 : _b2.forEach(([symbol, enclosingDeclaration, meaning]) => context.tracker.trackSymbol(symbol, enclosingDeclaration, meaning));
                            if (cachedResult.truncating) {
                                context.truncating = true;
                            }
                            context.approximateLength += cachedResult.addedLength;
                            return deepCloneOrReuseNode(cachedResult.node);
                        }
                        let depth;
                        if (id) {
                            depth = context.symbolDepth.get(id) || 0;
                            if (depth > 10) {
                                return createElidedInformationPlaceholder(context);
                            }
                            context.symbolDepth.set(id, depth + 1);
                        }
                        context.visitedTypes.add(typeId);
                        const prevTrackedSymbols = context.trackedSymbols;
                        context.trackedSymbols = void 0;
                        const startLength = context.approximateLength;
                        const result = transform2(type2);
                        const addedLength = context.approximateLength - startLength;
                        if (!context.reportedDiagnostic && !context.encounteredError) {
                            (_c = links == null ? void 0 : links.serializedTypes) == null ? void 0 : _c.set(key, {
                                node: result,
                                truncating: context.truncating,
                                addedLength,
                                trackedSymbols: context.trackedSymbols
                            });
                        }
                        context.visitedTypes.delete(typeId);
                        if (id) {
                            context.symbolDepth.set(id, depth);
                        }
                        context.trackedSymbols = prevTrackedSymbols;
                        return result;
                        function deepCloneOrReuseNode(node) {
                            if (!nodeIsSynthesized(node) && getParseTreeNode(node) === node) {
                                return node;
                            }
                            return setTextRange(factory.cloneNode(visitEachChild(node, deepCloneOrReuseNode, 
                            /*context*/
                            void 0, deepCloneOrReuseNodes)), node);
                        }
                        function deepCloneOrReuseNodes(nodes, visitor, test, start, count) {
                            if (nodes && nodes.length === 0) {
                                return setTextRange(factory.createNodeArray(
                                /*elements*/
                                void 0, nodes.hasTrailingComma), nodes);
                            }
                            return visitNodes2(nodes, visitor, test, start, count);
                        }
                    }
                    function createTypeNodeFromObjectType(type2) {
                        if (isGenericMappedType(type2) || type2.containsError) {
                            return createMappedTypeNodeFromType(type2);
                        }
                        const resolved = resolveStructuredTypeMembers(type2);
                        if (!resolved.properties.length && !resolved.indexInfos.length) {
                            if (!resolved.callSignatures.length && !resolved.constructSignatures.length) {
                                context.approximateLength += 2;
                                return setEmitFlags(factory.createTypeLiteralNode(
                                /*members*/
                                void 0), 1 /* SingleLine */);
                            }
                            if (resolved.callSignatures.length === 1 && !resolved.constructSignatures.length) {
                                const signature = resolved.callSignatures[0];
                                const signatureNode = signatureToSignatureDeclarationHelper(signature, 184 /* FunctionType */, context);
                                return signatureNode;
                            }
                            if (resolved.constructSignatures.length === 1 && !resolved.callSignatures.length) {
                                const signature = resolved.constructSignatures[0];
                                const signatureNode = signatureToSignatureDeclarationHelper(signature, 185 /* ConstructorType */, context);
                                return signatureNode;
                            }
                        }
                        const abstractSignatures = filter(resolved.constructSignatures, (signature) => !!(signature.flags & 4 /* Abstract */));
                        if (some(abstractSignatures)) {
                            const types = map(abstractSignatures, getOrCreateTypeFromSignature);
                            const typeElementCount = resolved.callSignatures.length + (resolved.constructSignatures.length - abstractSignatures.length) + resolved.indexInfos.length + // exclude `prototype` when writing a class expression as a type literal, as per
                                // the logic in `createTypeNodesFromResolvedType`.
                                (context.flags & 2048 /* WriteClassExpressionAsTypeLiteral */ ? countWhere(resolved.properties, (p) => !(p.flags & 4194304 /* Prototype */)) : length(resolved.properties));
                            if (typeElementCount) {
                                types.push(getResolvedTypeWithoutAbstractConstructSignatures(resolved));
                            }
                            return typeToTypeNodeHelper(getIntersectionType(types), context);
                        }
                        const savedFlags = context.flags;
                        context.flags |= 4194304 /* InObjectTypeLiteral */;
                        const members = createTypeNodesFromResolvedType(resolved);
                        context.flags = savedFlags;
                        const typeLiteralNode = factory.createTypeLiteralNode(members);
                        context.approximateLength += 2;
                        setEmitFlags(typeLiteralNode, context.flags & 1024 /* MultilineObjectLiterals */ ? 0 : 1 /* SingleLine */);
                        return typeLiteralNode;
                    }
                    function typeReferenceToTypeNode(type2) {
                        let typeArguments = getTypeArguments(type2);
                        if (type2.target === globalArrayType || type2.target === globalReadonlyArrayType) {
                            if (context.flags & 2 /* WriteArrayAsGenericType */) {
                                const typeArgumentNode = typeToTypeNodeHelper(typeArguments[0], context);
                                return factory.createTypeReferenceNode(type2.target === globalArrayType ? "Array" : "ReadonlyArray", [typeArgumentNode]);
                            }
                            const elementType = typeToTypeNodeHelper(typeArguments[0], context);
                            const arrayType = factory.createArrayTypeNode(elementType);
                            return type2.target === globalArrayType ? arrayType : factory.createTypeOperatorNode(148 /* ReadonlyKeyword */, arrayType);
                        }
                        else if (type2.target.objectFlags & 8 /* Tuple */) {
                            typeArguments = sameMap(typeArguments, (t, i) => removeMissingType(t, !!(type2.target.elementFlags[i] & 2 /* Optional */)));
                            if (typeArguments.length > 0) {
                                const arity = getTypeReferenceArity(type2);
                                const tupleConstituentNodes = mapToTypeNodes(typeArguments.slice(0, arity), context);
                                if (tupleConstituentNodes) {
                                    const { labeledElementDeclarations } = type2.target;
                                    for (let i = 0; i < tupleConstituentNodes.length; i++) {
                                        const flags = type2.target.elementFlags[i];
                                        const labeledElementDeclaration = labeledElementDeclarations == null ? void 0 : labeledElementDeclarations[i];
                                        if (labeledElementDeclaration) {
                                            tupleConstituentNodes[i] = factory.createNamedTupleMember(flags & 12 /* Variable */ ? factory.createToken(26 /* DotDotDotToken */) : void 0, factory.createIdentifier(unescapeLeadingUnderscores(getTupleElementLabel(labeledElementDeclaration))), flags & 2 /* Optional */ ? factory.createToken(58 /* QuestionToken */) : void 0, flags & 4 /* Rest */ ? factory.createArrayTypeNode(tupleConstituentNodes[i]) : tupleConstituentNodes[i]);
                                        }
                                        else {
                                            tupleConstituentNodes[i] = flags & 12 /* Variable */ ? factory.createRestTypeNode(flags & 4 /* Rest */ ? factory.createArrayTypeNode(tupleConstituentNodes[i]) : tupleConstituentNodes[i]) : flags & 2 /* Optional */ ? factory.createOptionalTypeNode(tupleConstituentNodes[i]) : tupleConstituentNodes[i];
                                        }
                                    }
                                    const tupleTypeNode = setEmitFlags(factory.createTupleTypeNode(tupleConstituentNodes), 1 /* SingleLine */);
                                    return type2.target.readonly ? factory.createTypeOperatorNode(148 /* ReadonlyKeyword */, tupleTypeNode) : tupleTypeNode;
                                }
                            }
                            if (context.encounteredError || context.flags & 524288 /* AllowEmptyTuple */) {
                                const tupleTypeNode = setEmitFlags(factory.createTupleTypeNode([]), 1 /* SingleLine */);
                                return type2.target.readonly ? factory.createTypeOperatorNode(148 /* ReadonlyKeyword */, tupleTypeNode) : tupleTypeNode;
                            }
                            context.encounteredError = true;
                            return void 0;
                        }
                        else if (context.flags & 2048 /* WriteClassExpressionAsTypeLiteral */ && type2.symbol.valueDeclaration && isClassLike(type2.symbol.valueDeclaration) && !isValueSymbolAccessible(type2.symbol, context.enclosingDeclaration)) {
                            return createAnonymousTypeNode(type2);
                        }
                        else {
                            const outerTypeParameters = type2.target.outerTypeParameters;
                            let i = 0;
                            let resultType;
                            if (outerTypeParameters) {
                                const length2 = outerTypeParameters.length;
                                while (i < length2) {
                                    const start = i;
                                    const parent2 = getParentSymbolOfTypeParameter(outerTypeParameters[i]);
                                    do {
                                        i++;
                                    } while (i < length2 && getParentSymbolOfTypeParameter(outerTypeParameters[i]) === parent2);
                                    if (!rangeEquals(outerTypeParameters, typeArguments, start, i)) {
                                        const typeArgumentSlice = mapToTypeNodes(typeArguments.slice(start, i), context);
                                        const flags2 = context.flags;
                                        context.flags |= 16 /* ForbidIndexedAccessSymbolReferences */;
                                        const ref = symbolToTypeNode(parent2, context, 788968 /* Type */, typeArgumentSlice);
                                        context.flags = flags2;
                                        resultType = !resultType ? ref : appendReferenceToType(resultType, ref);
                                    }
                                }
                            }
                            let typeArgumentNodes;
                            if (typeArguments.length > 0) {
                                const typeParameterCount = (type2.target.typeParameters || emptyArray).length;
                                typeArgumentNodes = mapToTypeNodes(typeArguments.slice(i, typeParameterCount), context);
                            }
                            const flags = context.flags;
                            context.flags |= 16 /* ForbidIndexedAccessSymbolReferences */;
                            const finalRef = symbolToTypeNode(type2.symbol, context, 788968 /* Type */, typeArgumentNodes);
                            context.flags = flags;
                            return !resultType ? finalRef : appendReferenceToType(resultType, finalRef);
                        }
                    }
                    function appendReferenceToType(root, ref) {
                        if (isImportTypeNode(root)) {
                            let typeArguments = root.typeArguments;
                            let qualifier = root.qualifier;
                            if (qualifier) {
                                if (isIdentifier(qualifier)) {
                                    if (typeArguments !== getIdentifierTypeArguments(qualifier)) {
                                        qualifier = setIdentifierTypeArguments(factory.cloneNode(qualifier), typeArguments);
                                    }
                                }
                                else {
                                    if (typeArguments !== getIdentifierTypeArguments(qualifier.right)) {
                                        qualifier = factory.updateQualifiedName(qualifier, qualifier.left, setIdentifierTypeArguments(factory.cloneNode(qualifier.right), typeArguments));
                                    }
                                }
                            }
                            typeArguments = ref.typeArguments;
                            const ids = getAccessStack(ref);
                            for (const id of ids) {
                                qualifier = qualifier ? factory.createQualifiedName(qualifier, id) : id;
                            }
                            return factory.updateImportTypeNode(root, root.argument, root.attributes, qualifier, typeArguments, root.isTypeOf);
                        }
                        else {
                            let typeArguments = root.typeArguments;
                            let typeName = root.typeName;
                            if (isIdentifier(typeName)) {
                                if (typeArguments !== getIdentifierTypeArguments(typeName)) {
                                    typeName = setIdentifierTypeArguments(factory.cloneNode(typeName), typeArguments);
                                }
                            }
                            else {
                                if (typeArguments !== getIdentifierTypeArguments(typeName.right)) {
                                    typeName = factory.updateQualifiedName(typeName, typeName.left, setIdentifierTypeArguments(factory.cloneNode(typeName.right), typeArguments));
                                }
                            }
                            typeArguments = ref.typeArguments;
                            const ids = getAccessStack(ref);
                            for (const id of ids) {
                                typeName = factory.createQualifiedName(typeName, id);
                            }
                            return factory.updateTypeReferenceNode(root, typeName, typeArguments);
                        }
                    }
                    function getAccessStack(ref) {
                        let state = ref.typeName;
                        const ids = [];
                        while (!isIdentifier(state)) {
                            ids.unshift(state.right);
                            state = state.left;
                        }
                        ids.unshift(state);
                        return ids;
                    }
                    function createTypeNodesFromResolvedType(resolvedType) {
                        if (checkTruncationLength(context)) {
                            return [factory.createPropertySignature(
                                /*modifiers*/
                                void 0, "...", 
                                /*questionToken*/
                                void 0, 
                                /*type*/
                                void 0)];
                        }
                        const typeElements = [];
                        for (const signature of resolvedType.callSignatures) {
                            typeElements.push(signatureToSignatureDeclarationHelper(signature, 179 /* CallSignature */, context));
                        }
                        for (const signature of resolvedType.constructSignatures) {
                            if (signature.flags & 4 /* Abstract */)
                                continue;
                            typeElements.push(signatureToSignatureDeclarationHelper(signature, 180 /* ConstructSignature */, context));
                        }
                        for (const info of resolvedType.indexInfos) {
                            typeElements.push(indexInfoToIndexSignatureDeclarationHelper(info, context, resolvedType.objectFlags & 1024 /* ReverseMapped */ ? createElidedInformationPlaceholder(context) : void 0));
                        }
                        const properties = resolvedType.properties;
                        if (!properties) {
                            return typeElements;
                        }
                        let i = 0;
                        for (const propertySymbol of properties) {
                            i++;
                            if (context.flags & 2048 /* WriteClassExpressionAsTypeLiteral */) {
                                if (propertySymbol.flags & 4194304 /* Prototype */) {
                                    continue;
                                }
                                if (getDeclarationModifierFlagsFromSymbol(propertySymbol) & (2 /* Private */ | 4 /* Protected */) && context.tracker.reportPrivateInBaseOfClassExpression) {
                                    context.tracker.reportPrivateInBaseOfClassExpression(unescapeLeadingUnderscores(propertySymbol.escapedName));
                                }
                            }
                            if (checkTruncationLength(context) && i + 2 < properties.length - 1) {
                                typeElements.push(factory.createPropertySignature(
                                /*modifiers*/
                                void 0, `... ${properties.length - i} more ...`, 
                                /*questionToken*/
                                void 0, 
                                /*type*/
                                void 0));
                                addPropertyToElementList(properties[properties.length - 1], context, typeElements);
                                break;
                            }
                            addPropertyToElementList(propertySymbol, context, typeElements);
                        }
                        return typeElements.length ? typeElements : void 0;
                    }
                }
                function createElidedInformationPlaceholder(context) {
                    context.approximateLength += 3;
                    if (!(context.flags & 1 /* NoTruncation */)) {
                        return factory.createTypeReferenceNode(factory.createIdentifier("..."), 
                        /*typeArguments*/
                        void 0);
                    }
                    return factory.createKeywordTypeNode(133 /* AnyKeyword */);
                }
                function shouldUsePlaceholderForProperty(propertySymbol, context) {
                    var _a;
                    return !!(getCheckFlags(propertySymbol) & 8192 /* ReverseMapped */) && (contains(context.reverseMappedStack, propertySymbol) || ((_a = context.reverseMappedStack) == null ? void 0 : _a[0]) && !(getObjectFlags(last(context.reverseMappedStack).links.propertyType) & 16 /* Anonymous */));
                }
                function addPropertyToElementList(propertySymbol, context, typeElements) {
                    var _a;
                    const propertyIsReverseMapped = !!(getCheckFlags(propertySymbol) & 8192 /* ReverseMapped */);
                    const propertyType = shouldUsePlaceholderForProperty(propertySymbol, context) ? anyType : getNonMissingTypeOfSymbol(propertySymbol);
                    const saveEnclosingDeclaration = context.enclosingDeclaration;
                    context.enclosingDeclaration = void 0;
                    if (context.tracker.canTrackSymbol && isLateBoundName(propertySymbol.escapedName)) {
                        if (propertySymbol.declarations) {
                            const decl = first(propertySymbol.declarations);
                            if (hasLateBindableName(decl)) {
                                if (isBinaryExpression(decl)) {
                                    const name = getNameOfDeclaration(decl);
                                    if (name && isElementAccessExpression(name) && isPropertyAccessEntityNameExpression(name.argumentExpression)) {
                                        trackComputedName(name.argumentExpression, saveEnclosingDeclaration, context);
                                    }
                                }
                                else {
                                    trackComputedName(decl.name.expression, saveEnclosingDeclaration, context);
                                }
                            }
                        }
                        else {
                            context.tracker.reportNonSerializableProperty(symbolToString(propertySymbol));
                        }
                    }
                    context.enclosingDeclaration = propertySymbol.valueDeclaration || ((_a = propertySymbol.declarations) == null ? void 0 : _a[0]) || saveEnclosingDeclaration;
                    const propertyName = getPropertyNameNodeForSymbol(propertySymbol, context);
                    context.enclosingDeclaration = saveEnclosingDeclaration;
                    context.approximateLength += symbolName(propertySymbol).length + 1;
                    if (propertySymbol.flags & 98304 /* Accessor */) {
                        const writeType = getWriteTypeOfSymbol(propertySymbol);
                        if (propertyType !== writeType && !isErrorType(propertyType) && !isErrorType(writeType)) {
                            const getterDeclaration = getDeclarationOfKind(propertySymbol, 177 /* GetAccessor */);
                            const getterSignature = getSignatureFromDeclaration(getterDeclaration);
                            typeElements.push(setCommentRange(signatureToSignatureDeclarationHelper(getterSignature, 177 /* GetAccessor */, context, { name: propertyName }), getterDeclaration));
                            const setterDeclaration = getDeclarationOfKind(propertySymbol, 178 /* SetAccessor */);
                            const setterSignature = getSignatureFromDeclaration(setterDeclaration);
                            typeElements.push(setCommentRange(signatureToSignatureDeclarationHelper(setterSignature, 178 /* SetAccessor */, context, { name: propertyName }), setterDeclaration));
                            return;
                        }
                    }
                    const optionalToken = propertySymbol.flags & 16777216 /* Optional */ ? factory.createToken(58 /* QuestionToken */) : void 0;
                    if (propertySymbol.flags & (16 /* Function */ | 8192 /* Method */) && !getPropertiesOfObjectType(propertyType).length && !isReadonlySymbol(propertySymbol)) {
                        const signatures = getSignaturesOfType(filterType(propertyType, (t) => !(t.flags & 32768 /* Undefined */)), 0 /* Call */);
                        for (const signature of signatures) {
                            const methodDeclaration = signatureToSignatureDeclarationHelper(signature, 173 /* MethodSignature */, context, { name: propertyName, questionToken: optionalToken });
                            typeElements.push(preserveCommentsOn(methodDeclaration));
                        }
                        if (signatures.length || !optionalToken) {
                            return;
                        }
                    }
                    let propertyTypeNode;
                    if (shouldUsePlaceholderForProperty(propertySymbol, context)) {
                        propertyTypeNode = createElidedInformationPlaceholder(context);
                    }
                    else {
                        if (propertyIsReverseMapped) {
                            context.reverseMappedStack || (context.reverseMappedStack = []);
                            context.reverseMappedStack.push(propertySymbol);
                        }
                        propertyTypeNode = propertyType ? serializeTypeForDeclaration(context, propertyType, propertySymbol, saveEnclosingDeclaration) : factory.createKeywordTypeNode(133 /* AnyKeyword */);
                        if (propertyIsReverseMapped) {
                            context.reverseMappedStack.pop();
                        }
                    }
                    const modifiers = isReadonlySymbol(propertySymbol) ? [factory.createToken(148 /* ReadonlyKeyword */)] : void 0;
                    if (modifiers) {
                        context.approximateLength += 9;
                    }
                    const propertySignature = factory.createPropertySignature(modifiers, propertyName, optionalToken, propertyTypeNode);
                    typeElements.push(preserveCommentsOn(propertySignature));
                    function preserveCommentsOn(node) {
                        var _a2;
                        const jsdocPropertyTag = (_a2 = propertySymbol.declarations) == null ? void 0 : _a2.find((d) => d.kind === 355 /* JSDocPropertyTag */);
                        if (jsdocPropertyTag) {
                            const commentText = getTextOfJSDocComment(jsdocPropertyTag.comment);
                            if (commentText) {
                                setSyntheticLeadingComments(node, [{ kind: 3 /* MultiLineCommentTrivia */, text: "*\n * " + commentText.replace(/\n/g, "\n * ") + "\n ", pos: -1, end: -1, hasTrailingNewLine: true }]);
                            }
                        }
                        else if (propertySymbol.valueDeclaration) {
                            setCommentRange(node, propertySymbol.valueDeclaration);
                        }
                        return node;
                    }
                }
                function mapToTypeNodes(types, context, isBareList) {
                    if (some(types)) {
                        if (checkTruncationLength(context)) {
                            if (!isBareList) {
                                return [factory.createTypeReferenceNode("...", 
                                    /*typeArguments*/
                                    void 0)];
                            }
                            else if (types.length > 2) {
                                return [
                                    typeToTypeNodeHelper(types[0], context),
                                    factory.createTypeReferenceNode(`... ${types.length - 2} more ...`, 
                                    /*typeArguments*/
                                    void 0),
                                    typeToTypeNodeHelper(types[types.length - 1], context)
                                ];
                            }
                        }
                        const mayHaveNameCollisions = !(context.flags & 64 /* UseFullyQualifiedType */);
                        const seenNames = mayHaveNameCollisions ? createMultiMap() : void 0;
                        const result = [];
                        let i = 0;
                        for (const type of types) {
                            i++;
                            if (checkTruncationLength(context) && i + 2 < types.length - 1) {
                                result.push(factory.createTypeReferenceNode(`... ${types.length - i} more ...`, 
                                /*typeArguments*/
                                void 0));
                                const typeNode2 = typeToTypeNodeHelper(types[types.length - 1], context);
                                if (typeNode2) {
                                    result.push(typeNode2);
                                }
                                break;
                            }
                            context.approximateLength += 2;
                            const typeNode = typeToTypeNodeHelper(type, context);
                            if (typeNode) {
                                result.push(typeNode);
                                if (seenNames && isIdentifierTypeReference(typeNode)) {
                                    seenNames.add(typeNode.typeName.escapedText, [type, result.length - 1]);
                                }
                            }
                        }
                        if (seenNames) {
                            const saveContextFlags = context.flags;
                            context.flags |= 64 /* UseFullyQualifiedType */;
                            seenNames.forEach((types2) => {
                                if (!arrayIsHomogeneous(types2, ([a], [b]) => typesAreSameReference(a, b))) {
                                    for (const [type, resultIndex] of types2) {
                                        result[resultIndex] = typeToTypeNodeHelper(type, context);
                                    }
                                }
                            });
                            context.flags = saveContextFlags;
                        }
                        return result;
                    }
                }
                function typesAreSameReference(a, b) {
                    return a === b || !!a.symbol && a.symbol === b.symbol || !!a.aliasSymbol && a.aliasSymbol === b.aliasSymbol;
                }
                function indexInfoToIndexSignatureDeclarationHelper(indexInfo, context, typeNode) {
                    const name = getNameFromIndexInfo(indexInfo) || "x";
                    const indexerTypeNode = typeToTypeNodeHelper(indexInfo.keyType, context);
                    const indexingParameter = factory.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, name, 
                    /*questionToken*/
                    void 0, indexerTypeNode, 
                    /*initializer*/
                    void 0);
                    if (!typeNode) {
                        typeNode = typeToTypeNodeHelper(indexInfo.type || anyType, context);
                    }
                    if (!indexInfo.type && !(context.flags & 2097152 /* AllowEmptyIndexInfoType */)) {
                        context.encounteredError = true;
                    }
                    context.approximateLength += name.length + 4;
                    return factory.createIndexSignature(indexInfo.isReadonly ? [factory.createToken(148 /* ReadonlyKeyword */)] : void 0, [indexingParameter], typeNode);
                }
                function signatureToSignatureDeclarationHelper(signature, kind, context, options) {
                    var _a;
                    const suppressAny = context.flags & 256 /* SuppressAnyReturnType */;
                    if (suppressAny)
                        context.flags &= ~256 /* SuppressAnyReturnType */;
                    context.approximateLength += 3;
                    let typeParameters;
                    let typeArguments;
                    if (context.flags & 32 /* WriteTypeArgumentsOfSignature */ && signature.target && signature.mapper && signature.target.typeParameters) {
                        typeArguments = signature.target.typeParameters.map((parameter) => typeToTypeNodeHelper(instantiateType(parameter, signature.mapper), context));
                    }
                    else {
                        typeParameters = signature.typeParameters && signature.typeParameters.map((parameter) => typeParameterToDeclaration(parameter, context));
                    }
                    const expandedParams = getExpandedParameters(signature, 
                    /*skipUnionExpanding*/
                    true)[0];
                    let cleanup;
                    if (context.enclosingDeclaration && signature.declaration && signature.declaration !== context.enclosingDeclaration && !isInJSFile(signature.declaration) && (some(expandedParams) || some(signature.typeParameters))) {
                        let pushFakeScope2 = function (kind2, addAll) {
                            Debug.assert(context.enclosingDeclaration);
                            let existingFakeScope;
                            if (getNodeLinks(context.enclosingDeclaration).fakeScopeForSignatureDeclaration === kind2) {
                                existingFakeScope = context.enclosingDeclaration;
                            }
                            else if (context.enclosingDeclaration.parent && getNodeLinks(context.enclosingDeclaration.parent).fakeScopeForSignatureDeclaration === kind2) {
                                existingFakeScope = context.enclosingDeclaration.parent;
                            }
                            Debug.assertOptionalNode(existingFakeScope, isBlock);
                            const locals = (existingFakeScope == null ? void 0 : existingFakeScope.locals) ?? createSymbolTable();
                            let newLocals;
                            addAll((name, symbol) => {
                                if (!locals.has(name)) {
                                    newLocals = append(newLocals, name);
                                    locals.set(name, symbol);
                                }
                            });
                            if (!newLocals)
                                return;
                            const oldCleanup = cleanup;
                            function undo() {
                                forEach(newLocals, (s) => locals.delete(s));
                                oldCleanup == null ? void 0 : oldCleanup();
                            }
                            if (existingFakeScope) {
                                cleanup = undo;
                            }
                            else {
                                const fakeScope = parseNodeFactory.createBlock(emptyArray);
                                getNodeLinks(fakeScope).fakeScopeForSignatureDeclaration = kind2;
                                fakeScope.locals = locals;
                                const saveEnclosingDeclaration = context.enclosingDeclaration;
                                setParent(fakeScope, saveEnclosingDeclaration);
                                context.enclosingDeclaration = fakeScope;
                                cleanup = () => {
                                    context.enclosingDeclaration = saveEnclosingDeclaration;
                                    undo();
                                };
                            }
                        };
                        var pushFakeScope = pushFakeScope2;
                        pushFakeScope2("params", (add) => {
                            for (const param of expandedParams) {
                                add(param.escapedName, param);
                            }
                        });
                        if (context.flags & 4 /* GenerateNamesForShadowedTypeParams */) {
                            pushFakeScope2("typeParams", (add) => {
                                for (const typeParam of signature.typeParameters ?? emptyArray) {
                                    const typeParamName = typeParameterToName(typeParam, context).escapedText;
                                    add(typeParamName, typeParam.symbol);
                                }
                            });
                        }
                    }
                    const parameters = (some(expandedParams, (p) => p !== expandedParams[expandedParams.length - 1] && !!(getCheckFlags(p) & 32768 /* RestParameter */)) ? signature.parameters : expandedParams).map((parameter) => symbolToParameterDeclaration(parameter, context, kind === 176 /* Constructor */, options == null ? void 0 : options.privateSymbolVisitor, options == null ? void 0 : options.bundledImports));
                    const thisParameter = context.flags & 33554432 /* OmitThisParameter */ ? void 0 : tryGetThisParameterDeclaration(signature, context);
                    if (thisParameter) {
                        parameters.unshift(thisParameter);
                    }
                    let returnTypeNode;
                    const typePredicate = getTypePredicateOfSignature(signature);
                    if (typePredicate) {
                        const assertsModifier = typePredicate.kind === 2 /* AssertsThis */ || typePredicate.kind === 3 /* AssertsIdentifier */ ? factory.createToken(131 /* AssertsKeyword */) : void 0;
                        const parameterName = typePredicate.kind === 1 /* Identifier */ || typePredicate.kind === 3 /* AssertsIdentifier */ ? setEmitFlags(factory.createIdentifier(typePredicate.parameterName), 16777216 /* NoAsciiEscaping */) : factory.createThisTypeNode();
                        const typeNode = typePredicate.type && typeToTypeNodeHelper(typePredicate.type, context);
                        returnTypeNode = factory.createTypePredicateNode(assertsModifier, parameterName, typeNode);
                    }
                    else {
                        const returnType = getReturnTypeOfSignature(signature);
                        if (returnType && !(suppressAny && isTypeAny(returnType))) {
                            returnTypeNode = serializeReturnTypeForSignature(context, returnType, signature, options == null ? void 0 : options.privateSymbolVisitor, options == null ? void 0 : options.bundledImports);
                        }
                        else if (!suppressAny) {
                            returnTypeNode = factory.createKeywordTypeNode(133 /* AnyKeyword */);
                        }
                    }
                    let modifiers = options == null ? void 0 : options.modifiers;
                    if (kind === 185 /* ConstructorType */ && signature.flags & 4 /* Abstract */) {
                        const flags = modifiersToFlags(modifiers);
                        modifiers = factory.createModifiersFromModifierFlags(flags | 64 /* Abstract */);
                    }
                    const node = kind === 179 /* CallSignature */ ? factory.createCallSignature(typeParameters, parameters, returnTypeNode) : kind === 180 /* ConstructSignature */ ? factory.createConstructSignature(typeParameters, parameters, returnTypeNode) : kind === 173 /* MethodSignature */ ? factory.createMethodSignature(modifiers, (options == null ? void 0 : options.name) ?? factory.createIdentifier(""), options == null ? void 0 : options.questionToken, typeParameters, parameters, returnTypeNode) : kind === 174 /* MethodDeclaration */ ? factory.createMethodDeclaration(modifiers, 
                    /*asteriskToken*/
                    void 0, (options == null ? void 0 : options.name) ?? factory.createIdentifier(""), 
                    /*questionToken*/
                    void 0, typeParameters, parameters, returnTypeNode, 
                    /*body*/
                    void 0) : kind === 176 /* Constructor */ ? factory.createConstructorDeclaration(modifiers, parameters, 
                    /*body*/
                    void 0) : kind === 177 /* GetAccessor */ ? factory.createGetAccessorDeclaration(modifiers, (options == null ? void 0 : options.name) ?? factory.createIdentifier(""), parameters, returnTypeNode, 
                    /*body*/
                    void 0) : kind === 178 /* SetAccessor */ ? factory.createSetAccessorDeclaration(modifiers, (options == null ? void 0 : options.name) ?? factory.createIdentifier(""), parameters, 
                    /*body*/
                    void 0) : kind === 181 /* IndexSignature */ ? factory.createIndexSignature(modifiers, parameters, returnTypeNode) : kind === 324 /* JSDocFunctionType */ ? factory.createJSDocFunctionType(parameters, returnTypeNode) : kind === 184 /* FunctionType */ ? factory.createFunctionTypeNode(typeParameters, parameters, returnTypeNode ?? factory.createTypeReferenceNode(factory.createIdentifier(""))) : kind === 185 /* ConstructorType */ ? factory.createConstructorTypeNode(modifiers, typeParameters, parameters, returnTypeNode ?? factory.createTypeReferenceNode(factory.createIdentifier(""))) : kind === 262 /* FunctionDeclaration */ ? factory.createFunctionDeclaration(modifiers, 
                    /*asteriskToken*/
                    void 0, (options == null ? void 0 : options.name) ? cast(options.name, isIdentifier) : factory.createIdentifier(""), typeParameters, parameters, returnTypeNode, 
                    /*body*/
                    void 0) : kind === 218 /* FunctionExpression */ ? factory.createFunctionExpression(modifiers, 
                    /*asteriskToken*/
                    void 0, (options == null ? void 0 : options.name) ? cast(options.name, isIdentifier) : factory.createIdentifier(""), typeParameters, parameters, returnTypeNode, factory.createBlock([])) : kind === 219 /* ArrowFunction */ ? factory.createArrowFunction(modifiers, typeParameters, parameters, returnTypeNode, 
                    /*equalsGreaterThanToken*/
                    void 0, factory.createBlock([])) : Debug.assertNever(kind);
                    if (typeArguments) {
                        node.typeArguments = factory.createNodeArray(typeArguments);
                    }
                    if (((_a = signature.declaration) == null ? void 0 : _a.kind) === 330 /* JSDocSignature */ && signature.declaration.parent.kind === 346 /* JSDocOverloadTag */) {
                        const comment = getTextOfNode(signature.declaration.parent.parent, 
                        /*includeTrivia*/
                        true).slice(2, -2).split(/\r\n|\n|\r/).map((line) => line.replace(/^\s+/, " ")).join("\n");
                        addSyntheticLeadingComment(node, 3 /* MultiLineCommentTrivia */, comment, 
                        /*hasTrailingNewLine*/
                        true);
                    }
                    cleanup == null ? void 0 : cleanup();
                    return node;
                }
                function tryGetThisParameterDeclaration(signature, context) {
                    if (signature.thisParameter) {
                        return symbolToParameterDeclaration(signature.thisParameter, context);
                    }
                    if (signature.declaration && isInJSFile(signature.declaration)) {
                        const thisTag = getJSDocThisTag(signature.declaration);
                        if (thisTag && thisTag.typeExpression) {
                            return factory.createParameterDeclaration(
                            /*modifiers*/
                            void 0, 
                            /*dotDotDotToken*/
                            void 0, "this", 
                            /*questionToken*/
                            void 0, typeToTypeNodeHelper(getTypeFromTypeNode(thisTag.typeExpression), context));
                        }
                    }
                }
                function typeParameterToDeclarationWithConstraint(type, context, constraintNode) {
                    const savedContextFlags = context.flags;
                    context.flags &= ~512 /* WriteTypeParametersInQualifiedName */;
                    const modifiers = factory.createModifiersFromModifierFlags(getTypeParameterModifiers(type));
                    const name = typeParameterToName(type, context);
                    const defaultParameter = getDefaultFromTypeParameter(type);
                    const defaultParameterNode = defaultParameter && typeToTypeNodeHelper(defaultParameter, context);
                    context.flags = savedContextFlags;
                    return factory.createTypeParameterDeclaration(modifiers, name, constraintNode, defaultParameterNode);
                }
                function typeParameterToDeclaration(type, context, constraint = getConstraintOfTypeParameter(type)) {
                    const constraintNode = constraint && typeToTypeNodeHelper(constraint, context);
                    return typeParameterToDeclarationWithConstraint(type, context, constraintNode);
                }
                function getEffectiveParameterDeclaration(parameterSymbol) {
                    const parameterDeclaration = getDeclarationOfKind(parameterSymbol, 169 /* Parameter */);
                    if (parameterDeclaration) {
                        return parameterDeclaration;
                    }
                    if (!isTransientSymbol(parameterSymbol)) {
                        return getDeclarationOfKind(parameterSymbol, 348 /* JSDocParameterTag */);
                    }
                }
                function symbolToParameterDeclaration(parameterSymbol, context, preserveModifierFlags, privateSymbolVisitor, bundledImports) {
                    const parameterDeclaration = getEffectiveParameterDeclaration(parameterSymbol);
                    let parameterType = getTypeOfSymbol(parameterSymbol);
                    if (parameterDeclaration && isRequiredInitializedParameter(parameterDeclaration)) {
                        parameterType = getOptionalType(parameterType);
                    }
                    const parameterTypeNode = serializeTypeForDeclaration(context, parameterType, parameterSymbol, context.enclosingDeclaration, privateSymbolVisitor, bundledImports);
                    const modifiers = !(context.flags & 8192 /* OmitParameterModifiers */) && preserveModifierFlags && parameterDeclaration && canHaveModifiers(parameterDeclaration) ? map(getModifiers(parameterDeclaration), factory.cloneNode) : void 0;
                    const isRest = parameterDeclaration && isRestParameter(parameterDeclaration) || getCheckFlags(parameterSymbol) & 32768 /* RestParameter */;
                    const dotDotDotToken = isRest ? factory.createToken(26 /* DotDotDotToken */) : void 0;
                    const name = parameterToParameterDeclarationName(parameterSymbol, parameterDeclaration, context);
                    const isOptional = parameterDeclaration && isOptionalParameter(parameterDeclaration) || getCheckFlags(parameterSymbol) & 16384 /* OptionalParameter */;
                    const questionToken = isOptional ? factory.createToken(58 /* QuestionToken */) : void 0;
                    const parameterNode = factory.createParameterDeclaration(modifiers, dotDotDotToken, name, questionToken, parameterTypeNode, 
                    /*initializer*/
                    void 0);
                    context.approximateLength += symbolName(parameterSymbol).length + 3;
                    return parameterNode;
                }
                function parameterToParameterDeclarationName(parameterSymbol, parameterDeclaration, context) {
                    return parameterDeclaration ? parameterDeclaration.name ? parameterDeclaration.name.kind === 80 /* Identifier */ ? setEmitFlags(factory.cloneNode(parameterDeclaration.name), 16777216 /* NoAsciiEscaping */) : parameterDeclaration.name.kind === 166 /* QualifiedName */ ? setEmitFlags(factory.cloneNode(parameterDeclaration.name.right), 16777216 /* NoAsciiEscaping */) : cloneBindingName(parameterDeclaration.name) : symbolName(parameterSymbol) : symbolName(parameterSymbol);
                    function cloneBindingName(node) {
                        return elideInitializerAndSetEmitFlags(node);
                        function elideInitializerAndSetEmitFlags(node2) {
                            if (context.tracker.canTrackSymbol && isComputedPropertyName(node2) && isLateBindableName(node2)) {
                                trackComputedName(node2.expression, context.enclosingDeclaration, context);
                            }
                            let visited = visitEachChild(node2, elideInitializerAndSetEmitFlags, 
                            /*context*/
                            void 0, 
                            /*nodesVisitor*/
                            void 0, elideInitializerAndSetEmitFlags);
                            if (isBindingElement(visited)) {
                                visited = factory.updateBindingElement(visited, visited.dotDotDotToken, visited.propertyName, visited.name, 
                                /*initializer*/
                                void 0);
                            }
                            if (!nodeIsSynthesized(visited)) {
                                visited = factory.cloneNode(visited);
                            }
                            return setEmitFlags(visited, 1 /* SingleLine */ | 16777216 /* NoAsciiEscaping */);
                        }
                    }
                }
                function trackComputedName(accessExpression, enclosingDeclaration, context) {
                    if (!context.tracker.canTrackSymbol)
                        return;
                    const firstIdentifier = getFirstIdentifier(accessExpression);
                    const name = resolveName(firstIdentifier, firstIdentifier.escapedText, 111551 /* Value */ | 1048576 /* ExportValue */, 
                    /*nameNotFoundMessage*/
                    void 0, 
                    /*nameArg*/
                    void 0, 
                    /*isUse*/
                    true);
                    if (name) {
                        context.tracker.trackSymbol(name, enclosingDeclaration, 111551 /* Value */);
                    }
                }
                function lookupSymbolChain(symbol, context, meaning, yieldModuleSymbol) {
                    context.tracker.trackSymbol(symbol, context.enclosingDeclaration, meaning);
                    return lookupSymbolChainWorker(symbol, context, meaning, yieldModuleSymbol);
                }
                function lookupSymbolChainWorker(symbol, context, meaning, yieldModuleSymbol) {
                    let chain;
                    const isTypeParameter = symbol.flags & 262144 /* TypeParameter */;
                    if (!isTypeParameter && (context.enclosingDeclaration || context.flags & 64 /* UseFullyQualifiedType */) && !(context.flags & 134217728 /* DoNotIncludeSymbolChain */)) {
                        chain = Debug.checkDefined(getSymbolChain(symbol, meaning, 
                        /*endOfChain*/
                        true));
                        Debug.assert(chain && chain.length > 0);
                    }
                    else {
                        chain = [symbol];
                    }
                    return chain;
                    function getSymbolChain(symbol2, meaning2, endOfChain) {
                        let accessibleSymbolChain = getAccessibleSymbolChain(symbol2, context.enclosingDeclaration, meaning2, !!(context.flags & 128 /* UseOnlyExternalAliasing */));
                        let parentSpecifiers;
                        if (!accessibleSymbolChain || needsQualification(accessibleSymbolChain[0], context.enclosingDeclaration, accessibleSymbolChain.length === 1 ? meaning2 : getQualifiedLeftMeaning(meaning2))) {
                            const parents = getContainersOfSymbol(accessibleSymbolChain ? accessibleSymbolChain[0] : symbol2, context.enclosingDeclaration, meaning2);
                            if (length(parents)) {
                                parentSpecifiers = parents.map((symbol3) => some(symbol3.declarations, hasNonGlobalAugmentationExternalModuleSymbol) ? getSpecifierForModuleSymbol(symbol3, context) : void 0);
                                const indices = parents.map((_, i) => i);
                                indices.sort(sortByBestName);
                                const sortedParents = indices.map((i) => parents[i]);
                                for (const parent2 of sortedParents) {
                                    const parentChain = getSymbolChain(parent2, getQualifiedLeftMeaning(meaning2), 
                                    /*endOfChain*/
                                    false);
                                    if (parentChain) {
                                        if (parent2.exports && parent2.exports.get("export=" /* ExportEquals */) && getSymbolIfSameReference(parent2.exports.get("export=" /* ExportEquals */), symbol2)) {
                                            accessibleSymbolChain = parentChain;
                                            break;
                                        }
                                        accessibleSymbolChain = parentChain.concat(accessibleSymbolChain || [getAliasForSymbolInContainer(parent2, symbol2) || symbol2]);
                                        break;
                                    }
                                }
                            }
                        }
                        if (accessibleSymbolChain) {
                            return accessibleSymbolChain;
                        }
                        if (
                        // If this is the last part of outputting the symbol, always output. The cases apply only to parent symbols.
                        endOfChain || // If a parent symbol is an anonymous type, don't write it.
                            !(symbol2.flags & (2048 /* TypeLiteral */ | 4096 /* ObjectLiteral */))) {
                            if (!endOfChain && !yieldModuleSymbol && !!forEach(symbol2.declarations, hasNonGlobalAugmentationExternalModuleSymbol)) {
                                return;
                            }
                            return [symbol2];
                        }
                        function sortByBestName(a, b) {
                            const specifierA = parentSpecifiers[a];
                            const specifierB = parentSpecifiers[b];
                            if (specifierA && specifierB) {
                                const isBRelative = pathIsRelative(specifierB);
                                if (pathIsRelative(specifierA) === isBRelative) {
                                    return countPathComponents(specifierA) - countPathComponents(specifierB);
                                }
                                if (isBRelative) {
                                    return -1;
                                }
                                return 1;
                            }
                            return 0;
                        }
                    }
                }
                function typeParametersToTypeParameterDeclarations(symbol, context) {
                    let typeParameterNodes;
                    const targetSymbol = getTargetSymbol(symbol);
                    if (targetSymbol.flags & (32 /* Class */ | 64 /* Interface */ | 524288 /* TypeAlias */)) {
                        typeParameterNodes = factory.createNodeArray(map(getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(symbol), (tp) => typeParameterToDeclaration(tp, context)));
                    }
                    return typeParameterNodes;
                }
                function lookupTypeParameterNodes(chain, index, context) {
                    var _a;
                    Debug.assert(chain && 0 <= index && index < chain.length);
                    const symbol = chain[index];
                    const symbolId = getSymbolId(symbol);
                    if ((_a = context.typeParameterSymbolList) == null ? void 0 : _a.has(symbolId)) {
                        return void 0;
                    }
                    (context.typeParameterSymbolList || (context.typeParameterSymbolList = /* @__PURE__ */ new Set())).add(symbolId);
                    let typeParameterNodes;
                    if (context.flags & 512 /* WriteTypeParametersInQualifiedName */ && index < chain.length - 1) {
                        const parentSymbol = symbol;
                        const nextSymbol = chain[index + 1];
                        if (getCheckFlags(nextSymbol) & 1 /* Instantiated */) {
                            const params = getTypeParametersOfClassOrInterface(parentSymbol.flags & 2097152 /* Alias */ ? resolveAlias(parentSymbol) : parentSymbol);
                            typeParameterNodes = mapToTypeNodes(map(params, (t) => getMappedType(t, nextSymbol.links.mapper)), context);
                        }
                        else {
                            typeParameterNodes = typeParametersToTypeParameterDeclarations(symbol, context);
                        }
                    }
                    return typeParameterNodes;
                }
                function getTopmostIndexedAccessType(top) {
                    if (isIndexedAccessTypeNode(top.objectType)) {
                        return getTopmostIndexedAccessType(top.objectType);
                    }
                    return top;
                }
                function getSpecifierForModuleSymbol(symbol, context, overrideImportMode) {
                    let file = getDeclarationOfKind(symbol, 312 /* SourceFile */);
                    if (!file) {
                        const equivalentFileSymbol = firstDefined(symbol.declarations, (d) => getFileSymbolIfFileSymbolExportEqualsContainer(d, symbol));
                        if (equivalentFileSymbol) {
                            file = getDeclarationOfKind(equivalentFileSymbol, 312 /* SourceFile */);
                        }
                    }
                    if (file && file.moduleName !== void 0) {
                        return file.moduleName;
                    }
                    if (!file) {
                        if (context.tracker.trackReferencedAmbientModule) {
                            const ambientDecls = filter(symbol.declarations, isAmbientModule);
                            if (length(ambientDecls)) {
                                for (const decl of ambientDecls) {
                                    context.tracker.trackReferencedAmbientModule(decl, symbol);
                                }
                            }
                        }
                        if (ambientModuleSymbolRegex.test(symbol.escapedName)) {
                            return symbol.escapedName.substring(1, symbol.escapedName.length - 1);
                        }
                    }
                    if (!context.enclosingDeclaration || !context.tracker.moduleResolverHost) {
                        if (ambientModuleSymbolRegex.test(symbol.escapedName)) {
                            return symbol.escapedName.substring(1, symbol.escapedName.length - 1);
                        }
                        return getSourceFileOfNode(getNonAugmentationDeclaration(symbol)).fileName;
                    }
                    const contextFile = getSourceFileOfNode(getOriginalNode(context.enclosingDeclaration));
                    const resolutionMode = overrideImportMode || (contextFile == null ? void 0 : contextFile.impliedNodeFormat);
                    const cacheKey = createModeAwareCacheKey(contextFile.path, resolutionMode);
                    const links = getSymbolLinks(symbol);
                    let specifier = links.specifierCache && links.specifierCache.get(cacheKey);
                    if (!specifier) {
                        const isBundle2 = !!outFile(compilerOptions);
                        const { moduleResolverHost } = context.tracker;
                        const specifierCompilerOptions = isBundle2 ? { ...compilerOptions, baseUrl: moduleResolverHost.getCommonSourceDirectory() } : compilerOptions;
                        specifier = first(getModuleSpecifiers(symbol, checker, specifierCompilerOptions, contextFile, moduleResolverHost, {
                            importModuleSpecifierPreference: isBundle2 ? "non-relative" : "project-relative",
                            importModuleSpecifierEnding: isBundle2 ? "minimal" : resolutionMode === 99 /* ESNext */ ? "js" : void 0
                        }, { overrideImportMode }));
                        links.specifierCache ?? (links.specifierCache = /* @__PURE__ */ new Map());
                        links.specifierCache.set(cacheKey, specifier);
                    }
                    return specifier;
                }
                function symbolToEntityNameNode(symbol) {
                    const identifier = factory.createIdentifier(unescapeLeadingUnderscores(symbol.escapedName));
                    return symbol.parent ? factory.createQualifiedName(symbolToEntityNameNode(symbol.parent), identifier) : identifier;
                }
                function symbolToTypeNode(symbol, context, meaning, overrideTypeArguments) {
                    const chain = lookupSymbolChain(symbol, context, meaning, !(context.flags & 16384 /* UseAliasDefinedOutsideCurrentScope */));
                    const isTypeOf = meaning === 111551 /* Value */;
                    if (some(chain[0].declarations, hasNonGlobalAugmentationExternalModuleSymbol)) {
                        const nonRootParts = chain.length > 1 ? createAccessFromSymbolChain(chain, chain.length - 1, 1) : void 0;
                        const typeParameterNodes = overrideTypeArguments || lookupTypeParameterNodes(chain, 0, context);
                        const contextFile = getSourceFileOfNode(getOriginalNode(context.enclosingDeclaration));
                        const targetFile = getSourceFileOfModule(chain[0]);
                        let specifier;
                        let attributes;
                        if (getEmitModuleResolutionKind(compilerOptions) === 3 /* Node16 */ || getEmitModuleResolutionKind(compilerOptions) === 99 /* NodeNext */) {
                            if ((targetFile == null ? void 0 : targetFile.impliedNodeFormat) === 99 /* ESNext */ && targetFile.impliedNodeFormat !== (contextFile == null ? void 0 : contextFile.impliedNodeFormat)) {
                                specifier = getSpecifierForModuleSymbol(chain[0], context, 99 /* ESNext */);
                                attributes = factory.createImportAttributes(factory.createNodeArray([
                                    factory.createImportAttribute(factory.createStringLiteral("resolution-mode"), factory.createStringLiteral("import"))
                                ]));
                            }
                        }
                        if (!specifier) {
                            specifier = getSpecifierForModuleSymbol(chain[0], context);
                        }
                        if (!(context.flags & 67108864 /* AllowNodeModulesRelativePaths */) && getEmitModuleResolutionKind(compilerOptions) !== 1 /* Classic */ && specifier.includes("/node_modules/")) {
                            const oldSpecifier = specifier;
                            if (getEmitModuleResolutionKind(compilerOptions) === 3 /* Node16 */ || getEmitModuleResolutionKind(compilerOptions) === 99 /* NodeNext */) {
                                const swappedMode = (contextFile == null ? void 0 : contextFile.impliedNodeFormat) === 99 /* ESNext */ ? 1 /* CommonJS */ : 99 /* ESNext */;
                                specifier = getSpecifierForModuleSymbol(chain[0], context, swappedMode);
                                if (specifier.includes("/node_modules/")) {
                                    specifier = oldSpecifier;
                                }
                                else {
                                    attributes = factory.createImportAttributes(factory.createNodeArray([
                                        factory.createImportAttribute(factory.createStringLiteral("resolution-mode"), factory.createStringLiteral(swappedMode === 99 /* ESNext */ ? "import" : "require"))
                                    ]));
                                }
                            }
                            if (!attributes) {
                                context.encounteredError = true;
                                if (context.tracker.reportLikelyUnsafeImportRequiredError) {
                                    context.tracker.reportLikelyUnsafeImportRequiredError(oldSpecifier);
                                }
                            }
                        }
                        const lit = factory.createLiteralTypeNode(factory.createStringLiteral(specifier));
                        if (context.tracker.trackExternalModuleSymbolOfImportTypeNode)
                            context.tracker.trackExternalModuleSymbolOfImportTypeNode(chain[0]);
                        context.approximateLength += specifier.length + 10;
                        if (!nonRootParts || isEntityName(nonRootParts)) {
                            if (nonRootParts) {
                                const lastId = isIdentifier(nonRootParts) ? nonRootParts : nonRootParts.right;
                                setIdentifierTypeArguments(lastId, 
                                /*typeArguments*/
                                void 0);
                            }
                            return factory.createImportTypeNode(lit, attributes, nonRootParts, typeParameterNodes, isTypeOf);
                        }
                        else {
                            const splitNode = getTopmostIndexedAccessType(nonRootParts);
                            const qualifier = splitNode.objectType.typeName;
                            return factory.createIndexedAccessTypeNode(factory.createImportTypeNode(lit, attributes, qualifier, typeParameterNodes, isTypeOf), splitNode.indexType);
                        }
                    }
                    const entityName = createAccessFromSymbolChain(chain, chain.length - 1, 0);
                    if (isIndexedAccessTypeNode(entityName)) {
                        return entityName;
                    }
                    if (isTypeOf) {
                        return factory.createTypeQueryNode(entityName);
                    }
                    else {
                        const lastId = isIdentifier(entityName) ? entityName : entityName.right;
                        const lastTypeArgs = getIdentifierTypeArguments(lastId);
                        setIdentifierTypeArguments(lastId, 
                        /*typeArguments*/
                        void 0);
                        return factory.createTypeReferenceNode(entityName, lastTypeArgs);
                    }
                    function createAccessFromSymbolChain(chain2, index, stopper) {
                        const typeParameterNodes = index === chain2.length - 1 ? overrideTypeArguments : lookupTypeParameterNodes(chain2, index, context);
                        const symbol2 = chain2[index];
                        const parent2 = chain2[index - 1];
                        let symbolName2;
                        if (index === 0) {
                            context.flags |= 16777216 /* InInitialEntityName */;
                            symbolName2 = getNameOfSymbolAsWritten(symbol2, context);
                            context.approximateLength += (symbolName2 ? symbolName2.length : 0) + 1;
                            context.flags ^= 16777216 /* InInitialEntityName */;
                        }
                        else {
                            if (parent2 && getExportsOfSymbol(parent2)) {
                                const exports = getExportsOfSymbol(parent2);
                                forEachEntry(exports, (ex, name) => {
                                    if (getSymbolIfSameReference(ex, symbol2) && !isLateBoundName(name) && name !== "export=" /* ExportEquals */) {
                                        symbolName2 = unescapeLeadingUnderscores(name);
                                        return true;
                                    }
                                });
                            }
                        }
                        if (symbolName2 === void 0) {
                            const name = firstDefined(symbol2.declarations, getNameOfDeclaration);
                            if (name && isComputedPropertyName(name) && isEntityName(name.expression)) {
                                const LHS = createAccessFromSymbolChain(chain2, index - 1, stopper);
                                if (isEntityName(LHS)) {
                                    return factory.createIndexedAccessTypeNode(factory.createParenthesizedType(factory.createTypeQueryNode(LHS)), factory.createTypeQueryNode(name.expression));
                                }
                                return LHS;
                            }
                            symbolName2 = getNameOfSymbolAsWritten(symbol2, context);
                        }
                        context.approximateLength += symbolName2.length + 1;
                        if (!(context.flags & 16 /* ForbidIndexedAccessSymbolReferences */) && parent2 && getMembersOfSymbol(parent2) && getMembersOfSymbol(parent2).get(symbol2.escapedName) && getSymbolIfSameReference(getMembersOfSymbol(parent2).get(symbol2.escapedName), symbol2)) {
                            const LHS = createAccessFromSymbolChain(chain2, index - 1, stopper);
                            if (isIndexedAccessTypeNode(LHS)) {
                                return factory.createIndexedAccessTypeNode(LHS, factory.createLiteralTypeNode(factory.createStringLiteral(symbolName2)));
                            }
                            else {
                                return factory.createIndexedAccessTypeNode(factory.createTypeReferenceNode(LHS, typeParameterNodes), factory.createLiteralTypeNode(factory.createStringLiteral(symbolName2)));
                            }
                        }
                        const identifier = setEmitFlags(factory.createIdentifier(symbolName2), 16777216 /* NoAsciiEscaping */);
                        if (typeParameterNodes)
                            setIdentifierTypeArguments(identifier, factory.createNodeArray(typeParameterNodes));
                        identifier.symbol = symbol2;
                        if (index > stopper) {
                            const LHS = createAccessFromSymbolChain(chain2, index - 1, stopper);
                            if (!isEntityName(LHS)) {
                                return Debug.fail("Impossible construct - an export of an indexed access cannot be reachable");
                            }
                            return factory.createQualifiedName(LHS, identifier);
                        }
                        return identifier;
                    }
                }
                function typeParameterShadowsOtherTypeParameterInScope(escapedName, context, type) {
                    const result = resolveName(context.enclosingDeclaration, escapedName, 788968 /* Type */, 
                    /*nameNotFoundMessage*/
                    void 0, escapedName, 
                    /*isUse*/
                    false);
                    if (result && result.flags & 262144 /* TypeParameter */) {
                        return result !== type.symbol;
                    }
                    return false;
                }
                function typeParameterToName(type, context) {
                    var _a, _b;
                    if (context.flags & 4 /* GenerateNamesForShadowedTypeParams */ && context.typeParameterNames) {
                        const cached = context.typeParameterNames.get(getTypeId(type));
                        if (cached) {
                            return cached;
                        }
                    }
                    let result = symbolToName(type.symbol, context, 788968 /* Type */, 
                    /*expectsIdentifier*/
                    true);
                    if (!(result.kind & 80 /* Identifier */)) {
                        return factory.createIdentifier("(Missing type parameter)");
                    }
                    if (context.flags & 4 /* GenerateNamesForShadowedTypeParams */) {
                        const rawtext = result.escapedText;
                        let i = ((_a = context.typeParameterNamesByTextNextNameCount) == null ? void 0 : _a.get(rawtext)) || 0;
                        let text = rawtext;
                        while (((_b = context.typeParameterNamesByText) == null ? void 0 : _b.has(text)) || typeParameterShadowsOtherTypeParameterInScope(text, context, type)) {
                            i++;
                            text = `${rawtext}_${i}`;
                        }
                        if (text !== rawtext) {
                            const typeArguments = getIdentifierTypeArguments(result);
                            result = factory.createIdentifier(text);
                            setIdentifierTypeArguments(result, typeArguments);
                        }
                        (context.typeParameterNamesByTextNextNameCount || (context.typeParameterNamesByTextNextNameCount = /* @__PURE__ */ new Map())).set(rawtext, i);
                        (context.typeParameterNames || (context.typeParameterNames = /* @__PURE__ */ new Map())).set(getTypeId(type), result);
                        (context.typeParameterNamesByText || (context.typeParameterNamesByText = /* @__PURE__ */ new Set())).add(text);
                    }
                    return result;
                }
                function symbolToName(symbol, context, meaning, expectsIdentifier) {
                    const chain = lookupSymbolChain(symbol, context, meaning);
                    if (expectsIdentifier && chain.length !== 1 && !context.encounteredError && !(context.flags & 65536 /* AllowQualifiedNameInPlaceOfIdentifier */)) {
                        context.encounteredError = true;
                    }
                    return createEntityNameFromSymbolChain(chain, chain.length - 1);
                    function createEntityNameFromSymbolChain(chain2, index) {
                        const typeParameterNodes = lookupTypeParameterNodes(chain2, index, context);
                        const symbol2 = chain2[index];
                        if (index === 0) {
                            context.flags |= 16777216 /* InInitialEntityName */;
                        }
                        const symbolName2 = getNameOfSymbolAsWritten(symbol2, context);
                        if (index === 0) {
                            context.flags ^= 16777216 /* InInitialEntityName */;
                        }
                        const identifier = setEmitFlags(factory.createIdentifier(symbolName2), 16777216 /* NoAsciiEscaping */);
                        if (typeParameterNodes)
                            setIdentifierTypeArguments(identifier, factory.createNodeArray(typeParameterNodes));
                        identifier.symbol = symbol2;
                        return index > 0 ? factory.createQualifiedName(createEntityNameFromSymbolChain(chain2, index - 1), identifier) : identifier;
                    }
                }
                function symbolToExpression(symbol, context, meaning) {
                    const chain = lookupSymbolChain(symbol, context, meaning);
                    return createExpressionFromSymbolChain(chain, chain.length - 1);
                    function createExpressionFromSymbolChain(chain2, index) {
                        const typeParameterNodes = lookupTypeParameterNodes(chain2, index, context);
                        const symbol2 = chain2[index];
                        if (index === 0) {
                            context.flags |= 16777216 /* InInitialEntityName */;
                        }
                        let symbolName2 = getNameOfSymbolAsWritten(symbol2, context);
                        if (index === 0) {
                            context.flags ^= 16777216 /* InInitialEntityName */;
                        }
                        let firstChar = symbolName2.charCodeAt(0);
                        if (isSingleOrDoubleQuote(firstChar) && some(symbol2.declarations, hasNonGlobalAugmentationExternalModuleSymbol)) {
                            return factory.createStringLiteral(getSpecifierForModuleSymbol(symbol2, context));
                        }
                        if (index === 0 || canUsePropertyAccess(symbolName2, languageVersion)) {
                            const identifier = setEmitFlags(factory.createIdentifier(symbolName2), 16777216 /* NoAsciiEscaping */);
                            if (typeParameterNodes)
                                setIdentifierTypeArguments(identifier, factory.createNodeArray(typeParameterNodes));
                            identifier.symbol = symbol2;
                            return index > 0 ? factory.createPropertyAccessExpression(createExpressionFromSymbolChain(chain2, index - 1), identifier) : identifier;
                        }
                        else {
                            if (firstChar === 91 /* openBracket */) {
                                symbolName2 = symbolName2.substring(1, symbolName2.length - 1);
                                firstChar = symbolName2.charCodeAt(0);
                            }
                            let expression;
                            if (isSingleOrDoubleQuote(firstChar) && !(symbol2.flags & 8 /* EnumMember */)) {
                                expression = factory.createStringLiteral(stripQuotes(symbolName2).replace(/\\./g, (s) => s.substring(1)), firstChar === 39 /* singleQuote */);
                            }
                            else if ("" + +symbolName2 === symbolName2) {
                                expression = factory.createNumericLiteral(+symbolName2);
                            }
                            if (!expression) {
                                const identifier = setEmitFlags(factory.createIdentifier(symbolName2), 16777216 /* NoAsciiEscaping */);
                                if (typeParameterNodes)
                                    setIdentifierTypeArguments(identifier, factory.createNodeArray(typeParameterNodes));
                                identifier.symbol = symbol2;
                                expression = identifier;
                            }
                            return factory.createElementAccessExpression(createExpressionFromSymbolChain(chain2, index - 1), expression);
                        }
                    }
                }
                function isStringNamed(d) {
                    const name = getNameOfDeclaration(d);
                    if (!name) {
                        return false;
                    }
                    if (isComputedPropertyName(name)) {
                        const type = checkExpression(name.expression);
                        return !!(type.flags & 402653316 /* StringLike */);
                    }
                    if (isElementAccessExpression(name)) {
                        const type = checkExpression(name.argumentExpression);
                        return !!(type.flags & 402653316 /* StringLike */);
                    }
                    return isStringLiteral(name);
                }
                function isSingleQuotedStringNamed(d) {
                    const name = getNameOfDeclaration(d);
                    return !!(name && isStringLiteral(name) && (name.singleQuote || !nodeIsSynthesized(name) && startsWith(getTextOfNode(name, 
                    /*includeTrivia*/
                    false), "'")));
                }
                function getPropertyNameNodeForSymbol(symbol, context) {
                    const stringNamed = !!length(symbol.declarations) && every(symbol.declarations, isStringNamed);
                    const singleQuote = !!length(symbol.declarations) && every(symbol.declarations, isSingleQuotedStringNamed);
                    const isMethod = !!(symbol.flags & 8192 /* Method */);
                    const fromNameType = getPropertyNameNodeForSymbolFromNameType(symbol, context, singleQuote, stringNamed, isMethod);
                    if (fromNameType) {
                        return fromNameType;
                    }
                    const rawName = unescapeLeadingUnderscores(symbol.escapedName);
                    return createPropertyNameNodeForIdentifierOrLiteral(rawName, getEmitScriptTarget(compilerOptions), singleQuote, stringNamed, isMethod);
                }
                function getPropertyNameNodeForSymbolFromNameType(symbol, context, singleQuote, stringNamed, isMethod) {
                    const nameType = getSymbolLinks(symbol).nameType;
                    if (nameType) {
                        if (nameType.flags & 384 /* StringOrNumberLiteral */) {
                            const name = "" + nameType.value;
                            if (!isIdentifierText(name, getEmitScriptTarget(compilerOptions)) && (stringNamed || !isNumericLiteralName(name))) {
                                return factory.createStringLiteral(name, !!singleQuote);
                            }
                            if (isNumericLiteralName(name) && startsWith(name, "-")) {
                                return factory.createComputedPropertyName(factory.createPrefixUnaryExpression(41 /* MinusToken */, factory.createNumericLiteral(-name)));
                            }
                            return createPropertyNameNodeForIdentifierOrLiteral(name, getEmitScriptTarget(compilerOptions), singleQuote, stringNamed, isMethod);
                        }
                        if (nameType.flags & 8192 /* UniqueESSymbol */) {
                            return factory.createComputedPropertyName(symbolToExpression(nameType.symbol, context, 111551 /* Value */));
                        }
                    }
                }
                function cloneNodeBuilderContext(context) {
                    const initial = { ...context };
                    if (initial.typeParameterNames) {
                        initial.typeParameterNames = new Map(initial.typeParameterNames);
                    }
                    if (initial.typeParameterNamesByText) {
                        initial.typeParameterNamesByText = new Set(initial.typeParameterNamesByText);
                    }
                    if (initial.typeParameterSymbolList) {
                        initial.typeParameterSymbolList = new Set(initial.typeParameterSymbolList);
                    }
                    initial.tracker = new SymbolTrackerImpl(initial, initial.tracker.inner, initial.tracker.moduleResolverHost);
                    return initial;
                }
                function getDeclarationWithTypeAnnotation(symbol, enclosingDeclaration) {
                    return symbol.declarations && find(symbol.declarations, (s) => !!getEffectiveTypeAnnotationNode(s) && (!enclosingDeclaration || !!findAncestor(s, (n) => n === enclosingDeclaration)));
                }
                function existingTypeNodeIsNotReferenceOrIsReferenceWithCompatibleTypeArgumentCount(existing, type) {
                    return !(getObjectFlags(type) & 4 /* Reference */) || !isTypeReferenceNode(existing) || length(existing.typeArguments) >= getMinTypeArgumentCount(type.target.typeParameters);
                }
                function getEnclosingDeclarationIgnoringFakeScope(enclosingDeclaration) {
                    while (getNodeLinks(enclosingDeclaration).fakeScopeForSignatureDeclaration) {
                        enclosingDeclaration = enclosingDeclaration.parent;
                    }
                    return enclosingDeclaration;
                }
                function serializeTypeForDeclaration(context, type, symbol, enclosingDeclaration, includePrivateSymbol, bundled) {
                    if (!isErrorType(type) && enclosingDeclaration) {
                        const declWithExistingAnnotation = getDeclarationWithTypeAnnotation(symbol, getEnclosingDeclarationIgnoringFakeScope(enclosingDeclaration));
                        if (declWithExistingAnnotation && !isFunctionLikeDeclaration(declWithExistingAnnotation) && !isGetAccessorDeclaration(declWithExistingAnnotation)) {
                            const existing = getEffectiveTypeAnnotationNode(declWithExistingAnnotation);
                            if (typeNodeIsEquivalentToType(existing, declWithExistingAnnotation, type) && existingTypeNodeIsNotReferenceOrIsReferenceWithCompatibleTypeArgumentCount(existing, type)) {
                                const result2 = serializeExistingTypeNode(context, existing, includePrivateSymbol, bundled);
                                if (result2) {
                                    return result2;
                                }
                            }
                        }
                    }
                    const oldFlags = context.flags;
                    if (type.flags & 8192 /* UniqueESSymbol */ && type.symbol === symbol && (!context.enclosingDeclaration || some(symbol.declarations, (d) => getSourceFileOfNode(d) === getSourceFileOfNode(context.enclosingDeclaration)))) {
                        context.flags |= 1048576 /* AllowUniqueESSymbolType */;
                    }
                    const result = typeToTypeNodeHelper(type, context);
                    context.flags = oldFlags;
                    return result;
                }
                function typeNodeIsEquivalentToType(typeNode, annotatedDeclaration, type) {
                    const typeFromTypeNode = getTypeFromTypeNode(typeNode);
                    if (typeFromTypeNode === type) {
                        return true;
                    }
                    if (isParameter(annotatedDeclaration) && annotatedDeclaration.questionToken) {
                        return getTypeWithFacts(type, 524288 /* NEUndefined */) === typeFromTypeNode;
                    }
                    return false;
                }
                function serializeReturnTypeForSignature(context, type, signature, includePrivateSymbol, bundled) {
                    if (!isErrorType(type) && context.enclosingDeclaration) {
                        const annotation = signature.declaration && getEffectiveReturnTypeNode(signature.declaration);
                        const enclosingDeclarationIgnoringFakeScope = getEnclosingDeclarationIgnoringFakeScope(context.enclosingDeclaration);
                        if (!!findAncestor(annotation, (n) => n === enclosingDeclarationIgnoringFakeScope) && annotation) {
                            const annotated = getTypeFromTypeNode(annotation);
                            const thisInstantiated = annotated.flags & 262144 /* TypeParameter */ && annotated.isThisType ? instantiateType(annotated, signature.mapper) : annotated;
                            if (thisInstantiated === type && existingTypeNodeIsNotReferenceOrIsReferenceWithCompatibleTypeArgumentCount(annotation, type)) {
                                const result = serializeExistingTypeNode(context, annotation, includePrivateSymbol, bundled);
                                if (result) {
                                    return result;
                                }
                            }
                        }
                    }
                    return typeToTypeNodeHelper(type, context);
                }
                function trackExistingEntityName(node, context, includePrivateSymbol) {
                    let introducesError = false;
                    const leftmost = getFirstIdentifier(node);
                    if (isInJSFile(node) && (isExportsIdentifier(leftmost) || isModuleExportsAccessExpression(leftmost.parent) || isQualifiedName(leftmost.parent) && isModuleIdentifier(leftmost.parent.left) && isExportsIdentifier(leftmost.parent.right))) {
                        introducesError = true;
                        return { introducesError, node };
                    }
                    const sym = resolveEntityName(leftmost, -1 /* All */, 
                    /*ignoreErrors*/
                    true, 
                    /*dontResolveAlias*/
                    true);
                    if (sym) {
                        if (isSymbolAccessible(sym, context.enclosingDeclaration, -1 /* All */, 
                        /*shouldComputeAliasesToMakeVisible*/
                        false).accessibility !== 0 /* Accessible */) {
                            introducesError = true;
                        }
                        else {
                            context.tracker.trackSymbol(sym, context.enclosingDeclaration, -1 /* All */);
                            includePrivateSymbol == null ? void 0 : includePrivateSymbol(sym);
                        }
                        if (isIdentifier(node)) {
                            const type = getDeclaredTypeOfSymbol(sym);
                            const name = sym.flags & 262144 /* TypeParameter */ ? typeParameterToName(type, context) : factory.cloneNode(node);
                            name.symbol = sym;
                            return { introducesError, node: setEmitFlags(setOriginalNode(name, node), 16777216 /* NoAsciiEscaping */) };
                        }
                    }
                    return { introducesError, node };
                }
                function serializeExistingTypeNode(context, existing, includePrivateSymbol, bundled) {
                    if (cancellationToken && cancellationToken.throwIfCancellationRequested) {
                        cancellationToken.throwIfCancellationRequested();
                    }
                    let hadError = false;
                    const file = getSourceFileOfNode(existing);
                    const transformed = visitNode(existing, visitExistingNodeTreeSymbols, isTypeNode);
                    if (hadError) {
                        return void 0;
                    }
                    return transformed === existing ? setTextRange(factory.cloneNode(existing), existing) : transformed;
                    function visitExistingNodeTreeSymbols(node) {
                        if (isJSDocAllType(node) || node.kind === 326 /* JSDocNamepathType */) {
                            return factory.createKeywordTypeNode(133 /* AnyKeyword */);
                        }
                        if (isJSDocUnknownType(node)) {
                            return factory.createKeywordTypeNode(159 /* UnknownKeyword */);
                        }
                        if (isJSDocNullableType(node)) {
                            return factory.createUnionTypeNode([visitNode(node.type, visitExistingNodeTreeSymbols, isTypeNode), factory.createLiteralTypeNode(factory.createNull())]);
                        }
                        if (isJSDocOptionalType(node)) {
                            return factory.createUnionTypeNode([visitNode(node.type, visitExistingNodeTreeSymbols, isTypeNode), factory.createKeywordTypeNode(157 /* UndefinedKeyword */)]);
                        }
                        if (isJSDocNonNullableType(node)) {
                            return visitNode(node.type, visitExistingNodeTreeSymbols);
                        }
                        if (isJSDocVariadicType(node)) {
                            return factory.createArrayTypeNode(visitNode(node.type, visitExistingNodeTreeSymbols, isTypeNode));
                        }
                        if (isJSDocTypeLiteral(node)) {
                            return factory.createTypeLiteralNode(map(node.jsDocPropertyTags, (t) => {
                                const name = isIdentifier(t.name) ? t.name : t.name.right;
                                const typeViaParent = getTypeOfPropertyOfType(getTypeFromTypeNode(node), name.escapedText);
                                const overrideTypeNode = typeViaParent && t.typeExpression && getTypeFromTypeNode(t.typeExpression.type) !== typeViaParent ? typeToTypeNodeHelper(typeViaParent, context) : void 0;
                                return factory.createPropertySignature(
                                /*modifiers*/
                                void 0, name, t.isBracketed || t.typeExpression && isJSDocOptionalType(t.typeExpression.type) ? factory.createToken(58 /* QuestionToken */) : void 0, overrideTypeNode || t.typeExpression && visitNode(t.typeExpression.type, visitExistingNodeTreeSymbols, isTypeNode) || factory.createKeywordTypeNode(133 /* AnyKeyword */));
                            }));
                        }
                        if (isTypeReferenceNode(node) && isIdentifier(node.typeName) && node.typeName.escapedText === "") {
                            return setOriginalNode(factory.createKeywordTypeNode(133 /* AnyKeyword */), node);
                        }
                        if ((isExpressionWithTypeArguments(node) || isTypeReferenceNode(node)) && isJSDocIndexSignature(node)) {
                            return factory.createTypeLiteralNode([factory.createIndexSignature(
                                /*modifiers*/
                                void 0, [factory.createParameterDeclaration(
                                    /*modifiers*/
                                    void 0, 
                                    /*dotDotDotToken*/
                                    void 0, "x", 
                                    /*questionToken*/
                                    void 0, visitNode(node.typeArguments[0], visitExistingNodeTreeSymbols, isTypeNode))], visitNode(node.typeArguments[1], visitExistingNodeTreeSymbols, isTypeNode))]);
                        }
                        if (isJSDocFunctionType(node)) {
                            if (isJSDocConstructSignature(node)) {
                                let newTypeNode;
                                return factory.createConstructorTypeNode(
                                /*modifiers*/
                                void 0, visitNodes2(node.typeParameters, visitExistingNodeTreeSymbols, isTypeParameterDeclaration), mapDefined(node.parameters, (p, i) => p.name && isIdentifier(p.name) && p.name.escapedText === "new" ? (newTypeNode = p.type, void 0) : factory.createParameterDeclaration(
                                /*modifiers*/
                                void 0, getEffectiveDotDotDotForParameter(p), getNameForJSDocFunctionParameter(p, i), p.questionToken, visitNode(p.type, visitExistingNodeTreeSymbols, isTypeNode), 
                                /*initializer*/
                                void 0)), visitNode(newTypeNode || node.type, visitExistingNodeTreeSymbols, isTypeNode) || factory.createKeywordTypeNode(133 /* AnyKeyword */));
                            }
                            else {
                                return factory.createFunctionTypeNode(visitNodes2(node.typeParameters, visitExistingNodeTreeSymbols, isTypeParameterDeclaration), map(node.parameters, (p, i) => factory.createParameterDeclaration(
                                /*modifiers*/
                                void 0, getEffectiveDotDotDotForParameter(p), getNameForJSDocFunctionParameter(p, i), p.questionToken, visitNode(p.type, visitExistingNodeTreeSymbols, isTypeNode), 
                                /*initializer*/
                                void 0)), visitNode(node.type, visitExistingNodeTreeSymbols, isTypeNode) || factory.createKeywordTypeNode(133 /* AnyKeyword */));
                            }
                        }
                        if (isTypeReferenceNode(node) && isInJSDoc(node) && (!existingTypeNodeIsNotReferenceOrIsReferenceWithCompatibleTypeArgumentCount(node, getTypeFromTypeNode(node)) || getIntendedTypeFromJSDocTypeReference(node) || unknownSymbol === resolveTypeReferenceName(node, 788968 /* Type */, 
                        /*ignoreErrors*/
                        true))) {
                            return setOriginalNode(typeToTypeNodeHelper(getTypeFromTypeNode(node), context), node);
                        }
                        if (isLiteralImportTypeNode(node)) {
                            const nodeSymbol = getNodeLinks(node).resolvedSymbol;
                            if (isInJSDoc(node) && nodeSymbol && // The import type resolved using jsdoc fallback logic
                                (!node.isTypeOf && !(nodeSymbol.flags & 788968 /* Type */) || // The import type had type arguments autofilled by js fallback logic
                                    !(length(node.typeArguments) >= getMinTypeArgumentCount(getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(nodeSymbol))))) {
                                return setOriginalNode(typeToTypeNodeHelper(getTypeFromTypeNode(node), context), node);
                            }
                            return factory.updateImportTypeNode(node, factory.updateLiteralTypeNode(node.argument, rewriteModuleSpecifier(node, node.argument.literal)), node.attributes, node.qualifier, visitNodes2(node.typeArguments, visitExistingNodeTreeSymbols, isTypeNode), node.isTypeOf);
                        }
                        if (isEntityName(node) || isEntityNameExpression(node)) {
                            const { introducesError, node: result } = trackExistingEntityName(node, context, includePrivateSymbol);
                            hadError = hadError || introducesError;
                            if (result !== node) {
                                return result;
                            }
                        }
                        if (file && isTupleTypeNode(node) && getLineAndCharacterOfPosition(file, node.pos).line === getLineAndCharacterOfPosition(file, node.end).line) {
                            setEmitFlags(node, 1 /* SingleLine */);
                        }
                        return visitEachChild(node, visitExistingNodeTreeSymbols, 
                        /*context*/
                        void 0);
                        function getEffectiveDotDotDotForParameter(p) {
                            return p.dotDotDotToken || (p.type && isJSDocVariadicType(p.type) ? factory.createToken(26 /* DotDotDotToken */) : void 0);
                        }
                        function getNameForJSDocFunctionParameter(p, index) {
                            return p.name && isIdentifier(p.name) && p.name.escapedText === "this" ? "this" : getEffectiveDotDotDotForParameter(p) ? `args` : `arg${index}`;
                        }
                        function rewriteModuleSpecifier(parent2, lit) {
                            if (bundled) {
                                if (context.tracker && context.tracker.moduleResolverHost) {
                                    const targetFile = getExternalModuleFileFromDeclaration(parent2);
                                    if (targetFile) {
                                        const getCanonicalFileName = createGetCanonicalFileName(!!host.useCaseSensitiveFileNames);
                                        const resolverHost = {
                                            getCanonicalFileName,
                                            getCurrentDirectory: () => context.tracker.moduleResolverHost.getCurrentDirectory(),
                                            getCommonSourceDirectory: () => context.tracker.moduleResolverHost.getCommonSourceDirectory()
                                        };
                                        const newName = getResolvedExternalModuleName(resolverHost, targetFile);
                                        return factory.createStringLiteral(newName);
                                    }
                                }
                            }
                            else {
                                if (context.tracker && context.tracker.trackExternalModuleSymbolOfImportTypeNode) {
                                    const moduleSym = resolveExternalModuleNameWorker(lit, lit, 
                                    /*moduleNotFoundError*/
                                    void 0);
                                    if (moduleSym) {
                                        context.tracker.trackExternalModuleSymbolOfImportTypeNode(moduleSym);
                                    }
                                }
                            }
                            return lit;
                        }
                    }
                }
                function symbolTableToDeclarationStatements(symbolTable, context, bundled) {
                    var _a;
                    const serializePropertySymbolForClass = makeSerializePropertySymbol(factory.createPropertyDeclaration, 174 /* MethodDeclaration */, 
                    /*useAccessors*/
                    true);
                    const serializePropertySymbolForInterfaceWorker = makeSerializePropertySymbol((mods, name, question, type) => factory.createPropertySignature(mods, name, question, type), 173 /* MethodSignature */, 
                    /*useAccessors*/
                    false);
                    const enclosingDeclaration = context.enclosingDeclaration;
                    let results = [];
                    const visitedSymbols = /* @__PURE__ */ new Set();
                    const deferredPrivatesStack = [];
                    const oldcontext = context;
                    context = {
                        ...oldcontext,
                        usedSymbolNames: new Set(oldcontext.usedSymbolNames),
                        remappedSymbolNames: /* @__PURE__ */ new Map(),
                        remappedSymbolReferences: new Map((_a = oldcontext.remappedSymbolReferences) == null ? void 0 : _a.entries()),
                        tracker: void 0
                    };
                    const tracker = {
                        ...oldcontext.tracker.inner,
                        trackSymbol: (sym, decl, meaning) => {
                            var _a2, _b;
                            if ((_a2 = context.remappedSymbolNames) == null ? void 0 : _a2.has(getSymbolId(sym)))
                                return false;
                            const accessibleResult = isSymbolAccessible(sym, decl, meaning, 
                            /*shouldComputeAliasesToMakeVisible*/
                            false);
                            if (accessibleResult.accessibility === 0 /* Accessible */) {
                                const chain = lookupSymbolChainWorker(sym, context, meaning);
                                if (!(sym.flags & 4 /* Property */)) {
                                    const root = chain[0];
                                    const contextFile = getSourceFileOfNode(oldcontext.enclosingDeclaration);
                                    if (some(root.declarations, (d) => getSourceFileOfNode(d) === contextFile)) {
                                        includePrivateSymbol(root);
                                    }
                                }
                            }
                            else if ((_b = oldcontext.tracker.inner) == null ? void 0 : _b.trackSymbol) {
                                return oldcontext.tracker.inner.trackSymbol(sym, decl, meaning);
                            }
                            return false;
                        }
                    };
                    context.tracker = new SymbolTrackerImpl(context, tracker, oldcontext.tracker.moduleResolverHost);
                    forEachEntry(symbolTable, (symbol, name) => {
                        const baseName = unescapeLeadingUnderscores(name);
                        void getInternalSymbolName(symbol, baseName);
                    });
                    let addingDeclare = !bundled;
                    const exportEquals = symbolTable.get("export=" /* ExportEquals */);
                    if (exportEquals && symbolTable.size > 1 && exportEquals.flags & (2097152 /* Alias */ | 1536 /* Module */)) {
                        symbolTable = createSymbolTable();
                        symbolTable.set("export=" /* ExportEquals */, exportEquals);
                    }
                    visitSymbolTable(symbolTable);
                    return mergeRedundantStatements(results);
                    function isIdentifierAndNotUndefined(node) {
                        return !!node && node.kind === 80 /* Identifier */;
                    }
                    function getNamesOfDeclaration(statement) {
                        if (isVariableStatement(statement)) {
                            return filter(map(statement.declarationList.declarations, getNameOfDeclaration), isIdentifierAndNotUndefined);
                        }
                        return filter([getNameOfDeclaration(statement)], isIdentifierAndNotUndefined);
                    }
                    function flattenExportAssignedNamespace(statements) {
                        const exportAssignment = find(statements, isExportAssignment);
                        const nsIndex = findIndex(statements, isModuleDeclaration);
                        let ns = nsIndex !== -1 ? statements[nsIndex] : void 0;
                        if (ns && exportAssignment && exportAssignment.isExportEquals && isIdentifier(exportAssignment.expression) && isIdentifier(ns.name) && idText(ns.name) === idText(exportAssignment.expression) && ns.body && isModuleBlock(ns.body)) {
                            const excessExports = filter(statements, (s) => !!(getEffectiveModifierFlags(s) & 32 /* Export */));
                            const name = ns.name;
                            let body = ns.body;
                            if (length(excessExports)) {
                                ns = factory.updateModuleDeclaration(ns, ns.modifiers, ns.name, body = factory.updateModuleBlock(body, factory.createNodeArray([
                                    ...ns.body.statements,
                                    factory.createExportDeclaration(
                                    /*modifiers*/
                                    void 0, 
                                    /*isTypeOnly*/
                                    false, factory.createNamedExports(map(flatMap(excessExports, (e) => getNamesOfDeclaration(e)), (id) => factory.createExportSpecifier(
                                    /*isTypeOnly*/
                                    false, 
                                    /*propertyName*/
                                    void 0, id))), 
                                    /*moduleSpecifier*/
                                    void 0)
                                ])));
                                statements = [...statements.slice(0, nsIndex), ns, ...statements.slice(nsIndex + 1)];
                            }
                            if (!find(statements, (s) => s !== ns && nodeHasName(s, name))) {
                                results = [];
                                const mixinExportFlag = !some(body.statements, (s) => hasSyntacticModifier(s, 32 /* Export */) || isExportAssignment(s) || isExportDeclaration(s));
                                forEach(body.statements, (s) => {
                                    addResult(s, mixinExportFlag ? 32 /* Export */ : 0 /* None */);
                                });
                                statements = [...filter(statements, (s) => s !== ns && s !== exportAssignment), ...results];
                            }
                        }
                        return statements;
                    }
                    function mergeExportDeclarations(statements) {
                        const exports = filter(statements, (d) => isExportDeclaration(d) && !d.moduleSpecifier && !!d.exportClause && isNamedExports(d.exportClause));
                        if (length(exports) > 1) {
                            const nonExports = filter(statements, (d) => !isExportDeclaration(d) || !!d.moduleSpecifier || !d.exportClause);
                            statements = [
                                ...nonExports,
                                factory.createExportDeclaration(
                                /*modifiers*/
                                void 0, 
                                /*isTypeOnly*/
                                false, factory.createNamedExports(flatMap(exports, (e) => cast(e.exportClause, isNamedExports).elements)), 
                                /*moduleSpecifier*/
                                void 0)
                            ];
                        }
                        const reexports = filter(statements, (d) => isExportDeclaration(d) && !!d.moduleSpecifier && !!d.exportClause && isNamedExports(d.exportClause));
                        if (length(reexports) > 1) {
                            const groups = group(reexports, (decl) => isStringLiteral(decl.moduleSpecifier) ? ">" + decl.moduleSpecifier.text : ">");
                            if (groups.length !== reexports.length) {
                                for (const group2 of groups) {
                                    if (group2.length > 1) {
                                        statements = [
                                            ...filter(statements, (s) => !group2.includes(s)),
                                            factory.createExportDeclaration(
                                            /*modifiers*/
                                            void 0, 
                                            /*isTypeOnly*/
                                            false, factory.createNamedExports(flatMap(group2, (e) => cast(e.exportClause, isNamedExports).elements)), group2[0].moduleSpecifier)
                                        ];
                                    }
                                }
                            }
                        }
                        return statements;
                    }
                    function inlineExportModifiers(statements) {
                        const index = findIndex(statements, (d) => isExportDeclaration(d) && !d.moduleSpecifier && !d.attributes && !!d.exportClause && isNamedExports(d.exportClause));
                        if (index >= 0) {
                            const exportDecl = statements[index];
                            const replacements = mapDefined(exportDecl.exportClause.elements, (e) => {
                                if (!e.propertyName) {
                                    const indices = indicesOf(statements);
                                    const associatedIndices = filter(indices, (i) => nodeHasName(statements[i], e.name));
                                    if (length(associatedIndices) && every(associatedIndices, (i) => canHaveExportModifier(statements[i]))) {
                                        for (const index2 of associatedIndices) {
                                            statements[index2] = addExportModifier(statements[index2]);
                                        }
                                        return void 0;
                                    }
                                }
                                return e;
                            });
                            if (!length(replacements)) {
                                orderedRemoveItemAt(statements, index);
                            }
                            else {
                                statements[index] = factory.updateExportDeclaration(exportDecl, exportDecl.modifiers, exportDecl.isTypeOnly, factory.updateNamedExports(exportDecl.exportClause, replacements), exportDecl.moduleSpecifier, exportDecl.attributes);
                            }
                        }
                        return statements;
                    }
                    function mergeRedundantStatements(statements) {
                        statements = flattenExportAssignedNamespace(statements);
                        statements = mergeExportDeclarations(statements);
                        statements = inlineExportModifiers(statements);
                        if (enclosingDeclaration && (isSourceFile(enclosingDeclaration) && isExternalOrCommonJsModule(enclosingDeclaration) || isModuleDeclaration(enclosingDeclaration)) && (!some(statements, isExternalModuleIndicator) || !hasScopeMarker(statements) && some(statements, needsScopeMarker))) {
                            statements.push(createEmptyExports(factory));
                        }
                        return statements;
                    }
                    function addExportModifier(node) {
                        const flags = (getEffectiveModifierFlags(node) | 32 /* Export */) & ~128 /* Ambient */;
                        return factory.replaceModifiers(node, flags);
                    }
                    function removeExportModifier(node) {
                        const flags = getEffectiveModifierFlags(node) & ~32 /* Export */;
                        return factory.replaceModifiers(node, flags);
                    }
                    function visitSymbolTable(symbolTable2, suppressNewPrivateContext, propertyAsAlias) {
                        if (!suppressNewPrivateContext) {
                            deferredPrivatesStack.push(/* @__PURE__ */ new Map());
                        }
                        symbolTable2.forEach((symbol) => {
                            serializeSymbol(symbol, 
                            /*isPrivate*/
                            false, !!propertyAsAlias);
                        });
                        if (!suppressNewPrivateContext) {
                            deferredPrivatesStack[deferredPrivatesStack.length - 1].forEach((symbol) => {
                                serializeSymbol(symbol, 
                                /*isPrivate*/
                                true, !!propertyAsAlias);
                            });
                            deferredPrivatesStack.pop();
                        }
                    }
                    function serializeSymbol(symbol, isPrivate, propertyAsAlias) {
                        const visitedSym = getMergedSymbol(symbol);
                        if (visitedSymbols.has(getSymbolId(visitedSym))) {
                            return;
                        }
                        visitedSymbols.add(getSymbolId(visitedSym));
                        const skipMembershipCheck = !isPrivate;
                        if (skipMembershipCheck || !!length(symbol.declarations) && some(symbol.declarations, (d) => !!findAncestor(d, (n) => n === enclosingDeclaration))) {
                            const oldContext = context;
                            context = cloneNodeBuilderContext(context);
                            serializeSymbolWorker(symbol, isPrivate, propertyAsAlias);
                            if (context.reportedDiagnostic) {
                                oldcontext.reportedDiagnostic = context.reportedDiagnostic;
                            }
                            if (context.trackedSymbols) {
                                if (!oldContext.trackedSymbols)
                                    oldContext.trackedSymbols = context.trackedSymbols;
                                else
                                    Debug.assert(context.trackedSymbols === oldContext.trackedSymbols);
                            }
                            context = oldContext;
                        }
                    }
                    function serializeSymbolWorker(symbol, isPrivate, propertyAsAlias, escapedSymbolName = symbol.escapedName) {
                        var _a2, _b, _c, _d, _e, _f;
                        const symbolName2 = unescapeLeadingUnderscores(escapedSymbolName);
                        const isDefault = escapedSymbolName === "default" /* Default */;
                        if (isPrivate && !(context.flags & 131072 /* AllowAnonymousIdentifier */) && isStringANonContextualKeyword(symbolName2) && !isDefault) {
                            context.encounteredError = true;
                            return;
                        }
                        let needsPostExportDefault = isDefault && !!(symbol.flags & -113 /* ExportDoesNotSupportDefaultModifier */ || symbol.flags & 16 /* Function */ && length(getPropertiesOfType(getTypeOfSymbol(symbol)))) && !(symbol.flags & 2097152 /* Alias */);
                        let needsExportDeclaration = !needsPostExportDefault && !isPrivate && isStringANonContextualKeyword(symbolName2) && !isDefault;
                        if (needsPostExportDefault || needsExportDeclaration) {
                            isPrivate = true;
                        }
                        const modifierFlags = (!isPrivate ? 32 /* Export */ : 0) | (isDefault && !needsPostExportDefault ? 2048 /* Default */ : 0);
                        const isConstMergedWithNS = symbol.flags & 1536 /* Module */ && symbol.flags & (2 /* BlockScopedVariable */ | 1 /* FunctionScopedVariable */ | 4 /* Property */) && escapedSymbolName !== "export=" /* ExportEquals */;
                        const isConstMergedWithNSPrintableAsSignatureMerge = isConstMergedWithNS && isTypeRepresentableAsFunctionNamespaceMerge(getTypeOfSymbol(symbol), symbol);
                        if (symbol.flags & (16 /* Function */ | 8192 /* Method */) || isConstMergedWithNSPrintableAsSignatureMerge) {
                            serializeAsFunctionNamespaceMerge(getTypeOfSymbol(symbol), symbol, getInternalSymbolName(symbol, symbolName2), modifierFlags);
                        }
                        if (symbol.flags & 524288 /* TypeAlias */) {
                            serializeTypeAlias(symbol, symbolName2, modifierFlags);
                        }
                        if (symbol.flags & (2 /* BlockScopedVariable */ | 1 /* FunctionScopedVariable */ | 4 /* Property */ | 98304 /* Accessor */) && escapedSymbolName !== "export=" /* ExportEquals */ && !(symbol.flags & 4194304 /* Prototype */) && !(symbol.flags & 32 /* Class */) && !(symbol.flags & 8192 /* Method */) && !isConstMergedWithNSPrintableAsSignatureMerge) {
                            if (propertyAsAlias) {
                                const createdExport = serializeMaybeAliasAssignment(symbol);
                                if (createdExport) {
                                    needsExportDeclaration = false;
                                    needsPostExportDefault = false;
                                }
                            }
                            else {
                                const type = getTypeOfSymbol(symbol);
                                const localName = getInternalSymbolName(symbol, symbolName2);
                                if (type.symbol && type.symbol !== symbol && type.symbol.flags & 16 /* Function */ && some(type.symbol.declarations, isFunctionExpressionOrArrowFunction) && (((_a2 = type.symbol.members) == null ? void 0 : _a2.size) || ((_b = type.symbol.exports) == null ? void 0 : _b.size))) {
                                    if (!context.remappedSymbolReferences) {
                                        context.remappedSymbolReferences = /* @__PURE__ */ new Map();
                                    }
                                    context.remappedSymbolReferences.set(getSymbolId(type.symbol), symbol);
                                    serializeSymbolWorker(type.symbol, isPrivate, propertyAsAlias, escapedSymbolName);
                                    context.remappedSymbolReferences.delete(getSymbolId(type.symbol));
                                }
                                else if (!(symbol.flags & 16 /* Function */) && isTypeRepresentableAsFunctionNamespaceMerge(type, symbol)) {
                                    serializeAsFunctionNamespaceMerge(type, symbol, localName, modifierFlags);
                                }
                                else {
                                    const flags = !(symbol.flags & 2 /* BlockScopedVariable */) ? ((_c = symbol.parent) == null ? void 0 : _c.valueDeclaration) && isSourceFile((_d = symbol.parent) == null ? void 0 : _d.valueDeclaration) ? 2 /* Const */ : void 0 : isConstantVariable(symbol) ? 2 /* Const */ : 1 /* Let */;
                                    const name = needsPostExportDefault || !(symbol.flags & 4 /* Property */) ? localName : getUnusedName(localName, symbol);
                                    let textRange = symbol.declarations && find(symbol.declarations, (d) => isVariableDeclaration(d));
                                    if (textRange && isVariableDeclarationList(textRange.parent) && textRange.parent.declarations.length === 1) {
                                        textRange = textRange.parent.parent;
                                    }
                                    const propertyAccessRequire = (_e = symbol.declarations) == null ? void 0 : _e.find(isPropertyAccessExpression);
                                    if (propertyAccessRequire && isBinaryExpression(propertyAccessRequire.parent) && isIdentifier(propertyAccessRequire.parent.right) && ((_f = type.symbol) == null ? void 0 : _f.valueDeclaration) && isSourceFile(type.symbol.valueDeclaration)) {
                                        const alias = localName === propertyAccessRequire.parent.right.escapedText ? void 0 : propertyAccessRequire.parent.right;
                                        addResult(factory.createExportDeclaration(
                                        /*modifiers*/
                                        void 0, 
                                        /*isTypeOnly*/
                                        false, factory.createNamedExports([factory.createExportSpecifier(
                                            /*isTypeOnly*/
                                            false, alias, localName)])), 0 /* None */);
                                        context.tracker.trackSymbol(type.symbol, context.enclosingDeclaration, 111551 /* Value */);
                                    }
                                    else {
                                        const statement = setTextRange(factory.createVariableStatement(
                                        /*modifiers*/
                                        void 0, factory.createVariableDeclarationList([
                                            factory.createVariableDeclaration(name, 
                                            /*exclamationToken*/
                                            void 0, serializeTypeForDeclaration(context, type, symbol, enclosingDeclaration, includePrivateSymbol, bundled))
                                        ], flags)), textRange);
                                        addResult(statement, name !== localName ? modifierFlags & ~32 /* Export */ : modifierFlags);
                                        if (name !== localName && !isPrivate) {
                                            addResult(factory.createExportDeclaration(
                                            /*modifiers*/
                                            void 0, 
                                            /*isTypeOnly*/
                                            false, factory.createNamedExports([factory.createExportSpecifier(
                                                /*isTypeOnly*/
                                                false, name, localName)])), 0 /* None */);
                                            needsExportDeclaration = false;
                                            needsPostExportDefault = false;
                                        }
                                    }
                                }
                            }
                        }
                        if (symbol.flags & 384 /* Enum */) {
                            serializeEnum(symbol, symbolName2, modifierFlags);
                        }
                        if (symbol.flags & 32 /* Class */) {
                            if (symbol.flags & 4 /* Property */ && symbol.valueDeclaration && isBinaryExpression(symbol.valueDeclaration.parent) && isClassExpression(symbol.valueDeclaration.parent.right)) {
                                serializeAsAlias(symbol, getInternalSymbolName(symbol, symbolName2), modifierFlags);
                            }
                            else {
                                serializeAsClass(symbol, getInternalSymbolName(symbol, symbolName2), modifierFlags);
                            }
                        }
                        if (symbol.flags & (512 /* ValueModule */ | 1024 /* NamespaceModule */) && (!isConstMergedWithNS || isTypeOnlyNamespace(symbol)) || isConstMergedWithNSPrintableAsSignatureMerge) {
                            serializeModule(symbol, symbolName2, modifierFlags);
                        }
                        if (symbol.flags & 64 /* Interface */ && !(symbol.flags & 32 /* Class */)) {
                            serializeInterface(symbol, symbolName2, modifierFlags);
                        }
                        if (symbol.flags & 2097152 /* Alias */) {
                            serializeAsAlias(symbol, getInternalSymbolName(symbol, symbolName2), modifierFlags);
                        }
                        if (symbol.flags & 4 /* Property */ && symbol.escapedName === "export=" /* ExportEquals */) {
                            serializeMaybeAliasAssignment(symbol);
                        }
                        if (symbol.flags & 8388608 /* ExportStar */) {
                            if (symbol.declarations) {
                                for (const node of symbol.declarations) {
                                    const resolvedModule = resolveExternalModuleName(node, node.moduleSpecifier);
                                    if (!resolvedModule)
                                        continue;
                                    addResult(factory.createExportDeclaration(
                                    /*modifiers*/
                                    void 0, 
                                    /*isTypeOnly*/
                                    node.isTypeOnly, 
                                    /*exportClause*/
                                    void 0, factory.createStringLiteral(getSpecifierForModuleSymbol(resolvedModule, context))), 0 /* None */);
                                }
                            }
                        }
                        if (needsPostExportDefault) {
                            addResult(factory.createExportAssignment(
                            /*modifiers*/
                            void 0, 
                            /*isExportEquals*/
                            false, factory.createIdentifier(getInternalSymbolName(symbol, symbolName2))), 0 /* None */);
                        }
                        else if (needsExportDeclaration) {
                            addResult(factory.createExportDeclaration(
                            /*modifiers*/
                            void 0, 
                            /*isTypeOnly*/
                            false, factory.createNamedExports([factory.createExportSpecifier(
                                /*isTypeOnly*/
                                false, getInternalSymbolName(symbol, symbolName2), symbolName2)])), 0 /* None */);
                        }
                    }
                    function includePrivateSymbol(symbol) {
                        if (some(symbol.declarations, isParameterDeclaration))
                            return;
                        Debug.assertIsDefined(deferredPrivatesStack[deferredPrivatesStack.length - 1]);
                        getUnusedName(unescapeLeadingUnderscores(symbol.escapedName), symbol);
                        const isExternalImportAlias = !!(symbol.flags & 2097152 /* Alias */) && !some(symbol.declarations, (d) => !!findAncestor(d, isExportDeclaration) || isNamespaceExport(d) || isImportEqualsDeclaration(d) && !isExternalModuleReference(d.moduleReference));
                        deferredPrivatesStack[isExternalImportAlias ? 0 : deferredPrivatesStack.length - 1].set(getSymbolId(symbol), symbol);
                    }
                    function isExportingScope(enclosingDeclaration2) {
                        return isSourceFile(enclosingDeclaration2) && (isExternalOrCommonJsModule(enclosingDeclaration2) || isJsonSourceFile(enclosingDeclaration2)) || isAmbientModule(enclosingDeclaration2) && !isGlobalScopeAugmentation(enclosingDeclaration2);
                    }
                    function addResult(node, additionalModifierFlags) {
                        if (canHaveModifiers(node)) {
                            let newModifierFlags = 0 /* None */;
                            const enclosingDeclaration2 = context.enclosingDeclaration && (isJSDocTypeAlias(context.enclosingDeclaration) ? getSourceFileOfNode(context.enclosingDeclaration) : context.enclosingDeclaration);
                            if (additionalModifierFlags & 32 /* Export */ && enclosingDeclaration2 && (isExportingScope(enclosingDeclaration2) || isModuleDeclaration(enclosingDeclaration2)) && canHaveExportModifier(node)) {
                                newModifierFlags |= 32 /* Export */;
                            }
                            if (addingDeclare && !(newModifierFlags & 32 /* Export */) && (!enclosingDeclaration2 || !(enclosingDeclaration2.flags & 33554432 /* Ambient */)) && (isEnumDeclaration(node) || isVariableStatement(node) || isFunctionDeclaration(node) || isClassDeclaration(node) || isModuleDeclaration(node))) {
                                newModifierFlags |= 128 /* Ambient */;
                            }
                            if (additionalModifierFlags & 2048 /* Default */ && (isClassDeclaration(node) || isInterfaceDeclaration(node) || isFunctionDeclaration(node))) {
                                newModifierFlags |= 2048 /* Default */;
                            }
                            if (newModifierFlags) {
                                node = factory.replaceModifiers(node, newModifierFlags | getEffectiveModifierFlags(node));
                            }
                        }
                        results.push(node);
                    }
                    function serializeTypeAlias(symbol, symbolName2, modifierFlags) {
                        var _a2;
                        const aliasType = getDeclaredTypeOfTypeAlias(symbol);
                        const typeParams = getSymbolLinks(symbol).typeParameters;
                        const typeParamDecls = map(typeParams, (p) => typeParameterToDeclaration(p, context));
                        const jsdocAliasDecl = (_a2 = symbol.declarations) == null ? void 0 : _a2.find(isJSDocTypeAlias);
                        const commentText = getTextOfJSDocComment(jsdocAliasDecl ? jsdocAliasDecl.comment || jsdocAliasDecl.parent.comment : void 0);
                        const oldFlags = context.flags;
                        context.flags |= 8388608 /* InTypeAlias */;
                        const oldEnclosingDecl = context.enclosingDeclaration;
                        context.enclosingDeclaration = jsdocAliasDecl;
                        const typeNode = jsdocAliasDecl && jsdocAliasDecl.typeExpression && isJSDocTypeExpression(jsdocAliasDecl.typeExpression) && serializeExistingTypeNode(context, jsdocAliasDecl.typeExpression.type, includePrivateSymbol, bundled) || typeToTypeNodeHelper(aliasType, context);
                        addResult(setSyntheticLeadingComments(factory.createTypeAliasDeclaration(
                        /*modifiers*/
                        void 0, getInternalSymbolName(symbol, symbolName2), typeParamDecls, typeNode), !commentText ? [] : [{ kind: 3 /* MultiLineCommentTrivia */, text: "*\n * " + commentText.replace(/\n/g, "\n * ") + "\n ", pos: -1, end: -1, hasTrailingNewLine: true }]), modifierFlags);
                        context.flags = oldFlags;
                        context.enclosingDeclaration = oldEnclosingDecl;
                    }
                    function serializeInterface(symbol, symbolName2, modifierFlags) {
                        const interfaceType = getDeclaredTypeOfClassOrInterface(symbol);
                        const localParams = getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(symbol);
                        const typeParamDecls = map(localParams, (p) => typeParameterToDeclaration(p, context));
                        const baseTypes = getBaseTypes(interfaceType);
                        const baseType = length(baseTypes) ? getIntersectionType(baseTypes) : void 0;
                        const members = flatMap(getPropertiesOfType(interfaceType), (p) => serializePropertySymbolForInterface(p, baseType));
                        const callSignatures = serializeSignatures(0 /* Call */, interfaceType, baseType, 179 /* CallSignature */);
                        const constructSignatures = serializeSignatures(1 /* Construct */, interfaceType, baseType, 180 /* ConstructSignature */);
                        const indexSignatures = serializeIndexSignatures(interfaceType, baseType);
                        const heritageClauses = !length(baseTypes) ? void 0 : [factory.createHeritageClause(96 /* ExtendsKeyword */, mapDefined(baseTypes, (b) => trySerializeAsTypeReference(b, 111551 /* Value */)))];
                        addResult(factory.createInterfaceDeclaration(
                        /*modifiers*/
                        void 0, getInternalSymbolName(symbol, symbolName2), typeParamDecls, heritageClauses, [...indexSignatures, ...constructSignatures, ...callSignatures, ...members]), modifierFlags);
                    }
                    function getNamespaceMembersForSerialization(symbol) {
                        let exports = arrayFrom(getExportsOfSymbol(symbol).values());
                        const merged = getMergedSymbol(symbol);
                        if (merged !== symbol) {
                            const membersSet = new Set(exports);
                            for (const exported of getExportsOfSymbol(merged).values()) {
                                if (!(getSymbolFlags(resolveSymbol(exported)) & 111551 /* Value */)) {
                                    membersSet.add(exported);
                                }
                            }
                            exports = arrayFrom(membersSet);
                        }
                        return filter(exports, (m) => isNamespaceMember(m) && isIdentifierText(m.escapedName, 99 /* ESNext */));
                    }
                    function isTypeOnlyNamespace(symbol) {
                        return every(getNamespaceMembersForSerialization(symbol), (m) => !(getSymbolFlags(resolveSymbol(m)) & 111551 /* Value */));
                    }
                    function serializeModule(symbol, symbolName2, modifierFlags) {
                        const members = getNamespaceMembersForSerialization(symbol);
                        const locationMap = arrayToMultiMap(members, (m) => m.parent && m.parent === symbol ? "real" : "merged");
                        const realMembers = locationMap.get("real") || emptyArray;
                        const mergedMembers = locationMap.get("merged") || emptyArray;
                        if (length(realMembers)) {
                            const localName = getInternalSymbolName(symbol, symbolName2);
                            serializeAsNamespaceDeclaration(realMembers, localName, modifierFlags, !!(symbol.flags & (16 /* Function */ | 67108864 /* Assignment */)));
                        }
                        if (length(mergedMembers)) {
                            const containingFile = getSourceFileOfNode(context.enclosingDeclaration);
                            const localName = getInternalSymbolName(symbol, symbolName2);
                            const nsBody = factory.createModuleBlock([factory.createExportDeclaration(
                                /*modifiers*/
                                void 0, 
                                /*isTypeOnly*/
                                false, factory.createNamedExports(mapDefined(filter(mergedMembers, (n) => n.escapedName !== "export=" /* ExportEquals */), (s) => {
                                    var _a2, _b;
                                    const name = unescapeLeadingUnderscores(s.escapedName);
                                    const localName2 = getInternalSymbolName(s, name);
                                    const aliasDecl = s.declarations && getDeclarationOfAliasSymbol(s);
                                    if (containingFile && (aliasDecl ? containingFile !== getSourceFileOfNode(aliasDecl) : !some(s.declarations, (d) => getSourceFileOfNode(d) === containingFile))) {
                                        (_b = (_a2 = context.tracker) == null ? void 0 : _a2.reportNonlocalAugmentation) == null ? void 0 : _b.call(_a2, containingFile, symbol, s);
                                        return void 0;
                                    }
                                    const target = aliasDecl && getTargetOfAliasDeclaration(aliasDecl, 
                                    /*dontRecursivelyResolve*/
                                    true);
                                    includePrivateSymbol(target || s);
                                    const targetName = target ? getInternalSymbolName(target, unescapeLeadingUnderscores(target.escapedName)) : localName2;
                                    return factory.createExportSpecifier(
                                    /*isTypeOnly*/
                                    false, name === targetName ? void 0 : targetName, name);
                                })))]);
                            addResult(factory.createModuleDeclaration(
                            /*modifiers*/
                            void 0, factory.createIdentifier(localName), nsBody, 32 /* Namespace */), 0 /* None */);
                        }
                    }
                    function serializeEnum(symbol, symbolName2, modifierFlags) {
                        addResult(factory.createEnumDeclaration(factory.createModifiersFromModifierFlags(isConstEnumSymbol(symbol) ? 4096 /* Const */ : 0), getInternalSymbolName(symbol, symbolName2), map(filter(getPropertiesOfType(getTypeOfSymbol(symbol)), (p) => !!(p.flags & 8 /* EnumMember */)), (p) => {
                            const initializedValue = p.declarations && p.declarations[0] && isEnumMember(p.declarations[0]) ? getConstantValue2(p.declarations[0]) : void 0;
                            return factory.createEnumMember(unescapeLeadingUnderscores(p.escapedName), initializedValue === void 0 ? void 0 : typeof initializedValue === "string" ? factory.createStringLiteral(initializedValue) : factory.createNumericLiteral(initializedValue));
                        })), modifierFlags);
                    }
                    function serializeAsFunctionNamespaceMerge(type, symbol, localName, modifierFlags) {
                        const signatures = getSignaturesOfType(type, 0 /* Call */);
                        for (const sig of signatures) {
                            const decl = signatureToSignatureDeclarationHelper(sig, 262 /* FunctionDeclaration */, context, { name: factory.createIdentifier(localName), privateSymbolVisitor: includePrivateSymbol, bundledImports: bundled });
                            addResult(setTextRange(decl, getSignatureTextRangeLocation(sig)), modifierFlags);
                        }
                        if (!(symbol.flags & (512 /* ValueModule */ | 1024 /* NamespaceModule */) && !!symbol.exports && !!symbol.exports.size)) {
                            const props = filter(getPropertiesOfType(type), isNamespaceMember);
                            serializeAsNamespaceDeclaration(props, localName, modifierFlags, 
                            /*suppressNewPrivateContext*/
                            true);
                        }
                    }
                    function getSignatureTextRangeLocation(signature) {
                        if (signature.declaration && signature.declaration.parent) {
                            if (isBinaryExpression(signature.declaration.parent) && getAssignmentDeclarationKind(signature.declaration.parent) === 5 /* Property */) {
                                return signature.declaration.parent;
                            }
                            if (isVariableDeclaration(signature.declaration.parent) && signature.declaration.parent.parent) {
                                return signature.declaration.parent.parent;
                            }
                        }
                        return signature.declaration;
                    }
                    function serializeAsNamespaceDeclaration(props, localName, modifierFlags, suppressNewPrivateContext) {
                        if (length(props)) {
                            const localVsRemoteMap = arrayToMultiMap(props, (p) => !length(p.declarations) || some(p.declarations, (d) => getSourceFileOfNode(d) === getSourceFileOfNode(context.enclosingDeclaration)) ? "local" : "remote");
                            const localProps = localVsRemoteMap.get("local") || emptyArray;
                            let fakespace = parseNodeFactory.createModuleDeclaration(
                            /*modifiers*/
                            void 0, factory.createIdentifier(localName), factory.createModuleBlock([]), 32 /* Namespace */);
                            setParent(fakespace, enclosingDeclaration);
                            fakespace.locals = createSymbolTable(props);
                            fakespace.symbol = props[0].parent;
                            const oldResults = results;
                            results = [];
                            const oldAddingDeclare = addingDeclare;
                            addingDeclare = false;
                            const subcontext = { ...context, enclosingDeclaration: fakespace };
                            const oldContext = context;
                            context = subcontext;
                            visitSymbolTable(createSymbolTable(localProps), suppressNewPrivateContext, 
                            /*propertyAsAlias*/
                            true);
                            context = oldContext;
                            addingDeclare = oldAddingDeclare;
                            const declarations = results;
                            results = oldResults;
                            const defaultReplaced = map(declarations, (d) => isExportAssignment(d) && !d.isExportEquals && isIdentifier(d.expression) ? factory.createExportDeclaration(
                            /*modifiers*/
                            void 0, 
                            /*isTypeOnly*/
                            false, factory.createNamedExports([factory.createExportSpecifier(
                                /*isTypeOnly*/
                                false, d.expression, factory.createIdentifier("default" /* Default */))])) : d);
                            const exportModifierStripped = every(defaultReplaced, (d) => hasSyntacticModifier(d, 32 /* Export */)) ? map(defaultReplaced, removeExportModifier) : defaultReplaced;
                            fakespace = factory.updateModuleDeclaration(fakespace, fakespace.modifiers, fakespace.name, factory.createModuleBlock(exportModifierStripped));
                            addResult(fakespace, modifierFlags);
                        }
                    }
                    function isNamespaceMember(p) {
                        return !!(p.flags & (788968 /* Type */ | 1920 /* Namespace */ | 2097152 /* Alias */)) || !(p.flags & 4194304 /* Prototype */ || p.escapedName === "prototype" || p.valueDeclaration && isStatic(p.valueDeclaration) && isClassLike(p.valueDeclaration.parent));
                    }
                    function sanitizeJSDocImplements(clauses) {
                        const result = mapDefined(clauses, (e) => {
                            const oldEnclosing = context.enclosingDeclaration;
                            context.enclosingDeclaration = e;
                            let expr = e.expression;
                            if (isEntityNameExpression(expr)) {
                                if (isIdentifier(expr) && idText(expr) === "") {
                                    return cleanup(
                                    /*result*/
                                    void 0);
                                }
                                let introducesError;
                                ({ introducesError, node: expr } = trackExistingEntityName(expr, context, includePrivateSymbol));
                                if (introducesError) {
                                    return cleanup(
                                    /*result*/
                                    void 0);
                                }
                            }
                            return cleanup(factory.createExpressionWithTypeArguments(expr, map(e.typeArguments, (a) => serializeExistingTypeNode(context, a, includePrivateSymbol, bundled) || typeToTypeNodeHelper(getTypeFromTypeNode(a), context))));
                            function cleanup(result2) {
                                context.enclosingDeclaration = oldEnclosing;
                                return result2;
                            }
                        });
                        if (result.length === clauses.length) {
                            return result;
                        }
                        return void 0;
                    }
                    function serializeAsClass(symbol, localName, modifierFlags) {
                        var _a2, _b;
                        const originalDecl = (_a2 = symbol.declarations) == null ? void 0 : _a2.find(isClassLike);
                        const oldEnclosing = context.enclosingDeclaration;
                        context.enclosingDeclaration = originalDecl || oldEnclosing;
                        const localParams = getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(symbol);
                        const typeParamDecls = map(localParams, (p) => typeParameterToDeclaration(p, context));
                        const classType = getTypeWithThisArgument(getDeclaredTypeOfClassOrInterface(symbol));
                        const baseTypes = getBaseTypes(classType);
                        const originalImplements = originalDecl && getEffectiveImplementsTypeNodes(originalDecl);
                        const implementsExpressions = originalImplements && sanitizeJSDocImplements(originalImplements) || mapDefined(getImplementsTypes(classType), serializeImplementedType);
                        const staticType = getTypeOfSymbol(symbol);
                        const isClass = !!((_b = staticType.symbol) == null ? void 0 : _b.valueDeclaration) && isClassLike(staticType.symbol.valueDeclaration);
                        const staticBaseType = isClass ? getBaseConstructorTypeOfClass(staticType) : anyType;
                        const heritageClauses = [
                            ...!length(baseTypes) ? [] : [factory.createHeritageClause(96 /* ExtendsKeyword */, map(baseTypes, (b) => serializeBaseType(b, staticBaseType, localName)))],
                            ...!length(implementsExpressions) ? [] : [factory.createHeritageClause(119 /* ImplementsKeyword */, implementsExpressions)]
                        ];
                        const symbolProps = getNonInheritedProperties(classType, baseTypes, getPropertiesOfType(classType));
                        const publicSymbolProps = filter(symbolProps, (s) => {
                            const valueDecl = s.valueDeclaration;
                            return !!valueDecl && !(isNamedDeclaration(valueDecl) && isPrivateIdentifier(valueDecl.name));
                        });
                        const hasPrivateIdentifier = some(symbolProps, (s) => {
                            const valueDecl = s.valueDeclaration;
                            return !!valueDecl && isNamedDeclaration(valueDecl) && isPrivateIdentifier(valueDecl.name);
                        });
                        const privateProperties = hasPrivateIdentifier ? [factory.createPropertyDeclaration(
                            /*modifiers*/
                            void 0, factory.createPrivateIdentifier("#private"), 
                            /*questionOrExclamationToken*/
                            void 0, 
                            /*type*/
                            void 0, 
                            /*initializer*/
                            void 0)] : emptyArray;
                        const publicProperties = flatMap(publicSymbolProps, (p) => serializePropertySymbolForClass(p, 
                        /*isStatic*/
                        false, baseTypes[0]));
                        const staticMembers = flatMap(filter(getPropertiesOfType(staticType), (p) => !(p.flags & 4194304 /* Prototype */) && p.escapedName !== "prototype" && !isNamespaceMember(p)), (p) => serializePropertySymbolForClass(p, 
                        /*isStatic*/
                        true, staticBaseType));
                        const isNonConstructableClassLikeInJsFile = !isClass && !!symbol.valueDeclaration && isInJSFile(symbol.valueDeclaration) && !some(getSignaturesOfType(staticType, 1 /* Construct */));
                        const constructors = isNonConstructableClassLikeInJsFile ? [factory.createConstructorDeclaration(factory.createModifiersFromModifierFlags(2 /* Private */), [], 
                            /*body*/
                            void 0)] : serializeSignatures(1 /* Construct */, staticType, staticBaseType, 176 /* Constructor */);
                        const indexSignatures = serializeIndexSignatures(classType, baseTypes[0]);
                        context.enclosingDeclaration = oldEnclosing;
                        addResult(setTextRange(factory.createClassDeclaration(
                        /*modifiers*/
                        void 0, localName, typeParamDecls, heritageClauses, [...indexSignatures, ...staticMembers, ...constructors, ...publicProperties, ...privateProperties]), symbol.declarations && filter(symbol.declarations, (d) => isClassDeclaration(d) || isClassExpression(d))[0]), modifierFlags);
                    }
                    function getSomeTargetNameFromDeclarations(declarations) {
                        return firstDefined(declarations, (d) => {
                            if (isImportSpecifier(d) || isExportSpecifier(d)) {
                                return idText(d.propertyName || d.name);
                            }
                            if (isBinaryExpression(d) || isExportAssignment(d)) {
                                const expression = isExportAssignment(d) ? d.expression : d.right;
                                if (isPropertyAccessExpression(expression)) {
                                    return idText(expression.name);
                                }
                            }
                            if (isAliasSymbolDeclaration2(d)) {
                                const name = getNameOfDeclaration(d);
                                if (name && isIdentifier(name)) {
                                    return idText(name);
                                }
                            }
                            return void 0;
                        });
                    }
                    function serializeAsAlias(symbol, localName, modifierFlags) {
                        var _a2, _b, _c, _d, _e, _f;
                        const node = getDeclarationOfAliasSymbol(symbol);
                        if (!node)
                            return Debug.fail();
                        const target = getMergedSymbol(getTargetOfAliasDeclaration(node, 
                        /*dontRecursivelyResolve*/
                        true));
                        if (!target) {
                            return;
                        }
                        let verbatimTargetName = isShorthandAmbientModuleSymbol(target) && getSomeTargetNameFromDeclarations(symbol.declarations) || unescapeLeadingUnderscores(target.escapedName);
                        if (verbatimTargetName === "export=" /* ExportEquals */ && allowSyntheticDefaultImports) {
                            verbatimTargetName = "default" /* Default */;
                        }
                        const targetName = getInternalSymbolName(target, verbatimTargetName);
                        includePrivateSymbol(target);
                        switch (node.kind) {
                            case 208 /* BindingElement */:
                                if (((_b = (_a2 = node.parent) == null ? void 0 : _a2.parent) == null ? void 0 : _b.kind) === 260 /* VariableDeclaration */) {
                                    const specifier2 = getSpecifierForModuleSymbol(target.parent || target, context);
                                    const { propertyName } = node;
                                    addResult(factory.createImportDeclaration(
                                    /*modifiers*/
                                    void 0, factory.createImportClause(
                                    /*isTypeOnly*/
                                    false, 
                                    /*name*/
                                    void 0, factory.createNamedImports([factory.createImportSpecifier(
                                        /*isTypeOnly*/
                                        false, propertyName && isIdentifier(propertyName) ? factory.createIdentifier(idText(propertyName)) : void 0, factory.createIdentifier(localName))])), factory.createStringLiteral(specifier2), 
                                    /*attributes*/
                                    void 0), 0 /* None */);
                                    break;
                                }
                                Debug.failBadSyntaxKind(((_c = node.parent) == null ? void 0 : _c.parent) || node, "Unhandled binding element grandparent kind in declaration serialization");
                                break;
                            case 304 /* ShorthandPropertyAssignment */:
                                if (((_e = (_d = node.parent) == null ? void 0 : _d.parent) == null ? void 0 : _e.kind) === 226 /* BinaryExpression */) {
                                    serializeExportSpecifier(unescapeLeadingUnderscores(symbol.escapedName), targetName);
                                }
                                break;
                            case 260 /* VariableDeclaration */:
                                if (isPropertyAccessExpression(node.initializer)) {
                                    const initializer = node.initializer;
                                    const uniqueName = factory.createUniqueName(localName);
                                    const specifier2 = getSpecifierForModuleSymbol(target.parent || target, context);
                                    addResult(factory.createImportEqualsDeclaration(
                                    /*modifiers*/
                                    void 0, 
                                    /*isTypeOnly*/
                                    false, uniqueName, factory.createExternalModuleReference(factory.createStringLiteral(specifier2))), 0 /* None */);
                                    addResult(factory.createImportEqualsDeclaration(
                                    /*modifiers*/
                                    void 0, 
                                    /*isTypeOnly*/
                                    false, factory.createIdentifier(localName), factory.createQualifiedName(uniqueName, initializer.name)), modifierFlags);
                                    break;
                                }
                            case 271 /* ImportEqualsDeclaration */:
                                if (target.escapedName === "export=" /* ExportEquals */ && some(target.declarations, (d) => isSourceFile(d) && isJsonSourceFile(d))) {
                                    serializeMaybeAliasAssignment(symbol);
                                    break;
                                }
                                const isLocalImport = !(target.flags & 512 /* ValueModule */) && !isVariableDeclaration(node);
                                addResult(factory.createImportEqualsDeclaration(
                                /*modifiers*/
                                void 0, 
                                /*isTypeOnly*/
                                false, factory.createIdentifier(localName), isLocalImport ? symbolToName(target, context, -1 /* All */, 
                                /*expectsIdentifier*/
                                false) : factory.createExternalModuleReference(factory.createStringLiteral(getSpecifierForModuleSymbol(target, context)))), isLocalImport ? modifierFlags : 0 /* None */);
                                break;
                            case 270 /* NamespaceExportDeclaration */:
                                addResult(factory.createNamespaceExportDeclaration(idText(node.name)), 0 /* None */);
                                break;
                            case 273 /* ImportClause */: {
                                const generatedSpecifier = getSpecifierForModuleSymbol(target.parent || target, context);
                                const specifier2 = bundled ? factory.createStringLiteral(generatedSpecifier) : node.parent.moduleSpecifier;
                                addResult(factory.createImportDeclaration(
                                /*modifiers*/
                                void 0, factory.createImportClause(
                                /*isTypeOnly*/
                                false, factory.createIdentifier(localName), 
                                /*namedBindings*/
                                void 0), specifier2, node.parent.attributes), 0 /* None */);
                                break;
                            }
                            case 274 /* NamespaceImport */: {
                                const generatedSpecifier = getSpecifierForModuleSymbol(target.parent || target, context);
                                const specifier2 = bundled ? factory.createStringLiteral(generatedSpecifier) : node.parent.parent.moduleSpecifier;
                                addResult(factory.createImportDeclaration(
                                /*modifiers*/
                                void 0, factory.createImportClause(
                                /*isTypeOnly*/
                                false, 
                                /*name*/
                                void 0, factory.createNamespaceImport(factory.createIdentifier(localName))), specifier2, node.parent.attributes), 0 /* None */);
                                break;
                            }
                            case 280 /* NamespaceExport */:
                                addResult(factory.createExportDeclaration(
                                /*modifiers*/
                                void 0, 
                                /*isTypeOnly*/
                                false, factory.createNamespaceExport(factory.createIdentifier(localName)), factory.createStringLiteral(getSpecifierForModuleSymbol(target, context))), 0 /* None */);
                                break;
                            case 276 /* ImportSpecifier */: {
                                const generatedSpecifier = getSpecifierForModuleSymbol(target.parent || target, context);
                                const specifier2 = bundled ? factory.createStringLiteral(generatedSpecifier) : node.parent.parent.parent.moduleSpecifier;
                                addResult(factory.createImportDeclaration(
                                /*modifiers*/
                                void 0, factory.createImportClause(
                                /*isTypeOnly*/
                                false, 
                                /*name*/
                                void 0, factory.createNamedImports([
                                    factory.createImportSpecifier(
                                    /*isTypeOnly*/
                                    false, localName !== verbatimTargetName ? factory.createIdentifier(verbatimTargetName) : void 0, factory.createIdentifier(localName))
                                ])), specifier2, node.parent.parent.parent.attributes), 0 /* None */);
                                break;
                            }
                            case 281 /* ExportSpecifier */:
                                const specifier = node.parent.parent.moduleSpecifier;
                                if (specifier && ((_f = node.propertyName) == null ? void 0 : _f.escapedText) === "default" /* Default */) {
                                    verbatimTargetName = "default" /* Default */;
                                }
                                serializeExportSpecifier(unescapeLeadingUnderscores(symbol.escapedName), specifier ? verbatimTargetName : targetName, specifier && isStringLiteralLike(specifier) ? factory.createStringLiteral(specifier.text) : void 0);
                                break;
                            case 277 /* ExportAssignment */:
                                serializeMaybeAliasAssignment(symbol);
                                break;
                            case 226 /* BinaryExpression */:
                            case 211 /* PropertyAccessExpression */:
                            case 212 /* ElementAccessExpression */:
                                if (symbol.escapedName === "default" /* Default */ || symbol.escapedName === "export=" /* ExportEquals */) {
                                    serializeMaybeAliasAssignment(symbol);
                                }
                                else {
                                    serializeExportSpecifier(localName, targetName);
                                }
                                break;
                            default:
                                return Debug.failBadSyntaxKind(node, "Unhandled alias declaration kind in symbol serializer!");
                        }
                    }
                    function serializeExportSpecifier(localName, targetName, specifier) {
                        addResult(factory.createExportDeclaration(
                        /*modifiers*/
                        void 0, 
                        /*isTypeOnly*/
                        false, factory.createNamedExports([factory.createExportSpecifier(
                            /*isTypeOnly*/
                            false, localName !== targetName ? targetName : void 0, localName)]), specifier), 0 /* None */);
                    }
                    function serializeMaybeAliasAssignment(symbol) {
                        var _a2;
                        if (symbol.flags & 4194304 /* Prototype */) {
                            return false;
                        }
                        const name = unescapeLeadingUnderscores(symbol.escapedName);
                        const isExportEquals = name === "export=" /* ExportEquals */;
                        const isDefault = name === "default" /* Default */;
                        const isExportAssignmentCompatibleSymbolName = isExportEquals || isDefault;
                        const aliasDecl = symbol.declarations && getDeclarationOfAliasSymbol(symbol);
                        const target = aliasDecl && getTargetOfAliasDeclaration(aliasDecl, 
                        /*dontRecursivelyResolve*/
                        true);
                        if (target && length(target.declarations) && some(target.declarations, (d) => getSourceFileOfNode(d) === getSourceFileOfNode(enclosingDeclaration))) {
                            const expr = aliasDecl && (isExportAssignment(aliasDecl) || isBinaryExpression(aliasDecl) ? getExportAssignmentExpression(aliasDecl) : getPropertyAssignmentAliasLikeExpression(aliasDecl));
                            const first2 = expr && isEntityNameExpression(expr) ? getFirstNonModuleExportsIdentifier(expr) : void 0;
                            const referenced = first2 && resolveEntityName(first2, -1 /* All */, 
                            /*ignoreErrors*/
                            true, 
                            /*dontResolveAlias*/
                            true, enclosingDeclaration);
                            if (referenced || target) {
                                includePrivateSymbol(referenced || target);
                            }
                            const prevDisableTrackSymbol = context.tracker.disableTrackSymbol;
                            context.tracker.disableTrackSymbol = true;
                            if (isExportAssignmentCompatibleSymbolName) {
                                results.push(factory.createExportAssignment(
                                /*modifiers*/
                                void 0, isExportEquals, symbolToExpression(target, context, -1 /* All */)));
                            }
                            else {
                                if (first2 === expr && first2) {
                                    serializeExportSpecifier(name, idText(first2));
                                }
                                else if (expr && isClassExpression(expr)) {
                                    serializeExportSpecifier(name, getInternalSymbolName(target, symbolName(target)));
                                }
                                else {
                                    const varName = getUnusedName(name, symbol);
                                    addResult(factory.createImportEqualsDeclaration(
                                    /*modifiers*/
                                    void 0, 
                                    /*isTypeOnly*/
                                    false, factory.createIdentifier(varName), symbolToName(target, context, -1 /* All */, 
                                    /*expectsIdentifier*/
                                    false)), 0 /* None */);
                                    serializeExportSpecifier(name, varName);
                                }
                            }
                            context.tracker.disableTrackSymbol = prevDisableTrackSymbol;
                            return true;
                        }
                        else {
                            const varName = getUnusedName(name, symbol);
                            const typeToSerialize = getWidenedType(getTypeOfSymbol(getMergedSymbol(symbol)));
                            if (isTypeRepresentableAsFunctionNamespaceMerge(typeToSerialize, symbol)) {
                                serializeAsFunctionNamespaceMerge(typeToSerialize, symbol, varName, isExportAssignmentCompatibleSymbolName ? 0 /* None */ : 32 /* Export */);
                            }
                            else {
                                const flags = ((_a2 = context.enclosingDeclaration) == null ? void 0 : _a2.kind) === 267 /* ModuleDeclaration */ && (!(symbol.flags & 98304 /* Accessor */) || symbol.flags & 65536 /* SetAccessor */) ? 1 /* Let */ : 2 /* Const */;
                                const statement = factory.createVariableStatement(
                                /*modifiers*/
                                void 0, factory.createVariableDeclarationList([
                                    factory.createVariableDeclaration(varName, 
                                    /*exclamationToken*/
                                    void 0, serializeTypeForDeclaration(context, typeToSerialize, symbol, enclosingDeclaration, includePrivateSymbol, bundled))
                                ], flags));
                                addResult(statement, target && target.flags & 4 /* Property */ && target.escapedName === "export=" /* ExportEquals */ ? 128 /* Ambient */ : name === varName ? 32 /* Export */ : 0 /* None */);
                            }
                            if (isExportAssignmentCompatibleSymbolName) {
                                results.push(factory.createExportAssignment(
                                /*modifiers*/
                                void 0, isExportEquals, factory.createIdentifier(varName)));
                                return true;
                            }
                            else if (name !== varName) {
                                serializeExportSpecifier(name, varName);
                                return true;
                            }
                            return false;
                        }
                    }
                    function isTypeRepresentableAsFunctionNamespaceMerge(typeToSerialize, hostSymbol) {
                        const ctxSrc = getSourceFileOfNode(context.enclosingDeclaration);
                        return getObjectFlags(typeToSerialize) & (16 /* Anonymous */ | 32 /* Mapped */) && !length(getIndexInfosOfType(typeToSerialize)) && !isClassInstanceSide(typeToSerialize) && // While a class instance is potentially representable as a NS, prefer printing a reference to the instance type and serializing the class
                            !!(length(filter(getPropertiesOfType(typeToSerialize), isNamespaceMember)) || length(getSignaturesOfType(typeToSerialize, 0 /* Call */))) && !length(getSignaturesOfType(typeToSerialize, 1 /* Construct */)) && // TODO: could probably serialize as function + ns + class, now that that's OK
                            !getDeclarationWithTypeAnnotation(hostSymbol, enclosingDeclaration) && !(typeToSerialize.symbol && some(typeToSerialize.symbol.declarations, (d) => getSourceFileOfNode(d) !== ctxSrc)) && !some(getPropertiesOfType(typeToSerialize), (p) => isLateBoundName(p.escapedName)) && !some(getPropertiesOfType(typeToSerialize), (p) => some(p.declarations, (d) => getSourceFileOfNode(d) !== ctxSrc)) && every(getPropertiesOfType(typeToSerialize), (p) => {
                            if (!isIdentifierText(symbolName(p), languageVersion)) {
                                return false;
                            }
                            if (!(p.flags & 98304 /* Accessor */)) {
                                return true;
                            }
                            return getNonMissingTypeOfSymbol(p) === getWriteTypeOfSymbol(p);
                        });
                    }
                    function makeSerializePropertySymbol(createProperty2, methodKind, useAccessors) {
                        return function serializePropertySymbol(p, isStatic2, baseType) {
                            var _a2, _b, _c, _d, _e;
                            const modifierFlags = getDeclarationModifierFlagsFromSymbol(p);
                            const isPrivate = !!(modifierFlags & 2 /* Private */);
                            if (isStatic2 && p.flags & (788968 /* Type */ | 1920 /* Namespace */ | 2097152 /* Alias */)) {
                                return [];
                            }
                            if (p.flags & 4194304 /* Prototype */ || p.escapedName === "constructor" || baseType && getPropertyOfType(baseType, p.escapedName) && isReadonlySymbol(getPropertyOfType(baseType, p.escapedName)) === isReadonlySymbol(p) && (p.flags & 16777216 /* Optional */) === (getPropertyOfType(baseType, p.escapedName).flags & 16777216 /* Optional */) && isTypeIdenticalTo(getTypeOfSymbol(p), getTypeOfPropertyOfType(baseType, p.escapedName))) {
                                return [];
                            }
                            const flag = modifierFlags & ~1024 /* Async */ | (isStatic2 ? 256 /* Static */ : 0);
                            const name = getPropertyNameNodeForSymbol(p, context);
                            const firstPropertyLikeDecl = (_a2 = p.declarations) == null ? void 0 : _a2.find(or(isPropertyDeclaration, isAccessor, isVariableDeclaration, isPropertySignature, isBinaryExpression, isPropertyAccessExpression));
                            if (p.flags & 98304 /* Accessor */ && useAccessors) {
                                const result = [];
                                if (p.flags & 65536 /* SetAccessor */) {
                                    const setter = p.declarations && forEach(p.declarations, (d) => {
                                        if (d.kind === 178 /* SetAccessor */) {
                                            return d;
                                        }
                                        if (isCallExpression(d) && isBindableObjectDefinePropertyCall(d)) {
                                            return forEach(d.arguments[2].properties, (propDecl) => {
                                                const id = getNameOfDeclaration(propDecl);
                                                if (!!id && isIdentifier(id) && idText(id) === "set") {
                                                    return propDecl;
                                                }
                                            });
                                        }
                                    });
                                    Debug.assert(!!setter);
                                    const paramSymbol = isFunctionLikeDeclaration(setter) ? getSignatureFromDeclaration(setter).parameters[0] : void 0;
                                    result.push(setTextRange(factory.createSetAccessorDeclaration(factory.createModifiersFromModifierFlags(flag), name, [factory.createParameterDeclaration(
                                        /*modifiers*/
                                        void 0, 
                                        /*dotDotDotToken*/
                                        void 0, paramSymbol ? parameterToParameterDeclarationName(paramSymbol, getEffectiveParameterDeclaration(paramSymbol), context) : "value", 
                                        /*questionToken*/
                                        void 0, isPrivate ? void 0 : serializeTypeForDeclaration(context, getTypeOfSymbol(p), p, enclosingDeclaration, includePrivateSymbol, bundled))], 
                                    /*body*/
                                    void 0), ((_b = p.declarations) == null ? void 0 : _b.find(isSetAccessor)) || firstPropertyLikeDecl));
                                }
                                if (p.flags & 32768 /* GetAccessor */) {
                                    const isPrivate2 = modifierFlags & 2 /* Private */;
                                    result.push(setTextRange(factory.createGetAccessorDeclaration(factory.createModifiersFromModifierFlags(flag), name, [], isPrivate2 ? void 0 : serializeTypeForDeclaration(context, getTypeOfSymbol(p), p, enclosingDeclaration, includePrivateSymbol, bundled), 
                                    /*body*/
                                    void 0), ((_c = p.declarations) == null ? void 0 : _c.find(isGetAccessor)) || firstPropertyLikeDecl));
                                }
                                return result;
                            }
                            else if (p.flags & (4 /* Property */ | 3 /* Variable */ | 98304 /* Accessor */)) {
                                return setTextRange(createProperty2(factory.createModifiersFromModifierFlags((isReadonlySymbol(p) ? 8 /* Readonly */ : 0) | flag), name, p.flags & 16777216 /* Optional */ ? factory.createToken(58 /* QuestionToken */) : void 0, isPrivate ? void 0 : serializeTypeForDeclaration(context, getWriteTypeOfSymbol(p), p, enclosingDeclaration, includePrivateSymbol, bundled), 
                                // TODO: https://github.com/microsoft/TypeScript/pull/32372#discussion_r328386357
                                // interface members can't have initializers, however class members _can_
                                /*initializer*/
                                void 0), ((_d = p.declarations) == null ? void 0 : _d.find(or(isPropertyDeclaration, isVariableDeclaration))) || firstPropertyLikeDecl);
                            }
                            if (p.flags & (8192 /* Method */ | 16 /* Function */)) {
                                const type = getTypeOfSymbol(p);
                                const signatures = getSignaturesOfType(type, 0 /* Call */);
                                if (flag & 2 /* Private */) {
                                    return setTextRange(createProperty2(factory.createModifiersFromModifierFlags((isReadonlySymbol(p) ? 8 /* Readonly */ : 0) | flag), name, p.flags & 16777216 /* Optional */ ? factory.createToken(58 /* QuestionToken */) : void 0, 
                                    /*type*/
                                    void 0, 
                                    /*initializer*/
                                    void 0), ((_e = p.declarations) == null ? void 0 : _e.find(isFunctionLikeDeclaration)) || signatures[0] && signatures[0].declaration || p.declarations && p.declarations[0]);
                                }
                                const results2 = [];
                                for (const sig of signatures) {
                                    const decl = signatureToSignatureDeclarationHelper(sig, methodKind, context, {
                                        name,
                                        questionToken: p.flags & 16777216 /* Optional */ ? factory.createToken(58 /* QuestionToken */) : void 0,
                                        modifiers: flag ? factory.createModifiersFromModifierFlags(flag) : void 0
                                    });
                                    const location = sig.declaration && isPrototypePropertyAssignment(sig.declaration.parent) ? sig.declaration.parent : sig.declaration;
                                    results2.push(setTextRange(decl, location));
                                }
                                return results2;
                            }
                            return Debug.fail(`Unhandled class member kind! ${p.__debugFlags || p.flags}`);
                        };
                    }
                    function serializePropertySymbolForInterface(p, baseType) {
                        return serializePropertySymbolForInterfaceWorker(p, 
                        /*isStatic*/
                        false, baseType);
                    }
                    function serializeSignatures(kind, input, baseType, outputKind) {
                        const signatures = getSignaturesOfType(input, kind);
                        if (kind === 1 /* Construct */) {
                            if (!baseType && every(signatures, (s) => length(s.parameters) === 0)) {
                                return [];
                            }
                            if (baseType) {
                                const baseSigs = getSignaturesOfType(baseType, 1 /* Construct */);
                                if (!length(baseSigs) && every(signatures, (s) => length(s.parameters) === 0)) {
                                    return [];
                                }
                                if (baseSigs.length === signatures.length) {
                                    let failed = false;
                                    for (let i = 0; i < baseSigs.length; i++) {
                                        if (!compareSignaturesIdentical(signatures[i], baseSigs[i], 
                                        /*partialMatch*/
                                        false, 
                                        /*ignoreThisTypes*/
                                        false, 
                                        /*ignoreReturnTypes*/
                                        true, compareTypesIdentical)) {
                                            failed = true;
                                            break;
                                        }
                                    }
                                    if (!failed) {
                                        return [];
                                    }
                                }
                            }
                            let privateProtected = 0;
                            for (const s of signatures) {
                                if (s.declaration) {
                                    privateProtected |= getSelectedEffectiveModifierFlags(s.declaration, 2 /* Private */ | 4 /* Protected */);
                                }
                            }
                            if (privateProtected) {
                                return [setTextRange(factory.createConstructorDeclaration(factory.createModifiersFromModifierFlags(privateProtected), 
                                    /*parameters*/
                                    [], 
                                    /*body*/
                                    void 0), signatures[0].declaration)];
                            }
                        }
                        const results2 = [];
                        for (const sig of signatures) {
                            const decl = signatureToSignatureDeclarationHelper(sig, outputKind, context);
                            results2.push(setTextRange(decl, sig.declaration));
                        }
                        return results2;
                    }
                    function serializeIndexSignatures(input, baseType) {
                        const results2 = [];
                        for (const info of getIndexInfosOfType(input)) {
                            if (baseType) {
                                const baseInfo = getIndexInfoOfType(baseType, info.keyType);
                                if (baseInfo) {
                                    if (isTypeIdenticalTo(info.type, baseInfo.type)) {
                                        continue;
                                    }
                                }
                            }
                            results2.push(indexInfoToIndexSignatureDeclarationHelper(info, context, 
                            /*typeNode*/
                            void 0));
                        }
                        return results2;
                    }
                    function serializeBaseType(t, staticType, rootName) {
                        const ref = trySerializeAsTypeReference(t, 111551 /* Value */);
                        if (ref) {
                            return ref;
                        }
                        const tempName = getUnusedName(`${rootName}_base`);
                        const statement = factory.createVariableStatement(
                        /*modifiers*/
                        void 0, factory.createVariableDeclarationList([
                            factory.createVariableDeclaration(tempName, 
                            /*exclamationToken*/
                            void 0, typeToTypeNodeHelper(staticType, context))
                        ], 2 /* Const */));
                        addResult(statement, 0 /* None */);
                        return factory.createExpressionWithTypeArguments(factory.createIdentifier(tempName), 
                        /*typeArguments*/
                        void 0);
                    }
                    function trySerializeAsTypeReference(t, flags) {
                        let typeArgs;
                        let reference;
                        if (t.target && isSymbolAccessibleByFlags(t.target.symbol, enclosingDeclaration, flags)) {
                            typeArgs = map(getTypeArguments(t), (t2) => typeToTypeNodeHelper(t2, context));
                            reference = symbolToExpression(t.target.symbol, context, 788968 /* Type */);
                        }
                        else if (t.symbol && isSymbolAccessibleByFlags(t.symbol, enclosingDeclaration, flags)) {
                            reference = symbolToExpression(t.symbol, context, 788968 /* Type */);
                        }
                        if (reference) {
                            return factory.createExpressionWithTypeArguments(reference, typeArgs);
                        }
                    }
                    function serializeImplementedType(t) {
                        const ref = trySerializeAsTypeReference(t, 788968 /* Type */);
                        if (ref) {
                            return ref;
                        }
                        if (t.symbol) {
                            return factory.createExpressionWithTypeArguments(symbolToExpression(t.symbol, context, 788968 /* Type */), 
                            /*typeArguments*/
                            void 0);
                        }
                    }
                    function getUnusedName(input, symbol) {
                        var _a2, _b;
                        const id = symbol ? getSymbolId(symbol) : void 0;
                        if (id) {
                            if (context.remappedSymbolNames.has(id)) {
                                return context.remappedSymbolNames.get(id);
                            }
                        }
                        if (symbol) {
                            input = getNameCandidateWorker(symbol, input);
                        }
                        let i = 0;
                        const original = input;
                        while ((_a2 = context.usedSymbolNames) == null ? void 0 : _a2.has(input)) {
                            i++;
                            input = `${original}_${i}`;
                        }
                        (_b = context.usedSymbolNames) == null ? void 0 : _b.add(input);
                        if (id) {
                            context.remappedSymbolNames.set(id, input);
                        }
                        return input;
                    }
                    function getNameCandidateWorker(symbol, localName) {
                        if (localName === "default" /* Default */ || localName === "__class" /* Class */ || localName === "__function" /* Function */) {
                            const flags = context.flags;
                            context.flags |= 16777216 /* InInitialEntityName */;
                            const nameCandidate = getNameOfSymbolAsWritten(symbol, context);
                            context.flags = flags;
                            localName = nameCandidate.length > 0 && isSingleOrDoubleQuote(nameCandidate.charCodeAt(0)) ? stripQuotes(nameCandidate) : nameCandidate;
                        }
                        if (localName === "default" /* Default */) {
                            localName = "_default";
                        }
                        else if (localName === "export=" /* ExportEquals */) {
                            localName = "_exports";
                        }
                        localName = isIdentifierText(localName, languageVersion) && !isStringANonContextualKeyword(localName) ? localName : "_" + localName.replace(/[^a-zA-Z0-9]/g, "_");
                        return localName;
                    }
                    function getInternalSymbolName(symbol, localName) {
                        const id = getSymbolId(symbol);
                        if (context.remappedSymbolNames.has(id)) {
                            return context.remappedSymbolNames.get(id);
                        }
                        localName = getNameCandidateWorker(symbol, localName);
                        context.remappedSymbolNames.set(id, localName);
                        return localName;
                    }
                }
            }
            function typePredicateToString(typePredicate, enclosingDeclaration, flags = 16384 /* UseAliasDefinedOutsideCurrentScope */, writer) {
                return writer ? typePredicateToStringWorker(writer).getText() : usingSingleLineStringWriter(typePredicateToStringWorker);
                function typePredicateToStringWorker(writer2) {
                    const predicate = factory.createTypePredicateNode(typePredicate.kind === 2 /* AssertsThis */ || typePredicate.kind === 3 /* AssertsIdentifier */ ? factory.createToken(131 /* AssertsKeyword */) : void 0, typePredicate.kind === 1 /* Identifier */ || typePredicate.kind === 3 /* AssertsIdentifier */ ? factory.createIdentifier(typePredicate.parameterName) : factory.createThisTypeNode(), typePredicate.type && nodeBuilder.typeToTypeNode(typePredicate.type, enclosingDeclaration, toNodeBuilderFlags(flags) | 70221824 /* IgnoreErrors */ | 512 /* WriteTypeParametersInQualifiedName */)
                    // TODO: GH#18217
                    );
                    const printer = createPrinterWithRemoveComments();
                    const sourceFile = enclosingDeclaration && getSourceFileOfNode(enclosingDeclaration);
                    printer.writeNode(4 /* Unspecified */, predicate, 
                    /*sourceFile*/
                    sourceFile, writer2);
                    return writer2;
                }
            }
            function formatUnionTypes(types) {
                const result = [];
                let flags = 0;
                for (let i = 0; i < types.length; i++) {
                    const t = types[i];
                    flags |= t.flags;
                    if (!(t.flags & 98304 /* Nullable */)) {
                        if (t.flags & (512 /* BooleanLiteral */ | 1056 /* EnumLike */)) {
                            const baseType = t.flags & 512 /* BooleanLiteral */ ? booleanType : getBaseTypeOfEnumLikeType(t);
                            if (baseType.flags & 1048576 /* Union */) {
                                const count = baseType.types.length;
                                if (i + count <= types.length && getRegularTypeOfLiteralType(types[i + count - 1]) === getRegularTypeOfLiteralType(baseType.types[count - 1])) {
                                    result.push(baseType);
                                    i += count - 1;
                                    continue;
                                }
                            }
                        }
                        result.push(t);
                    }
                }
                if (flags & 65536 /* Null */)
                    result.push(nullType);
                if (flags & 32768 /* Undefined */)
                    result.push(undefinedType);
                return result || types;
            }
            function visibilityToString(flags) {
                if (flags === 2 /* Private */) {
                    return "private";
                }
                if (flags === 4 /* Protected */) {
                    return "protected";
                }
                return "public";
            }
            function getTypeAliasForTypeLiteral(type) {
                if (type.symbol && type.symbol.flags & 2048 /* TypeLiteral */ && type.symbol.declarations) {
                    const node = walkUpParenthesizedTypes(type.symbol.declarations[0].parent);
                    if (isTypeAliasDeclaration(node)) {
                        return getSymbolOfDeclaration(node);
                    }
                }
                return void 0;
            }
            function isTopLevelInExternalModuleAugmentation(node) {
                return node && node.parent && node.parent.kind === 268 /* ModuleBlock */ && isExternalModuleAugmentation(node.parent.parent);
            }
            function isDefaultBindingContext(location) {
                return location.kind === 312 /* SourceFile */ || isAmbientModule(location);
            }
            function getNameOfSymbolFromNameType(symbol, context) {
                const nameType = getSymbolLinks(symbol).nameType;
                if (nameType) {
                    if (nameType.flags & 384 /* StringOrNumberLiteral */) {
                        const name = "" + nameType.value;
                        if (!isIdentifierText(name, getEmitScriptTarget(compilerOptions)) && !isNumericLiteralName(name)) {
                            return `"${escapeString(name, 34 /* doubleQuote */)}"`;
                        }
                        if (isNumericLiteralName(name) && startsWith(name, "-")) {
                            return `[${name}]`;
                        }
                        return name;
                    }
                    if (nameType.flags & 8192 /* UniqueESSymbol */) {
                        return `[${getNameOfSymbolAsWritten(nameType.symbol, context)}]`;
                    }
                }
            }
            function getNameOfSymbolAsWritten(symbol, context) {
                var _a;
                if ((_a = context == null ? void 0 : context.remappedSymbolReferences) == null ? void 0 : _a.has(getSymbolId(symbol))) {
                    symbol = context.remappedSymbolReferences.get(getSymbolId(symbol));
                }
                if (context && symbol.escapedName === "default" /* Default */ && !(context.flags & 16384 /* UseAliasDefinedOutsideCurrentScope */) && // If it's not the first part of an entity name, it must print as `default`
                    (!(context.flags & 16777216 /* InInitialEntityName */) || // if the symbol is synthesized, it will only be referenced externally it must print as `default`
                        !symbol.declarations || // if not in the same binding context (source file, module declaration), it must print as `default`
                        context.enclosingDeclaration && findAncestor(symbol.declarations[0], isDefaultBindingContext) !== findAncestor(context.enclosingDeclaration, isDefaultBindingContext))) {
                    return "default";
                }
                if (symbol.declarations && symbol.declarations.length) {
                    let declaration = firstDefined(symbol.declarations, (d) => getNameOfDeclaration(d) ? d : void 0);
                    const name2 = declaration && getNameOfDeclaration(declaration);
                    if (declaration && name2) {
                        if (isCallExpression(declaration) && isBindableObjectDefinePropertyCall(declaration)) {
                            return symbolName(symbol);
                        }
                        if (isComputedPropertyName(name2) && !(getCheckFlags(symbol) & 4096 /* Late */)) {
                            const nameType = getSymbolLinks(symbol).nameType;
                            if (nameType && nameType.flags & 384 /* StringOrNumberLiteral */) {
                                const result = getNameOfSymbolFromNameType(symbol, context);
                                if (result !== void 0) {
                                    return result;
                                }
                            }
                        }
                        return declarationNameToString(name2);
                    }
                    if (!declaration) {
                        declaration = symbol.declarations[0];
                    }
                    if (declaration.parent && declaration.parent.kind === 260 /* VariableDeclaration */) {
                        return declarationNameToString(declaration.parent.name);
                    }
                    switch (declaration.kind) {
                        case 231 /* ClassExpression */:
                        case 218 /* FunctionExpression */:
                        case 219 /* ArrowFunction */:
                            if (context && !context.encounteredError && !(context.flags & 131072 /* AllowAnonymousIdentifier */)) {
                                context.encounteredError = true;
                            }
                            return declaration.kind === 231 /* ClassExpression */ ? "(Anonymous class)" : "(Anonymous function)";
                    }
                }
                const name = getNameOfSymbolFromNameType(symbol, context);
                return name !== void 0 ? name : symbolName(symbol);
            }
            function isDeclarationVisible(node) {
                if (node) {
                    const links = getNodeLinks(node);
                    if (links.isVisible === void 0) {
                        links.isVisible = !!determineIfDeclarationIsVisible();
                    }
                    return links.isVisible;
                }
                return false;
                function determineIfDeclarationIsVisible() {
                    switch (node.kind) {
                        case 345 /* JSDocCallbackTag */:
                        case 353 /* JSDocTypedefTag */:
                        case 347 /* JSDocEnumTag */:
                            return !!(node.parent && node.parent.parent && node.parent.parent.parent && isSourceFile(node.parent.parent.parent));
                        case 208 /* BindingElement */:
                            return isDeclarationVisible(node.parent.parent);
                        case 260 /* VariableDeclaration */:
                            if (isBindingPattern(node.name) && !node.name.elements.length) {
                                return false;
                            }
                        case 267 /* ModuleDeclaration */:
                        case 263 /* ClassDeclaration */:
                        case 264 /* InterfaceDeclaration */:
                        case 265 /* TypeAliasDeclaration */:
                        case 262 /* FunctionDeclaration */:
                        case 266 /* EnumDeclaration */:
                        case 271 /* ImportEqualsDeclaration */:
                            if (isExternalModuleAugmentation(node)) {
                                return true;
                            }
                            const parent2 = getDeclarationContainer(node);
                            if (!(getCombinedModifierFlagsCached(node) & 32 /* Export */) && !(node.kind !== 271 /* ImportEqualsDeclaration */ && parent2.kind !== 312 /* SourceFile */ && parent2.flags & 33554432 /* Ambient */)) {
                                return isGlobalSourceFile(parent2);
                            }
                            return isDeclarationVisible(parent2);
                        case 172 /* PropertyDeclaration */:
                        case 171 /* PropertySignature */:
                        case 177 /* GetAccessor */:
                        case 178 /* SetAccessor */:
                        case 174 /* MethodDeclaration */:
                        case 173 /* MethodSignature */:
                            if (hasEffectiveModifier(node, 2 /* Private */ | 4 /* Protected */)) {
                                return false;
                            }
                        case 176 /* Constructor */:
                        case 180 /* ConstructSignature */:
                        case 179 /* CallSignature */:
                        case 181 /* IndexSignature */:
                        case 169 /* Parameter */:
                        case 268 /* ModuleBlock */:
                        case 184 /* FunctionType */:
                        case 185 /* ConstructorType */:
                        case 187 /* TypeLiteral */:
                        case 183 /* TypeReference */:
                        case 188 /* ArrayType */:
                        case 189 /* TupleType */:
                        case 192 /* UnionType */:
                        case 193 /* IntersectionType */:
                        case 196 /* ParenthesizedType */:
                        case 202 /* NamedTupleMember */:
                            return isDeclarationVisible(node.parent);
                        case 273 /* ImportClause */:
                        case 274 /* NamespaceImport */:
                        case 276 /* ImportSpecifier */:
                            return false;
                        case 168 /* TypeParameter */:
                        case 312 /* SourceFile */:
                        case 270 /* NamespaceExportDeclaration */:
                            return true;
                        case 277 /* ExportAssignment */:
                            return false;
                        default:
                            return false;
                    }
                }
            }
            function collectLinkedAliases(node, setVisibility) {
                let exportSymbol;
                if (node.parent && node.parent.kind === 277 /* ExportAssignment */) {
                    exportSymbol = resolveName(node, node.escapedText, 111551 /* Value */ | 788968 /* Type */ | 1920 /* Namespace */ | 2097152 /* Alias */, 
                    /*nameNotFoundMessage*/
                    void 0, node, 
                    /*isUse*/
                    false);
                }
                else if (node.parent.kind === 281 /* ExportSpecifier */) {
                    exportSymbol = getTargetOfExportSpecifier(node.parent, 111551 /* Value */ | 788968 /* Type */ | 1920 /* Namespace */ | 2097152 /* Alias */);
                }
                let result;
                let visited;
                if (exportSymbol) {
                    visited = /* @__PURE__ */ new Set();
                    visited.add(getSymbolId(exportSymbol));
                    buildVisibleNodeList(exportSymbol.declarations);
                }
                return result;
                function buildVisibleNodeList(declarations) {
                    forEach(declarations, (declaration) => {
                        const resultNode = getAnyImportSyntax(declaration) || declaration;
                        if (setVisibility) {
                            getNodeLinks(declaration).isVisible = true;
                        }
                        else {
                            result = result || [];
                            pushIfUnique(result, resultNode);
                        }
                        if (isInternalModuleImportEqualsDeclaration(declaration)) {
                            const internalModuleReference = declaration.moduleReference;
                            const firstIdentifier = getFirstIdentifier(internalModuleReference);
                            const importSymbol = resolveName(declaration, firstIdentifier.escapedText, 111551 /* Value */ | 788968 /* Type */ | 1920 /* Namespace */, 
                            /*nameNotFoundMessage*/
                            void 0, 
                            /*nameArg*/
                            void 0, 
                            /*isUse*/
                            false);
                            if (importSymbol && visited) {
                                if (tryAddToSet(visited, getSymbolId(importSymbol))) {
                                    buildVisibleNodeList(importSymbol.declarations);
                                }
                            }
                        }
                    });
                }
            }
            function pushTypeResolution(target, propertyName) {
                const resolutionCycleStartIndex = findResolutionCycleStartIndex(target, propertyName);
                if (resolutionCycleStartIndex >= 0) {
                    const { length: length2 } = resolutionTargets;
                    for (let i = resolutionCycleStartIndex; i < length2; i++) {
                        resolutionResults[i] = false;
                    }
                    return false;
                }
                resolutionTargets.push(target);
                resolutionResults.push(
                /*items*/
                true);
                resolutionPropertyNames.push(propertyName);
                return true;
            }
            function findResolutionCycleStartIndex(target, propertyName) {
                for (let i = resolutionTargets.length - 1; i >= resolutionStart; i--) {
                    if (resolutionTargetHasProperty(resolutionTargets[i], resolutionPropertyNames[i])) {
                        return -1;
                    }
                    if (resolutionTargets[i] === target && resolutionPropertyNames[i] === propertyName) {
                        return i;
                    }
                }
                return -1;
            }
            function resolutionTargetHasProperty(target, propertyName) {
                switch (propertyName) {
                    case 0 /* Type */:
                        return !!getSymbolLinks(target).type;
                    case 5 /* EnumTagType */:
                        return !!getNodeLinks(target).resolvedEnumType;
                    case 2 /* DeclaredType */:
                        return !!getSymbolLinks(target).declaredType;
                    case 1 /* ResolvedBaseConstructorType */:
                        return !!target.resolvedBaseConstructorType;
                    case 3 /* ResolvedReturnType */:
                        return !!target.resolvedReturnType;
                    case 4 /* ImmediateBaseConstraint */:
                        return !!target.immediateBaseConstraint;
                    case 6 /* ResolvedTypeArguments */:
                        return !!target.resolvedTypeArguments;
                    case 7 /* ResolvedBaseTypes */:
                        return !!target.baseTypesResolved;
                    case 8 /* WriteType */:
                        return !!getSymbolLinks(target).writeType;
                    case 9 /* ParameterInitializerContainsUndefined */:
                        return getNodeLinks(target).parameterInitializerContainsUndefined !== void 0;
                }
                return Debug.assertNever(propertyName);
            }
            function popTypeResolution() {
                resolutionTargets.pop();
                resolutionPropertyNames.pop();
                return resolutionResults.pop();
            }
            function getDeclarationContainer(node) {
                return findAncestor(getRootDeclaration(node), (node2) => {
                    switch (node2.kind) {
                        case 260 /* VariableDeclaration */:
                        case 261 /* VariableDeclarationList */:
                        case 276 /* ImportSpecifier */:
                        case 275 /* NamedImports */:
                        case 274 /* NamespaceImport */:
                        case 273 /* ImportClause */:
                            return false;
                        default:
                            return true;
                    }
                }).parent;
            }
            function getTypeOfPrototypeProperty(prototype) {
                const classType = getDeclaredTypeOfSymbol(getParentOfSymbol(prototype));
                return classType.typeParameters ? createTypeReference(classType, map(classType.typeParameters, (_) => anyType)) : classType;
            }
            function getTypeOfPropertyOfType(type, name) {
                const prop = getPropertyOfType(type, name);
                return prop ? getTypeOfSymbol(prop) : void 0;
            }
            function getTypeOfPropertyOrIndexSignatureOfType(type, name) {
                var _a;
                let propType;
                return getTypeOfPropertyOfType(type, name) || (propType = (_a = getApplicableIndexInfoForName(type, name)) == null ? void 0 : _a.type) && addOptionality(propType, 
                /*isProperty*/
                true, 
                /*isOptional*/
                true);
            }
            function isTypeAny(type) {
                return type && (type.flags & 1 /* Any */) !== 0;
            }
            function isErrorType(type) {
                return type === errorType || !!(type.flags & 1 /* Any */ && type.aliasSymbol);
            }
            function getTypeForBindingElementParent(node, checkMode) {
                if (checkMode !== 0 /* Normal */) {
                    return getTypeForVariableLikeDeclaration(node, 
                    /*includeOptionality*/
                    false, checkMode);
                }
                const symbol = getSymbolOfDeclaration(node);
                return symbol && getSymbolLinks(symbol).type || getTypeForVariableLikeDeclaration(node, 
                /*includeOptionality*/
                false, checkMode);
            }
            function getRestType(source, properties, symbol) {
                source = filterType(source, (t) => !(t.flags & 98304 /* Nullable */));
                if (source.flags & 131072 /* Never */) {
                    return emptyObjectType;
                }
                if (source.flags & 1048576 /* Union */) {
                    return mapType(source, (t) => getRestType(t, properties, symbol));
                }
                let omitKeyType = getUnionType(map(properties, getLiteralTypeFromPropertyName));
                const spreadableProperties = [];
                const unspreadableToRestKeys = [];
                for (const prop of getPropertiesOfType(source)) {
                    const literalTypeFromProperty = getLiteralTypeFromProperty(prop, 8576 /* StringOrNumberLiteralOrUnique */);
                    if (!isTypeAssignableTo(literalTypeFromProperty, omitKeyType) && !(getDeclarationModifierFlagsFromSymbol(prop) & (2 /* Private */ | 4 /* Protected */)) && isSpreadableProperty(prop)) {
                        spreadableProperties.push(prop);
                    }
                    else {
                        unspreadableToRestKeys.push(literalTypeFromProperty);
                    }
                }
                if (isGenericObjectType(source) || isGenericIndexType(omitKeyType)) {
                    if (unspreadableToRestKeys.length) {
                        omitKeyType = getUnionType([omitKeyType, ...unspreadableToRestKeys]);
                    }
                    if (omitKeyType.flags & 131072 /* Never */) {
                        return source;
                    }
                    const omitTypeAlias = getGlobalOmitSymbol();
                    if (!omitTypeAlias) {
                        return errorType;
                    }
                    return getTypeAliasInstantiation(omitTypeAlias, [source, omitKeyType]);
                }
                const members = createSymbolTable();
                for (const prop of spreadableProperties) {
                    members.set(prop.escapedName, getSpreadSymbol(prop, 
                    /*readonly*/
                    false));
                }
                const result = createAnonymousType(symbol, members, emptyArray, emptyArray, getIndexInfosOfType(source));
                result.objectFlags |= 4194304 /* ObjectRestType */;
                return result;
            }
            function isGenericTypeWithUndefinedConstraint(type) {
                return !!(type.flags & 465829888 /* Instantiable */) && maybeTypeOfKind(getBaseConstraintOfType(type) || unknownType, 32768 /* Undefined */);
            }
            function getNonUndefinedType(type) {
                const typeOrConstraint = someType(type, isGenericTypeWithUndefinedConstraint) ? mapType(type, (t) => t.flags & 465829888 /* Instantiable */ ? getBaseConstraintOrType(t) : t) : type;
                return getTypeWithFacts(typeOrConstraint, 524288 /* NEUndefined */);
            }
            function getFlowTypeOfDestructuring(node, declaredType) {
                const reference = getSyntheticElementAccess(node);
                return reference ? getFlowTypeOfReference(reference, declaredType) : declaredType;
            }
            function getSyntheticElementAccess(node) {
                const parentAccess = getParentElementAccess(node);
                if (parentAccess && canHaveFlowNode(parentAccess) && parentAccess.flowNode) {
                    const propName = getDestructuringPropertyName(node);
                    if (propName) {
                        const literal = setTextRange(parseNodeFactory.createStringLiteral(propName), node);
                        const lhsExpr = isLeftHandSideExpression(parentAccess) ? parentAccess : parseNodeFactory.createParenthesizedExpression(parentAccess);
                        const result = setTextRange(parseNodeFactory.createElementAccessExpression(lhsExpr, literal), node);
                        setParent(literal, result);
                        setParent(result, node);
                        if (lhsExpr !== parentAccess) {
                            setParent(lhsExpr, result);
                        }
                        result.flowNode = parentAccess.flowNode;
                        return result;
                    }
                }
            }
            function getParentElementAccess(node) {
                const ancestor = node.parent.parent;
                switch (ancestor.kind) {
                    case 208 /* BindingElement */:
                    case 303 /* PropertyAssignment */:
                        return getSyntheticElementAccess(ancestor);
                    case 209 /* ArrayLiteralExpression */:
                        return getSyntheticElementAccess(node.parent);
                    case 260 /* VariableDeclaration */:
                        return ancestor.initializer;
                    case 226 /* BinaryExpression */:
                        return ancestor.right;
                }
            }
            function getDestructuringPropertyName(node) {
                const parent2 = node.parent;
                if (node.kind === 208 /* BindingElement */ && parent2.kind === 206 /* ObjectBindingPattern */) {
                    return getLiteralPropertyNameText(node.propertyName || node.name);
                }
                if (node.kind === 303 /* PropertyAssignment */ || node.kind === 304 /* ShorthandPropertyAssignment */) {
                    return getLiteralPropertyNameText(node.name);
                }
                return "" + parent2.elements.indexOf(node);
            }
            function getLiteralPropertyNameText(name) {
                const type = getLiteralTypeFromPropertyName(name);
                return type.flags & (128 /* StringLiteral */ | 256 /* NumberLiteral */) ? "" + type.value : void 0;
            }
            function getTypeForBindingElement(declaration) {
                const checkMode = declaration.dotDotDotToken ? 32 /* RestBindingElement */ : 0 /* Normal */;
                const parentType = getTypeForBindingElementParent(declaration.parent.parent, checkMode);
                return parentType && getBindingElementTypeFromParentType(declaration, parentType, 
                /*noTupleBoundsCheck*/
                false);
            }
            function getBindingElementTypeFromParentType(declaration, parentType, noTupleBoundsCheck) {
                if (isTypeAny(parentType)) {
                    return parentType;
                }
                const pattern = declaration.parent;
                if (strictNullChecks && declaration.flags & 33554432 /* Ambient */ && isParameterDeclaration(declaration)) {
                    parentType = getNonNullableType(parentType);
                }
                else if (strictNullChecks && pattern.parent.initializer && !hasTypeFacts(getTypeOfInitializer(pattern.parent.initializer), 65536 /* EQUndefined */)) {
                    parentType = getTypeWithFacts(parentType, 524288 /* NEUndefined */);
                }
                let type;
                if (pattern.kind === 206 /* ObjectBindingPattern */) {
                    if (declaration.dotDotDotToken) {
                        parentType = getReducedType(parentType);
                        if (parentType.flags & 2 /* Unknown */ || !isValidSpreadType(parentType)) {
                            error2(declaration, Diagnostics.Rest_types_may_only_be_created_from_object_types);
                            return errorType;
                        }
                        const literalMembers = [];
                        for (const element of pattern.elements) {
                            if (!element.dotDotDotToken) {
                                literalMembers.push(element.propertyName || element.name);
                            }
                        }
                        type = getRestType(parentType, literalMembers, declaration.symbol);
                    }
                    else {
                        const name = declaration.propertyName || declaration.name;
                        const indexType = getLiteralTypeFromPropertyName(name);
                        const declaredType = getIndexedAccessType(parentType, indexType, 32 /* ExpressionPosition */, name);
                        type = getFlowTypeOfDestructuring(declaration, declaredType);
                    }
                }
                else {
                    const elementType = checkIteratedTypeOrElementType(65 /* Destructuring */ | (declaration.dotDotDotToken ? 0 : 128 /* PossiblyOutOfBounds */), parentType, undefinedType, pattern);
                    const index = pattern.elements.indexOf(declaration);
                    if (declaration.dotDotDotToken) {
                        const baseConstraint = mapType(parentType, (t) => t.flags & 58982400 /* InstantiableNonPrimitive */ ? getBaseConstraintOrType(t) : t);
                        type = everyType(baseConstraint, isTupleType) ? mapType(baseConstraint, (t) => sliceTupleType(t, index)) : createArrayType(elementType);
                    }
                    else if (isArrayLikeType(parentType)) {
                        const indexType = getNumberLiteralType(index);
                        const accessFlags = 32 /* ExpressionPosition */ | (noTupleBoundsCheck || hasDefaultValue(declaration) ? 16 /* NoTupleBoundsCheck */ : 0);
                        const declaredType = getIndexedAccessTypeOrUndefined(parentType, indexType, accessFlags, declaration.name) || errorType;
                        type = getFlowTypeOfDestructuring(declaration, declaredType);
                    }
                    else {
                        type = elementType;
                    }
                }
                if (!declaration.initializer) {
                    return type;
                }
                if (getEffectiveTypeAnnotationNode(walkUpBindingElementsAndPatterns(declaration))) {
                    return strictNullChecks && !hasTypeFacts(checkDeclarationInitializer(declaration, 0 /* Normal */), 16777216 /* IsUndefined */) ? getNonUndefinedType(type) : type;
                }
                return widenTypeInferredFromInitializer(declaration, getUnionType([getNonUndefinedType(type), checkDeclarationInitializer(declaration, 0 /* Normal */)], 2 /* Subtype */));
            }
            function getTypeForDeclarationFromJSDocComment(declaration) {
                const jsdocType = getJSDocType(declaration);
                if (jsdocType) {
                    return getTypeFromTypeNode(jsdocType);
                }
                return void 0;
            }
            function isNullOrUndefined3(node) {
                const expr = skipParentheses(node, 
                /*excludeJSDocTypeAssertions*/
                true);
                return expr.kind === 106 /* NullKeyword */ || expr.kind === 80 /* Identifier */ && getResolvedSymbol(expr) === undefinedSymbol;
            }
            function isEmptyArrayLiteral2(node) {
                const expr = skipParentheses(node, 
                /*excludeJSDocTypeAssertions*/
                true);
                return expr.kind === 209 /* ArrayLiteralExpression */ && expr.elements.length === 0;
            }
            function addOptionality(type, isProperty = false, isOptional = true) {
                return strictNullChecks && isOptional ? getOptionalType(type, isProperty) : type;
            }
            function getTypeForVariableLikeDeclaration(declaration, includeOptionality, checkMode) {
                if (isVariableDeclaration(declaration) && declaration.parent.parent.kind === 249 /* ForInStatement */) {
                    const indexType = getIndexType(getNonNullableTypeIfNeeded(checkExpression(declaration.parent.parent.expression, 
                    /*checkMode*/
                    checkMode)));
                    return indexType.flags & (262144 /* TypeParameter */ | 4194304 /* Index */) ? getExtractStringType(indexType) : stringType;
                }
                if (isVariableDeclaration(declaration) && declaration.parent.parent.kind === 250 /* ForOfStatement */) {
                    const forOfStatement = declaration.parent.parent;
                    return checkRightHandSideOfForOf(forOfStatement) || anyType;
                }
                if (isBindingPattern(declaration.parent)) {
                    return getTypeForBindingElement(declaration);
                }
                const isProperty = isPropertyDeclaration(declaration) && !hasAccessorModifier(declaration) || isPropertySignature(declaration) || isJSDocPropertyTag(declaration);
                const isOptional = includeOptionality && isOptionalDeclaration(declaration);
                const declaredType = tryGetTypeFromEffectiveTypeNode(declaration);
                if (isCatchClauseVariableDeclarationOrBindingElement(declaration)) {
                    if (declaredType) {
                        return isTypeAny(declaredType) || declaredType === unknownType ? declaredType : errorType;
                    }
                    return useUnknownInCatchVariables ? unknownType : anyType;
                }
                if (declaredType) {
                    return addOptionality(declaredType, isProperty, isOptional);
                }
                if ((noImplicitAny || isInJSFile(declaration)) && isVariableDeclaration(declaration) && !isBindingPattern(declaration.name) && !(getCombinedModifierFlagsCached(declaration) & 32 /* Export */) && !(declaration.flags & 33554432 /* Ambient */)) {
                    if (!(getCombinedNodeFlagsCached(declaration) & 6 /* Constant */) && (!declaration.initializer || isNullOrUndefined3(declaration.initializer))) {
                        return autoType;
                    }
                    if (declaration.initializer && isEmptyArrayLiteral2(declaration.initializer)) {
                        return autoArrayType;
                    }
                }
                if (isParameter(declaration)) {
                    const func = declaration.parent;
                    if (func.kind === 178 /* SetAccessor */ && hasBindableName(func)) {
                        const getter = getDeclarationOfKind(getSymbolOfDeclaration(declaration.parent), 177 /* GetAccessor */);
                        if (getter) {
                            const getterSignature = getSignatureFromDeclaration(getter);
                            const thisParameter = getAccessorThisParameter(func);
                            if (thisParameter && declaration === thisParameter) {
                                Debug.assert(!thisParameter.type);
                                return getTypeOfSymbol(getterSignature.thisParameter);
                            }
                            return getReturnTypeOfSignature(getterSignature);
                        }
                    }
                    const parameterTypeOfTypeTag = getParameterTypeOfTypeTag(func, declaration);
                    if (parameterTypeOfTypeTag)
                        return parameterTypeOfTypeTag;
                    const type = declaration.symbol.escapedName === "this" /* This */ ? getContextualThisParameterType(func) : getContextuallyTypedParameterType(declaration);
                    if (type) {
                        return addOptionality(type, 
                        /*isProperty*/
                        false, isOptional);
                    }
                }
                if (hasOnlyExpressionInitializer(declaration) && !!declaration.initializer) {
                    if (isInJSFile(declaration) && !isParameter(declaration)) {
                        const containerObjectType = getJSContainerObjectType(declaration, getSymbolOfDeclaration(declaration), getDeclaredExpandoInitializer(declaration));
                        if (containerObjectType) {
                            return containerObjectType;
                        }
                    }
                    const type = widenTypeInferredFromInitializer(declaration, checkDeclarationInitializer(declaration, checkMode));
                    return addOptionality(type, isProperty, isOptional);
                }
                if (isPropertyDeclaration(declaration) && (noImplicitAny || isInJSFile(declaration))) {
                    if (!hasStaticModifier(declaration)) {
                        const constructor = findConstructorDeclaration(declaration.parent);
                        const type = constructor ? getFlowTypeInConstructor(declaration.symbol, constructor) : getEffectiveModifierFlags(declaration) & 128 /* Ambient */ ? getTypeOfPropertyInBaseClass(declaration.symbol) : void 0;
                        return type && addOptionality(type, 
                        /*isProperty*/
                        true, isOptional);
                    }
                    else {
                        const staticBlocks = filter(declaration.parent.members, isClassStaticBlockDeclaration);
                        const type = staticBlocks.length ? getFlowTypeInStaticBlocks(declaration.symbol, staticBlocks) : getEffectiveModifierFlags(declaration) & 128 /* Ambient */ ? getTypeOfPropertyInBaseClass(declaration.symbol) : void 0;
                        return type && addOptionality(type, 
                        /*isProperty*/
                        true, isOptional);
                    }
                }
                if (isJsxAttribute(declaration)) {
                    return trueType;
                }
                if (isBindingPattern(declaration.name)) {
                    return getTypeFromBindingPattern(declaration.name, 
                    /*includePatternInType*/
                    false, 
                    /*reportErrors*/
                    true);
                }
                return void 0;
            }
            function isConstructorDeclaredProperty(symbol) {
                if (symbol.valueDeclaration && isBinaryExpression(symbol.valueDeclaration)) {
                    const links = getSymbolLinks(symbol);
                    if (links.isConstructorDeclaredProperty === void 0) {
                        links.isConstructorDeclaredProperty = false;
                        links.isConstructorDeclaredProperty = !!getDeclaringConstructor(symbol) && every(symbol.declarations, (declaration) => isBinaryExpression(declaration) && isPossiblyAliasedThisProperty(declaration) && (declaration.left.kind !== 212 /* ElementAccessExpression */ || isStringOrNumericLiteralLike(declaration.left.argumentExpression)) && !getAnnotatedTypeForAssignmentDeclaration(
                        /*declaredType*/
                        void 0, declaration, symbol, declaration));
                    }
                    return links.isConstructorDeclaredProperty;
                }
                return false;
            }
            function isAutoTypedProperty(symbol) {
                const declaration = symbol.valueDeclaration;
                return declaration && isPropertyDeclaration(declaration) && !getEffectiveTypeAnnotationNode(declaration) && !declaration.initializer && (noImplicitAny || isInJSFile(declaration));
            }
            function getDeclaringConstructor(symbol) {
                if (!symbol.declarations) {
                    return;
                }
                for (const declaration of symbol.declarations) {
                    const container = getThisContainer(declaration, 
                    /*includeArrowFunctions*/
                    false, 
                    /*includeClassComputedPropertyName*/
                    false);
                    if (container && (container.kind === 176 /* Constructor */ || isJSConstructor(container))) {
                        return container;
                    }
                }
            }
            function getFlowTypeFromCommonJSExport(symbol) {
                const file = getSourceFileOfNode(symbol.declarations[0]);
                const accessName = unescapeLeadingUnderscores(symbol.escapedName);
                const areAllModuleExports = symbol.declarations.every((d) => isInJSFile(d) && isAccessExpression(d) && isModuleExportsAccessExpression(d.expression));
                const reference = areAllModuleExports ? factory.createPropertyAccessExpression(factory.createPropertyAccessExpression(factory.createIdentifier("module"), factory.createIdentifier("exports")), accessName) : factory.createPropertyAccessExpression(factory.createIdentifier("exports"), accessName);
                if (areAllModuleExports) {
                    setParent(reference.expression.expression, reference.expression);
                }
                setParent(reference.expression, reference);
                setParent(reference, file);
                reference.flowNode = file.endFlowNode;
                return getFlowTypeOfReference(reference, autoType, undefinedType);
            }
            function getFlowTypeInStaticBlocks(symbol, staticBlocks) {
                const accessName = startsWith(symbol.escapedName, "__#") ? factory.createPrivateIdentifier(symbol.escapedName.split("@")[1]) : unescapeLeadingUnderscores(symbol.escapedName);
                for (const staticBlock of staticBlocks) {
                    const reference = factory.createPropertyAccessExpression(factory.createThis(), accessName);
                    setParent(reference.expression, reference);
                    setParent(reference, staticBlock);
                    reference.flowNode = staticBlock.returnFlowNode;
                    const flowType = getFlowTypeOfProperty(reference, symbol);
                    if (noImplicitAny && (flowType === autoType || flowType === autoArrayType)) {
                        error2(symbol.valueDeclaration, Diagnostics.Member_0_implicitly_has_an_1_type, symbolToString(symbol), typeToString(flowType));
                    }
                    if (everyType(flowType, isNullableType)) {
                        continue;
                    }
                    return convertAutoToAny(flowType);
                }
            }
            function getFlowTypeInConstructor(symbol, constructor) {
                const accessName = startsWith(symbol.escapedName, "__#") ? factory.createPrivateIdentifier(symbol.escapedName.split("@")[1]) : unescapeLeadingUnderscores(symbol.escapedName);
                const reference = factory.createPropertyAccessExpression(factory.createThis(), accessName);
                setParent(reference.expression, reference);
                setParent(reference, constructor);
                reference.flowNode = constructor.returnFlowNode;
                const flowType = getFlowTypeOfProperty(reference, symbol);
                if (noImplicitAny && (flowType === autoType || flowType === autoArrayType)) {
                    error2(symbol.valueDeclaration, Diagnostics.Member_0_implicitly_has_an_1_type, symbolToString(symbol), typeToString(flowType));
                }
                return everyType(flowType, isNullableType) ? void 0 : convertAutoToAny(flowType);
            }
            function getFlowTypeOfProperty(reference, prop) {
                const initialType = (prop == null ? void 0 : prop.valueDeclaration) && (!isAutoTypedProperty(prop) || getEffectiveModifierFlags(prop.valueDeclaration) & 128 /* Ambient */) && getTypeOfPropertyInBaseClass(prop) || undefinedType;
                return getFlowTypeOfReference(reference, autoType, initialType);
            }
            function getWidenedTypeForAssignmentDeclaration(symbol, resolvedSymbol) {
                const container = getAssignedExpandoInitializer(symbol.valueDeclaration);
                if (container) {
                    const tag = isInJSFile(container) ? getJSDocTypeTag(container) : void 0;
                    if (tag && tag.typeExpression) {
                        return getTypeFromTypeNode(tag.typeExpression);
                    }
                    const containerObjectType = symbol.valueDeclaration && getJSContainerObjectType(symbol.valueDeclaration, symbol, container);
                    return containerObjectType || getWidenedLiteralType(checkExpressionCached(container));
                }
                let type;
                let definedInConstructor = false;
                let definedInMethod = false;
                if (isConstructorDeclaredProperty(symbol)) {
                    type = getFlowTypeInConstructor(symbol, getDeclaringConstructor(symbol));
                }
                if (!type) {
                    let types;
                    if (symbol.declarations) {
                        let jsdocType;
                        for (const declaration of symbol.declarations) {
                            const expression = isBinaryExpression(declaration) || isCallExpression(declaration) ? declaration : isAccessExpression(declaration) ? isBinaryExpression(declaration.parent) ? declaration.parent : declaration : void 0;
                            if (!expression) {
                                continue;
                            }
                            const kind = isAccessExpression(expression) ? getAssignmentDeclarationPropertyAccessKind(expression) : getAssignmentDeclarationKind(expression);
                            if (kind === 4 /* ThisProperty */ || isBinaryExpression(expression) && isPossiblyAliasedThisProperty(expression, kind)) {
                                if (isDeclarationInConstructor(expression)) {
                                    definedInConstructor = true;
                                }
                                else {
                                    definedInMethod = true;
                                }
                            }
                            if (!isCallExpression(expression)) {
                                jsdocType = getAnnotatedTypeForAssignmentDeclaration(jsdocType, expression, symbol, declaration);
                            }
                            if (!jsdocType) {
                                (types || (types = [])).push(isBinaryExpression(expression) || isCallExpression(expression) ? getInitializerTypeFromAssignmentDeclaration(symbol, resolvedSymbol, expression, kind) : neverType);
                            }
                        }
                        type = jsdocType;
                    }
                    if (!type) {
                        if (!length(types)) {
                            return errorType;
                        }
                        let constructorTypes = definedInConstructor && symbol.declarations ? getConstructorDefinedThisAssignmentTypes(types, symbol.declarations) : void 0;
                        if (definedInMethod) {
                            const propType = getTypeOfPropertyInBaseClass(symbol);
                            if (propType) {
                                (constructorTypes || (constructorTypes = [])).push(propType);
                                definedInConstructor = true;
                            }
                        }
                        const sourceTypes = some(constructorTypes, (t) => !!(t.flags & ~98304 /* Nullable */)) ? constructorTypes : types;
                        type = getUnionType(sourceTypes);
                    }
                }
                const widened = getWidenedType(addOptionality(type, 
                /*isProperty*/
                false, definedInMethod && !definedInConstructor));
                if (symbol.valueDeclaration && isInJSFile(symbol.valueDeclaration) && filterType(widened, (t) => !!(t.flags & ~98304 /* Nullable */)) === neverType) {
                    reportImplicitAny(symbol.valueDeclaration, anyType);
                    return anyType;
                }
                return widened;
            }
            function getJSContainerObjectType(decl, symbol, init) {
                var _a, _b;
                if (!isInJSFile(decl) || !init || !isObjectLiteralExpression(init) || init.properties.length) {
                    return void 0;
                }
                const exports = createSymbolTable();
                while (isBinaryExpression(decl) || isPropertyAccessExpression(decl)) {
                    const s2 = getSymbolOfNode(decl);
                    if ((_a = s2 == null ? void 0 : s2.exports) == null ? void 0 : _a.size) {
                        mergeSymbolTable(exports, s2.exports);
                    }
                    decl = isBinaryExpression(decl) ? decl.parent : decl.parent.parent;
                }
                const s = getSymbolOfNode(decl);
                if ((_b = s == null ? void 0 : s.exports) == null ? void 0 : _b.size) {
                    mergeSymbolTable(exports, s.exports);
                }
                const type = createAnonymousType(symbol, exports, emptyArray, emptyArray, emptyArray);
                type.objectFlags |= 4096 /* JSLiteral */;
                return type;
            }
            function getAnnotatedTypeForAssignmentDeclaration(declaredType, expression, symbol, declaration) {
                var _a;
                const typeNode = getEffectiveTypeAnnotationNode(expression.parent);
                if (typeNode) {
                    const type = getWidenedType(getTypeFromTypeNode(typeNode));
                    if (!declaredType) {
                        return type;
                    }
                    else if (!isErrorType(declaredType) && !isErrorType(type) && !isTypeIdenticalTo(declaredType, type)) {
                        errorNextVariableOrPropertyDeclarationMustHaveSameType(
                        /*firstDeclaration*/
                        void 0, declaredType, declaration, type);
                    }
                }
                if ((_a = symbol.parent) == null ? void 0 : _a.valueDeclaration) {
                    const possiblyAnnotatedSymbol = getFunctionExpressionParentSymbolOrSymbol(symbol.parent);
                    if (possiblyAnnotatedSymbol.valueDeclaration) {
                        const typeNode2 = getEffectiveTypeAnnotationNode(possiblyAnnotatedSymbol.valueDeclaration);
                        if (typeNode2) {
                            const annotationSymbol = getPropertyOfType(getTypeFromTypeNode(typeNode2), symbol.escapedName);
                            if (annotationSymbol) {
                                return getNonMissingTypeOfSymbol(annotationSymbol);
                            }
                        }
                    }
                }
                return declaredType;
            }
            function getInitializerTypeFromAssignmentDeclaration(symbol, resolvedSymbol, expression, kind) {
                if (isCallExpression(expression)) {
                    if (resolvedSymbol) {
                        return getTypeOfSymbol(resolvedSymbol);
                    }
                    const objectLitType = checkExpressionCached(expression.arguments[2]);
                    const valueType = getTypeOfPropertyOfType(objectLitType, "value");
                    if (valueType) {
                        return valueType;
                    }
                    const getFunc = getTypeOfPropertyOfType(objectLitType, "get");
                    if (getFunc) {
                        const getSig = getSingleCallSignature(getFunc);
                        if (getSig) {
                            return getReturnTypeOfSignature(getSig);
                        }
                    }
                    const setFunc = getTypeOfPropertyOfType(objectLitType, "set");
                    if (setFunc) {
                        const setSig = getSingleCallSignature(setFunc);
                        if (setSig) {
                            return getTypeOfFirstParameterOfSignature(setSig);
                        }
                    }
                    return anyType;
                }
                if (containsSameNamedThisProperty(expression.left, expression.right)) {
                    return anyType;
                }
                const isDirectExport = kind === 1 /* ExportsProperty */ && (isPropertyAccessExpression(expression.left) || isElementAccessExpression(expression.left)) && (isModuleExportsAccessExpression(expression.left.expression) || isIdentifier(expression.left.expression) && isExportsIdentifier(expression.left.expression));
                const type = resolvedSymbol ? getTypeOfSymbol(resolvedSymbol) : isDirectExport ? getRegularTypeOfLiteralType(checkExpressionCached(expression.right)) : getWidenedLiteralType(checkExpressionCached(expression.right));
                if (type.flags & 524288 /* Object */ && kind === 2 /* ModuleExports */ && symbol.escapedName === "export=" /* ExportEquals */) {
                    const exportedType = resolveStructuredTypeMembers(type);
                    const members = createSymbolTable();
                    copyEntries(exportedType.members, members);
                    const initialSize = members.size;
                    if (resolvedSymbol && !resolvedSymbol.exports) {
                        resolvedSymbol.exports = createSymbolTable();
                    }
                    (resolvedSymbol || symbol).exports.forEach((s, name) => {
                        var _a;
                        const exportedMember = members.get(name);
                        if (exportedMember && exportedMember !== s && !(s.flags & 2097152 /* Alias */)) {
                            if (s.flags & 111551 /* Value */ && exportedMember.flags & 111551 /* Value */) {
                                if (s.valueDeclaration && exportedMember.valueDeclaration && getSourceFileOfNode(s.valueDeclaration) !== getSourceFileOfNode(exportedMember.valueDeclaration)) {
                                    const unescapedName = unescapeLeadingUnderscores(s.escapedName);
                                    const exportedMemberName = ((_a = tryCast(exportedMember.valueDeclaration, isNamedDeclaration)) == null ? void 0 : _a.name) || exportedMember.valueDeclaration;
                                    addRelatedInfo(error2(s.valueDeclaration, Diagnostics.Duplicate_identifier_0, unescapedName), createDiagnosticForNode(exportedMemberName, Diagnostics._0_was_also_declared_here, unescapedName));
                                    addRelatedInfo(error2(exportedMemberName, Diagnostics.Duplicate_identifier_0, unescapedName), createDiagnosticForNode(s.valueDeclaration, Diagnostics._0_was_also_declared_here, unescapedName));
                                }
                                const union = createSymbol(s.flags | exportedMember.flags, name);
                                union.links.type = getUnionType([getTypeOfSymbol(s), getTypeOfSymbol(exportedMember)]);
                                union.valueDeclaration = exportedMember.valueDeclaration;
                                union.declarations = concatenate(exportedMember.declarations, s.declarations);
                                members.set(name, union);
                            }
                            else {
                                members.set(name, mergeSymbol(s, exportedMember));
                            }
                        }
                        else {
                            members.set(name, s);
                        }
                    });
                    const result = createAnonymousType(initialSize !== members.size ? void 0 : exportedType.symbol, 
                    // Only set the type's symbol if it looks to be the same as the original type
                    members, exportedType.callSignatures, exportedType.constructSignatures, exportedType.indexInfos);
                    if (initialSize === members.size) {
                        if (type.aliasSymbol) {
                            result.aliasSymbol = type.aliasSymbol;
                            result.aliasTypeArguments = type.aliasTypeArguments;
                        }
                        if (getObjectFlags(type) & 4 /* Reference */) {
                            result.aliasSymbol = type.symbol;
                            const args = getTypeArguments(type);
                            result.aliasTypeArguments = length(args) ? args : void 0;
                        }
                    }
                    result.objectFlags |= getObjectFlags(type) & 4096 /* JSLiteral */;
                    if (result.symbol && result.symbol.flags & 32 /* Class */ && type === getDeclaredTypeOfClassOrInterface(result.symbol)) {
                        result.objectFlags |= 16777216 /* IsClassInstanceClone */;
                    }
                    return result;
                }
                if (isEmptyArrayLiteralType(type)) {
                    reportImplicitAny(expression, anyArrayType);
                    return anyArrayType;
                }
                return type;
            }
            function containsSameNamedThisProperty(thisProperty, expression) {
                return isPropertyAccessExpression(thisProperty) && thisProperty.expression.kind === 110 /* ThisKeyword */ && forEachChildRecursively(expression, (n) => isMatchingReference(thisProperty, n));
            }
            function isDeclarationInConstructor(expression) {
                const thisContainer = getThisContainer(expression, 
                /*includeArrowFunctions*/
                false, 
                /*includeClassComputedPropertyName*/
                false);
                return thisContainer.kind === 176 /* Constructor */ || thisContainer.kind === 262 /* FunctionDeclaration */ || thisContainer.kind === 218 /* FunctionExpression */ && !isPrototypePropertyAssignment(thisContainer.parent);
            }
            function getConstructorDefinedThisAssignmentTypes(types, declarations) {
                Debug.assert(types.length === declarations.length);
                return types.filter((_, i) => {
                    const declaration = declarations[i];
                    const expression = isBinaryExpression(declaration) ? declaration : isBinaryExpression(declaration.parent) ? declaration.parent : void 0;
                    return expression && isDeclarationInConstructor(expression);
                });
            }
            function getTypeFromBindingElement(element, includePatternInType, reportErrors2) {
                if (element.initializer) {
                    const contextualType = isBindingPattern(element.name) ? getTypeFromBindingPattern(element.name, 
                    /*includePatternInType*/
                    true, 
                    /*reportErrors*/
                    false) : unknownType;
                    return addOptionality(widenTypeInferredFromInitializer(element, checkDeclarationInitializer(element, reportErrors2 ? 0 /* Normal */ : 1 /* Contextual */, contextualType)));
                }
                if (isBindingPattern(element.name)) {
                    return getTypeFromBindingPattern(element.name, includePatternInType, reportErrors2);
                }
                if (reportErrors2 && !declarationBelongsToPrivateAmbientMember(element)) {
                    reportImplicitAny(element, anyType);
                }
                return includePatternInType ? nonInferrableAnyType : anyType;
            }
            function getTypeFromObjectBindingPattern(pattern, includePatternInType, reportErrors2) {
                const members = createSymbolTable();
                let stringIndexInfo;
                let objectFlags = 128 /* ObjectLiteral */ | 131072 /* ContainsObjectOrArrayLiteral */;
                forEach(pattern.elements, (e) => {
                    const name = e.propertyName || e.name;
                    if (e.dotDotDotToken) {
                        stringIndexInfo = createIndexInfo(stringType, anyType, 
                        /*isReadonly*/
                        false);
                        return;
                    }
                    const exprType = getLiteralTypeFromPropertyName(name);
                    if (!isTypeUsableAsPropertyName(exprType)) {
                        objectFlags |= 512 /* ObjectLiteralPatternWithComputedProperties */;
                        return;
                    }
                    const text = getPropertyNameFromType(exprType);
                    const flags = 4 /* Property */ | (e.initializer ? 16777216 /* Optional */ : 0);
                    const symbol = createSymbol(flags, text);
                    symbol.links.type = getTypeFromBindingElement(e, includePatternInType, reportErrors2);
                    symbol.links.bindingElement = e;
                    members.set(symbol.escapedName, symbol);
                });
                const result = createAnonymousType(
                /*symbol*/
                void 0, members, emptyArray, emptyArray, stringIndexInfo ? [stringIndexInfo] : emptyArray);
                result.objectFlags |= objectFlags;
                if (includePatternInType) {
                    result.pattern = pattern;
                    result.objectFlags |= 131072 /* ContainsObjectOrArrayLiteral */;
                }
                return result;
            }
            function getTypeFromArrayBindingPattern(pattern, includePatternInType, reportErrors2) {
                const elements = pattern.elements;
                const lastElement = lastOrUndefined(elements);
                const restElement = lastElement && lastElement.kind === 208 /* BindingElement */ && lastElement.dotDotDotToken ? lastElement : void 0;
                if (elements.length === 0 || elements.length === 1 && restElement) {
                    return languageVersion >= 2 /* ES2015 */ ? createIterableType(anyType) : anyArrayType;
                }
                const elementTypes = map(elements, (e) => isOmittedExpression(e) ? anyType : getTypeFromBindingElement(e, includePatternInType, reportErrors2));
                const minLength = findLastIndex(elements, (e) => !(e === restElement || isOmittedExpression(e) || hasDefaultValue(e)), elements.length - 1) + 1;
                const elementFlags = map(elements, (e, i) => e === restElement ? 4 /* Rest */ : i >= minLength ? 2 /* Optional */ : 1 /* Required */);
                let result = createTupleType(elementTypes, elementFlags);
                if (includePatternInType) {
                    result = cloneTypeReference(result);
                    result.pattern = pattern;
                    result.objectFlags |= 131072 /* ContainsObjectOrArrayLiteral */;
                }
                return result;
            }
            function getTypeFromBindingPattern(pattern, includePatternInType = false, reportErrors2 = false) {
                return pattern.kind === 206 /* ObjectBindingPattern */ ? getTypeFromObjectBindingPattern(pattern, includePatternInType, reportErrors2) : getTypeFromArrayBindingPattern(pattern, includePatternInType, reportErrors2);
            }
            function getWidenedTypeForVariableLikeDeclaration(declaration, reportErrors2) {
                return widenTypeForVariableLikeDeclaration(getTypeForVariableLikeDeclaration(declaration, 
                /*includeOptionality*/
                true, 0 /* Normal */), declaration, reportErrors2);
            }
            function getTypeFromImportAttributes(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    const symbol = createSymbol(4096 /* ObjectLiteral */, "__importAttributes" /* ImportAttributes */);
                    const members = createSymbolTable();
                    forEach(node.elements, (attr) => {
                        const member = createSymbol(4 /* Property */, getNameFromImportAttribute(attr));
                        member.parent = symbol;
                        member.links.type = checkImportAttribute(attr);
                        member.links.target = member;
                        members.set(member.escapedName, member);
                    });
                    const type = createAnonymousType(symbol, members, emptyArray, emptyArray, emptyArray);
                    type.objectFlags |= 128 /* ObjectLiteral */ | 262144 /* NonInferrableType */;
                    links.resolvedType = type;
                }
                return links.resolvedType;
            }
            function isGlobalSymbolConstructor(node) {
                const symbol = getSymbolOfNode(node);
                const globalSymbol = getGlobalESSymbolConstructorTypeSymbol(
                /*reportErrors*/
                false);
                return globalSymbol && symbol && symbol === globalSymbol;
            }
            function widenTypeForVariableLikeDeclaration(type, declaration, reportErrors2) {
                if (type) {
                    if (type.flags & 4096 /* ESSymbol */ && isGlobalSymbolConstructor(declaration.parent)) {
                        type = getESSymbolLikeTypeForNode(declaration);
                    }
                    if (reportErrors2) {
                        reportErrorsFromWidening(declaration, type);
                    }
                    if (type.flags & 8192 /* UniqueESSymbol */ && (isBindingElement(declaration) || !declaration.type) && type.symbol !== getSymbolOfDeclaration(declaration)) {
                        type = esSymbolType;
                    }
                    return getWidenedType(type);
                }
                type = isParameter(declaration) && declaration.dotDotDotToken ? anyArrayType : anyType;
                if (reportErrors2) {
                    if (!declarationBelongsToPrivateAmbientMember(declaration)) {
                        reportImplicitAny(declaration, type);
                    }
                }
                return type;
            }
            function declarationBelongsToPrivateAmbientMember(declaration) {
                const root = getRootDeclaration(declaration);
                const memberDeclaration = root.kind === 169 /* Parameter */ ? root.parent : root;
                return isPrivateWithinAmbient(memberDeclaration);
            }
            function tryGetTypeFromEffectiveTypeNode(node) {
                const typeNode = getEffectiveTypeAnnotationNode(node);
                if (typeNode) {
                    return getTypeFromTypeNode(typeNode);
                }
            }
            function isParameterOfContextSensitiveSignature(symbol) {
                let decl = symbol.valueDeclaration;
                if (!decl) {
                    return false;
                }
                if (isBindingElement(decl)) {
                    decl = walkUpBindingElementsAndPatterns(decl);
                }
                if (isParameter(decl)) {
                    return isContextSensitiveFunctionOrObjectLiteralMethod(decl.parent);
                }
                return false;
            }
            function getTypeOfVariableOrParameterOrProperty(symbol, checkMode) {
                const links = getSymbolLinks(symbol);
                if (!links.type) {
                    const type = getTypeOfVariableOrParameterOrPropertyWorker(symbol, checkMode);
                    if (!links.type && !isParameterOfContextSensitiveSignature(symbol) && !checkMode) {
                        links.type = type;
                    }
                    return type;
                }
                return links.type;
            }
            function getTypeOfVariableOrParameterOrPropertyWorker(symbol, checkMode) {
                if (symbol.flags & 4194304 /* Prototype */) {
                    return getTypeOfPrototypeProperty(symbol);
                }
                if (symbol === requireSymbol) {
                    return anyType;
                }
                if (symbol.flags & 134217728 /* ModuleExports */ && symbol.valueDeclaration) {
                    const fileSymbol = getSymbolOfDeclaration(getSourceFileOfNode(symbol.valueDeclaration));
                    const result = createSymbol(fileSymbol.flags, "exports");
                    result.declarations = fileSymbol.declarations ? fileSymbol.declarations.slice() : [];
                    result.parent = symbol;
                    result.links.target = fileSymbol;
                    if (fileSymbol.valueDeclaration)
                        result.valueDeclaration = fileSymbol.valueDeclaration;
                    if (fileSymbol.members)
                        result.members = new Map(fileSymbol.members);
                    if (fileSymbol.exports)
                        result.exports = new Map(fileSymbol.exports);
                    const members = createSymbolTable();
                    members.set("exports", result);
                    return createAnonymousType(symbol, members, emptyArray, emptyArray, emptyArray);
                }
                Debug.assertIsDefined(symbol.valueDeclaration);
                const declaration = symbol.valueDeclaration;
                if (isSourceFile(declaration) && isJsonSourceFile(declaration)) {
                    if (!declaration.statements.length) {
                        return emptyObjectType;
                    }
                    return getWidenedType(getWidenedLiteralType(checkExpression(declaration.statements[0].expression)));
                }
                if (isAccessor(declaration)) {
                    return getTypeOfAccessors(symbol);
                }
                if (!pushTypeResolution(symbol, 0 /* Type */)) {
                    if (symbol.flags & 512 /* ValueModule */ && !(symbol.flags & 67108864 /* Assignment */)) {
                        return getTypeOfFuncClassEnumModule(symbol);
                    }
                    if (isBindingElement(declaration) && checkMode === 1 /* Contextual */) {
                        return errorType;
                    }
                    return reportCircularityError(symbol);
                }
                let type;
                if (declaration.kind === 277 /* ExportAssignment */) {
                    type = widenTypeForVariableLikeDeclaration(tryGetTypeFromEffectiveTypeNode(declaration) || checkExpressionCached(declaration.expression), declaration);
                }
                else if (isBinaryExpression(declaration) || isInJSFile(declaration) && (isCallExpression(declaration) || (isPropertyAccessExpression(declaration) || isBindableStaticElementAccessExpression(declaration)) && isBinaryExpression(declaration.parent))) {
                    type = getWidenedTypeForAssignmentDeclaration(symbol);
                }
                else if (isPropertyAccessExpression(declaration) || isElementAccessExpression(declaration) || isIdentifier(declaration) || isStringLiteralLike(declaration) || isNumericLiteral(declaration) || isClassDeclaration(declaration) || isFunctionDeclaration(declaration) || isMethodDeclaration(declaration) && !isObjectLiteralMethod(declaration) || isMethodSignature(declaration) || isSourceFile(declaration)) {
                    if (symbol.flags & (16 /* Function */ | 8192 /* Method */ | 32 /* Class */ | 384 /* Enum */ | 512 /* ValueModule */)) {
                        return getTypeOfFuncClassEnumModule(symbol);
                    }
                    type = isBinaryExpression(declaration.parent) ? getWidenedTypeForAssignmentDeclaration(symbol) : tryGetTypeFromEffectiveTypeNode(declaration) || anyType;
                }
                else if (isPropertyAssignment(declaration)) {
                    type = tryGetTypeFromEffectiveTypeNode(declaration) || checkPropertyAssignment(declaration);
                }
                else if (isJsxAttribute(declaration)) {
                    type = tryGetTypeFromEffectiveTypeNode(declaration) || checkJsxAttribute(declaration);
                }
                else if (isShorthandPropertyAssignment(declaration)) {
                    type = tryGetTypeFromEffectiveTypeNode(declaration) || checkExpressionForMutableLocation(declaration.name, 0 /* Normal */);
                }
                else if (isObjectLiteralMethod(declaration)) {
                    type = tryGetTypeFromEffectiveTypeNode(declaration) || checkObjectLiteralMethod(declaration, 0 /* Normal */);
                }
                else if (isParameter(declaration) || isPropertyDeclaration(declaration) || isPropertySignature(declaration) || isVariableDeclaration(declaration) || isBindingElement(declaration) || isJSDocPropertyLikeTag(declaration)) {
                    type = getWidenedTypeForVariableLikeDeclaration(declaration, 
                    /*reportErrors*/
                    true);
                }
                else if (isEnumDeclaration(declaration)) {
                    type = getTypeOfFuncClassEnumModule(symbol);
                }
                else if (isEnumMember(declaration)) {
                    type = getTypeOfEnumMember(symbol);
                }
                else {
                    return Debug.fail("Unhandled declaration kind! " + Debug.formatSyntaxKind(declaration.kind) + " for " + Debug.formatSymbol(symbol));
                }
                if (!popTypeResolution()) {
                    if (symbol.flags & 512 /* ValueModule */ && !(symbol.flags & 67108864 /* Assignment */)) {
                        return getTypeOfFuncClassEnumModule(symbol);
                    }
                    if (isBindingElement(declaration) && checkMode === 1 /* Contextual */) {
                        return type;
                    }
                    return reportCircularityError(symbol);
                }
                return type;
            }
            function getAnnotatedAccessorTypeNode(accessor) {
                if (accessor) {
                    switch (accessor.kind) {
                        case 177 /* GetAccessor */:
                            const getterTypeAnnotation = getEffectiveReturnTypeNode(accessor);
                            return getterTypeAnnotation;
                        case 178 /* SetAccessor */:
                            const setterTypeAnnotation = getEffectiveSetAccessorTypeAnnotationNode(accessor);
                            return setterTypeAnnotation;
                        case 172 /* PropertyDeclaration */:
                            Debug.assert(hasAccessorModifier(accessor));
                            const accessorTypeAnnotation = getEffectiveTypeAnnotationNode(accessor);
                            return accessorTypeAnnotation;
                    }
                }
                return void 0;
            }
            function getAnnotatedAccessorType(accessor) {
                const node = getAnnotatedAccessorTypeNode(accessor);
                return node && getTypeFromTypeNode(node);
            }
            function getAnnotatedAccessorThisParameter(accessor) {
                const parameter = getAccessorThisParameter(accessor);
                return parameter && parameter.symbol;
            }
            function getThisTypeOfDeclaration(declaration) {
                return getThisTypeOfSignature(getSignatureFromDeclaration(declaration));
            }
            function getTypeOfAccessors(symbol) {
                const links = getSymbolLinks(symbol);
                if (!links.type) {
                    if (!pushTypeResolution(symbol, 0 /* Type */)) {
                        return errorType;
                    }
                    const getter = getDeclarationOfKind(symbol, 177 /* GetAccessor */);
                    const setter = getDeclarationOfKind(symbol, 178 /* SetAccessor */);
                    const accessor = tryCast(getDeclarationOfKind(symbol, 172 /* PropertyDeclaration */), isAutoAccessorPropertyDeclaration);
                    let type = getter && isInJSFile(getter) && getTypeForDeclarationFromJSDocComment(getter) || getAnnotatedAccessorType(getter) || getAnnotatedAccessorType(setter) || getAnnotatedAccessorType(accessor) || getter && getter.body && getReturnTypeFromBody(getter) || accessor && accessor.initializer && getWidenedTypeForVariableLikeDeclaration(accessor, 
                    /*reportErrors*/
                    true);
                    if (!type) {
                        if (setter && !isPrivateWithinAmbient(setter)) {
                            errorOrSuggestion(noImplicitAny, setter, Diagnostics.Property_0_implicitly_has_type_any_because_its_set_accessor_lacks_a_parameter_type_annotation, symbolToString(symbol));
                        }
                        else if (getter && !isPrivateWithinAmbient(getter)) {
                            errorOrSuggestion(noImplicitAny, getter, Diagnostics.Property_0_implicitly_has_type_any_because_its_get_accessor_lacks_a_return_type_annotation, symbolToString(symbol));
                        }
                        else if (accessor && !isPrivateWithinAmbient(accessor)) {
                            errorOrSuggestion(noImplicitAny, accessor, Diagnostics.Member_0_implicitly_has_an_1_type, symbolToString(symbol), "any");
                        }
                        type = anyType;
                    }
                    if (!popTypeResolution()) {
                        if (getAnnotatedAccessorTypeNode(getter)) {
                            error2(getter, Diagnostics._0_is_referenced_directly_or_indirectly_in_its_own_type_annotation, symbolToString(symbol));
                        }
                        else if (getAnnotatedAccessorTypeNode(setter)) {
                            error2(setter, Diagnostics._0_is_referenced_directly_or_indirectly_in_its_own_type_annotation, symbolToString(symbol));
                        }
                        else if (getAnnotatedAccessorTypeNode(accessor)) {
                            error2(setter, Diagnostics._0_is_referenced_directly_or_indirectly_in_its_own_type_annotation, symbolToString(symbol));
                        }
                        else if (getter && noImplicitAny) {
                            error2(getter, Diagnostics._0_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_referenced_directly_or_indirectly_in_one_of_its_return_expressions, symbolToString(symbol));
                        }
                        type = anyType;
                    }
                    links.type = type;
                }
                return links.type;
            }
            function getWriteTypeOfAccessors(symbol) {
                const links = getSymbolLinks(symbol);
                if (!links.writeType) {
                    if (!pushTypeResolution(symbol, 8 /* WriteType */)) {
                        return errorType;
                    }
                    const setter = getDeclarationOfKind(symbol, 178 /* SetAccessor */) ?? tryCast(getDeclarationOfKind(symbol, 172 /* PropertyDeclaration */), isAutoAccessorPropertyDeclaration);
                    let writeType = getAnnotatedAccessorType(setter);
                    if (!popTypeResolution()) {
                        if (getAnnotatedAccessorTypeNode(setter)) {
                            error2(setter, Diagnostics._0_is_referenced_directly_or_indirectly_in_its_own_type_annotation, symbolToString(symbol));
                        }
                        writeType = anyType;
                    }
                    links.writeType = writeType || getTypeOfAccessors(symbol);
                }
                return links.writeType;
            }
            function getBaseTypeVariableOfClass(symbol) {
                const baseConstructorType = getBaseConstructorTypeOfClass(getDeclaredTypeOfClassOrInterface(symbol));
                return baseConstructorType.flags & 8650752 /* TypeVariable */ ? baseConstructorType : baseConstructorType.flags & 2097152 /* Intersection */ ? find(baseConstructorType.types, (t) => !!(t.flags & 8650752 /* TypeVariable */)) : void 0;
            }
            function getTypeOfFuncClassEnumModule(symbol) {
                let links = getSymbolLinks(symbol);
                const originalLinks = links;
                if (!links.type) {
                    const expando = symbol.valueDeclaration && getSymbolOfExpando(symbol.valueDeclaration, 
                    /*allowDeclaration*/
                    false);
                    if (expando) {
                        const merged = mergeJSSymbols(symbol, expando);
                        if (merged) {
                            symbol = merged;
                            links = merged.links;
                        }
                    }
                    originalLinks.type = links.type = getTypeOfFuncClassEnumModuleWorker(symbol);
                }
                return links.type;
            }
            function getTypeOfFuncClassEnumModuleWorker(symbol) {
                const declaration = symbol.valueDeclaration;
                if (symbol.flags & 1536 /* Module */ && isShorthandAmbientModuleSymbol(symbol)) {
                    return anyType;
                }
                else if (declaration && (declaration.kind === 226 /* BinaryExpression */ || isAccessExpression(declaration) && declaration.parent.kind === 226 /* BinaryExpression */)) {
                    return getWidenedTypeForAssignmentDeclaration(symbol);
                }
                else if (symbol.flags & 512 /* ValueModule */ && declaration && isSourceFile(declaration) && declaration.commonJsModuleIndicator) {
                    const resolvedModule = resolveExternalModuleSymbol(symbol);
                    if (resolvedModule !== symbol) {
                        if (!pushTypeResolution(symbol, 0 /* Type */)) {
                            return errorType;
                        }
                        const exportEquals = getMergedSymbol(symbol.exports.get("export=" /* ExportEquals */));
                        const type2 = getWidenedTypeForAssignmentDeclaration(exportEquals, exportEquals === resolvedModule ? void 0 : resolvedModule);
                        if (!popTypeResolution()) {
                            return reportCircularityError(symbol);
                        }
                        return type2;
                    }
                }
                const type = createObjectType(16 /* Anonymous */, symbol);
                if (symbol.flags & 32 /* Class */) {
                    const baseTypeVariable = getBaseTypeVariableOfClass(symbol);
                    return baseTypeVariable ? getIntersectionType([type, baseTypeVariable]) : type;
                }
                else {
                    return strictNullChecks && symbol.flags & 16777216 /* Optional */ ? getOptionalType(type, 
                    /*isProperty*/
                    true) : type;
                }
            }
            function getTypeOfEnumMember(symbol) {
                const links = getSymbolLinks(symbol);
                return links.type || (links.type = getDeclaredTypeOfEnumMember(symbol));
            }
            function getTypeOfAlias(symbol) {
                const links = getSymbolLinks(symbol);
                if (!links.type) {
                    if (!pushTypeResolution(symbol, 0 /* Type */)) {
                        return errorType;
                    }
                    const targetSymbol = resolveAlias(symbol);
                    const exportSymbol = symbol.declarations && getTargetOfAliasDeclaration(getDeclarationOfAliasSymbol(symbol), 
                    /*dontRecursivelyResolve*/
                    true);
                    const declaredType = firstDefined(exportSymbol == null ? void 0 : exportSymbol.declarations, (d) => isExportAssignment(d) ? tryGetTypeFromEffectiveTypeNode(d) : void 0);
                    links.type = (exportSymbol == null ? void 0 : exportSymbol.declarations) && isDuplicatedCommonJSExport(exportSymbol.declarations) && symbol.declarations.length ? getFlowTypeFromCommonJSExport(exportSymbol) : isDuplicatedCommonJSExport(symbol.declarations) ? autoType : declaredType ? declaredType : getSymbolFlags(targetSymbol) & 111551 /* Value */ ? getTypeOfSymbol(targetSymbol) : errorType;
                    if (!popTypeResolution()) {
                        reportCircularityError(exportSymbol ?? symbol);
                        return links.type = errorType;
                    }
                }
                return links.type;
            }
            function getTypeOfInstantiatedSymbol(symbol) {
                const links = getSymbolLinks(symbol);
                return links.type || (links.type = instantiateType(getTypeOfSymbol(links.target), links.mapper));
            }
            function getWriteTypeOfInstantiatedSymbol(symbol) {
                const links = getSymbolLinks(symbol);
                return links.writeType || (links.writeType = instantiateType(getWriteTypeOfSymbol(links.target), links.mapper));
            }
            function reportCircularityError(symbol) {
                const declaration = symbol.valueDeclaration;
                if (declaration) {
                    if (getEffectiveTypeAnnotationNode(declaration)) {
                        error2(symbol.valueDeclaration, Diagnostics._0_is_referenced_directly_or_indirectly_in_its_own_type_annotation, symbolToString(symbol));
                        return errorType;
                    }
                    if (noImplicitAny && (declaration.kind !== 169 /* Parameter */ || declaration.initializer)) {
                        error2(symbol.valueDeclaration, Diagnostics._0_implicitly_has_type_any_because_it_does_not_have_a_type_annotation_and_is_referenced_directly_or_indirectly_in_its_own_initializer, symbolToString(symbol));
                    }
                }
                else if (symbol.flags & 2097152 /* Alias */) {
                    const node = getDeclarationOfAliasSymbol(symbol);
                    if (node) {
                        error2(node, Diagnostics.Circular_definition_of_import_alias_0, symbolToString(symbol));
                    }
                }
                return anyType;
            }
            function getTypeOfSymbolWithDeferredType(symbol) {
                const links = getSymbolLinks(symbol);
                if (!links.type) {
                    Debug.assertIsDefined(links.deferralParent);
                    Debug.assertIsDefined(links.deferralConstituents);
                    links.type = links.deferralParent.flags & 1048576 /* Union */ ? getUnionType(links.deferralConstituents) : getIntersectionType(links.deferralConstituents);
                }
                return links.type;
            }
            function getWriteTypeOfSymbolWithDeferredType(symbol) {
                const links = getSymbolLinks(symbol);
                if (!links.writeType && links.deferralWriteConstituents) {
                    Debug.assertIsDefined(links.deferralParent);
                    Debug.assertIsDefined(links.deferralConstituents);
                    links.writeType = links.deferralParent.flags & 1048576 /* Union */ ? getUnionType(links.deferralWriteConstituents) : getIntersectionType(links.deferralWriteConstituents);
                }
                return links.writeType;
            }
            function getWriteTypeOfSymbol(symbol) {
                const checkFlags = getCheckFlags(symbol);
                if (symbol.flags & 4 /* Property */) {
                    return checkFlags & 2 /* SyntheticProperty */ ? checkFlags & 65536 /* DeferredType */ ? getWriteTypeOfSymbolWithDeferredType(symbol) || getTypeOfSymbolWithDeferredType(symbol) : (
                    // NOTE: cast to TransientSymbol should be safe because only TransientSymbols can have CheckFlags.SyntheticProperty
                    symbol.links.writeType || symbol.links.type) : removeMissingType(getTypeOfSymbol(symbol), !!(symbol.flags & 16777216 /* Optional */));
                }
                if (symbol.flags & 98304 /* Accessor */) {
                    return checkFlags & 1 /* Instantiated */ ? getWriteTypeOfInstantiatedSymbol(symbol) : getWriteTypeOfAccessors(symbol);
                }
                return getTypeOfSymbol(symbol);
            }
            function getTypeOfSymbol(symbol, checkMode) {
                const checkFlags = getCheckFlags(symbol);
                if (checkFlags & 65536 /* DeferredType */) {
                    return getTypeOfSymbolWithDeferredType(symbol);
                }
                if (checkFlags & 1 /* Instantiated */) {
                    return getTypeOfInstantiatedSymbol(symbol);
                }
                if (checkFlags & 262144 /* Mapped */) {
                    return getTypeOfMappedSymbol(symbol);
                }
                if (checkFlags & 8192 /* ReverseMapped */) {
                    return getTypeOfReverseMappedSymbol(symbol);
                }
                if (symbol.flags & (3 /* Variable */ | 4 /* Property */)) {
                    return getTypeOfVariableOrParameterOrProperty(symbol, checkMode);
                }
                if (symbol.flags & (16 /* Function */ | 8192 /* Method */ | 32 /* Class */ | 384 /* Enum */ | 512 /* ValueModule */)) {
                    return getTypeOfFuncClassEnumModule(symbol);
                }
                if (symbol.flags & 8 /* EnumMember */) {
                    return getTypeOfEnumMember(symbol);
                }
                if (symbol.flags & 98304 /* Accessor */) {
                    return getTypeOfAccessors(symbol);
                }
                if (symbol.flags & 2097152 /* Alias */) {
                    return getTypeOfAlias(symbol);
                }
                return errorType;
            }
            function getNonMissingTypeOfSymbol(symbol) {
                return removeMissingType(getTypeOfSymbol(symbol), !!(symbol.flags & 16777216 /* Optional */));
            }
            function isReferenceToType2(type, target) {
                return type !== void 0 && target !== void 0 && (getObjectFlags(type) & 4 /* Reference */) !== 0 && type.target === target;
            }
            function getTargetType(type) {
                return getObjectFlags(type) & 4 /* Reference */ ? type.target : type;
            }
            function hasBaseType(type, checkBase) {
                return check(type);
                function check(type2) {
                    if (getObjectFlags(type2) & (3 /* ClassOrInterface */ | 4 /* Reference */)) {
                        const target = getTargetType(type2);
                        return target === checkBase || some(getBaseTypes(target), check);
                    }
                    else if (type2.flags & 2097152 /* Intersection */) {
                        return some(type2.types, check);
                    }
                    return false;
                }
            }
            function appendTypeParameters(typeParameters, declarations) {
                for (const declaration of declarations) {
                    typeParameters = appendIfUnique(typeParameters, getDeclaredTypeOfTypeParameter(getSymbolOfDeclaration(declaration)));
                }
                return typeParameters;
            }
            function getOuterTypeParameters(node, includeThisTypes) {
                while (true) {
                    node = node.parent;
                    if (node && isBinaryExpression(node)) {
                        const assignmentKind = getAssignmentDeclarationKind(node);
                        if (assignmentKind === 6 /* Prototype */ || assignmentKind === 3 /* PrototypeProperty */) {
                            const symbol = getSymbolOfDeclaration(node.left);
                            if (symbol && symbol.parent && !findAncestor(symbol.parent.valueDeclaration, (d) => node === d)) {
                                node = symbol.parent.valueDeclaration;
                            }
                        }
                    }
                    if (!node) {
                        return void 0;
                    }
                    switch (node.kind) {
                        case 263 /* ClassDeclaration */:
                        case 231 /* ClassExpression */:
                        case 264 /* InterfaceDeclaration */:
                        case 179 /* CallSignature */:
                        case 180 /* ConstructSignature */:
                        case 173 /* MethodSignature */:
                        case 184 /* FunctionType */:
                        case 185 /* ConstructorType */:
                        case 324 /* JSDocFunctionType */:
                        case 262 /* FunctionDeclaration */:
                        case 174 /* MethodDeclaration */:
                        case 218 /* FunctionExpression */:
                        case 219 /* ArrowFunction */:
                        case 265 /* TypeAliasDeclaration */:
                        case 352 /* JSDocTemplateTag */:
                        case 353 /* JSDocTypedefTag */:
                        case 347 /* JSDocEnumTag */:
                        case 345 /* JSDocCallbackTag */:
                        case 200 /* MappedType */:
                        case 194 /* ConditionalType */: {
                            const outerTypeParameters = getOuterTypeParameters(node, includeThisTypes);
                            if (node.kind === 200 /* MappedType */) {
                                return append(outerTypeParameters, getDeclaredTypeOfTypeParameter(getSymbolOfDeclaration(node.typeParameter)));
                            }
                            else if (node.kind === 194 /* ConditionalType */) {
                                return concatenate(outerTypeParameters, getInferTypeParameters(node));
                            }
                            const outerAndOwnTypeParameters = appendTypeParameters(outerTypeParameters, getEffectiveTypeParameterDeclarations(node));
                            const thisType = includeThisTypes && (node.kind === 263 /* ClassDeclaration */ || node.kind === 231 /* ClassExpression */ || node.kind === 264 /* InterfaceDeclaration */ || isJSConstructor(node)) && getDeclaredTypeOfClassOrInterface(getSymbolOfDeclaration(node)).thisType;
                            return thisType ? append(outerAndOwnTypeParameters, thisType) : outerAndOwnTypeParameters;
                        }
                        case 348 /* JSDocParameterTag */:
                            const paramSymbol = getParameterSymbolFromJSDoc(node);
                            if (paramSymbol) {
                                node = paramSymbol.valueDeclaration;
                            }
                            break;
                        case 327 /* JSDoc */: {
                            const outerTypeParameters = getOuterTypeParameters(node, includeThisTypes);
                            return node.tags ? appendTypeParameters(outerTypeParameters, flatMap(node.tags, (t) => isJSDocTemplateTag(t) ? t.typeParameters : void 0)) : outerTypeParameters;
                        }
                    }
                }
            }
            function getOuterTypeParametersOfClassOrInterface(symbol) {
                var _a;
                const declaration = symbol.flags & 32 /* Class */ || symbol.flags & 16 /* Function */ ? symbol.valueDeclaration : (_a = symbol.declarations) == null ? void 0 : _a.find((decl) => {
                    if (decl.kind === 264 /* InterfaceDeclaration */) {
                        return true;
                    }
                    if (decl.kind !== 260 /* VariableDeclaration */) {
                        return false;
                    }
                    const initializer = decl.initializer;
                    return !!initializer && (initializer.kind === 218 /* FunctionExpression */ || initializer.kind === 219 /* ArrowFunction */);
                });
                Debug.assert(!!declaration, "Class was missing valueDeclaration -OR- non-class had no interface declarations");
                return getOuterTypeParameters(declaration);
            }
            function getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(symbol) {
                if (!symbol.declarations) {
                    return;
                }
                let result;
                for (const node of symbol.declarations) {
                    if (node.kind === 264 /* InterfaceDeclaration */ || node.kind === 263 /* ClassDeclaration */ || node.kind === 231 /* ClassExpression */ || isJSConstructor(node) || isTypeAlias(node)) {
                        const declaration = node;
                        result = appendTypeParameters(result, getEffectiveTypeParameterDeclarations(declaration));
                    }
                }
                return result;
            }
            function getTypeParametersOfClassOrInterface(symbol) {
                return concatenate(getOuterTypeParametersOfClassOrInterface(symbol), getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(symbol));
            }
            function isMixinConstructorType(type) {
                const signatures = getSignaturesOfType(type, 1 /* Construct */);
                if (signatures.length === 1) {
                    const s = signatures[0];
                    if (!s.typeParameters && s.parameters.length === 1 && signatureHasRestParameter(s)) {
                        const paramType = getTypeOfParameter(s.parameters[0]);
                        return isTypeAny(paramType) || getElementTypeOfArrayType(paramType) === anyType;
                    }
                }
                return false;
            }
            function isConstructorType(type) {
                if (getSignaturesOfType(type, 1 /* Construct */).length > 0) {
                    return true;
                }
                if (type.flags & 8650752 /* TypeVariable */) {
                    const constraint = getBaseConstraintOfType(type);
                    return !!constraint && isMixinConstructorType(constraint);
                }
                return false;
            }
            function getBaseTypeNodeOfClass(type) {
                const decl = getClassLikeDeclarationOfSymbol(type.symbol);
                return decl && getEffectiveBaseTypeNode(decl);
            }
            function getConstructorsForTypeArguments(type, typeArgumentNodes, location) {
                const typeArgCount = length(typeArgumentNodes);
                const isJavascript = isInJSFile(location);
                return filter(getSignaturesOfType(type, 1 /* Construct */), (sig) => (isJavascript || typeArgCount >= getMinTypeArgumentCount(sig.typeParameters)) && typeArgCount <= length(sig.typeParameters));
            }
            function getInstantiatedConstructorsForTypeArguments(type, typeArgumentNodes, location) {
                const signatures = getConstructorsForTypeArguments(type, typeArgumentNodes, location);
                const typeArguments = map(typeArgumentNodes, getTypeFromTypeNode);
                return sameMap(signatures, (sig) => some(sig.typeParameters) ? getSignatureInstantiation(sig, typeArguments, isInJSFile(location)) : sig);
            }
            function getBaseConstructorTypeOfClass(type) {
                if (!type.resolvedBaseConstructorType) {
                    const decl = getClassLikeDeclarationOfSymbol(type.symbol);
                    const extended = decl && getEffectiveBaseTypeNode(decl);
                    const baseTypeNode = getBaseTypeNodeOfClass(type);
                    if (!baseTypeNode) {
                        return type.resolvedBaseConstructorType = undefinedType;
                    }
                    if (!pushTypeResolution(type, 1 /* ResolvedBaseConstructorType */)) {
                        return errorType;
                    }
                    const baseConstructorType = checkExpression(baseTypeNode.expression);
                    if (extended && baseTypeNode !== extended) {
                        Debug.assert(!extended.typeArguments);
                        checkExpression(extended.expression);
                    }
                    if (baseConstructorType.flags & (524288 /* Object */ | 2097152 /* Intersection */)) {
                        resolveStructuredTypeMembers(baseConstructorType);
                    }
                    if (!popTypeResolution()) {
                        error2(type.symbol.valueDeclaration, Diagnostics._0_is_referenced_directly_or_indirectly_in_its_own_base_expression, symbolToString(type.symbol));
                        return type.resolvedBaseConstructorType = errorType;
                    }
                    if (!(baseConstructorType.flags & 1 /* Any */) && baseConstructorType !== nullWideningType && !isConstructorType(baseConstructorType)) {
                        const err = error2(baseTypeNode.expression, Diagnostics.Type_0_is_not_a_constructor_function_type, typeToString(baseConstructorType));
                        if (baseConstructorType.flags & 262144 /* TypeParameter */) {
                            const constraint = getConstraintFromTypeParameter(baseConstructorType);
                            let ctorReturn = unknownType;
                            if (constraint) {
                                const ctorSig = getSignaturesOfType(constraint, 1 /* Construct */);
                                if (ctorSig[0]) {
                                    ctorReturn = getReturnTypeOfSignature(ctorSig[0]);
                                }
                            }
                            if (baseConstructorType.symbol.declarations) {
                                addRelatedInfo(err, createDiagnosticForNode(baseConstructorType.symbol.declarations[0], Diagnostics.Did_you_mean_for_0_to_be_constrained_to_type_new_args_Colon_any_1, symbolToString(baseConstructorType.symbol), typeToString(ctorReturn)));
                            }
                        }
                        return type.resolvedBaseConstructorType = errorType;
                    }
                    type.resolvedBaseConstructorType = baseConstructorType;
                }
                return type.resolvedBaseConstructorType;
            }
            function getImplementsTypes(type) {
                let resolvedImplementsTypes = emptyArray;
                if (type.symbol.declarations) {
                    for (const declaration of type.symbol.declarations) {
                        const implementsTypeNodes = getEffectiveImplementsTypeNodes(declaration);
                        if (!implementsTypeNodes)
                            continue;
                        for (const node of implementsTypeNodes) {
                            const implementsType = getTypeFromTypeNode(node);
                            if (!isErrorType(implementsType)) {
                                if (resolvedImplementsTypes === emptyArray) {
                                    resolvedImplementsTypes = [implementsType];
                                }
                                else {
                                    resolvedImplementsTypes.push(implementsType);
                                }
                            }
                        }
                    }
                }
                return resolvedImplementsTypes;
            }
            function reportCircularBaseType(node, type) {
                error2(node, Diagnostics.Type_0_recursively_references_itself_as_a_base_type, typeToString(type, 
                /*enclosingDeclaration*/
                void 0, 2 /* WriteArrayAsGenericType */));
            }
            function getBaseTypes(type) {
                if (!type.baseTypesResolved) {
                    if (pushTypeResolution(type, 7 /* ResolvedBaseTypes */)) {
                        if (type.objectFlags & 8 /* Tuple */) {
                            type.resolvedBaseTypes = [getTupleBaseType(type)];
                        }
                        else if (type.symbol.flags & (32 /* Class */ | 64 /* Interface */)) {
                            if (type.symbol.flags & 32 /* Class */) {
                                resolveBaseTypesOfClass(type);
                            }
                            if (type.symbol.flags & 64 /* Interface */) {
                                resolveBaseTypesOfInterface(type);
                            }
                        }
                        else {
                            Debug.fail("type must be class or interface");
                        }
                        if (!popTypeResolution() && type.symbol.declarations) {
                            for (const declaration of type.symbol.declarations) {
                                if (declaration.kind === 263 /* ClassDeclaration */ || declaration.kind === 264 /* InterfaceDeclaration */) {
                                    reportCircularBaseType(declaration, type);
                                }
                            }
                        }
                    }
                    type.baseTypesResolved = true;
                }
                return type.resolvedBaseTypes;
            }
            function getTupleBaseType(type) {
                const elementTypes = sameMap(type.typeParameters, (t, i) => type.elementFlags[i] & 8 /* Variadic */ ? getIndexedAccessType(t, numberType) : t);
                return createArrayType(getUnionType(elementTypes || emptyArray), type.readonly);
            }
            function resolveBaseTypesOfClass(type) {
                type.resolvedBaseTypes = resolvingEmptyArray;
                const baseConstructorType = getApparentType(getBaseConstructorTypeOfClass(type));
                if (!(baseConstructorType.flags & (524288 /* Object */ | 2097152 /* Intersection */ | 1 /* Any */))) {
                    return type.resolvedBaseTypes = emptyArray;
                }
                const baseTypeNode = getBaseTypeNodeOfClass(type);
                let baseType;
                const originalBaseType = baseConstructorType.symbol ? getDeclaredTypeOfSymbol(baseConstructorType.symbol) : void 0;
                if (baseConstructorType.symbol && baseConstructorType.symbol.flags & 32 /* Class */ && areAllOuterTypeParametersApplied(originalBaseType)) {
                    baseType = getTypeFromClassOrInterfaceReference(baseTypeNode, baseConstructorType.symbol);
                }
                else if (baseConstructorType.flags & 1 /* Any */) {
                    baseType = baseConstructorType;
                }
                else {
                    const constructors = getInstantiatedConstructorsForTypeArguments(baseConstructorType, baseTypeNode.typeArguments, baseTypeNode);
                    if (!constructors.length) {
                        error2(baseTypeNode.expression, Diagnostics.No_base_constructor_has_the_specified_number_of_type_arguments);
                        return type.resolvedBaseTypes = emptyArray;
                    }
                    baseType = getReturnTypeOfSignature(constructors[0]);
                }
                if (isErrorType(baseType)) {
                    return type.resolvedBaseTypes = emptyArray;
                }
                const reducedBaseType = getReducedType(baseType);
                if (!isValidBaseType(reducedBaseType)) {
                    const elaboration = elaborateNeverIntersection(
                    /*errorInfo*/
                    void 0, baseType);
                    const diagnostic = chainDiagnosticMessages(elaboration, Diagnostics.Base_constructor_return_type_0_is_not_an_object_type_or_intersection_of_object_types_with_statically_known_members, typeToString(reducedBaseType));
                    diagnostics.add(createDiagnosticForNodeFromMessageChain(getSourceFileOfNode(baseTypeNode.expression), baseTypeNode.expression, diagnostic));
                    return type.resolvedBaseTypes = emptyArray;
                }
                if (type === reducedBaseType || hasBaseType(reducedBaseType, type)) {
                    error2(type.symbol.valueDeclaration, Diagnostics.Type_0_recursively_references_itself_as_a_base_type, typeToString(type, 
                    /*enclosingDeclaration*/
                    void 0, 2 /* WriteArrayAsGenericType */));
                    return type.resolvedBaseTypes = emptyArray;
                }
                if (type.resolvedBaseTypes === resolvingEmptyArray) {
                    type.members = void 0;
                }
                return type.resolvedBaseTypes = [reducedBaseType];
            }
            function areAllOuterTypeParametersApplied(type) {
                const outerTypeParameters = type.outerTypeParameters;
                if (outerTypeParameters) {
                    const last2 = outerTypeParameters.length - 1;
                    const typeArguments = getTypeArguments(type);
                    return outerTypeParameters[last2].symbol !== typeArguments[last2].symbol;
                }
                return true;
            }
            function isValidBaseType(type) {
                if (type.flags & 262144 /* TypeParameter */) {
                    const constraint = getBaseConstraintOfType(type);
                    if (constraint) {
                        return isValidBaseType(constraint);
                    }
                }
                return !!(type.flags & (524288 /* Object */ | 67108864 /* NonPrimitive */ | 1 /* Any */) && !isGenericMappedType(type) || type.flags & 2097152 /* Intersection */ && every(type.types, isValidBaseType));
            }
            function resolveBaseTypesOfInterface(type) {
                type.resolvedBaseTypes = type.resolvedBaseTypes || emptyArray;
                if (type.symbol.declarations) {
                    for (const declaration of type.symbol.declarations) {
                        if (declaration.kind === 264 /* InterfaceDeclaration */ && getInterfaceBaseTypeNodes(declaration)) {
                            for (const node of getInterfaceBaseTypeNodes(declaration)) {
                                const baseType = getReducedType(getTypeFromTypeNode(node));
                                if (!isErrorType(baseType)) {
                                    if (isValidBaseType(baseType)) {
                                        if (type !== baseType && !hasBaseType(baseType, type)) {
                                            if (type.resolvedBaseTypes === emptyArray) {
                                                type.resolvedBaseTypes = [baseType];
                                            }
                                            else {
                                                type.resolvedBaseTypes.push(baseType);
                                            }
                                        }
                                        else {
                                            reportCircularBaseType(declaration, type);
                                        }
                                    }
                                    else {
                                        error2(node, Diagnostics.An_interface_can_only_extend_an_object_type_or_intersection_of_object_types_with_statically_known_members);
                                    }
                                }
                            }
                        }
                    }
                }
            }
            function isThislessInterface(symbol) {
                if (!symbol.declarations) {
                    return true;
                }
                for (const declaration of symbol.declarations) {
                    if (declaration.kind === 264 /* InterfaceDeclaration */) {
                        if (declaration.flags & 256 /* ContainsThis */) {
                            return false;
                        }
                        const baseTypeNodes = getInterfaceBaseTypeNodes(declaration);
                        if (baseTypeNodes) {
                            for (const node of baseTypeNodes) {
                                if (isEntityNameExpression(node.expression)) {
                                    const baseSymbol = resolveEntityName(node.expression, 788968 /* Type */, 
                                    /*ignoreErrors*/
                                    true);
                                    if (!baseSymbol || !(baseSymbol.flags & 64 /* Interface */) || getDeclaredTypeOfClassOrInterface(baseSymbol).thisType) {
                                        return false;
                                    }
                                }
                            }
                        }
                    }
                }
                return true;
            }
            function getDeclaredTypeOfClassOrInterface(symbol) {
                let links = getSymbolLinks(symbol);
                const originalLinks = links;
                if (!links.declaredType) {
                    const kind = symbol.flags & 32 /* Class */ ? 1 /* Class */ : 2 /* Interface */;
                    const merged = mergeJSSymbols(symbol, symbol.valueDeclaration && getAssignedClassSymbol(symbol.valueDeclaration));
                    if (merged) {
                        symbol = merged;
                        links = merged.links;
                    }
                    const type = originalLinks.declaredType = links.declaredType = createObjectType(kind, symbol);
                    const outerTypeParameters = getOuterTypeParametersOfClassOrInterface(symbol);
                    const localTypeParameters = getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(symbol);
                    if (outerTypeParameters || localTypeParameters || kind === 1 /* Class */ || !isThislessInterface(symbol)) {
                        type.objectFlags |= 4 /* Reference */;
                        type.typeParameters = concatenate(outerTypeParameters, localTypeParameters);
                        type.outerTypeParameters = outerTypeParameters;
                        type.localTypeParameters = localTypeParameters;
                        type.instantiations = /* @__PURE__ */ new Map();
                        type.instantiations.set(getTypeListId(type.typeParameters), type);
                        type.target = type;
                        type.resolvedTypeArguments = type.typeParameters;
                        type.thisType = createTypeParameter(symbol);
                        type.thisType.isThisType = true;
                        type.thisType.constraint = type;
                    }
                }
                return links.declaredType;
            }
            function getDeclaredTypeOfTypeAlias(symbol) {
                var _a;
                const links = getSymbolLinks(symbol);
                if (!links.declaredType) {
                    if (!pushTypeResolution(symbol, 2 /* DeclaredType */)) {
                        return errorType;
                    }
                    const declaration = Debug.checkDefined((_a = symbol.declarations) == null ? void 0 : _a.find(isTypeAlias), "Type alias symbol with no valid declaration found");
                    const typeNode = isJSDocTypeAlias(declaration) ? declaration.typeExpression : declaration.type;
                    let type = typeNode ? getTypeFromTypeNode(typeNode) : errorType;
                    if (popTypeResolution()) {
                        const typeParameters = getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(symbol);
                        if (typeParameters) {
                            links.typeParameters = typeParameters;
                            links.instantiations = /* @__PURE__ */ new Map();
                            links.instantiations.set(getTypeListId(typeParameters), type);
                        }
                    }
                    else {
                        type = errorType;
                        if (declaration.kind === 347 /* JSDocEnumTag */) {
                            error2(declaration.typeExpression.type, Diagnostics.Type_alias_0_circularly_references_itself, symbolToString(symbol));
                        }
                        else {
                            error2(isNamedDeclaration(declaration) ? declaration.name || declaration : declaration, Diagnostics.Type_alias_0_circularly_references_itself, symbolToString(symbol));
                        }
                    }
                    links.declaredType = type;
                }
                return links.declaredType;
            }
            function getBaseTypeOfEnumLikeType(type) {
                return type.flags & 1056 /* EnumLike */ && type.symbol.flags & 8 /* EnumMember */ ? getDeclaredTypeOfSymbol(getParentOfSymbol(type.symbol)) : type;
            }
            function getDeclaredTypeOfEnum(symbol) {
                const links = getSymbolLinks(symbol);
                if (!links.declaredType) {
                    const memberTypeList = [];
                    if (symbol.declarations) {
                        for (const declaration of symbol.declarations) {
                            if (declaration.kind === 266 /* EnumDeclaration */) {
                                for (const member of declaration.members) {
                                    if (hasBindableName(member)) {
                                        const memberSymbol = getSymbolOfDeclaration(member);
                                        const value = getEnumMemberValue(member);
                                        const memberType = getFreshTypeOfLiteralType(value !== void 0 ? getEnumLiteralType(value, getSymbolId(symbol), memberSymbol) : createComputedEnumType(memberSymbol));
                                        getSymbolLinks(memberSymbol).declaredType = memberType;
                                        memberTypeList.push(getRegularTypeOfLiteralType(memberType));
                                    }
                                }
                            }
                        }
                    }
                    const enumType = memberTypeList.length ? getUnionType(memberTypeList, 1 /* Literal */, symbol, 
                    /*aliasTypeArguments*/
                    void 0) : createComputedEnumType(symbol);
                    if (enumType.flags & 1048576 /* Union */) {
                        enumType.flags |= 1024 /* EnumLiteral */;
                        enumType.symbol = symbol;
                    }
                    links.declaredType = enumType;
                }
                return links.declaredType;
            }
            function createComputedEnumType(symbol) {
                const regularType = createTypeWithSymbol(32 /* Enum */, symbol);
                const freshType = createTypeWithSymbol(32 /* Enum */, symbol);
                regularType.regularType = regularType;
                regularType.freshType = freshType;
                freshType.regularType = regularType;
                freshType.freshType = freshType;
                return regularType;
            }
            function getDeclaredTypeOfEnumMember(symbol) {
                const links = getSymbolLinks(symbol);
                if (!links.declaredType) {
                    const enumType = getDeclaredTypeOfEnum(getParentOfSymbol(symbol));
                    if (!links.declaredType) {
                        links.declaredType = enumType;
                    }
                }
                return links.declaredType;
            }
            function getDeclaredTypeOfTypeParameter(symbol) {
                const links = getSymbolLinks(symbol);
                return links.declaredType || (links.declaredType = createTypeParameter(symbol));
            }
            function getDeclaredTypeOfAlias(symbol) {
                const links = getSymbolLinks(symbol);
                return links.declaredType || (links.declaredType = getDeclaredTypeOfSymbol(resolveAlias(symbol)));
            }
            function getDeclaredTypeOfSymbol(symbol) {
                return tryGetDeclaredTypeOfSymbol(symbol) || errorType;
            }
            function tryGetDeclaredTypeOfSymbol(symbol) {
                if (symbol.flags & (32 /* Class */ | 64 /* Interface */)) {
                    return getDeclaredTypeOfClassOrInterface(symbol);
                }
                if (symbol.flags & 524288 /* TypeAlias */) {
                    return getDeclaredTypeOfTypeAlias(symbol);
                }
                if (symbol.flags & 262144 /* TypeParameter */) {
                    return getDeclaredTypeOfTypeParameter(symbol);
                }
                if (symbol.flags & 384 /* Enum */) {
                    return getDeclaredTypeOfEnum(symbol);
                }
                if (symbol.flags & 8 /* EnumMember */) {
                    return getDeclaredTypeOfEnumMember(symbol);
                }
                if (symbol.flags & 2097152 /* Alias */) {
                    return getDeclaredTypeOfAlias(symbol);
                }
                return void 0;
            }
            function isThislessType(node) {
                switch (node.kind) {
                    case 133 /* AnyKeyword */:
                    case 159 /* UnknownKeyword */:
                    case 154 /* StringKeyword */:
                    case 150 /* NumberKeyword */:
                    case 163 /* BigIntKeyword */:
                    case 136 /* BooleanKeyword */:
                    case 155 /* SymbolKeyword */:
                    case 151 /* ObjectKeyword */:
                    case 116 /* VoidKeyword */:
                    case 157 /* UndefinedKeyword */:
                    case 146 /* NeverKeyword */:
                    case 201 /* LiteralType */:
                        return true;
                    case 188 /* ArrayType */:
                        return isThislessType(node.elementType);
                    case 183 /* TypeReference */:
                        return !node.typeArguments || node.typeArguments.every(isThislessType);
                }
                return false;
            }
            function isThislessTypeParameter(node) {
                const constraint = getEffectiveConstraintOfTypeParameter(node);
                return !constraint || isThislessType(constraint);
            }
            function isThislessVariableLikeDeclaration(node) {
                const typeNode = getEffectiveTypeAnnotationNode(node);
                return typeNode ? isThislessType(typeNode) : !hasInitializer(node);
            }
            function isThislessFunctionLikeDeclaration(node) {
                const returnType = getEffectiveReturnTypeNode(node);
                const typeParameters = getEffectiveTypeParameterDeclarations(node);
                return (node.kind === 176 /* Constructor */ || !!returnType && isThislessType(returnType)) && node.parameters.every(isThislessVariableLikeDeclaration) && typeParameters.every(isThislessTypeParameter);
            }
            function isThisless(symbol) {
                if (symbol.declarations && symbol.declarations.length === 1) {
                    const declaration = symbol.declarations[0];
                    if (declaration) {
                        switch (declaration.kind) {
                            case 172 /* PropertyDeclaration */:
                            case 171 /* PropertySignature */:
                                return isThislessVariableLikeDeclaration(declaration);
                            case 174 /* MethodDeclaration */:
                            case 173 /* MethodSignature */:
                            case 176 /* Constructor */:
                            case 177 /* GetAccessor */:
                            case 178 /* SetAccessor */:
                                return isThislessFunctionLikeDeclaration(declaration);
                        }
                    }
                }
                return false;
            }
            function createInstantiatedSymbolTable(symbols, mapper, mappingThisOnly) {
                const result = createSymbolTable();
                for (const symbol of symbols) {
                    result.set(symbol.escapedName, mappingThisOnly && isThisless(symbol) ? symbol : instantiateSymbol(symbol, mapper));
                }
                return result;
            }
            function addInheritedMembers(symbols, baseSymbols) {
                for (const base of baseSymbols) {
                    if (isStaticPrivateIdentifierProperty(base)) {
                        continue;
                    }
                    const derived = symbols.get(base.escapedName);
                    if (!derived || derived.valueDeclaration && isBinaryExpression(derived.valueDeclaration) && !isConstructorDeclaredProperty(derived) && !getContainingClassStaticBlock(derived.valueDeclaration)) {
                        symbols.set(base.escapedName, base);
                        symbols.set(base.escapedName, base);
                    }
                }
            }
            function isStaticPrivateIdentifierProperty(s) {
                return !!s.valueDeclaration && isPrivateIdentifierClassElementDeclaration(s.valueDeclaration) && isStatic(s.valueDeclaration);
            }
            function resolveDeclaredMembers(type) {
                if (!type.declaredProperties) {
                    const symbol = type.symbol;
                    const members = getMembersOfSymbol(symbol);
                    type.declaredProperties = getNamedMembers(members);
                    type.declaredCallSignatures = emptyArray;
                    type.declaredConstructSignatures = emptyArray;
                    type.declaredIndexInfos = emptyArray;
                    type.declaredCallSignatures = getSignaturesOfSymbol(members.get("__call" /* Call */));
                    type.declaredConstructSignatures = getSignaturesOfSymbol(members.get("__new" /* New */));
                    type.declaredIndexInfos = getIndexInfosOfSymbol(symbol);
                }
                return type;
            }
            function isLateBindableName(node) {
                if (!isComputedPropertyName(node) && !isElementAccessExpression(node)) {
                    return false;
                }
                const expr = isComputedPropertyName(node) ? node.expression : node.argumentExpression;
                return isEntityNameExpression(expr) && isTypeUsableAsPropertyName(isComputedPropertyName(node) ? checkComputedPropertyName(node) : checkExpressionCached(expr));
            }
            function isLateBoundName(name) {
                return name.charCodeAt(0) === 95 /* _ */ && name.charCodeAt(1) === 95 /* _ */ && name.charCodeAt(2) === 64 /* at */;
            }
            function hasLateBindableName(node) {
                const name = getNameOfDeclaration(node);
                return !!name && isLateBindableName(name);
            }
            function hasBindableName(node) {
                return !hasDynamicName(node) || hasLateBindableName(node);
            }
            function isNonBindableDynamicName(node) {
                return isDynamicName(node) && !isLateBindableName(node);
            }
            function addDeclarationToLateBoundSymbol(symbol, member, symbolFlags) {
                Debug.assert(!!(getCheckFlags(symbol) & 4096 /* Late */), "Expected a late-bound symbol.");
                symbol.flags |= symbolFlags;
                getSymbolLinks(member.symbol).lateSymbol = symbol;
                if (!symbol.declarations) {
                    symbol.declarations = [member];
                }
                else if (!member.symbol.isReplaceableByMethod) {
                    symbol.declarations.push(member);
                }
                if (symbolFlags & 111551 /* Value */) {
                    if (!symbol.valueDeclaration || symbol.valueDeclaration.kind !== member.kind) {
                        symbol.valueDeclaration = member;
                    }
                }
            }
            function lateBindMember(parent2, earlySymbols, lateSymbols, decl) {
                Debug.assert(!!decl.symbol, "The member is expected to have a symbol.");
                const links = getNodeLinks(decl);
                if (!links.resolvedSymbol) {
                    links.resolvedSymbol = decl.symbol;
                    const declName = isBinaryExpression(decl) ? decl.left : decl.name;
                    const type = isElementAccessExpression(declName) ? checkExpressionCached(declName.argumentExpression) : checkComputedPropertyName(declName);
                    if (isTypeUsableAsPropertyName(type)) {
                        const memberName = getPropertyNameFromType(type);
                        const symbolFlags = decl.symbol.flags;
                        let lateSymbol = lateSymbols.get(memberName);
                        if (!lateSymbol)
                            lateSymbols.set(memberName, lateSymbol = createSymbol(0 /* None */, memberName, 4096 /* Late */));
                        const earlySymbol = earlySymbols && earlySymbols.get(memberName);
                        if (!(parent2.flags & 32 /* Class */) && (lateSymbol.flags & getExcludedSymbolFlags(symbolFlags) || earlySymbol)) {
                            const declarations = earlySymbol ? concatenate(earlySymbol.declarations, lateSymbol.declarations) : lateSymbol.declarations;
                            const name = !(type.flags & 8192 /* UniqueESSymbol */) && unescapeLeadingUnderscores(memberName) || declarationNameToString(declName);
                            forEach(declarations, (declaration) => error2(getNameOfDeclaration(declaration) || declaration, Diagnostics.Property_0_was_also_declared_here, name));
                            error2(declName || decl, Diagnostics.Duplicate_property_0, name);
                            lateSymbol = createSymbol(0 /* None */, memberName, 4096 /* Late */);
                        }
                        lateSymbol.links.nameType = type;
                        addDeclarationToLateBoundSymbol(lateSymbol, decl, symbolFlags);
                        if (lateSymbol.parent) {
                            Debug.assert(lateSymbol.parent === parent2, "Existing symbol parent should match new one");
                        }
                        else {
                            lateSymbol.parent = parent2;
                        }
                        return links.resolvedSymbol = lateSymbol;
                    }
                }
                return links.resolvedSymbol;
            }
            function getResolvedMembersOrExportsOfSymbol(symbol, resolutionKind) {
                const links = getSymbolLinks(symbol);
                if (!links[resolutionKind]) {
                    const isStatic2 = resolutionKind === "resolvedExports" /* resolvedExports */;
                    const earlySymbols = !isStatic2 ? symbol.members : symbol.flags & 1536 /* Module */ ? getExportsOfModuleWorker(symbol).exports : symbol.exports;
                    links[resolutionKind] = earlySymbols || emptySymbols;
                    const lateSymbols = createSymbolTable();
                    for (const decl of symbol.declarations || emptyArray) {
                        const members = getMembersOfDeclaration(decl);
                        if (members) {
                            for (const member of members) {
                                if (isStatic2 === hasStaticModifier(member)) {
                                    if (hasLateBindableName(member)) {
                                        lateBindMember(symbol, earlySymbols, lateSymbols, member);
                                    }
                                }
                            }
                        }
                    }
                    const assignments = getFunctionExpressionParentSymbolOrSymbol(symbol).assignmentDeclarationMembers;
                    if (assignments) {
                        const decls = arrayFrom(assignments.values());
                        for (const member of decls) {
                            const assignmentKind = getAssignmentDeclarationKind(member);
                            const isInstanceMember = assignmentKind === 3 /* PrototypeProperty */ || isBinaryExpression(member) && isPossiblyAliasedThisProperty(member, assignmentKind) || assignmentKind === 9 /* ObjectDefinePrototypeProperty */ || assignmentKind === 6 /* Prototype */;
                            if (isStatic2 === !isInstanceMember) {
                                if (hasLateBindableName(member)) {
                                    lateBindMember(symbol, earlySymbols, lateSymbols, member);
                                }
                            }
                        }
                    }
                    let resolved = combineSymbolTables(earlySymbols, lateSymbols);
                    if (symbol.flags & 33554432 /* Transient */ && links.cjsExportMerged && symbol.declarations) {
                        for (const decl of symbol.declarations) {
                            const original = getSymbolLinks(decl.symbol)[resolutionKind];
                            if (!resolved) {
                                resolved = original;
                                continue;
                            }
                            if (!original)
                                continue;
                            original.forEach((s, name) => {
                                const existing = resolved.get(name);
                                if (!existing)
                                    resolved.set(name, s);
                                else if (existing === s)
                                    return;
                                else
                                    resolved.set(name, mergeSymbol(existing, s));
                            });
                        }
                    }
                    links[resolutionKind] = resolved || emptySymbols;
                }
                return links[resolutionKind];
            }
            function getMembersOfSymbol(symbol) {
                return symbol.flags & 6256 /* LateBindingContainer */ ? getResolvedMembersOrExportsOfSymbol(symbol, "resolvedMembers" /* resolvedMembers */) : symbol.members || emptySymbols;
            }
            function getLateBoundSymbol(symbol) {
                if (symbol.flags & 106500 /* ClassMember */ && symbol.escapedName === "__computed" /* Computed */) {
                    const links = getSymbolLinks(symbol);
                    if (!links.lateSymbol && some(symbol.declarations, hasLateBindableName)) {
                        const parent2 = getMergedSymbol(symbol.parent);
                        if (some(symbol.declarations, hasStaticModifier)) {
                            getExportsOfSymbol(parent2);
                        }
                        else {
                            getMembersOfSymbol(parent2);
                        }
                    }
                    return links.lateSymbol || (links.lateSymbol = symbol);
                }
                return symbol;
            }
            function getTypeWithThisArgument(type, thisArgument, needApparentType) {
                if (getObjectFlags(type) & 4 /* Reference */) {
                    const target = type.target;
                    const typeArguments = getTypeArguments(type);
                    return length(target.typeParameters) === length(typeArguments) ? createTypeReference(target, concatenate(typeArguments, [thisArgument || target.thisType])) : type;
                }
                else if (type.flags & 2097152 /* Intersection */) {
                    const types = sameMap(type.types, (t) => getTypeWithThisArgument(t, thisArgument, needApparentType));
                    return types !== type.types ? getIntersectionType(types) : type;
                }
                return needApparentType ? getApparentType(type) : type;
            }
            function resolveObjectTypeMembers(type, source, typeParameters, typeArguments) {
                let mapper;
                let members;
                let callSignatures;
                let constructSignatures;
                let indexInfos;
                if (rangeEquals(typeParameters, typeArguments, 0, typeParameters.length)) {
                    members = source.symbol ? getMembersOfSymbol(source.symbol) : createSymbolTable(source.declaredProperties);
                    callSignatures = source.declaredCallSignatures;
                    constructSignatures = source.declaredConstructSignatures;
                    indexInfos = source.declaredIndexInfos;
                }
                else {
                    mapper = createTypeMapper(typeParameters, typeArguments);
                    members = createInstantiatedSymbolTable(source.declaredProperties, mapper, 
                    /*mappingThisOnly*/
                    typeParameters.length === 1);
                    callSignatures = instantiateSignatures(source.declaredCallSignatures, mapper);
                    constructSignatures = instantiateSignatures(source.declaredConstructSignatures, mapper);
                    indexInfos = instantiateIndexInfos(source.declaredIndexInfos, mapper);
                }
                const baseTypes = getBaseTypes(source);
                if (baseTypes.length) {
                    if (source.symbol && members === getMembersOfSymbol(source.symbol)) {
                        const symbolTable = createSymbolTable(source.declaredProperties);
                        const sourceIndex = getIndexSymbol(source.symbol);
                        if (sourceIndex) {
                            symbolTable.set("__index" /* Index */, sourceIndex);
                        }
                        members = symbolTable;
                    }
                    setStructuredTypeMembers(type, members, callSignatures, constructSignatures, indexInfos);
                    const thisArgument = lastOrUndefined(typeArguments);
                    for (const baseType of baseTypes) {
                        const instantiatedBaseType = thisArgument ? getTypeWithThisArgument(instantiateType(baseType, mapper), thisArgument) : baseType;
                        addInheritedMembers(members, getPropertiesOfType(instantiatedBaseType));
                        callSignatures = concatenate(callSignatures, getSignaturesOfType(instantiatedBaseType, 0 /* Call */));
                        constructSignatures = concatenate(constructSignatures, getSignaturesOfType(instantiatedBaseType, 1 /* Construct */));
                        const inheritedIndexInfos = instantiatedBaseType !== anyType ? getIndexInfosOfType(instantiatedBaseType) : [createIndexInfo(stringType, anyType, 
                            /*isReadonly*/
                            false)];
                        indexInfos = concatenate(indexInfos, filter(inheritedIndexInfos, (info) => !findIndexInfo(indexInfos, info.keyType)));
                    }
                }
                setStructuredTypeMembers(type, members, callSignatures, constructSignatures, indexInfos);
            }
            function resolveClassOrInterfaceMembers(type) {
                resolveObjectTypeMembers(type, resolveDeclaredMembers(type), emptyArray, emptyArray);
            }
            function resolveTypeReferenceMembers(type) {
                const source = resolveDeclaredMembers(type.target);
                const typeParameters = concatenate(source.typeParameters, [source.thisType]);
                const typeArguments = getTypeArguments(type);
                const paddedTypeArguments = typeArguments.length === typeParameters.length ? typeArguments : concatenate(typeArguments, [type]);
                resolveObjectTypeMembers(type, source, typeParameters, paddedTypeArguments);
            }
            function createSignature(declaration, typeParameters, thisParameter, parameters, resolvedReturnType, resolvedTypePredicate, minArgumentCount, flags) {
                const sig = new Signature14(checker, flags);
                sig.declaration = declaration;
                sig.typeParameters = typeParameters;
                sig.parameters = parameters;
                sig.thisParameter = thisParameter;
                sig.resolvedReturnType = resolvedReturnType;
                sig.resolvedTypePredicate = resolvedTypePredicate;
                sig.minArgumentCount = minArgumentCount;
                sig.resolvedMinArgumentCount = void 0;
                sig.target = void 0;
                sig.mapper = void 0;
                sig.compositeSignatures = void 0;
                sig.compositeKind = void 0;
                return sig;
            }
            function cloneSignature(sig) {
                const result = createSignature(sig.declaration, sig.typeParameters, sig.thisParameter, sig.parameters, 
                /*resolvedReturnType*/
                void 0, 
                /*resolvedTypePredicate*/
                void 0, sig.minArgumentCount, sig.flags & 167 /* PropagatingFlags */);
                result.target = sig.target;
                result.mapper = sig.mapper;
                result.compositeSignatures = sig.compositeSignatures;
                result.compositeKind = sig.compositeKind;
                return result;
            }
            function createUnionSignature(signature, unionSignatures) {
                const result = cloneSignature(signature);
                result.compositeSignatures = unionSignatures;
                result.compositeKind = 1048576 /* Union */;
                result.target = void 0;
                result.mapper = void 0;
                return result;
            }
            function getOptionalCallSignature(signature, callChainFlags) {
                if ((signature.flags & 24 /* CallChainFlags */) === callChainFlags) {
                    return signature;
                }
                if (!signature.optionalCallSignatureCache) {
                    signature.optionalCallSignatureCache = {};
                }
                const key = callChainFlags === 8 /* IsInnerCallChain */ ? "inner" : "outer";
                return signature.optionalCallSignatureCache[key] || (signature.optionalCallSignatureCache[key] = createOptionalCallSignature(signature, callChainFlags));
            }
            function createOptionalCallSignature(signature, callChainFlags) {
                Debug.assert(callChainFlags === 8 /* IsInnerCallChain */ || callChainFlags === 16 /* IsOuterCallChain */, "An optional call signature can either be for an inner call chain or an outer call chain, but not both.");
                const result = cloneSignature(signature);
                result.flags |= callChainFlags;
                return result;
            }
            function getExpandedParameters(sig, skipUnionExpanding) {
                if (signatureHasRestParameter(sig)) {
                    const restIndex = sig.parameters.length - 1;
                    const restName = sig.parameters[restIndex].escapedName;
                    const restType = getTypeOfSymbol(sig.parameters[restIndex]);
                    if (isTupleType(restType)) {
                        return [expandSignatureParametersWithTupleMembers(restType, restIndex, restName)];
                    }
                    else if (!skipUnionExpanding && restType.flags & 1048576 /* Union */ && every(restType.types, isTupleType)) {
                        return map(restType.types, (t) => expandSignatureParametersWithTupleMembers(t, restIndex, restName));
                    }
                }
                return [sig.parameters];
                function expandSignatureParametersWithTupleMembers(restType, restIndex, restName) {
                    const elementTypes = getTypeArguments(restType);
                    const associatedNames = getUniqAssociatedNamesFromTupleType(restType, restName);
                    const restParams = map(elementTypes, (t, i) => {
                        const name = associatedNames && associatedNames[i] ? associatedNames[i] : getParameterNameAtPosition(sig, restIndex + i, restType);
                        const flags = restType.target.elementFlags[i];
                        const checkFlags = flags & 12 /* Variable */ ? 32768 /* RestParameter */ : flags & 2 /* Optional */ ? 16384 /* OptionalParameter */ : 0;
                        const symbol = createSymbol(1 /* FunctionScopedVariable */, name, checkFlags);
                        symbol.links.type = flags & 4 /* Rest */ ? createArrayType(t) : t;
                        return symbol;
                    });
                    return concatenate(sig.parameters.slice(0, restIndex), restParams);
                }
                function getUniqAssociatedNamesFromTupleType(type, restName) {
                    const associatedNamesMap = /* @__PURE__ */ new Map();
                    return map(type.target.labeledElementDeclarations, (labeledElement, i) => {
                        const name = getTupleElementLabel(labeledElement, i, restName);
                        const prevCounter = associatedNamesMap.get(name);
                        if (prevCounter === void 0) {
                            associatedNamesMap.set(name, 1);
                            return name;
                        }
                        else {
                            associatedNamesMap.set(name, prevCounter + 1);
                            return `${name}_${prevCounter}`;
                        }
                    });
                }
            }
            function getDefaultConstructSignatures(classType) {
                const baseConstructorType = getBaseConstructorTypeOfClass(classType);
                const baseSignatures = getSignaturesOfType(baseConstructorType, 1 /* Construct */);
                const declaration = getClassLikeDeclarationOfSymbol(classType.symbol);
                const isAbstract = !!declaration && hasSyntacticModifier(declaration, 64 /* Abstract */);
                if (baseSignatures.length === 0) {
                    return [createSignature(
                        /*declaration*/
                        void 0, classType.localTypeParameters, 
                        /*thisParameter*/
                        void 0, emptyArray, classType, 
                        /*resolvedTypePredicate*/
                        void 0, 0, isAbstract ? 4 /* Abstract */ : 0 /* None */)];
                }
                const baseTypeNode = getBaseTypeNodeOfClass(classType);
                const isJavaScript = isInJSFile(baseTypeNode);
                const typeArguments = typeArgumentsFromTypeReferenceNode(baseTypeNode);
                const typeArgCount = length(typeArguments);
                const result = [];
                for (const baseSig of baseSignatures) {
                    const minTypeArgumentCount = getMinTypeArgumentCount(baseSig.typeParameters);
                    const typeParamCount = length(baseSig.typeParameters);
                    if (isJavaScript || typeArgCount >= minTypeArgumentCount && typeArgCount <= typeParamCount) {
                        const sig = typeParamCount ? createSignatureInstantiation(baseSig, fillMissingTypeArguments(typeArguments, baseSig.typeParameters, minTypeArgumentCount, isJavaScript)) : cloneSignature(baseSig);
                        sig.typeParameters = classType.localTypeParameters;
                        sig.resolvedReturnType = classType;
                        sig.flags = isAbstract ? sig.flags | 4 /* Abstract */ : sig.flags & ~4 /* Abstract */;
                        result.push(sig);
                    }
                }
                return result;
            }
            function findMatchingSignature(signatureList, signature, partialMatch, ignoreThisTypes, ignoreReturnTypes) {
                for (const s of signatureList) {
                    if (compareSignaturesIdentical(s, signature, partialMatch, ignoreThisTypes, ignoreReturnTypes, partialMatch ? compareTypesSubtypeOf : compareTypesIdentical)) {
                        return s;
                    }
                }
            }
            function findMatchingSignatures(signatureLists, signature, listIndex) {
                if (signature.typeParameters) {
                    if (listIndex > 0) {
                        return void 0;
                    }
                    for (let i = 1; i < signatureLists.length; i++) {
                        if (!findMatchingSignature(signatureLists[i], signature, 
                        /*partialMatch*/
                        false, 
                        /*ignoreThisTypes*/
                        false, 
                        /*ignoreReturnTypes*/
                        false)) {
                            return void 0;
                        }
                    }
                    return [signature];
                }
                let result;
                for (let i = 0; i < signatureLists.length; i++) {
                    const match = i === listIndex ? signature : findMatchingSignature(signatureLists[i], signature, 
                    /*partialMatch*/
                    false, 
                    /*ignoreThisTypes*/
                    false, 
                    /*ignoreReturnTypes*/
                    true) || findMatchingSignature(signatureLists[i], signature, 
                    /*partialMatch*/
                    true, 
                    /*ignoreThisTypes*/
                    false, 
                    /*ignoreReturnTypes*/
                    true);
                    if (!match) {
                        return void 0;
                    }
                    result = appendIfUnique(result, match);
                }
                return result;
            }
            function getUnionSignatures(signatureLists) {
                let result;
                let indexWithLengthOverOne;
                for (let i = 0; i < signatureLists.length; i++) {
                    if (signatureLists[i].length === 0)
                        return emptyArray;
                    if (signatureLists[i].length > 1) {
                        indexWithLengthOverOne = indexWithLengthOverOne === void 0 ? i : -1;
                    }
                    for (const signature of signatureLists[i]) {
                        if (!result || !findMatchingSignature(result, signature, 
                        /*partialMatch*/
                        false, 
                        /*ignoreThisTypes*/
                        false, 
                        /*ignoreReturnTypes*/
                        true)) {
                            const unionSignatures = findMatchingSignatures(signatureLists, signature, i);
                            if (unionSignatures) {
                                let s = signature;
                                if (unionSignatures.length > 1) {
                                    let thisParameter = signature.thisParameter;
                                    const firstThisParameterOfUnionSignatures = forEach(unionSignatures, (sig) => sig.thisParameter);
                                    if (firstThisParameterOfUnionSignatures) {
                                        const thisType = getIntersectionType(mapDefined(unionSignatures, (sig) => sig.thisParameter && getTypeOfSymbol(sig.thisParameter)));
                                        thisParameter = createSymbolWithType(firstThisParameterOfUnionSignatures, thisType);
                                    }
                                    s = createUnionSignature(signature, unionSignatures);
                                    s.thisParameter = thisParameter;
                                }
                                (result || (result = [])).push(s);
                            }
                        }
                    }
                }
                if (!length(result) && indexWithLengthOverOne !== -1) {
                    const masterList = signatureLists[indexWithLengthOverOne !== void 0 ? indexWithLengthOverOne : 0];
                    let results = masterList.slice();
                    for (const signatures of signatureLists) {
                        if (signatures !== masterList) {
                            const signature = signatures[0];
                            Debug.assert(!!signature, "getUnionSignatures bails early on empty signature lists and should not have empty lists on second pass");
                            results = !!signature.typeParameters && some(results, (s) => !!s.typeParameters && !compareTypeParametersIdentical(signature.typeParameters, s.typeParameters)) ? void 0 : map(results, (sig) => combineSignaturesOfUnionMembers(sig, signature));
                            if (!results) {
                                break;
                            }
                        }
                    }
                    result = results;
                }
                return result || emptyArray;
            }
            function compareTypeParametersIdentical(sourceParams, targetParams) {
                if (length(sourceParams) !== length(targetParams)) {
                    return false;
                }
                if (!sourceParams || !targetParams) {
                    return true;
                }
                const mapper = createTypeMapper(targetParams, sourceParams);
                for (let i = 0; i < sourceParams.length; i++) {
                    const source = sourceParams[i];
                    const target = targetParams[i];
                    if (source === target)
                        continue;
                    if (!isTypeIdenticalTo(getConstraintFromTypeParameter(source) || unknownType, instantiateType(getConstraintFromTypeParameter(target) || unknownType, mapper)))
                        return false;
                }
                return true;
            }
            function combineUnionThisParam(left, right, mapper) {
                if (!left || !right) {
                    return left || right;
                }
                const thisType = getIntersectionType([getTypeOfSymbol(left), instantiateType(getTypeOfSymbol(right), mapper)]);
                return createSymbolWithType(left, thisType);
            }
            function combineUnionParameters(left, right, mapper) {
                const leftCount = getParameterCount(left);
                const rightCount = getParameterCount(right);
                const longest = leftCount >= rightCount ? left : right;
                const shorter = longest === left ? right : left;
                const longestCount = longest === left ? leftCount : rightCount;
                const eitherHasEffectiveRest = hasEffectiveRestParameter(left) || hasEffectiveRestParameter(right);
                const needsExtraRestElement = eitherHasEffectiveRest && !hasEffectiveRestParameter(longest);
                const params = new Array(longestCount + (needsExtraRestElement ? 1 : 0));
                for (let i = 0; i < longestCount; i++) {
                    let longestParamType = tryGetTypeAtPosition(longest, i);
                    if (longest === right) {
                        longestParamType = instantiateType(longestParamType, mapper);
                    }
                    let shorterParamType = tryGetTypeAtPosition(shorter, i) || unknownType;
                    if (shorter === right) {
                        shorterParamType = instantiateType(shorterParamType, mapper);
                    }
                    const unionParamType = getIntersectionType([longestParamType, shorterParamType]);
                    const isRestParam = eitherHasEffectiveRest && !needsExtraRestElement && i === longestCount - 1;
                    const isOptional = i >= getMinArgumentCount(longest) && i >= getMinArgumentCount(shorter);
                    const leftName = i >= leftCount ? void 0 : getParameterNameAtPosition(left, i);
                    const rightName = i >= rightCount ? void 0 : getParameterNameAtPosition(right, i);
                    const paramName = leftName === rightName ? leftName : !leftName ? rightName : !rightName ? leftName : void 0;
                    const paramSymbol = createSymbol(1 /* FunctionScopedVariable */ | (isOptional && !isRestParam ? 16777216 /* Optional */ : 0), paramName || `arg${i}`, isRestParam ? 32768 /* RestParameter */ : isOptional ? 16384 /* OptionalParameter */ : 0);
                    paramSymbol.links.type = isRestParam ? createArrayType(unionParamType) : unionParamType;
                    params[i] = paramSymbol;
                }
                if (needsExtraRestElement) {
                    const restParamSymbol = createSymbol(1 /* FunctionScopedVariable */, "args", 32768 /* RestParameter */);
                    restParamSymbol.links.type = createArrayType(getTypeAtPosition(shorter, longestCount));
                    if (shorter === right) {
                        restParamSymbol.links.type = instantiateType(restParamSymbol.links.type, mapper);
                    }
                    params[longestCount] = restParamSymbol;
                }
                return params;
            }
            function combineSignaturesOfUnionMembers(left, right) {
                const typeParams = left.typeParameters || right.typeParameters;
                let paramMapper;
                if (left.typeParameters && right.typeParameters) {
                    paramMapper = createTypeMapper(right.typeParameters, left.typeParameters);
                }
                const declaration = left.declaration;
                const params = combineUnionParameters(left, right, paramMapper);
                const thisParam = combineUnionThisParam(left.thisParameter, right.thisParameter, paramMapper);
                const minArgCount = Math.max(left.minArgumentCount, right.minArgumentCount);
                const result = createSignature(declaration, typeParams, thisParam, params, 
                /*resolvedReturnType*/
                void 0, 
                /*resolvedTypePredicate*/
                void 0, minArgCount, (left.flags | right.flags) & 167 /* PropagatingFlags */);
                result.compositeKind = 1048576 /* Union */;
                result.compositeSignatures = concatenate(left.compositeKind !== 2097152 /* Intersection */ && left.compositeSignatures || [left], [right]);
                if (paramMapper) {
                    result.mapper = left.compositeKind !== 2097152 /* Intersection */ && left.mapper && left.compositeSignatures ? combineTypeMappers(left.mapper, paramMapper) : paramMapper;
                }
                else if (left.compositeKind !== 2097152 /* Intersection */ && left.mapper && left.compositeSignatures) {
                    result.mapper = left.mapper;
                }
                return result;
            }
            function getUnionIndexInfos(types) {
                const sourceInfos = getIndexInfosOfType(types[0]);
                if (sourceInfos) {
                    const result = [];
                    for (const info of sourceInfos) {
                        const indexType = info.keyType;
                        if (every(types, (t) => !!getIndexInfoOfType(t, indexType))) {
                            result.push(createIndexInfo(indexType, getUnionType(map(types, (t) => getIndexTypeOfType(t, indexType))), some(types, (t) => getIndexInfoOfType(t, indexType).isReadonly)));
                        }
                    }
                    return result;
                }
                return emptyArray;
            }
            function resolveUnionTypeMembers(type) {
                const callSignatures = getUnionSignatures(map(type.types, (t) => t === globalFunctionType ? [unknownSignature] : getSignaturesOfType(t, 0 /* Call */)));
                const constructSignatures = getUnionSignatures(map(type.types, (t) => getSignaturesOfType(t, 1 /* Construct */)));
                const indexInfos = getUnionIndexInfos(type.types);
                setStructuredTypeMembers(type, emptySymbols, callSignatures, constructSignatures, indexInfos);
            }
            function intersectTypes(type1, type2) {
                return !type1 ? type2 : !type2 ? type1 : getIntersectionType([type1, type2]);
            }
            function findMixins(types) {
                const constructorTypeCount = countWhere(types, (t) => getSignaturesOfType(t, 1 /* Construct */).length > 0);
                const mixinFlags = map(types, isMixinConstructorType);
                if (constructorTypeCount > 0 && constructorTypeCount === countWhere(mixinFlags, (b) => b)) {
                    const firstMixinIndex = mixinFlags.indexOf(
                    /*searchElement*/
                    true);
                    mixinFlags[firstMixinIndex] = false;
                }
                return mixinFlags;
            }
            function includeMixinType(type, types, mixinFlags, index) {
                const mixedTypes = [];
                for (let i = 0; i < types.length; i++) {
                    if (i === index) {
                        mixedTypes.push(type);
                    }
                    else if (mixinFlags[i]) {
                        mixedTypes.push(getReturnTypeOfSignature(getSignaturesOfType(types[i], 1 /* Construct */)[0]));
                    }
                }
                return getIntersectionType(mixedTypes);
            }
            function resolveIntersectionTypeMembers(type) {
                let callSignatures;
                let constructSignatures;
                let indexInfos;
                const types = type.types;
                const mixinFlags = findMixins(types);
                const mixinCount = countWhere(mixinFlags, (b) => b);
                for (let i = 0; i < types.length; i++) {
                    const t = type.types[i];
                    if (!mixinFlags[i]) {
                        let signatures = getSignaturesOfType(t, 1 /* Construct */);
                        if (signatures.length && mixinCount > 0) {
                            signatures = map(signatures, (s) => {
                                const clone2 = cloneSignature(s);
                                clone2.resolvedReturnType = includeMixinType(getReturnTypeOfSignature(s), types, mixinFlags, i);
                                return clone2;
                            });
                        }
                        constructSignatures = appendSignatures(constructSignatures, signatures);
                    }
                    callSignatures = appendSignatures(callSignatures, getSignaturesOfType(t, 0 /* Call */));
                    indexInfos = reduceLeft(getIndexInfosOfType(t), (infos, newInfo) => appendIndexInfo(infos, newInfo, 
                    /*union*/
                    false), indexInfos);
                }
                setStructuredTypeMembers(type, emptySymbols, callSignatures || emptyArray, constructSignatures || emptyArray, indexInfos || emptyArray);
            }
            function appendSignatures(signatures, newSignatures) {
                for (const sig of newSignatures) {
                    if (!signatures || every(signatures, (s) => !compareSignaturesIdentical(s, sig, 
                    /*partialMatch*/
                    false, 
                    /*ignoreThisTypes*/
                    false, 
                    /*ignoreReturnTypes*/
                    false, compareTypesIdentical))) {
                        signatures = append(signatures, sig);
                    }
                }
                return signatures;
            }
            function appendIndexInfo(indexInfos, newInfo, union) {
                if (indexInfos) {
                    for (let i = 0; i < indexInfos.length; i++) {
                        const info = indexInfos[i];
                        if (info.keyType === newInfo.keyType) {
                            indexInfos[i] = createIndexInfo(info.keyType, union ? getUnionType([info.type, newInfo.type]) : getIntersectionType([info.type, newInfo.type]), union ? info.isReadonly || newInfo.isReadonly : info.isReadonly && newInfo.isReadonly);
                            return indexInfos;
                        }
                    }
                }
                return append(indexInfos, newInfo);
            }
            function resolveAnonymousTypeMembers(type) {
                if (type.target) {
                    setStructuredTypeMembers(type, emptySymbols, emptyArray, emptyArray, emptyArray);
                    const members2 = createInstantiatedSymbolTable(getPropertiesOfObjectType(type.target), type.mapper, 
                    /*mappingThisOnly*/
                    false);
                    const callSignatures = instantiateSignatures(getSignaturesOfType(type.target, 0 /* Call */), type.mapper);
                    const constructSignatures = instantiateSignatures(getSignaturesOfType(type.target, 1 /* Construct */), type.mapper);
                    const indexInfos2 = instantiateIndexInfos(getIndexInfosOfType(type.target), type.mapper);
                    setStructuredTypeMembers(type, members2, callSignatures, constructSignatures, indexInfos2);
                    return;
                }
                const symbol = getMergedSymbol(type.symbol);
                if (symbol.flags & 2048 /* TypeLiteral */) {
                    setStructuredTypeMembers(type, emptySymbols, emptyArray, emptyArray, emptyArray);
                    const members2 = getMembersOfSymbol(symbol);
                    const callSignatures = getSignaturesOfSymbol(members2.get("__call" /* Call */));
                    const constructSignatures = getSignaturesOfSymbol(members2.get("__new" /* New */));
                    const indexInfos2 = getIndexInfosOfSymbol(symbol);
                    setStructuredTypeMembers(type, members2, callSignatures, constructSignatures, indexInfos2);
                    return;
                }
                let members = getExportsOfSymbol(symbol);
                let indexInfos;
                if (symbol === globalThisSymbol) {
                    const varsOnly = /* @__PURE__ */ new Map();
                    members.forEach((p) => {
                        var _a;
                        if (!(p.flags & 418 /* BlockScoped */) && !(p.flags & 512 /* ValueModule */ && ((_a = p.declarations) == null ? void 0 : _a.length) && every(p.declarations, isAmbientModule))) {
                            varsOnly.set(p.escapedName, p);
                        }
                    });
                    members = varsOnly;
                }
                let baseConstructorIndexInfo;
                setStructuredTypeMembers(type, members, emptyArray, emptyArray, emptyArray);
                if (symbol.flags & 32 /* Class */) {
                    const classType = getDeclaredTypeOfClassOrInterface(symbol);
                    const baseConstructorType = getBaseConstructorTypeOfClass(classType);
                    if (baseConstructorType.flags & (524288 /* Object */ | 2097152 /* Intersection */ | 8650752 /* TypeVariable */)) {
                        members = createSymbolTable(getNamedOrIndexSignatureMembers(members));
                        addInheritedMembers(members, getPropertiesOfType(baseConstructorType));
                    }
                    else if (baseConstructorType === anyType) {
                        baseConstructorIndexInfo = createIndexInfo(stringType, anyType, 
                        /*isReadonly*/
                        false);
                    }
                }
                const indexSymbol = getIndexSymbolFromSymbolTable(members);
                if (indexSymbol) {
                    indexInfos = getIndexInfosOfIndexSymbol(indexSymbol);
                }
                else {
                    if (baseConstructorIndexInfo) {
                        indexInfos = append(indexInfos, baseConstructorIndexInfo);
                    }
                    if (symbol.flags & 384 /* Enum */ && (getDeclaredTypeOfSymbol(symbol).flags & 32 /* Enum */ || some(type.properties, (prop) => !!(getTypeOfSymbol(prop).flags & 296 /* NumberLike */)))) {
                        indexInfos = append(indexInfos, enumNumberIndexInfo);
                    }
                }
                setStructuredTypeMembers(type, members, emptyArray, emptyArray, indexInfos || emptyArray);
                if (symbol.flags & (16 /* Function */ | 8192 /* Method */)) {
                    type.callSignatures = getSignaturesOfSymbol(symbol);
                }
                if (symbol.flags & 32 /* Class */) {
                    const classType = getDeclaredTypeOfClassOrInterface(symbol);
                    let constructSignatures = symbol.members ? getSignaturesOfSymbol(symbol.members.get("__constructor" /* Constructor */)) : emptyArray;
                    if (symbol.flags & 16 /* Function */) {
                        constructSignatures = addRange(constructSignatures.slice(), mapDefined(type.callSignatures, (sig) => isJSConstructor(sig.declaration) ? createSignature(sig.declaration, sig.typeParameters, sig.thisParameter, sig.parameters, classType, 
                        /*resolvedTypePredicate*/
                        void 0, sig.minArgumentCount, sig.flags & 167 /* PropagatingFlags */) : void 0));
                    }
                    if (!constructSignatures.length) {
                        constructSignatures = getDefaultConstructSignatures(classType);
                    }
                    type.constructSignatures = constructSignatures;
                }
            }
            function replaceIndexedAccess(instantiable, type, replacement) {
                return instantiateType(instantiable, createTypeMapper([type.indexType, type.objectType], [getNumberLiteralType(0), createTupleType([replacement])]));
            }
            function getLimitedConstraint(type) {
                const constraint = getConstraintTypeFromMappedType(type.mappedType);
                if (!(constraint.flags & 1048576 /* Union */ || constraint.flags & 2097152 /* Intersection */)) {
                    return;
                }
                const origin = constraint.flags & 1048576 /* Union */ ? constraint.origin : constraint;
                if (!origin || !(origin.flags & 2097152 /* Intersection */)) {
                    return;
                }
                const limitedConstraint = getIntersectionType(origin.types.filter((t) => t !== type.constraintType));
                return limitedConstraint !== neverType ? limitedConstraint : void 0;
            }
            function resolveReverseMappedTypeMembers(type) {
                const indexInfo = getIndexInfoOfType(type.source, stringType);
                const modifiers = getMappedTypeModifiers(type.mappedType);
                const readonlyMask = modifiers & 1 /* IncludeReadonly */ ? false : true;
                const optionalMask = modifiers & 4 /* IncludeOptional */ ? 0 : 16777216 /* Optional */;
                const indexInfos = indexInfo ? [createIndexInfo(stringType, inferReverseMappedType(indexInfo.type, type.mappedType, type.constraintType), readonlyMask && indexInfo.isReadonly)] : emptyArray;
                const members = createSymbolTable();
                const limitedConstraint = getLimitedConstraint(type);
                for (const prop of getPropertiesOfType(type.source)) {
                    if (limitedConstraint) {
                        const propertyNameType = getLiteralTypeFromProperty(prop, 8576 /* StringOrNumberLiteralOrUnique */);
                        if (!isTypeAssignableTo(propertyNameType, limitedConstraint)) {
                            continue;
                        }
                    }
                    const checkFlags = 8192 /* ReverseMapped */ | (readonlyMask && isReadonlySymbol(prop) ? 8 /* Readonly */ : 0);
                    const inferredProp = createSymbol(4 /* Property */ | prop.flags & optionalMask, prop.escapedName, checkFlags);
                    inferredProp.declarations = prop.declarations;
                    inferredProp.links.nameType = getSymbolLinks(prop).nameType;
                    inferredProp.links.propertyType = getTypeOfSymbol(prop);
                    if (type.constraintType.type.flags & 8388608 /* IndexedAccess */ && type.constraintType.type.objectType.flags & 262144 /* TypeParameter */ && type.constraintType.type.indexType.flags & 262144 /* TypeParameter */) {
                        const newTypeParam = type.constraintType.type.objectType;
                        const newMappedType = replaceIndexedAccess(type.mappedType, type.constraintType.type, newTypeParam);
                        inferredProp.links.mappedType = newMappedType;
                        inferredProp.links.constraintType = getIndexType(newTypeParam);
                    }
                    else {
                        inferredProp.links.mappedType = type.mappedType;
                        inferredProp.links.constraintType = type.constraintType;
                    }
                    members.set(prop.escapedName, inferredProp);
                }
                setStructuredTypeMembers(type, members, emptyArray, emptyArray, indexInfos);
            }
            function getLowerBoundOfKeyType(type) {
                if (type.flags & 4194304 /* Index */) {
                    const t = getApparentType(type.type);
                    return isGenericTupleType(t) ? getKnownKeysOfTupleType(t) : getIndexType(t);
                }
                if (type.flags & 16777216 /* Conditional */) {
                    if (type.root.isDistributive) {
                        const checkType = type.checkType;
                        const constraint = getLowerBoundOfKeyType(checkType);
                        if (constraint !== checkType) {
                            return getConditionalTypeInstantiation(type, prependTypeMapping(type.root.checkType, constraint, type.mapper), 
                            /*forConstraint*/
                            false);
                        }
                    }
                    return type;
                }
                if (type.flags & 1048576 /* Union */) {
                    return mapType(type, getLowerBoundOfKeyType, 
                    /*noReductions*/
                    true);
                }
                if (type.flags & 2097152 /* Intersection */) {
                    const types = type.types;
                    if (types.length === 2 && !!(types[0].flags & (4 /* String */ | 8 /* Number */ | 64 /* BigInt */)) && types[1] === emptyTypeLiteralType) {
                        return type;
                    }
                    return getIntersectionType(sameMap(type.types, getLowerBoundOfKeyType));
                }
                return type;
            }
            function getIsLateCheckFlag(s) {
                return getCheckFlags(s) & 4096 /* Late */;
            }
            function forEachMappedTypePropertyKeyTypeAndIndexSignatureKeyType(type, include, stringsOnly, cb) {
                for (const prop of getPropertiesOfType(type)) {
                    cb(getLiteralTypeFromProperty(prop, include));
                }
                if (type.flags & 1 /* Any */) {
                    cb(stringType);
                }
                else {
                    for (const info of getIndexInfosOfType(type)) {
                        if (!stringsOnly || info.keyType.flags & (4 /* String */ | 134217728 /* TemplateLiteral */)) {
                            cb(info.keyType);
                        }
                    }
                }
            }
            function resolveMappedTypeMembers(type) {
                const members = createSymbolTable();
                let indexInfos;
                setStructuredTypeMembers(type, emptySymbols, emptyArray, emptyArray, emptyArray);
                const typeParameter = getTypeParameterFromMappedType(type);
                const constraintType = getConstraintTypeFromMappedType(type);
                const mappedType = type.target || type;
                const nameType = getNameTypeFromMappedType(mappedType);
                const shouldLinkPropDeclarations = getMappedTypeNameTypeKind(mappedType) !== 2 /* Remapping */;
                const templateType = getTemplateTypeFromMappedType(mappedType);
                const modifiersType = getApparentType(getModifiersTypeFromMappedType(type));
                const templateModifiers = getMappedTypeModifiers(type);
                const include = keyofStringsOnly ? 128 /* StringLiteral */ : 8576 /* StringOrNumberLiteralOrUnique */;
                if (isMappedTypeWithKeyofConstraintDeclaration(type)) {
                    forEachMappedTypePropertyKeyTypeAndIndexSignatureKeyType(modifiersType, include, keyofStringsOnly, addMemberForKeyType);
                }
                else {
                    forEachType(getLowerBoundOfKeyType(constraintType), addMemberForKeyType);
                }
                setStructuredTypeMembers(type, members, emptyArray, emptyArray, indexInfos || emptyArray);
                function addMemberForKeyType(keyType) {
                    const propNameType = nameType ? instantiateType(nameType, appendTypeMapping(type.mapper, typeParameter, keyType)) : keyType;
                    forEachType(propNameType, (t) => addMemberForKeyTypeWorker(keyType, t));
                }
                function addMemberForKeyTypeWorker(keyType, propNameType) {
                    if (isTypeUsableAsPropertyName(propNameType)) {
                        const propName = getPropertyNameFromType(propNameType);
                        const existingProp = members.get(propName);
                        if (existingProp) {
                            existingProp.links.nameType = getUnionType([existingProp.links.nameType, propNameType]);
                            existingProp.links.keyType = getUnionType([existingProp.links.keyType, keyType]);
                        }
                        else {
                            const modifiersProp = isTypeUsableAsPropertyName(keyType) ? getPropertyOfType(modifiersType, getPropertyNameFromType(keyType)) : void 0;
                            const isOptional = !!(templateModifiers & 4 /* IncludeOptional */ || !(templateModifiers & 8 /* ExcludeOptional */) && modifiersProp && modifiersProp.flags & 16777216 /* Optional */);
                            const isReadonly = !!(templateModifiers & 1 /* IncludeReadonly */ || !(templateModifiers & 2 /* ExcludeReadonly */) && modifiersProp && isReadonlySymbol(modifiersProp));
                            const stripOptional = strictNullChecks && !isOptional && modifiersProp && modifiersProp.flags & 16777216 /* Optional */;
                            const lateFlag = modifiersProp ? getIsLateCheckFlag(modifiersProp) : 0;
                            const prop = createSymbol(4 /* Property */ | (isOptional ? 16777216 /* Optional */ : 0), propName, lateFlag | 262144 /* Mapped */ | (isReadonly ? 8 /* Readonly */ : 0) | (stripOptional ? 524288 /* StripOptional */ : 0));
                            prop.links.mappedType = type;
                            prop.links.nameType = propNameType;
                            prop.links.keyType = keyType;
                            if (modifiersProp) {
                                prop.links.syntheticOrigin = modifiersProp;
                                prop.declarations = shouldLinkPropDeclarations ? modifiersProp.declarations : void 0;
                            }
                            members.set(propName, prop);
                        }
                    }
                    else if (isValidIndexKeyType(propNameType) || propNameType.flags & (1 /* Any */ | 32 /* Enum */)) {
                        const indexKeyType = propNameType.flags & (1 /* Any */ | 4 /* String */) ? stringType : propNameType.flags & (8 /* Number */ | 32 /* Enum */) ? numberType : propNameType;
                        const propType = instantiateType(templateType, appendTypeMapping(type.mapper, typeParameter, keyType));
                        const modifiersIndexInfo = getApplicableIndexInfo(modifiersType, propNameType);
                        const isReadonly = !!(templateModifiers & 1 /* IncludeReadonly */ || !(templateModifiers & 2 /* ExcludeReadonly */) && (modifiersIndexInfo == null ? void 0 : modifiersIndexInfo.isReadonly));
                        const indexInfo = createIndexInfo(indexKeyType, propType, isReadonly);
                        indexInfos = appendIndexInfo(indexInfos, indexInfo, 
                        /*union*/
                        true);
                    }
                }
            }
            function getTypeOfMappedSymbol(symbol) {
                if (!symbol.links.type) {
                    const mappedType = symbol.links.mappedType;
                    if (!pushTypeResolution(symbol, 0 /* Type */)) {
                        mappedType.containsError = true;
                        return errorType;
                    }
                    const templateType = getTemplateTypeFromMappedType(mappedType.target || mappedType);
                    const mapper = appendTypeMapping(mappedType.mapper, getTypeParameterFromMappedType(mappedType), symbol.links.keyType);
                    const propType = instantiateType(templateType, mapper);
                    let type = strictNullChecks && symbol.flags & 16777216 /* Optional */ && !maybeTypeOfKind(propType, 32768 /* Undefined */ | 16384 /* Void */) ? getOptionalType(propType, 
                    /*isProperty*/
                    true) : symbol.links.checkFlags & 524288 /* StripOptional */ ? removeMissingOrUndefinedType(propType) : propType;
                    if (!popTypeResolution()) {
                        error2(currentNode, Diagnostics.Type_of_property_0_circularly_references_itself_in_mapped_type_1, symbolToString(symbol), typeToString(mappedType));
                        type = errorType;
                    }
                    symbol.links.type = type;
                }
                return symbol.links.type;
            }
            function getTypeParameterFromMappedType(type) {
                return type.typeParameter || (type.typeParameter = getDeclaredTypeOfTypeParameter(getSymbolOfDeclaration(type.declaration.typeParameter)));
            }
            function getConstraintTypeFromMappedType(type) {
                return type.constraintType || (type.constraintType = getConstraintOfTypeParameter(getTypeParameterFromMappedType(type)) || errorType);
            }
            function getNameTypeFromMappedType(type) {
                return type.declaration.nameType ? type.nameType || (type.nameType = instantiateType(getTypeFromTypeNode(type.declaration.nameType), type.mapper)) : void 0;
            }
            function getTemplateTypeFromMappedType(type) {
                return type.templateType || (type.templateType = type.declaration.type ? instantiateType(addOptionality(getTypeFromTypeNode(type.declaration.type), 
                /*isProperty*/
                true, !!(getMappedTypeModifiers(type) & 4 /* IncludeOptional */)), type.mapper) : errorType);
            }
            function getConstraintDeclarationForMappedType(type) {
                return getEffectiveConstraintOfTypeParameter(type.declaration.typeParameter);
            }
            function isMappedTypeWithKeyofConstraintDeclaration(type) {
                const constraintDeclaration = getConstraintDeclarationForMappedType(type);
                return constraintDeclaration.kind === 198 /* TypeOperator */ && constraintDeclaration.operator === 143 /* KeyOfKeyword */;
            }
            function getModifiersTypeFromMappedType(type) {
                if (!type.modifiersType) {
                    if (isMappedTypeWithKeyofConstraintDeclaration(type)) {
                        type.modifiersType = instantiateType(getTypeFromTypeNode(getConstraintDeclarationForMappedType(type).type), type.mapper);
                    }
                    else {
                        const declaredType = getTypeFromMappedTypeNode(type.declaration);
                        const constraint = getConstraintTypeFromMappedType(declaredType);
                        const extendedConstraint = constraint && constraint.flags & 262144 /* TypeParameter */ ? getConstraintOfTypeParameter(constraint) : constraint;
                        type.modifiersType = extendedConstraint && extendedConstraint.flags & 4194304 /* Index */ ? instantiateType(extendedConstraint.type, type.mapper) : unknownType;
                    }
                }
                return type.modifiersType;
            }
            function getMappedTypeModifiers(type) {
                const declaration = type.declaration;
                return (declaration.readonlyToken ? declaration.readonlyToken.kind === 41 /* MinusToken */ ? 2 /* ExcludeReadonly */ : 1 /* IncludeReadonly */ : 0) | (declaration.questionToken ? declaration.questionToken.kind === 41 /* MinusToken */ ? 8 /* ExcludeOptional */ : 4 /* IncludeOptional */ : 0);
            }
            function getMappedTypeOptionality(type) {
                const modifiers = getMappedTypeModifiers(type);
                return modifiers & 8 /* ExcludeOptional */ ? -1 : modifiers & 4 /* IncludeOptional */ ? 1 : 0;
            }
            function getCombinedMappedTypeOptionality(type) {
                const optionality = getMappedTypeOptionality(type);
                const modifiersType = getModifiersTypeFromMappedType(type);
                return optionality || (isGenericMappedType(modifiersType) ? getMappedTypeOptionality(modifiersType) : 0);
            }
            function isPartialMappedType(type) {
                return !!(getObjectFlags(type) & 32 /* Mapped */ && getMappedTypeModifiers(type) & 4 /* IncludeOptional */);
            }
            function isGenericMappedType(type) {
                if (getObjectFlags(type) & 32 /* Mapped */) {
                    const constraint = getConstraintTypeFromMappedType(type);
                    if (isGenericIndexType(constraint)) {
                        return true;
                    }
                    const nameType = getNameTypeFromMappedType(type);
                    if (nameType && isGenericIndexType(instantiateType(nameType, makeUnaryTypeMapper(getTypeParameterFromMappedType(type), constraint)))) {
                        return true;
                    }
                }
                return false;
            }
            function getMappedTypeNameTypeKind(type) {
                const nameType = getNameTypeFromMappedType(type);
                if (!nameType) {
                    return 0 /* None */;
                }
                return isTypeAssignableTo(nameType, getTypeParameterFromMappedType(type)) ? 1 /* Filtering */ : 2 /* Remapping */;
            }
            function resolveStructuredTypeMembers(type) {
                if (!type.members) {
                    if (type.flags & 524288 /* Object */) {
                        if (type.objectFlags & 4 /* Reference */) {
                            resolveTypeReferenceMembers(type);
                        }
                        else if (type.objectFlags & 3 /* ClassOrInterface */) {
                            resolveClassOrInterfaceMembers(type);
                        }
                        else if (type.objectFlags & 1024 /* ReverseMapped */) {
                            resolveReverseMappedTypeMembers(type);
                        }
                        else if (type.objectFlags & 16 /* Anonymous */) {
                            resolveAnonymousTypeMembers(type);
                        }
                        else if (type.objectFlags & 32 /* Mapped */) {
                            resolveMappedTypeMembers(type);
                        }
                        else {
                            Debug.fail("Unhandled object type " + Debug.formatObjectFlags(type.objectFlags));
                        }
                    }
                    else if (type.flags & 1048576 /* Union */) {
                        resolveUnionTypeMembers(type);
                    }
                    else if (type.flags & 2097152 /* Intersection */) {
                        resolveIntersectionTypeMembers(type);
                    }
                    else {
                        Debug.fail("Unhandled type " + Debug.formatTypeFlags(type.flags));
                    }
                }
                return type;
            }
            function getPropertiesOfObjectType(type) {
                if (type.flags & 524288 /* Object */) {
                    return resolveStructuredTypeMembers(type).properties;
                }
                return emptyArray;
            }
            function getPropertyOfObjectType(type, name) {
                if (type.flags & 524288 /* Object */) {
                    const resolved = resolveStructuredTypeMembers(type);
                    const symbol = resolved.members.get(name);
                    if (symbol && symbolIsValue(symbol)) {
                        return symbol;
                    }
                }
            }
            function getPropertiesOfUnionOrIntersectionType(type) {
                if (!type.resolvedProperties) {
                    const members = createSymbolTable();
                    for (const current of type.types) {
                        for (const prop of getPropertiesOfType(current)) {
                            if (!members.has(prop.escapedName)) {
                                const combinedProp = getPropertyOfUnionOrIntersectionType(type, prop.escapedName, 
                                /*skipObjectFunctionPropertyAugment*/
                                !!(type.flags & 2097152 /* Intersection */));
                                if (combinedProp) {
                                    members.set(prop.escapedName, combinedProp);
                                }
                            }
                        }
                        if (type.flags & 1048576 /* Union */ && getIndexInfosOfType(current).length === 0) {
                            break;
                        }
                    }
                    type.resolvedProperties = getNamedMembers(members);
                }
                return type.resolvedProperties;
            }
            function getPropertiesOfType(type) {
                type = getReducedApparentType(type);
                return type.flags & 3145728 /* UnionOrIntersection */ ? getPropertiesOfUnionOrIntersectionType(type) : getPropertiesOfObjectType(type);
            }
            function forEachPropertyOfType(type, action) {
                type = getReducedApparentType(type);
                if (type.flags & 3670016 /* StructuredType */) {
                    resolveStructuredTypeMembers(type).members.forEach((symbol, escapedName) => {
                        if (isNamedMember(symbol, escapedName)) {
                            action(symbol, escapedName);
                        }
                    });
                }
            }
            function isTypeInvalidDueToUnionDiscriminant(contextualType, obj) {
                const list = obj.properties;
                return list.some((property) => {
                    const nameType = property.name && (isJsxNamespacedName(property.name) ? getStringLiteralType(getTextOfJsxAttributeName(property.name)) : getLiteralTypeFromPropertyName(property.name));
                    const name = nameType && isTypeUsableAsPropertyName(nameType) ? getPropertyNameFromType(nameType) : void 0;
                    const expected = name === void 0 ? void 0 : getTypeOfPropertyOfType(contextualType, name);
                    return !!expected && isLiteralType(expected) && !isTypeAssignableTo(getTypeOfNode(property), expected);
                });
            }
            function getAllPossiblePropertiesOfTypes(types) {
                const unionType = getUnionType(types);
                if (!(unionType.flags & 1048576 /* Union */)) {
                    return getAugmentedPropertiesOfType(unionType);
                }
                const props = createSymbolTable();
                for (const memberType of types) {
                    for (const { escapedName } of getAugmentedPropertiesOfType(memberType)) {
                        if (!props.has(escapedName)) {
                            const prop = createUnionOrIntersectionProperty(unionType, escapedName);
                            if (prop)
                                props.set(escapedName, prop);
                        }
                    }
                }
                return arrayFrom(props.values());
            }
            function getConstraintOfType(type) {
                return type.flags & 262144 /* TypeParameter */ ? getConstraintOfTypeParameter(type) : type.flags & 8388608 /* IndexedAccess */ ? getConstraintOfIndexedAccess(type) : type.flags & 16777216 /* Conditional */ ? getConstraintOfConditionalType(type) : getBaseConstraintOfType(type);
            }
            function getConstraintOfTypeParameter(typeParameter) {
                return hasNonCircularBaseConstraint(typeParameter) ? getConstraintFromTypeParameter(typeParameter) : void 0;
            }
            function isConstMappedType(type, depth) {
                const typeVariable = getHomomorphicTypeVariable(type);
                return !!typeVariable && isConstTypeVariable(typeVariable, depth);
            }
            function isConstTypeVariable(type, depth = 0) {
                var _a;
                return depth < 5 && !!(type && (type.flags & 262144 /* TypeParameter */ && some((_a = type.symbol) == null ? void 0 : _a.declarations, (d) => hasSyntacticModifier(d, 4096 /* Const */)) || type.flags & 3145728 /* UnionOrIntersection */ && some(type.types, (t) => isConstTypeVariable(t, depth)) || type.flags & 8388608 /* IndexedAccess */ && isConstTypeVariable(type.objectType, depth + 1) || type.flags & 16777216 /* Conditional */ && isConstTypeVariable(getConstraintOfConditionalType(type), depth + 1) || type.flags & 33554432 /* Substitution */ && isConstTypeVariable(type.baseType, depth) || getObjectFlags(type) & 32 /* Mapped */ && isConstMappedType(type, depth) || isGenericTupleType(type) && findIndex(getElementTypes(type), (t, i) => !!(type.target.elementFlags[i] & 8 /* Variadic */) && isConstTypeVariable(t, depth)) >= 0));
            }
            function getConstraintOfIndexedAccess(type) {
                return hasNonCircularBaseConstraint(type) ? getConstraintFromIndexedAccess(type) : void 0;
            }
            function getSimplifiedTypeOrConstraint(type) {
                const simplified = getSimplifiedType(type, 
                /*writing*/
                false);
                return simplified !== type ? simplified : getConstraintOfType(type);
            }
            function getConstraintFromIndexedAccess(type) {
                if (isMappedTypeGenericIndexedAccess(type)) {
                    return substituteIndexedMappedType(type.objectType, type.indexType);
                }
                const indexConstraint = getSimplifiedTypeOrConstraint(type.indexType);
                if (indexConstraint && indexConstraint !== type.indexType) {
                    const indexedAccess = getIndexedAccessTypeOrUndefined(type.objectType, indexConstraint, type.accessFlags);
                    if (indexedAccess) {
                        return indexedAccess;
                    }
                }
                const objectConstraint = getSimplifiedTypeOrConstraint(type.objectType);
                if (objectConstraint && objectConstraint !== type.objectType) {
                    return getIndexedAccessTypeOrUndefined(objectConstraint, type.indexType, type.accessFlags);
                }
                return void 0;
            }
            function getDefaultConstraintOfConditionalType(type) {
                if (!type.resolvedDefaultConstraint) {
                    const trueConstraint = getInferredTrueTypeFromConditionalType(type);
                    const falseConstraint = getFalseTypeFromConditionalType(type);
                    type.resolvedDefaultConstraint = isTypeAny(trueConstraint) ? falseConstraint : isTypeAny(falseConstraint) ? trueConstraint : getUnionType([trueConstraint, falseConstraint]);
                }
                return type.resolvedDefaultConstraint;
            }
            function getConstraintOfDistributiveConditionalType(type) {
                if (type.resolvedConstraintOfDistributive !== void 0) {
                    return type.resolvedConstraintOfDistributive || void 0;
                }
                if (type.root.isDistributive && type.restrictiveInstantiation !== type) {
                    const simplified = getSimplifiedType(type.checkType, 
                    /*writing*/
                    false);
                    const constraint = simplified === type.checkType ? getConstraintOfType(simplified) : simplified;
                    if (constraint && constraint !== type.checkType) {
                        const instantiated = getConditionalTypeInstantiation(type, prependTypeMapping(type.root.checkType, constraint, type.mapper), 
                        /*forConstraint*/
                        true);
                        if (!(instantiated.flags & 131072 /* Never */)) {
                            type.resolvedConstraintOfDistributive = instantiated;
                            return instantiated;
                        }
                    }
                }
                type.resolvedConstraintOfDistributive = false;
                return void 0;
            }
            function getConstraintFromConditionalType(type) {
                return getConstraintOfDistributiveConditionalType(type) || getDefaultConstraintOfConditionalType(type);
            }
            function getConstraintOfConditionalType(type) {
                return hasNonCircularBaseConstraint(type) ? getConstraintFromConditionalType(type) : void 0;
            }
            function getEffectiveConstraintOfIntersection(types, targetIsUnion) {
                let constraints;
                let hasDisjointDomainType = false;
                for (const t of types) {
                    if (t.flags & 465829888 /* Instantiable */) {
                        let constraint = getConstraintOfType(t);
                        while (constraint && constraint.flags & (262144 /* TypeParameter */ | 4194304 /* Index */ | 16777216 /* Conditional */)) {
                            constraint = getConstraintOfType(constraint);
                        }
                        if (constraint) {
                            constraints = append(constraints, constraint);
                            if (targetIsUnion) {
                                constraints = append(constraints, t);
                            }
                        }
                    }
                    else if (t.flags & 469892092 /* DisjointDomains */ || isEmptyAnonymousObjectType(t)) {
                        hasDisjointDomainType = true;
                    }
                }
                if (constraints && (targetIsUnion || hasDisjointDomainType)) {
                    if (hasDisjointDomainType) {
                        for (const t of types) {
                            if (t.flags & 469892092 /* DisjointDomains */ || isEmptyAnonymousObjectType(t)) {
                                constraints = append(constraints, t);
                            }
                        }
                    }
                    return getNormalizedType(getIntersectionType(constraints), 
                    /*writing*/
                    false);
                }
                return void 0;
            }
            function getBaseConstraintOfType(type) {
                if (type.flags & (58982400 /* InstantiableNonPrimitive */ | 3145728 /* UnionOrIntersection */ | 134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */) || isGenericTupleType(type)) {
                    const constraint = getResolvedBaseConstraint(type);
                    return constraint !== noConstraintType && constraint !== circularConstraintType ? constraint : void 0;
                }
                return type.flags & 4194304 /* Index */ ? keyofConstraintType : void 0;
            }
            function getBaseConstraintOrType(type) {
                return getBaseConstraintOfType(type) || type;
            }
            function hasNonCircularBaseConstraint(type) {
                return getResolvedBaseConstraint(type) !== circularConstraintType;
            }
            function getResolvedBaseConstraint(type) {
                if (type.resolvedBaseConstraint) {
                    return type.resolvedBaseConstraint;
                }
                const stack = [];
                return type.resolvedBaseConstraint = getImmediateBaseConstraint(type);
                function getImmediateBaseConstraint(t) {
                    if (!t.immediateBaseConstraint) {
                        if (!pushTypeResolution(t, 4 /* ImmediateBaseConstraint */)) {
                            return circularConstraintType;
                        }
                        let result;
                        const identity2 = getRecursionIdentity(t);
                        if (stack.length < 10 || stack.length < 50 && !contains(stack, identity2)) {
                            stack.push(identity2);
                            result = computeBaseConstraint(getSimplifiedType(t, 
                            /*writing*/
                            false));
                            stack.pop();
                        }
                        if (!popTypeResolution()) {
                            if (t.flags & 262144 /* TypeParameter */) {
                                const errorNode = getConstraintDeclaration(t);
                                if (errorNode) {
                                    const diagnostic = error2(errorNode, Diagnostics.Type_parameter_0_has_a_circular_constraint, typeToString(t));
                                    if (currentNode && !isNodeDescendantOf(errorNode, currentNode) && !isNodeDescendantOf(currentNode, errorNode)) {
                                        addRelatedInfo(diagnostic, createDiagnosticForNode(currentNode, Diagnostics.Circularity_originates_in_type_at_this_location));
                                    }
                                }
                            }
                            result = circularConstraintType;
                        }
                        t.immediateBaseConstraint = result || noConstraintType;
                    }
                    return t.immediateBaseConstraint;
                }
                function getBaseConstraint(t) {
                    const c = getImmediateBaseConstraint(t);
                    return c !== noConstraintType && c !== circularConstraintType ? c : void 0;
                }
                function computeBaseConstraint(t) {
                    if (t.flags & 262144 /* TypeParameter */) {
                        const constraint = getConstraintFromTypeParameter(t);
                        return t.isThisType || !constraint ? constraint : getBaseConstraint(constraint);
                    }
                    if (t.flags & 3145728 /* UnionOrIntersection */) {
                        const types = t.types;
                        const baseTypes = [];
                        let different = false;
                        for (const type2 of types) {
                            const baseType = getBaseConstraint(type2);
                            if (baseType) {
                                if (baseType !== type2) {
                                    different = true;
                                }
                                baseTypes.push(baseType);
                            }
                            else {
                                different = true;
                            }
                        }
                        if (!different) {
                            return t;
                        }
                        return t.flags & 1048576 /* Union */ && baseTypes.length === types.length ? getUnionType(baseTypes) : t.flags & 2097152 /* Intersection */ && baseTypes.length ? getIntersectionType(baseTypes) : void 0;
                    }
                    if (t.flags & 4194304 /* Index */) {
                        return keyofConstraintType;
                    }
                    if (t.flags & 134217728 /* TemplateLiteral */) {
                        const types = t.types;
                        const constraints = mapDefined(types, getBaseConstraint);
                        return constraints.length === types.length ? getTemplateLiteralType(t.texts, constraints) : stringType;
                    }
                    if (t.flags & 268435456 /* StringMapping */) {
                        const constraint = getBaseConstraint(t.type);
                        return constraint && constraint !== t.type ? getStringMappingType(t.symbol, constraint) : stringType;
                    }
                    if (t.flags & 8388608 /* IndexedAccess */) {
                        if (isMappedTypeGenericIndexedAccess(t)) {
                            return getBaseConstraint(substituteIndexedMappedType(t.objectType, t.indexType));
                        }
                        const baseObjectType = getBaseConstraint(t.objectType);
                        const baseIndexType = getBaseConstraint(t.indexType);
                        const baseIndexedAccess = baseObjectType && baseIndexType && getIndexedAccessTypeOrUndefined(baseObjectType, baseIndexType, t.accessFlags);
                        return baseIndexedAccess && getBaseConstraint(baseIndexedAccess);
                    }
                    if (t.flags & 16777216 /* Conditional */) {
                        const constraint = getConstraintFromConditionalType(t);
                        return constraint && getBaseConstraint(constraint);
                    }
                    if (t.flags & 33554432 /* Substitution */) {
                        return getBaseConstraint(getSubstitutionIntersection(t));
                    }
                    if (isGenericTupleType(t)) {
                        const newElements = map(getElementTypes(t), (v, i) => {
                            const constraint = v.flags & 262144 /* TypeParameter */ && t.target.elementFlags[i] & 8 /* Variadic */ && getBaseConstraint(v) || v;
                            return constraint !== v && everyType(constraint, (c) => isArrayOrTupleType(c) && !isGenericTupleType(c)) ? constraint : v;
                        });
                        return createTupleType(newElements, t.target.elementFlags, t.target.readonly, t.target.labeledElementDeclarations);
                    }
                    return t;
                }
            }
            function getApparentTypeOfIntersectionType(type, thisArgument) {
                return type.resolvedApparentType || (type.resolvedApparentType = getTypeWithThisArgument(type, thisArgument, 
                /*needApparentType*/
                true));
            }
            function getResolvedTypeParameterDefault(typeParameter) {
                if (!typeParameter.default) {
                    if (typeParameter.target) {
                        const targetDefault = getResolvedTypeParameterDefault(typeParameter.target);
                        typeParameter.default = targetDefault ? instantiateType(targetDefault, typeParameter.mapper) : noConstraintType;
                    }
                    else {
                        typeParameter.default = resolvingDefaultType;
                        const defaultDeclaration = typeParameter.symbol && forEach(typeParameter.symbol.declarations, (decl) => isTypeParameterDeclaration(decl) && decl.default);
                        const defaultType = defaultDeclaration ? getTypeFromTypeNode(defaultDeclaration) : noConstraintType;
                        if (typeParameter.default === resolvingDefaultType) {
                            typeParameter.default = defaultType;
                        }
                    }
                }
                else if (typeParameter.default === resolvingDefaultType) {
                    typeParameter.default = circularConstraintType;
                }
                return typeParameter.default;
            }
            function getDefaultFromTypeParameter(typeParameter) {
                const defaultType = getResolvedTypeParameterDefault(typeParameter);
                return defaultType !== noConstraintType && defaultType !== circularConstraintType ? defaultType : void 0;
            }
            function hasNonCircularTypeParameterDefault(typeParameter) {
                return getResolvedTypeParameterDefault(typeParameter) !== circularConstraintType;
            }
            function hasTypeParameterDefault(typeParameter) {
                return !!(typeParameter.symbol && forEach(typeParameter.symbol.declarations, (decl) => isTypeParameterDeclaration(decl) && decl.default));
            }
            function getApparentTypeOfMappedType(type) {
                return type.resolvedApparentType || (type.resolvedApparentType = getResolvedApparentTypeOfMappedType(type));
            }
            function getResolvedApparentTypeOfMappedType(type) {
                const target = type.target ?? type;
                const typeVariable = getHomomorphicTypeVariable(target);
                if (typeVariable && !target.declaration.nameType) {
                    const constraint = getConstraintTypeFromMappedType(type);
                    if (constraint.flags & 4194304 /* Index */) {
                        const baseConstraint = getBaseConstraintOfType(constraint.type);
                        if (baseConstraint && everyType(baseConstraint, (t) => isArrayOrTupleType(t) || isArrayOrTupleOrIntersection(t))) {
                            return instantiateType(target, prependTypeMapping(typeVariable, baseConstraint, type.mapper));
                        }
                    }
                }
                return type;
            }
            function isArrayOrTupleOrIntersection(type) {
                return !!(type.flags & 2097152 /* Intersection */) && every(type.types, isArrayOrTupleType);
            }
            function isMappedTypeGenericIndexedAccess(type) {
                let objectType;
                return !!(type.flags & 8388608 /* IndexedAccess */ && getObjectFlags(objectType = type.objectType) & 32 /* Mapped */ && !isGenericMappedType(objectType) && isGenericIndexType(type.indexType) && !(getMappedTypeModifiers(objectType) & 8 /* ExcludeOptional */) && !objectType.declaration.nameType);
            }
            function getApparentType(type) {
                const t = type.flags & 465829888 /* Instantiable */ ? getBaseConstraintOfType(type) || unknownType : type;
                const objectFlags = getObjectFlags(t);
                return objectFlags & 32 /* Mapped */ ? getApparentTypeOfMappedType(t) : objectFlags & 4 /* Reference */ && t !== type ? getTypeWithThisArgument(t, type) : t.flags & 2097152 /* Intersection */ ? getApparentTypeOfIntersectionType(t, type) : t.flags & 402653316 /* StringLike */ ? globalStringType : t.flags & 296 /* NumberLike */ ? globalNumberType : t.flags & 2112 /* BigIntLike */ ? getGlobalBigIntType() : t.flags & 528 /* BooleanLike */ ? globalBooleanType : t.flags & 12288 /* ESSymbolLike */ ? getGlobalESSymbolType() : t.flags & 67108864 /* NonPrimitive */ ? emptyObjectType : t.flags & 4194304 /* Index */ ? keyofConstraintType : t.flags & 2 /* Unknown */ && !strictNullChecks ? emptyObjectType : t;
            }
            function getReducedApparentType(type) {
                return getReducedType(getApparentType(getReducedType(type)));
            }
            function createUnionOrIntersectionProperty(containingType, name, skipObjectFunctionPropertyAugment) {
                var _a, _b, _c;
                let singleProp;
                let propSet;
                let indexTypes;
                const isUnion = containingType.flags & 1048576 /* Union */;
                let optionalFlag;
                let syntheticFlag = 4 /* SyntheticMethod */;
                let checkFlags = isUnion ? 0 : 8 /* Readonly */;
                let mergedInstantiations = false;
                for (const current of containingType.types) {
                    const type = getApparentType(current);
                    if (!(isErrorType(type) || type.flags & 131072 /* Never */)) {
                        const prop = getPropertyOfType(type, name, skipObjectFunctionPropertyAugment);
                        const modifiers = prop ? getDeclarationModifierFlagsFromSymbol(prop) : 0;
                        if (prop) {
                            if (prop.flags & 106500 /* ClassMember */) {
                                optionalFlag ?? (optionalFlag = isUnion ? 0 /* None */ : 16777216 /* Optional */);
                                if (isUnion) {
                                    optionalFlag |= prop.flags & 16777216 /* Optional */;
                                }
                                else {
                                    optionalFlag &= prop.flags;
                                }
                            }
                            if (!singleProp) {
                                singleProp = prop;
                            }
                            else if (prop !== singleProp) {
                                const isInstantiation = (getTargetSymbol(prop) || prop) === (getTargetSymbol(singleProp) || singleProp);
                                if (isInstantiation && compareProperties2(singleProp, prop, (a, b) => a === b ? -1 /* True */ : 0 /* False */) === -1 /* True */) {
                                    mergedInstantiations = !!singleProp.parent && !!length(getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(singleProp.parent));
                                }
                                else {
                                    if (!propSet) {
                                        propSet = /* @__PURE__ */ new Map();
                                        propSet.set(getSymbolId(singleProp), singleProp);
                                    }
                                    const id = getSymbolId(prop);
                                    if (!propSet.has(id)) {
                                        propSet.set(id, prop);
                                    }
                                }
                            }
                            if (isUnion && isReadonlySymbol(prop)) {
                                checkFlags |= 8 /* Readonly */;
                            }
                            else if (!isUnion && !isReadonlySymbol(prop)) {
                                checkFlags &= ~8 /* Readonly */;
                            }
                            checkFlags |= (!(modifiers & 6 /* NonPublicAccessibilityModifier */) ? 256 /* ContainsPublic */ : 0) | (modifiers & 4 /* Protected */ ? 512 /* ContainsProtected */ : 0) | (modifiers & 2 /* Private */ ? 1024 /* ContainsPrivate */ : 0) | (modifiers & 256 /* Static */ ? 2048 /* ContainsStatic */ : 0);
                            if (!isPrototypeProperty(prop)) {
                                syntheticFlag = 2 /* SyntheticProperty */;
                            }
                        }
                        else if (isUnion) {
                            const indexInfo = !isLateBoundName(name) && getApplicableIndexInfoForName(type, name);
                            if (indexInfo) {
                                checkFlags |= 32 /* WritePartial */ | (indexInfo.isReadonly ? 8 /* Readonly */ : 0);
                                indexTypes = append(indexTypes, isTupleType(type) ? getRestTypeOfTupleType(type) || undefinedType : indexInfo.type);
                            }
                            else if (isObjectLiteralType2(type) && !(getObjectFlags(type) & 2097152 /* ContainsSpread */)) {
                                checkFlags |= 32 /* WritePartial */;
                                indexTypes = append(indexTypes, undefinedType);
                            }
                            else {
                                checkFlags |= 16 /* ReadPartial */;
                            }
                        }
                    }
                }
                if (!singleProp || isUnion && (propSet || checkFlags & 48 /* Partial */) && checkFlags & (1024 /* ContainsPrivate */ | 512 /* ContainsProtected */) && !(propSet && getCommonDeclarationsOfSymbols(propSet.values()))) {
                    return void 0;
                }
                if (!propSet && !(checkFlags & 16 /* ReadPartial */) && !indexTypes) {
                    if (mergedInstantiations) {
                        const links = (_a = tryCast(singleProp, isTransientSymbol)) == null ? void 0 : _a.links;
                        const clone2 = createSymbolWithType(singleProp, links == null ? void 0 : links.type);
                        clone2.parent = (_c = (_b = singleProp.valueDeclaration) == null ? void 0 : _b.symbol) == null ? void 0 : _c.parent;
                        clone2.links.containingType = containingType;
                        clone2.links.mapper = links == null ? void 0 : links.mapper;
                        clone2.links.writeType = getWriteTypeOfSymbol(singleProp);
                        return clone2;
                    }
                    else {
                        return singleProp;
                    }
                }
                const props = propSet ? arrayFrom(propSet.values()) : [singleProp];
                let declarations;
                let firstType;
                let nameType;
                const propTypes = [];
                let writeTypes;
                let firstValueDeclaration;
                let hasNonUniformValueDeclaration = false;
                for (const prop of props) {
                    if (!firstValueDeclaration) {
                        firstValueDeclaration = prop.valueDeclaration;
                    }
                    else if (prop.valueDeclaration && prop.valueDeclaration !== firstValueDeclaration) {
                        hasNonUniformValueDeclaration = true;
                    }
                    declarations = addRange(declarations, prop.declarations);
                    const type = getTypeOfSymbol(prop);
                    if (!firstType) {
                        firstType = type;
                        nameType = getSymbolLinks(prop).nameType;
                    }
                    const writeType = getWriteTypeOfSymbol(prop);
                    if (writeTypes || writeType !== type) {
                        writeTypes = append(!writeTypes ? propTypes.slice() : writeTypes, writeType);
                    }
                    if (type !== firstType) {
                        checkFlags |= 64 /* HasNonUniformType */;
                    }
                    if (isLiteralType(type) || isPatternLiteralType(type)) {
                        checkFlags |= 128 /* HasLiteralType */;
                    }
                    if (type.flags & 131072 /* Never */ && type !== uniqueLiteralType) {
                        checkFlags |= 131072 /* HasNeverType */;
                    }
                    propTypes.push(type);
                }
                addRange(propTypes, indexTypes);
                const result = createSymbol(4 /* Property */ | (optionalFlag ?? 0), name, syntheticFlag | checkFlags);
                result.links.containingType = containingType;
                if (!hasNonUniformValueDeclaration && firstValueDeclaration) {
                    result.valueDeclaration = firstValueDeclaration;
                    if (firstValueDeclaration.symbol.parent) {
                        result.parent = firstValueDeclaration.symbol.parent;
                    }
                }
                result.declarations = declarations;
                result.links.nameType = nameType;
                if (propTypes.length > 2) {
                    result.links.checkFlags |= 65536 /* DeferredType */;
                    result.links.deferralParent = containingType;
                    result.links.deferralConstituents = propTypes;
                    result.links.deferralWriteConstituents = writeTypes;
                }
                else {
                    result.links.type = isUnion ? getUnionType(propTypes) : getIntersectionType(propTypes);
                    if (writeTypes) {
                        result.links.writeType = isUnion ? getUnionType(writeTypes) : getIntersectionType(writeTypes);
                    }
                }
                return result;
            }
            function getUnionOrIntersectionProperty(type, name, skipObjectFunctionPropertyAugment) {
                var _a, _b, _c;
                let property = ((_a = type.propertyCacheWithoutObjectFunctionPropertyAugment) == null ? void 0 : _a.get(name)) || !skipObjectFunctionPropertyAugment ? (_b = type.propertyCache) == null ? void 0 : _b.get(name) : void 0;
                if (!property) {
                    property = createUnionOrIntersectionProperty(type, name, skipObjectFunctionPropertyAugment);
                    if (property) {
                        const properties = skipObjectFunctionPropertyAugment ? type.propertyCacheWithoutObjectFunctionPropertyAugment || (type.propertyCacheWithoutObjectFunctionPropertyAugment = createSymbolTable()) : type.propertyCache || (type.propertyCache = createSymbolTable());
                        properties.set(name, property);
                        if (skipObjectFunctionPropertyAugment && !((_c = type.propertyCache) == null ? void 0 : _c.get(name))) {
                            const properties2 = type.propertyCache || (type.propertyCache = createSymbolTable());
                            properties2.set(name, property);
                        }
                    }
                }
                return property;
            }
            function getCommonDeclarationsOfSymbols(symbols) {
                let commonDeclarations;
                for (const symbol of symbols) {
                    if (!symbol.declarations) {
                        return void 0;
                    }
                    if (!commonDeclarations) {
                        commonDeclarations = new Set(symbol.declarations);
                        continue;
                    }
                    commonDeclarations.forEach((declaration) => {
                        if (!contains(symbol.declarations, declaration)) {
                            commonDeclarations.delete(declaration);
                        }
                    });
                    if (commonDeclarations.size === 0) {
                        return void 0;
                    }
                }
                return commonDeclarations;
            }
            function getPropertyOfUnionOrIntersectionType(type, name, skipObjectFunctionPropertyAugment) {
                const property = getUnionOrIntersectionProperty(type, name, skipObjectFunctionPropertyAugment);
                return property && !(getCheckFlags(property) & 16 /* ReadPartial */) ? property : void 0;
            }
            function getReducedType(type) {
                if (type.flags & 1048576 /* Union */ && type.objectFlags & 16777216 /* ContainsIntersections */) {
                    return type.resolvedReducedType || (type.resolvedReducedType = getReducedUnionType(type));
                }
                else if (type.flags & 2097152 /* Intersection */) {
                    if (!(type.objectFlags & 16777216 /* IsNeverIntersectionComputed */)) {
                        type.objectFlags |= 16777216 /* IsNeverIntersectionComputed */ | (some(getPropertiesOfUnionOrIntersectionType(type), isNeverReducedProperty) ? 33554432 /* IsNeverIntersection */ : 0);
                    }
                    return type.objectFlags & 33554432 /* IsNeverIntersection */ ? neverType : type;
                }
                return type;
            }
            function getReducedUnionType(unionType) {
                const reducedTypes = sameMap(unionType.types, getReducedType);
                if (reducedTypes === unionType.types) {
                    return unionType;
                }
                const reduced = getUnionType(reducedTypes);
                if (reduced.flags & 1048576 /* Union */) {
                    reduced.resolvedReducedType = reduced;
                }
                return reduced;
            }
            function isNeverReducedProperty(prop) {
                return isDiscriminantWithNeverType(prop) || isConflictingPrivateProperty(prop);
            }
            function isDiscriminantWithNeverType(prop) {
                return !(prop.flags & 16777216 /* Optional */) && (getCheckFlags(prop) & (192 /* Discriminant */ | 131072 /* HasNeverType */)) === 192 /* Discriminant */ && !!(getTypeOfSymbol(prop).flags & 131072 /* Never */);
            }
            function isConflictingPrivateProperty(prop) {
                return !prop.valueDeclaration && !!(getCheckFlags(prop) & 1024 /* ContainsPrivate */);
            }
            function isGenericReducibleType(type) {
                return !!(type.flags & 1048576 /* Union */ && type.objectFlags & 16777216 /* ContainsIntersections */ && some(type.types, isGenericReducibleType) || type.flags & 2097152 /* Intersection */ && isReducibleIntersection(type));
            }
            function isReducibleIntersection(type) {
                const uniqueFilled = type.uniqueLiteralFilledInstantiation || (type.uniqueLiteralFilledInstantiation = instantiateType(type, uniqueLiteralMapper));
                return getReducedType(uniqueFilled) !== uniqueFilled;
            }
            function elaborateNeverIntersection(errorInfo, type) {
                if (type.flags & 2097152 /* Intersection */ && getObjectFlags(type) & 33554432 /* IsNeverIntersection */) {
                    const neverProp = find(getPropertiesOfUnionOrIntersectionType(type), isDiscriminantWithNeverType);
                    if (neverProp) {
                        return chainDiagnosticMessages(errorInfo, Diagnostics.The_intersection_0_was_reduced_to_never_because_property_1_has_conflicting_types_in_some_constituents, typeToString(type, 
                        /*enclosingDeclaration*/
                        void 0, 536870912 /* NoTypeReduction */), symbolToString(neverProp));
                    }
                    const privateProp = find(getPropertiesOfUnionOrIntersectionType(type), isConflictingPrivateProperty);
                    if (privateProp) {
                        return chainDiagnosticMessages(errorInfo, Diagnostics.The_intersection_0_was_reduced_to_never_because_property_1_exists_in_multiple_constituents_and_is_private_in_some, typeToString(type, 
                        /*enclosingDeclaration*/
                        void 0, 536870912 /* NoTypeReduction */), symbolToString(privateProp));
                    }
                }
                return errorInfo;
            }
            function getPropertyOfType(type, name, skipObjectFunctionPropertyAugment, includeTypeOnlyMembers) {
                var _a, _b;
                type = getReducedApparentType(type);
                if (type.flags & 524288 /* Object */) {
                    const resolved = resolveStructuredTypeMembers(type);
                    const symbol = resolved.members.get(name);
                    if (symbol && !includeTypeOnlyMembers && ((_a = type.symbol) == null ? void 0 : _a.flags) & 512 /* ValueModule */ && ((_b = getSymbolLinks(type.symbol).typeOnlyExportStarMap) == null ? void 0 : _b.has(name))) {
                        return void 0;
                    }
                    if (symbol && symbolIsValue(symbol, includeTypeOnlyMembers)) {
                        return symbol;
                    }
                    if (skipObjectFunctionPropertyAugment)
                        return void 0;
                    const functionType = resolved === anyFunctionType ? globalFunctionType : resolved.callSignatures.length ? globalCallableFunctionType : resolved.constructSignatures.length ? globalNewableFunctionType : void 0;
                    if (functionType) {
                        const symbol2 = getPropertyOfObjectType(functionType, name);
                        if (symbol2) {
                            return symbol2;
                        }
                    }
                    return getPropertyOfObjectType(globalObjectType, name);
                }
                if (type.flags & 2097152 /* Intersection */) {
                    const prop = getPropertyOfUnionOrIntersectionType(type, name, 
                    /*skipObjectFunctionPropertyAugment*/
                    true);
                    if (prop) {
                        return prop;
                    }
                    if (!skipObjectFunctionPropertyAugment) {
                        return getPropertyOfUnionOrIntersectionType(type, name, skipObjectFunctionPropertyAugment);
                    }
                    return void 0;
                }
                if (type.flags & 1048576 /* Union */) {
                    return getPropertyOfUnionOrIntersectionType(type, name, skipObjectFunctionPropertyAugment);
                }
                return void 0;
            }
            function getSignaturesOfStructuredType(type, kind) {
                if (type.flags & 3670016 /* StructuredType */) {
                    const resolved = resolveStructuredTypeMembers(type);
                    return kind === 0 /* Call */ ? resolved.callSignatures : resolved.constructSignatures;
                }
                return emptyArray;
            }
            function getSignaturesOfType(type, kind) {
                const result = getSignaturesOfStructuredType(getReducedApparentType(type), kind);
                if (kind === 0 /* Call */ && !length(result) && type.flags & 1048576 /* Union */) {
                    if (type.arrayFallbackSignatures) {
                        return type.arrayFallbackSignatures;
                    }
                    let memberName;
                    if (everyType(type, (t) => {
                        var _a;
                        return !!((_a = t.symbol) == null ? void 0 : _a.parent) && isArrayOrTupleSymbol(t.symbol.parent) && (!memberName ? (memberName = t.symbol.escapedName, true) : memberName === t.symbol.escapedName);
                    })) {
                        const arrayArg = mapType(type, (t) => getMappedType((isReadonlyArraySymbol(t.symbol.parent) ? globalReadonlyArrayType : globalArrayType).typeParameters[0], t.mapper));
                        const arrayType = createArrayType(arrayArg, someType(type, (t) => isReadonlyArraySymbol(t.symbol.parent)));
                        return type.arrayFallbackSignatures = getSignaturesOfType(getTypeOfPropertyOfType(arrayType, memberName), kind);
                    }
                    type.arrayFallbackSignatures = result;
                }
                return result;
            }
            function isArrayOrTupleSymbol(symbol) {
                if (!symbol || !globalArrayType.symbol || !globalReadonlyArrayType.symbol) {
                    return false;
                }
                return !!getSymbolIfSameReference(symbol, globalArrayType.symbol) || !!getSymbolIfSameReference(symbol, globalReadonlyArrayType.symbol);
            }
            function isReadonlyArraySymbol(symbol) {
                if (!symbol || !globalReadonlyArrayType.symbol) {
                    return false;
                }
                return !!getSymbolIfSameReference(symbol, globalReadonlyArrayType.symbol);
            }
            function findIndexInfo(indexInfos, keyType) {
                return find(indexInfos, (info) => info.keyType === keyType);
            }
            function findApplicableIndexInfo(indexInfos, keyType) {
                let stringIndexInfo;
                let applicableInfo;
                let applicableInfos;
                for (const info of indexInfos) {
                    if (info.keyType === stringType) {
                        stringIndexInfo = info;
                    }
                    else if (isApplicableIndexType(keyType, info.keyType)) {
                        if (!applicableInfo) {
                            applicableInfo = info;
                        }
                        else {
                            (applicableInfos || (applicableInfos = [applicableInfo])).push(info);
                        }
                    }
                }
                return applicableInfos ? createIndexInfo(unknownType, getIntersectionType(map(applicableInfos, (info) => info.type)), reduceLeft(applicableInfos, (isReadonly, info) => isReadonly && info.isReadonly, 
                /*initial*/
                true)) : applicableInfo ? applicableInfo : stringIndexInfo && isApplicableIndexType(keyType, stringType) ? stringIndexInfo : void 0;
            }
            function isApplicableIndexType(source, target) {
                return isTypeAssignableTo(source, target) || target === stringType && isTypeAssignableTo(source, numberType) || target === numberType && (source === numericStringType || !!(source.flags & 128 /* StringLiteral */) && isNumericLiteralName(source.value));
            }
            function getIndexInfosOfStructuredType(type) {
                if (type.flags & 3670016 /* StructuredType */) {
                    const resolved = resolveStructuredTypeMembers(type);
                    return resolved.indexInfos;
                }
                return emptyArray;
            }
            function getIndexInfosOfType(type) {
                return getIndexInfosOfStructuredType(getReducedApparentType(type));
            }
            function getIndexInfoOfType(type, keyType) {
                return findIndexInfo(getIndexInfosOfType(type), keyType);
            }
            function getIndexTypeOfType(type, keyType) {
                var _a;
                return (_a = getIndexInfoOfType(type, keyType)) == null ? void 0 : _a.type;
            }
            function getApplicableIndexInfos(type, keyType) {
                return getIndexInfosOfType(type).filter((info) => isApplicableIndexType(keyType, info.keyType));
            }
            function getApplicableIndexInfo(type, keyType) {
                return findApplicableIndexInfo(getIndexInfosOfType(type), keyType);
            }
            function getApplicableIndexInfoForName(type, name) {
                return getApplicableIndexInfo(type, isLateBoundName(name) ? esSymbolType : getStringLiteralType(unescapeLeadingUnderscores(name)));
            }
            function getTypeParametersFromDeclaration(declaration) {
                var _a;
                let result;
                for (const node of getEffectiveTypeParameterDeclarations(declaration)) {
                    result = appendIfUnique(result, getDeclaredTypeOfTypeParameter(node.symbol));
                }
                return (result == null ? void 0 : result.length) ? result : isFunctionDeclaration(declaration) ? (_a = getSignatureOfTypeTag(declaration)) == null ? void 0 : _a.typeParameters : void 0;
            }
            function symbolsToArray(symbols) {
                const result = [];
                symbols.forEach((symbol, id) => {
                    if (!isReservedMemberName(id)) {
                        result.push(symbol);
                    }
                });
                return result;
            }
            function tryFindAmbientModule(moduleName, withAugmentations) {
                if (isExternalModuleNameRelative(moduleName)) {
                    return void 0;
                }
                const symbol = getSymbol2(globals, '"' + moduleName + '"', 512 /* ValueModule */);
                return symbol && withAugmentations ? getMergedSymbol(symbol) : symbol;
            }
            function isOptionalParameter(node) {
                if (hasQuestionToken(node) || isOptionalJSDocPropertyLikeTag(node) || isJSDocOptionalParameter(node)) {
                    return true;
                }
                if (node.initializer) {
                    const signature = getSignatureFromDeclaration(node.parent);
                    const parameterIndex = node.parent.parameters.indexOf(node);
                    Debug.assert(parameterIndex >= 0);
                    return parameterIndex >= getMinArgumentCount(signature, 1 /* StrongArityForUntypedJS */ | 2 /* VoidIsNonOptional */);
                }
                const iife = getImmediatelyInvokedFunctionExpression(node.parent);
                if (iife) {
                    return !node.type && !node.dotDotDotToken && node.parent.parameters.indexOf(node) >= getEffectiveCallArguments(iife).length;
                }
                return false;
            }
            function isOptionalPropertyDeclaration(node) {
                return isPropertyDeclaration(node) && !hasAccessorModifier(node) && node.questionToken;
            }
            function createTypePredicate(kind, parameterName, parameterIndex, type) {
                return { kind, parameterName, parameterIndex, type };
            }
            function getMinTypeArgumentCount(typeParameters) {
                let minTypeArgumentCount = 0;
                if (typeParameters) {
                    for (let i = 0; i < typeParameters.length; i++) {
                        if (!hasTypeParameterDefault(typeParameters[i])) {
                            minTypeArgumentCount = i + 1;
                        }
                    }
                }
                return minTypeArgumentCount;
            }
            function fillMissingTypeArguments(typeArguments, typeParameters, minTypeArgumentCount, isJavaScriptImplicitAny) {
                const numTypeParameters = length(typeParameters);
                if (!numTypeParameters) {
                    return [];
                }
                const numTypeArguments = length(typeArguments);
                if (isJavaScriptImplicitAny || numTypeArguments >= minTypeArgumentCount && numTypeArguments <= numTypeParameters) {
                    const result = typeArguments ? typeArguments.slice() : [];
                    for (let i = numTypeArguments; i < numTypeParameters; i++) {
                        result[i] = errorType;
                    }
                    const baseDefaultType = getDefaultTypeArgumentType(isJavaScriptImplicitAny);
                    for (let i = numTypeArguments; i < numTypeParameters; i++) {
                        let defaultType = getDefaultFromTypeParameter(typeParameters[i]);
                        if (isJavaScriptImplicitAny && defaultType && (isTypeIdenticalTo(defaultType, unknownType) || isTypeIdenticalTo(defaultType, emptyObjectType))) {
                            defaultType = anyType;
                        }
                        result[i] = defaultType ? instantiateType(defaultType, createTypeMapper(typeParameters, result)) : baseDefaultType;
                    }
                    result.length = typeParameters.length;
                    return result;
                }
                return typeArguments && typeArguments.slice();
            }
            function getSignatureFromDeclaration(declaration) {
                const links = getNodeLinks(declaration);
                if (!links.resolvedSignature) {
                    const parameters = [];
                    let flags = 0 /* None */;
                    let minArgumentCount = 0;
                    let thisParameter;
                    let thisTag = isInJSFile(declaration) ? getJSDocThisTag(declaration) : void 0;
                    let hasThisParameter2 = false;
                    const iife = getImmediatelyInvokedFunctionExpression(declaration);
                    const isJSConstructSignature = isJSDocConstructSignature(declaration);
                    const isUntypedSignatureInJSFile = !iife && isInJSFile(declaration) && isValueSignatureDeclaration(declaration) && !hasJSDocParameterTags(declaration) && !getJSDocType(declaration);
                    if (isUntypedSignatureInJSFile) {
                        flags |= 32 /* IsUntypedSignatureInJSFile */;
                    }
                    for (let i = isJSConstructSignature ? 1 : 0; i < declaration.parameters.length; i++) {
                        const param = declaration.parameters[i];
                        if (isInJSFile(param) && isJSDocThisTag(param)) {
                            thisTag = param;
                            continue;
                        }
                        let paramSymbol = param.symbol;
                        const type = isJSDocParameterTag(param) ? param.typeExpression && param.typeExpression.type : param.type;
                        if (paramSymbol && !!(paramSymbol.flags & 4 /* Property */) && !isBindingPattern(param.name)) {
                            const resolvedSymbol = resolveName(param, paramSymbol.escapedName, 111551 /* Value */, 
                            /*nameNotFoundMessage*/
                            void 0, 
                            /*nameArg*/
                            void 0, 
                            /*isUse*/
                            false);
                            paramSymbol = resolvedSymbol;
                        }
                        if (i === 0 && paramSymbol.escapedName === "this" /* This */) {
                            hasThisParameter2 = true;
                            thisParameter = param.symbol;
                        }
                        else {
                            parameters.push(paramSymbol);
                        }
                        if (type && type.kind === 201 /* LiteralType */) {
                            flags |= 2 /* HasLiteralTypes */;
                        }
                        const isOptionalParameter2 = isOptionalJSDocPropertyLikeTag(param) || param.initializer || param.questionToken || isRestParameter(param) || iife && parameters.length > iife.arguments.length && !type || isJSDocOptionalParameter(param);
                        if (!isOptionalParameter2) {
                            minArgumentCount = parameters.length;
                        }
                    }
                    if ((declaration.kind === 177 /* GetAccessor */ || declaration.kind === 178 /* SetAccessor */) && hasBindableName(declaration) && (!hasThisParameter2 || !thisParameter)) {
                        const otherKind = declaration.kind === 177 /* GetAccessor */ ? 178 /* SetAccessor */ : 177 /* GetAccessor */;
                        const other = getDeclarationOfKind(getSymbolOfDeclaration(declaration), otherKind);
                        if (other) {
                            thisParameter = getAnnotatedAccessorThisParameter(other);
                        }
                    }
                    if (thisTag && thisTag.typeExpression) {
                        thisParameter = createSymbolWithType(createSymbol(1 /* FunctionScopedVariable */, "this" /* This */), getTypeFromTypeNode(thisTag.typeExpression));
                    }
                    const hostDeclaration = isJSDocSignature(declaration) ? getEffectiveJSDocHost(declaration) : declaration;
                    const classType = hostDeclaration && isConstructorDeclaration(hostDeclaration) ? getDeclaredTypeOfClassOrInterface(getMergedSymbol(hostDeclaration.parent.symbol)) : void 0;
                    const typeParameters = classType ? classType.localTypeParameters : getTypeParametersFromDeclaration(declaration);
                    if (hasRestParameter(declaration) || isInJSFile(declaration) && maybeAddJsSyntheticRestParameter(declaration, parameters)) {
                        flags |= 1 /* HasRestParameter */;
                    }
                    if (isConstructorTypeNode(declaration) && hasSyntacticModifier(declaration, 64 /* Abstract */) || isConstructorDeclaration(declaration) && hasSyntacticModifier(declaration.parent, 64 /* Abstract */)) {
                        flags |= 4 /* Abstract */;
                    }
                    links.resolvedSignature = createSignature(declaration, typeParameters, thisParameter, parameters, 
                    /*resolvedReturnType*/
                    void 0, 
                    /*resolvedTypePredicate*/
                    void 0, minArgumentCount, flags);
                }
                return links.resolvedSignature;
            }
            function maybeAddJsSyntheticRestParameter(declaration, parameters) {
                if (isJSDocSignature(declaration) || !containsArgumentsReference(declaration)) {
                    return false;
                }
                const lastParam = lastOrUndefined(declaration.parameters);
                const lastParamTags = lastParam ? getJSDocParameterTags(lastParam) : getJSDocTags(declaration).filter(isJSDocParameterTag);
                const lastParamVariadicType = firstDefined(lastParamTags, (p) => p.typeExpression && isJSDocVariadicType(p.typeExpression.type) ? p.typeExpression.type : void 0);
                const syntheticArgsSymbol = createSymbol(3 /* Variable */, "args", 32768 /* RestParameter */);
                if (lastParamVariadicType) {
                    syntheticArgsSymbol.links.type = createArrayType(getTypeFromTypeNode(lastParamVariadicType.type));
                }
                else {
                    syntheticArgsSymbol.links.checkFlags |= 65536 /* DeferredType */;
                    syntheticArgsSymbol.links.deferralParent = neverType;
                    syntheticArgsSymbol.links.deferralConstituents = [anyArrayType];
                    syntheticArgsSymbol.links.deferralWriteConstituents = [anyArrayType];
                }
                if (lastParamVariadicType) {
                    parameters.pop();
                }
                parameters.push(syntheticArgsSymbol);
                return true;
            }
            function getSignatureOfTypeTag(node) {
                if (!(isInJSFile(node) && isFunctionLikeDeclaration(node)))
                    return void 0;
                const typeTag = getJSDocTypeTag(node);
                return (typeTag == null ? void 0 : typeTag.typeExpression) && getSingleCallSignature(getTypeFromTypeNode(typeTag.typeExpression));
            }
            function getParameterTypeOfTypeTag(func, parameter) {
                const signature = getSignatureOfTypeTag(func);
                if (!signature)
                    return void 0;
                const pos = func.parameters.indexOf(parameter);
                return parameter.dotDotDotToken ? getRestTypeAtPosition(signature, pos) : getTypeAtPosition(signature, pos);
            }
            function getReturnTypeOfTypeTag(node) {
                const signature = getSignatureOfTypeTag(node);
                return signature && getReturnTypeOfSignature(signature);
            }
            function containsArgumentsReference(declaration) {
                const links = getNodeLinks(declaration);
                if (links.containsArgumentsReference === void 0) {
                    if (links.flags & 512 /* CaptureArguments */) {
                        links.containsArgumentsReference = true;
                    }
                    else {
                        links.containsArgumentsReference = traverse(declaration.body);
                    }
                }
                return links.containsArgumentsReference;
                function traverse(node) {
                    if (!node)
                        return false;
                    switch (node.kind) {
                        case 80 /* Identifier */:
                            return node.escapedText === argumentsSymbol.escapedName && getReferencedValueSymbol(node) === argumentsSymbol;
                        case 172 /* PropertyDeclaration */:
                        case 174 /* MethodDeclaration */:
                        case 177 /* GetAccessor */:
                        case 178 /* SetAccessor */:
                            return node.name.kind === 167 /* ComputedPropertyName */ && traverse(node.name);
                        case 211 /* PropertyAccessExpression */:
                        case 212 /* ElementAccessExpression */:
                            return traverse(node.expression);
                        case 303 /* PropertyAssignment */:
                            return traverse(node.initializer);
                        default:
                            return !nodeStartsNewLexicalEnvironment(node) && !isPartOfTypeNode(node) && !!forEachChild(node, traverse);
                    }
                }
            }
            function getSignaturesOfSymbol(symbol) {
                if (!symbol || !symbol.declarations)
                    return emptyArray;
                const result = [];
                for (let i = 0; i < symbol.declarations.length; i++) {
                    const decl = symbol.declarations[i];
                    if (!isFunctionLike(decl))
                        continue;
                    if (i > 0 && decl.body) {
                        const previous = symbol.declarations[i - 1];
                        if (decl.parent === previous.parent && decl.kind === previous.kind && decl.pos === previous.end) {
                            continue;
                        }
                    }
                    if (isInJSFile(decl) && decl.jsDoc) {
                        const tags = getJSDocOverloadTags(decl);
                        if (length(tags)) {
                            for (const tag of tags) {
                                const jsDocSignature = tag.typeExpression;
                                if (jsDocSignature.type === void 0 && !isConstructorDeclaration(decl)) {
                                    reportImplicitAny(jsDocSignature, anyType);
                                }
                                result.push(getSignatureFromDeclaration(jsDocSignature));
                            }
                            continue;
                        }
                    }
                    result.push(!isFunctionExpressionOrArrowFunction(decl) && !isObjectLiteralMethod(decl) && getSignatureOfTypeTag(decl) || getSignatureFromDeclaration(decl));
                }
                return result;
            }
            function resolveExternalModuleTypeByLiteral(name) {
                const moduleSym = resolveExternalModuleName(name, name);
                if (moduleSym) {
                    const resolvedModuleSymbol = resolveExternalModuleSymbol(moduleSym);
                    if (resolvedModuleSymbol) {
                        return getTypeOfSymbol(resolvedModuleSymbol);
                    }
                }
                return anyType;
            }
            function getThisTypeOfSignature(signature) {
                if (signature.thisParameter) {
                    return getTypeOfSymbol(signature.thisParameter);
                }
            }
            function getTypePredicateOfSignature(signature) {
                if (!signature.resolvedTypePredicate) {
                    if (signature.target) {
                        const targetTypePredicate = getTypePredicateOfSignature(signature.target);
                        signature.resolvedTypePredicate = targetTypePredicate ? instantiateTypePredicate(targetTypePredicate, signature.mapper) : noTypePredicate;
                    }
                    else if (signature.compositeSignatures) {
                        signature.resolvedTypePredicate = getUnionOrIntersectionTypePredicate(signature.compositeSignatures, signature.compositeKind) || noTypePredicate;
                    }
                    else {
                        const type = signature.declaration && getEffectiveReturnTypeNode(signature.declaration);
                        let jsdocPredicate;
                        if (!type) {
                            const jsdocSignature = getSignatureOfTypeTag(signature.declaration);
                            if (jsdocSignature && signature !== jsdocSignature) {
                                jsdocPredicate = getTypePredicateOfSignature(jsdocSignature);
                            }
                        }
                        signature.resolvedTypePredicate = type && isTypePredicateNode(type) ? createTypePredicateFromTypePredicateNode(type, signature) : jsdocPredicate || noTypePredicate;
                    }
                    Debug.assert(!!signature.resolvedTypePredicate);
                }
                return signature.resolvedTypePredicate === noTypePredicate ? void 0 : signature.resolvedTypePredicate;
            }
            function createTypePredicateFromTypePredicateNode(node, signature) {
                const parameterName = node.parameterName;
                const type = node.type && getTypeFromTypeNode(node.type);
                return parameterName.kind === 197 /* ThisType */ ? createTypePredicate(node.assertsModifier ? 2 /* AssertsThis */ : 0 /* This */, 
                /*parameterName*/
                void 0, 
                /*parameterIndex*/
                void 0, type) : createTypePredicate(node.assertsModifier ? 3 /* AssertsIdentifier */ : 1 /* Identifier */, parameterName.escapedText, findIndex(signature.parameters, (p) => p.escapedName === parameterName.escapedText), type);
            }
            function getUnionOrIntersectionType(types, kind, unionReduction) {
                return kind !== 2097152 /* Intersection */ ? getUnionType(types, unionReduction) : getIntersectionType(types);
            }
            function getReturnTypeOfSignature(signature) {
                if (!signature.resolvedReturnType) {
                    if (!pushTypeResolution(signature, 3 /* ResolvedReturnType */)) {
                        return errorType;
                    }
                    let type = signature.target ? instantiateType(getReturnTypeOfSignature(signature.target), signature.mapper) : signature.compositeSignatures ? instantiateType(getUnionOrIntersectionType(map(signature.compositeSignatures, getReturnTypeOfSignature), signature.compositeKind, 2 /* Subtype */), signature.mapper) : getReturnTypeFromAnnotation(signature.declaration) || (nodeIsMissing(signature.declaration.body) ? anyType : getReturnTypeFromBody(signature.declaration));
                    if (signature.flags & 8 /* IsInnerCallChain */) {
                        type = addOptionalTypeMarker(type);
                    }
                    else if (signature.flags & 16 /* IsOuterCallChain */) {
                        type = getOptionalType(type);
                    }
                    if (!popTypeResolution()) {
                        if (signature.declaration) {
                            const typeNode = getEffectiveReturnTypeNode(signature.declaration);
                            if (typeNode) {
                                error2(typeNode, Diagnostics.Return_type_annotation_circularly_references_itself);
                            }
                            else if (noImplicitAny) {
                                const declaration = signature.declaration;
                                const name = getNameOfDeclaration(declaration);
                                if (name) {
                                    error2(name, Diagnostics._0_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_referenced_directly_or_indirectly_in_one_of_its_return_expressions, declarationNameToString(name));
                                }
                                else {
                                    error2(declaration, Diagnostics.Function_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_referenced_directly_or_indirectly_in_one_of_its_return_expressions);
                                }
                            }
                        }
                        type = anyType;
                    }
                    signature.resolvedReturnType = type;
                }
                return signature.resolvedReturnType;
            }
            function getReturnTypeFromAnnotation(declaration) {
                if (declaration.kind === 176 /* Constructor */) {
                    return getDeclaredTypeOfClassOrInterface(getMergedSymbol(declaration.parent.symbol));
                }
                const typeNode = getEffectiveReturnTypeNode(declaration);
                if (isJSDocSignature(declaration)) {
                    const root = getJSDocRoot(declaration);
                    if (root && isConstructorDeclaration(root.parent) && !typeNode) {
                        return getDeclaredTypeOfClassOrInterface(getMergedSymbol(root.parent.parent.symbol));
                    }
                }
                if (isJSDocConstructSignature(declaration)) {
                    return getTypeFromTypeNode(declaration.parameters[0].type);
                }
                if (typeNode) {
                    return getTypeFromTypeNode(typeNode);
                }
                if (declaration.kind === 177 /* GetAccessor */ && hasBindableName(declaration)) {
                    const jsDocType = isInJSFile(declaration) && getTypeForDeclarationFromJSDocComment(declaration);
                    if (jsDocType) {
                        return jsDocType;
                    }
                    const setter = getDeclarationOfKind(getSymbolOfDeclaration(declaration), 178 /* SetAccessor */);
                    const setterType = getAnnotatedAccessorType(setter);
                    if (setterType) {
                        return setterType;
                    }
                }
                return getReturnTypeOfTypeTag(declaration);
            }
            function isResolvingReturnTypeOfSignature(signature) {
                return signature.compositeSignatures && some(signature.compositeSignatures, isResolvingReturnTypeOfSignature) || !signature.resolvedReturnType && findResolutionCycleStartIndex(signature, 3 /* ResolvedReturnType */) >= 0;
            }
            function getRestTypeOfSignature(signature) {
                return tryGetRestTypeOfSignature(signature) || anyType;
            }
            function tryGetRestTypeOfSignature(signature) {
                if (signatureHasRestParameter(signature)) {
                    const sigRestType = getTypeOfSymbol(signature.parameters[signature.parameters.length - 1]);
                    const restType = isTupleType(sigRestType) ? getRestTypeOfTupleType(sigRestType) : sigRestType;
                    return restType && getIndexTypeOfType(restType, numberType);
                }
                return void 0;
            }
            function getSignatureInstantiation(signature, typeArguments, isJavascript, inferredTypeParameters) {
                const instantiatedSignature = getSignatureInstantiationWithoutFillingInTypeArguments(signature, fillMissingTypeArguments(typeArguments, signature.typeParameters, getMinTypeArgumentCount(signature.typeParameters), isJavascript));
                if (inferredTypeParameters) {
                    const returnSignature = getSingleCallOrConstructSignature(getReturnTypeOfSignature(instantiatedSignature));
                    if (returnSignature) {
                        const newReturnSignature = cloneSignature(returnSignature);
                        newReturnSignature.typeParameters = inferredTypeParameters;
                        const newInstantiatedSignature = cloneSignature(instantiatedSignature);
                        newInstantiatedSignature.resolvedReturnType = getOrCreateTypeFromSignature(newReturnSignature);
                        return newInstantiatedSignature;
                    }
                }
                return instantiatedSignature;
            }
            function getSignatureInstantiationWithoutFillingInTypeArguments(signature, typeArguments) {
                const instantiations = signature.instantiations || (signature.instantiations = /* @__PURE__ */ new Map());
                const id = getTypeListId(typeArguments);
                let instantiation = instantiations.get(id);
                if (!instantiation) {
                    instantiations.set(id, instantiation = createSignatureInstantiation(signature, typeArguments));
                }
                return instantiation;
            }
            function createSignatureInstantiation(signature, typeArguments) {
                return instantiateSignature(signature, createSignatureTypeMapper(signature, typeArguments), 
                /*eraseTypeParameters*/
                true);
            }
            function createSignatureTypeMapper(signature, typeArguments) {
                return createTypeMapper(signature.typeParameters, typeArguments);
            }
            function getErasedSignature(signature) {
                return signature.typeParameters ? signature.erasedSignatureCache || (signature.erasedSignatureCache = createErasedSignature(signature)) : signature;
            }
            function createErasedSignature(signature) {
                return instantiateSignature(signature, createTypeEraser(signature.typeParameters), 
                /*eraseTypeParameters*/
                true);
            }
            function getCanonicalSignature(signature) {
                return signature.typeParameters ? signature.canonicalSignatureCache || (signature.canonicalSignatureCache = createCanonicalSignature(signature)) : signature;
            }
            function createCanonicalSignature(signature) {
                return getSignatureInstantiation(signature, map(signature.typeParameters, (tp) => tp.target && !getConstraintOfTypeParameter(tp.target) ? tp.target : tp), isInJSFile(signature.declaration));
            }
            function getBaseSignature(signature) {
                const typeParameters = signature.typeParameters;
                if (typeParameters) {
                    if (signature.baseSignatureCache) {
                        return signature.baseSignatureCache;
                    }
                    const typeEraser = createTypeEraser(typeParameters);
                    const baseConstraintMapper = createTypeMapper(typeParameters, map(typeParameters, (tp) => getConstraintOfTypeParameter(tp) || unknownType));
                    let baseConstraints = map(typeParameters, (tp) => instantiateType(tp, baseConstraintMapper) || unknownType);
                    for (let i = 0; i < typeParameters.length - 1; i++) {
                        baseConstraints = instantiateTypes(baseConstraints, baseConstraintMapper);
                    }
                    baseConstraints = instantiateTypes(baseConstraints, typeEraser);
                    return signature.baseSignatureCache = instantiateSignature(signature, createTypeMapper(typeParameters, baseConstraints), 
                    /*eraseTypeParameters*/
                    true);
                }
                return signature;
            }
            function getOrCreateTypeFromSignature(signature) {
                var _a;
                if (!signature.isolatedSignatureType) {
                    const kind = (_a = signature.declaration) == null ? void 0 : _a.kind;
                    const isConstructor = kind === void 0 || kind === 176 /* Constructor */ || kind === 180 /* ConstructSignature */ || kind === 185 /* ConstructorType */;
                    const type = createObjectType(16 /* Anonymous */);
                    type.members = emptySymbols;
                    type.properties = emptyArray;
                    type.callSignatures = !isConstructor ? [signature] : emptyArray;
                    type.constructSignatures = isConstructor ? [signature] : emptyArray;
                    type.indexInfos = emptyArray;
                    signature.isolatedSignatureType = type;
                }
                return signature.isolatedSignatureType;
            }
            function getIndexSymbol(symbol) {
                return symbol.members ? getIndexSymbolFromSymbolTable(symbol.members) : void 0;
            }
            function getIndexSymbolFromSymbolTable(symbolTable) {
                return symbolTable.get("__index" /* Index */);
            }
            function createIndexInfo(keyType, type, isReadonly, declaration) {
                return { keyType, type, isReadonly, declaration };
            }
            function getIndexInfosOfSymbol(symbol) {
                const indexSymbol = getIndexSymbol(symbol);
                return indexSymbol ? getIndexInfosOfIndexSymbol(indexSymbol) : emptyArray;
            }
            function getIndexInfosOfIndexSymbol(indexSymbol) {
                if (indexSymbol.declarations) {
                    const indexInfos = [];
                    for (const declaration of indexSymbol.declarations) {
                        if (declaration.parameters.length === 1) {
                            const parameter = declaration.parameters[0];
                            if (parameter.type) {
                                forEachType(getTypeFromTypeNode(parameter.type), (keyType) => {
                                    if (isValidIndexKeyType(keyType) && !findIndexInfo(indexInfos, keyType)) {
                                        indexInfos.push(createIndexInfo(keyType, declaration.type ? getTypeFromTypeNode(declaration.type) : anyType, hasEffectiveModifier(declaration, 8 /* Readonly */), declaration));
                                    }
                                });
                            }
                        }
                    }
                    return indexInfos;
                }
                return emptyArray;
            }
            function isValidIndexKeyType(type) {
                return !!(type.flags & (4 /* String */ | 8 /* Number */ | 4096 /* ESSymbol */)) || isPatternLiteralType(type) || !!(type.flags & 2097152 /* Intersection */) && !isGenericType(type) && some(type.types, isValidIndexKeyType);
            }
            function getConstraintDeclaration(type) {
                return mapDefined(filter(type.symbol && type.symbol.declarations, isTypeParameterDeclaration), getEffectiveConstraintOfTypeParameter)[0];
            }
            function getInferredTypeParameterConstraint(typeParameter, omitTypeReferences) {
                var _a;
                let inferences;
                if ((_a = typeParameter.symbol) == null ? void 0 : _a.declarations) {
                    for (const declaration of typeParameter.symbol.declarations) {
                        if (declaration.parent.kind === 195 /* InferType */) {
                            const [childTypeParameter = declaration.parent, grandParent] = walkUpParenthesizedTypesAndGetParentAndChild(declaration.parent.parent);
                            if (grandParent.kind === 183 /* TypeReference */ && !omitTypeReferences) {
                                const typeReference = grandParent;
                                const typeParameters = getTypeParametersForTypeReferenceOrImport(typeReference);
                                if (typeParameters) {
                                    const index = typeReference.typeArguments.indexOf(childTypeParameter);
                                    if (index < typeParameters.length) {
                                        const declaredConstraint = getConstraintOfTypeParameter(typeParameters[index]);
                                        if (declaredConstraint) {
                                            const mapper = makeDeferredTypeMapper(typeParameters, typeParameters.map((_, index2) => () => {
                                                return getEffectiveTypeArgumentAtIndex(typeReference, typeParameters, index2);
                                            }));
                                            const constraint = instantiateType(declaredConstraint, mapper);
                                            if (constraint !== typeParameter) {
                                                inferences = append(inferences, constraint);
                                            }
                                        }
                                    }
                                }
                            }
                            else if (grandParent.kind === 169 /* Parameter */ && grandParent.dotDotDotToken || grandParent.kind === 191 /* RestType */ || grandParent.kind === 202 /* NamedTupleMember */ && grandParent.dotDotDotToken) {
                                inferences = append(inferences, createArrayType(unknownType));
                            }
                            else if (grandParent.kind === 204 /* TemplateLiteralTypeSpan */) {
                                inferences = append(inferences, stringType);
                            }
                            else if (grandParent.kind === 168 /* TypeParameter */ && grandParent.parent.kind === 200 /* MappedType */) {
                                inferences = append(inferences, keyofConstraintType);
                            }
                            else if (grandParent.kind === 200 /* MappedType */ && grandParent.type && skipParentheses(grandParent.type) === declaration.parent && grandParent.parent.kind === 194 /* ConditionalType */ && grandParent.parent.extendsType === grandParent && grandParent.parent.checkType.kind === 200 /* MappedType */ && grandParent.parent.checkType.type) {
                                const checkMappedType2 = grandParent.parent.checkType;
                                const nodeType = getTypeFromTypeNode(checkMappedType2.type);
                                inferences = append(inferences, instantiateType(nodeType, makeUnaryTypeMapper(getDeclaredTypeOfTypeParameter(getSymbolOfDeclaration(checkMappedType2.typeParameter)), checkMappedType2.typeParameter.constraint ? getTypeFromTypeNode(checkMappedType2.typeParameter.constraint) : keyofConstraintType)));
                            }
                        }
                    }
                }
                return inferences && getIntersectionType(inferences);
            }
            function getConstraintFromTypeParameter(typeParameter) {
                if (!typeParameter.constraint) {
                    if (typeParameter.target) {
                        const targetConstraint = getConstraintOfTypeParameter(typeParameter.target);
                        typeParameter.constraint = targetConstraint ? instantiateType(targetConstraint, typeParameter.mapper) : noConstraintType;
                    }
                    else {
                        const constraintDeclaration = getConstraintDeclaration(typeParameter);
                        if (!constraintDeclaration) {
                            typeParameter.constraint = getInferredTypeParameterConstraint(typeParameter) || noConstraintType;
                        }
                        else {
                            let type = getTypeFromTypeNode(constraintDeclaration);
                            if (type.flags & 1 /* Any */ && !isErrorType(type)) {
                                type = constraintDeclaration.parent.parent.kind === 200 /* MappedType */ ? keyofConstraintType : unknownType;
                            }
                            typeParameter.constraint = type;
                        }
                    }
                }
                return typeParameter.constraint === noConstraintType ? void 0 : typeParameter.constraint;
            }
            function getParentSymbolOfTypeParameter(typeParameter) {
                const tp = getDeclarationOfKind(typeParameter.symbol, 168 /* TypeParameter */);
                const host2 = isJSDocTemplateTag(tp.parent) ? getEffectiveContainerForJSDocTemplateTag(tp.parent) : tp.parent;
                return host2 && getSymbolOfNode(host2);
            }
            function getTypeListId(types) {
                let result = "";
                if (types) {
                    const length2 = types.length;
                    let i = 0;
                    while (i < length2) {
                        const startId = types[i].id;
                        let count = 1;
                        while (i + count < length2 && types[i + count].id === startId + count) {
                            count++;
                        }
                        if (result.length) {
                            result += ",";
                        }
                        result += startId;
                        if (count > 1) {
                            result += ":" + count;
                        }
                        i += count;
                    }
                }
                return result;
            }
            function getAliasId(aliasSymbol, aliasTypeArguments) {
                return aliasSymbol ? `@${getSymbolId(aliasSymbol)}` + (aliasTypeArguments ? `:${getTypeListId(aliasTypeArguments)}` : "") : "";
            }
            function getPropagatingFlagsOfTypes(types, excludeKinds) {
                let result = 0;
                for (const type of types) {
                    if (excludeKinds === void 0 || !(type.flags & excludeKinds)) {
                        result |= getObjectFlags(type);
                    }
                }
                return result & 458752 /* PropagatingFlags */;
            }
            function tryCreateTypeReference(target, typeArguments) {
                if (some(typeArguments) && target === emptyGenericType) {
                    return unknownType;
                }
                return createTypeReference(target, typeArguments);
            }
            function createTypeReference(target, typeArguments) {
                const id = getTypeListId(typeArguments);
                let type = target.instantiations.get(id);
                if (!type) {
                    type = createObjectType(4 /* Reference */, target.symbol);
                    target.instantiations.set(id, type);
                    type.objectFlags |= typeArguments ? getPropagatingFlagsOfTypes(typeArguments) : 0;
                    type.target = target;
                    type.resolvedTypeArguments = typeArguments;
                }
                return type;
            }
            function cloneTypeReference(source) {
                const type = createTypeWithSymbol(source.flags, source.symbol);
                type.objectFlags = source.objectFlags;
                type.target = source.target;
                type.resolvedTypeArguments = source.resolvedTypeArguments;
                return type;
            }
            function createDeferredTypeReference(target, node, mapper, aliasSymbol, aliasTypeArguments) {
                if (!aliasSymbol) {
                    aliasSymbol = getAliasSymbolForTypeNode(node);
                    const localAliasTypeArguments = getTypeArgumentsForAliasSymbol(aliasSymbol);
                    aliasTypeArguments = mapper ? instantiateTypes(localAliasTypeArguments, mapper) : localAliasTypeArguments;
                }
                const type = createObjectType(4 /* Reference */, target.symbol);
                type.target = target;
                type.node = node;
                type.mapper = mapper;
                type.aliasSymbol = aliasSymbol;
                type.aliasTypeArguments = aliasTypeArguments;
                return type;
            }
            function getTypeArguments(type) {
                var _a, _b;
                if (!type.resolvedTypeArguments) {
                    if (!pushTypeResolution(type, 6 /* ResolvedTypeArguments */)) {
                        return ((_a = type.target.localTypeParameters) == null ? void 0 : _a.map(() => errorType)) || emptyArray;
                    }
                    const node = type.node;
                    const typeArguments = !node ? emptyArray : node.kind === 183 /* TypeReference */ ? concatenate(type.target.outerTypeParameters, getEffectiveTypeArguments2(node, type.target.localTypeParameters)) : node.kind === 188 /* ArrayType */ ? [getTypeFromTypeNode(node.elementType)] : map(node.elements, getTypeFromTypeNode);
                    if (popTypeResolution()) {
                        type.resolvedTypeArguments = type.mapper ? instantiateTypes(typeArguments, type.mapper) : typeArguments;
                    }
                    else {
                        type.resolvedTypeArguments = ((_b = type.target.localTypeParameters) == null ? void 0 : _b.map(() => errorType)) || emptyArray;
                        error2(type.node || currentNode, type.target.symbol ? Diagnostics.Type_arguments_for_0_circularly_reference_themselves : Diagnostics.Tuple_type_arguments_circularly_reference_themselves, type.target.symbol && symbolToString(type.target.symbol));
                    }
                }
                return type.resolvedTypeArguments;
            }
            function getTypeReferenceArity(type) {
                return length(type.target.typeParameters);
            }
            function getTypeFromClassOrInterfaceReference(node, symbol) {
                const type = getDeclaredTypeOfSymbol(getMergedSymbol(symbol));
                const typeParameters = type.localTypeParameters;
                if (typeParameters) {
                    const numTypeArguments = length(node.typeArguments);
                    const minTypeArgumentCount = getMinTypeArgumentCount(typeParameters);
                    const isJs = isInJSFile(node);
                    const isJsImplicitAny = !noImplicitAny && isJs;
                    if (!isJsImplicitAny && (numTypeArguments < minTypeArgumentCount || numTypeArguments > typeParameters.length)) {
                        const missingAugmentsTag = isJs && isExpressionWithTypeArguments(node) && !isJSDocAugmentsTag(node.parent);
                        const diag2 = minTypeArgumentCount === typeParameters.length ? missingAugmentsTag ? Diagnostics.Expected_0_type_arguments_provide_these_with_an_extends_tag : Diagnostics.Generic_type_0_requires_1_type_argument_s : missingAugmentsTag ? Diagnostics.Expected_0_1_type_arguments_provide_these_with_an_extends_tag : Diagnostics.Generic_type_0_requires_between_1_and_2_type_arguments;
                        const typeStr = typeToString(type, 
                        /*enclosingDeclaration*/
                        void 0, 2 /* WriteArrayAsGenericType */);
                        error2(node, diag2, typeStr, minTypeArgumentCount, typeParameters.length);
                        if (!isJs) {
                            return errorType;
                        }
                    }
                    if (node.kind === 183 /* TypeReference */ && isDeferredTypeReferenceNode(node, length(node.typeArguments) !== typeParameters.length)) {
                        return createDeferredTypeReference(type, node, 
                        /*mapper*/
                        void 0);
                    }
                    const typeArguments = concatenate(type.outerTypeParameters, fillMissingTypeArguments(typeArgumentsFromTypeReferenceNode(node), typeParameters, minTypeArgumentCount, isJs));
                    return createTypeReference(type, typeArguments);
                }
                return checkNoTypeArguments(node, symbol) ? type : errorType;
            }
            function getTypeAliasInstantiation(symbol, typeArguments, aliasSymbol, aliasTypeArguments) {
                const type = getDeclaredTypeOfSymbol(symbol);
                if (type === intrinsicMarkerType) {
                    const typeKind = intrinsicTypeKinds.get(symbol.escapedName);
                    if (typeKind !== void 0 && typeArguments && typeArguments.length === 1) {
                        return typeKind === 4 /* NoInfer */ ? getNoInferType(typeArguments[0]) : getStringMappingType(symbol, typeArguments[0]);
                    }
                }
                const links = getSymbolLinks(symbol);
                const typeParameters = links.typeParameters;
                const id = getTypeListId(typeArguments) + getAliasId(aliasSymbol, aliasTypeArguments);
                let instantiation = links.instantiations.get(id);
                if (!instantiation) {
                    links.instantiations.set(id, instantiation = instantiateTypeWithAlias(type, createTypeMapper(typeParameters, fillMissingTypeArguments(typeArguments, typeParameters, getMinTypeArgumentCount(typeParameters), isInJSFile(symbol.valueDeclaration))), aliasSymbol, aliasTypeArguments));
                }
                return instantiation;
            }
            function getTypeFromTypeAliasReference(node, symbol) {
                if (getCheckFlags(symbol) & 1048576 /* Unresolved */) {
                    const typeArguments = typeArgumentsFromTypeReferenceNode(node);
                    const id = getAliasId(symbol, typeArguments);
                    let errorType2 = errorTypes.get(id);
                    if (!errorType2) {
                        errorType2 = createIntrinsicType(1 /* Any */, "error", 
                        /*objectFlags*/
                        void 0, `alias ${id}`);
                        errorType2.aliasSymbol = symbol;
                        errorType2.aliasTypeArguments = typeArguments;
                        errorTypes.set(id, errorType2);
                    }
                    return errorType2;
                }
                const type = getDeclaredTypeOfSymbol(symbol);
                const typeParameters = getSymbolLinks(symbol).typeParameters;
                if (typeParameters) {
                    const numTypeArguments = length(node.typeArguments);
                    const minTypeArgumentCount = getMinTypeArgumentCount(typeParameters);
                    if (numTypeArguments < minTypeArgumentCount || numTypeArguments > typeParameters.length) {
                        error2(node, minTypeArgumentCount === typeParameters.length ? Diagnostics.Generic_type_0_requires_1_type_argument_s : Diagnostics.Generic_type_0_requires_between_1_and_2_type_arguments, symbolToString(symbol), minTypeArgumentCount, typeParameters.length);
                        return errorType;
                    }
                    const aliasSymbol = getAliasSymbolForTypeNode(node);
                    let newAliasSymbol = aliasSymbol && (isLocalTypeAlias(symbol) || !isLocalTypeAlias(aliasSymbol)) ? aliasSymbol : void 0;
                    let aliasTypeArguments;
                    if (newAliasSymbol) {
                        aliasTypeArguments = getTypeArgumentsForAliasSymbol(newAliasSymbol);
                    }
                    else if (isTypeReferenceType(node)) {
                        const aliasSymbol2 = resolveTypeReferenceName(node, 2097152 /* Alias */, 
                        /*ignoreErrors*/
                        true);
                        if (aliasSymbol2 && aliasSymbol2 !== unknownSymbol) {
                            const resolved = resolveAlias(aliasSymbol2);
                            if (resolved && resolved.flags & 524288 /* TypeAlias */) {
                                newAliasSymbol = resolved;
                                aliasTypeArguments = typeArgumentsFromTypeReferenceNode(node) || (typeParameters ? [] : void 0);
                            }
                        }
                    }
                    return getTypeAliasInstantiation(symbol, typeArgumentsFromTypeReferenceNode(node), newAliasSymbol, aliasTypeArguments);
                }
                return checkNoTypeArguments(node, symbol) ? type : errorType;
            }
            function isLocalTypeAlias(symbol) {
                var _a;
                const declaration = (_a = symbol.declarations) == null ? void 0 : _a.find(isTypeAlias);
                return !!(declaration && getContainingFunction(declaration));
            }
            function getTypeReferenceName(node) {
                switch (node.kind) {
                    case 183 /* TypeReference */:
                        return node.typeName;
                    case 233 /* ExpressionWithTypeArguments */:
                        const expr = node.expression;
                        if (isEntityNameExpression(expr)) {
                            return expr;
                        }
                }
                return void 0;
            }
            function getSymbolPath(symbol) {
                return symbol.parent ? `${getSymbolPath(symbol.parent)}.${symbol.escapedName}` : symbol.escapedName;
            }
            function getUnresolvedSymbolForEntityName(name) {
                const identifier = name.kind === 166 /* QualifiedName */ ? name.right : name.kind === 211 /* PropertyAccessExpression */ ? name.name : name;
                const text = identifier.escapedText;
                if (text) {
                    const parentSymbol = name.kind === 166 /* QualifiedName */ ? getUnresolvedSymbolForEntityName(name.left) : name.kind === 211 /* PropertyAccessExpression */ ? getUnresolvedSymbolForEntityName(name.expression) : void 0;
                    const path = parentSymbol ? `${getSymbolPath(parentSymbol)}.${text}` : text;
                    let result = unresolvedSymbols.get(path);
                    if (!result) {
                        unresolvedSymbols.set(path, result = createSymbol(524288 /* TypeAlias */, text, 1048576 /* Unresolved */));
                        result.parent = parentSymbol;
                        result.links.declaredType = unresolvedType;
                    }
                    return result;
                }
                return unknownSymbol;
            }
            function resolveTypeReferenceName(typeReference, meaning, ignoreErrors) {
                const name = getTypeReferenceName(typeReference);
                if (!name) {
                    return unknownSymbol;
                }
                const symbol = resolveEntityName(name, meaning, ignoreErrors);
                return symbol && symbol !== unknownSymbol ? symbol : ignoreErrors ? unknownSymbol : getUnresolvedSymbolForEntityName(name);
            }
            function getTypeReferenceType(node, symbol) {
                if (symbol === unknownSymbol) {
                    return errorType;
                }
                symbol = getExpandoSymbol(symbol) || symbol;
                if (symbol.flags & (32 /* Class */ | 64 /* Interface */)) {
                    return getTypeFromClassOrInterfaceReference(node, symbol);
                }
                if (symbol.flags & 524288 /* TypeAlias */) {
                    return getTypeFromTypeAliasReference(node, symbol);
                }
                const res = tryGetDeclaredTypeOfSymbol(symbol);
                if (res) {
                    return checkNoTypeArguments(node, symbol) ? getRegularTypeOfLiteralType(res) : errorType;
                }
                if (symbol.flags & 111551 /* Value */ && isJSDocTypeReference(node)) {
                    const jsdocType = getTypeFromJSDocValueReference(node, symbol);
                    if (jsdocType) {
                        return jsdocType;
                    }
                    else {
                        resolveTypeReferenceName(node, 788968 /* Type */);
                        return getTypeOfSymbol(symbol);
                    }
                }
                return errorType;
            }
            function getTypeFromJSDocValueReference(node, symbol) {
                const links = getNodeLinks(node);
                if (!links.resolvedJSDocType) {
                    const valueType = getTypeOfSymbol(symbol);
                    let typeType = valueType;
                    if (symbol.valueDeclaration) {
                        const isImportTypeWithQualifier = node.kind === 205 /* ImportType */ && node.qualifier;
                        if (valueType.symbol && valueType.symbol !== symbol && isImportTypeWithQualifier) {
                            typeType = getTypeReferenceType(node, valueType.symbol);
                        }
                    }
                    links.resolvedJSDocType = typeType;
                }
                return links.resolvedJSDocType;
            }
            function getNoInferType(type) {
                return isNoInferTargetType(type) ? getOrCreateSubstitutionType(type, unknownType) : type;
            }
            function isNoInferTargetType(type) {
                return !!(type.flags & 3145728 /* UnionOrIntersection */ && some(type.types, isNoInferTargetType) || type.flags & 33554432 /* Substitution */ && !isNoInferType(type) && isNoInferTargetType(type.baseType) || type.flags & 524288 /* Object */ && !isEmptyAnonymousObjectType(type) || type.flags & (465829888 /* Instantiable */ & ~33554432 /* Substitution */) && !isPatternLiteralType(type));
            }
            function isNoInferType(type) {
                return !!(type.flags & 33554432 /* Substitution */ && type.constraint.flags & 2 /* Unknown */);
            }
            function getSubstitutionType(baseType, constraint) {
                return constraint.flags & 3 /* AnyOrUnknown */ || constraint === baseType || baseType.flags & 1 /* Any */ ? baseType : getOrCreateSubstitutionType(baseType, constraint);
            }
            function getOrCreateSubstitutionType(baseType, constraint) {
                const id = `${getTypeId(baseType)}>${getTypeId(constraint)}`;
                const cached = substitutionTypes.get(id);
                if (cached) {
                    return cached;
                }
                const result = createType(33554432 /* Substitution */);
                result.baseType = baseType;
                result.constraint = constraint;
                substitutionTypes.set(id, result);
                return result;
            }
            function getSubstitutionIntersection(substitutionType) {
                return isNoInferType(substitutionType) ? substitutionType.baseType : getIntersectionType([substitutionType.constraint, substitutionType.baseType]);
            }
            function isUnaryTupleTypeNode(node) {
                return node.kind === 189 /* TupleType */ && node.elements.length === 1;
            }
            function getImpliedConstraint(type, checkNode, extendsNode) {
                return isUnaryTupleTypeNode(checkNode) && isUnaryTupleTypeNode(extendsNode) ? getImpliedConstraint(type, checkNode.elements[0], extendsNode.elements[0]) : getActualTypeVariable(getTypeFromTypeNode(checkNode)) === getActualTypeVariable(type) ? getTypeFromTypeNode(extendsNode) : void 0;
            }
            function getConditionalFlowTypeOfType(type, node) {
                let constraints;
                let covariant = true;
                while (node && !isStatement(node) && node.kind !== 327 /* JSDoc */) {
                    const parent2 = node.parent;
                    if (parent2.kind === 169 /* Parameter */) {
                        covariant = !covariant;
                    }
                    if ((covariant || type.flags & 8650752 /* TypeVariable */) && parent2.kind === 194 /* ConditionalType */ && node === parent2.trueType) {
                        const constraint = getImpliedConstraint(type, parent2.checkType, parent2.extendsType);
                        if (constraint) {
                            constraints = append(constraints, constraint);
                        }
                    }
                    else if (type.flags & 262144 /* TypeParameter */ && parent2.kind === 200 /* MappedType */ && !parent2.nameType && node === parent2.type) {
                        const mappedType = getTypeFromTypeNode(parent2);
                        if (getTypeParameterFromMappedType(mappedType) === getActualTypeVariable(type)) {
                            const typeParameter = getHomomorphicTypeVariable(mappedType);
                            if (typeParameter) {
                                const constraint = getConstraintOfTypeParameter(typeParameter);
                                if (constraint && everyType(constraint, isArrayOrTupleType)) {
                                    constraints = append(constraints, getUnionType([numberType, numericStringType]));
                                }
                            }
                        }
                    }
                    node = parent2;
                }
                return constraints ? getSubstitutionType(type, getIntersectionType(constraints)) : type;
            }
            function isJSDocTypeReference(node) {
                return !!(node.flags & 16777216 /* JSDoc */) && (node.kind === 183 /* TypeReference */ || node.kind === 205 /* ImportType */);
            }
            function checkNoTypeArguments(node, symbol) {
                if (node.typeArguments) {
                    error2(node, Diagnostics.Type_0_is_not_generic, symbol ? symbolToString(symbol) : node.typeName ? declarationNameToString(node.typeName) : anon);
                    return false;
                }
                return true;
            }
            function getIntendedTypeFromJSDocTypeReference(node) {
                if (isIdentifier(node.typeName)) {
                    const typeArgs = node.typeArguments;
                    switch (node.typeName.escapedText) {
                        case "String":
                            checkNoTypeArguments(node);
                            return stringType;
                        case "Number":
                            checkNoTypeArguments(node);
                            return numberType;
                        case "Boolean":
                            checkNoTypeArguments(node);
                            return booleanType;
                        case "Void":
                            checkNoTypeArguments(node);
                            return voidType;
                        case "Undefined":
                            checkNoTypeArguments(node);
                            return undefinedType;
                        case "Null":
                            checkNoTypeArguments(node);
                            return nullType;
                        case "Function":
                        case "function":
                            checkNoTypeArguments(node);
                            return globalFunctionType;
                        case "array":
                            return (!typeArgs || !typeArgs.length) && !noImplicitAny ? anyArrayType : void 0;
                        case "promise":
                            return (!typeArgs || !typeArgs.length) && !noImplicitAny ? createPromiseType(anyType) : void 0;
                        case "Object":
                            if (typeArgs && typeArgs.length === 2) {
                                if (isJSDocIndexSignature(node)) {
                                    const indexed = getTypeFromTypeNode(typeArgs[0]);
                                    const target = getTypeFromTypeNode(typeArgs[1]);
                                    const indexInfo = indexed === stringType || indexed === numberType ? [createIndexInfo(indexed, target, 
                                        /*isReadonly*/
                                        false)] : emptyArray;
                                    return createAnonymousType(
                                    /*symbol*/
                                    void 0, emptySymbols, emptyArray, emptyArray, indexInfo);
                                }
                                return anyType;
                            }
                            checkNoTypeArguments(node);
                            return !noImplicitAny ? anyType : void 0;
                    }
                }
            }
            function getTypeFromJSDocNullableTypeNode(node) {
                const type = getTypeFromTypeNode(node.type);
                return strictNullChecks ? getNullableType(type, 65536 /* Null */) : type;
            }
            function getTypeFromTypeReference(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    if (isConstTypeReference(node) && isAssertionExpression(node.parent)) {
                        links.resolvedSymbol = unknownSymbol;
                        return links.resolvedType = checkExpressionCached(node.parent.expression);
                    }
                    let symbol;
                    let type;
                    const meaning = 788968 /* Type */;
                    if (isJSDocTypeReference(node)) {
                        type = getIntendedTypeFromJSDocTypeReference(node);
                        if (!type) {
                            symbol = resolveTypeReferenceName(node, meaning, 
                            /*ignoreErrors*/
                            true);
                            if (symbol === unknownSymbol) {
                                symbol = resolveTypeReferenceName(node, meaning | 111551 /* Value */);
                            }
                            else {
                                resolveTypeReferenceName(node, meaning);
                            }
                            type = getTypeReferenceType(node, symbol);
                        }
                    }
                    if (!type) {
                        symbol = resolveTypeReferenceName(node, meaning);
                        type = getTypeReferenceType(node, symbol);
                    }
                    links.resolvedSymbol = symbol;
                    links.resolvedType = type;
                }
                return links.resolvedType;
            }
            function typeArgumentsFromTypeReferenceNode(node) {
                return map(node.typeArguments, getTypeFromTypeNode);
            }
            function getTypeFromTypeQueryNode(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    const type = checkExpressionWithTypeArguments(node);
                    links.resolvedType = getRegularTypeOfLiteralType(getWidenedType(type));
                }
                return links.resolvedType;
            }
            function getTypeOfGlobalSymbol(symbol, arity) {
                function getTypeDeclaration(symbol2) {
                    const declarations = symbol2.declarations;
                    if (declarations) {
                        for (const declaration of declarations) {
                            switch (declaration.kind) {
                                case 263 /* ClassDeclaration */:
                                case 264 /* InterfaceDeclaration */:
                                case 266 /* EnumDeclaration */:
                                    return declaration;
                            }
                        }
                    }
                }
                if (!symbol) {
                    return arity ? emptyGenericType : emptyObjectType;
                }
                const type = getDeclaredTypeOfSymbol(symbol);
                if (!(type.flags & 524288 /* Object */)) {
                    error2(getTypeDeclaration(symbol), Diagnostics.Global_type_0_must_be_a_class_or_interface_type, symbolName(symbol));
                    return arity ? emptyGenericType : emptyObjectType;
                }
                if (length(type.typeParameters) !== arity) {
                    error2(getTypeDeclaration(symbol), Diagnostics.Global_type_0_must_have_1_type_parameter_s, symbolName(symbol), arity);
                    return arity ? emptyGenericType : emptyObjectType;
                }
                return type;
            }
            function getGlobalValueSymbol(name, reportErrors2) {
                return getGlobalSymbol(name, 111551 /* Value */, reportErrors2 ? Diagnostics.Cannot_find_global_value_0 : void 0);
            }
            function getGlobalTypeSymbol(name, reportErrors2) {
                return getGlobalSymbol(name, 788968 /* Type */, reportErrors2 ? Diagnostics.Cannot_find_global_type_0 : void 0);
            }
            function getGlobalTypeAliasSymbol(name, arity, reportErrors2) {
                const symbol = getGlobalSymbol(name, 788968 /* Type */, reportErrors2 ? Diagnostics.Cannot_find_global_type_0 : void 0);
                if (symbol) {
                    getDeclaredTypeOfSymbol(symbol);
                    if (length(getSymbolLinks(symbol).typeParameters) !== arity) {
                        const decl = symbol.declarations && find(symbol.declarations, isTypeAliasDeclaration);
                        error2(decl, Diagnostics.Global_type_0_must_have_1_type_parameter_s, symbolName(symbol), arity);
                        return void 0;
                    }
                }
                return symbol;
            }
            function getGlobalSymbol(name, meaning, diagnostic) {
                return resolveName(
                /*location*/
                void 0, name, meaning, diagnostic, name, 
                /*isUse*/
                false, 
                /*excludeGlobals*/
                false, 
                /*getSpellingSuggestions*/
                false);
            }
            function getGlobalType(name, arity, reportErrors2) {
                const symbol = getGlobalTypeSymbol(name, reportErrors2);
                return symbol || reportErrors2 ? getTypeOfGlobalSymbol(symbol, arity) : void 0;
            }
            function getGlobalTypedPropertyDescriptorType() {
                return deferredGlobalTypedPropertyDescriptorType || (deferredGlobalTypedPropertyDescriptorType = getGlobalType("TypedPropertyDescriptor", 
                /*arity*/
                1, 
                /*reportErrors*/
                true) || emptyGenericType);
            }
            function getGlobalTemplateStringsArrayType() {
                return deferredGlobalTemplateStringsArrayType || (deferredGlobalTemplateStringsArrayType = getGlobalType("TemplateStringsArray", 
                /*arity*/
                0, 
                /*reportErrors*/
                true) || emptyObjectType);
            }
            function getGlobalImportMetaType() {
                return deferredGlobalImportMetaType || (deferredGlobalImportMetaType = getGlobalType("ImportMeta", 
                /*arity*/
                0, 
                /*reportErrors*/
                true) || emptyObjectType);
            }
            function getGlobalImportMetaExpressionType() {
                if (!deferredGlobalImportMetaExpressionType) {
                    const symbol = createSymbol(0 /* None */, "ImportMetaExpression");
                    const importMetaType = getGlobalImportMetaType();
                    const metaPropertySymbol = createSymbol(4 /* Property */, "meta", 8 /* Readonly */);
                    metaPropertySymbol.parent = symbol;
                    metaPropertySymbol.links.type = importMetaType;
                    const members = createSymbolTable([metaPropertySymbol]);
                    symbol.members = members;
                    deferredGlobalImportMetaExpressionType = createAnonymousType(symbol, members, emptyArray, emptyArray, emptyArray);
                }
                return deferredGlobalImportMetaExpressionType;
            }
            function getGlobalImportCallOptionsType(reportErrors2) {
                return deferredGlobalImportCallOptionsType || (deferredGlobalImportCallOptionsType = getGlobalType("ImportCallOptions", 
                /*arity*/
                0, reportErrors2)) || emptyObjectType;
            }
            function getGlobalImportAttributesType(reportErrors2) {
                return deferredGlobalImportAttributesType || (deferredGlobalImportAttributesType = getGlobalType("ImportAttributes", 
                /*arity*/
                0, reportErrors2)) || emptyObjectType;
            }
            function getGlobalESSymbolConstructorSymbol(reportErrors2) {
                return deferredGlobalESSymbolConstructorSymbol || (deferredGlobalESSymbolConstructorSymbol = getGlobalValueSymbol("Symbol", reportErrors2));
            }
            function getGlobalESSymbolConstructorTypeSymbol(reportErrors2) {
                return deferredGlobalESSymbolConstructorTypeSymbol || (deferredGlobalESSymbolConstructorTypeSymbol = getGlobalTypeSymbol("SymbolConstructor", reportErrors2));
            }
            function getGlobalESSymbolType() {
                return deferredGlobalESSymbolType || (deferredGlobalESSymbolType = getGlobalType("Symbol", 
                /*arity*/
                0, 
                /*reportErrors*/
                false)) || emptyObjectType;
            }
            function getGlobalPromiseType(reportErrors2) {
                return deferredGlobalPromiseType || (deferredGlobalPromiseType = getGlobalType("Promise", 
                /*arity*/
                1, reportErrors2)) || emptyGenericType;
            }
            function getGlobalPromiseLikeType(reportErrors2) {
                return deferredGlobalPromiseLikeType || (deferredGlobalPromiseLikeType = getGlobalType("PromiseLike", 
                /*arity*/
                1, reportErrors2)) || emptyGenericType;
            }
            function getGlobalPromiseConstructorSymbol(reportErrors2) {
                return deferredGlobalPromiseConstructorSymbol || (deferredGlobalPromiseConstructorSymbol = getGlobalValueSymbol("Promise", reportErrors2));
            }
            function getGlobalPromiseConstructorLikeType(reportErrors2) {
                return deferredGlobalPromiseConstructorLikeType || (deferredGlobalPromiseConstructorLikeType = getGlobalType("PromiseConstructorLike", 
                /*arity*/
                0, reportErrors2)) || emptyObjectType;
            }
            function getGlobalAsyncIterableType(reportErrors2) {
                return deferredGlobalAsyncIterableType || (deferredGlobalAsyncIterableType = getGlobalType("AsyncIterable", 
                /*arity*/
                1, reportErrors2)) || emptyGenericType;
            }
            function getGlobalAsyncIteratorType(reportErrors2) {
                return deferredGlobalAsyncIteratorType || (deferredGlobalAsyncIteratorType = getGlobalType("AsyncIterator", 
                /*arity*/
                3, reportErrors2)) || emptyGenericType;
            }
            function getGlobalAsyncIterableIteratorType(reportErrors2) {
                return deferredGlobalAsyncIterableIteratorType || (deferredGlobalAsyncIterableIteratorType = getGlobalType("AsyncIterableIterator", 
                /*arity*/
                1, reportErrors2)) || emptyGenericType;
            }
            function getGlobalAsyncGeneratorType(reportErrors2) {
                return deferredGlobalAsyncGeneratorType || (deferredGlobalAsyncGeneratorType = getGlobalType("AsyncGenerator", 
                /*arity*/
                3, reportErrors2)) || emptyGenericType;
            }
            function getGlobalIterableType(reportErrors2) {
                return deferredGlobalIterableType || (deferredGlobalIterableType = getGlobalType("Iterable", 
                /*arity*/
                1, reportErrors2)) || emptyGenericType;
            }
            function getGlobalIteratorType(reportErrors2) {
                return deferredGlobalIteratorType || (deferredGlobalIteratorType = getGlobalType("Iterator", 
                /*arity*/
                3, reportErrors2)) || emptyGenericType;
            }
            function getGlobalIterableIteratorType(reportErrors2) {
                return deferredGlobalIterableIteratorType || (deferredGlobalIterableIteratorType = getGlobalType("IterableIterator", 
                /*arity*/
                1, reportErrors2)) || emptyGenericType;
            }
            function getGlobalGeneratorType(reportErrors2) {
                return deferredGlobalGeneratorType || (deferredGlobalGeneratorType = getGlobalType("Generator", 
                /*arity*/
                3, reportErrors2)) || emptyGenericType;
            }
            function getGlobalIteratorYieldResultType(reportErrors2) {
                return deferredGlobalIteratorYieldResultType || (deferredGlobalIteratorYieldResultType = getGlobalType("IteratorYieldResult", 
                /*arity*/
                1, reportErrors2)) || emptyGenericType;
            }
            function getGlobalIteratorReturnResultType(reportErrors2) {
                return deferredGlobalIteratorReturnResultType || (deferredGlobalIteratorReturnResultType = getGlobalType("IteratorReturnResult", 
                /*arity*/
                1, reportErrors2)) || emptyGenericType;
            }
            function getGlobalDisposableType(reportErrors2) {
                return deferredGlobalDisposableType || (deferredGlobalDisposableType = getGlobalType("Disposable", 
                /*arity*/
                0, reportErrors2)) || emptyObjectType;
            }
            function getGlobalAsyncDisposableType(reportErrors2) {
                return deferredGlobalAsyncDisposableType || (deferredGlobalAsyncDisposableType = getGlobalType("AsyncDisposable", 
                /*arity*/
                0, reportErrors2)) || emptyObjectType;
            }
            function getGlobalTypeOrUndefined(name, arity = 0) {
                const symbol = getGlobalSymbol(name, 788968 /* Type */, 
                /*diagnostic*/
                void 0);
                return symbol && getTypeOfGlobalSymbol(symbol, arity);
            }
            function getGlobalExtractSymbol() {
                deferredGlobalExtractSymbol || (deferredGlobalExtractSymbol = getGlobalTypeAliasSymbol("Extract", 
                /*arity*/
                2, 
                /*reportErrors*/
                true) || unknownSymbol);
                return deferredGlobalExtractSymbol === unknownSymbol ? void 0 : deferredGlobalExtractSymbol;
            }
            function getGlobalOmitSymbol() {
                deferredGlobalOmitSymbol || (deferredGlobalOmitSymbol = getGlobalTypeAliasSymbol("Omit", 
                /*arity*/
                2, 
                /*reportErrors*/
                true) || unknownSymbol);
                return deferredGlobalOmitSymbol === unknownSymbol ? void 0 : deferredGlobalOmitSymbol;
            }
            function getGlobalAwaitedSymbol(reportErrors2) {
                deferredGlobalAwaitedSymbol || (deferredGlobalAwaitedSymbol = getGlobalTypeAliasSymbol("Awaited", 
                /*arity*/
                1, reportErrors2) || (reportErrors2 ? unknownSymbol : void 0));
                return deferredGlobalAwaitedSymbol === unknownSymbol ? void 0 : deferredGlobalAwaitedSymbol;
            }
            function getGlobalBigIntType() {
                return deferredGlobalBigIntType || (deferredGlobalBigIntType = getGlobalType("BigInt", 
                /*arity*/
                0, 
                /*reportErrors*/
                false)) || emptyObjectType;
            }
            function getGlobalClassDecoratorContextType(reportErrors2) {
                return deferredGlobalClassDecoratorContextType ?? (deferredGlobalClassDecoratorContextType = getGlobalType("ClassDecoratorContext", 
                /*arity*/
                1, reportErrors2)) ?? emptyGenericType;
            }
            function getGlobalClassMethodDecoratorContextType(reportErrors2) {
                return deferredGlobalClassMethodDecoratorContextType ?? (deferredGlobalClassMethodDecoratorContextType = getGlobalType("ClassMethodDecoratorContext", 
                /*arity*/
                2, reportErrors2)) ?? emptyGenericType;
            }
            function getGlobalClassGetterDecoratorContextType(reportErrors2) {
                return deferredGlobalClassGetterDecoratorContextType ?? (deferredGlobalClassGetterDecoratorContextType = getGlobalType("ClassGetterDecoratorContext", 
                /*arity*/
                2, reportErrors2)) ?? emptyGenericType;
            }
            function getGlobalClassSetterDecoratorContextType(reportErrors2) {
                return deferredGlobalClassSetterDecoratorContextType ?? (deferredGlobalClassSetterDecoratorContextType = getGlobalType("ClassSetterDecoratorContext", 
                /*arity*/
                2, reportErrors2)) ?? emptyGenericType;
            }
            function getGlobalClassAccessorDecoratorContextType(reportErrors2) {
                return deferredGlobalClassAccessorDecoratorContextType ?? (deferredGlobalClassAccessorDecoratorContextType = getGlobalType("ClassAccessorDecoratorContext", 
                /*arity*/
                2, reportErrors2)) ?? emptyGenericType;
            }
            function getGlobalClassAccessorDecoratorTargetType(reportErrors2) {
                return deferredGlobalClassAccessorDecoratorTargetType ?? (deferredGlobalClassAccessorDecoratorTargetType = getGlobalType("ClassAccessorDecoratorTarget", 
                /*arity*/
                2, reportErrors2)) ?? emptyGenericType;
            }
            function getGlobalClassAccessorDecoratorResultType(reportErrors2) {
                return deferredGlobalClassAccessorDecoratorResultType ?? (deferredGlobalClassAccessorDecoratorResultType = getGlobalType("ClassAccessorDecoratorResult", 
                /*arity*/
                2, reportErrors2)) ?? emptyGenericType;
            }
            function getGlobalClassFieldDecoratorContextType(reportErrors2) {
                return deferredGlobalClassFieldDecoratorContextType ?? (deferredGlobalClassFieldDecoratorContextType = getGlobalType("ClassFieldDecoratorContext", 
                /*arity*/
                2, reportErrors2)) ?? emptyGenericType;
            }
            function getGlobalNaNSymbol() {
                return deferredGlobalNaNSymbol || (deferredGlobalNaNSymbol = getGlobalValueSymbol("NaN", 
                /*reportErrors*/
                false));
            }
            function getGlobalRecordSymbol() {
                deferredGlobalRecordSymbol || (deferredGlobalRecordSymbol = getGlobalTypeAliasSymbol("Record", 
                /*arity*/
                2, 
                /*reportErrors*/
                true) || unknownSymbol);
                return deferredGlobalRecordSymbol === unknownSymbol ? void 0 : deferredGlobalRecordSymbol;
            }
            function createTypeFromGenericGlobalType(genericGlobalType, typeArguments) {
                return genericGlobalType !== emptyGenericType ? createTypeReference(genericGlobalType, typeArguments) : emptyObjectType;
            }
            function createTypedPropertyDescriptorType(propertyType) {
                return createTypeFromGenericGlobalType(getGlobalTypedPropertyDescriptorType(), [propertyType]);
            }
            function createIterableType(iteratedType) {
                return createTypeFromGenericGlobalType(getGlobalIterableType(
                /*reportErrors*/
                true), [iteratedType]);
            }
            function createArrayType(elementType, readonly) {
                return createTypeFromGenericGlobalType(readonly ? globalReadonlyArrayType : globalArrayType, [elementType]);
            }
            function getTupleElementFlags(node) {
                switch (node.kind) {
                    case 190 /* OptionalType */:
                        return 2 /* Optional */;
                    case 191 /* RestType */:
                        return getRestTypeElementFlags(node);
                    case 202 /* NamedTupleMember */:
                        return node.questionToken ? 2 /* Optional */ : node.dotDotDotToken ? getRestTypeElementFlags(node) : 1 /* Required */;
                    default:
                        return 1 /* Required */;
                }
            }
            function getRestTypeElementFlags(node) {
                return getArrayElementTypeNode(node.type) ? 4 /* Rest */ : 8 /* Variadic */;
            }
            function getArrayOrTupleTargetType(node) {
                const readonly = isReadonlyTypeOperator(node.parent);
                const elementType = getArrayElementTypeNode(node);
                if (elementType) {
                    return readonly ? globalReadonlyArrayType : globalArrayType;
                }
                const elementFlags = map(node.elements, getTupleElementFlags);
                return getTupleTargetType(elementFlags, readonly, map(node.elements, memberIfLabeledElementDeclaration));
            }
            function memberIfLabeledElementDeclaration(member) {
                return isNamedTupleMember(member) || isParameter(member) ? member : void 0;
            }
            function isDeferredTypeReferenceNode(node, hasDefaultTypeArguments) {
                return !!getAliasSymbolForTypeNode(node) || isResolvedByTypeAlias(node) && (node.kind === 188 /* ArrayType */ ? mayResolveTypeAlias(node.elementType) : node.kind === 189 /* TupleType */ ? some(node.elements, mayResolveTypeAlias) : hasDefaultTypeArguments || some(node.typeArguments, mayResolveTypeAlias));
            }
            function isResolvedByTypeAlias(node) {
                const parent2 = node.parent;
                switch (parent2.kind) {
                    case 196 /* ParenthesizedType */:
                    case 202 /* NamedTupleMember */:
                    case 183 /* TypeReference */:
                    case 192 /* UnionType */:
                    case 193 /* IntersectionType */:
                    case 199 /* IndexedAccessType */:
                    case 194 /* ConditionalType */:
                    case 198 /* TypeOperator */:
                    case 188 /* ArrayType */:
                    case 189 /* TupleType */:
                        return isResolvedByTypeAlias(parent2);
                    case 265 /* TypeAliasDeclaration */:
                        return true;
                }
                return false;
            }
            function mayResolveTypeAlias(node) {
                switch (node.kind) {
                    case 183 /* TypeReference */:
                        return isJSDocTypeReference(node) || !!(resolveTypeReferenceName(node, 788968 /* Type */).flags & 524288 /* TypeAlias */);
                    case 186 /* TypeQuery */:
                        return true;
                    case 198 /* TypeOperator */:
                        return node.operator !== 158 /* UniqueKeyword */ && mayResolveTypeAlias(node.type);
                    case 196 /* ParenthesizedType */:
                    case 190 /* OptionalType */:
                    case 202 /* NamedTupleMember */:
                    case 323 /* JSDocOptionalType */:
                    case 321 /* JSDocNullableType */:
                    case 322 /* JSDocNonNullableType */:
                    case 316 /* JSDocTypeExpression */:
                        return mayResolveTypeAlias(node.type);
                    case 191 /* RestType */:
                        return node.type.kind !== 188 /* ArrayType */ || mayResolveTypeAlias(node.type.elementType);
                    case 192 /* UnionType */:
                    case 193 /* IntersectionType */:
                        return some(node.types, mayResolveTypeAlias);
                    case 199 /* IndexedAccessType */:
                        return mayResolveTypeAlias(node.objectType) || mayResolveTypeAlias(node.indexType);
                    case 194 /* ConditionalType */:
                        return mayResolveTypeAlias(node.checkType) || mayResolveTypeAlias(node.extendsType) || mayResolveTypeAlias(node.trueType) || mayResolveTypeAlias(node.falseType);
                }
                return false;
            }
            function getTypeFromArrayOrTupleTypeNode(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    const target = getArrayOrTupleTargetType(node);
                    if (target === emptyGenericType) {
                        links.resolvedType = emptyObjectType;
                    }
                    else if (!(node.kind === 189 /* TupleType */ && some(node.elements, (e) => !!(getTupleElementFlags(e) & 8 /* Variadic */))) && isDeferredTypeReferenceNode(node)) {
                        links.resolvedType = node.kind === 189 /* TupleType */ && node.elements.length === 0 ? target : createDeferredTypeReference(target, node, 
                        /*mapper*/
                        void 0);
                    }
                    else {
                        const elementTypes = node.kind === 188 /* ArrayType */ ? [getTypeFromTypeNode(node.elementType)] : map(node.elements, getTypeFromTypeNode);
                        links.resolvedType = createNormalizedTypeReference(target, elementTypes);
                    }
                }
                return links.resolvedType;
            }
            function isReadonlyTypeOperator(node) {
                return isTypeOperatorNode(node) && node.operator === 148 /* ReadonlyKeyword */;
            }
            function createTupleType(elementTypes, elementFlags, readonly = false, namedMemberDeclarations = []) {
                const tupleTarget = getTupleTargetType(elementFlags || map(elementTypes, (_) => 1 /* Required */), readonly, namedMemberDeclarations);
                return tupleTarget === emptyGenericType ? emptyObjectType : elementTypes.length ? createNormalizedTypeReference(tupleTarget, elementTypes) : tupleTarget;
            }
            function getTupleTargetType(elementFlags, readonly, namedMemberDeclarations) {
                if (elementFlags.length === 1 && elementFlags[0] & 4 /* Rest */) {
                    return readonly ? globalReadonlyArrayType : globalArrayType;
                }
                const key = map(elementFlags, (f) => f & 1 /* Required */ ? "#" : f & 2 /* Optional */ ? "?" : f & 4 /* Rest */ ? "." : "*").join() + (readonly ? "R" : "") + (some(namedMemberDeclarations, (node) => !!node) ? "," + map(namedMemberDeclarations, (node) => node ? getNodeId(node) : "_").join(",") : "");
                let type = tupleTypes.get(key);
                if (!type) {
                    tupleTypes.set(key, type = createTupleTargetType(elementFlags, readonly, namedMemberDeclarations));
                }
                return type;
            }
            function createTupleTargetType(elementFlags, readonly, namedMemberDeclarations) {
                const arity = elementFlags.length;
                const minLength = countWhere(elementFlags, (f) => !!(f & (1 /* Required */ | 8 /* Variadic */)));
                let typeParameters;
                const properties = [];
                let combinedFlags = 0;
                if (arity) {
                    typeParameters = new Array(arity);
                    for (let i = 0; i < arity; i++) {
                        const typeParameter = typeParameters[i] = createTypeParameter();
                        const flags = elementFlags[i];
                        combinedFlags |= flags;
                        if (!(combinedFlags & 12 /* Variable */)) {
                            const property = createSymbol(4 /* Property */ | (flags & 2 /* Optional */ ? 16777216 /* Optional */ : 0), "" + i, readonly ? 8 /* Readonly */ : 0);
                            property.links.tupleLabelDeclaration = namedMemberDeclarations == null ? void 0 : namedMemberDeclarations[i];
                            property.links.type = typeParameter;
                            properties.push(property);
                        }
                    }
                }
                const fixedLength = properties.length;
                const lengthSymbol = createSymbol(4 /* Property */, "length", readonly ? 8 /* Readonly */ : 0);
                if (combinedFlags & 12 /* Variable */) {
                    lengthSymbol.links.type = numberType;
                }
                else {
                    const literalTypes = [];
                    for (let i = minLength; i <= arity; i++)
                        literalTypes.push(getNumberLiteralType(i));
                    lengthSymbol.links.type = getUnionType(literalTypes);
                }
                properties.push(lengthSymbol);
                const type = createObjectType(8 /* Tuple */ | 4 /* Reference */);
                type.typeParameters = typeParameters;
                type.outerTypeParameters = void 0;
                type.localTypeParameters = typeParameters;
                type.instantiations = /* @__PURE__ */ new Map();
                type.instantiations.set(getTypeListId(type.typeParameters), type);
                type.target = type;
                type.resolvedTypeArguments = type.typeParameters;
                type.thisType = createTypeParameter();
                type.thisType.isThisType = true;
                type.thisType.constraint = type;
                type.declaredProperties = properties;
                type.declaredCallSignatures = emptyArray;
                type.declaredConstructSignatures = emptyArray;
                type.declaredIndexInfos = emptyArray;
                type.elementFlags = elementFlags;
                type.minLength = minLength;
                type.fixedLength = fixedLength;
                type.hasRestElement = !!(combinedFlags & 12 /* Variable */);
                type.combinedFlags = combinedFlags;
                type.readonly = readonly;
                type.labeledElementDeclarations = namedMemberDeclarations;
                return type;
            }
            function createNormalizedTypeReference(target, typeArguments) {
                return target.objectFlags & 8 /* Tuple */ ? createNormalizedTupleType(target, typeArguments) : createTypeReference(target, typeArguments);
            }
            function createNormalizedTupleType(target, elementTypes) {
                var _a, _b, _c, _d;
                if (!(target.combinedFlags & 14 /* NonRequired */)) {
                    return createTypeReference(target, elementTypes);
                }
                if (target.combinedFlags & 8 /* Variadic */) {
                    const unionIndex = findIndex(elementTypes, (t, i) => !!(target.elementFlags[i] & 8 /* Variadic */ && t.flags & (131072 /* Never */ | 1048576 /* Union */)));
                    if (unionIndex >= 0) {
                        return checkCrossProductUnion(map(elementTypes, (t, i) => target.elementFlags[i] & 8 /* Variadic */ ? t : unknownType)) ? mapType(elementTypes[unionIndex], (t) => createNormalizedTupleType(target, replaceElement(elementTypes, unionIndex, t))) : errorType;
                    }
                }
                const expandedTypes = [];
                const expandedFlags = [];
                const expandedDeclarations = [];
                let lastRequiredIndex = -1;
                let firstRestIndex = -1;
                let lastOptionalOrRestIndex = -1;
                for (let i = 0; i < elementTypes.length; i++) {
                    const type = elementTypes[i];
                    const flags = target.elementFlags[i];
                    if (flags & 8 /* Variadic */) {
                        if (type.flags & 1 /* Any */) {
                            addElement(type, 4 /* Rest */, (_a = target.labeledElementDeclarations) == null ? void 0 : _a[i]);
                        }
                        else if (type.flags & 58982400 /* InstantiableNonPrimitive */ || isGenericMappedType(type)) {
                            addElement(type, 8 /* Variadic */, (_b = target.labeledElementDeclarations) == null ? void 0 : _b[i]);
                        }
                        else if (isTupleType(type)) {
                            const elements = getElementTypes(type);
                            if (elements.length + expandedTypes.length >= 1e4) {
                                error2(currentNode, isPartOfTypeNode(currentNode) ? Diagnostics.Type_produces_a_tuple_type_that_is_too_large_to_represent : Diagnostics.Expression_produces_a_tuple_type_that_is_too_large_to_represent);
                                return errorType;
                            }
                            forEach(elements, (t, n) => {
                                var _a2;
                                return addElement(t, type.target.elementFlags[n], (_a2 = type.target.labeledElementDeclarations) == null ? void 0 : _a2[n]);
                            });
                        }
                        else {
                            addElement(isArrayLikeType(type) && getIndexTypeOfType(type, numberType) || errorType, 4 /* Rest */, (_c = target.labeledElementDeclarations) == null ? void 0 : _c[i]);
                        }
                    }
                    else {
                        addElement(type, flags, (_d = target.labeledElementDeclarations) == null ? void 0 : _d[i]);
                    }
                }
                for (let i = 0; i < lastRequiredIndex; i++) {
                    if (expandedFlags[i] & 2 /* Optional */)
                        expandedFlags[i] = 1 /* Required */;
                }
                if (firstRestIndex >= 0 && firstRestIndex < lastOptionalOrRestIndex) {
                    expandedTypes[firstRestIndex] = getUnionType(sameMap(expandedTypes.slice(firstRestIndex, lastOptionalOrRestIndex + 1), (t, i) => expandedFlags[firstRestIndex + i] & 8 /* Variadic */ ? getIndexedAccessType(t, numberType) : t));
                    expandedTypes.splice(firstRestIndex + 1, lastOptionalOrRestIndex - firstRestIndex);
                    expandedFlags.splice(firstRestIndex + 1, lastOptionalOrRestIndex - firstRestIndex);
                    expandedDeclarations.splice(firstRestIndex + 1, lastOptionalOrRestIndex - firstRestIndex);
                }
                const tupleTarget = getTupleTargetType(expandedFlags, target.readonly, expandedDeclarations);
                return tupleTarget === emptyGenericType ? emptyObjectType : expandedFlags.length ? createTypeReference(tupleTarget, expandedTypes) : tupleTarget;
                function addElement(type, flags, declaration) {
                    if (flags & 1 /* Required */) {
                        lastRequiredIndex = expandedFlags.length;
                    }
                    if (flags & 4 /* Rest */ && firstRestIndex < 0) {
                        firstRestIndex = expandedFlags.length;
                    }
                    if (flags & (2 /* Optional */ | 4 /* Rest */)) {
                        lastOptionalOrRestIndex = expandedFlags.length;
                    }
                    expandedTypes.push(flags & 2 /* Optional */ ? addOptionality(type, 
                    /*isProperty*/
                    true) : type);
                    expandedFlags.push(flags);
                    expandedDeclarations.push(declaration);
                }
            }
            function sliceTupleType(type, index, endSkipCount = 0) {
                const target = type.target;
                const endIndex = getTypeReferenceArity(type) - endSkipCount;
                return index > target.fixedLength ? getRestArrayTypeOfTupleType(type) || createTupleType(emptyArray) : createTupleType(getTypeArguments(type).slice(index, endIndex), target.elementFlags.slice(index, endIndex), 
                /*readonly*/
                false, target.labeledElementDeclarations && target.labeledElementDeclarations.slice(index, endIndex));
            }
            function getKnownKeysOfTupleType(type) {
                return getUnionType(append(arrayOf(type.target.fixedLength, (i) => getStringLiteralType("" + i)), getIndexType(type.target.readonly ? globalReadonlyArrayType : globalArrayType)));
            }
            function getStartElementCount(type, flags) {
                const index = findIndex(type.elementFlags, (f) => !(f & flags));
                return index >= 0 ? index : type.elementFlags.length;
            }
            function getEndElementCount(type, flags) {
                return type.elementFlags.length - findLastIndex(type.elementFlags, (f) => !(f & flags)) - 1;
            }
            function getTotalFixedElementCount(type) {
                return type.fixedLength + getEndElementCount(type, 3 /* Fixed */);
            }
            function getElementTypes(type) {
                const typeArguments = getTypeArguments(type);
                const arity = getTypeReferenceArity(type);
                return typeArguments.length === arity ? typeArguments : typeArguments.slice(0, arity);
            }
            function getTypeFromOptionalTypeNode(node) {
                return addOptionality(getTypeFromTypeNode(node.type), 
                /*isProperty*/
                true);
            }
            function getTypeId(type) {
                return type.id;
            }
            function containsType(types, type) {
                return binarySearch(types, type, getTypeId, compareValues) >= 0;
            }
            function insertType(types, type) {
                const index = binarySearch(types, type, getTypeId, compareValues);
                if (index < 0) {
                    types.splice(~index, 0, type);
                    return true;
                }
                return false;
            }
            function addTypeToUnion(typeSet, includes, type) {
                const flags = type.flags;
                if (!(flags & 131072 /* Never */)) {
                    includes |= flags & 473694207 /* IncludesMask */;
                    if (flags & 465829888 /* Instantiable */)
                        includes |= 33554432 /* IncludesInstantiable */;
                    if (flags & 2097152 /* Intersection */ && getObjectFlags(type) & 67108864 /* IsConstrainedTypeVariable */)
                        includes |= 536870912 /* IncludesConstrainedTypeVariable */;
                    if (type === wildcardType)
                        includes |= 8388608 /* IncludesWildcard */;
                    if (!strictNullChecks && flags & 98304 /* Nullable */) {
                        if (!(getObjectFlags(type) & 65536 /* ContainsWideningType */))
                            includes |= 4194304 /* IncludesNonWideningType */;
                    }
                    else {
                        const len = typeSet.length;
                        const index = len && type.id > typeSet[len - 1].id ? ~len : binarySearch(typeSet, type, getTypeId, compareValues);
                        if (index < 0) {
                            typeSet.splice(~index, 0, type);
                        }
                    }
                }
                return includes;
            }
            function addTypesToUnion(typeSet, includes, types) {
                let lastType;
                for (const type of types) {
                    if (type !== lastType) {
                        includes = type.flags & 1048576 /* Union */ ? addTypesToUnion(typeSet, includes | (isNamedUnionType(type) ? 1048576 /* Union */ : 0), type.types) : addTypeToUnion(typeSet, includes, type);
                        lastType = type;
                    }
                }
                return includes;
            }
            function removeSubtypes(types, hasObjectTypes) {
                var _a;
                if (types.length < 2) {
                    return types;
                }
                const id = getTypeListId(types);
                const match = subtypeReductionCache.get(id);
                if (match) {
                    return match;
                }
                const hasEmptyObject = hasObjectTypes && some(types, (t) => !!(t.flags & 524288 /* Object */) && !isGenericMappedType(t) && isEmptyResolvedType(resolveStructuredTypeMembers(t)));
                const len = types.length;
                let i = len;
                let count = 0;
                while (i > 0) {
                    i--;
                    const source = types[i];
                    if (hasEmptyObject || source.flags & 469499904 /* StructuredOrInstantiable */) {
                        if (source.flags & 262144 /* TypeParameter */ && getBaseConstraintOrType(source).flags & 1048576 /* Union */) {
                            if (isTypeRelatedTo(source, getUnionType(map(types, (t) => t === source ? neverType : t)), strictSubtypeRelation)) {
                                orderedRemoveItemAt(types, i);
                            }
                            continue;
                        }
                        const keyProperty = source.flags & (524288 /* Object */ | 2097152 /* Intersection */ | 58982400 /* InstantiableNonPrimitive */) ? find(getPropertiesOfType(source), (p) => isUnitType(getTypeOfSymbol(p))) : void 0;
                        const keyPropertyType = keyProperty && getRegularTypeOfLiteralType(getTypeOfSymbol(keyProperty));
                        for (const target of types) {
                            if (source !== target) {
                                if (count === 1e5) {
                                    const estimatedCount = count / (len - i) * len;
                                    if (estimatedCount > 1e6) {
                                        (_a = tracing) == null ? void 0 : _a.instant(tracing.Phase.CheckTypes, "removeSubtypes_DepthLimit", { typeIds: types.map((t) => t.id) });
                                        error2(currentNode, Diagnostics.Expression_produces_a_union_type_that_is_too_complex_to_represent);
                                        return void 0;
                                    }
                                }
                                count++;
                                if (keyProperty && target.flags & (524288 /* Object */ | 2097152 /* Intersection */ | 58982400 /* InstantiableNonPrimitive */)) {
                                    const t = getTypeOfPropertyOfType(target, keyProperty.escapedName);
                                    if (t && isUnitType(t) && getRegularTypeOfLiteralType(t) !== keyPropertyType) {
                                        continue;
                                    }
                                }
                                if (isTypeRelatedTo(source, target, strictSubtypeRelation) && (!(getObjectFlags(getTargetType(source)) & 1 /* Class */) || !(getObjectFlags(getTargetType(target)) & 1 /* Class */) || isTypeDerivedFrom(source, target))) {
                                    orderedRemoveItemAt(types, i);
                                    break;
                                }
                            }
                        }
                    }
                }
                subtypeReductionCache.set(id, types);
                return types;
            }
            function removeRedundantLiteralTypes(types, includes, reduceVoidUndefined) {
                let i = types.length;
                while (i > 0) {
                    i--;
                    const t = types[i];
                    const flags = t.flags;
                    const remove = flags & (128 /* StringLiteral */ | 134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */) && includes & 4 /* String */ || flags & 256 /* NumberLiteral */ && includes & 8 /* Number */ || flags & 2048 /* BigIntLiteral */ && includes & 64 /* BigInt */ || flags & 8192 /* UniqueESSymbol */ && includes & 4096 /* ESSymbol */ || reduceVoidUndefined && flags & 32768 /* Undefined */ && includes & 16384 /* Void */ || isFreshLiteralType(t) && containsType(types, t.regularType);
                    if (remove) {
                        orderedRemoveItemAt(types, i);
                    }
                }
            }
            function removeStringLiteralsMatchedByTemplateLiterals(types) {
                const templates = filter(types, isPatternLiteralType);
                if (templates.length) {
                    let i = types.length;
                    while (i > 0) {
                        i--;
                        const t = types[i];
                        if (t.flags & 128 /* StringLiteral */ && some(templates, (template) => isTypeMatchedByTemplateLiteralOrStringMapping(t, template))) {
                            orderedRemoveItemAt(types, i);
                        }
                    }
                }
            }
            function isTypeMatchedByTemplateLiteralOrStringMapping(type, template) {
                return template.flags & 134217728 /* TemplateLiteral */ ? isTypeMatchedByTemplateLiteralType(type, template) : isMemberOfStringMapping(type, template);
            }
            function removeConstrainedTypeVariables(types) {
                const typeVariables = [];
                for (const type of types) {
                    if (type.flags & 2097152 /* Intersection */ && getObjectFlags(type) & 67108864 /* IsConstrainedTypeVariable */) {
                        const index = type.types[0].flags & 8650752 /* TypeVariable */ ? 0 : 1;
                        pushIfUnique(typeVariables, type.types[index]);
                    }
                }
                for (const typeVariable of typeVariables) {
                    const primitives = [];
                    for (const type of types) {
                        if (type.flags & 2097152 /* Intersection */ && getObjectFlags(type) & 67108864 /* IsConstrainedTypeVariable */) {
                            const index = type.types[0].flags & 8650752 /* TypeVariable */ ? 0 : 1;
                            if (type.types[index] === typeVariable) {
                                insertType(primitives, type.types[1 - index]);
                            }
                        }
                    }
                    const constraint = getBaseConstraintOfType(typeVariable);
                    if (everyType(constraint, (t) => containsType(primitives, t))) {
                        let i = types.length;
                        while (i > 0) {
                            i--;
                            const type = types[i];
                            if (type.flags & 2097152 /* Intersection */ && getObjectFlags(type) & 67108864 /* IsConstrainedTypeVariable */) {
                                const index = type.types[0].flags & 8650752 /* TypeVariable */ ? 0 : 1;
                                if (type.types[index] === typeVariable && containsType(primitives, type.types[1 - index])) {
                                    orderedRemoveItemAt(types, i);
                                }
                            }
                        }
                        insertType(types, typeVariable);
                    }
                }
            }
            function isNamedUnionType(type) {
                return !!(type.flags & 1048576 /* Union */ && (type.aliasSymbol || type.origin));
            }
            function addNamedUnions(namedUnions, types) {
                for (const t of types) {
                    if (t.flags & 1048576 /* Union */) {
                        const origin = t.origin;
                        if (t.aliasSymbol || origin && !(origin.flags & 1048576 /* Union */)) {
                            pushIfUnique(namedUnions, t);
                        }
                        else if (origin && origin.flags & 1048576 /* Union */) {
                            addNamedUnions(namedUnions, origin.types);
                        }
                    }
                }
            }
            function createOriginUnionOrIntersectionType(flags, types) {
                const result = createOriginType(flags);
                result.types = types;
                return result;
            }
            function getUnionType(types, unionReduction = 1 /* Literal */, aliasSymbol, aliasTypeArguments, origin) {
                if (types.length === 0) {
                    return neverType;
                }
                if (types.length === 1) {
                    return types[0];
                }
                if (types.length === 2 && !origin && (types[0].flags & 1048576 /* Union */ || types[1].flags & 1048576 /* Union */)) {
                    const infix = unionReduction === 0 /* None */ ? "N" : unionReduction === 2 /* Subtype */ ? "S" : "L";
                    const index = types[0].id < types[1].id ? 0 : 1;
                    const id = types[index].id + infix + types[1 - index].id + getAliasId(aliasSymbol, aliasTypeArguments);
                    let type = unionOfUnionTypes.get(id);
                    if (!type) {
                        type = getUnionTypeWorker(types, unionReduction, aliasSymbol, aliasTypeArguments, 
                        /*origin*/
                        void 0);
                        unionOfUnionTypes.set(id, type);
                    }
                    return type;
                }
                return getUnionTypeWorker(types, unionReduction, aliasSymbol, aliasTypeArguments, origin);
            }
            function getUnionTypeWorker(types, unionReduction, aliasSymbol, aliasTypeArguments, origin) {
                let typeSet = [];
                const includes = addTypesToUnion(typeSet, 0, types);
                if (unionReduction !== 0 /* None */) {
                    if (includes & 3 /* AnyOrUnknown */) {
                        return includes & 1 /* Any */ ? includes & 8388608 /* IncludesWildcard */ ? wildcardType : anyType : includes & 65536 /* Null */ || containsType(typeSet, unknownType) ? unknownType : nonNullUnknownType;
                    }
                    if (includes & 32768 /* Undefined */) {
                        if (typeSet.length >= 2 && typeSet[0] === undefinedType && typeSet[1] === missingType) {
                            orderedRemoveItemAt(typeSet, 1);
                        }
                    }
                    if (includes & (32 /* Enum */ | 2944 /* Literal */ | 8192 /* UniqueESSymbol */ | 134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */) || includes & 16384 /* Void */ && includes & 32768 /* Undefined */) {
                        removeRedundantLiteralTypes(typeSet, includes, !!(unionReduction & 2 /* Subtype */));
                    }
                    if (includes & 128 /* StringLiteral */ && includes & (134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */)) {
                        removeStringLiteralsMatchedByTemplateLiterals(typeSet);
                    }
                    if (includes & 536870912 /* IncludesConstrainedTypeVariable */) {
                        removeConstrainedTypeVariables(typeSet);
                    }
                    if (unionReduction === 2 /* Subtype */) {
                        typeSet = removeSubtypes(typeSet, !!(includes & 524288 /* Object */));
                        if (!typeSet) {
                            return errorType;
                        }
                    }
                    if (typeSet.length === 0) {
                        return includes & 65536 /* Null */ ? includes & 4194304 /* IncludesNonWideningType */ ? nullType : nullWideningType : includes & 32768 /* Undefined */ ? includes & 4194304 /* IncludesNonWideningType */ ? undefinedType : undefinedWideningType : neverType;
                    }
                }
                if (!origin && includes & 1048576 /* Union */) {
                    const namedUnions = [];
                    addNamedUnions(namedUnions, types);
                    const reducedTypes = [];
                    for (const t of typeSet) {
                        if (!some(namedUnions, (union) => containsType(union.types, t))) {
                            reducedTypes.push(t);
                        }
                    }
                    if (!aliasSymbol && namedUnions.length === 1 && reducedTypes.length === 0) {
                        return namedUnions[0];
                    }
                    const namedTypesCount = reduceLeft(namedUnions, (sum, union) => sum + union.types.length, 0);
                    if (namedTypesCount + reducedTypes.length === typeSet.length) {
                        for (const t of namedUnions) {
                            insertType(reducedTypes, t);
                        }
                        origin = createOriginUnionOrIntersectionType(1048576 /* Union */, reducedTypes);
                    }
                }
                const objectFlags = (includes & 36323331 /* NotPrimitiveUnion */ ? 0 : 32768 /* PrimitiveUnion */) | (includes & 2097152 /* Intersection */ ? 16777216 /* ContainsIntersections */ : 0);
                return getUnionTypeFromSortedList(typeSet, objectFlags, aliasSymbol, aliasTypeArguments, origin);
            }
            function getUnionOrIntersectionTypePredicate(signatures, kind) {
                let last2;
                const types = [];
                for (const sig of signatures) {
                    const pred = getTypePredicateOfSignature(sig);
                    if (pred) {
                        if (pred.kind !== 0 /* This */ && pred.kind !== 1 /* Identifier */ || last2 && !typePredicateKindsMatch(last2, pred)) {
                            return void 0;
                        }
                        last2 = pred;
                        types.push(pred.type);
                    }
                    else {
                        const returnType = kind !== 2097152 /* Intersection */ ? getReturnTypeOfSignature(sig) : void 0;
                        if (returnType !== falseType && returnType !== regularFalseType) {
                            return void 0;
                        }
                    }
                }
                if (!last2) {
                    return void 0;
                }
                const compositeType = getUnionOrIntersectionType(types, kind);
                return createTypePredicate(last2.kind, last2.parameterName, last2.parameterIndex, compositeType);
            }
            function typePredicateKindsMatch(a, b) {
                return a.kind === b.kind && a.parameterIndex === b.parameterIndex;
            }
            function getUnionTypeFromSortedList(types, precomputedObjectFlags, aliasSymbol, aliasTypeArguments, origin) {
                if (types.length === 0) {
                    return neverType;
                }
                if (types.length === 1) {
                    return types[0];
                }
                const typeKey = !origin ? getTypeListId(types) : origin.flags & 1048576 /* Union */ ? `|${getTypeListId(origin.types)}` : origin.flags & 2097152 /* Intersection */ ? `&${getTypeListId(origin.types)}` : `#${origin.type.id}|${getTypeListId(types)}`;
                const id = typeKey + getAliasId(aliasSymbol, aliasTypeArguments);
                let type = unionTypes.get(id);
                if (!type) {
                    type = createType(1048576 /* Union */);
                    type.objectFlags = precomputedObjectFlags | getPropagatingFlagsOfTypes(types, 
                    /*excludeKinds*/
                    98304 /* Nullable */);
                    type.types = types;
                    type.origin = origin;
                    type.aliasSymbol = aliasSymbol;
                    type.aliasTypeArguments = aliasTypeArguments;
                    if (types.length === 2 && types[0].flags & 512 /* BooleanLiteral */ && types[1].flags & 512 /* BooleanLiteral */) {
                        type.flags |= 16 /* Boolean */;
                        type.intrinsicName = "boolean";
                    }
                    unionTypes.set(id, type);
                }
                return type;
            }
            function getTypeFromUnionTypeNode(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    const aliasSymbol = getAliasSymbolForTypeNode(node);
                    links.resolvedType = getUnionType(map(node.types, getTypeFromTypeNode), 1 /* Literal */, aliasSymbol, getTypeArgumentsForAliasSymbol(aliasSymbol));
                }
                return links.resolvedType;
            }
            function addTypeToIntersection(typeSet, includes, type) {
                const flags = type.flags;
                if (flags & 2097152 /* Intersection */) {
                    return addTypesToIntersection(typeSet, includes, type.types);
                }
                if (isEmptyAnonymousObjectType(type)) {
                    if (!(includes & 16777216 /* IncludesEmptyObject */)) {
                        includes |= 16777216 /* IncludesEmptyObject */;
                        typeSet.set(type.id.toString(), type);
                    }
                }
                else {
                    if (flags & 3 /* AnyOrUnknown */) {
                        if (type === wildcardType)
                            includes |= 8388608 /* IncludesWildcard */;
                    }
                    else if (strictNullChecks || !(flags & 98304 /* Nullable */)) {
                        if (type === missingType) {
                            includes |= 262144 /* IncludesMissingType */;
                            type = undefinedType;
                        }
                        if (!typeSet.has(type.id.toString())) {
                            if (type.flags & 109472 /* Unit */ && includes & 109472 /* Unit */) {
                                includes |= 67108864 /* NonPrimitive */;
                            }
                            typeSet.set(type.id.toString(), type);
                        }
                    }
                    includes |= flags & 473694207 /* IncludesMask */;
                }
                return includes;
            }
            function addTypesToIntersection(typeSet, includes, types) {
                for (const type of types) {
                    includes = addTypeToIntersection(typeSet, includes, getRegularTypeOfLiteralType(type));
                }
                return includes;
            }
            function removeRedundantSupertypes(types, includes) {
                let i = types.length;
                while (i > 0) {
                    i--;
                    const t = types[i];
                    const remove = t.flags & 4 /* String */ && includes & (128 /* StringLiteral */ | 134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */) || t.flags & 8 /* Number */ && includes & 256 /* NumberLiteral */ || t.flags & 64 /* BigInt */ && includes & 2048 /* BigIntLiteral */ || t.flags & 4096 /* ESSymbol */ && includes & 8192 /* UniqueESSymbol */ || t.flags & 16384 /* Void */ && includes & 32768 /* Undefined */ || isEmptyAnonymousObjectType(t) && includes & 470302716 /* DefinitelyNonNullable */;
                    if (remove) {
                        orderedRemoveItemAt(types, i);
                    }
                }
            }
            function eachUnionContains(unionTypes2, type) {
                for (const u of unionTypes2) {
                    if (!containsType(u.types, type)) {
                        const primitive = type.flags & 128 /* StringLiteral */ ? stringType : type.flags & (32 /* Enum */ | 256 /* NumberLiteral */) ? numberType : type.flags & 2048 /* BigIntLiteral */ ? bigintType : type.flags & 8192 /* UniqueESSymbol */ ? esSymbolType : void 0;
                        if (!primitive || !containsType(u.types, primitive)) {
                            return false;
                        }
                    }
                }
                return true;
            }
            function extractRedundantTemplateLiterals(types) {
                let i = types.length;
                const literals = filter(types, (t) => !!(t.flags & 128 /* StringLiteral */));
                while (i > 0) {
                    i--;
                    const t = types[i];
                    if (!(t.flags & (134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */)))
                        continue;
                    for (const t2 of literals) {
                        if (isTypeSubtypeOf(t2, t)) {
                            orderedRemoveItemAt(types, i);
                            break;
                        }
                        else if (isPatternLiteralType(t)) {
                            return true;
                        }
                    }
                }
                return false;
            }
            function removeFromEach(types, flag) {
                for (let i = 0; i < types.length; i++) {
                    types[i] = filterType(types[i], (t) => !(t.flags & flag));
                }
            }
            function intersectUnionsOfPrimitiveTypes(types) {
                let unionTypes2;
                const index = findIndex(types, (t) => !!(getObjectFlags(t) & 32768 /* PrimitiveUnion */));
                if (index < 0) {
                    return false;
                }
                let i = index + 1;
                while (i < types.length) {
                    const t = types[i];
                    if (getObjectFlags(t) & 32768 /* PrimitiveUnion */) {
                        (unionTypes2 || (unionTypes2 = [types[index]])).push(t);
                        orderedRemoveItemAt(types, i);
                    }
                    else {
                        i++;
                    }
                }
                if (!unionTypes2) {
                    return false;
                }
                const checked = [];
                const result = [];
                for (const u of unionTypes2) {
                    for (const t of u.types) {
                        if (insertType(checked, t)) {
                            if (eachUnionContains(unionTypes2, t)) {
                                insertType(result, t);
                            }
                        }
                    }
                }
                types[index] = getUnionTypeFromSortedList(result, 32768 /* PrimitiveUnion */);
                return true;
            }
            function createIntersectionType(types, objectFlags, aliasSymbol, aliasTypeArguments) {
                const result = createType(2097152 /* Intersection */);
                result.objectFlags = objectFlags | getPropagatingFlagsOfTypes(types, 
                /*excludeKinds*/
                98304 /* Nullable */);
                result.types = types;
                result.aliasSymbol = aliasSymbol;
                result.aliasTypeArguments = aliasTypeArguments;
                return result;
            }
            function getIntersectionType(types, aliasSymbol, aliasTypeArguments, noSupertypeReduction) {
                const typeMembershipMap = /* @__PURE__ */ new Map();
                const includes = addTypesToIntersection(typeMembershipMap, 0, types);
                const typeSet = arrayFrom(typeMembershipMap.values());
                let objectFlags = 0 /* None */;
                if (includes & 131072 /* Never */) {
                    return contains(typeSet, silentNeverType) ? silentNeverType : neverType;
                }
                if (strictNullChecks && includes & 98304 /* Nullable */ && includes & (524288 /* Object */ | 67108864 /* NonPrimitive */ | 16777216 /* IncludesEmptyObject */) || includes & 67108864 /* NonPrimitive */ && includes & (469892092 /* DisjointDomains */ & ~67108864 /* NonPrimitive */) || includes & 402653316 /* StringLike */ && includes & (469892092 /* DisjointDomains */ & ~402653316 /* StringLike */) || includes & 296 /* NumberLike */ && includes & (469892092 /* DisjointDomains */ & ~296 /* NumberLike */) || includes & 2112 /* BigIntLike */ && includes & (469892092 /* DisjointDomains */ & ~2112 /* BigIntLike */) || includes & 12288 /* ESSymbolLike */ && includes & (469892092 /* DisjointDomains */ & ~12288 /* ESSymbolLike */) || includes & 49152 /* VoidLike */ && includes & (469892092 /* DisjointDomains */ & ~49152 /* VoidLike */)) {
                    return neverType;
                }
                if (includes & (134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */) && includes & 128 /* StringLiteral */ && extractRedundantTemplateLiterals(typeSet)) {
                    return neverType;
                }
                if (includes & 1 /* Any */) {
                    return includes & 8388608 /* IncludesWildcard */ ? wildcardType : anyType;
                }
                if (!strictNullChecks && includes & 98304 /* Nullable */) {
                    return includes & 16777216 /* IncludesEmptyObject */ ? neverType : includes & 32768 /* Undefined */ ? undefinedType : nullType;
                }
                if (includes & 4 /* String */ && includes & (128 /* StringLiteral */ | 134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */) || includes & 8 /* Number */ && includes & 256 /* NumberLiteral */ || includes & 64 /* BigInt */ && includes & 2048 /* BigIntLiteral */ || includes & 4096 /* ESSymbol */ && includes & 8192 /* UniqueESSymbol */ || includes & 16384 /* Void */ && includes & 32768 /* Undefined */ || includes & 16777216 /* IncludesEmptyObject */ && includes & 470302716 /* DefinitelyNonNullable */) {
                    if (!noSupertypeReduction)
                        removeRedundantSupertypes(typeSet, includes);
                }
                if (includes & 262144 /* IncludesMissingType */) {
                    typeSet[typeSet.indexOf(undefinedType)] = missingType;
                }
                if (typeSet.length === 0) {
                    return unknownType;
                }
                if (typeSet.length === 1) {
                    return typeSet[0];
                }
                if (typeSet.length === 2) {
                    const typeVarIndex = typeSet[0].flags & 8650752 /* TypeVariable */ ? 0 : 1;
                    const typeVariable = typeSet[typeVarIndex];
                    const primitiveType = typeSet[1 - typeVarIndex];
                    if (typeVariable.flags & 8650752 /* TypeVariable */ && (primitiveType.flags & (402784252 /* Primitive */ | 67108864 /* NonPrimitive */) && !isGenericStringLikeType(primitiveType) || includes & 16777216 /* IncludesEmptyObject */)) {
                        const constraint = getBaseConstraintOfType(typeVariable);
                        if (constraint && everyType(constraint, (t) => !!(t.flags & (402784252 /* Primitive */ | 67108864 /* NonPrimitive */)) || isEmptyAnonymousObjectType(t))) {
                            if (isTypeStrictSubtypeOf(constraint, primitiveType)) {
                                return typeVariable;
                            }
                            if (!(constraint.flags & 1048576 /* Union */ && someType(constraint, (c) => isTypeStrictSubtypeOf(c, primitiveType)))) {
                                if (!isTypeStrictSubtypeOf(primitiveType, constraint)) {
                                    return neverType;
                                }
                            }
                            objectFlags = 67108864 /* IsConstrainedTypeVariable */;
                        }
                    }
                }
                const id = getTypeListId(typeSet) + getAliasId(aliasSymbol, aliasTypeArguments);
                let result = intersectionTypes.get(id);
                if (!result) {
                    if (includes & 1048576 /* Union */) {
                        if (intersectUnionsOfPrimitiveTypes(typeSet)) {
                            result = getIntersectionType(typeSet, aliasSymbol, aliasTypeArguments);
                        }
                        else if (every(typeSet, (t) => !!(t.flags & 1048576 /* Union */ && t.types[0].flags & 32768 /* Undefined */))) {
                            const containedUndefinedType = some(typeSet, containsMissingType) ? missingType : undefinedType;
                            removeFromEach(typeSet, 32768 /* Undefined */);
                            result = getUnionType([getIntersectionType(typeSet), containedUndefinedType], 1 /* Literal */, aliasSymbol, aliasTypeArguments);
                        }
                        else if (every(typeSet, (t) => !!(t.flags & 1048576 /* Union */ && (t.types[0].flags & 65536 /* Null */ || t.types[1].flags & 65536 /* Null */)))) {
                            removeFromEach(typeSet, 65536 /* Null */);
                            result = getUnionType([getIntersectionType(typeSet), nullType], 1 /* Literal */, aliasSymbol, aliasTypeArguments);
                        }
                        else {
                            if (!checkCrossProductUnion(typeSet)) {
                                return errorType;
                            }
                            const constituents = getCrossProductIntersections(typeSet);
                            const origin = some(constituents, (t) => !!(t.flags & 2097152 /* Intersection */)) && getConstituentCountOfTypes(constituents) > getConstituentCountOfTypes(typeSet) ? createOriginUnionOrIntersectionType(2097152 /* Intersection */, typeSet) : void 0;
                            result = getUnionType(constituents, 1 /* Literal */, aliasSymbol, aliasTypeArguments, origin);
                        }
                    }
                    else {
                        result = createIntersectionType(typeSet, objectFlags, aliasSymbol, aliasTypeArguments);
                    }
                    intersectionTypes.set(id, result);
                }
                return result;
            }
            function getCrossProductUnionSize(types) {
                return reduceLeft(types, (n, t) => t.flags & 1048576 /* Union */ ? n * t.types.length : t.flags & 131072 /* Never */ ? 0 : n, 1);
            }
            function checkCrossProductUnion(types) {
                var _a;
                const size = getCrossProductUnionSize(types);
                if (size >= 1e5) {
                    (_a = tracing) == null ? void 0 : _a.instant(tracing.Phase.CheckTypes, "checkCrossProductUnion_DepthLimit", { typeIds: types.map((t) => t.id), size });
                    error2(currentNode, Diagnostics.Expression_produces_a_union_type_that_is_too_complex_to_represent);
                    return false;
                }
                return true;
            }
            function getCrossProductIntersections(types) {
                const count = getCrossProductUnionSize(types);
                const intersections = [];
                for (let i = 0; i < count; i++) {
                    const constituents = types.slice();
                    let n = i;
                    for (let j = types.length - 1; j >= 0; j--) {
                        if (types[j].flags & 1048576 /* Union */) {
                            const sourceTypes = types[j].types;
                            const length2 = sourceTypes.length;
                            constituents[j] = sourceTypes[n % length2];
                            n = Math.floor(n / length2);
                        }
                    }
                    const t = getIntersectionType(constituents);
                    if (!(t.flags & 131072 /* Never */))
                        intersections.push(t);
                }
                return intersections;
            }
            function getConstituentCount(type) {
                return !(type.flags & 3145728 /* UnionOrIntersection */) || type.aliasSymbol ? 1 : type.flags & 1048576 /* Union */ && type.origin ? getConstituentCount(type.origin) : getConstituentCountOfTypes(type.types);
            }
            function getConstituentCountOfTypes(types) {
                return reduceLeft(types, (n, t) => n + getConstituentCount(t), 0);
            }
            function getTypeFromIntersectionTypeNode(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    const aliasSymbol = getAliasSymbolForTypeNode(node);
                    const types = map(node.types, getTypeFromTypeNode);
                    const emptyIndex = types.length === 2 ? types.indexOf(emptyTypeLiteralType) : -1;
                    const t = emptyIndex >= 0 ? types[1 - emptyIndex] : unknownType;
                    const noSupertypeReduction = !!(t.flags & (4 /* String */ | 8 /* Number */ | 64 /* BigInt */) || t.flags & 134217728 /* TemplateLiteral */ && isPatternLiteralType(t));
                    links.resolvedType = getIntersectionType(types, aliasSymbol, getTypeArgumentsForAliasSymbol(aliasSymbol), noSupertypeReduction);
                }
                return links.resolvedType;
            }
            function createIndexType(type, indexFlags) {
                const result = createType(4194304 /* Index */);
                result.type = type;
                result.indexFlags = indexFlags;
                return result;
            }
            function createOriginIndexType(type) {
                const result = createOriginType(4194304 /* Index */);
                result.type = type;
                return result;
            }
            function getIndexTypeForGenericType(type, indexFlags) {
                return indexFlags & 1 /* StringsOnly */ ? type.resolvedStringIndexType || (type.resolvedStringIndexType = createIndexType(type, 1 /* StringsOnly */)) : type.resolvedIndexType || (type.resolvedIndexType = createIndexType(type, 0 /* None */));
            }
            function getIndexTypeForMappedType(type, indexFlags) {
                const typeParameter = getTypeParameterFromMappedType(type);
                const constraintType = getConstraintTypeFromMappedType(type);
                const nameType = getNameTypeFromMappedType(type.target || type);
                if (!nameType && !(indexFlags & 2 /* NoIndexSignatures */)) {
                    return constraintType;
                }
                const keyTypes = [];
                if (isGenericIndexType(constraintType)) {
                    if (isMappedTypeWithKeyofConstraintDeclaration(type)) {
                        return getIndexTypeForGenericType(type, indexFlags);
                    }
                    forEachType(constraintType, addMemberForKeyType);
                }
                else if (isMappedTypeWithKeyofConstraintDeclaration(type)) {
                    const modifiersType = getApparentType(getModifiersTypeFromMappedType(type));
                    forEachMappedTypePropertyKeyTypeAndIndexSignatureKeyType(modifiersType, 8576 /* StringOrNumberLiteralOrUnique */, !!(indexFlags & 1 /* StringsOnly */), addMemberForKeyType);
                }
                else {
                    forEachType(getLowerBoundOfKeyType(constraintType), addMemberForKeyType);
                }
                const result = indexFlags & 2 /* NoIndexSignatures */ ? filterType(getUnionType(keyTypes), (t) => !(t.flags & (1 /* Any */ | 4 /* String */))) : getUnionType(keyTypes);
                if (result.flags & 1048576 /* Union */ && constraintType.flags & 1048576 /* Union */ && getTypeListId(result.types) === getTypeListId(constraintType.types)) {
                    return constraintType;
                }
                return result;
                function addMemberForKeyType(keyType) {
                    const propNameType = nameType ? instantiateType(nameType, appendTypeMapping(type.mapper, typeParameter, keyType)) : keyType;
                    keyTypes.push(propNameType === stringType ? stringOrNumberType : propNameType);
                }
            }
            function hasDistributiveNameType(mappedType) {
                const typeVariable = getTypeParameterFromMappedType(mappedType);
                return isDistributive(getNameTypeFromMappedType(mappedType) || typeVariable);
                function isDistributive(type) {
                    return type.flags & (3 /* AnyOrUnknown */ | 402784252 /* Primitive */ | 131072 /* Never */ | 262144 /* TypeParameter */ | 524288 /* Object */ | 67108864 /* NonPrimitive */) ? true : type.flags & 16777216 /* Conditional */ ? type.root.isDistributive && type.checkType === typeVariable : type.flags & (3145728 /* UnionOrIntersection */ | 134217728 /* TemplateLiteral */) ? every(type.types, isDistributive) : type.flags & 8388608 /* IndexedAccess */ ? isDistributive(type.objectType) && isDistributive(type.indexType) : type.flags & 33554432 /* Substitution */ ? isDistributive(type.baseType) && isDistributive(type.constraint) : type.flags & 268435456 /* StringMapping */ ? isDistributive(type.type) : false;
                }
            }
            function getLiteralTypeFromPropertyName(name) {
                if (isPrivateIdentifier(name)) {
                    return neverType;
                }
                if (isNumericLiteral(name)) {
                    return getRegularTypeOfLiteralType(checkExpression(name));
                }
                if (isComputedPropertyName(name)) {
                    return getRegularTypeOfLiteralType(checkComputedPropertyName(name));
                }
                const propertyName = getPropertyNameForPropertyNameNode(name);
                if (propertyName !== void 0) {
                    return getStringLiteralType(unescapeLeadingUnderscores(propertyName));
                }
                if (isExpression(name)) {
                    return getRegularTypeOfLiteralType(checkExpression(name));
                }
                return neverType;
            }
            function getLiteralTypeFromProperty(prop, include, includeNonPublic) {
                if (includeNonPublic || !(getDeclarationModifierFlagsFromSymbol(prop) & 6 /* NonPublicAccessibilityModifier */)) {
                    let type = getSymbolLinks(getLateBoundSymbol(prop)).nameType;
                    if (!type) {
                        const name = getNameOfDeclaration(prop.valueDeclaration);
                        type = prop.escapedName === "default" /* Default */ ? getStringLiteralType("default") : name && getLiteralTypeFromPropertyName(name) || (!isKnownSymbol(prop) ? getStringLiteralType(symbolName(prop)) : void 0);
                    }
                    if (type && type.flags & include) {
                        return type;
                    }
                }
                return neverType;
            }
            function isKeyTypeIncluded(keyType, include) {
                return !!(keyType.flags & include || keyType.flags & 2097152 /* Intersection */ && some(keyType.types, (t) => isKeyTypeIncluded(t, include)));
            }
            function getLiteralTypeFromProperties(type, include, includeOrigin) {
                const origin = includeOrigin && (getObjectFlags(type) & (3 /* ClassOrInterface */ | 4 /* Reference */) || type.aliasSymbol) ? createOriginIndexType(type) : void 0;
                const propertyTypes = map(getPropertiesOfType(type), (prop) => getLiteralTypeFromProperty(prop, include));
                const indexKeyTypes = map(getIndexInfosOfType(type), (info) => info !== enumNumberIndexInfo && isKeyTypeIncluded(info.keyType, include) ? info.keyType === stringType && include & 8 /* Number */ ? stringOrNumberType : info.keyType : neverType);
                return getUnionType(concatenate(propertyTypes, indexKeyTypes), 1 /* Literal */, 
                /*aliasSymbol*/
                void 0, 
                /*aliasTypeArguments*/
                void 0, origin);
            }
            function shouldDeferIndexType(type, indexFlags = 0 /* None */) {
                return !!(type.flags & 58982400 /* InstantiableNonPrimitive */ || isGenericTupleType(type) || isGenericMappedType(type) && (!hasDistributiveNameType(type) || getMappedTypeNameTypeKind(type) === 2 /* Remapping */) || type.flags & 1048576 /* Union */ && !(indexFlags & 4 /* NoReducibleCheck */) && isGenericReducibleType(type) || type.flags & 2097152 /* Intersection */ && maybeTypeOfKind(type, 465829888 /* Instantiable */) && some(type.types, isEmptyAnonymousObjectType));
            }
            function getIndexType(type, indexFlags = defaultIndexFlags) {
                type = getReducedType(type);
                return isNoInferType(type) ? getNoInferType(getIndexType(type.baseType, indexFlags)) : shouldDeferIndexType(type, indexFlags) ? getIndexTypeForGenericType(type, indexFlags) : type.flags & 1048576 /* Union */ ? getIntersectionType(map(type.types, (t) => getIndexType(t, indexFlags))) : type.flags & 2097152 /* Intersection */ ? getUnionType(map(type.types, (t) => getIndexType(t, indexFlags))) : getObjectFlags(type) & 32 /* Mapped */ ? getIndexTypeForMappedType(type, indexFlags) : type === wildcardType ? wildcardType : type.flags & 2 /* Unknown */ ? neverType : type.flags & (1 /* Any */ | 131072 /* Never */) ? keyofConstraintType : getLiteralTypeFromProperties(type, (indexFlags & 2 /* NoIndexSignatures */ ? 128 /* StringLiteral */ : 402653316 /* StringLike */) | (indexFlags & 1 /* StringsOnly */ ? 0 : 296 /* NumberLike */ | 12288 /* ESSymbolLike */), indexFlags === defaultIndexFlags);
            }
            function getExtractStringType(type) {
                if (keyofStringsOnly) {
                    return type;
                }
                const extractTypeAlias = getGlobalExtractSymbol();
                return extractTypeAlias ? getTypeAliasInstantiation(extractTypeAlias, [type, stringType]) : stringType;
            }
            function getIndexTypeOrString(type) {
                const indexType = getExtractStringType(getIndexType(type));
                return indexType.flags & 131072 /* Never */ ? stringType : indexType;
            }
            function getTypeFromTypeOperatorNode(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    switch (node.operator) {
                        case 143 /* KeyOfKeyword */:
                            links.resolvedType = getIndexType(getTypeFromTypeNode(node.type));
                            break;
                        case 158 /* UniqueKeyword */:
                            links.resolvedType = node.type.kind === 155 /* SymbolKeyword */ ? getESSymbolLikeTypeForNode(walkUpParenthesizedTypes(node.parent)) : errorType;
                            break;
                        case 148 /* ReadonlyKeyword */:
                            links.resolvedType = getTypeFromTypeNode(node.type);
                            break;
                        default:
                            Debug.assertNever(node.operator);
                    }
                }
                return links.resolvedType;
            }
            function getTypeFromTemplateTypeNode(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    links.resolvedType = getTemplateLiteralType([node.head.text, ...map(node.templateSpans, (span) => span.literal.text)], map(node.templateSpans, (span) => getTypeFromTypeNode(span.type)));
                }
                return links.resolvedType;
            }
            function getTemplateLiteralType(texts, types) {
                const unionIndex = findIndex(types, (t) => !!(t.flags & (131072 /* Never */ | 1048576 /* Union */)));
                if (unionIndex >= 0) {
                    return checkCrossProductUnion(types) ? mapType(types[unionIndex], (t) => getTemplateLiteralType(texts, replaceElement(types, unionIndex, t))) : errorType;
                }
                if (contains(types, wildcardType)) {
                    return wildcardType;
                }
                const newTypes = [];
                const newTexts = [];
                let text = texts[0];
                if (!addSpans(texts, types)) {
                    return stringType;
                }
                if (newTypes.length === 0) {
                    return getStringLiteralType(text);
                }
                newTexts.push(text);
                if (every(newTexts, (t) => t === "")) {
                    if (every(newTypes, (t) => !!(t.flags & 4 /* String */))) {
                        return stringType;
                    }
                    if (newTypes.length === 1 && isPatternLiteralType(newTypes[0])) {
                        return newTypes[0];
                    }
                }
                const id = `${getTypeListId(newTypes)}|${map(newTexts, (t) => t.length).join(",")}|${newTexts.join("")}`;
                let type = templateLiteralTypes.get(id);
                if (!type) {
                    templateLiteralTypes.set(id, type = createTemplateLiteralType(newTexts, newTypes));
                }
                return type;
                function addSpans(texts2, types2) {
                    for (let i = 0; i < types2.length; i++) {
                        const t = types2[i];
                        if (t.flags & (2944 /* Literal */ | 65536 /* Null */ | 32768 /* Undefined */)) {
                            text += getTemplateStringForType(t) || "";
                            text += texts2[i + 1];
                        }
                        else if (t.flags & 134217728 /* TemplateLiteral */) {
                            text += t.texts[0];
                            if (!addSpans(t.texts, t.types))
                                return false;
                            text += texts2[i + 1];
                        }
                        else if (isGenericIndexType(t) || isPatternLiteralPlaceholderType(t)) {
                            newTypes.push(t);
                            newTexts.push(text);
                            text = texts2[i + 1];
                        }
                        else {
                            return false;
                        }
                    }
                    return true;
                }
            }
            function getTemplateStringForType(type) {
                return type.flags & 128 /* StringLiteral */ ? type.value : type.flags & 256 /* NumberLiteral */ ? "" + type.value : type.flags & 2048 /* BigIntLiteral */ ? pseudoBigIntToString(type.value) : type.flags & (512 /* BooleanLiteral */ | 98304 /* Nullable */) ? type.intrinsicName : void 0;
            }
            function createTemplateLiteralType(texts, types) {
                const type = createType(134217728 /* TemplateLiteral */);
                type.texts = texts;
                type.types = types;
                return type;
            }
            function getStringMappingType(symbol, type) {
                return type.flags & (1048576 /* Union */ | 131072 /* Never */) ? mapType(type, (t) => getStringMappingType(symbol, t)) : type.flags & 128 /* StringLiteral */ ? getStringLiteralType(applyStringMapping(symbol, type.value)) : type.flags & 134217728 /* TemplateLiteral */ ? getTemplateLiteralType(...applyTemplateStringMapping(symbol, type.texts, type.types)) : (
                // Mapping<Mapping<T>> === Mapping<T>
                type.flags & 268435456 /* StringMapping */ && symbol === type.symbol ? type : type.flags & (1 /* Any */ | 4 /* String */ | 268435456 /* StringMapping */) || isGenericIndexType(type) ? getStringMappingTypeForGenericType(symbol, type) : (
                // This handles Mapping<`${number}`> and Mapping<`${bigint}`>
                isPatternLiteralPlaceholderType(type) ? getStringMappingTypeForGenericType(symbol, getTemplateLiteralType(["", ""], [type])) : type));
            }
            function applyStringMapping(symbol, str) {
                switch (intrinsicTypeKinds.get(symbol.escapedName)) {
                    case 0 /* Uppercase */:
                        return str.toUpperCase();
                    case 1 /* Lowercase */:
                        return str.toLowerCase();
                    case 2 /* Capitalize */:
                        return str.charAt(0).toUpperCase() + str.slice(1);
                    case 3 /* Uncapitalize */:
                        return str.charAt(0).toLowerCase() + str.slice(1);
                }
                return str;
            }
            function applyTemplateStringMapping(symbol, texts, types) {
                switch (intrinsicTypeKinds.get(symbol.escapedName)) {
                    case 0 /* Uppercase */:
                        return [texts.map((t) => t.toUpperCase()), types.map((t) => getStringMappingType(symbol, t))];
                    case 1 /* Lowercase */:
                        return [texts.map((t) => t.toLowerCase()), types.map((t) => getStringMappingType(symbol, t))];
                    case 2 /* Capitalize */:
                        return [texts[0] === "" ? texts : [texts[0].charAt(0).toUpperCase() + texts[0].slice(1), ...texts.slice(1)], texts[0] === "" ? [getStringMappingType(symbol, types[0]), ...types.slice(1)] : types];
                    case 3 /* Uncapitalize */:
                        return [texts[0] === "" ? texts : [texts[0].charAt(0).toLowerCase() + texts[0].slice(1), ...texts.slice(1)], texts[0] === "" ? [getStringMappingType(symbol, types[0]), ...types.slice(1)] : types];
                }
                return [texts, types];
            }
            function getStringMappingTypeForGenericType(symbol, type) {
                const id = `${getSymbolId(symbol)},${getTypeId(type)}`;
                let result = stringMappingTypes.get(id);
                if (!result) {
                    stringMappingTypes.set(id, result = createStringMappingType(symbol, type));
                }
                return result;
            }
            function createStringMappingType(symbol, type) {
                const result = createTypeWithSymbol(268435456 /* StringMapping */, symbol);
                result.type = type;
                return result;
            }
            function createIndexedAccessType(objectType, indexType, accessFlags, aliasSymbol, aliasTypeArguments) {
                const type = createType(8388608 /* IndexedAccess */);
                type.objectType = objectType;
                type.indexType = indexType;
                type.accessFlags = accessFlags;
                type.aliasSymbol = aliasSymbol;
                type.aliasTypeArguments = aliasTypeArguments;
                return type;
            }
            function isJSLiteralType(type) {
                if (noImplicitAny) {
                    return false;
                }
                if (getObjectFlags(type) & 4096 /* JSLiteral */) {
                    return true;
                }
                if (type.flags & 1048576 /* Union */) {
                    return every(type.types, isJSLiteralType);
                }
                if (type.flags & 2097152 /* Intersection */) {
                    return some(type.types, isJSLiteralType);
                }
                if (type.flags & 465829888 /* Instantiable */) {
                    const constraint = getResolvedBaseConstraint(type);
                    return constraint !== type && isJSLiteralType(constraint);
                }
                return false;
            }
            function getPropertyNameFromIndex(indexType, accessNode) {
                return isTypeUsableAsPropertyName(indexType) ? getPropertyNameFromType(indexType) : accessNode && isPropertyName(accessNode) ? (
                // late bound names are handled in the first branch, so here we only need to handle normal names
                getPropertyNameForPropertyNameNode(accessNode)) : void 0;
            }
            function isUncalledFunctionReference(node, symbol) {
                if (symbol.flags & (16 /* Function */ | 8192 /* Method */)) {
                    const parent2 = findAncestor(node.parent, (n) => !isAccessExpression(n)) || node.parent;
                    if (isCallLikeExpression(parent2)) {
                        return isCallOrNewExpression(parent2) && isIdentifier(node) && hasMatchingArgument(parent2, node);
                    }
                    return every(symbol.declarations, (d) => !isFunctionLike(d) || isDeprecatedDeclaration2(d));
                }
                return true;
            }
            function getPropertyTypeForIndexType(originalObjectType, objectType, indexType, fullIndexType, accessNode, accessFlags) {
                const accessExpression = accessNode && accessNode.kind === 212 /* ElementAccessExpression */ ? accessNode : void 0;
                const propName = accessNode && isPrivateIdentifier(accessNode) ? void 0 : getPropertyNameFromIndex(indexType, accessNode);
                if (propName !== void 0) {
                    if (accessFlags & 256 /* Contextual */) {
                        return getTypeOfPropertyOfContextualType(objectType, propName) || anyType;
                    }
                    const prop = getPropertyOfType(objectType, propName);
                    if (prop) {
                        if (accessFlags & 64 /* ReportDeprecated */ && accessNode && prop.declarations && isDeprecatedSymbol(prop) && isUncalledFunctionReference(accessNode, prop)) {
                            const deprecatedNode = (accessExpression == null ? void 0 : accessExpression.argumentExpression) ?? (isIndexedAccessTypeNode(accessNode) ? accessNode.indexType : accessNode);
                            addDeprecatedSuggestion(deprecatedNode, prop.declarations, propName);
                        }
                        if (accessExpression) {
                            markPropertyAsReferenced(prop, accessExpression, isSelfTypeAccess(accessExpression.expression, objectType.symbol));
                            if (isAssignmentToReadonlyEntity(accessExpression, prop, getAssignmentTargetKind(accessExpression))) {
                                error2(accessExpression.argumentExpression, Diagnostics.Cannot_assign_to_0_because_it_is_a_read_only_property, symbolToString(prop));
                                return void 0;
                            }
                            if (accessFlags & 8 /* CacheSymbol */) {
                                getNodeLinks(accessNode).resolvedSymbol = prop;
                            }
                            if (isThisPropertyAccessInConstructor(accessExpression, prop)) {
                                return autoType;
                            }
                        }
                        const propType = accessFlags & 4 /* Writing */ ? getWriteTypeOfSymbol(prop) : getTypeOfSymbol(prop);
                        return accessExpression && getAssignmentTargetKind(accessExpression) !== 1 /* Definite */ ? getFlowTypeOfReference(accessExpression, propType) : accessNode && isIndexedAccessTypeNode(accessNode) && containsMissingType(propType) ? getUnionType([propType, undefinedType]) : propType;
                    }
                    if (everyType(objectType, isTupleType) && isNumericLiteralName(propName)) {
                        const index = +propName;
                        if (accessNode && everyType(objectType, (t) => !t.target.hasRestElement) && !(accessFlags & 16 /* NoTupleBoundsCheck */)) {
                            const indexNode = getIndexNodeForAccessExpression(accessNode);
                            if (isTupleType(objectType)) {
                                if (index < 0) {
                                    error2(indexNode, Diagnostics.A_tuple_type_cannot_be_indexed_with_a_negative_value);
                                    return undefinedType;
                                }
                                error2(indexNode, Diagnostics.Tuple_type_0_of_length_1_has_no_element_at_index_2, typeToString(objectType), getTypeReferenceArity(objectType), unescapeLeadingUnderscores(propName));
                            }
                            else {
                                error2(indexNode, Diagnostics.Property_0_does_not_exist_on_type_1, unescapeLeadingUnderscores(propName), typeToString(objectType));
                            }
                        }
                        if (index >= 0) {
                            errorIfWritingToReadonlyIndex(getIndexInfoOfType(objectType, numberType));
                            return getTupleElementTypeOutOfStartCount(objectType, index, accessFlags & 1 /* IncludeUndefined */ ? missingType : void 0);
                        }
                    }
                }
                if (!(indexType.flags & 98304 /* Nullable */) && isTypeAssignableToKind(indexType, 402653316 /* StringLike */ | 296 /* NumberLike */ | 12288 /* ESSymbolLike */)) {
                    if (objectType.flags & (1 /* Any */ | 131072 /* Never */)) {
                        return objectType;
                    }
                    const indexInfo = getApplicableIndexInfo(objectType, indexType) || getIndexInfoOfType(objectType, stringType);
                    if (indexInfo) {
                        if (accessFlags & 2 /* NoIndexSignatures */ && indexInfo.keyType !== numberType) {
                            if (accessExpression) {
                                if (accessFlags & 4 /* Writing */) {
                                    error2(accessExpression, Diagnostics.Type_0_is_generic_and_can_only_be_indexed_for_reading, typeToString(originalObjectType));
                                }
                                else {
                                    error2(accessExpression, Diagnostics.Type_0_cannot_be_used_to_index_type_1, typeToString(indexType), typeToString(originalObjectType));
                                }
                            }
                            return void 0;
                        }
                        if (accessNode && indexInfo.keyType === stringType && !isTypeAssignableToKind(indexType, 4 /* String */ | 8 /* Number */)) {
                            const indexNode = getIndexNodeForAccessExpression(accessNode);
                            error2(indexNode, Diagnostics.Type_0_cannot_be_used_as_an_index_type, typeToString(indexType));
                            return accessFlags & 1 /* IncludeUndefined */ ? getUnionType([indexInfo.type, missingType]) : indexInfo.type;
                        }
                        errorIfWritingToReadonlyIndex(indexInfo);
                        if (accessFlags & 1 /* IncludeUndefined */ && !(objectType.symbol && objectType.symbol.flags & (256 /* RegularEnum */ | 128 /* ConstEnum */) && (indexType.symbol && indexType.flags & 1024 /* EnumLiteral */ && getParentOfSymbol(indexType.symbol) === objectType.symbol))) {
                            return getUnionType([indexInfo.type, missingType]);
                        }
                        return indexInfo.type;
                    }
                    if (indexType.flags & 131072 /* Never */) {
                        return neverType;
                    }
                    if (isJSLiteralType(objectType)) {
                        return anyType;
                    }
                    if (accessExpression && !isConstEnumObjectType(objectType)) {
                        if (isObjectLiteralType2(objectType)) {
                            if (noImplicitAny && indexType.flags & (128 /* StringLiteral */ | 256 /* NumberLiteral */)) {
                                diagnostics.add(createDiagnosticForNode(accessExpression, Diagnostics.Property_0_does_not_exist_on_type_1, indexType.value, typeToString(objectType)));
                                return undefinedType;
                            }
                            else if (indexType.flags & (8 /* Number */ | 4 /* String */)) {
                                const types = map(objectType.properties, (property) => {
                                    return getTypeOfSymbol(property);
                                });
                                return getUnionType(append(types, undefinedType));
                            }
                        }
                        if (objectType.symbol === globalThisSymbol && propName !== void 0 && globalThisSymbol.exports.has(propName) && globalThisSymbol.exports.get(propName).flags & 418 /* BlockScoped */) {
                            error2(accessExpression, Diagnostics.Property_0_does_not_exist_on_type_1, unescapeLeadingUnderscores(propName), typeToString(objectType));
                        }
                        else if (noImplicitAny && !compilerOptions.suppressImplicitAnyIndexErrors && !(accessFlags & 128 /* SuppressNoImplicitAnyError */)) {
                            if (propName !== void 0 && typeHasStaticProperty(propName, objectType)) {
                                const typeName = typeToString(objectType);
                                error2(accessExpression, Diagnostics.Property_0_does_not_exist_on_type_1_Did_you_mean_to_access_the_static_member_2_instead, propName, typeName, typeName + "[" + getTextOfNode(accessExpression.argumentExpression) + "]");
                            }
                            else if (getIndexTypeOfType(objectType, numberType)) {
                                error2(accessExpression.argumentExpression, Diagnostics.Element_implicitly_has_an_any_type_because_index_expression_is_not_of_type_number);
                            }
                            else {
                                let suggestion;
                                if (propName !== void 0 && (suggestion = getSuggestionForNonexistentProperty(propName, objectType))) {
                                    if (suggestion !== void 0) {
                                        error2(accessExpression.argumentExpression, Diagnostics.Property_0_does_not_exist_on_type_1_Did_you_mean_2, propName, typeToString(objectType), suggestion);
                                    }
                                }
                                else {
                                    const suggestion2 = getSuggestionForNonexistentIndexSignature(objectType, accessExpression, indexType);
                                    if (suggestion2 !== void 0) {
                                        error2(accessExpression, Diagnostics.Element_implicitly_has_an_any_type_because_type_0_has_no_index_signature_Did_you_mean_to_call_1, typeToString(objectType), suggestion2);
                                    }
                                    else {
                                        let errorInfo;
                                        if (indexType.flags & 1024 /* EnumLiteral */) {
                                            errorInfo = chainDiagnosticMessages(
                                            /*details*/
                                            void 0, Diagnostics.Property_0_does_not_exist_on_type_1, "[" + typeToString(indexType) + "]", typeToString(objectType));
                                        }
                                        else if (indexType.flags & 8192 /* UniqueESSymbol */) {
                                            const symbolName2 = getFullyQualifiedName(indexType.symbol, accessExpression);
                                            errorInfo = chainDiagnosticMessages(
                                            /*details*/
                                            void 0, Diagnostics.Property_0_does_not_exist_on_type_1, "[" + symbolName2 + "]", typeToString(objectType));
                                        }
                                        else if (indexType.flags & 128 /* StringLiteral */) {
                                            errorInfo = chainDiagnosticMessages(
                                            /*details*/
                                            void 0, Diagnostics.Property_0_does_not_exist_on_type_1, indexType.value, typeToString(objectType));
                                        }
                                        else if (indexType.flags & 256 /* NumberLiteral */) {
                                            errorInfo = chainDiagnosticMessages(
                                            /*details*/
                                            void 0, Diagnostics.Property_0_does_not_exist_on_type_1, indexType.value, typeToString(objectType));
                                        }
                                        else if (indexType.flags & (8 /* Number */ | 4 /* String */)) {
                                            errorInfo = chainDiagnosticMessages(
                                            /*details*/
                                            void 0, Diagnostics.No_index_signature_with_a_parameter_of_type_0_was_found_on_type_1, typeToString(indexType), typeToString(objectType));
                                        }
                                        errorInfo = chainDiagnosticMessages(errorInfo, Diagnostics.Element_implicitly_has_an_any_type_because_expression_of_type_0_can_t_be_used_to_index_type_1, typeToString(fullIndexType), typeToString(objectType));
                                        diagnostics.add(createDiagnosticForNodeFromMessageChain(getSourceFileOfNode(accessExpression), accessExpression, errorInfo));
                                    }
                                }
                            }
                        }
                        return void 0;
                    }
                }
                if (isJSLiteralType(objectType)) {
                    return anyType;
                }
                if (accessNode) {
                    const indexNode = getIndexNodeForAccessExpression(accessNode);
                    if (indexType.flags & (128 /* StringLiteral */ | 256 /* NumberLiteral */)) {
                        error2(indexNode, Diagnostics.Property_0_does_not_exist_on_type_1, "" + indexType.value, typeToString(objectType));
                    }
                    else if (indexType.flags & (4 /* String */ | 8 /* Number */)) {
                        error2(indexNode, Diagnostics.Type_0_has_no_matching_index_signature_for_type_1, typeToString(objectType), typeToString(indexType));
                    }
                    else {
                        error2(indexNode, Diagnostics.Type_0_cannot_be_used_as_an_index_type, typeToString(indexType));
                    }
                }
                if (isTypeAny(indexType)) {
                    return indexType;
                }
                return void 0;
                function errorIfWritingToReadonlyIndex(indexInfo) {
                    if (indexInfo && indexInfo.isReadonly && accessExpression && (isAssignmentTarget(accessExpression) || isDeleteTarget(accessExpression))) {
                        error2(accessExpression, Diagnostics.Index_signature_in_type_0_only_permits_reading, typeToString(objectType));
                    }
                }
            }
            function getIndexNodeForAccessExpression(accessNode) {
                return accessNode.kind === 212 /* ElementAccessExpression */ ? accessNode.argumentExpression : accessNode.kind === 199 /* IndexedAccessType */ ? accessNode.indexType : accessNode.kind === 167 /* ComputedPropertyName */ ? accessNode.expression : accessNode;
            }
            function isPatternLiteralPlaceholderType(type) {
                if (type.flags & 2097152 /* Intersection */) {
                    let seenPlaceholder = false;
                    for (const t of type.types) {
                        if (t.flags & (2944 /* Literal */ | 98304 /* Nullable */) || isPatternLiteralPlaceholderType(t)) {
                            seenPlaceholder = true;
                        }
                        else if (!(t.flags & 524288 /* Object */)) {
                            return false;
                        }
                    }
                    return seenPlaceholder;
                }
                return !!(type.flags & (1 /* Any */ | 4 /* String */ | 8 /* Number */ | 64 /* BigInt */)) || isPatternLiteralType(type);
            }
            function isPatternLiteralType(type) {
                return !!(type.flags & 134217728 /* TemplateLiteral */) && every(type.types, isPatternLiteralPlaceholderType) || !!(type.flags & 268435456 /* StringMapping */) && isPatternLiteralPlaceholderType(type.type);
            }
            function isGenericStringLikeType(type) {
                return !!(type.flags & (134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */)) && !isPatternLiteralType(type);
            }
            function isGenericType(type) {
                return !!getGenericObjectFlags(type);
            }
            function isGenericObjectType(type) {
                return !!(getGenericObjectFlags(type) & 4194304 /* IsGenericObjectType */);
            }
            function isGenericIndexType(type) {
                return !!(getGenericObjectFlags(type) & 8388608 /* IsGenericIndexType */);
            }
            function getGenericObjectFlags(type) {
                if (type.flags & 3145728 /* UnionOrIntersection */) {
                    if (!(type.objectFlags & 2097152 /* IsGenericTypeComputed */)) {
                        type.objectFlags |= 2097152 /* IsGenericTypeComputed */ | reduceLeft(type.types, (flags, t) => flags | getGenericObjectFlags(t), 0);
                    }
                    return type.objectFlags & 12582912 /* IsGenericType */;
                }
                if (type.flags & 33554432 /* Substitution */) {
                    if (!(type.objectFlags & 2097152 /* IsGenericTypeComputed */)) {
                        type.objectFlags |= 2097152 /* IsGenericTypeComputed */ | getGenericObjectFlags(type.baseType) | getGenericObjectFlags(type.constraint);
                    }
                    return type.objectFlags & 12582912 /* IsGenericType */;
                }
                return (type.flags & 58982400 /* InstantiableNonPrimitive */ || isGenericMappedType(type) || isGenericTupleType(type) ? 4194304 /* IsGenericObjectType */ : 0) | (type.flags & (58982400 /* InstantiableNonPrimitive */ | 4194304 /* Index */) || isGenericStringLikeType(type) ? 8388608 /* IsGenericIndexType */ : 0);
            }
            function getSimplifiedType(type, writing) {
                return type.flags & 8388608 /* IndexedAccess */ ? getSimplifiedIndexedAccessType(type, writing) : type.flags & 16777216 /* Conditional */ ? getSimplifiedConditionalType(type, writing) : type;
            }
            function distributeIndexOverObjectType(objectType, indexType, writing) {
                if (objectType.flags & 1048576 /* Union */ || objectType.flags & 2097152 /* Intersection */ && !shouldDeferIndexType(objectType)) {
                    const types = map(objectType.types, (t) => getSimplifiedType(getIndexedAccessType(t, indexType), writing));
                    return objectType.flags & 2097152 /* Intersection */ || writing ? getIntersectionType(types) : getUnionType(types);
                }
            }
            function distributeObjectOverIndexType(objectType, indexType, writing) {
                if (indexType.flags & 1048576 /* Union */) {
                    const types = map(indexType.types, (t) => getSimplifiedType(getIndexedAccessType(objectType, t), writing));
                    return writing ? getIntersectionType(types) : getUnionType(types);
                }
            }
            function getSimplifiedIndexedAccessType(type, writing) {
                const cache = writing ? "simplifiedForWriting" : "simplifiedForReading";
                if (type[cache]) {
                    return type[cache] === circularConstraintType ? type : type[cache];
                }
                type[cache] = circularConstraintType;
                const objectType = getSimplifiedType(type.objectType, writing);
                const indexType = getSimplifiedType(type.indexType, writing);
                const distributedOverIndex = distributeObjectOverIndexType(objectType, indexType, writing);
                if (distributedOverIndex) {
                    return type[cache] = distributedOverIndex;
                }
                if (!(indexType.flags & 465829888 /* Instantiable */)) {
                    const distributedOverObject = distributeIndexOverObjectType(objectType, indexType, writing);
                    if (distributedOverObject) {
                        return type[cache] = distributedOverObject;
                    }
                }
                if (isGenericTupleType(objectType) && indexType.flags & 296 /* NumberLike */) {
                    const elementType = getElementTypeOfSliceOfTupleType(objectType, indexType.flags & 8 /* Number */ ? 0 : objectType.target.fixedLength, 
                    /*endSkipCount*/
                    0, writing);
                    if (elementType) {
                        return type[cache] = elementType;
                    }
                }
                if (isGenericMappedType(objectType)) {
                    if (getMappedTypeNameTypeKind(objectType) !== 2 /* Remapping */) {
                        return type[cache] = mapType(substituteIndexedMappedType(objectType, type.indexType), (t) => getSimplifiedType(t, writing));
                    }
                }
                return type[cache] = type;
            }
            function getSimplifiedConditionalType(type, writing) {
                const checkType = type.checkType;
                const extendsType = type.extendsType;
                const trueType2 = getTrueTypeFromConditionalType(type);
                const falseType2 = getFalseTypeFromConditionalType(type);
                if (falseType2.flags & 131072 /* Never */ && getActualTypeVariable(trueType2) === getActualTypeVariable(checkType)) {
                    if (checkType.flags & 1 /* Any */ || isTypeAssignableTo(getRestrictiveInstantiation(checkType), getRestrictiveInstantiation(extendsType))) {
                        return getSimplifiedType(trueType2, writing);
                    }
                    else if (isIntersectionEmpty(checkType, extendsType)) {
                        return neverType;
                    }
                }
                else if (trueType2.flags & 131072 /* Never */ && getActualTypeVariable(falseType2) === getActualTypeVariable(checkType)) {
                    if (!(checkType.flags & 1 /* Any */) && isTypeAssignableTo(getRestrictiveInstantiation(checkType), getRestrictiveInstantiation(extendsType))) {
                        return neverType;
                    }
                    else if (checkType.flags & 1 /* Any */ || isIntersectionEmpty(checkType, extendsType)) {
                        return getSimplifiedType(falseType2, writing);
                    }
                }
                return type;
            }
            function isIntersectionEmpty(type1, type2) {
                return !!(getUnionType([intersectTypes(type1, type2), neverType]).flags & 131072 /* Never */);
            }
            function substituteIndexedMappedType(objectType, index) {
                const mapper = createTypeMapper([getTypeParameterFromMappedType(objectType)], [index]);
                const templateMapper = combineTypeMappers(objectType.mapper, mapper);
                return instantiateType(getTemplateTypeFromMappedType(objectType.target || objectType), templateMapper);
            }
            function getIndexedAccessType(objectType, indexType, accessFlags = 0 /* None */, accessNode, aliasSymbol, aliasTypeArguments) {
                return getIndexedAccessTypeOrUndefined(objectType, indexType, accessFlags, accessNode, aliasSymbol, aliasTypeArguments) || (accessNode ? errorType : unknownType);
            }
            function indexTypeLessThan(indexType, limit) {
                return everyType(indexType, (t) => {
                    if (t.flags & 384 /* StringOrNumberLiteral */) {
                        const propName = getPropertyNameFromType(t);
                        if (isNumericLiteralName(propName)) {
                            const index = +propName;
                            return index >= 0 && index < limit;
                        }
                    }
                    return false;
                });
            }
            function getIndexedAccessTypeOrUndefined(objectType, indexType, accessFlags = 0 /* None */, accessNode, aliasSymbol, aliasTypeArguments) {
                if (objectType === wildcardType || indexType === wildcardType) {
                    return wildcardType;
                }
                objectType = getReducedType(objectType);
                if (isStringIndexSignatureOnlyType(objectType) && !(indexType.flags & 98304 /* Nullable */) && isTypeAssignableToKind(indexType, 4 /* String */ | 8 /* Number */)) {
                    indexType = stringType;
                }
                if (compilerOptions.noUncheckedIndexedAccess && accessFlags & 32 /* ExpressionPosition */)
                    accessFlags |= 1 /* IncludeUndefined */;
                if (isGenericIndexType(indexType) || (accessNode && accessNode.kind !== 199 /* IndexedAccessType */ ? isGenericTupleType(objectType) && !indexTypeLessThan(indexType, getTotalFixedElementCount(objectType.target)) : isGenericObjectType(objectType) && !(isTupleType(objectType) && indexTypeLessThan(indexType, getTotalFixedElementCount(objectType.target))) || isGenericReducibleType(objectType))) {
                    if (objectType.flags & 3 /* AnyOrUnknown */) {
                        return objectType;
                    }
                    const persistentAccessFlags = accessFlags & 1 /* Persistent */;
                    const id = objectType.id + "," + indexType.id + "," + persistentAccessFlags + getAliasId(aliasSymbol, aliasTypeArguments);
                    let type = indexedAccessTypes.get(id);
                    if (!type) {
                        indexedAccessTypes.set(id, type = createIndexedAccessType(objectType, indexType, persistentAccessFlags, aliasSymbol, aliasTypeArguments));
                    }
                    return type;
                }
                const apparentObjectType = getReducedApparentType(objectType);
                if (indexType.flags & 1048576 /* Union */ && !(indexType.flags & 16 /* Boolean */)) {
                    const propTypes = [];
                    let wasMissingProp = false;
                    for (const t of indexType.types) {
                        const propType = getPropertyTypeForIndexType(objectType, apparentObjectType, t, indexType, accessNode, accessFlags | (wasMissingProp ? 128 /* SuppressNoImplicitAnyError */ : 0));
                        if (propType) {
                            propTypes.push(propType);
                        }
                        else if (!accessNode) {
                            return void 0;
                        }
                        else {
                            wasMissingProp = true;
                        }
                    }
                    if (wasMissingProp) {
                        return void 0;
                    }
                    return accessFlags & 4 /* Writing */ ? getIntersectionType(propTypes, aliasSymbol, aliasTypeArguments) : getUnionType(propTypes, 1 /* Literal */, aliasSymbol, aliasTypeArguments);
                }
                return getPropertyTypeForIndexType(objectType, apparentObjectType, indexType, indexType, accessNode, accessFlags | 8 /* CacheSymbol */ | 64 /* ReportDeprecated */);
            }
            function getTypeFromIndexedAccessTypeNode(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    const objectType = getTypeFromTypeNode(node.objectType);
                    const indexType = getTypeFromTypeNode(node.indexType);
                    const potentialAlias = getAliasSymbolForTypeNode(node);
                    links.resolvedType = getIndexedAccessType(objectType, indexType, 0 /* None */, node, potentialAlias, getTypeArgumentsForAliasSymbol(potentialAlias));
                }
                return links.resolvedType;
            }
            function getTypeFromMappedTypeNode(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    const type = createObjectType(32 /* Mapped */, node.symbol);
                    type.declaration = node;
                    type.aliasSymbol = getAliasSymbolForTypeNode(node);
                    type.aliasTypeArguments = getTypeArgumentsForAliasSymbol(type.aliasSymbol);
                    links.resolvedType = type;
                    getConstraintTypeFromMappedType(type);
                }
                return links.resolvedType;
            }
            function getActualTypeVariable(type) {
                if (type.flags & 33554432 /* Substitution */) {
                    return getActualTypeVariable(type.baseType);
                }
                if (type.flags & 8388608 /* IndexedAccess */ && (type.objectType.flags & 33554432 /* Substitution */ || type.indexType.flags & 33554432 /* Substitution */)) {
                    return getIndexedAccessType(getActualTypeVariable(type.objectType), getActualTypeVariable(type.indexType));
                }
                return type;
            }
            function isSimpleTupleType(node) {
                return isTupleTypeNode(node) && length(node.elements) > 0 && !some(node.elements, (e) => isOptionalTypeNode(e) || isRestTypeNode(e) || isNamedTupleMember(e) && !!(e.questionToken || e.dotDotDotToken));
            }
            function isDeferredType(type, checkTuples) {
                return isGenericType(type) || checkTuples && isTupleType(type) && some(getElementTypes(type), isGenericType);
            }
            function getConditionalType(root, mapper, forConstraint, aliasSymbol, aliasTypeArguments) {
                let result;
                let extraTypes;
                let tailCount = 0;
                while (true) {
                    if (tailCount === 1e3) {
                        error2(currentNode, Diagnostics.Type_instantiation_is_excessively_deep_and_possibly_infinite);
                        return errorType;
                    }
                    const checkType = instantiateType(getActualTypeVariable(root.checkType), mapper);
                    const extendsType = instantiateType(root.extendsType, mapper);
                    if (checkType === errorType || extendsType === errorType) {
                        return errorType;
                    }
                    if (checkType === wildcardType || extendsType === wildcardType) {
                        return wildcardType;
                    }
                    const checkTypeNode = skipTypeParentheses(root.node.checkType);
                    const extendsTypeNode = skipTypeParentheses(root.node.extendsType);
                    const checkTuples = isSimpleTupleType(checkTypeNode) && isSimpleTupleType(extendsTypeNode) && length(checkTypeNode.elements) === length(extendsTypeNode.elements);
                    const checkTypeDeferred = isDeferredType(checkType, checkTuples);
                    let combinedMapper;
                    if (root.inferTypeParameters) {
                        const context = createInferenceContext(root.inferTypeParameters, 
                        /*signature*/
                        void 0, 0 /* None */);
                        if (mapper) {
                            context.nonFixingMapper = combineTypeMappers(context.nonFixingMapper, mapper);
                        }
                        if (!checkTypeDeferred) {
                            inferTypes(context.inferences, checkType, extendsType, 512 /* NoConstraints */ | 1024 /* AlwaysStrict */);
                        }
                        combinedMapper = mapper ? combineTypeMappers(context.mapper, mapper) : context.mapper;
                    }
                    const inferredExtendsType = combinedMapper ? instantiateType(root.extendsType, combinedMapper) : extendsType;
                    if (!checkTypeDeferred && !isDeferredType(inferredExtendsType, checkTuples)) {
                        if (!(inferredExtendsType.flags & 3 /* AnyOrUnknown */) && (checkType.flags & 1 /* Any */ || !isTypeAssignableTo(getPermissiveInstantiation(checkType), getPermissiveInstantiation(inferredExtendsType)))) {
                            if (checkType.flags & 1 /* Any */ || forConstraint && !(inferredExtendsType.flags & 131072 /* Never */) && someType(getPermissiveInstantiation(inferredExtendsType), (t) => isTypeAssignableTo(t, getPermissiveInstantiation(checkType)))) {
                                (extraTypes || (extraTypes = [])).push(instantiateType(getTypeFromTypeNode(root.node.trueType), combinedMapper || mapper));
                            }
                            const falseType2 = getTypeFromTypeNode(root.node.falseType);
                            if (falseType2.flags & 16777216 /* Conditional */) {
                                const newRoot = falseType2.root;
                                if (newRoot.node.parent === root.node && (!newRoot.isDistributive || newRoot.checkType === root.checkType)) {
                                    root = newRoot;
                                    continue;
                                }
                                if (canTailRecurse(falseType2, mapper)) {
                                    continue;
                                }
                            }
                            result = instantiateType(falseType2, mapper);
                            break;
                        }
                        if (inferredExtendsType.flags & 3 /* AnyOrUnknown */ || isTypeAssignableTo(getRestrictiveInstantiation(checkType), getRestrictiveInstantiation(inferredExtendsType))) {
                            const trueType2 = getTypeFromTypeNode(root.node.trueType);
                            const trueMapper = combinedMapper || mapper;
                            if (canTailRecurse(trueType2, trueMapper)) {
                                continue;
                            }
                            result = instantiateType(trueType2, trueMapper);
                            break;
                        }
                    }
                    result = createType(16777216 /* Conditional */);
                    result.root = root;
                    result.checkType = instantiateType(root.checkType, mapper);
                    result.extendsType = instantiateType(root.extendsType, mapper);
                    result.mapper = mapper;
                    result.combinedMapper = combinedMapper;
                    result.aliasSymbol = aliasSymbol || root.aliasSymbol;
                    result.aliasTypeArguments = aliasSymbol ? aliasTypeArguments : instantiateTypes(root.aliasTypeArguments, mapper);
                    break;
                }
                return extraTypes ? getUnionType(append(extraTypes, result)) : result;
                function canTailRecurse(newType, newMapper) {
                    if (newType.flags & 16777216 /* Conditional */ && newMapper) {
                        const newRoot = newType.root;
                        if (newRoot.outerTypeParameters) {
                            const typeParamMapper = combineTypeMappers(newType.mapper, newMapper);
                            const typeArguments = map(newRoot.outerTypeParameters, (t) => getMappedType(t, typeParamMapper));
                            const newRootMapper = createTypeMapper(newRoot.outerTypeParameters, typeArguments);
                            const newCheckType = newRoot.isDistributive ? getMappedType(newRoot.checkType, newRootMapper) : void 0;
                            if (!newCheckType || newCheckType === newRoot.checkType || !(newCheckType.flags & (1048576 /* Union */ | 131072 /* Never */))) {
                                root = newRoot;
                                mapper = newRootMapper;
                                aliasSymbol = void 0;
                                aliasTypeArguments = void 0;
                                if (newRoot.aliasSymbol) {
                                    tailCount++;
                                }
                                return true;
                            }
                        }
                    }
                    return false;
                }
            }
            function getTrueTypeFromConditionalType(type) {
                return type.resolvedTrueType || (type.resolvedTrueType = instantiateType(getTypeFromTypeNode(type.root.node.trueType), type.mapper));
            }
            function getFalseTypeFromConditionalType(type) {
                return type.resolvedFalseType || (type.resolvedFalseType = instantiateType(getTypeFromTypeNode(type.root.node.falseType), type.mapper));
            }
            function getInferredTrueTypeFromConditionalType(type) {
                return type.resolvedInferredTrueType || (type.resolvedInferredTrueType = type.combinedMapper ? instantiateType(getTypeFromTypeNode(type.root.node.trueType), type.combinedMapper) : getTrueTypeFromConditionalType(type));
            }
            function getInferTypeParameters(node) {
                let result;
                if (node.locals) {
                    node.locals.forEach((symbol) => {
                        if (symbol.flags & 262144 /* TypeParameter */) {
                            result = append(result, getDeclaredTypeOfSymbol(symbol));
                        }
                    });
                }
                return result;
            }
            function isDistributionDependent(root) {
                return root.isDistributive && (isTypeParameterPossiblyReferenced(root.checkType, root.node.trueType) || isTypeParameterPossiblyReferenced(root.checkType, root.node.falseType));
            }
            function getTypeFromConditionalTypeNode(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    const checkType = getTypeFromTypeNode(node.checkType);
                    const aliasSymbol = getAliasSymbolForTypeNode(node);
                    const aliasTypeArguments = getTypeArgumentsForAliasSymbol(aliasSymbol);
                    const allOuterTypeParameters = getOuterTypeParameters(node, 
                    /*includeThisTypes*/
                    true);
                    const outerTypeParameters = aliasTypeArguments ? allOuterTypeParameters : filter(allOuterTypeParameters, (tp) => isTypeParameterPossiblyReferenced(tp, node));
                    const root = {
                        node,
                        checkType,
                        extendsType: getTypeFromTypeNode(node.extendsType),
                        isDistributive: !!(checkType.flags & 262144 /* TypeParameter */),
                        inferTypeParameters: getInferTypeParameters(node),
                        outerTypeParameters,
                        instantiations: void 0,
                        aliasSymbol,
                        aliasTypeArguments
                    };
                    links.resolvedType = getConditionalType(root, 
                    /*mapper*/
                    void 0, 
                    /*forConstraint*/
                    false);
                    if (outerTypeParameters) {
                        root.instantiations = /* @__PURE__ */ new Map();
                        root.instantiations.set(getTypeListId(outerTypeParameters), links.resolvedType);
                    }
                }
                return links.resolvedType;
            }
            function getTypeFromInferTypeNode(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    links.resolvedType = getDeclaredTypeOfTypeParameter(getSymbolOfDeclaration(node.typeParameter));
                }
                return links.resolvedType;
            }
            function getIdentifierChain(node) {
                if (isIdentifier(node)) {
                    return [node];
                }
                else {
                    return append(getIdentifierChain(node.left), node.right);
                }
            }
            function getTypeFromImportTypeNode(node) {
                var _a;
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    if (!isLiteralImportTypeNode(node)) {
                        error2(node.argument, Diagnostics.String_literal_expected);
                        links.resolvedSymbol = unknownSymbol;
                        return links.resolvedType = errorType;
                    }
                    const targetMeaning = node.isTypeOf ? 111551 /* Value */ : node.flags & 16777216 /* JSDoc */ ? 111551 /* Value */ | 788968 /* Type */ : 788968 /* Type */;
                    const innerModuleSymbol = resolveExternalModuleName(node, node.argument.literal);
                    if (!innerModuleSymbol) {
                        links.resolvedSymbol = unknownSymbol;
                        return links.resolvedType = errorType;
                    }
                    const isExportEquals = !!((_a = innerModuleSymbol.exports) == null ? void 0 : _a.get("export=" /* ExportEquals */));
                    const moduleSymbol = resolveExternalModuleSymbol(innerModuleSymbol, 
                    /*dontResolveAlias*/
                    false);
                    if (!nodeIsMissing(node.qualifier)) {
                        const nameStack = getIdentifierChain(node.qualifier);
                        let currentNamespace = moduleSymbol;
                        let current;
                        while (current = nameStack.shift()) {
                            const meaning = nameStack.length ? 1920 /* Namespace */ : targetMeaning;
                            const mergedResolvedSymbol = getMergedSymbol(resolveSymbol(currentNamespace));
                            const symbolFromVariable = node.isTypeOf || isInJSFile(node) && isExportEquals ? getPropertyOfType(getTypeOfSymbol(mergedResolvedSymbol), current.escapedText, 
                            /*skipObjectFunctionPropertyAugment*/
                            false, 
                            /*includeTypeOnlyMembers*/
                            true) : void 0;
                            const symbolFromModule = node.isTypeOf ? void 0 : getSymbol2(getExportsOfSymbol(mergedResolvedSymbol), current.escapedText, meaning);
                            const next = symbolFromModule ?? symbolFromVariable;
                            if (!next) {
                                error2(current, Diagnostics.Namespace_0_has_no_exported_member_1, getFullyQualifiedName(currentNamespace), declarationNameToString(current));
                                return links.resolvedType = errorType;
                            }
                            getNodeLinks(current).resolvedSymbol = next;
                            getNodeLinks(current.parent).resolvedSymbol = next;
                            currentNamespace = next;
                        }
                        links.resolvedType = resolveImportSymbolType(node, links, currentNamespace, targetMeaning);
                    }
                    else {
                        if (moduleSymbol.flags & targetMeaning) {
                            links.resolvedType = resolveImportSymbolType(node, links, moduleSymbol, targetMeaning);
                        }
                        else {
                            const errorMessage = targetMeaning === 111551 /* Value */ ? Diagnostics.Module_0_does_not_refer_to_a_value_but_is_used_as_a_value_here : Diagnostics.Module_0_does_not_refer_to_a_type_but_is_used_as_a_type_here_Did_you_mean_typeof_import_0;
                            error2(node, errorMessage, node.argument.literal.text);
                            links.resolvedSymbol = unknownSymbol;
                            links.resolvedType = errorType;
                        }
                    }
                }
                return links.resolvedType;
            }
            function resolveImportSymbolType(node, links, symbol, meaning) {
                const resolvedSymbol = resolveSymbol(symbol);
                links.resolvedSymbol = resolvedSymbol;
                if (meaning === 111551 /* Value */) {
                    return getInstantiationExpressionType(getTypeOfSymbol(symbol), node);
                }
                else {
                    return getTypeReferenceType(node, resolvedSymbol);
                }
            }
            function getTypeFromTypeLiteralOrFunctionOrConstructorTypeNode(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    const aliasSymbol = getAliasSymbolForTypeNode(node);
                    if (getMembersOfSymbol(node.symbol).size === 0 && !aliasSymbol) {
                        links.resolvedType = emptyTypeLiteralType;
                    }
                    else {
                        let type = createObjectType(16 /* Anonymous */, node.symbol);
                        type.aliasSymbol = aliasSymbol;
                        type.aliasTypeArguments = getTypeArgumentsForAliasSymbol(aliasSymbol);
                        if (isJSDocTypeLiteral(node) && node.isArrayType) {
                            type = createArrayType(type);
                        }
                        links.resolvedType = type;
                    }
                }
                return links.resolvedType;
            }
            function getAliasSymbolForTypeNode(node) {
                let host2 = node.parent;
                while (isParenthesizedTypeNode(host2) || isJSDocTypeExpression(host2) || isTypeOperatorNode(host2) && host2.operator === 148 /* ReadonlyKeyword */) {
                    host2 = host2.parent;
                }
                return isTypeAlias(host2) ? getSymbolOfDeclaration(host2) : void 0;
            }
            function getTypeArgumentsForAliasSymbol(symbol) {
                return symbol ? getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(symbol) : void 0;
            }
            function isNonGenericObjectType(type) {
                return !!(type.flags & 524288 /* Object */) && !isGenericMappedType(type);
            }
            function isEmptyObjectTypeOrSpreadsIntoEmptyObject(type) {
                return isEmptyObjectType(type) || !!(type.flags & (65536 /* Null */ | 32768 /* Undefined */ | 528 /* BooleanLike */ | 296 /* NumberLike */ | 2112 /* BigIntLike */ | 402653316 /* StringLike */ | 1056 /* EnumLike */ | 67108864 /* NonPrimitive */ | 4194304 /* Index */));
            }
            function tryMergeUnionOfObjectTypeAndEmptyObject(type, readonly) {
                if (!(type.flags & 1048576 /* Union */)) {
                    return type;
                }
                if (every(type.types, isEmptyObjectTypeOrSpreadsIntoEmptyObject)) {
                    return find(type.types, isEmptyObjectType) || emptyObjectType;
                }
                const firstType = find(type.types, (t) => !isEmptyObjectTypeOrSpreadsIntoEmptyObject(t));
                if (!firstType) {
                    return type;
                }
                const secondType = find(type.types, (t) => t !== firstType && !isEmptyObjectTypeOrSpreadsIntoEmptyObject(t));
                if (secondType) {
                    return type;
                }
                return getAnonymousPartialType(firstType);
                function getAnonymousPartialType(type2) {
                    const members = createSymbolTable();
                    for (const prop of getPropertiesOfType(type2)) {
                        if (getDeclarationModifierFlagsFromSymbol(prop) & (2 /* Private */ | 4 /* Protected */)) {
                        }
                        else if (isSpreadableProperty(prop)) {
                            const isSetonlyAccessor = prop.flags & 65536 /* SetAccessor */ && !(prop.flags & 32768 /* GetAccessor */);
                            const flags = 4 /* Property */ | 16777216 /* Optional */;
                            const result = createSymbol(flags, prop.escapedName, getIsLateCheckFlag(prop) | (readonly ? 8 /* Readonly */ : 0));
                            result.links.type = isSetonlyAccessor ? undefinedType : addOptionality(getTypeOfSymbol(prop), 
                            /*isProperty*/
                            true);
                            result.declarations = prop.declarations;
                            result.links.nameType = getSymbolLinks(prop).nameType;
                            result.links.syntheticOrigin = prop;
                            members.set(prop.escapedName, result);
                        }
                    }
                    const spread = createAnonymousType(type2.symbol, members, emptyArray, emptyArray, getIndexInfosOfType(type2));
                    spread.objectFlags |= 128 /* ObjectLiteral */ | 131072 /* ContainsObjectOrArrayLiteral */;
                    return spread;
                }
            }
            function getSpreadType(left, right, symbol, objectFlags, readonly) {
                if (left.flags & 1 /* Any */ || right.flags & 1 /* Any */) {
                    return anyType;
                }
                if (left.flags & 2 /* Unknown */ || right.flags & 2 /* Unknown */) {
                    return unknownType;
                }
                if (left.flags & 131072 /* Never */) {
                    return right;
                }
                if (right.flags & 131072 /* Never */) {
                    return left;
                }
                left = tryMergeUnionOfObjectTypeAndEmptyObject(left, readonly);
                if (left.flags & 1048576 /* Union */) {
                    return checkCrossProductUnion([left, right]) ? mapType(left, (t) => getSpreadType(t, right, symbol, objectFlags, readonly)) : errorType;
                }
                right = tryMergeUnionOfObjectTypeAndEmptyObject(right, readonly);
                if (right.flags & 1048576 /* Union */) {
                    return checkCrossProductUnion([left, right]) ? mapType(right, (t) => getSpreadType(left, t, symbol, objectFlags, readonly)) : errorType;
                }
                if (right.flags & (528 /* BooleanLike */ | 296 /* NumberLike */ | 2112 /* BigIntLike */ | 402653316 /* StringLike */ | 1056 /* EnumLike */ | 67108864 /* NonPrimitive */ | 4194304 /* Index */)) {
                    return left;
                }
                if (isGenericObjectType(left) || isGenericObjectType(right)) {
                    if (isEmptyObjectType(left)) {
                        return right;
                    }
                    if (left.flags & 2097152 /* Intersection */) {
                        const types = left.types;
                        const lastLeft = types[types.length - 1];
                        if (isNonGenericObjectType(lastLeft) && isNonGenericObjectType(right)) {
                            return getIntersectionType(concatenate(types.slice(0, types.length - 1), [getSpreadType(lastLeft, right, symbol, objectFlags, readonly)]));
                        }
                    }
                    return getIntersectionType([left, right]);
                }
                const members = createSymbolTable();
                const skippedPrivateMembers = /* @__PURE__ */ new Set();
                const indexInfos = left === emptyObjectType ? getIndexInfosOfType(right) : getUnionIndexInfos([left, right]);
                for (const rightProp of getPropertiesOfType(right)) {
                    if (getDeclarationModifierFlagsFromSymbol(rightProp) & (2 /* Private */ | 4 /* Protected */)) {
                        skippedPrivateMembers.add(rightProp.escapedName);
                    }
                    else if (isSpreadableProperty(rightProp)) {
                        members.set(rightProp.escapedName, getSpreadSymbol(rightProp, readonly));
                    }
                }
                for (const leftProp of getPropertiesOfType(left)) {
                    if (skippedPrivateMembers.has(leftProp.escapedName) || !isSpreadableProperty(leftProp)) {
                        continue;
                    }
                    if (members.has(leftProp.escapedName)) {
                        const rightProp = members.get(leftProp.escapedName);
                        const rightType = getTypeOfSymbol(rightProp);
                        if (rightProp.flags & 16777216 /* Optional */) {
                            const declarations = concatenate(leftProp.declarations, rightProp.declarations);
                            const flags = 4 /* Property */ | leftProp.flags & 16777216 /* Optional */;
                            const result = createSymbol(flags, leftProp.escapedName);
                            const leftType = getTypeOfSymbol(leftProp);
                            const leftTypeWithoutUndefined = removeMissingOrUndefinedType(leftType);
                            const rightTypeWithoutUndefined = removeMissingOrUndefinedType(rightType);
                            result.links.type = leftTypeWithoutUndefined === rightTypeWithoutUndefined ? leftType : getUnionType([leftType, rightTypeWithoutUndefined], 2 /* Subtype */);
                            result.links.leftSpread = leftProp;
                            result.links.rightSpread = rightProp;
                            result.declarations = declarations;
                            result.links.nameType = getSymbolLinks(leftProp).nameType;
                            members.set(leftProp.escapedName, result);
                        }
                    }
                    else {
                        members.set(leftProp.escapedName, getSpreadSymbol(leftProp, readonly));
                    }
                }
                const spread = createAnonymousType(symbol, members, emptyArray, emptyArray, sameMap(indexInfos, (info) => getIndexInfoWithReadonly(info, readonly)));
                spread.objectFlags |= 128 /* ObjectLiteral */ | 131072 /* ContainsObjectOrArrayLiteral */ | 2097152 /* ContainsSpread */ | objectFlags;
                return spread;
            }
            function isSpreadableProperty(prop) {
                var _a;
                return !some(prop.declarations, isPrivateIdentifierClassElementDeclaration) && (!(prop.flags & (8192 /* Method */ | 32768 /* GetAccessor */ | 65536 /* SetAccessor */)) || !((_a = prop.declarations) == null ? void 0 : _a.some((decl) => isClassLike(decl.parent))));
            }
            function getSpreadSymbol(prop, readonly) {
                const isSetonlyAccessor = prop.flags & 65536 /* SetAccessor */ && !(prop.flags & 32768 /* GetAccessor */);
                if (!isSetonlyAccessor && readonly === isReadonlySymbol(prop)) {
                    return prop;
                }
                const flags = 4 /* Property */ | prop.flags & 16777216 /* Optional */;
                const result = createSymbol(flags, prop.escapedName, getIsLateCheckFlag(prop) | (readonly ? 8 /* Readonly */ : 0));
                result.links.type = isSetonlyAccessor ? undefinedType : getTypeOfSymbol(prop);
                result.declarations = prop.declarations;
                result.links.nameType = getSymbolLinks(prop).nameType;
                result.links.syntheticOrigin = prop;
                return result;
            }
            function getIndexInfoWithReadonly(info, readonly) {
                return info.isReadonly !== readonly ? createIndexInfo(info.keyType, info.type, readonly, info.declaration) : info;
            }
            function createLiteralType(flags, value, symbol, regularType) {
                const type = createTypeWithSymbol(flags, symbol);
                type.value = value;
                type.regularType = regularType || type;
                return type;
            }
            function getFreshTypeOfLiteralType(type) {
                if (type.flags & 2976 /* Freshable */) {
                    if (!type.freshType) {
                        const freshType = createLiteralType(type.flags, type.value, type.symbol, type);
                        freshType.freshType = freshType;
                        type.freshType = freshType;
                    }
                    return type.freshType;
                }
                return type;
            }
            function getRegularTypeOfLiteralType(type) {
                return type.flags & 2976 /* Freshable */ ? type.regularType : type.flags & 1048576 /* Union */ ? type.regularType || (type.regularType = mapType(type, getRegularTypeOfLiteralType)) : type;
            }
            function isFreshLiteralType(type) {
                return !!(type.flags & 2976 /* Freshable */) && type.freshType === type;
            }
            function getStringLiteralType(value) {
                let type;
                return stringLiteralTypes.get(value) || (stringLiteralTypes.set(value, type = createLiteralType(128 /* StringLiteral */, value)), type);
            }
            function getNumberLiteralType(value) {
                let type;
                return numberLiteralTypes.get(value) || (numberLiteralTypes.set(value, type = createLiteralType(256 /* NumberLiteral */, value)), type);
            }
            function getBigIntLiteralType(value) {
                let type;
                const key = pseudoBigIntToString(value);
                return bigIntLiteralTypes.get(key) || (bigIntLiteralTypes.set(key, type = createLiteralType(2048 /* BigIntLiteral */, value)), type);
            }
            function getEnumLiteralType(value, enumId, symbol) {
                let type;
                const key = `${enumId}${typeof value === "string" ? "@" : "#"}${value}`;
                const flags = 1024 /* EnumLiteral */ | (typeof value === "string" ? 128 /* StringLiteral */ : 256 /* NumberLiteral */);
                return enumLiteralTypes.get(key) || (enumLiteralTypes.set(key, type = createLiteralType(flags, value, symbol)), type);
            }
            function getTypeFromLiteralTypeNode(node) {
                if (node.literal.kind === 106 /* NullKeyword */) {
                    return nullType;
                }
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    links.resolvedType = getRegularTypeOfLiteralType(checkExpression(node.literal));
                }
                return links.resolvedType;
            }
            function createUniqueESSymbolType(symbol) {
                const type = createTypeWithSymbol(8192 /* UniqueESSymbol */, symbol);
                type.escapedName = `__@${type.symbol.escapedName}@${getSymbolId(type.symbol)}`;
                return type;
            }
            function getESSymbolLikeTypeForNode(node) {
                if (isInJSFile(node) && isJSDocTypeExpression(node)) {
                    const host2 = getJSDocHost(node);
                    if (host2) {
                        node = getSingleVariableOfVariableStatement(host2) || host2;
                    }
                }
                if (isValidESSymbolDeclaration(node)) {
                    const symbol = isCommonJsExportPropertyAssignment(node) ? getSymbolOfNode(node.left) : getSymbolOfNode(node);
                    if (symbol) {
                        const links = getSymbolLinks(symbol);
                        return links.uniqueESSymbolType || (links.uniqueESSymbolType = createUniqueESSymbolType(symbol));
                    }
                }
                return esSymbolType;
            }
            function getThisType(node) {
                const container = getThisContainer(node, 
                /*includeArrowFunctions*/
                false, 
                /*includeClassComputedPropertyName*/
                false);
                const parent2 = container && container.parent;
                if (parent2 && (isClassLike(parent2) || parent2.kind === 264 /* InterfaceDeclaration */)) {
                    if (!isStatic(container) && (!isConstructorDeclaration(container) || isNodeDescendantOf(node, container.body))) {
                        return getDeclaredTypeOfClassOrInterface(getSymbolOfDeclaration(parent2)).thisType;
                    }
                }
                if (parent2 && isObjectLiteralExpression(parent2) && isBinaryExpression(parent2.parent) && getAssignmentDeclarationKind(parent2.parent) === 6 /* Prototype */) {
                    return getDeclaredTypeOfClassOrInterface(getSymbolOfNode(parent2.parent.left).parent).thisType;
                }
                const host2 = node.flags & 16777216 /* JSDoc */ ? getHostSignatureFromJSDoc(node) : void 0;
                if (host2 && isFunctionExpression(host2) && isBinaryExpression(host2.parent) && getAssignmentDeclarationKind(host2.parent) === 3 /* PrototypeProperty */) {
                    return getDeclaredTypeOfClassOrInterface(getSymbolOfNode(host2.parent.left).parent).thisType;
                }
                if (isJSConstructor(container) && isNodeDescendantOf(node, container.body)) {
                    return getDeclaredTypeOfClassOrInterface(getSymbolOfDeclaration(container)).thisType;
                }
                error2(node, Diagnostics.A_this_type_is_available_only_in_a_non_static_member_of_a_class_or_interface);
                return errorType;
            }
            function getTypeFromThisTypeNode(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    links.resolvedType = getThisType(node);
                }
                return links.resolvedType;
            }
            function getTypeFromRestTypeNode(node) {
                return getTypeFromTypeNode(getArrayElementTypeNode(node.type) || node.type);
            }
            function getArrayElementTypeNode(node) {
                switch (node.kind) {
                    case 196 /* ParenthesizedType */:
                        return getArrayElementTypeNode(node.type);
                    case 189 /* TupleType */:
                        if (node.elements.length === 1) {
                            node = node.elements[0];
                            if (node.kind === 191 /* RestType */ || node.kind === 202 /* NamedTupleMember */ && node.dotDotDotToken) {
                                return getArrayElementTypeNode(node.type);
                            }
                        }
                        break;
                    case 188 /* ArrayType */:
                        return node.elementType;
                }
                return void 0;
            }
            function getTypeFromNamedTupleTypeNode(node) {
                const links = getNodeLinks(node);
                return links.resolvedType || (links.resolvedType = node.dotDotDotToken ? getTypeFromRestTypeNode(node) : addOptionality(getTypeFromTypeNode(node.type), 
                /*isProperty*/
                true, !!node.questionToken));
            }
            function getTypeFromTypeNode(node) {
                return getConditionalFlowTypeOfType(getTypeFromTypeNodeWorker(node), node);
            }
            function getTypeFromTypeNodeWorker(node) {
                switch (node.kind) {
                    case 133 /* AnyKeyword */:
                    case 319 /* JSDocAllType */:
                    case 320 /* JSDocUnknownType */:
                        return anyType;
                    case 159 /* UnknownKeyword */:
                        return unknownType;
                    case 154 /* StringKeyword */:
                        return stringType;
                    case 150 /* NumberKeyword */:
                        return numberType;
                    case 163 /* BigIntKeyword */:
                        return bigintType;
                    case 136 /* BooleanKeyword */:
                        return booleanType;
                    case 155 /* SymbolKeyword */:
                        return esSymbolType;
                    case 116 /* VoidKeyword */:
                        return voidType;
                    case 157 /* UndefinedKeyword */:
                        return undefinedType;
                    case 106 /* NullKeyword */:
                        return nullType;
                    case 146 /* NeverKeyword */:
                        return neverType;
                    case 151 /* ObjectKeyword */:
                        return node.flags & 524288 /* JavaScriptFile */ && !noImplicitAny ? anyType : nonPrimitiveType;
                    case 141 /* IntrinsicKeyword */:
                        return intrinsicMarkerType;
                    case 197 /* ThisType */:
                    case 110 /* ThisKeyword */:
                        return getTypeFromThisTypeNode(node);
                    case 201 /* LiteralType */:
                        return getTypeFromLiteralTypeNode(node);
                    case 183 /* TypeReference */:
                        return getTypeFromTypeReference(node);
                    case 182 /* TypePredicate */:
                        return node.assertsModifier ? voidType : booleanType;
                    case 233 /* ExpressionWithTypeArguments */:
                        return getTypeFromTypeReference(node);
                    case 186 /* TypeQuery */:
                        return getTypeFromTypeQueryNode(node);
                    case 188 /* ArrayType */:
                    case 189 /* TupleType */:
                        return getTypeFromArrayOrTupleTypeNode(node);
                    case 190 /* OptionalType */:
                        return getTypeFromOptionalTypeNode(node);
                    case 192 /* UnionType */:
                        return getTypeFromUnionTypeNode(node);
                    case 193 /* IntersectionType */:
                        return getTypeFromIntersectionTypeNode(node);
                    case 321 /* JSDocNullableType */:
                        return getTypeFromJSDocNullableTypeNode(node);
                    case 323 /* JSDocOptionalType */:
                        return addOptionality(getTypeFromTypeNode(node.type));
                    case 202 /* NamedTupleMember */:
                        return getTypeFromNamedTupleTypeNode(node);
                    case 196 /* ParenthesizedType */:
                    case 322 /* JSDocNonNullableType */:
                    case 316 /* JSDocTypeExpression */:
                        return getTypeFromTypeNode(node.type);
                    case 191 /* RestType */:
                        return getTypeFromRestTypeNode(node);
                    case 325 /* JSDocVariadicType */:
                        return getTypeFromJSDocVariadicType(node);
                    case 184 /* FunctionType */:
                    case 185 /* ConstructorType */:
                    case 187 /* TypeLiteral */:
                    case 329 /* JSDocTypeLiteral */:
                    case 324 /* JSDocFunctionType */:
                    case 330 /* JSDocSignature */:
                        return getTypeFromTypeLiteralOrFunctionOrConstructorTypeNode(node);
                    case 198 /* TypeOperator */:
                        return getTypeFromTypeOperatorNode(node);
                    case 199 /* IndexedAccessType */:
                        return getTypeFromIndexedAccessTypeNode(node);
                    case 200 /* MappedType */:
                        return getTypeFromMappedTypeNode(node);
                    case 194 /* ConditionalType */:
                        return getTypeFromConditionalTypeNode(node);
                    case 195 /* InferType */:
                        return getTypeFromInferTypeNode(node);
                    case 203 /* TemplateLiteralType */:
                        return getTypeFromTemplateTypeNode(node);
                    case 205 /* ImportType */:
                        return getTypeFromImportTypeNode(node);
                    case 80 /* Identifier */:
                    case 166 /* QualifiedName */:
                    case 211 /* PropertyAccessExpression */:
                        const symbol = getSymbolAtLocation(node);
                        return symbol ? getDeclaredTypeOfSymbol(symbol) : errorType;
                    default:
                        return errorType;
                }
            }
            function instantiateList(items, mapper, instantiator) {
                if (items && items.length) {
                    for (let i = 0; i < items.length; i++) {
                        const item = items[i];
                        const mapped = instantiator(item, mapper);
                        if (item !== mapped) {
                            const result = i === 0 ? [] : items.slice(0, i);
                            result.push(mapped);
                            for (i++; i < items.length; i++) {
                                result.push(instantiator(items[i], mapper));
                            }
                            return result;
                        }
                    }
                }
                return items;
            }
            function instantiateTypes(types, mapper) {
                return instantiateList(types, mapper, instantiateType);
            }
            function instantiateSignatures(signatures, mapper) {
                return instantiateList(signatures, mapper, instantiateSignature);
            }
            function instantiateIndexInfos(indexInfos, mapper) {
                return instantiateList(indexInfos, mapper, instantiateIndexInfo);
            }
            function createTypeMapper(sources, targets) {
                return sources.length === 1 ? makeUnaryTypeMapper(sources[0], targets ? targets[0] : anyType) : makeArrayTypeMapper(sources, targets);
            }
            function getMappedType(type, mapper) {
                switch (mapper.kind) {
                    case 0 /* Simple */:
                        return type === mapper.source ? mapper.target : type;
                    case 1 /* Array */: {
                        const sources = mapper.sources;
                        const targets = mapper.targets;
                        for (let i = 0; i < sources.length; i++) {
                            if (type === sources[i]) {
                                return targets ? targets[i] : anyType;
                            }
                        }
                        return type;
                    }
                    case 2 /* Deferred */: {
                        const sources = mapper.sources;
                        const targets = mapper.targets;
                        for (let i = 0; i < sources.length; i++) {
                            if (type === sources[i]) {
                                return targets[i]();
                            }
                        }
                        return type;
                    }
                    case 3 /* Function */:
                        return mapper.func(type);
                    case 4 /* Composite */:
                    case 5 /* Merged */:
                        const t1 = getMappedType(type, mapper.mapper1);
                        return t1 !== type && mapper.kind === 4 /* Composite */ ? instantiateType(t1, mapper.mapper2) : getMappedType(t1, mapper.mapper2);
                }
            }
            function makeUnaryTypeMapper(source, target) {
                return Debug.attachDebugPrototypeIfDebug({ kind: 0 /* Simple */, source, target });
            }
            function makeArrayTypeMapper(sources, targets) {
                return Debug.attachDebugPrototypeIfDebug({ kind: 1 /* Array */, sources, targets });
            }
            function makeFunctionTypeMapper(func, debugInfo) {
                return Debug.attachDebugPrototypeIfDebug({ kind: 3 /* Function */, func, debugInfo: Debug.isDebugging ? debugInfo : void 0 });
            }
            function makeDeferredTypeMapper(sources, targets) {
                return Debug.attachDebugPrototypeIfDebug({ kind: 2 /* Deferred */, sources, targets });
            }
            function makeCompositeTypeMapper(kind, mapper1, mapper2) {
                return Debug.attachDebugPrototypeIfDebug({ kind, mapper1, mapper2 });
            }
            function createTypeEraser(sources) {
                return createTypeMapper(sources, 
                /*targets*/
                void 0);
            }
            function createBackreferenceMapper(context, index) {
                const forwardInferences = context.inferences.slice(index);
                return createTypeMapper(map(forwardInferences, (i) => i.typeParameter), map(forwardInferences, () => unknownType));
            }
            function combineTypeMappers(mapper1, mapper2) {
                return mapper1 ? makeCompositeTypeMapper(4 /* Composite */, mapper1, mapper2) : mapper2;
            }
            function mergeTypeMappers(mapper1, mapper2) {
                return mapper1 ? makeCompositeTypeMapper(5 /* Merged */, mapper1, mapper2) : mapper2;
            }
            function prependTypeMapping(source, target, mapper) {
                return !mapper ? makeUnaryTypeMapper(source, target) : makeCompositeTypeMapper(5 /* Merged */, makeUnaryTypeMapper(source, target), mapper);
            }
            function appendTypeMapping(mapper, source, target) {
                return !mapper ? makeUnaryTypeMapper(source, target) : makeCompositeTypeMapper(5 /* Merged */, mapper, makeUnaryTypeMapper(source, target));
            }
            function getRestrictiveTypeParameter(tp) {
                return !tp.constraint && !getConstraintDeclaration(tp) || tp.constraint === noConstraintType ? tp : tp.restrictiveInstantiation || (tp.restrictiveInstantiation = createTypeParameter(tp.symbol), tp.restrictiveInstantiation.constraint = noConstraintType, tp.restrictiveInstantiation);
            }
            function cloneTypeParameter(typeParameter) {
                const result = createTypeParameter(typeParameter.symbol);
                result.target = typeParameter;
                return result;
            }
            function instantiateTypePredicate(predicate, mapper) {
                return createTypePredicate(predicate.kind, predicate.parameterName, predicate.parameterIndex, instantiateType(predicate.type, mapper));
            }
            function instantiateSignature(signature, mapper, eraseTypeParameters) {
                let freshTypeParameters;
                if (signature.typeParameters && !eraseTypeParameters) {
                    freshTypeParameters = map(signature.typeParameters, cloneTypeParameter);
                    mapper = combineTypeMappers(createTypeMapper(signature.typeParameters, freshTypeParameters), mapper);
                    for (const tp of freshTypeParameters) {
                        tp.mapper = mapper;
                    }
                }
                const result = createSignature(signature.declaration, freshTypeParameters, signature.thisParameter && instantiateSymbol(signature.thisParameter, mapper), instantiateList(signature.parameters, mapper, instantiateSymbol), 
                /*resolvedReturnType*/
                void 0, 
                /*resolvedTypePredicate*/
                void 0, signature.minArgumentCount, signature.flags & 167 /* PropagatingFlags */);
                result.target = signature;
                result.mapper = mapper;
                return result;
            }
            function instantiateSymbol(symbol, mapper) {
                const links = getSymbolLinks(symbol);
                if (links.type && !couldContainTypeVariables(links.type)) {
                    if (!(symbol.flags & 65536 /* SetAccessor */)) {
                        return symbol;
                    }
                    if (links.writeType && !couldContainTypeVariables(links.writeType)) {
                        return symbol;
                    }
                }
                if (getCheckFlags(symbol) & 1 /* Instantiated */) {
                    symbol = links.target;
                    mapper = combineTypeMappers(links.mapper, mapper);
                }
                const result = createSymbol(symbol.flags, symbol.escapedName, 1 /* Instantiated */ | getCheckFlags(symbol) & (8 /* Readonly */ | 4096 /* Late */ | 16384 /* OptionalParameter */ | 32768 /* RestParameter */));
                result.declarations = symbol.declarations;
                result.parent = symbol.parent;
                result.links.target = symbol;
                result.links.mapper = mapper;
                if (symbol.valueDeclaration) {
                    result.valueDeclaration = symbol.valueDeclaration;
                }
                if (links.nameType) {
                    result.links.nameType = links.nameType;
                }
                return result;
            }
            function getObjectTypeInstantiation(type, mapper, aliasSymbol, aliasTypeArguments) {
                const declaration = type.objectFlags & 4 /* Reference */ ? type.node : type.objectFlags & 8388608 /* InstantiationExpressionType */ ? type.node : type.symbol.declarations[0];
                const links = getNodeLinks(declaration);
                const target = type.objectFlags & 4 /* Reference */ ? links.resolvedType : type.objectFlags & 64 /* Instantiated */ ? type.target : type;
                let typeParameters = links.outerTypeParameters;
                if (!typeParameters) {
                    let outerTypeParameters = getOuterTypeParameters(declaration, 
                    /*includeThisTypes*/
                    true);
                    if (isJSConstructor(declaration)) {
                        const templateTagParameters = getTypeParametersFromDeclaration(declaration);
                        outerTypeParameters = addRange(outerTypeParameters, templateTagParameters);
                    }
                    typeParameters = outerTypeParameters || emptyArray;
                    const allDeclarations = type.objectFlags & (4 /* Reference */ | 8388608 /* InstantiationExpressionType */) ? [declaration] : type.symbol.declarations;
                    typeParameters = (target.objectFlags & (4 /* Reference */ | 8388608 /* InstantiationExpressionType */) || target.symbol.flags & 8192 /* Method */ || target.symbol.flags & 2048 /* TypeLiteral */) && !target.aliasTypeArguments ? filter(typeParameters, (tp) => some(allDeclarations, (d) => isTypeParameterPossiblyReferenced(tp, d))) : typeParameters;
                    links.outerTypeParameters = typeParameters;
                }
                if (typeParameters.length) {
                    const combinedMapper = combineTypeMappers(type.mapper, mapper);
                    const typeArguments = map(typeParameters, (t) => getMappedType(t, combinedMapper));
                    const newAliasSymbol = aliasSymbol || type.aliasSymbol;
                    const newAliasTypeArguments = aliasSymbol ? aliasTypeArguments : instantiateTypes(type.aliasTypeArguments, mapper);
                    const id = getTypeListId(typeArguments) + getAliasId(newAliasSymbol, newAliasTypeArguments);
                    if (!target.instantiations) {
                        target.instantiations = /* @__PURE__ */ new Map();
                        target.instantiations.set(getTypeListId(typeParameters) + getAliasId(target.aliasSymbol, target.aliasTypeArguments), target);
                    }
                    let result = target.instantiations.get(id);
                    if (!result) {
                        const newMapper = createTypeMapper(typeParameters, typeArguments);
                        result = target.objectFlags & 4 /* Reference */ ? createDeferredTypeReference(type.target, type.node, newMapper, newAliasSymbol, newAliasTypeArguments) : target.objectFlags & 32 /* Mapped */ ? instantiateMappedType(target, newMapper, newAliasSymbol, newAliasTypeArguments) : instantiateAnonymousType(target, newMapper, newAliasSymbol, newAliasTypeArguments);
                        target.instantiations.set(id, result);
                        const resultObjectFlags = getObjectFlags(result);
                        if (result.flags & 3899393 /* ObjectFlagsType */ && !(resultObjectFlags & 524288 /* CouldContainTypeVariablesComputed */)) {
                            const resultCouldContainTypeVariables = some(typeArguments, couldContainTypeVariables);
                            if (!(getObjectFlags(result) & 524288 /* CouldContainTypeVariablesComputed */)) {
                                if (resultObjectFlags & (32 /* Mapped */ | 16 /* Anonymous */ | 4 /* Reference */)) {
                                    result.objectFlags |= 524288 /* CouldContainTypeVariablesComputed */ | (resultCouldContainTypeVariables ? 1048576 /* CouldContainTypeVariables */ : 0);
                                }
                                else {
                                    result.objectFlags |= !resultCouldContainTypeVariables ? 524288 /* CouldContainTypeVariablesComputed */ : 0;
                                }
                            }
                        }
                    }
                    return result;
                }
                return type;
            }
            function maybeTypeParameterReference(node) {
                return !(node.parent.kind === 183 /* TypeReference */ && node.parent.typeArguments && node === node.parent.typeName || node.parent.kind === 205 /* ImportType */ && node.parent.typeArguments && node === node.parent.qualifier);
            }
            function isTypeParameterPossiblyReferenced(tp, node) {
                if (tp.symbol && tp.symbol.declarations && tp.symbol.declarations.length === 1) {
                    const container = tp.symbol.declarations[0].parent;
                    for (let n = node; n !== container; n = n.parent) {
                        if (!n || n.kind === 241 /* Block */ || n.kind === 194 /* ConditionalType */ && forEachChild(n.extendsType, containsReference)) {
                            return true;
                        }
                    }
                    return containsReference(node);
                }
                return true;
                function containsReference(node2) {
                    switch (node2.kind) {
                        case 197 /* ThisType */:
                            return !!tp.isThisType;
                        case 80 /* Identifier */:
                            return !tp.isThisType && isPartOfTypeNode(node2) && maybeTypeParameterReference(node2) && getTypeFromTypeNodeWorker(node2) === tp;
                        case 186 /* TypeQuery */:
                            const entityName = node2.exprName;
                            const firstIdentifier = getFirstIdentifier(entityName);
                            if (!isThisIdentifier(firstIdentifier)) {
                                const firstIdentifierSymbol = getResolvedSymbol(firstIdentifier);
                                const tpDeclaration = tp.symbol.declarations[0];
                                const tpScope = tpDeclaration.kind === 168 /* TypeParameter */ ? tpDeclaration.parent : (
                                // Type parameter is a regular type parameter, e.g. foo<T>
                                tp.isThisType ? tpDeclaration : (
                                // Type parameter is the this type, and its declaration is the class declaration.
                                void 0));
                                if (firstIdentifierSymbol.declarations && tpScope) {
                                    return some(firstIdentifierSymbol.declarations, (idDecl) => isNodeDescendantOf(idDecl, tpScope)) || some(node2.typeArguments, containsReference);
                                }
                            }
                            return true;
                        case 174 /* MethodDeclaration */:
                        case 173 /* MethodSignature */:
                            return !node2.type && !!node2.body || some(node2.typeParameters, containsReference) || some(node2.parameters, containsReference) || !!node2.type && containsReference(node2.type);
                    }
                    return !!forEachChild(node2, containsReference);
                }
            }
            function getHomomorphicTypeVariable(type) {
                const constraintType = getConstraintTypeFromMappedType(type);
                if (constraintType.flags & 4194304 /* Index */) {
                    const typeVariable = getActualTypeVariable(constraintType.type);
                    if (typeVariable.flags & 262144 /* TypeParameter */) {
                        return typeVariable;
                    }
                }
                return void 0;
            }
            function instantiateMappedType(type, mapper, aliasSymbol, aliasTypeArguments) {
                const typeVariable = getHomomorphicTypeVariable(type);
                if (typeVariable) {
                    const mappedTypeVariable = instantiateType(typeVariable, mapper);
                    if (typeVariable !== mappedTypeVariable) {
                        return mapTypeWithAlias(getReducedType(mappedTypeVariable), instantiateConstituent, aliasSymbol, aliasTypeArguments);
                    }
                }
                return instantiateType(getConstraintTypeFromMappedType(type), mapper) === wildcardType ? wildcardType : instantiateAnonymousType(type, mapper, aliasSymbol, aliasTypeArguments);
                function instantiateConstituent(t) {
                    if (t.flags & (3 /* AnyOrUnknown */ | 58982400 /* InstantiableNonPrimitive */ | 524288 /* Object */ | 2097152 /* Intersection */) && t !== wildcardType && !isErrorType(t)) {
                        if (!type.declaration.nameType) {
                            let constraint;
                            if (isArrayType(t) || t.flags & 1 /* Any */ && findResolutionCycleStartIndex(typeVariable, 4 /* ImmediateBaseConstraint */) < 0 && (constraint = getConstraintOfTypeParameter(typeVariable)) && everyType(constraint, isArrayOrTupleType)) {
                                return instantiateMappedArrayType(t, type, prependTypeMapping(typeVariable, t, mapper));
                            }
                            if (isTupleType(t)) {
                                return instantiateMappedTupleType(t, type, typeVariable, mapper);
                            }
                            if (isArrayOrTupleOrIntersection(t)) {
                                return getIntersectionType(map(t.types, instantiateConstituent));
                            }
                        }
                        return instantiateAnonymousType(type, prependTypeMapping(typeVariable, t, mapper));
                    }
                    return t;
                }
            }
            function getModifiedReadonlyState(state, modifiers) {
                return modifiers & 1 /* IncludeReadonly */ ? true : modifiers & 2 /* ExcludeReadonly */ ? false : state;
            }
            function instantiateMappedTupleType(tupleType, mappedType, typeVariable, mapper) {
                const elementFlags = tupleType.target.elementFlags;
                const fixedLength = tupleType.target.fixedLength;
                const fixedMapper = fixedLength ? prependTypeMapping(typeVariable, tupleType, mapper) : mapper;
                const newElementTypes = map(getElementTypes(tupleType), (type, i) => {
                    const flags = elementFlags[i];
                    return i < fixedLength ? instantiateMappedTypeTemplate(mappedType, getStringLiteralType("" + i), !!(flags & 2 /* Optional */), fixedMapper) : flags & 8 /* Variadic */ ? instantiateType(mappedType, prependTypeMapping(typeVariable, type, mapper)) : getElementTypeOfArrayType(instantiateType(mappedType, prependTypeMapping(typeVariable, createArrayType(type), mapper))) ?? unknownType;
                });
                const modifiers = getMappedTypeModifiers(mappedType);
                const newElementFlags = modifiers & 4 /* IncludeOptional */ ? map(elementFlags, (f) => f & 1 /* Required */ ? 2 /* Optional */ : f) : modifiers & 8 /* ExcludeOptional */ ? map(elementFlags, (f) => f & 2 /* Optional */ ? 1 /* Required */ : f) : elementFlags;
                const newReadonly = getModifiedReadonlyState(tupleType.target.readonly, getMappedTypeModifiers(mappedType));
                return contains(newElementTypes, errorType) ? errorType : createTupleType(newElementTypes, newElementFlags, newReadonly, tupleType.target.labeledElementDeclarations);
            }
            function instantiateMappedArrayType(arrayType, mappedType, mapper) {
                const elementType = instantiateMappedTypeTemplate(mappedType, numberType, 
                /*isOptional*/
                true, mapper);
                return isErrorType(elementType) ? errorType : createArrayType(elementType, getModifiedReadonlyState(isReadonlyArrayType(arrayType), getMappedTypeModifiers(mappedType)));
            }
            function instantiateMappedTypeTemplate(type, key, isOptional, mapper) {
                const templateMapper = appendTypeMapping(mapper, getTypeParameterFromMappedType(type), key);
                const propType = instantiateType(getTemplateTypeFromMappedType(type.target || type), templateMapper);
                const modifiers = getMappedTypeModifiers(type);
                return strictNullChecks && modifiers & 4 /* IncludeOptional */ && !maybeTypeOfKind(propType, 32768 /* Undefined */ | 16384 /* Void */) ? getOptionalType(propType, 
                /*isProperty*/
                true) : strictNullChecks && modifiers & 8 /* ExcludeOptional */ && isOptional ? getTypeWithFacts(propType, 524288 /* NEUndefined */) : propType;
            }
            function instantiateAnonymousType(type, mapper, aliasSymbol, aliasTypeArguments) {
                Debug.assert(type.symbol, "anonymous type must have symbol to be instantiated");
                const result = createObjectType(type.objectFlags & ~(524288 /* CouldContainTypeVariablesComputed */ | 1048576 /* CouldContainTypeVariables */) | 64 /* Instantiated */, type.symbol);
                if (type.objectFlags & 32 /* Mapped */) {
                    result.declaration = type.declaration;
                    const origTypeParameter = getTypeParameterFromMappedType(type);
                    const freshTypeParameter = cloneTypeParameter(origTypeParameter);
                    result.typeParameter = freshTypeParameter;
                    mapper = combineTypeMappers(makeUnaryTypeMapper(origTypeParameter, freshTypeParameter), mapper);
                    freshTypeParameter.mapper = mapper;
                }
                if (type.objectFlags & 8388608 /* InstantiationExpressionType */) {
                    result.node = type.node;
                }
                result.target = type;
                result.mapper = mapper;
                result.aliasSymbol = aliasSymbol || type.aliasSymbol;
                result.aliasTypeArguments = aliasSymbol ? aliasTypeArguments : instantiateTypes(type.aliasTypeArguments, mapper);
                result.objectFlags |= result.aliasTypeArguments ? getPropagatingFlagsOfTypes(result.aliasTypeArguments) : 0;
                return result;
            }
            function getConditionalTypeInstantiation(type, mapper, forConstraint, aliasSymbol, aliasTypeArguments) {
                const root = type.root;
                if (root.outerTypeParameters) {
                    const typeArguments = map(root.outerTypeParameters, (t) => getMappedType(t, mapper));
                    const id = (forConstraint ? "C" : "") + getTypeListId(typeArguments) + getAliasId(aliasSymbol, aliasTypeArguments);
                    let result = root.instantiations.get(id);
                    if (!result) {
                        const newMapper = createTypeMapper(root.outerTypeParameters, typeArguments);
                        const checkType = root.checkType;
                        const distributionType = root.isDistributive ? getReducedType(getMappedType(checkType, newMapper)) : void 0;
                        result = distributionType && checkType !== distributionType && distributionType.flags & (1048576 /* Union */ | 131072 /* Never */) ? mapTypeWithAlias(distributionType, (t) => getConditionalType(root, prependTypeMapping(checkType, t, newMapper), forConstraint), aliasSymbol, aliasTypeArguments) : getConditionalType(root, newMapper, forConstraint, aliasSymbol, aliasTypeArguments);
                        root.instantiations.set(id, result);
                    }
                    return result;
                }
                return type;
            }
            function instantiateType(type, mapper) {
                return type && mapper ? instantiateTypeWithAlias(type, mapper, 
                /*aliasSymbol*/
                void 0, 
                /*aliasTypeArguments*/
                void 0) : type;
            }
            function instantiateTypeWithAlias(type, mapper, aliasSymbol, aliasTypeArguments) {
                var _a;
                if (!couldContainTypeVariables(type)) {
                    return type;
                }
                if (instantiationDepth === 100 || instantiationCount >= 5e6) {
                    (_a = tracing) == null ? void 0 : _a.instant(tracing.Phase.CheckTypes, "instantiateType_DepthLimit", { typeId: type.id, instantiationDepth, instantiationCount });
                    error2(currentNode, Diagnostics.Type_instantiation_is_excessively_deep_and_possibly_infinite);
                    return errorType;
                }
                totalInstantiationCount++;
                instantiationCount++;
                instantiationDepth++;
                const result = instantiateTypeWorker(type, mapper, aliasSymbol, aliasTypeArguments);
                instantiationDepth--;
                return result;
            }
            function instantiateTypeWorker(type, mapper, aliasSymbol, aliasTypeArguments) {
                const flags = type.flags;
                if (flags & 262144 /* TypeParameter */) {
                    return getMappedType(type, mapper);
                }
                if (flags & 524288 /* Object */) {
                    const objectFlags = type.objectFlags;
                    if (objectFlags & (4 /* Reference */ | 16 /* Anonymous */ | 32 /* Mapped */)) {
                        if (objectFlags & 4 /* Reference */ && !type.node) {
                            const resolvedTypeArguments = type.resolvedTypeArguments;
                            const newTypeArguments = instantiateTypes(resolvedTypeArguments, mapper);
                            return newTypeArguments !== resolvedTypeArguments ? createNormalizedTypeReference(type.target, newTypeArguments) : type;
                        }
                        if (objectFlags & 1024 /* ReverseMapped */) {
                            return instantiateReverseMappedType(type, mapper);
                        }
                        return getObjectTypeInstantiation(type, mapper, aliasSymbol, aliasTypeArguments);
                    }
                    return type;
                }
                if (flags & 3145728 /* UnionOrIntersection */) {
                    const origin = type.flags & 1048576 /* Union */ ? type.origin : void 0;
                    const types = origin && origin.flags & 3145728 /* UnionOrIntersection */ ? origin.types : type.types;
                    const newTypes = instantiateTypes(types, mapper);
                    if (newTypes === types && aliasSymbol === type.aliasSymbol) {
                        return type;
                    }
                    const newAliasSymbol = aliasSymbol || type.aliasSymbol;
                    const newAliasTypeArguments = aliasSymbol ? aliasTypeArguments : instantiateTypes(type.aliasTypeArguments, mapper);
                    return flags & 2097152 /* Intersection */ || origin && origin.flags & 2097152 /* Intersection */ ? getIntersectionType(newTypes, newAliasSymbol, newAliasTypeArguments) : getUnionType(newTypes, 1 /* Literal */, newAliasSymbol, newAliasTypeArguments);
                }
                if (flags & 4194304 /* Index */) {
                    return getIndexType(instantiateType(type.type, mapper));
                }
                if (flags & 134217728 /* TemplateLiteral */) {
                    return getTemplateLiteralType(type.texts, instantiateTypes(type.types, mapper));
                }
                if (flags & 268435456 /* StringMapping */) {
                    return getStringMappingType(type.symbol, instantiateType(type.type, mapper));
                }
                if (flags & 8388608 /* IndexedAccess */) {
                    const newAliasSymbol = aliasSymbol || type.aliasSymbol;
                    const newAliasTypeArguments = aliasSymbol ? aliasTypeArguments : instantiateTypes(type.aliasTypeArguments, mapper);
                    return getIndexedAccessType(instantiateType(type.objectType, mapper), instantiateType(type.indexType, mapper), type.accessFlags, 
                    /*accessNode*/
                    void 0, newAliasSymbol, newAliasTypeArguments);
                }
                if (flags & 16777216 /* Conditional */) {
                    return getConditionalTypeInstantiation(type, combineTypeMappers(type.mapper, mapper), 
                    /*forConstraint*/
                    false, aliasSymbol, aliasTypeArguments);
                }
                if (flags & 33554432 /* Substitution */) {
                    const newBaseType = instantiateType(type.baseType, mapper);
                    if (isNoInferType(type)) {
                        return getNoInferType(newBaseType);
                    }
                    const newConstraint = instantiateType(type.constraint, mapper);
                    if (newBaseType.flags & 8650752 /* TypeVariable */ && isGenericType(newConstraint)) {
                        return getSubstitutionType(newBaseType, newConstraint);
                    }
                    if (newConstraint.flags & 3 /* AnyOrUnknown */ || isTypeAssignableTo(getRestrictiveInstantiation(newBaseType), getRestrictiveInstantiation(newConstraint))) {
                        return newBaseType;
                    }
                    return newBaseType.flags & 8650752 /* TypeVariable */ ? getSubstitutionType(newBaseType, newConstraint) : getIntersectionType([newConstraint, newBaseType]);
                }
                return type;
            }
            function instantiateReverseMappedType(type, mapper) {
                const innerMappedType = instantiateType(type.mappedType, mapper);
                if (!(getObjectFlags(innerMappedType) & 32 /* Mapped */)) {
                    return type;
                }
                const innerIndexType = instantiateType(type.constraintType, mapper);
                if (!(innerIndexType.flags & 4194304 /* Index */)) {
                    return type;
                }
                const instantiated = inferTypeForHomomorphicMappedType(instantiateType(type.source, mapper), innerMappedType, innerIndexType);
                if (instantiated) {
                    return instantiated;
                }
                return type;
            }
            function getPermissiveInstantiation(type) {
                return type.flags & (402784252 /* Primitive */ | 3 /* AnyOrUnknown */ | 131072 /* Never */) ? type : type.permissiveInstantiation || (type.permissiveInstantiation = instantiateType(type, permissiveMapper));
            }
            function getRestrictiveInstantiation(type) {
                if (type.flags & (402784252 /* Primitive */ | 3 /* AnyOrUnknown */ | 131072 /* Never */)) {
                    return type;
                }
                if (type.restrictiveInstantiation) {
                    return type.restrictiveInstantiation;
                }
                type.restrictiveInstantiation = instantiateType(type, restrictiveMapper);
                type.restrictiveInstantiation.restrictiveInstantiation = type.restrictiveInstantiation;
                return type.restrictiveInstantiation;
            }
            function instantiateIndexInfo(info, mapper) {
                return createIndexInfo(info.keyType, instantiateType(info.type, mapper), info.isReadonly, info.declaration);
            }
            function isContextSensitive(node) {
                Debug.assert(node.kind !== 174 /* MethodDeclaration */ || isObjectLiteralMethod(node));
                switch (node.kind) {
                    case 218 /* FunctionExpression */:
                    case 219 /* ArrowFunction */:
                    case 174 /* MethodDeclaration */:
                    case 262 /* FunctionDeclaration */:
                        return isContextSensitiveFunctionLikeDeclaration(node);
                    case 210 /* ObjectLiteralExpression */:
                        return some(node.properties, isContextSensitive);
                    case 209 /* ArrayLiteralExpression */:
                        return some(node.elements, isContextSensitive);
                    case 227 /* ConditionalExpression */:
                        return isContextSensitive(node.whenTrue) || isContextSensitive(node.whenFalse);
                    case 226 /* BinaryExpression */:
                        return (node.operatorToken.kind === 57 /* BarBarToken */ || node.operatorToken.kind === 61 /* QuestionQuestionToken */) && (isContextSensitive(node.left) || isContextSensitive(node.right));
                    case 303 /* PropertyAssignment */:
                        return isContextSensitive(node.initializer);
                    case 217 /* ParenthesizedExpression */:
                        return isContextSensitive(node.expression);
                    case 292 /* JsxAttributes */:
                        return some(node.properties, isContextSensitive) || isJsxOpeningElement(node.parent) && some(node.parent.parent.children, isContextSensitive);
                    case 291 /* JsxAttribute */: {
                        const { initializer } = node;
                        return !!initializer && isContextSensitive(initializer);
                    }
                    case 294 /* JsxExpression */: {
                        const { expression } = node;
                        return !!expression && isContextSensitive(expression);
                    }
                }
                return false;
            }
            function isContextSensitiveFunctionLikeDeclaration(node) {
                return hasContextSensitiveParameters(node) || hasContextSensitiveReturnExpression(node);
            }
            function hasContextSensitiveReturnExpression(node) {
                if (node.typeParameters || getEffectiveReturnTypeNode(node) || !node.body) {
                    return false;
                }
                if (node.body.kind !== 241 /* Block */) {
                    return isContextSensitive(node.body);
                }
                return !!forEachReturnStatement(node.body, (statement) => !!statement.expression && isContextSensitive(statement.expression));
            }
            function isContextSensitiveFunctionOrObjectLiteralMethod(func) {
                return (isFunctionExpressionOrArrowFunction(func) || isObjectLiteralMethod(func)) && isContextSensitiveFunctionLikeDeclaration(func);
            }
            function getTypeWithoutSignatures(type) {
                if (type.flags & 524288 /* Object */) {
                    const resolved = resolveStructuredTypeMembers(type);
                    if (resolved.constructSignatures.length || resolved.callSignatures.length) {
                        const result = createObjectType(16 /* Anonymous */, type.symbol);
                        result.members = resolved.members;
                        result.properties = resolved.properties;
                        result.callSignatures = emptyArray;
                        result.constructSignatures = emptyArray;
                        result.indexInfos = emptyArray;
                        return result;
                    }
                }
                else if (type.flags & 2097152 /* Intersection */) {
                    return getIntersectionType(map(type.types, getTypeWithoutSignatures));
                }
                return type;
            }
            function isTypeIdenticalTo(source, target) {
                return isTypeRelatedTo(source, target, identityRelation);
            }
            function compareTypesIdentical(source, target) {
                return isTypeRelatedTo(source, target, identityRelation) ? -1 /* True */ : 0 /* False */;
            }
            function compareTypesAssignable(source, target) {
                return isTypeRelatedTo(source, target, assignableRelation) ? -1 /* True */ : 0 /* False */;
            }
            function compareTypesSubtypeOf(source, target) {
                return isTypeRelatedTo(source, target, subtypeRelation) ? -1 /* True */ : 0 /* False */;
            }
            function isTypeSubtypeOf(source, target) {
                return isTypeRelatedTo(source, target, subtypeRelation);
            }
            function isTypeStrictSubtypeOf(source, target) {
                return isTypeRelatedTo(source, target, strictSubtypeRelation);
            }
            function isTypeAssignableTo(source, target) {
                return isTypeRelatedTo(source, target, assignableRelation);
            }
            function isTypeDerivedFrom(source, target) {
                return source.flags & 1048576 /* Union */ ? every(source.types, (t) => isTypeDerivedFrom(t, target)) : target.flags & 1048576 /* Union */ ? some(target.types, (t) => isTypeDerivedFrom(source, t)) : source.flags & 2097152 /* Intersection */ ? some(source.types, (t) => isTypeDerivedFrom(t, target)) : source.flags & 58982400 /* InstantiableNonPrimitive */ ? isTypeDerivedFrom(getBaseConstraintOfType(source) || unknownType, target) : isEmptyAnonymousObjectType(target) ? !!(source.flags & (524288 /* Object */ | 67108864 /* NonPrimitive */)) : target === globalObjectType ? !!(source.flags & (524288 /* Object */ | 67108864 /* NonPrimitive */)) && !isEmptyAnonymousObjectType(source) : target === globalFunctionType ? !!(source.flags & 524288 /* Object */) && isFunctionObjectType(source) : hasBaseType(source, getTargetType(target)) || isArrayType(target) && !isReadonlyArrayType(target) && isTypeDerivedFrom(source, globalReadonlyArrayType);
            }
            function isTypeComparableTo(source, target) {
                return isTypeRelatedTo(source, target, comparableRelation);
            }
            function areTypesComparable(type1, type2) {
                return isTypeComparableTo(type1, type2) || isTypeComparableTo(type2, type1);
            }
            function checkTypeAssignableTo(source, target, errorNode, headMessage, containingMessageChain, errorOutputObject) {
                return checkTypeRelatedTo(source, target, assignableRelation, errorNode, headMessage, containingMessageChain, errorOutputObject);
            }
            function checkTypeAssignableToAndOptionallyElaborate(source, target, errorNode, expr, headMessage, containingMessageChain) {
                return checkTypeRelatedToAndOptionallyElaborate(source, target, assignableRelation, errorNode, expr, headMessage, containingMessageChain, 
                /*errorOutputContainer*/
                void 0);
            }
            function checkTypeRelatedToAndOptionallyElaborate(source, target, relation, errorNode, expr, headMessage, containingMessageChain, errorOutputContainer) {
                if (isTypeRelatedTo(source, target, relation))
                    return true;
                if (!errorNode || !elaborateError(expr, source, target, relation, headMessage, containingMessageChain, errorOutputContainer)) {
                    return checkTypeRelatedTo(source, target, relation, errorNode, headMessage, containingMessageChain, errorOutputContainer);
                }
                return false;
            }
            function isOrHasGenericConditional(type) {
                return !!(type.flags & 16777216 /* Conditional */ || type.flags & 2097152 /* Intersection */ && some(type.types, isOrHasGenericConditional));
            }
            function elaborateError(node, source, target, relation, headMessage, containingMessageChain, errorOutputContainer) {
                if (!node || isOrHasGenericConditional(target))
                    return false;
                if (!checkTypeRelatedTo(source, target, relation, 
                /*errorNode*/
                void 0) && elaborateDidYouMeanToCallOrConstruct(node, source, target, relation, headMessage, containingMessageChain, errorOutputContainer)) {
                    return true;
                }
                switch (node.kind) {
                    case 234 /* AsExpression */:
                        if (!isConstAssertion(node)) {
                            break;
                        }
                    case 294 /* JsxExpression */:
                    case 217 /* ParenthesizedExpression */:
                        return elaborateError(node.expression, source, target, relation, headMessage, containingMessageChain, errorOutputContainer);
                    case 226 /* BinaryExpression */:
                        switch (node.operatorToken.kind) {
                            case 64 /* EqualsToken */:
                            case 28 /* CommaToken */:
                                return elaborateError(node.right, source, target, relation, headMessage, containingMessageChain, errorOutputContainer);
                        }
                        break;
                    case 210 /* ObjectLiteralExpression */:
                        return elaborateObjectLiteral(node, source, target, relation, containingMessageChain, errorOutputContainer);
                    case 209 /* ArrayLiteralExpression */:
                        return elaborateArrayLiteral(node, source, target, relation, containingMessageChain, errorOutputContainer);
                    case 292 /* JsxAttributes */:
                        return elaborateJsxComponents(node, source, target, relation, containingMessageChain, errorOutputContainer);
                    case 219 /* ArrowFunction */:
                        return elaborateArrowFunction(node, source, target, relation, containingMessageChain, errorOutputContainer);
                }
                return false;
            }
            function elaborateDidYouMeanToCallOrConstruct(node, source, target, relation, headMessage, containingMessageChain, errorOutputContainer) {
                const callSignatures = getSignaturesOfType(source, 0 /* Call */);
                const constructSignatures = getSignaturesOfType(source, 1 /* Construct */);
                for (const signatures of [constructSignatures, callSignatures]) {
                    if (some(signatures, (s) => {
                        const returnType = getReturnTypeOfSignature(s);
                        return !(returnType.flags & (1 /* Any */ | 131072 /* Never */)) && checkTypeRelatedTo(returnType, target, relation, 
                        /*errorNode*/
                        void 0);
                    })) {
                        const resultObj = errorOutputContainer || {};
                        checkTypeAssignableTo(source, target, node, headMessage, containingMessageChain, resultObj);
                        const diagnostic = resultObj.errors[resultObj.errors.length - 1];
                        addRelatedInfo(diagnostic, createDiagnosticForNode(node, signatures === constructSignatures ? Diagnostics.Did_you_mean_to_use_new_with_this_expression : Diagnostics.Did_you_mean_to_call_this_expression));
                        return true;
                    }
                }
                return false;
            }
            function elaborateArrowFunction(node, source, target, relation, containingMessageChain, errorOutputContainer) {
                if (isBlock(node.body)) {
                    return false;
                }
                if (some(node.parameters, hasType)) {
                    return false;
                }
                const sourceSig = getSingleCallSignature(source);
                if (!sourceSig) {
                    return false;
                }
                const targetSignatures = getSignaturesOfType(target, 0 /* Call */);
                if (!length(targetSignatures)) {
                    return false;
                }
                const returnExpression = node.body;
                const sourceReturn = getReturnTypeOfSignature(sourceSig);
                const targetReturn = getUnionType(map(targetSignatures, getReturnTypeOfSignature));
                if (!checkTypeRelatedTo(sourceReturn, targetReturn, relation, 
                /*errorNode*/
                void 0)) {
                    const elaborated = returnExpression && elaborateError(returnExpression, sourceReturn, targetReturn, relation, 
                    /*headMessage*/
                    void 0, containingMessageChain, errorOutputContainer);
                    if (elaborated) {
                        return elaborated;
                    }
                    const resultObj = errorOutputContainer || {};
                    checkTypeRelatedTo(sourceReturn, targetReturn, relation, returnExpression, 
                    /*headMessage*/
                    void 0, containingMessageChain, resultObj);
                    if (resultObj.errors) {
                        if (target.symbol && length(target.symbol.declarations)) {
                            addRelatedInfo(resultObj.errors[resultObj.errors.length - 1], createDiagnosticForNode(target.symbol.declarations[0], Diagnostics.The_expected_type_comes_from_the_return_type_of_this_signature));
                        }
                        if ((getFunctionFlags(node) & 2 /* Async */) === 0 && !getTypeOfPropertyOfType(sourceReturn, "then") && checkTypeRelatedTo(createPromiseType(sourceReturn), targetReturn, relation, 
                        /*errorNode*/
                        void 0)) {
                            addRelatedInfo(resultObj.errors[resultObj.errors.length - 1], createDiagnosticForNode(node, Diagnostics.Did_you_mean_to_mark_this_function_as_async));
                        }
                        return true;
                    }
                }
                return false;
            }
            function getBestMatchIndexedAccessTypeOrUndefined(source, target, nameType) {
                const idx = getIndexedAccessTypeOrUndefined(target, nameType);
                if (idx) {
                    return idx;
                }
                if (target.flags & 1048576 /* Union */) {
                    const best = getBestMatchingType(source, target);
                    if (best) {
                        return getIndexedAccessTypeOrUndefined(best, nameType);
                    }
                }
            }
            function checkExpressionForMutableLocationWithContextualType(next, sourcePropType) {
                pushContextualType(next, sourcePropType, 
                /*isCache*/
                false);
                const result = checkExpressionForMutableLocation(next, 1 /* Contextual */);
                popContextualType();
                return result;
            }
            function elaborateElementwise(iterator, source, target, relation, containingMessageChain, errorOutputContainer) {
                let reportedError = false;
                for (const value of iterator) {
                    const { errorNode: prop, innerExpression: next, nameType, errorMessage } = value;
                    let targetPropType = getBestMatchIndexedAccessTypeOrUndefined(source, target, nameType);
                    if (!targetPropType || targetPropType.flags & 8388608 /* IndexedAccess */)
                        continue;
                    let sourcePropType = getIndexedAccessTypeOrUndefined(source, nameType);
                    if (!sourcePropType)
                        continue;
                    const propName = getPropertyNameFromIndex(nameType, 
                    /*accessNode*/
                    void 0);
                    if (!checkTypeRelatedTo(sourcePropType, targetPropType, relation, 
                    /*errorNode*/
                    void 0)) {
                        const elaborated = next && elaborateError(next, sourcePropType, targetPropType, relation, 
                        /*headMessage*/
                        void 0, containingMessageChain, errorOutputContainer);
                        reportedError = true;
                        if (!elaborated) {
                            const resultObj = errorOutputContainer || {};
                            const specificSource = next ? checkExpressionForMutableLocationWithContextualType(next, sourcePropType) : sourcePropType;
                            if (exactOptionalPropertyTypes && isExactOptionalPropertyMismatch(specificSource, targetPropType)) {
                                const diag2 = createDiagnosticForNode(prop, Diagnostics.Type_0_is_not_assignable_to_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_type_of_the_target, typeToString(specificSource), typeToString(targetPropType));
                                diagnostics.add(diag2);
                                resultObj.errors = [diag2];
                            }
                            else {
                                const targetIsOptional = !!(propName && (getPropertyOfType(target, propName) || unknownSymbol).flags & 16777216 /* Optional */);
                                const sourceIsOptional = !!(propName && (getPropertyOfType(source, propName) || unknownSymbol).flags & 16777216 /* Optional */);
                                targetPropType = removeMissingType(targetPropType, targetIsOptional);
                                sourcePropType = removeMissingType(sourcePropType, targetIsOptional && sourceIsOptional);
                                const result = checkTypeRelatedTo(specificSource, targetPropType, relation, prop, errorMessage, containingMessageChain, resultObj);
                                if (result && specificSource !== sourcePropType) {
                                    checkTypeRelatedTo(sourcePropType, targetPropType, relation, prop, errorMessage, containingMessageChain, resultObj);
                                }
                            }
                            if (resultObj.errors) {
                                const reportedDiag = resultObj.errors[resultObj.errors.length - 1];
                                const propertyName = isTypeUsableAsPropertyName(nameType) ? getPropertyNameFromType(nameType) : void 0;
                                const targetProp = propertyName !== void 0 ? getPropertyOfType(target, propertyName) : void 0;
                                let issuedElaboration = false;
                                if (!targetProp) {
                                    const indexInfo = getApplicableIndexInfo(target, nameType);
                                    if (indexInfo && indexInfo.declaration && !getSourceFileOfNode(indexInfo.declaration).hasNoDefaultLib) {
                                        issuedElaboration = true;
                                        addRelatedInfo(reportedDiag, createDiagnosticForNode(indexInfo.declaration, Diagnostics.The_expected_type_comes_from_this_index_signature));
                                    }
                                }
                                if (!issuedElaboration && (targetProp && length(targetProp.declarations) || target.symbol && length(target.symbol.declarations))) {
                                    const targetNode = targetProp && length(targetProp.declarations) ? targetProp.declarations[0] : target.symbol.declarations[0];
                                    if (!getSourceFileOfNode(targetNode).hasNoDefaultLib) {
                                        addRelatedInfo(reportedDiag, createDiagnosticForNode(targetNode, Diagnostics.The_expected_type_comes_from_property_0_which_is_declared_here_on_type_1, propertyName && !(nameType.flags & 8192 /* UniqueESSymbol */) ? unescapeLeadingUnderscores(propertyName) : typeToString(nameType), typeToString(target)));
                                    }
                                }
                            }
                        }
                    }
                }
                return reportedError;
            }
            function elaborateIterableOrArrayLikeTargetElementwise(iterator, source, target, relation, containingMessageChain, errorOutputContainer) {
                const tupleOrArrayLikeTargetParts = filterType(target, isArrayOrTupleLikeType);
                const nonTupleOrArrayLikeTargetParts = filterType(target, (t) => !isArrayOrTupleLikeType(t));
                const iterationType = nonTupleOrArrayLikeTargetParts !== neverType ? getIterationTypeOfIterable(13 /* ForOf */, 0 /* Yield */, nonTupleOrArrayLikeTargetParts, 
                /*errorNode*/
                void 0) : void 0;
                let reportedError = false;
                for (let status = iterator.next(); !status.done; status = iterator.next()) {
                    const { errorNode: prop, innerExpression: next, nameType, errorMessage } = status.value;
                    let targetPropType = iterationType;
                    const targetIndexedPropType = tupleOrArrayLikeTargetParts !== neverType ? getBestMatchIndexedAccessTypeOrUndefined(source, tupleOrArrayLikeTargetParts, nameType) : void 0;
                    if (targetIndexedPropType && !(targetIndexedPropType.flags & 8388608 /* IndexedAccess */)) {
                        targetPropType = iterationType ? getUnionType([iterationType, targetIndexedPropType]) : targetIndexedPropType;
                    }
                    if (!targetPropType)
                        continue;
                    let sourcePropType = getIndexedAccessTypeOrUndefined(source, nameType);
                    if (!sourcePropType)
                        continue;
                    const propName = getPropertyNameFromIndex(nameType, 
                    /*accessNode*/
                    void 0);
                    if (!checkTypeRelatedTo(sourcePropType, targetPropType, relation, 
                    /*errorNode*/
                    void 0)) {
                        const elaborated = next && elaborateError(next, sourcePropType, targetPropType, relation, 
                        /*headMessage*/
                        void 0, containingMessageChain, errorOutputContainer);
                        reportedError = true;
                        if (!elaborated) {
                            const resultObj = errorOutputContainer || {};
                            const specificSource = next ? checkExpressionForMutableLocationWithContextualType(next, sourcePropType) : sourcePropType;
                            if (exactOptionalPropertyTypes && isExactOptionalPropertyMismatch(specificSource, targetPropType)) {
                                const diag2 = createDiagnosticForNode(prop, Diagnostics.Type_0_is_not_assignable_to_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_type_of_the_target, typeToString(specificSource), typeToString(targetPropType));
                                diagnostics.add(diag2);
                                resultObj.errors = [diag2];
                            }
                            else {
                                const targetIsOptional = !!(propName && (getPropertyOfType(tupleOrArrayLikeTargetParts, propName) || unknownSymbol).flags & 16777216 /* Optional */);
                                const sourceIsOptional = !!(propName && (getPropertyOfType(source, propName) || unknownSymbol).flags & 16777216 /* Optional */);
                                targetPropType = removeMissingType(targetPropType, targetIsOptional);
                                sourcePropType = removeMissingType(sourcePropType, targetIsOptional && sourceIsOptional);
                                const result = checkTypeRelatedTo(specificSource, targetPropType, relation, prop, errorMessage, containingMessageChain, resultObj);
                                if (result && specificSource !== sourcePropType) {
                                    checkTypeRelatedTo(sourcePropType, targetPropType, relation, prop, errorMessage, containingMessageChain, resultObj);
                                }
                            }
                        }
                    }
                }
                return reportedError;
            }
            function* generateJsxAttributes(node) {
                if (!length(node.properties))
                    return;
                for (const prop of node.properties) {
                    if (isJsxSpreadAttribute(prop) || isHyphenatedJsxName(getTextOfJsxAttributeName(prop.name)))
                        continue;
                    yield { errorNode: prop.name, innerExpression: prop.initializer, nameType: getStringLiteralType(getTextOfJsxAttributeName(prop.name)) };
                }
            }
            function* generateJsxChildren(node, getInvalidTextDiagnostic) {
                if (!length(node.children))
                    return;
                let memberOffset = 0;
                for (let i = 0; i < node.children.length; i++) {
                    const child = node.children[i];
                    const nameType = getNumberLiteralType(i - memberOffset);
                    const elem = getElaborationElementForJsxChild(child, nameType, getInvalidTextDiagnostic);
                    if (elem) {
                        yield elem;
                    }
                    else {
                        memberOffset++;
                    }
                }
            }
            function getElaborationElementForJsxChild(child, nameType, getInvalidTextDiagnostic) {
                switch (child.kind) {
                    case 294 /* JsxExpression */:
                        return { errorNode: child, innerExpression: child.expression, nameType };
                    case 12 /* JsxText */:
                        if (child.containsOnlyTriviaWhiteSpaces) {
                            break;
                        }
                        return { errorNode: child, innerExpression: void 0, nameType, errorMessage: getInvalidTextDiagnostic() };
                    case 284 /* JsxElement */:
                    case 285 /* JsxSelfClosingElement */:
                    case 288 /* JsxFragment */:
                        return { errorNode: child, innerExpression: child, nameType };
                    default:
                        return Debug.assertNever(child, "Found invalid jsx child");
                }
            }
            function elaborateJsxComponents(node, source, target, relation, containingMessageChain, errorOutputContainer) {
                let result = elaborateElementwise(generateJsxAttributes(node), source, target, relation, containingMessageChain, errorOutputContainer);
                let invalidTextDiagnostic;
                if (isJsxOpeningElement(node.parent) && isJsxElement(node.parent.parent)) {
                    const containingElement = node.parent.parent;
                    const childPropName = getJsxElementChildrenPropertyName(getJsxNamespaceAt(node));
                    const childrenPropName = childPropName === void 0 ? "children" : unescapeLeadingUnderscores(childPropName);
                    const childrenNameType = getStringLiteralType(childrenPropName);
                    const childrenTargetType = getIndexedAccessType(target, childrenNameType);
                    const validChildren = getSemanticJsxChildren(containingElement.children);
                    if (!length(validChildren)) {
                        return result;
                    }
                    const moreThanOneRealChildren = length(validChildren) > 1;
                    let arrayLikeTargetParts;
                    let nonArrayLikeTargetParts;
                    const iterableType = getGlobalIterableType(
                    /*reportErrors*/
                    false);
                    if (iterableType !== emptyGenericType) {
                        const anyIterable = createIterableType(anyType);
                        arrayLikeTargetParts = filterType(childrenTargetType, (t) => isTypeAssignableTo(t, anyIterable));
                        nonArrayLikeTargetParts = filterType(childrenTargetType, (t) => !isTypeAssignableTo(t, anyIterable));
                    }
                    else {
                        arrayLikeTargetParts = filterType(childrenTargetType, isArrayOrTupleLikeType);
                        nonArrayLikeTargetParts = filterType(childrenTargetType, (t) => !isArrayOrTupleLikeType(t));
                    }
                    if (moreThanOneRealChildren) {
                        if (arrayLikeTargetParts !== neverType) {
                            const realSource = createTupleType(checkJsxChildren(containingElement, 0 /* Normal */));
                            const children = generateJsxChildren(containingElement, getInvalidTextualChildDiagnostic);
                            result = elaborateIterableOrArrayLikeTargetElementwise(children, realSource, arrayLikeTargetParts, relation, containingMessageChain, errorOutputContainer) || result;
                        }
                        else if (!isTypeRelatedTo(getIndexedAccessType(source, childrenNameType), childrenTargetType, relation)) {
                            result = true;
                            const diag2 = error2(containingElement.openingElement.tagName, Diagnostics.This_JSX_tag_s_0_prop_expects_a_single_child_of_type_1_but_multiple_children_were_provided, childrenPropName, typeToString(childrenTargetType));
                            if (errorOutputContainer && errorOutputContainer.skipLogging) {
                                (errorOutputContainer.errors || (errorOutputContainer.errors = [])).push(diag2);
                            }
                        }
                    }
                    else {
                        if (nonArrayLikeTargetParts !== neverType) {
                            const child = validChildren[0];
                            const elem = getElaborationElementForJsxChild(child, childrenNameType, getInvalidTextualChildDiagnostic);
                            if (elem) {
                                result = elaborateElementwise(function* () {
                                    yield elem;
                                }(), source, target, relation, containingMessageChain, errorOutputContainer) || result;
                            }
                        }
                        else if (!isTypeRelatedTo(getIndexedAccessType(source, childrenNameType), childrenTargetType, relation)) {
                            result = true;
                            const diag2 = error2(containingElement.openingElement.tagName, Diagnostics.This_JSX_tag_s_0_prop_expects_type_1_which_requires_multiple_children_but_only_a_single_child_was_provided, childrenPropName, typeToString(childrenTargetType));
                            if (errorOutputContainer && errorOutputContainer.skipLogging) {
                                (errorOutputContainer.errors || (errorOutputContainer.errors = [])).push(diag2);
                            }
                        }
                    }
                }
                return result;
                function getInvalidTextualChildDiagnostic() {
                    if (!invalidTextDiagnostic) {
                        const tagNameText = getTextOfNode(node.parent.tagName);
                        const childPropName = getJsxElementChildrenPropertyName(getJsxNamespaceAt(node));
                        const childrenPropName = childPropName === void 0 ? "children" : unescapeLeadingUnderscores(childPropName);
                        const childrenTargetType = getIndexedAccessType(target, getStringLiteralType(childrenPropName));
                        const diagnostic = Diagnostics._0_components_don_t_accept_text_as_child_elements_Text_in_JSX_has_the_type_string_but_the_expected_type_of_1_is_2;
                        invalidTextDiagnostic = { ...diagnostic, key: "!!ALREADY FORMATTED!!", message: formatMessage(diagnostic, tagNameText, childrenPropName, typeToString(childrenTargetType)) };
                    }
                    return invalidTextDiagnostic;
                }
            }
            function* generateLimitedTupleElements(node, target) {
                const len = length(node.elements);
                if (!len)
                    return;
                for (let i = 0; i < len; i++) {
                    if (isTupleLikeType(target) && !getPropertyOfType(target, "" + i))
                        continue;
                    const elem = node.elements[i];
                    if (isOmittedExpression(elem))
                        continue;
                    const nameType = getNumberLiteralType(i);
                    const checkNode = getEffectiveCheckNode(elem);
                    yield { errorNode: checkNode, innerExpression: checkNode, nameType };
                }
            }
            function elaborateArrayLiteral(node, source, target, relation, containingMessageChain, errorOutputContainer) {
                if (target.flags & (402784252 /* Primitive */ | 131072 /* Never */))
                    return false;
                if (isTupleLikeType(source)) {
                    return elaborateElementwise(generateLimitedTupleElements(node, target), source, target, relation, containingMessageChain, errorOutputContainer);
                }
                pushContextualType(node, target, 
                /*isCache*/
                false);
                const tupleizedType = checkArrayLiteral(node, 1 /* Contextual */, 
                /*forceTuple*/
                true);
                popContextualType();
                if (isTupleLikeType(tupleizedType)) {
                    return elaborateElementwise(generateLimitedTupleElements(node, target), tupleizedType, target, relation, containingMessageChain, errorOutputContainer);
                }
                return false;
            }
            function* generateObjectLiteralElements(node) {
                if (!length(node.properties))
                    return;
                for (const prop of node.properties) {
                    if (isSpreadAssignment(prop))
                        continue;
                    const type = getLiteralTypeFromProperty(getSymbolOfDeclaration(prop), 8576 /* StringOrNumberLiteralOrUnique */);
                    if (!type || type.flags & 131072 /* Never */) {
                        continue;
                    }
                    switch (prop.kind) {
                        case 178 /* SetAccessor */:
                        case 177 /* GetAccessor */:
                        case 174 /* MethodDeclaration */:
                        case 304 /* ShorthandPropertyAssignment */:
                            yield { errorNode: prop.name, innerExpression: void 0, nameType: type };
                            break;
                        case 303 /* PropertyAssignment */:
                            yield { errorNode: prop.name, innerExpression: prop.initializer, nameType: type, errorMessage: isComputedNonLiteralName(prop.name) ? Diagnostics.Type_of_computed_property_s_value_is_0_which_is_not_assignable_to_type_1 : void 0 };
                            break;
                        default:
                            Debug.assertNever(prop);
                    }
                }
            }
            function elaborateObjectLiteral(node, source, target, relation, containingMessageChain, errorOutputContainer) {
                if (target.flags & (402784252 /* Primitive */ | 131072 /* Never */))
                    return false;
                return elaborateElementwise(generateObjectLiteralElements(node), source, target, relation, containingMessageChain, errorOutputContainer);
            }
            function checkTypeComparableTo(source, target, errorNode, headMessage, containingMessageChain) {
                return checkTypeRelatedTo(source, target, comparableRelation, errorNode, headMessage, containingMessageChain);
            }
            function isSignatureAssignableTo(source, target, ignoreReturnTypes) {
                return compareSignaturesRelated(source, target, ignoreReturnTypes ? 4 /* IgnoreReturnTypes */ : 0 /* None */, 
                /*reportErrors*/
                false, 
                /*errorReporter*/
                void 0, 
                /*incompatibleErrorReporter*/
                void 0, compareTypesAssignable, 
                /*reportUnreliableMarkers*/
                void 0) !== 0 /* False */;
            }
            function isTopSignature(s) {
                if (!s.typeParameters && (!s.thisParameter || isTypeAny(getTypeOfParameter(s.thisParameter))) && s.parameters.length === 1 && signatureHasRestParameter(s)) {
                    const paramType = getTypeOfParameter(s.parameters[0]);
                    const restType = isArrayType(paramType) ? getTypeArguments(paramType)[0] : paramType;
                    return !!(restType.flags & (1 /* Any */ | 131072 /* Never */) && getReturnTypeOfSignature(s).flags & 3 /* AnyOrUnknown */);
                }
                return false;
            }
            function compareSignaturesRelated(source, target, checkMode, reportErrors2, errorReporter, incompatibleErrorReporter, compareTypes, reportUnreliableMarkers) {
                if (source === target) {
                    return -1 /* True */;
                }
                if (!(checkMode & 16 /* StrictTopSignature */ && isTopSignature(source)) && isTopSignature(target)) {
                    return -1 /* True */;
                }
                if (checkMode & 16 /* StrictTopSignature */ && isTopSignature(source) && !isTopSignature(target)) {
                    return 0 /* False */;
                }
                const targetCount = getParameterCount(target);
                const sourceHasMoreParameters = !hasEffectiveRestParameter(target) && (checkMode & 8 /* StrictArity */ ? hasEffectiveRestParameter(source) || getParameterCount(source) > targetCount : getMinArgumentCount(source) > targetCount);
                if (sourceHasMoreParameters) {
                    if (reportErrors2 && !(checkMode & 8 /* StrictArity */)) {
                        errorReporter(Diagnostics.Target_signature_provides_too_few_arguments_Expected_0_or_more_but_got_1, getMinArgumentCount(source), targetCount);
                    }
                    return 0 /* False */;
                }
                if (source.typeParameters && source.typeParameters !== target.typeParameters) {
                    target = getCanonicalSignature(target);
                    source = instantiateSignatureInContextOf(source, target, 
                    /*inferenceContext*/
                    void 0, compareTypes);
                }
                const sourceCount = getParameterCount(source);
                const sourceRestType = getNonArrayRestType(source);
                const targetRestType = getNonArrayRestType(target);
                if (sourceRestType || targetRestType) {
                    void instantiateType(sourceRestType || targetRestType, reportUnreliableMarkers);
                }
                const kind = target.declaration ? target.declaration.kind : 0 /* Unknown */;
                const strictVariance = !(checkMode & 3 /* Callback */) && strictFunctionTypes && kind !== 174 /* MethodDeclaration */ && kind !== 173 /* MethodSignature */ && kind !== 176 /* Constructor */;
                let result = -1 /* True */;
                const sourceThisType = getThisTypeOfSignature(source);
                if (sourceThisType && sourceThisType !== voidType) {
                    const targetThisType = getThisTypeOfSignature(target);
                    if (targetThisType) {
                        const related = !strictVariance && compareTypes(sourceThisType, targetThisType, 
                        /*reportErrors*/
                        false) || compareTypes(targetThisType, sourceThisType, reportErrors2);
                        if (!related) {
                            if (reportErrors2) {
                                errorReporter(Diagnostics.The_this_types_of_each_signature_are_incompatible);
                            }
                            return 0 /* False */;
                        }
                        result &= related;
                    }
                }
                const paramCount = sourceRestType || targetRestType ? Math.min(sourceCount, targetCount) : Math.max(sourceCount, targetCount);
                const restIndex = sourceRestType || targetRestType ? paramCount - 1 : -1;
                for (let i = 0; i < paramCount; i++) {
                    const sourceType = i === restIndex ? getRestOrAnyTypeAtPosition(source, i) : tryGetTypeAtPosition(source, i);
                    const targetType = i === restIndex ? getRestOrAnyTypeAtPosition(target, i) : tryGetTypeAtPosition(target, i);
                    if (sourceType && targetType) {
                        const sourceSig = checkMode & 3 /* Callback */ || isInstantiatedGenericParameter(source, i) ? void 0 : getSingleCallSignature(getNonNullableType(sourceType));
                        const targetSig = checkMode & 3 /* Callback */ || isInstantiatedGenericParameter(target, i) ? void 0 : getSingleCallSignature(getNonNullableType(targetType));
                        const callbacks = sourceSig && targetSig && !getTypePredicateOfSignature(sourceSig) && !getTypePredicateOfSignature(targetSig) && getTypeFacts(sourceType, 50331648 /* IsUndefinedOrNull */) === getTypeFacts(targetType, 50331648 /* IsUndefinedOrNull */);
                        let related = callbacks ? compareSignaturesRelated(targetSig, sourceSig, checkMode & 8 /* StrictArity */ | (strictVariance ? 2 /* StrictCallback */ : 1 /* BivariantCallback */), reportErrors2, errorReporter, incompatibleErrorReporter, compareTypes, reportUnreliableMarkers) : !(checkMode & 3 /* Callback */) && !strictVariance && compareTypes(sourceType, targetType, 
                        /*reportErrors*/
                        false) || compareTypes(targetType, sourceType, reportErrors2);
                        if (related && checkMode & 8 /* StrictArity */ && i >= getMinArgumentCount(source) && i < getMinArgumentCount(target) && compareTypes(sourceType, targetType, 
                        /*reportErrors*/
                        false)) {
                            related = 0 /* False */;
                        }
                        if (!related) {
                            if (reportErrors2) {
                                errorReporter(Diagnostics.Types_of_parameters_0_and_1_are_incompatible, unescapeLeadingUnderscores(getParameterNameAtPosition(source, i)), unescapeLeadingUnderscores(getParameterNameAtPosition(target, i)));
                            }
                            return 0 /* False */;
                        }
                        result &= related;
                    }
                }
                if (!(checkMode & 4 /* IgnoreReturnTypes */)) {
                    const targetReturnType = isResolvingReturnTypeOfSignature(target) ? anyType : target.declaration && isJSConstructor(target.declaration) ? getDeclaredTypeOfClassOrInterface(getMergedSymbol(target.declaration.symbol)) : getReturnTypeOfSignature(target);
                    if (targetReturnType === voidType || targetReturnType === anyType) {
                        return result;
                    }
                    const sourceReturnType = isResolvingReturnTypeOfSignature(source) ? anyType : source.declaration && isJSConstructor(source.declaration) ? getDeclaredTypeOfClassOrInterface(getMergedSymbol(source.declaration.symbol)) : getReturnTypeOfSignature(source);
                    const targetTypePredicate = getTypePredicateOfSignature(target);
                    if (targetTypePredicate) {
                        const sourceTypePredicate = getTypePredicateOfSignature(source);
                        if (sourceTypePredicate) {
                            result &= compareTypePredicateRelatedTo(sourceTypePredicate, targetTypePredicate, reportErrors2, errorReporter, compareTypes);
                        }
                        else if (isIdentifierTypePredicate(targetTypePredicate)) {
                            if (reportErrors2) {
                                errorReporter(Diagnostics.Signature_0_must_be_a_type_predicate, signatureToString(source));
                            }
                            return 0 /* False */;
                        }
                    }
                    else {
                        result &= checkMode & 1 /* BivariantCallback */ && compareTypes(targetReturnType, sourceReturnType, 
                        /*reportErrors*/
                        false) || compareTypes(sourceReturnType, targetReturnType, reportErrors2);
                        if (!result && reportErrors2 && incompatibleErrorReporter) {
                            incompatibleErrorReporter(sourceReturnType, targetReturnType);
                        }
                    }
                }
                return result;
            }
            function compareTypePredicateRelatedTo(source, target, reportErrors2, errorReporter, compareTypes) {
                if (source.kind !== target.kind) {
                    if (reportErrors2) {
                        errorReporter(Diagnostics.A_this_based_type_guard_is_not_compatible_with_a_parameter_based_type_guard);
                        errorReporter(Diagnostics.Type_predicate_0_is_not_assignable_to_1, typePredicateToString(source), typePredicateToString(target));
                    }
                    return 0 /* False */;
                }
                if (source.kind === 1 /* Identifier */ || source.kind === 3 /* AssertsIdentifier */) {
                    if (source.parameterIndex !== target.parameterIndex) {
                        if (reportErrors2) {
                            errorReporter(Diagnostics.Parameter_0_is_not_in_the_same_position_as_parameter_1, source.parameterName, target.parameterName);
                            errorReporter(Diagnostics.Type_predicate_0_is_not_assignable_to_1, typePredicateToString(source), typePredicateToString(target));
                        }
                        return 0 /* False */;
                    }
                }
                const related = source.type === target.type ? -1 /* True */ : source.type && target.type ? compareTypes(source.type, target.type, reportErrors2) : 0 /* False */;
                if (related === 0 /* False */ && reportErrors2) {
                    errorReporter(Diagnostics.Type_predicate_0_is_not_assignable_to_1, typePredicateToString(source), typePredicateToString(target));
                }
                return related;
            }
            function isImplementationCompatibleWithOverload(implementation, overload) {
                const erasedSource = getErasedSignature(implementation);
                const erasedTarget = getErasedSignature(overload);
                const sourceReturnType = getReturnTypeOfSignature(erasedSource);
                const targetReturnType = getReturnTypeOfSignature(erasedTarget);
                if (targetReturnType === voidType || isTypeRelatedTo(targetReturnType, sourceReturnType, assignableRelation) || isTypeRelatedTo(sourceReturnType, targetReturnType, assignableRelation)) {
                    return isSignatureAssignableTo(erasedSource, erasedTarget, 
                    /*ignoreReturnTypes*/
                    true);
                }
                return false;
            }
            function isEmptyResolvedType(t) {
                return t !== anyFunctionType && t.properties.length === 0 && t.callSignatures.length === 0 && t.constructSignatures.length === 0 && t.indexInfos.length === 0;
            }
            function isEmptyObjectType(type) {
                return type.flags & 524288 /* Object */ ? !isGenericMappedType(type) && isEmptyResolvedType(resolveStructuredTypeMembers(type)) : type.flags & 67108864 /* NonPrimitive */ ? true : type.flags & 1048576 /* Union */ ? some(type.types, isEmptyObjectType) : type.flags & 2097152 /* Intersection */ ? every(type.types, isEmptyObjectType) : false;
            }
            function isEmptyAnonymousObjectType(type) {
                return !!(getObjectFlags(type) & 16 /* Anonymous */ && (type.members && isEmptyResolvedType(type) || type.symbol && type.symbol.flags & 2048 /* TypeLiteral */ && getMembersOfSymbol(type.symbol).size === 0));
            }
            function isUnknownLikeUnionType(type) {
                if (strictNullChecks && type.flags & 1048576 /* Union */) {
                    if (!(type.objectFlags & 33554432 /* IsUnknownLikeUnionComputed */)) {
                        const types = type.types;
                        type.objectFlags |= 33554432 /* IsUnknownLikeUnionComputed */ | (types.length >= 3 && types[0].flags & 32768 /* Undefined */ && types[1].flags & 65536 /* Null */ && some(types, isEmptyAnonymousObjectType) ? 67108864 /* IsUnknownLikeUnion */ : 0);
                    }
                    return !!(type.objectFlags & 67108864 /* IsUnknownLikeUnion */);
                }
                return false;
            }
            function containsUndefinedType(type) {
                return !!((type.flags & 1048576 /* Union */ ? type.types[0] : type).flags & 32768 /* Undefined */);
            }
            function isStringIndexSignatureOnlyType(type) {
                return type.flags & 524288 /* Object */ && !isGenericMappedType(type) && getPropertiesOfType(type).length === 0 && getIndexInfosOfType(type).length === 1 && !!getIndexInfoOfType(type, stringType) || type.flags & 3145728 /* UnionOrIntersection */ && every(type.types, isStringIndexSignatureOnlyType) || false;
            }
            function isEnumTypeRelatedTo(source, target, errorReporter) {
                const sourceSymbol = source.flags & 8 /* EnumMember */ ? getParentOfSymbol(source) : source;
                const targetSymbol = target.flags & 8 /* EnumMember */ ? getParentOfSymbol(target) : target;
                if (sourceSymbol === targetSymbol) {
                    return true;
                }
                if (sourceSymbol.escapedName !== targetSymbol.escapedName || !(sourceSymbol.flags & 256 /* RegularEnum */) || !(targetSymbol.flags & 256 /* RegularEnum */)) {
                    return false;
                }
                const id = getSymbolId(sourceSymbol) + "," + getSymbolId(targetSymbol);
                const entry = enumRelation.get(id);
                if (entry !== void 0 && !(!(entry & 4 /* Reported */) && entry & 2 /* Failed */ && errorReporter)) {
                    return !!(entry & 1 /* Succeeded */);
                }
                const targetEnumType = getTypeOfSymbol(targetSymbol);
                for (const sourceProperty of getPropertiesOfType(getTypeOfSymbol(sourceSymbol))) {
                    if (sourceProperty.flags & 8 /* EnumMember */) {
                        const targetProperty = getPropertyOfType(targetEnumType, sourceProperty.escapedName);
                        if (!targetProperty || !(targetProperty.flags & 8 /* EnumMember */)) {
                            if (errorReporter) {
                                errorReporter(Diagnostics.Property_0_is_missing_in_type_1, symbolName(sourceProperty), typeToString(getDeclaredTypeOfSymbol(targetSymbol), 
                                /*enclosingDeclaration*/
                                void 0, 64 /* UseFullyQualifiedType */));
                                enumRelation.set(id, 2 /* Failed */ | 4 /* Reported */);
                            }
                            else {
                                enumRelation.set(id, 2 /* Failed */);
                            }
                            return false;
                        }
                        const sourceValue = getEnumMemberValue(getDeclarationOfKind(sourceProperty, 306 /* EnumMember */));
                        const targetValue = getEnumMemberValue(getDeclarationOfKind(targetProperty, 306 /* EnumMember */));
                        if (sourceValue !== targetValue) {
                            const sourceIsString = typeof sourceValue === "string";
                            const targetIsString = typeof targetValue === "string";
                            if (sourceValue !== void 0 && targetValue !== void 0) {
                                if (!errorReporter) {
                                    enumRelation.set(id, 2 /* Failed */);
                                }
                                else {
                                    const escapedSource = sourceIsString ? `"${escapeString(sourceValue)}"` : sourceValue;
                                    const escapedTarget = targetIsString ? `"${escapeString(targetValue)}"` : targetValue;
                                    errorReporter(Diagnostics.Each_declaration_of_0_1_differs_in_its_value_where_2_was_expected_but_3_was_given, symbolName(targetSymbol), symbolName(targetProperty), escapedTarget, escapedSource);
                                    enumRelation.set(id, 2 /* Failed */ | 4 /* Reported */);
                                }
                                return false;
                            }
                            if (sourceIsString || targetIsString) {
                                if (!errorReporter) {
                                    enumRelation.set(id, 2 /* Failed */);
                                }
                                else {
                                    const knownStringValue = sourceValue ?? targetValue;
                                    Debug.assert(typeof knownStringValue === "string");
                                    const escapedValue = `"${escapeString(knownStringValue)}"`;
                                    errorReporter(Diagnostics.One_value_of_0_1_is_the_string_2_and_the_other_is_assumed_to_be_an_unknown_numeric_value, symbolName(targetSymbol), symbolName(targetProperty), escapedValue);
                                    enumRelation.set(id, 2 /* Failed */ | 4 /* Reported */);
                                }
                                return false;
                            }
                        }
                    }
                }
                enumRelation.set(id, 1 /* Succeeded */);
                return true;
            }
            function isSimpleTypeRelatedTo(source, target, relation, errorReporter) {
                const s = source.flags;
                const t = target.flags;
                if (t & 1 /* Any */ || s & 131072 /* Never */ || source === wildcardType)
                    return true;
                if (t & 2 /* Unknown */ && !(relation === strictSubtypeRelation && s & 1 /* Any */))
                    return true;
                if (t & 131072 /* Never */)
                    return false;
                if (s & 402653316 /* StringLike */ && t & 4 /* String */)
                    return true;
                if (s & 128 /* StringLiteral */ && s & 1024 /* EnumLiteral */ && t & 128 /* StringLiteral */ && !(t & 1024 /* EnumLiteral */) && source.value === target.value)
                    return true;
                if (s & 296 /* NumberLike */ && t & 8 /* Number */)
                    return true;
                if (s & 256 /* NumberLiteral */ && s & 1024 /* EnumLiteral */ && t & 256 /* NumberLiteral */ && !(t & 1024 /* EnumLiteral */) && source.value === target.value)
                    return true;
                if (s & 2112 /* BigIntLike */ && t & 64 /* BigInt */)
                    return true;
                if (s & 528 /* BooleanLike */ && t & 16 /* Boolean */)
                    return true;
                if (s & 12288 /* ESSymbolLike */ && t & 4096 /* ESSymbol */)
                    return true;
                if (s & 32 /* Enum */ && t & 32 /* Enum */ && source.symbol.escapedName === target.symbol.escapedName && isEnumTypeRelatedTo(source.symbol, target.symbol, errorReporter))
                    return true;
                if (s & 1024 /* EnumLiteral */ && t & 1024 /* EnumLiteral */) {
                    if (s & 1048576 /* Union */ && t & 1048576 /* Union */ && isEnumTypeRelatedTo(source.symbol, target.symbol, errorReporter))
                        return true;
                    if (s & 2944 /* Literal */ && t & 2944 /* Literal */ && source.value === target.value && isEnumTypeRelatedTo(source.symbol, target.symbol, errorReporter))
                        return true;
                }
                if (s & 32768 /* Undefined */ && (!strictNullChecks && !(t & 3145728 /* UnionOrIntersection */) || t & (32768 /* Undefined */ | 16384 /* Void */)))
                    return true;
                if (s & 65536 /* Null */ && (!strictNullChecks && !(t & 3145728 /* UnionOrIntersection */) || t & 65536 /* Null */))
                    return true;
                if (s & 524288 /* Object */ && t & 67108864 /* NonPrimitive */ && !(relation === strictSubtypeRelation && isEmptyAnonymousObjectType(source) && !(getObjectFlags(source) & 8192 /* FreshLiteral */)))
                    return true;
                if (relation === assignableRelation || relation === comparableRelation) {
                    if (s & 1 /* Any */)
                        return true;
                    if (s & 8 /* Number */ && (t & 32 /* Enum */ || t & 256 /* NumberLiteral */ && t & 1024 /* EnumLiteral */))
                        return true;
                    if (s & 256 /* NumberLiteral */ && !(s & 1024 /* EnumLiteral */) && (t & 32 /* Enum */ || t & 256 /* NumberLiteral */ && t & 1024 /* EnumLiteral */ && source.value === target.value))
                        return true;
                    if (isUnknownLikeUnionType(target))
                        return true;
                }
                return false;
            }
            function isTypeRelatedTo(source, target, relation) {
                if (isFreshLiteralType(source)) {
                    source = source.regularType;
                }
                if (isFreshLiteralType(target)) {
                    target = target.regularType;
                }
                if (source === target) {
                    return true;
                }
                if (relation !== identityRelation) {
                    if (relation === comparableRelation && !(target.flags & 131072 /* Never */) && isSimpleTypeRelatedTo(target, source, relation) || isSimpleTypeRelatedTo(source, target, relation)) {
                        return true;
                    }
                }
                else if (!((source.flags | target.flags) & (3145728 /* UnionOrIntersection */ | 8388608 /* IndexedAccess */ | 16777216 /* Conditional */ | 33554432 /* Substitution */))) {
                    if (source.flags !== target.flags)
                        return false;
                    if (source.flags & 67358815 /* Singleton */)
                        return true;
                }
                if (source.flags & 524288 /* Object */ && target.flags & 524288 /* Object */) {
                    const related = relation.get(getRelationKey(source, target, 0 /* None */, relation, 
                    /*ignoreConstraints*/
                    false));
                    if (related !== void 0) {
                        return !!(related & 1 /* Succeeded */);
                    }
                }
                if (source.flags & 469499904 /* StructuredOrInstantiable */ || target.flags & 469499904 /* StructuredOrInstantiable */) {
                    return checkTypeRelatedTo(source, target, relation, 
                    /*errorNode*/
                    void 0);
                }
                return false;
            }
            function isIgnoredJsxProperty(source, sourceProp) {
                return getObjectFlags(source) & 2048 /* JsxAttributes */ && isHyphenatedJsxName(sourceProp.escapedName);
            }
            function getNormalizedType(type, writing) {
                while (true) {
                    const t = isFreshLiteralType(type) ? type.regularType : isGenericTupleType(type) ? getNormalizedTupleType(type, writing) : getObjectFlags(type) & 4 /* Reference */ ? type.node ? createTypeReference(type.target, getTypeArguments(type)) : getSingleBaseForNonAugmentingSubtype(type) || type : type.flags & 3145728 /* UnionOrIntersection */ ? getNormalizedUnionOrIntersectionType(type, writing) : type.flags & 33554432 /* Substitution */ ? writing ? type.baseType : getSubstitutionIntersection(type) : type.flags & 25165824 /* Simplifiable */ ? getSimplifiedType(type, writing) : type;
                    if (t === type)
                        return t;
                    type = t;
                }
            }
            function getNormalizedUnionOrIntersectionType(type, writing) {
                const reduced = getReducedType(type);
                if (reduced !== type) {
                    return reduced;
                }
                if (type.flags & 2097152 /* Intersection */ && some(type.types, isEmptyAnonymousObjectType)) {
                    const normalizedTypes = sameMap(type.types, (t) => getNormalizedType(t, writing));
                    if (normalizedTypes !== type.types) {
                        return getIntersectionType(normalizedTypes);
                    }
                }
                return type;
            }
            function getNormalizedTupleType(type, writing) {
                const elements = getElementTypes(type);
                const normalizedElements = sameMap(elements, (t) => t.flags & 25165824 /* Simplifiable */ ? getSimplifiedType(t, writing) : t);
                return elements !== normalizedElements ? createNormalizedTupleType(type.target, normalizedElements) : type;
            }
            function checkTypeRelatedTo(source, target, relation, errorNode, headMessage, containingMessageChain, errorOutputContainer) {
                var _a;
                let errorInfo;
                let relatedInfo;
                let maybeKeys;
                let maybeKeysSet;
                let sourceStack;
                let targetStack;
                let maybeCount = 0;
                let sourceDepth = 0;
                let targetDepth = 0;
                let expandingFlags = 0 /* None */;
                let overflow = false;
                let overrideNextErrorInfo = 0;
                let skipParentCounter = 0;
                let lastSkippedInfo;
                let incompatibleStack;
                let relationCount = 16e6 - relation.size >> 3;
                Debug.assert(relation !== identityRelation || !errorNode, "no error reporting in identity checking");
                const result = isRelatedTo(source, target, 3 /* Both */, 
                /*reportErrors*/
                !!errorNode, headMessage);
                if (incompatibleStack) {
                    reportIncompatibleStack();
                }
                if (overflow) {
                    const id = getRelationKey(source, target, 
                    /*intersectionState*/
                    0 /* None */, relation, 
                    /*ignoreConstraints*/
                    false);
                    relation.set(id, 4 /* Reported */ | 2 /* Failed */);
                    (_a = tracing) == null ? void 0 : _a.instant(tracing.Phase.CheckTypes, "checkTypeRelatedTo_DepthLimit", { sourceId: source.id, targetId: target.id, depth: sourceDepth, targetDepth });
                    const message = relationCount <= 0 ? Diagnostics.Excessive_complexity_comparing_types_0_and_1 : Diagnostics.Excessive_stack_depth_comparing_types_0_and_1;
                    const diag2 = error2(errorNode || currentNode, message, typeToString(source), typeToString(target));
                    if (errorOutputContainer) {
                        (errorOutputContainer.errors || (errorOutputContainer.errors = [])).push(diag2);
                    }
                }
                else if (errorInfo) {
                    if (containingMessageChain) {
                        const chain = containingMessageChain();
                        if (chain) {
                            concatenateDiagnosticMessageChains(chain, errorInfo);
                            errorInfo = chain;
                        }
                    }
                    let relatedInformation;
                    if (headMessage && errorNode && !result && source.symbol) {
                        const links = getSymbolLinks(source.symbol);
                        if (links.originatingImport && !isImportCall(links.originatingImport)) {
                            const helpfulRetry = checkTypeRelatedTo(getTypeOfSymbol(links.target), target, relation, 
                            /*errorNode*/
                            void 0);
                            if (helpfulRetry) {
                                const diag3 = createDiagnosticForNode(links.originatingImport, Diagnostics.Type_originates_at_this_import_A_namespace_style_import_cannot_be_called_or_constructed_and_will_cause_a_failure_at_runtime_Consider_using_a_default_import_or_import_require_here_instead);
                                relatedInformation = append(relatedInformation, diag3);
                            }
                        }
                    }
                    const diag2 = createDiagnosticForNodeFromMessageChain(getSourceFileOfNode(errorNode), errorNode, errorInfo, relatedInformation);
                    if (relatedInfo) {
                        addRelatedInfo(diag2, ...relatedInfo);
                    }
                    if (errorOutputContainer) {
                        (errorOutputContainer.errors || (errorOutputContainer.errors = [])).push(diag2);
                    }
                    if (!errorOutputContainer || !errorOutputContainer.skipLogging) {
                        diagnostics.add(diag2);
                    }
                }
                if (errorNode && errorOutputContainer && errorOutputContainer.skipLogging && result === 0 /* False */) {
                    Debug.assert(!!errorOutputContainer.errors, "missed opportunity to interact with error.");
                }
                return result !== 0 /* False */;
                function resetErrorInfo(saved) {
                    errorInfo = saved.errorInfo;
                    lastSkippedInfo = saved.lastSkippedInfo;
                    incompatibleStack = saved.incompatibleStack;
                    overrideNextErrorInfo = saved.overrideNextErrorInfo;
                    skipParentCounter = saved.skipParentCounter;
                    relatedInfo = saved.relatedInfo;
                }
                function captureErrorCalculationState() {
                    return {
                        errorInfo,
                        lastSkippedInfo,
                        incompatibleStack: incompatibleStack == null ? void 0 : incompatibleStack.slice(),
                        overrideNextErrorInfo,
                        skipParentCounter,
                        relatedInfo: relatedInfo == null ? void 0 : relatedInfo.slice()
                    };
                }
                function reportIncompatibleError(message, ...args) {
                    overrideNextErrorInfo++;
                    lastSkippedInfo = void 0;
                    (incompatibleStack || (incompatibleStack = [])).push([message, ...args]);
                }
                function reportIncompatibleStack() {
                    const stack = incompatibleStack || [];
                    incompatibleStack = void 0;
                    const info = lastSkippedInfo;
                    lastSkippedInfo = void 0;
                    if (stack.length === 1) {
                        reportError(...stack[0]);
                        if (info) {
                            reportRelationError(
                            /*message*/
                            void 0, ...info);
                        }
                        return;
                    }
                    let path = "";
                    const secondaryRootErrors = [];
                    while (stack.length) {
                        const [msg, ...args] = stack.pop();
                        switch (msg.code) {
                            case Diagnostics.Types_of_property_0_are_incompatible.code: {
                                if (path.indexOf("new ") === 0) {
                                    path = `(${path})`;
                                }
                                const str = "" + args[0];
                                if (path.length === 0) {
                                    path = `${str}`;
                                }
                                else if (isIdentifierText(str, getEmitScriptTarget(compilerOptions))) {
                                    path = `${path}.${str}`;
                                }
                                else if (str[0] === "[" && str[str.length - 1] === "]") {
                                    path = `${path}${str}`;
                                }
                                else {
                                    path = `${path}[${str}]`;
                                }
                                break;
                            }
                            case Diagnostics.Call_signature_return_types_0_and_1_are_incompatible.code:
                            case Diagnostics.Construct_signature_return_types_0_and_1_are_incompatible.code:
                            case Diagnostics.Call_signatures_with_no_arguments_have_incompatible_return_types_0_and_1.code:
                            case Diagnostics.Construct_signatures_with_no_arguments_have_incompatible_return_types_0_and_1.code: {
                                if (path.length === 0) {
                                    let mappedMsg = msg;
                                    if (msg.code === Diagnostics.Call_signatures_with_no_arguments_have_incompatible_return_types_0_and_1.code) {
                                        mappedMsg = Diagnostics.Call_signature_return_types_0_and_1_are_incompatible;
                                    }
                                    else if (msg.code === Diagnostics.Construct_signatures_with_no_arguments_have_incompatible_return_types_0_and_1.code) {
                                        mappedMsg = Diagnostics.Construct_signature_return_types_0_and_1_are_incompatible;
                                    }
                                    secondaryRootErrors.unshift([mappedMsg, args[0], args[1]]);
                                }
                                else {
                                    const prefix = msg.code === Diagnostics.Construct_signature_return_types_0_and_1_are_incompatible.code || msg.code === Diagnostics.Construct_signatures_with_no_arguments_have_incompatible_return_types_0_and_1.code ? "new " : "";
                                    const params = msg.code === Diagnostics.Call_signatures_with_no_arguments_have_incompatible_return_types_0_and_1.code || msg.code === Diagnostics.Construct_signatures_with_no_arguments_have_incompatible_return_types_0_and_1.code ? "" : "...";
                                    path = `${prefix}${path}(${params})`;
                                }
                                break;
                            }
                            case Diagnostics.Type_at_position_0_in_source_is_not_compatible_with_type_at_position_1_in_target.code: {
                                secondaryRootErrors.unshift([Diagnostics.Type_at_position_0_in_source_is_not_compatible_with_type_at_position_1_in_target, args[0], args[1]]);
                                break;
                            }
                            case Diagnostics.Type_at_positions_0_through_1_in_source_is_not_compatible_with_type_at_position_2_in_target.code: {
                                secondaryRootErrors.unshift([Diagnostics.Type_at_positions_0_through_1_in_source_is_not_compatible_with_type_at_position_2_in_target, args[0], args[1], args[2]]);
                                break;
                            }
                            default:
                                return Debug.fail(`Unhandled Diagnostic: ${msg.code}`);
                        }
                    }
                    if (path) {
                        reportError(path[path.length - 1] === ")" ? Diagnostics.The_types_returned_by_0_are_incompatible_between_these_types : Diagnostics.The_types_of_0_are_incompatible_between_these_types, path);
                    }
                    else {
                        secondaryRootErrors.shift();
                    }
                    for (const [msg, ...args] of secondaryRootErrors) {
                        const originalValue = msg.elidedInCompatabilityPyramid;
                        msg.elidedInCompatabilityPyramid = false;
                        reportError(msg, ...args);
                        msg.elidedInCompatabilityPyramid = originalValue;
                    }
                    if (info) {
                        reportRelationError(
                        /*message*/
                        void 0, ...info);
                    }
                }
                function reportError(message, ...args) {
                    Debug.assert(!!errorNode);
                    if (incompatibleStack)
                        reportIncompatibleStack();
                    if (message.elidedInCompatabilityPyramid)
                        return;
                    if (skipParentCounter === 0) {
                        errorInfo = chainDiagnosticMessages(errorInfo, message, ...args);
                    }
                    else {
                        skipParentCounter--;
                    }
                }
                function reportParentSkippedError(message, ...args) {
                    reportError(message, ...args);
                    skipParentCounter++;
                }
                function associateRelatedInfo(info) {
                    Debug.assert(!!errorInfo);
                    if (!relatedInfo) {
                        relatedInfo = [info];
                    }
                    else {
                        relatedInfo.push(info);
                    }
                }
                function reportRelationError(message, source2, target2) {
                    if (incompatibleStack)
                        reportIncompatibleStack();
                    const [sourceType, targetType] = getTypeNamesForErrorDisplay(source2, target2);
                    let generalizedSource = source2;
                    let generalizedSourceType = sourceType;
                    if (isLiteralType(source2) && !typeCouldHaveTopLevelSingletonTypes(target2)) {
                        generalizedSource = getBaseTypeOfLiteralType(source2);
                        Debug.assert(!isTypeAssignableTo(generalizedSource, target2), "generalized source shouldn't be assignable");
                        generalizedSourceType = getTypeNameForErrorDisplay(generalizedSource);
                    }
                    const targetFlags = target2.flags & 8388608 /* IndexedAccess */ && !(source2.flags & 8388608 /* IndexedAccess */) ? target2.objectType.flags : target2.flags;
                    if (targetFlags & 262144 /* TypeParameter */ && target2 !== markerSuperTypeForCheck && target2 !== markerSubTypeForCheck) {
                        const constraint = getBaseConstraintOfType(target2);
                        let needsOriginalSource;
                        if (constraint && (isTypeAssignableTo(generalizedSource, constraint) || (needsOriginalSource = isTypeAssignableTo(source2, constraint)))) {
                            reportError(Diagnostics._0_is_assignable_to_the_constraint_of_type_1_but_1_could_be_instantiated_with_a_different_subtype_of_constraint_2, needsOriginalSource ? sourceType : generalizedSourceType, targetType, typeToString(constraint));
                        }
                        else {
                            errorInfo = void 0;
                            reportError(Diagnostics._0_could_be_instantiated_with_an_arbitrary_type_which_could_be_unrelated_to_1, targetType, generalizedSourceType);
                        }
                    }
                    if (!message) {
                        if (relation === comparableRelation) {
                            message = Diagnostics.Type_0_is_not_comparable_to_type_1;
                        }
                        else if (sourceType === targetType) {
                            message = Diagnostics.Type_0_is_not_assignable_to_type_1_Two_different_types_with_this_name_exist_but_they_are_unrelated;
                        }
                        else if (exactOptionalPropertyTypes && getExactOptionalUnassignableProperties(source2, target2).length) {
                            message = Diagnostics.Type_0_is_not_assignable_to_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_types_of_the_target_s_properties;
                        }
                        else {
                            if (source2.flags & 128 /* StringLiteral */ && target2.flags & 1048576 /* Union */) {
                                const suggestedType = getSuggestedTypeForNonexistentStringLiteralType(source2, target2);
                                if (suggestedType) {
                                    reportError(Diagnostics.Type_0_is_not_assignable_to_type_1_Did_you_mean_2, generalizedSourceType, targetType, typeToString(suggestedType));
                                    return;
                                }
                            }
                            message = Diagnostics.Type_0_is_not_assignable_to_type_1;
                        }
                    }
                    else if (message === Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1 && exactOptionalPropertyTypes && getExactOptionalUnassignableProperties(source2, target2).length) {
                        message = Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_types_of_the_target_s_properties;
                    }
                    reportError(message, generalizedSourceType, targetType);
                }
                function tryElaborateErrorsForPrimitivesAndObjects(source2, target2) {
                    const sourceType = symbolValueDeclarationIsContextSensitive(source2.symbol) ? typeToString(source2, source2.symbol.valueDeclaration) : typeToString(source2);
                    const targetType = symbolValueDeclarationIsContextSensitive(target2.symbol) ? typeToString(target2, target2.symbol.valueDeclaration) : typeToString(target2);
                    if (globalStringType === source2 && stringType === target2 || globalNumberType === source2 && numberType === target2 || globalBooleanType === source2 && booleanType === target2 || getGlobalESSymbolType() === source2 && esSymbolType === target2) {
                        reportError(Diagnostics._0_is_a_primitive_but_1_is_a_wrapper_object_Prefer_using_0_when_possible, targetType, sourceType);
                    }
                }
                function tryElaborateArrayLikeErrors(source2, target2, reportErrors2) {
                    if (isTupleType(source2)) {
                        if (source2.target.readonly && isMutableArrayOrTuple(target2)) {
                            if (reportErrors2) {
                                reportError(Diagnostics.The_type_0_is_readonly_and_cannot_be_assigned_to_the_mutable_type_1, typeToString(source2), typeToString(target2));
                            }
                            return false;
                        }
                        return isArrayOrTupleType(target2);
                    }
                    if (isReadonlyArrayType(source2) && isMutableArrayOrTuple(target2)) {
                        if (reportErrors2) {
                            reportError(Diagnostics.The_type_0_is_readonly_and_cannot_be_assigned_to_the_mutable_type_1, typeToString(source2), typeToString(target2));
                        }
                        return false;
                    }
                    if (isTupleType(target2)) {
                        return isArrayType(source2);
                    }
                    return true;
                }
                function isRelatedToWorker(source2, target2, reportErrors2) {
                    return isRelatedTo(source2, target2, 3 /* Both */, reportErrors2);
                }
                function isRelatedTo(originalSource, originalTarget, recursionFlags = 3 /* Both */, reportErrors2 = false, headMessage2, intersectionState = 0 /* None */) {
                    if (originalSource === originalTarget)
                        return -1 /* True */;
                    if (originalSource.flags & 524288 /* Object */ && originalTarget.flags & 402784252 /* Primitive */) {
                        if (relation === comparableRelation && !(originalTarget.flags & 131072 /* Never */) && isSimpleTypeRelatedTo(originalTarget, originalSource, relation) || isSimpleTypeRelatedTo(originalSource, originalTarget, relation, reportErrors2 ? reportError : void 0)) {
                            return -1 /* True */;
                        }
                        if (reportErrors2) {
                            reportErrorResults(originalSource, originalTarget, originalSource, originalTarget, headMessage2);
                        }
                        return 0 /* False */;
                    }
                    const source2 = getNormalizedType(originalSource, 
                    /*writing*/
                    false);
                    let target2 = getNormalizedType(originalTarget, 
                    /*writing*/
                    true);
                    if (source2 === target2)
                        return -1 /* True */;
                    if (relation === identityRelation) {
                        if (source2.flags !== target2.flags)
                            return 0 /* False */;
                        if (source2.flags & 67358815 /* Singleton */)
                            return -1 /* True */;
                        traceUnionsOrIntersectionsTooLarge(source2, target2);
                        return recursiveTypeRelatedTo(source2, target2, 
                        /*reportErrors*/
                        false, 0 /* None */, recursionFlags);
                    }
                    if (source2.flags & 262144 /* TypeParameter */ && getConstraintOfType(source2) === target2) {
                        return -1 /* True */;
                    }
                    if (source2.flags & 470302716 /* DefinitelyNonNullable */ && target2.flags & 1048576 /* Union */) {
                        const types = target2.types;
                        const candidate = types.length === 2 && types[0].flags & 98304 /* Nullable */ ? types[1] : types.length === 3 && types[0].flags & 98304 /* Nullable */ && types[1].flags & 98304 /* Nullable */ ? types[2] : void 0;
                        if (candidate && !(candidate.flags & 98304 /* Nullable */)) {
                            target2 = getNormalizedType(candidate, 
                            /*writing*/
                            true);
                            if (source2 === target2)
                                return -1 /* True */;
                        }
                    }
                    if (relation === comparableRelation && !(target2.flags & 131072 /* Never */) && isSimpleTypeRelatedTo(target2, source2, relation) || isSimpleTypeRelatedTo(source2, target2, relation, reportErrors2 ? reportError : void 0))
                        return -1 /* True */;
                    if (source2.flags & 469499904 /* StructuredOrInstantiable */ || target2.flags & 469499904 /* StructuredOrInstantiable */) {
                        const isPerformingExcessPropertyChecks = !(intersectionState & 2 /* Target */) && (isObjectLiteralType2(source2) && getObjectFlags(source2) & 8192 /* FreshLiteral */);
                        if (isPerformingExcessPropertyChecks) {
                            if (hasExcessProperties(source2, target2, reportErrors2)) {
                                if (reportErrors2) {
                                    reportRelationError(headMessage2, source2, originalTarget.aliasSymbol ? originalTarget : target2);
                                }
                                return 0 /* False */;
                            }
                        }
                        const isPerformingCommonPropertyChecks = (relation !== comparableRelation || isUnitType(source2)) && !(intersectionState & 2 /* Target */) && source2.flags & (402784252 /* Primitive */ | 524288 /* Object */ | 2097152 /* Intersection */) && source2 !== globalObjectType && target2.flags & (524288 /* Object */ | 2097152 /* Intersection */) && isWeakType(target2) && (getPropertiesOfType(source2).length > 0 || typeHasCallOrConstructSignatures(source2));
                        const isComparingJsxAttributes = !!(getObjectFlags(source2) & 2048 /* JsxAttributes */);
                        if (isPerformingCommonPropertyChecks && !hasCommonProperties(source2, target2, isComparingJsxAttributes)) {
                            if (reportErrors2) {
                                const sourceString = typeToString(originalSource.aliasSymbol ? originalSource : source2);
                                const targetString = typeToString(originalTarget.aliasSymbol ? originalTarget : target2);
                                const calls = getSignaturesOfType(source2, 0 /* Call */);
                                const constructs = getSignaturesOfType(source2, 1 /* Construct */);
                                if (calls.length > 0 && isRelatedTo(getReturnTypeOfSignature(calls[0]), target2, 1 /* Source */, 
                                /*reportErrors*/
                                false) || constructs.length > 0 && isRelatedTo(getReturnTypeOfSignature(constructs[0]), target2, 1 /* Source */, 
                                /*reportErrors*/
                                false)) {
                                    reportError(Diagnostics.Value_of_type_0_has_no_properties_in_common_with_type_1_Did_you_mean_to_call_it, sourceString, targetString);
                                }
                                else {
                                    reportError(Diagnostics.Type_0_has_no_properties_in_common_with_type_1, sourceString, targetString);
                                }
                            }
                            return 0 /* False */;
                        }
                        traceUnionsOrIntersectionsTooLarge(source2, target2);
                        const skipCaching = source2.flags & 1048576 /* Union */ && source2.types.length < 4 && !(target2.flags & 1048576 /* Union */) || target2.flags & 1048576 /* Union */ && target2.types.length < 4 && !(source2.flags & 469499904 /* StructuredOrInstantiable */);
                        const result2 = skipCaching ? unionOrIntersectionRelatedTo(source2, target2, reportErrors2, intersectionState) : recursiveTypeRelatedTo(source2, target2, reportErrors2, intersectionState, recursionFlags);
                        if (result2) {
                            return result2;
                        }
                    }
                    if (reportErrors2) {
                        reportErrorResults(originalSource, originalTarget, source2, target2, headMessage2);
                    }
                    return 0 /* False */;
                }
                function reportErrorResults(originalSource, originalTarget, source2, target2, headMessage2) {
                    var _a2, _b;
                    const sourceHasBase = !!getSingleBaseForNonAugmentingSubtype(originalSource);
                    const targetHasBase = !!getSingleBaseForNonAugmentingSubtype(originalTarget);
                    source2 = originalSource.aliasSymbol || sourceHasBase ? originalSource : source2;
                    target2 = originalTarget.aliasSymbol || targetHasBase ? originalTarget : target2;
                    let maybeSuppress = overrideNextErrorInfo > 0;
                    if (maybeSuppress) {
                        overrideNextErrorInfo--;
                    }
                    if (source2.flags & 524288 /* Object */ && target2.flags & 524288 /* Object */) {
                        const currentError = errorInfo;
                        tryElaborateArrayLikeErrors(source2, target2, 
                        /*reportErrors*/
                        true);
                        if (errorInfo !== currentError) {
                            maybeSuppress = !!errorInfo;
                        }
                    }
                    if (source2.flags & 524288 /* Object */ && target2.flags & 402784252 /* Primitive */) {
                        tryElaborateErrorsForPrimitivesAndObjects(source2, target2);
                    }
                    else if (source2.symbol && source2.flags & 524288 /* Object */ && globalObjectType === source2) {
                        reportError(Diagnostics.The_Object_type_is_assignable_to_very_few_other_types_Did_you_mean_to_use_the_any_type_instead);
                    }
                    else if (getObjectFlags(source2) & 2048 /* JsxAttributes */ && target2.flags & 2097152 /* Intersection */) {
                        const targetTypes = target2.types;
                        const intrinsicAttributes = getJsxType(JsxNames.IntrinsicAttributes, errorNode);
                        const intrinsicClassAttributes = getJsxType(JsxNames.IntrinsicClassAttributes, errorNode);
                        if (!isErrorType(intrinsicAttributes) && !isErrorType(intrinsicClassAttributes) && (contains(targetTypes, intrinsicAttributes) || contains(targetTypes, intrinsicClassAttributes))) {
                            return;
                        }
                    }
                    else {
                        errorInfo = elaborateNeverIntersection(errorInfo, originalTarget);
                    }
                    if (!headMessage2 && maybeSuppress) {
                        lastSkippedInfo = [source2, target2];
                        return;
                    }
                    reportRelationError(headMessage2, source2, target2);
                    if (source2.flags & 262144 /* TypeParameter */ && ((_b = (_a2 = source2.symbol) == null ? void 0 : _a2.declarations) == null ? void 0 : _b[0]) && !getConstraintOfType(source2)) {
                        const syntheticParam = cloneTypeParameter(source2);
                        syntheticParam.constraint = instantiateType(target2, makeUnaryTypeMapper(source2, syntheticParam));
                        if (hasNonCircularBaseConstraint(syntheticParam)) {
                            const targetConstraintString = typeToString(target2, source2.symbol.declarations[0]);
                            associateRelatedInfo(createDiagnosticForNode(source2.symbol.declarations[0], Diagnostics.This_type_parameter_might_need_an_extends_0_constraint, targetConstraintString));
                        }
                    }
                }
                function traceUnionsOrIntersectionsTooLarge(source2, target2) {
                    if (!tracing) {
                        return;
                    }
                    if (source2.flags & 3145728 /* UnionOrIntersection */ && target2.flags & 3145728 /* UnionOrIntersection */) {
                        const sourceUnionOrIntersection = source2;
                        const targetUnionOrIntersection = target2;
                        if (sourceUnionOrIntersection.objectFlags & targetUnionOrIntersection.objectFlags & 32768 /* PrimitiveUnion */) {
                            return;
                        }
                        const sourceSize = sourceUnionOrIntersection.types.length;
                        const targetSize = targetUnionOrIntersection.types.length;
                        if (sourceSize * targetSize > 1e6) {
                            tracing.instant(tracing.Phase.CheckTypes, "traceUnionsOrIntersectionsTooLarge_DepthLimit", {
                                sourceId: source2.id,
                                sourceSize,
                                targetId: target2.id,
                                targetSize,
                                pos: errorNode == null ? void 0 : errorNode.pos,
                                end: errorNode == null ? void 0 : errorNode.end
                            });
                        }
                    }
                }
                function getTypeOfPropertyInTypes(types, name) {
                    const appendPropType = (propTypes, type) => {
                        var _a2;
                        type = getApparentType(type);
                        const prop = type.flags & 3145728 /* UnionOrIntersection */ ? getPropertyOfUnionOrIntersectionType(type, name) : getPropertyOfObjectType(type, name);
                        const propType = prop && getTypeOfSymbol(prop) || ((_a2 = getApplicableIndexInfoForName(type, name)) == null ? void 0 : _a2.type) || undefinedType;
                        return append(propTypes, propType);
                    };
                    return getUnionType(reduceLeft(types, appendPropType, 
                    /*initial*/
                    void 0) || emptyArray);
                }
                function hasExcessProperties(source2, target2, reportErrors2) {
                    var _a2;
                    if (!isExcessPropertyCheckTarget(target2) || !noImplicitAny && getObjectFlags(target2) & 4096 /* JSLiteral */) {
                        return false;
                    }
                    const isComparingJsxAttributes = !!(getObjectFlags(source2) & 2048 /* JsxAttributes */);
                    if ((relation === assignableRelation || relation === comparableRelation) && (isTypeSubsetOf(globalObjectType, target2) || !isComparingJsxAttributes && isEmptyObjectType(target2))) {
                        return false;
                    }
                    let reducedTarget = target2;
                    let checkTypes;
                    if (target2.flags & 1048576 /* Union */) {
                        reducedTarget = findMatchingDiscriminantType(source2, target2, isRelatedTo) || filterPrimitivesIfContainsNonPrimitive(target2);
                        checkTypes = reducedTarget.flags & 1048576 /* Union */ ? reducedTarget.types : [reducedTarget];
                    }
                    for (const prop of getPropertiesOfType(source2)) {
                        if (shouldCheckAsExcessProperty(prop, source2.symbol) && !isIgnoredJsxProperty(source2, prop)) {
                            if (!isKnownProperty(reducedTarget, prop.escapedName, isComparingJsxAttributes)) {
                                if (reportErrors2) {
                                    const errorTarget = filterType(reducedTarget, isExcessPropertyCheckTarget);
                                    if (!errorNode)
                                        return Debug.fail();
                                    if (isJsxAttributes(errorNode) || isJsxOpeningLikeElement(errorNode) || isJsxOpeningLikeElement(errorNode.parent)) {
                                        if (prop.valueDeclaration && isJsxAttribute(prop.valueDeclaration) && getSourceFileOfNode(errorNode) === getSourceFileOfNode(prop.valueDeclaration.name)) {
                                            errorNode = prop.valueDeclaration.name;
                                        }
                                        const propName = symbolToString(prop);
                                        const suggestionSymbol = getSuggestedSymbolForNonexistentJSXAttribute(propName, errorTarget);
                                        const suggestion = suggestionSymbol ? symbolToString(suggestionSymbol) : void 0;
                                        if (suggestion) {
                                            reportError(Diagnostics.Property_0_does_not_exist_on_type_1_Did_you_mean_2, propName, typeToString(errorTarget), suggestion);
                                        }
                                        else {
                                            reportError(Diagnostics.Property_0_does_not_exist_on_type_1, propName, typeToString(errorTarget));
                                        }
                                    }
                                    else {
                                        const objectLiteralDeclaration = ((_a2 = source2.symbol) == null ? void 0 : _a2.declarations) && firstOrUndefined(source2.symbol.declarations);
                                        let suggestion;
                                        if (prop.valueDeclaration && findAncestor(prop.valueDeclaration, (d) => d === objectLiteralDeclaration) && getSourceFileOfNode(objectLiteralDeclaration) === getSourceFileOfNode(errorNode)) {
                                            const propDeclaration = prop.valueDeclaration;
                                            Debug.assertNode(propDeclaration, isObjectLiteralElementLike);
                                            const name = propDeclaration.name;
                                            errorNode = name;
                                            if (isIdentifier(name)) {
                                                suggestion = getSuggestionForNonexistentProperty(name, errorTarget);
                                            }
                                        }
                                        if (suggestion !== void 0) {
                                            reportParentSkippedError(Diagnostics.Object_literal_may_only_specify_known_properties_but_0_does_not_exist_in_type_1_Did_you_mean_to_write_2, symbolToString(prop), typeToString(errorTarget), suggestion);
                                        }
                                        else {
                                            reportParentSkippedError(Diagnostics.Object_literal_may_only_specify_known_properties_and_0_does_not_exist_in_type_1, symbolToString(prop), typeToString(errorTarget));
                                        }
                                    }
                                }
                                return true;
                            }
                            if (checkTypes && !isRelatedTo(getTypeOfSymbol(prop), getTypeOfPropertyInTypes(checkTypes, prop.escapedName), 3 /* Both */, reportErrors2)) {
                                if (reportErrors2) {
                                    reportIncompatibleError(Diagnostics.Types_of_property_0_are_incompatible, symbolToString(prop));
                                }
                                return true;
                            }
                        }
                    }
                    return false;
                }
                function shouldCheckAsExcessProperty(prop, container) {
                    return prop.valueDeclaration && container.valueDeclaration && prop.valueDeclaration.parent === container.valueDeclaration;
                }
                function unionOrIntersectionRelatedTo(source2, target2, reportErrors2, intersectionState) {
                    if (source2.flags & 1048576 /* Union */) {
                        if (target2.flags & 1048576 /* Union */) {
                            const sourceOrigin = source2.origin;
                            if (sourceOrigin && sourceOrigin.flags & 2097152 /* Intersection */ && target2.aliasSymbol && contains(sourceOrigin.types, target2)) {
                                return -1 /* True */;
                            }
                            const targetOrigin = target2.origin;
                            if (targetOrigin && targetOrigin.flags & 1048576 /* Union */ && source2.aliasSymbol && contains(targetOrigin.types, source2)) {
                                return -1 /* True */;
                            }
                        }
                        return relation === comparableRelation ? someTypeRelatedToType(source2, target2, reportErrors2 && !(source2.flags & 402784252 /* Primitive */), intersectionState) : eachTypeRelatedToType(source2, target2, reportErrors2 && !(source2.flags & 402784252 /* Primitive */), intersectionState);
                    }
                    if (target2.flags & 1048576 /* Union */) {
                        return typeRelatedToSomeType(getRegularTypeOfObjectLiteral(source2), target2, reportErrors2 && !(source2.flags & 402784252 /* Primitive */) && !(target2.flags & 402784252 /* Primitive */), intersectionState);
                    }
                    if (target2.flags & 2097152 /* Intersection */) {
                        return typeRelatedToEachType(source2, target2, reportErrors2, 2 /* Target */);
                    }
                    if (relation === comparableRelation && target2.flags & 402784252 /* Primitive */) {
                        const constraints = sameMap(source2.types, (t) => t.flags & 465829888 /* Instantiable */ ? getBaseConstraintOfType(t) || unknownType : t);
                        if (constraints !== source2.types) {
                            source2 = getIntersectionType(constraints);
                            if (source2.flags & 131072 /* Never */) {
                                return 0 /* False */;
                            }
                            if (!(source2.flags & 2097152 /* Intersection */)) {
                                return isRelatedTo(source2, target2, 1 /* Source */, 
                                /*reportErrors*/
                                false) || isRelatedTo(target2, source2, 1 /* Source */, 
                                /*reportErrors*/
                                false);
                            }
                        }
                    }
                    return someTypeRelatedToType(source2, target2, 
                    /*reportErrors*/
                    false, 1 /* Source */);
                }
                function eachTypeRelatedToSomeType(source2, target2) {
                    let result2 = -1 /* True */;
                    const sourceTypes = source2.types;
                    for (const sourceType of sourceTypes) {
                        const related = typeRelatedToSomeType(sourceType, target2, 
                        /*reportErrors*/
                        false, 0 /* None */);
                        if (!related) {
                            return 0 /* False */;
                        }
                        result2 &= related;
                    }
                    return result2;
                }
                function typeRelatedToSomeType(source2, target2, reportErrors2, intersectionState) {
                    const targetTypes = target2.types;
                    if (target2.flags & 1048576 /* Union */) {
                        if (containsType(targetTypes, source2)) {
                            return -1 /* True */;
                        }
                        if (relation !== comparableRelation && getObjectFlags(target2) & 32768 /* PrimitiveUnion */ && !(source2.flags & 1024 /* EnumLiteral */) && (source2.flags & (128 /* StringLiteral */ | 512 /* BooleanLiteral */ | 2048 /* BigIntLiteral */) || (relation === subtypeRelation || relation === strictSubtypeRelation) && source2.flags & 256 /* NumberLiteral */)) {
                            const alternateForm = source2 === source2.regularType ? source2.freshType : source2.regularType;
                            const primitive = source2.flags & 128 /* StringLiteral */ ? stringType : source2.flags & 256 /* NumberLiteral */ ? numberType : source2.flags & 2048 /* BigIntLiteral */ ? bigintType : void 0;
                            return primitive && containsType(targetTypes, primitive) || alternateForm && containsType(targetTypes, alternateForm) ? -1 /* True */ : 0 /* False */;
                        }
                        const match = getMatchingUnionConstituentForType(target2, source2);
                        if (match) {
                            const related = isRelatedTo(source2, match, 2 /* Target */, 
                            /*reportErrors*/
                            false, 
                            /*headMessage*/
                            void 0, intersectionState);
                            if (related) {
                                return related;
                            }
                        }
                    }
                    for (const type of targetTypes) {
                        const related = isRelatedTo(source2, type, 2 /* Target */, 
                        /*reportErrors*/
                        false, 
                        /*headMessage*/
                        void 0, intersectionState);
                        if (related) {
                            return related;
                        }
                    }
                    if (reportErrors2) {
                        const bestMatchingType = getBestMatchingType(source2, target2, isRelatedTo);
                        if (bestMatchingType) {
                            isRelatedTo(source2, bestMatchingType, 2 /* Target */, 
                            /*reportErrors*/
                            true, 
                            /*headMessage*/
                            void 0, intersectionState);
                        }
                    }
                    return 0 /* False */;
                }
                function typeRelatedToEachType(source2, target2, reportErrors2, intersectionState) {
                    let result2 = -1 /* True */;
                    const targetTypes = target2.types;
                    for (const targetType of targetTypes) {
                        const related = isRelatedTo(source2, targetType, 2 /* Target */, reportErrors2, 
                        /*headMessage*/
                        void 0, intersectionState);
                        if (!related) {
                            return 0 /* False */;
                        }
                        result2 &= related;
                    }
                    return result2;
                }
                function someTypeRelatedToType(source2, target2, reportErrors2, intersectionState) {
                    const sourceTypes = source2.types;
                    if (source2.flags & 1048576 /* Union */ && containsType(sourceTypes, target2)) {
                        return -1 /* True */;
                    }
                    const len = sourceTypes.length;
                    for (let i = 0; i < len; i++) {
                        const related = isRelatedTo(sourceTypes[i], target2, 1 /* Source */, reportErrors2 && i === len - 1, 
                        /*headMessage*/
                        void 0, intersectionState);
                        if (related) {
                            return related;
                        }
                    }
                    return 0 /* False */;
                }
                function getUndefinedStrippedTargetIfNeeded(source2, target2) {
                    if (source2.flags & 1048576 /* Union */ && target2.flags & 1048576 /* Union */ && !(source2.types[0].flags & 32768 /* Undefined */) && target2.types[0].flags & 32768 /* Undefined */) {
                        return extractTypesOfKind(target2, ~32768 /* Undefined */);
                    }
                    return target2;
                }
                function eachTypeRelatedToType(source2, target2, reportErrors2, intersectionState) {
                    let result2 = -1 /* True */;
                    const sourceTypes = source2.types;
                    const undefinedStrippedTarget = getUndefinedStrippedTargetIfNeeded(source2, target2);
                    for (let i = 0; i < sourceTypes.length; i++) {
                        const sourceType = sourceTypes[i];
                        if (undefinedStrippedTarget.flags & 1048576 /* Union */ && sourceTypes.length >= undefinedStrippedTarget.types.length && sourceTypes.length % undefinedStrippedTarget.types.length === 0) {
                            const related2 = isRelatedTo(sourceType, undefinedStrippedTarget.types[i % undefinedStrippedTarget.types.length], 3 /* Both */, 
                            /*reportErrors*/
                            false, 
                            /*headMessage*/
                            void 0, intersectionState);
                            if (related2) {
                                result2 &= related2;
                                continue;
                            }
                        }
                        const related = isRelatedTo(sourceType, target2, 1 /* Source */, reportErrors2, 
                        /*headMessage*/
                        void 0, intersectionState);
                        if (!related) {
                            return 0 /* False */;
                        }
                        result2 &= related;
                    }
                    return result2;
                }
                function typeArgumentsRelatedTo(sources = emptyArray, targets = emptyArray, variances = emptyArray, reportErrors2, intersectionState) {
                    if (sources.length !== targets.length && relation === identityRelation) {
                        return 0 /* False */;
                    }
                    const length2 = sources.length <= targets.length ? sources.length : targets.length;
                    let result2 = -1 /* True */;
                    for (let i = 0; i < length2; i++) {
                        const varianceFlags = i < variances.length ? variances[i] : 1 /* Covariant */;
                        const variance = varianceFlags & 7 /* VarianceMask */;
                        if (variance !== 4 /* Independent */) {
                            const s = sources[i];
                            const t = targets[i];
                            let related = -1 /* True */;
                            if (varianceFlags & 8 /* Unmeasurable */) {
                                related = relation === identityRelation ? isRelatedTo(s, t, 3 /* Both */, 
                                /*reportErrors*/
                                false) : compareTypesIdentical(s, t);
                            }
                            else if (variance === 1 /* Covariant */) {
                                related = isRelatedTo(s, t, 3 /* Both */, reportErrors2, 
                                /*headMessage*/
                                void 0, intersectionState);
                            }
                            else if (variance === 2 /* Contravariant */) {
                                related = isRelatedTo(t, s, 3 /* Both */, reportErrors2, 
                                /*headMessage*/
                                void 0, intersectionState);
                            }
                            else if (variance === 3 /* Bivariant */) {
                                related = isRelatedTo(t, s, 3 /* Both */, 
                                /*reportErrors*/
                                false);
                                if (!related) {
                                    related = isRelatedTo(s, t, 3 /* Both */, reportErrors2, 
                                    /*headMessage*/
                                    void 0, intersectionState);
                                }
                            }
                            else {
                                related = isRelatedTo(s, t, 3 /* Both */, reportErrors2, 
                                /*headMessage*/
                                void 0, intersectionState);
                                if (related) {
                                    related &= isRelatedTo(t, s, 3 /* Both */, reportErrors2, 
                                    /*headMessage*/
                                    void 0, intersectionState);
                                }
                            }
                            if (!related) {
                                return 0 /* False */;
                            }
                            result2 &= related;
                        }
                    }
                    return result2;
                }
                function recursiveTypeRelatedTo(source2, target2, reportErrors2, intersectionState, recursionFlags) {
                    var _a2, _b, _c;
                    if (overflow) {
                        return 0 /* False */;
                    }
                    const id = getRelationKey(source2, target2, intersectionState, relation, 
                    /*ignoreConstraints*/
                    false);
                    const entry = relation.get(id);
                    if (entry !== void 0) {
                        if (reportErrors2 && entry & 2 /* Failed */ && !(entry & 4 /* Reported */)) {
                        }
                        else {
                            if (outofbandVarianceMarkerHandler) {
                                const saved = entry & 24 /* ReportsMask */;
                                if (saved & 8 /* ReportsUnmeasurable */) {
                                    instantiateType(source2, reportUnmeasurableMapper);
                                }
                                if (saved & 16 /* ReportsUnreliable */) {
                                    instantiateType(source2, reportUnreliableMapper);
                                }
                            }
                            return entry & 1 /* Succeeded */ ? -1 /* True */ : 0 /* False */;
                        }
                    }
                    if (relationCount <= 0) {
                        overflow = true;
                        return 0 /* False */;
                    }
                    if (!maybeKeys) {
                        maybeKeys = [];
                        maybeKeysSet = /* @__PURE__ */ new Set();
                        sourceStack = [];
                        targetStack = [];
                    }
                    else {
                        if (maybeKeysSet.has(id)) {
                            return 3 /* Maybe */;
                        }
                        const broadestEquivalentId = id.startsWith("*") ? getRelationKey(source2, target2, intersectionState, relation, 
                        /*ignoreConstraints*/
                        true) : void 0;
                        if (broadestEquivalentId && maybeKeysSet.has(broadestEquivalentId)) {
                            return 3 /* Maybe */;
                        }
                        if (sourceDepth === 100 || targetDepth === 100) {
                            overflow = true;
                            return 0 /* False */;
                        }
                    }
                    const maybeStart = maybeCount;
                    maybeKeys[maybeCount] = id;
                    maybeKeysSet.add(id);
                    maybeCount++;
                    const saveExpandingFlags = expandingFlags;
                    if (recursionFlags & 1 /* Source */) {
                        sourceStack[sourceDepth] = source2;
                        sourceDepth++;
                        if (!(expandingFlags & 1 /* Source */) && isDeeplyNestedType(source2, sourceStack, sourceDepth))
                            expandingFlags |= 1 /* Source */;
                    }
                    if (recursionFlags & 2 /* Target */) {
                        targetStack[targetDepth] = target2;
                        targetDepth++;
                        if (!(expandingFlags & 2 /* Target */) && isDeeplyNestedType(target2, targetStack, targetDepth))
                            expandingFlags |= 2 /* Target */;
                    }
                    let originalHandler;
                    let propagatingVarianceFlags = 0;
                    if (outofbandVarianceMarkerHandler) {
                        originalHandler = outofbandVarianceMarkerHandler;
                        outofbandVarianceMarkerHandler = (onlyUnreliable) => {
                            propagatingVarianceFlags |= onlyUnreliable ? 16 /* ReportsUnreliable */ : 8 /* ReportsUnmeasurable */;
                            return originalHandler(onlyUnreliable);
                        };
                    }
                    let result2;
                    if (expandingFlags === 3 /* Both */) {
                        (_a2 = tracing) == null ? void 0 : _a2.instant(tracing.Phase.CheckTypes, "recursiveTypeRelatedTo_DepthLimit", {
                            sourceId: source2.id,
                            sourceIdStack: sourceStack.map((t) => t.id),
                            targetId: target2.id,
                            targetIdStack: targetStack.map((t) => t.id),
                            depth: sourceDepth,
                            targetDepth
                        });
                        result2 = 3 /* Maybe */;
                    }
                    else {
                        (_b = tracing) == null ? void 0 : _b.push(tracing.Phase.CheckTypes, "structuredTypeRelatedTo", { sourceId: source2.id, targetId: target2.id });
                        result2 = structuredTypeRelatedTo(source2, target2, reportErrors2, intersectionState);
                        (_c = tracing) == null ? void 0 : _c.pop();
                    }
                    if (outofbandVarianceMarkerHandler) {
                        outofbandVarianceMarkerHandler = originalHandler;
                    }
                    if (recursionFlags & 1 /* Source */) {
                        sourceDepth--;
                    }
                    if (recursionFlags & 2 /* Target */) {
                        targetDepth--;
                    }
                    expandingFlags = saveExpandingFlags;
                    if (result2) {
                        if (result2 === -1 /* True */ || sourceDepth === 0 && targetDepth === 0) {
                            if (result2 === -1 /* True */ || result2 === 3 /* Maybe */) {
                                resetMaybeStack(
                                /*markAllAsSucceeded*/
                                true);
                            }
                            else {
                                resetMaybeStack(
                                /*markAllAsSucceeded*/
                                false);
                            }
                        }
                    }
                    else {
                        relation.set(id, (reportErrors2 ? 4 /* Reported */ : 0) | 2 /* Failed */ | propagatingVarianceFlags);
                        relationCount--;
                        resetMaybeStack(
                        /*markAllAsSucceeded*/
                        false);
                    }
                    return result2;
                    function resetMaybeStack(markAllAsSucceeded) {
                        for (let i = maybeStart; i < maybeCount; i++) {
                            maybeKeysSet.delete(maybeKeys[i]);
                            if (markAllAsSucceeded) {
                                relation.set(maybeKeys[i], 1 /* Succeeded */ | propagatingVarianceFlags);
                                relationCount--;
                            }
                        }
                        maybeCount = maybeStart;
                    }
                }
                function structuredTypeRelatedTo(source2, target2, reportErrors2, intersectionState) {
                    const saveErrorInfo = captureErrorCalculationState();
                    let result2 = structuredTypeRelatedToWorker(source2, target2, reportErrors2, intersectionState, saveErrorInfo);
                    if (relation !== identityRelation) {
                        if (!result2 && (source2.flags & 2097152 /* Intersection */ || source2.flags & 262144 /* TypeParameter */ && target2.flags & 1048576 /* Union */)) {
                            const constraint = getEffectiveConstraintOfIntersection(source2.flags & 2097152 /* Intersection */ ? source2.types : [source2], !!(target2.flags & 1048576 /* Union */));
                            if (constraint && everyType(constraint, (c) => c !== source2)) {
                                result2 = isRelatedTo(constraint, target2, 1 /* Source */, 
                                /*reportErrors*/
                                false, 
                                /*headMessage*/
                                void 0, intersectionState);
                            }
                        }
                        if (result2 && !(intersectionState & 2 /* Target */) && target2.flags & 2097152 /* Intersection */ && !isGenericObjectType(target2) && source2.flags & (524288 /* Object */ | 2097152 /* Intersection */)) {
                            result2 &= propertiesRelatedTo(source2, target2, reportErrors2, 
                            /*excludedProperties*/
                            void 0, 
                            /*optionalsOnly*/
                            false, 0 /* None */);
                            if (result2 && isObjectLiteralType2(source2) && getObjectFlags(source2) & 8192 /* FreshLiteral */) {
                                result2 &= indexSignaturesRelatedTo(source2, target2, 
                                /*sourceIsPrimitive*/
                                false, reportErrors2, 0 /* None */);
                            }
                        }
                        else if (result2 && isNonGenericObjectType(target2) && !isArrayOrTupleType(target2) && source2.flags & 2097152 /* Intersection */ && getApparentType(source2).flags & 3670016 /* StructuredType */ && !some(source2.types, (t) => t === target2 || !!(getObjectFlags(t) & 262144 /* NonInferrableType */))) {
                            result2 &= propertiesRelatedTo(source2, target2, reportErrors2, 
                            /*excludedProperties*/
                            void 0, 
                            /*optionalsOnly*/
                            true, intersectionState);
                        }
                    }
                    if (result2) {
                        resetErrorInfo(saveErrorInfo);
                    }
                    return result2;
                }
                function getApparentMappedTypeKeys(nameType, targetType) {
                    const modifiersType = getApparentType(getModifiersTypeFromMappedType(targetType));
                    const mappedKeys = [];
                    forEachMappedTypePropertyKeyTypeAndIndexSignatureKeyType(modifiersType, 8576 /* StringOrNumberLiteralOrUnique */, 
                    /*stringsOnly*/
                    false, (t) => void mappedKeys.push(instantiateType(nameType, appendTypeMapping(targetType.mapper, getTypeParameterFromMappedType(targetType), t))));
                    return getUnionType(mappedKeys);
                }
                function structuredTypeRelatedToWorker(source2, target2, reportErrors2, intersectionState, saveErrorInfo) {
                    let result2;
                    let originalErrorInfo;
                    let varianceCheckFailed = false;
                    let sourceFlags = source2.flags;
                    const targetFlags = target2.flags;
                    if (relation === identityRelation) {
                        if (sourceFlags & 3145728 /* UnionOrIntersection */) {
                            let result3 = eachTypeRelatedToSomeType(source2, target2);
                            if (result3) {
                                result3 &= eachTypeRelatedToSomeType(target2, source2);
                            }
                            return result3;
                        }
                        if (sourceFlags & 4194304 /* Index */) {
                            return isRelatedTo(source2.type, target2.type, 3 /* Both */, 
                            /*reportErrors*/
                            false);
                        }
                        if (sourceFlags & 8388608 /* IndexedAccess */) {
                            if (result2 = isRelatedTo(source2.objectType, target2.objectType, 3 /* Both */, 
                            /*reportErrors*/
                            false)) {
                                if (result2 &= isRelatedTo(source2.indexType, target2.indexType, 3 /* Both */, 
                                /*reportErrors*/
                                false)) {
                                    return result2;
                                }
                            }
                        }
                        if (sourceFlags & 16777216 /* Conditional */) {
                            if (source2.root.isDistributive === target2.root.isDistributive) {
                                if (result2 = isRelatedTo(source2.checkType, target2.checkType, 3 /* Both */, 
                                /*reportErrors*/
                                false)) {
                                    if (result2 &= isRelatedTo(source2.extendsType, target2.extendsType, 3 /* Both */, 
                                    /*reportErrors*/
                                    false)) {
                                        if (result2 &= isRelatedTo(getTrueTypeFromConditionalType(source2), getTrueTypeFromConditionalType(target2), 3 /* Both */, 
                                        /*reportErrors*/
                                        false)) {
                                            if (result2 &= isRelatedTo(getFalseTypeFromConditionalType(source2), getFalseTypeFromConditionalType(target2), 3 /* Both */, 
                                            /*reportErrors*/
                                            false)) {
                                                return result2;
                                            }
                                        }
                                    }
                                }
                            }
                        }
                        if (sourceFlags & 33554432 /* Substitution */) {
                            if (result2 = isRelatedTo(source2.baseType, target2.baseType, 3 /* Both */, 
                            /*reportErrors*/
                            false)) {
                                if (result2 &= isRelatedTo(source2.constraint, target2.constraint, 3 /* Both */, 
                                /*reportErrors*/
                                false)) {
                                    return result2;
                                }
                            }
                        }
                        if (!(sourceFlags & 524288 /* Object */)) {
                            return 0 /* False */;
                        }
                    }
                    else if (sourceFlags & 3145728 /* UnionOrIntersection */ || targetFlags & 3145728 /* UnionOrIntersection */) {
                        if (result2 = unionOrIntersectionRelatedTo(source2, target2, reportErrors2, intersectionState)) {
                            return result2;
                        }
                        if (!(sourceFlags & 465829888 /* Instantiable */ || sourceFlags & 524288 /* Object */ && targetFlags & 1048576 /* Union */ || sourceFlags & 2097152 /* Intersection */ && targetFlags & (524288 /* Object */ | 1048576 /* Union */ | 465829888 /* Instantiable */))) {
                            return 0 /* False */;
                        }
                    }
                    if (sourceFlags & (524288 /* Object */ | 16777216 /* Conditional */) && source2.aliasSymbol && source2.aliasTypeArguments && source2.aliasSymbol === target2.aliasSymbol && !(isMarkerType(source2) || isMarkerType(target2))) {
                        const variances = getAliasVariances(source2.aliasSymbol);
                        if (variances === emptyArray) {
                            return 1 /* Unknown */;
                        }
                        const params = getSymbolLinks(source2.aliasSymbol).typeParameters;
                        const minParams = getMinTypeArgumentCount(params);
                        const sourceTypes = fillMissingTypeArguments(source2.aliasTypeArguments, params, minParams, isInJSFile(source2.aliasSymbol.valueDeclaration));
                        const targetTypes = fillMissingTypeArguments(target2.aliasTypeArguments, params, minParams, isInJSFile(source2.aliasSymbol.valueDeclaration));
                        const varianceResult = relateVariances(sourceTypes, targetTypes, variances, intersectionState);
                        if (varianceResult !== void 0) {
                            return varianceResult;
                        }
                    }
                    if (isSingleElementGenericTupleType(source2) && !source2.target.readonly && (result2 = isRelatedTo(getTypeArguments(source2)[0], target2, 1 /* Source */)) || isSingleElementGenericTupleType(target2) && (target2.target.readonly || isMutableArrayOrTuple(getBaseConstraintOfType(source2) || source2)) && (result2 = isRelatedTo(source2, getTypeArguments(target2)[0], 2 /* Target */))) {
                        return result2;
                    }
                    if (targetFlags & 262144 /* TypeParameter */) {
                        if (getObjectFlags(source2) & 32 /* Mapped */ && !source2.declaration.nameType && isRelatedTo(getIndexType(target2), getConstraintTypeFromMappedType(source2), 3 /* Both */)) {
                            if (!(getMappedTypeModifiers(source2) & 4 /* IncludeOptional */)) {
                                const templateType = getTemplateTypeFromMappedType(source2);
                                const indexedAccessType = getIndexedAccessType(target2, getTypeParameterFromMappedType(source2));
                                if (result2 = isRelatedTo(templateType, indexedAccessType, 3 /* Both */, reportErrors2)) {
                                    return result2;
                                }
                            }
                        }
                        if (relation === comparableRelation && sourceFlags & 262144 /* TypeParameter */) {
                            let constraint = getConstraintOfTypeParameter(source2);
                            if (constraint) {
                                while (constraint && someType(constraint, (c) => !!(c.flags & 262144 /* TypeParameter */))) {
                                    if (result2 = isRelatedTo(constraint, target2, 1 /* Source */, 
                                    /*reportErrors*/
                                    false)) {
                                        return result2;
                                    }
                                    constraint = getConstraintOfTypeParameter(constraint);
                                }
                            }
                            return 0 /* False */;
                        }
                    }
                    else if (targetFlags & 4194304 /* Index */) {
                        const targetType = target2.type;
                        if (sourceFlags & 4194304 /* Index */) {
                            if (result2 = isRelatedTo(targetType, source2.type, 3 /* Both */, 
                            /*reportErrors*/
                            false)) {
                                return result2;
                            }
                        }
                        if (isTupleType(targetType)) {
                            if (result2 = isRelatedTo(source2, getKnownKeysOfTupleType(targetType), 2 /* Target */, reportErrors2)) {
                                return result2;
                            }
                        }
                        else {
                            const constraint = getSimplifiedTypeOrConstraint(targetType);
                            if (constraint) {
                                if (isRelatedTo(source2, getIndexType(constraint, target2.indexFlags | 4 /* NoReducibleCheck */), 2 /* Target */, reportErrors2) === -1 /* True */) {
                                    return -1 /* True */;
                                }
                            }
                            else if (isGenericMappedType(targetType)) {
                                const nameType = getNameTypeFromMappedType(targetType);
                                const constraintType = getConstraintTypeFromMappedType(targetType);
                                let targetKeys;
                                if (nameType && isMappedTypeWithKeyofConstraintDeclaration(targetType)) {
                                    const mappedKeys = getApparentMappedTypeKeys(nameType, targetType);
                                    targetKeys = getUnionType([mappedKeys, nameType]);
                                }
                                else {
                                    targetKeys = nameType || constraintType;
                                }
                                if (isRelatedTo(source2, targetKeys, 2 /* Target */, reportErrors2) === -1 /* True */) {
                                    return -1 /* True */;
                                }
                            }
                        }
                    }
                    else if (targetFlags & 8388608 /* IndexedAccess */) {
                        if (sourceFlags & 8388608 /* IndexedAccess */) {
                            if (result2 = isRelatedTo(source2.objectType, target2.objectType, 3 /* Both */, reportErrors2)) {
                                result2 &= isRelatedTo(source2.indexType, target2.indexType, 3 /* Both */, reportErrors2);
                            }
                            if (result2) {
                                return result2;
                            }
                            if (reportErrors2) {
                                originalErrorInfo = errorInfo;
                            }
                        }
                        if (relation === assignableRelation || relation === comparableRelation) {
                            const objectType = target2.objectType;
                            const indexType = target2.indexType;
                            const baseObjectType = getBaseConstraintOfType(objectType) || objectType;
                            const baseIndexType = getBaseConstraintOfType(indexType) || indexType;
                            if (!isGenericObjectType(baseObjectType) && !isGenericIndexType(baseIndexType)) {
                                const accessFlags = 4 /* Writing */ | (baseObjectType !== objectType ? 2 /* NoIndexSignatures */ : 0);
                                const constraint = getIndexedAccessTypeOrUndefined(baseObjectType, baseIndexType, accessFlags);
                                if (constraint) {
                                    if (reportErrors2 && originalErrorInfo) {
                                        resetErrorInfo(saveErrorInfo);
                                    }
                                    if (result2 = isRelatedTo(source2, constraint, 2 /* Target */, reportErrors2, 
                                    /*headMessage*/
                                    void 0, intersectionState)) {
                                        return result2;
                                    }
                                    if (reportErrors2 && originalErrorInfo && errorInfo) {
                                        errorInfo = countMessageChainBreadth([originalErrorInfo]) <= countMessageChainBreadth([errorInfo]) ? originalErrorInfo : errorInfo;
                                    }
                                }
                            }
                        }
                        if (reportErrors2) {
                            originalErrorInfo = void 0;
                        }
                    }
                    else if (isGenericMappedType(target2) && relation !== identityRelation) {
                        const keysRemapped = !!target2.declaration.nameType;
                        const templateType = getTemplateTypeFromMappedType(target2);
                        const modifiers = getMappedTypeModifiers(target2);
                        if (!(modifiers & 8 /* ExcludeOptional */)) {
                            if (!keysRemapped && templateType.flags & 8388608 /* IndexedAccess */ && templateType.objectType === source2 && templateType.indexType === getTypeParameterFromMappedType(target2)) {
                                return -1 /* True */;
                            }
                            if (!isGenericMappedType(source2)) {
                                const targetKeys = keysRemapped ? getNameTypeFromMappedType(target2) : getConstraintTypeFromMappedType(target2);
                                const sourceKeys = getIndexType(source2, 2 /* NoIndexSignatures */);
                                const includeOptional = modifiers & 4 /* IncludeOptional */;
                                const filteredByApplicability = includeOptional ? intersectTypes(targetKeys, sourceKeys) : void 0;
                                if (includeOptional ? !(filteredByApplicability.flags & 131072 /* Never */) : isRelatedTo(targetKeys, sourceKeys, 3 /* Both */)) {
                                    const templateType2 = getTemplateTypeFromMappedType(target2);
                                    const typeParameter = getTypeParameterFromMappedType(target2);
                                    const nonNullComponent = extractTypesOfKind(templateType2, ~98304 /* Nullable */);
                                    if (!keysRemapped && nonNullComponent.flags & 8388608 /* IndexedAccess */ && nonNullComponent.indexType === typeParameter) {
                                        if (result2 = isRelatedTo(source2, nonNullComponent.objectType, 2 /* Target */, reportErrors2)) {
                                            return result2;
                                        }
                                    }
                                    else {
                                        const indexingType = keysRemapped ? filteredByApplicability || targetKeys : filteredByApplicability ? getIntersectionType([filteredByApplicability, typeParameter]) : typeParameter;
                                        const indexedAccessType = getIndexedAccessType(source2, indexingType);
                                        if (result2 = isRelatedTo(indexedAccessType, templateType2, 3 /* Both */, reportErrors2)) {
                                            return result2;
                                        }
                                    }
                                }
                                originalErrorInfo = errorInfo;
                                resetErrorInfo(saveErrorInfo);
                            }
                        }
                    }
                    else if (targetFlags & 16777216 /* Conditional */) {
                        if (isDeeplyNestedType(target2, targetStack, targetDepth, 10)) {
                            return 3 /* Maybe */;
                        }
                        const c = target2;
                        if (!c.root.inferTypeParameters && !isDistributionDependent(c.root) && !(source2.flags & 16777216 /* Conditional */ && source2.root === c.root)) {
                            const skipTrue = !isTypeAssignableTo(getPermissiveInstantiation(c.checkType), getPermissiveInstantiation(c.extendsType));
                            const skipFalse = !skipTrue && isTypeAssignableTo(getRestrictiveInstantiation(c.checkType), getRestrictiveInstantiation(c.extendsType));
                            if (result2 = skipTrue ? -1 /* True */ : isRelatedTo(source2, getTrueTypeFromConditionalType(c), 2 /* Target */, 
                            /*reportErrors*/
                            false, 
                            /*headMessage*/
                            void 0, intersectionState)) {
                                result2 &= skipFalse ? -1 /* True */ : isRelatedTo(source2, getFalseTypeFromConditionalType(c), 2 /* Target */, 
                                /*reportErrors*/
                                false, 
                                /*headMessage*/
                                void 0, intersectionState);
                                if (result2) {
                                    return result2;
                                }
                            }
                        }
                    }
                    else if (targetFlags & 134217728 /* TemplateLiteral */) {
                        if (sourceFlags & 134217728 /* TemplateLiteral */) {
                            if (relation === comparableRelation) {
                                return templateLiteralTypesDefinitelyUnrelated(source2, target2) ? 0 /* False */ : -1 /* True */;
                            }
                            instantiateType(source2, reportUnreliableMapper);
                        }
                        if (isTypeMatchedByTemplateLiteralType(source2, target2)) {
                            return -1 /* True */;
                        }
                    }
                    else if (target2.flags & 268435456 /* StringMapping */) {
                        if (!(source2.flags & 268435456 /* StringMapping */)) {
                            if (isMemberOfStringMapping(source2, target2)) {
                                return -1 /* True */;
                            }
                        }
                    }
                    if (sourceFlags & 8650752 /* TypeVariable */) {
                        if (!(sourceFlags & 8388608 /* IndexedAccess */ && targetFlags & 8388608 /* IndexedAccess */)) {
                            const constraint = getConstraintOfType(source2) || unknownType;
                            if (result2 = isRelatedTo(constraint, target2, 1 /* Source */, 
                            /*reportErrors*/
                            false, 
                            /*headMessage*/
                            void 0, intersectionState)) {
                                return result2;
                            }
                            else if (result2 = isRelatedTo(getTypeWithThisArgument(constraint, source2), target2, 1 /* Source */, reportErrors2 && constraint !== unknownType && !(targetFlags & sourceFlags & 262144 /* TypeParameter */), 
                            /*headMessage*/
                            void 0, intersectionState)) {
                                return result2;
                            }
                            if (isMappedTypeGenericIndexedAccess(source2)) {
                                const indexConstraint = getConstraintOfType(source2.indexType);
                                if (indexConstraint) {
                                    if (result2 = isRelatedTo(getIndexedAccessType(source2.objectType, indexConstraint), target2, 1 /* Source */, reportErrors2)) {
                                        return result2;
                                    }
                                }
                            }
                        }
                    }
                    else if (sourceFlags & 4194304 /* Index */) {
                        const isDeferredMappedIndex = shouldDeferIndexType(source2.type, source2.indexFlags) && getObjectFlags(source2.type) & 32 /* Mapped */;
                        if (result2 = isRelatedTo(keyofConstraintType, target2, 1 /* Source */, reportErrors2 && !isDeferredMappedIndex)) {
                            return result2;
                        }
                        if (isDeferredMappedIndex) {
                            const mappedType = source2.type;
                            const nameType = getNameTypeFromMappedType(mappedType);
                            const sourceMappedKeys = nameType && isMappedTypeWithKeyofConstraintDeclaration(mappedType) ? getApparentMappedTypeKeys(nameType, mappedType) : nameType || getConstraintTypeFromMappedType(mappedType);
                            if (result2 = isRelatedTo(sourceMappedKeys, target2, 1 /* Source */, reportErrors2)) {
                                return result2;
                            }
                        }
                    }
                    else if (sourceFlags & 134217728 /* TemplateLiteral */ && !(targetFlags & 524288 /* Object */)) {
                        if (!(targetFlags & 134217728 /* TemplateLiteral */)) {
                            const constraint = getBaseConstraintOfType(source2);
                            if (constraint && constraint !== source2 && (result2 = isRelatedTo(constraint, target2, 1 /* Source */, reportErrors2))) {
                                return result2;
                            }
                        }
                    }
                    else if (sourceFlags & 268435456 /* StringMapping */) {
                        if (targetFlags & 268435456 /* StringMapping */) {
                            if (source2.symbol !== target2.symbol) {
                                return 0 /* False */;
                            }
                            if (result2 = isRelatedTo(source2.type, target2.type, 3 /* Both */, reportErrors2)) {
                                return result2;
                            }
                        }
                        else {
                            const constraint = getBaseConstraintOfType(source2);
                            if (constraint && (result2 = isRelatedTo(constraint, target2, 1 /* Source */, reportErrors2))) {
                                return result2;
                            }
                        }
                    }
                    else if (sourceFlags & 16777216 /* Conditional */) {
                        if (isDeeplyNestedType(source2, sourceStack, sourceDepth, 10)) {
                            return 3 /* Maybe */;
                        }
                        if (targetFlags & 16777216 /* Conditional */) {
                            const sourceParams = source2.root.inferTypeParameters;
                            let sourceExtends = source2.extendsType;
                            let mapper;
                            if (sourceParams) {
                                const ctx = createInferenceContext(sourceParams, 
                                /*signature*/
                                void 0, 0 /* None */, isRelatedToWorker);
                                inferTypes(ctx.inferences, target2.extendsType, sourceExtends, 512 /* NoConstraints */ | 1024 /* AlwaysStrict */);
                                sourceExtends = instantiateType(sourceExtends, ctx.mapper);
                                mapper = ctx.mapper;
                            }
                            if (isTypeIdenticalTo(sourceExtends, target2.extendsType) && (isRelatedTo(source2.checkType, target2.checkType, 3 /* Both */) || isRelatedTo(target2.checkType, source2.checkType, 3 /* Both */))) {
                                if (result2 = isRelatedTo(instantiateType(getTrueTypeFromConditionalType(source2), mapper), getTrueTypeFromConditionalType(target2), 3 /* Both */, reportErrors2)) {
                                    result2 &= isRelatedTo(getFalseTypeFromConditionalType(source2), getFalseTypeFromConditionalType(target2), 3 /* Both */, reportErrors2);
                                }
                                if (result2) {
                                    return result2;
                                }
                            }
                        }
                        const defaultConstraint = getDefaultConstraintOfConditionalType(source2);
                        if (defaultConstraint) {
                            if (result2 = isRelatedTo(defaultConstraint, target2, 1 /* Source */, reportErrors2)) {
                                return result2;
                            }
                        }
                        const distributiveConstraint = !(targetFlags & 16777216 /* Conditional */) && hasNonCircularBaseConstraint(source2) ? getConstraintOfDistributiveConditionalType(source2) : void 0;
                        if (distributiveConstraint) {
                            resetErrorInfo(saveErrorInfo);
                            if (result2 = isRelatedTo(distributiveConstraint, target2, 1 /* Source */, reportErrors2)) {
                                return result2;
                            }
                        }
                    }
                    else {
                        if (relation !== subtypeRelation && relation !== strictSubtypeRelation && isPartialMappedType(target2) && isEmptyObjectType(source2)) {
                            return -1 /* True */;
                        }
                        if (isGenericMappedType(target2)) {
                            if (isGenericMappedType(source2)) {
                                if (result2 = mappedTypeRelatedTo(source2, target2, reportErrors2)) {
                                    return result2;
                                }
                            }
                            return 0 /* False */;
                        }
                        const sourceIsPrimitive = !!(sourceFlags & 402784252 /* Primitive */);
                        if (relation !== identityRelation) {
                            source2 = getApparentType(source2);
                            sourceFlags = source2.flags;
                        }
                        else if (isGenericMappedType(source2)) {
                            return 0 /* False */;
                        }
                        if (getObjectFlags(source2) & 4 /* Reference */ && getObjectFlags(target2) & 4 /* Reference */ && source2.target === target2.target && !isTupleType(source2) && !(isMarkerType(source2) || isMarkerType(target2))) {
                            if (isEmptyArrayLiteralType(source2)) {
                                return -1 /* True */;
                            }
                            const variances = getVariances(source2.target);
                            if (variances === emptyArray) {
                                return 1 /* Unknown */;
                            }
                            const varianceResult = relateVariances(getTypeArguments(source2), getTypeArguments(target2), variances, intersectionState);
                            if (varianceResult !== void 0) {
                                return varianceResult;
                            }
                        }
                        else if (isReadonlyArrayType(target2) ? everyType(source2, isArrayOrTupleType) : isArrayType(target2) && everyType(source2, (t) => isTupleType(t) && !t.target.readonly)) {
                            if (relation !== identityRelation) {
                                return isRelatedTo(getIndexTypeOfType(source2, numberType) || anyType, getIndexTypeOfType(target2, numberType) || anyType, 3 /* Both */, reportErrors2);
                            }
                            else {
                                return 0 /* False */;
                            }
                        }
                        else if (isGenericTupleType(source2) && isTupleType(target2) && !isGenericTupleType(target2)) {
                            const constraint = getBaseConstraintOrType(source2);
                            if (constraint !== source2) {
                                return isRelatedTo(constraint, target2, 1 /* Source */, reportErrors2);
                            }
                        }
                        else if ((relation === subtypeRelation || relation === strictSubtypeRelation) && isEmptyObjectType(target2) && getObjectFlags(target2) & 8192 /* FreshLiteral */ && !isEmptyObjectType(source2)) {
                            return 0 /* False */;
                        }
                        if (sourceFlags & (524288 /* Object */ | 2097152 /* Intersection */) && targetFlags & 524288 /* Object */) {
                            const reportStructuralErrors = reportErrors2 && errorInfo === saveErrorInfo.errorInfo && !sourceIsPrimitive;
                            result2 = propertiesRelatedTo(source2, target2, reportStructuralErrors, 
                            /*excludedProperties*/
                            void 0, 
                            /*optionalsOnly*/
                            false, intersectionState);
                            if (result2) {
                                result2 &= signaturesRelatedTo(source2, target2, 0 /* Call */, reportStructuralErrors, intersectionState);
                                if (result2) {
                                    result2 &= signaturesRelatedTo(source2, target2, 1 /* Construct */, reportStructuralErrors, intersectionState);
                                    if (result2) {
                                        result2 &= indexSignaturesRelatedTo(source2, target2, sourceIsPrimitive, reportStructuralErrors, intersectionState);
                                    }
                                }
                            }
                            if (varianceCheckFailed && result2) {
                                errorInfo = originalErrorInfo || errorInfo || saveErrorInfo.errorInfo;
                            }
                            else if (result2) {
                                return result2;
                            }
                        }
                        if (sourceFlags & (524288 /* Object */ | 2097152 /* Intersection */) && targetFlags & 1048576 /* Union */) {
                            const objectOnlyTarget = extractTypesOfKind(target2, 524288 /* Object */ | 2097152 /* Intersection */ | 33554432 /* Substitution */);
                            if (objectOnlyTarget.flags & 1048576 /* Union */) {
                                const result3 = typeRelatedToDiscriminatedType(source2, objectOnlyTarget);
                                if (result3) {
                                    return result3;
                                }
                            }
                        }
                    }
                    return 0 /* False */;
                    function countMessageChainBreadth(info) {
                        if (!info)
                            return 0;
                        return reduceLeft(info, (value, chain) => value + 1 + countMessageChainBreadth(chain.next), 0);
                    }
                    function relateVariances(sourceTypeArguments, targetTypeArguments, variances, intersectionState2) {
                        if (result2 = typeArgumentsRelatedTo(sourceTypeArguments, targetTypeArguments, variances, reportErrors2, intersectionState2)) {
                            return result2;
                        }
                        if (some(variances, (v) => !!(v & 24 /* AllowsStructuralFallback */))) {
                            originalErrorInfo = void 0;
                            resetErrorInfo(saveErrorInfo);
                            return void 0;
                        }
                        const allowStructuralFallback = targetTypeArguments && hasCovariantVoidArgument(targetTypeArguments, variances);
                        varianceCheckFailed = !allowStructuralFallback;
                        if (variances !== emptyArray && !allowStructuralFallback) {
                            if (varianceCheckFailed && !(reportErrors2 && some(variances, (v) => (v & 7 /* VarianceMask */) === 0 /* Invariant */))) {
                                return 0 /* False */;
                            }
                            originalErrorInfo = errorInfo;
                            resetErrorInfo(saveErrorInfo);
                        }
                    }
                }
                function mappedTypeRelatedTo(source2, target2, reportErrors2) {
                    const modifiersRelated = relation === comparableRelation || (relation === identityRelation ? getMappedTypeModifiers(source2) === getMappedTypeModifiers(target2) : getCombinedMappedTypeOptionality(source2) <= getCombinedMappedTypeOptionality(target2));
                    if (modifiersRelated) {
                        let result2;
                        const targetConstraint = getConstraintTypeFromMappedType(target2);
                        const sourceConstraint = instantiateType(getConstraintTypeFromMappedType(source2), getCombinedMappedTypeOptionality(source2) < 0 ? reportUnmeasurableMapper : reportUnreliableMapper);
                        if (result2 = isRelatedTo(targetConstraint, sourceConstraint, 3 /* Both */, reportErrors2)) {
                            const mapper = createTypeMapper([getTypeParameterFromMappedType(source2)], [getTypeParameterFromMappedType(target2)]);
                            if (instantiateType(getNameTypeFromMappedType(source2), mapper) === instantiateType(getNameTypeFromMappedType(target2), mapper)) {
                                return result2 & isRelatedTo(instantiateType(getTemplateTypeFromMappedType(source2), mapper), getTemplateTypeFromMappedType(target2), 3 /* Both */, reportErrors2);
                            }
                        }
                    }
                    return 0 /* False */;
                }
                function typeRelatedToDiscriminatedType(source2, target2) {
                    var _a2;
                    const sourceProperties = getPropertiesOfType(source2);
                    const sourcePropertiesFiltered = findDiscriminantProperties(sourceProperties, target2);
                    if (!sourcePropertiesFiltered)
                        return 0 /* False */;
                    let numCombinations = 1;
                    for (const sourceProperty of sourcePropertiesFiltered) {
                        numCombinations *= countTypes(getNonMissingTypeOfSymbol(sourceProperty));
                        if (numCombinations > 25) {
                            (_a2 = tracing) == null ? void 0 : _a2.instant(tracing.Phase.CheckTypes, "typeRelatedToDiscriminatedType_DepthLimit", { sourceId: source2.id, targetId: target2.id, numCombinations });
                            return 0 /* False */;
                        }
                    }
                    const sourceDiscriminantTypes = new Array(sourcePropertiesFiltered.length);
                    const excludedProperties = /* @__PURE__ */ new Set();
                    for (let i = 0; i < sourcePropertiesFiltered.length; i++) {
                        const sourceProperty = sourcePropertiesFiltered[i];
                        const sourcePropertyType = getNonMissingTypeOfSymbol(sourceProperty);
                        sourceDiscriminantTypes[i] = sourcePropertyType.flags & 1048576 /* Union */ ? sourcePropertyType.types : [sourcePropertyType];
                        excludedProperties.add(sourceProperty.escapedName);
                    }
                    const discriminantCombinations = cartesianProduct(sourceDiscriminantTypes);
                    const matchingTypes = [];
                    for (const combination of discriminantCombinations) {
                        let hasMatch = false;
                        outer: for (const type of target2.types) {
                            for (let i = 0; i < sourcePropertiesFiltered.length; i++) {
                                const sourceProperty = sourcePropertiesFiltered[i];
                                const targetProperty = getPropertyOfType(type, sourceProperty.escapedName);
                                if (!targetProperty)
                                    continue outer;
                                if (sourceProperty === targetProperty)
                                    continue;
                                const related = propertyRelatedTo(source2, target2, sourceProperty, targetProperty, (_) => combination[i], 
                                /*reportErrors*/
                                false, 0 /* None */, 
                                /*skipOptional*/
                                strictNullChecks || relation === comparableRelation);
                                if (!related) {
                                    continue outer;
                                }
                            }
                            pushIfUnique(matchingTypes, type, equateValues);
                            hasMatch = true;
                        }
                        if (!hasMatch) {
                            return 0 /* False */;
                        }
                    }
                    let result2 = -1 /* True */;
                    for (const type of matchingTypes) {
                        result2 &= propertiesRelatedTo(source2, type, 
                        /*reportErrors*/
                        false, excludedProperties, 
                        /*optionalsOnly*/
                        false, 0 /* None */);
                        if (result2) {
                            result2 &= signaturesRelatedTo(source2, type, 0 /* Call */, 
                            /*reportErrors*/
                            false, 0 /* None */);
                            if (result2) {
                                result2 &= signaturesRelatedTo(source2, type, 1 /* Construct */, 
                                /*reportErrors*/
                                false, 0 /* None */);
                                if (result2 && !(isTupleType(source2) && isTupleType(type))) {
                                    result2 &= indexSignaturesRelatedTo(source2, type, 
                                    /*sourceIsPrimitive*/
                                    false, 
                                    /*reportErrors*/
                                    false, 0 /* None */);
                                }
                            }
                        }
                        if (!result2) {
                            return result2;
                        }
                    }
                    return result2;
                }
                function excludeProperties(properties, excludedProperties) {
                    if (!excludedProperties || properties.length === 0)
                        return properties;
                    let result2;
                    for (let i = 0; i < properties.length; i++) {
                        if (!excludedProperties.has(properties[i].escapedName)) {
                            if (result2) {
                                result2.push(properties[i]);
                            }
                        }
                        else if (!result2) {
                            result2 = properties.slice(0, i);
                        }
                    }
                    return result2 || properties;
                }
                function isPropertySymbolTypeRelated(sourceProp, targetProp, getTypeOfSourceProperty, reportErrors2, intersectionState) {
                    const targetIsOptional = strictNullChecks && !!(getCheckFlags(targetProp) & 48 /* Partial */);
                    const effectiveTarget = addOptionality(getNonMissingTypeOfSymbol(targetProp), 
                    /*isProperty*/
                    false, targetIsOptional);
                    const effectiveSource = getTypeOfSourceProperty(sourceProp);
                    return isRelatedTo(effectiveSource, effectiveTarget, 3 /* Both */, reportErrors2, 
                    /*headMessage*/
                    void 0, intersectionState);
                }
                function propertyRelatedTo(source2, target2, sourceProp, targetProp, getTypeOfSourceProperty, reportErrors2, intersectionState, skipOptional) {
                    const sourcePropFlags = getDeclarationModifierFlagsFromSymbol(sourceProp);
                    const targetPropFlags = getDeclarationModifierFlagsFromSymbol(targetProp);
                    if (sourcePropFlags & 2 /* Private */ || targetPropFlags & 2 /* Private */) {
                        if (sourceProp.valueDeclaration !== targetProp.valueDeclaration) {
                            if (reportErrors2) {
                                if (sourcePropFlags & 2 /* Private */ && targetPropFlags & 2 /* Private */) {
                                    reportError(Diagnostics.Types_have_separate_declarations_of_a_private_property_0, symbolToString(targetProp));
                                }
                                else {
                                    reportError(Diagnostics.Property_0_is_private_in_type_1_but_not_in_type_2, symbolToString(targetProp), typeToString(sourcePropFlags & 2 /* Private */ ? source2 : target2), typeToString(sourcePropFlags & 2 /* Private */ ? target2 : source2));
                                }
                            }
                            return 0 /* False */;
                        }
                    }
                    else if (targetPropFlags & 4 /* Protected */) {
                        if (!isValidOverrideOf(sourceProp, targetProp)) {
                            if (reportErrors2) {
                                reportError(Diagnostics.Property_0_is_protected_but_type_1_is_not_a_class_derived_from_2, symbolToString(targetProp), typeToString(getDeclaringClass(sourceProp) || source2), typeToString(getDeclaringClass(targetProp) || target2));
                            }
                            return 0 /* False */;
                        }
                    }
                    else if (sourcePropFlags & 4 /* Protected */) {
                        if (reportErrors2) {
                            reportError(Diagnostics.Property_0_is_protected_in_type_1_but_public_in_type_2, symbolToString(targetProp), typeToString(source2), typeToString(target2));
                        }
                        return 0 /* False */;
                    }
                    if (relation === strictSubtypeRelation && isReadonlySymbol(sourceProp) && !isReadonlySymbol(targetProp)) {
                        return 0 /* False */;
                    }
                    const related = isPropertySymbolTypeRelated(sourceProp, targetProp, getTypeOfSourceProperty, reportErrors2, intersectionState);
                    if (!related) {
                        if (reportErrors2) {
                            reportIncompatibleError(Diagnostics.Types_of_property_0_are_incompatible, symbolToString(targetProp));
                        }
                        return 0 /* False */;
                    }
                    if (!skipOptional && sourceProp.flags & 16777216 /* Optional */ && targetProp.flags & 106500 /* ClassMember */ && !(targetProp.flags & 16777216 /* Optional */)) {
                        if (reportErrors2) {
                            reportError(Diagnostics.Property_0_is_optional_in_type_1_but_required_in_type_2, symbolToString(targetProp), typeToString(source2), typeToString(target2));
                        }
                        return 0 /* False */;
                    }
                    return related;
                }
                function reportUnmatchedProperty(source2, target2, unmatchedProperty, requireOptionalProperties) {
                    let shouldSkipElaboration = false;
                    if (unmatchedProperty.valueDeclaration && isNamedDeclaration(unmatchedProperty.valueDeclaration) && isPrivateIdentifier(unmatchedProperty.valueDeclaration.name) && source2.symbol && source2.symbol.flags & 32 /* Class */) {
                        const privateIdentifierDescription = unmatchedProperty.valueDeclaration.name.escapedText;
                        const symbolTableKey = getSymbolNameForPrivateIdentifier(source2.symbol, privateIdentifierDescription);
                        if (symbolTableKey && getPropertyOfType(source2, symbolTableKey)) {
                            const sourceName = factory.getDeclarationName(source2.symbol.valueDeclaration);
                            const targetName = factory.getDeclarationName(target2.symbol.valueDeclaration);
                            reportError(Diagnostics.Property_0_in_type_1_refers_to_a_different_member_that_cannot_be_accessed_from_within_type_2, diagnosticName(privateIdentifierDescription), diagnosticName(sourceName.escapedText === "" ? anon : sourceName), diagnosticName(targetName.escapedText === "" ? anon : targetName));
                            return;
                        }
                    }
                    const props = arrayFrom(getUnmatchedProperties(source2, target2, requireOptionalProperties, 
                    /*matchDiscriminantProperties*/
                    false));
                    if (!headMessage || headMessage.code !== Diagnostics.Class_0_incorrectly_implements_interface_1.code && headMessage.code !== Diagnostics.Class_0_incorrectly_implements_class_1_Did_you_mean_to_extend_1_and_inherit_its_members_as_a_subclass.code) {
                        shouldSkipElaboration = true;
                    }
                    if (props.length === 1) {
                        const propName = symbolToString(unmatchedProperty, 
                        /*enclosingDeclaration*/
                        void 0, 0 /* None */, 4 /* AllowAnyNodeKind */ | 16 /* WriteComputedProps */);
                        reportError(Diagnostics.Property_0_is_missing_in_type_1_but_required_in_type_2, propName, ...getTypeNamesForErrorDisplay(source2, target2));
                        if (length(unmatchedProperty.declarations)) {
                            associateRelatedInfo(createDiagnosticForNode(unmatchedProperty.declarations[0], Diagnostics._0_is_declared_here, propName));
                        }
                        if (shouldSkipElaboration && errorInfo) {
                            overrideNextErrorInfo++;
                        }
                    }
                    else if (tryElaborateArrayLikeErrors(source2, target2, 
                    /*reportErrors*/
                    false)) {
                        if (props.length > 5) {
                            reportError(Diagnostics.Type_0_is_missing_the_following_properties_from_type_1_Colon_2_and_3_more, typeToString(source2), typeToString(target2), map(props.slice(0, 4), (p) => symbolToString(p)).join(", "), props.length - 4);
                        }
                        else {
                            reportError(Diagnostics.Type_0_is_missing_the_following_properties_from_type_1_Colon_2, typeToString(source2), typeToString(target2), map(props, (p) => symbolToString(p)).join(", "));
                        }
                        if (shouldSkipElaboration && errorInfo) {
                            overrideNextErrorInfo++;
                        }
                    }
                }
                function propertiesRelatedTo(source2, target2, reportErrors2, excludedProperties, optionalsOnly, intersectionState) {
                    if (relation === identityRelation) {
                        return propertiesIdenticalTo(source2, target2, excludedProperties);
                    }
                    let result2 = -1 /* True */;
                    if (isTupleType(target2)) {
                        if (isArrayOrTupleType(source2)) {
                            if (!target2.target.readonly && (isReadonlyArrayType(source2) || isTupleType(source2) && source2.target.readonly)) {
                                return 0 /* False */;
                            }
                            const sourceArity = getTypeReferenceArity(source2);
                            const targetArity = getTypeReferenceArity(target2);
                            const sourceRestFlag = isTupleType(source2) ? source2.target.combinedFlags & 4 /* Rest */ : 4 /* Rest */;
                            const targetRestFlag = target2.target.combinedFlags & 4 /* Rest */;
                            const sourceMinLength = isTupleType(source2) ? source2.target.minLength : 0;
                            const targetMinLength = target2.target.minLength;
                            if (!sourceRestFlag && sourceArity < targetMinLength) {
                                if (reportErrors2) {
                                    reportError(Diagnostics.Source_has_0_element_s_but_target_requires_1, sourceArity, targetMinLength);
                                }
                                return 0 /* False */;
                            }
                            if (!targetRestFlag && targetArity < sourceMinLength) {
                                if (reportErrors2) {
                                    reportError(Diagnostics.Source_has_0_element_s_but_target_allows_only_1, sourceMinLength, targetArity);
                                }
                                return 0 /* False */;
                            }
                            if (!targetRestFlag && (sourceRestFlag || targetArity < sourceArity)) {
                                if (reportErrors2) {
                                    if (sourceMinLength < targetMinLength) {
                                        reportError(Diagnostics.Target_requires_0_element_s_but_source_may_have_fewer, targetMinLength);
                                    }
                                    else {
                                        reportError(Diagnostics.Target_allows_only_0_element_s_but_source_may_have_more, targetArity);
                                    }
                                }
                                return 0 /* False */;
                            }
                            const sourceTypeArguments = getTypeArguments(source2);
                            const targetTypeArguments = getTypeArguments(target2);
                            const targetStartCount = getStartElementCount(target2.target, 11 /* NonRest */);
                            const targetEndCount = getEndElementCount(target2.target, 11 /* NonRest */);
                            const targetHasRestElement = target2.target.hasRestElement;
                            let canExcludeDiscriminants = !!excludedProperties;
                            for (let sourcePosition = 0; sourcePosition < sourceArity; sourcePosition++) {
                                const sourceFlags = isTupleType(source2) ? source2.target.elementFlags[sourcePosition] : 4 /* Rest */;
                                const sourcePositionFromEnd = sourceArity - 1 - sourcePosition;
                                const targetPosition = targetHasRestElement && sourcePosition >= targetStartCount ? targetArity - 1 - Math.min(sourcePositionFromEnd, targetEndCount) : sourcePosition;
                                const targetFlags = target2.target.elementFlags[targetPosition];
                                if (targetFlags & 8 /* Variadic */ && !(sourceFlags & 8 /* Variadic */)) {
                                    if (reportErrors2) {
                                        reportError(Diagnostics.Source_provides_no_match_for_variadic_element_at_position_0_in_target, targetPosition);
                                    }
                                    return 0 /* False */;
                                }
                                if (sourceFlags & 8 /* Variadic */ && !(targetFlags & 12 /* Variable */)) {
                                    if (reportErrors2) {
                                        reportError(Diagnostics.Variadic_element_at_position_0_in_source_does_not_match_element_at_position_1_in_target, sourcePosition, targetPosition);
                                    }
                                    return 0 /* False */;
                                }
                                if (targetFlags & 1 /* Required */ && !(sourceFlags & 1 /* Required */)) {
                                    if (reportErrors2) {
                                        reportError(Diagnostics.Source_provides_no_match_for_required_element_at_position_0_in_target, targetPosition);
                                    }
                                    return 0 /* False */;
                                }
                                if (canExcludeDiscriminants) {
                                    if (sourceFlags & 12 /* Variable */ || targetFlags & 12 /* Variable */) {
                                        canExcludeDiscriminants = false;
                                    }
                                    if (canExcludeDiscriminants && (excludedProperties == null ? void 0 : excludedProperties.has("" + sourcePosition))) {
                                        continue;
                                    }
                                }
                                const sourceType = removeMissingType(sourceTypeArguments[sourcePosition], !!(sourceFlags & targetFlags & 2 /* Optional */));
                                const targetType = targetTypeArguments[targetPosition];
                                const targetCheckType = sourceFlags & 8 /* Variadic */ && targetFlags & 4 /* Rest */ ? createArrayType(targetType) : removeMissingType(targetType, !!(targetFlags & 2 /* Optional */));
                                const related = isRelatedTo(sourceType, targetCheckType, 3 /* Both */, reportErrors2, 
                                /*headMessage*/
                                void 0, intersectionState);
                                if (!related) {
                                    if (reportErrors2 && (targetArity > 1 || sourceArity > 1)) {
                                        if (targetHasRestElement && sourcePosition >= targetStartCount && sourcePositionFromEnd >= targetEndCount && targetStartCount !== sourceArity - targetEndCount - 1) {
                                            reportIncompatibleError(Diagnostics.Type_at_positions_0_through_1_in_source_is_not_compatible_with_type_at_position_2_in_target, targetStartCount, sourceArity - targetEndCount - 1, targetPosition);
                                        }
                                        else {
                                            reportIncompatibleError(Diagnostics.Type_at_position_0_in_source_is_not_compatible_with_type_at_position_1_in_target, sourcePosition, targetPosition);
                                        }
                                    }
                                    return 0 /* False */;
                                }
                                result2 &= related;
                            }
                            return result2;
                        }
                        if (target2.target.combinedFlags & 12 /* Variable */) {
                            return 0 /* False */;
                        }
                    }
                    const requireOptionalProperties = (relation === subtypeRelation || relation === strictSubtypeRelation) && !isObjectLiteralType2(source2) && !isEmptyArrayLiteralType(source2) && !isTupleType(source2);
                    const unmatchedProperty = getUnmatchedProperty(source2, target2, requireOptionalProperties, 
                    /*matchDiscriminantProperties*/
                    false);
                    if (unmatchedProperty) {
                        if (reportErrors2 && shouldReportUnmatchedPropertyError(source2, target2)) {
                            reportUnmatchedProperty(source2, target2, unmatchedProperty, requireOptionalProperties);
                        }
                        return 0 /* False */;
                    }
                    if (isObjectLiteralType2(target2)) {
                        for (const sourceProp of excludeProperties(getPropertiesOfType(source2), excludedProperties)) {
                            if (!getPropertyOfObjectType(target2, sourceProp.escapedName)) {
                                const sourceType = getTypeOfSymbol(sourceProp);
                                if (!(sourceType.flags & 32768 /* Undefined */)) {
                                    if (reportErrors2) {
                                        reportError(Diagnostics.Property_0_does_not_exist_on_type_1, symbolToString(sourceProp), typeToString(target2));
                                    }
                                    return 0 /* False */;
                                }
                            }
                        }
                    }
                    const properties = getPropertiesOfType(target2);
                    const numericNamesOnly = isTupleType(source2) && isTupleType(target2);
                    for (const targetProp of excludeProperties(properties, excludedProperties)) {
                        const name = targetProp.escapedName;
                        if (!(targetProp.flags & 4194304 /* Prototype */) && (!numericNamesOnly || isNumericLiteralName(name) || name === "length") && (!optionalsOnly || targetProp.flags & 16777216 /* Optional */)) {
                            const sourceProp = getPropertyOfType(source2, name);
                            if (sourceProp && sourceProp !== targetProp) {
                                const related = propertyRelatedTo(source2, target2, sourceProp, targetProp, getNonMissingTypeOfSymbol, reportErrors2, intersectionState, relation === comparableRelation);
                                if (!related) {
                                    return 0 /* False */;
                                }
                                result2 &= related;
                            }
                        }
                    }
                    return result2;
                }
                function propertiesIdenticalTo(source2, target2, excludedProperties) {
                    if (!(source2.flags & 524288 /* Object */ && target2.flags & 524288 /* Object */)) {
                        return 0 /* False */;
                    }
                    const sourceProperties = excludeProperties(getPropertiesOfObjectType(source2), excludedProperties);
                    const targetProperties = excludeProperties(getPropertiesOfObjectType(target2), excludedProperties);
                    if (sourceProperties.length !== targetProperties.length) {
                        return 0 /* False */;
                    }
                    let result2 = -1 /* True */;
                    for (const sourceProp of sourceProperties) {
                        const targetProp = getPropertyOfObjectType(target2, sourceProp.escapedName);
                        if (!targetProp) {
                            return 0 /* False */;
                        }
                        const related = compareProperties2(sourceProp, targetProp, isRelatedTo);
                        if (!related) {
                            return 0 /* False */;
                        }
                        result2 &= related;
                    }
                    return result2;
                }
                function signaturesRelatedTo(source2, target2, kind, reportErrors2, intersectionState) {
                    var _a2, _b;
                    if (relation === identityRelation) {
                        return signaturesIdenticalTo(source2, target2, kind);
                    }
                    if (target2 === anyFunctionType || source2 === anyFunctionType) {
                        return -1 /* True */;
                    }
                    const sourceIsJSConstructor = source2.symbol && isJSConstructor(source2.symbol.valueDeclaration);
                    const targetIsJSConstructor = target2.symbol && isJSConstructor(target2.symbol.valueDeclaration);
                    const sourceSignatures = getSignaturesOfType(source2, sourceIsJSConstructor && kind === 1 /* Construct */ ? 0 /* Call */ : kind);
                    const targetSignatures = getSignaturesOfType(target2, targetIsJSConstructor && kind === 1 /* Construct */ ? 0 /* Call */ : kind);
                    if (kind === 1 /* Construct */ && sourceSignatures.length && targetSignatures.length) {
                        const sourceIsAbstract = !!(sourceSignatures[0].flags & 4 /* Abstract */);
                        const targetIsAbstract = !!(targetSignatures[0].flags & 4 /* Abstract */);
                        if (sourceIsAbstract && !targetIsAbstract) {
                            if (reportErrors2) {
                                reportError(Diagnostics.Cannot_assign_an_abstract_constructor_type_to_a_non_abstract_constructor_type);
                            }
                            return 0 /* False */;
                        }
                        if (!constructorVisibilitiesAreCompatible(sourceSignatures[0], targetSignatures[0], reportErrors2)) {
                            return 0 /* False */;
                        }
                    }
                    let result2 = -1 /* True */;
                    const incompatibleReporter = kind === 1 /* Construct */ ? reportIncompatibleConstructSignatureReturn : reportIncompatibleCallSignatureReturn;
                    const sourceObjectFlags = getObjectFlags(source2);
                    const targetObjectFlags = getObjectFlags(target2);
                    if (sourceObjectFlags & 64 /* Instantiated */ && targetObjectFlags & 64 /* Instantiated */ && source2.symbol === target2.symbol || sourceObjectFlags & 4 /* Reference */ && targetObjectFlags & 4 /* Reference */ && source2.target === target2.target) {
                        Debug.assertEqual(sourceSignatures.length, targetSignatures.length);
                        for (let i = 0; i < targetSignatures.length; i++) {
                            const related = signatureRelatedTo(sourceSignatures[i], targetSignatures[i], 
                            /*erase*/
                            true, reportErrors2, intersectionState, incompatibleReporter(sourceSignatures[i], targetSignatures[i]));
                            if (!related) {
                                return 0 /* False */;
                            }
                            result2 &= related;
                        }
                    }
                    else if (sourceSignatures.length === 1 && targetSignatures.length === 1) {
                        const eraseGenerics = relation === comparableRelation || !!compilerOptions.noStrictGenericChecks;
                        const sourceSignature = first(sourceSignatures);
                        const targetSignature = first(targetSignatures);
                        result2 = signatureRelatedTo(sourceSignature, targetSignature, eraseGenerics, reportErrors2, intersectionState, incompatibleReporter(sourceSignature, targetSignature));
                        if (!result2 && reportErrors2 && kind === 1 /* Construct */ && sourceObjectFlags & targetObjectFlags && (((_a2 = targetSignature.declaration) == null ? void 0 : _a2.kind) === 176 /* Constructor */ || ((_b = sourceSignature.declaration) == null ? void 0 : _b.kind) === 176 /* Constructor */)) {
                            const constructSignatureToString = (signature) => signatureToString(signature, 
                            /*enclosingDeclaration*/
                            void 0, 262144 /* WriteArrowStyleSignature */, kind);
                            reportError(Diagnostics.Type_0_is_not_assignable_to_type_1, constructSignatureToString(sourceSignature), constructSignatureToString(targetSignature));
                            reportError(Diagnostics.Types_of_construct_signatures_are_incompatible);
                            return result2;
                        }
                    }
                    else {
                        outer: for (const t of targetSignatures) {
                            const saveErrorInfo = captureErrorCalculationState();
                            let shouldElaborateErrors = reportErrors2;
                            for (const s of sourceSignatures) {
                                const related = signatureRelatedTo(s, t, 
                                /*erase*/
                                true, shouldElaborateErrors, intersectionState, incompatibleReporter(s, t));
                                if (related) {
                                    result2 &= related;
                                    resetErrorInfo(saveErrorInfo);
                                    continue outer;
                                }
                                shouldElaborateErrors = false;
                            }
                            if (shouldElaborateErrors) {
                                reportError(Diagnostics.Type_0_provides_no_match_for_the_signature_1, typeToString(source2), signatureToString(t, 
                                /*enclosingDeclaration*/
                                void 0, 
                                /*flags*/
                                void 0, kind));
                            }
                            return 0 /* False */;
                        }
                    }
                    return result2;
                }
                function shouldReportUnmatchedPropertyError(source2, target2) {
                    const typeCallSignatures = getSignaturesOfStructuredType(source2, 0 /* Call */);
                    const typeConstructSignatures = getSignaturesOfStructuredType(source2, 1 /* Construct */);
                    const typeProperties = getPropertiesOfObjectType(source2);
                    if ((typeCallSignatures.length || typeConstructSignatures.length) && !typeProperties.length) {
                        if (getSignaturesOfType(target2, 0 /* Call */).length && typeCallSignatures.length || getSignaturesOfType(target2, 1 /* Construct */).length && typeConstructSignatures.length) {
                            return true;
                        }
                        return false;
                    }
                    return true;
                }
                function reportIncompatibleCallSignatureReturn(siga, sigb) {
                    if (siga.parameters.length === 0 && sigb.parameters.length === 0) {
                        return (source2, target2) => reportIncompatibleError(Diagnostics.Call_signatures_with_no_arguments_have_incompatible_return_types_0_and_1, typeToString(source2), typeToString(target2));
                    }
                    return (source2, target2) => reportIncompatibleError(Diagnostics.Call_signature_return_types_0_and_1_are_incompatible, typeToString(source2), typeToString(target2));
                }
                function reportIncompatibleConstructSignatureReturn(siga, sigb) {
                    if (siga.parameters.length === 0 && sigb.parameters.length === 0) {
                        return (source2, target2) => reportIncompatibleError(Diagnostics.Construct_signatures_with_no_arguments_have_incompatible_return_types_0_and_1, typeToString(source2), typeToString(target2));
                    }
                    return (source2, target2) => reportIncompatibleError(Diagnostics.Construct_signature_return_types_0_and_1_are_incompatible, typeToString(source2), typeToString(target2));
                }
                function signatureRelatedTo(source2, target2, erase, reportErrors2, intersectionState, incompatibleReporter) {
                    const checkMode = relation === subtypeRelation ? 16 /* StrictTopSignature */ : relation === strictSubtypeRelation ? 16 /* StrictTopSignature */ | 8 /* StrictArity */ : 0 /* None */;
                    return compareSignaturesRelated(erase ? getErasedSignature(source2) : source2, erase ? getErasedSignature(target2) : target2, checkMode, reportErrors2, reportError, incompatibleReporter, isRelatedToWorker2, reportUnreliableMapper);
                    function isRelatedToWorker2(source3, target3, reportErrors3) {
                        return isRelatedTo(source3, target3, 3 /* Both */, reportErrors3, 
                        /*headMessage*/
                        void 0, intersectionState);
                    }
                }
                function signaturesIdenticalTo(source2, target2, kind) {
                    const sourceSignatures = getSignaturesOfType(source2, kind);
                    const targetSignatures = getSignaturesOfType(target2, kind);
                    if (sourceSignatures.length !== targetSignatures.length) {
                        return 0 /* False */;
                    }
                    let result2 = -1 /* True */;
                    for (let i = 0; i < sourceSignatures.length; i++) {
                        const related = compareSignaturesIdentical(sourceSignatures[i], targetSignatures[i], 
                        /*partialMatch*/
                        false, 
                        /*ignoreThisTypes*/
                        false, 
                        /*ignoreReturnTypes*/
                        false, isRelatedTo);
                        if (!related) {
                            return 0 /* False */;
                        }
                        result2 &= related;
                    }
                    return result2;
                }
                function membersRelatedToIndexInfo(source2, targetInfo, reportErrors2, intersectionState) {
                    let result2 = -1 /* True */;
                    const keyType = targetInfo.keyType;
                    const props = source2.flags & 2097152 /* Intersection */ ? getPropertiesOfUnionOrIntersectionType(source2) : getPropertiesOfObjectType(source2);
                    for (const prop of props) {
                        if (isIgnoredJsxProperty(source2, prop)) {
                            continue;
                        }
                        if (isApplicableIndexType(getLiteralTypeFromProperty(prop, 8576 /* StringOrNumberLiteralOrUnique */), keyType)) {
                            const propType = getNonMissingTypeOfSymbol(prop);
                            const type = exactOptionalPropertyTypes || propType.flags & 32768 /* Undefined */ || keyType === numberType || !(prop.flags & 16777216 /* Optional */) ? propType : getTypeWithFacts(propType, 524288 /* NEUndefined */);
                            const related = isRelatedTo(type, targetInfo.type, 3 /* Both */, reportErrors2, 
                            /*headMessage*/
                            void 0, intersectionState);
                            if (!related) {
                                if (reportErrors2) {
                                    reportError(Diagnostics.Property_0_is_incompatible_with_index_signature, symbolToString(prop));
                                }
                                return 0 /* False */;
                            }
                            result2 &= related;
                        }
                    }
                    for (const info of getIndexInfosOfType(source2)) {
                        if (isApplicableIndexType(info.keyType, keyType)) {
                            const related = indexInfoRelatedTo(info, targetInfo, reportErrors2, intersectionState);
                            if (!related) {
                                return 0 /* False */;
                            }
                            result2 &= related;
                        }
                    }
                    return result2;
                }
                function indexInfoRelatedTo(sourceInfo, targetInfo, reportErrors2, intersectionState) {
                    const related = isRelatedTo(sourceInfo.type, targetInfo.type, 3 /* Both */, reportErrors2, 
                    /*headMessage*/
                    void 0, intersectionState);
                    if (!related && reportErrors2) {
                        if (sourceInfo.keyType === targetInfo.keyType) {
                            reportError(Diagnostics._0_index_signatures_are_incompatible, typeToString(sourceInfo.keyType));
                        }
                        else {
                            reportError(Diagnostics._0_and_1_index_signatures_are_incompatible, typeToString(sourceInfo.keyType), typeToString(targetInfo.keyType));
                        }
                    }
                    return related;
                }
                function indexSignaturesRelatedTo(source2, target2, sourceIsPrimitive, reportErrors2, intersectionState) {
                    if (relation === identityRelation) {
                        return indexSignaturesIdenticalTo(source2, target2);
                    }
                    const indexInfos = getIndexInfosOfType(target2);
                    const targetHasStringIndex = some(indexInfos, (info) => info.keyType === stringType);
                    let result2 = -1 /* True */;
                    for (const targetInfo of indexInfos) {
                        const related = relation !== strictSubtypeRelation && !sourceIsPrimitive && targetHasStringIndex && targetInfo.type.flags & 1 /* Any */ ? -1 /* True */ : isGenericMappedType(source2) && targetHasStringIndex ? isRelatedTo(getTemplateTypeFromMappedType(source2), targetInfo.type, 3 /* Both */, reportErrors2) : typeRelatedToIndexInfo(source2, targetInfo, reportErrors2, intersectionState);
                        if (!related) {
                            return 0 /* False */;
                        }
                        result2 &= related;
                    }
                    return result2;
                }
                function typeRelatedToIndexInfo(source2, targetInfo, reportErrors2, intersectionState) {
                    const sourceInfo = getApplicableIndexInfo(source2, targetInfo.keyType);
                    if (sourceInfo) {
                        return indexInfoRelatedTo(sourceInfo, targetInfo, reportErrors2, intersectionState);
                    }
                    if (!(intersectionState & 1 /* Source */) && (relation !== strictSubtypeRelation || getObjectFlags(source2) & 8192 /* FreshLiteral */) && isObjectTypeWithInferableIndex(source2)) {
                        return membersRelatedToIndexInfo(source2, targetInfo, reportErrors2, intersectionState);
                    }
                    if (reportErrors2) {
                        reportError(Diagnostics.Index_signature_for_type_0_is_missing_in_type_1, typeToString(targetInfo.keyType), typeToString(source2));
                    }
                    return 0 /* False */;
                }
                function indexSignaturesIdenticalTo(source2, target2) {
                    const sourceInfos = getIndexInfosOfType(source2);
                    const targetInfos = getIndexInfosOfType(target2);
                    if (sourceInfos.length !== targetInfos.length) {
                        return 0 /* False */;
                    }
                    for (const targetInfo of targetInfos) {
                        const sourceInfo = getIndexInfoOfType(source2, targetInfo.keyType);
                        if (!(sourceInfo && isRelatedTo(sourceInfo.type, targetInfo.type, 3 /* Both */) && sourceInfo.isReadonly === targetInfo.isReadonly)) {
                            return 0 /* False */;
                        }
                    }
                    return -1 /* True */;
                }
                function constructorVisibilitiesAreCompatible(sourceSignature, targetSignature, reportErrors2) {
                    if (!sourceSignature.declaration || !targetSignature.declaration) {
                        return true;
                    }
                    const sourceAccessibility = getSelectedEffectiveModifierFlags(sourceSignature.declaration, 6 /* NonPublicAccessibilityModifier */);
                    const targetAccessibility = getSelectedEffectiveModifierFlags(targetSignature.declaration, 6 /* NonPublicAccessibilityModifier */);
                    if (targetAccessibility === 2 /* Private */) {
                        return true;
                    }
                    if (targetAccessibility === 4 /* Protected */ && sourceAccessibility !== 2 /* Private */) {
                        return true;
                    }
                    if (targetAccessibility !== 4 /* Protected */ && !sourceAccessibility) {
                        return true;
                    }
                    if (reportErrors2) {
                        reportError(Diagnostics.Cannot_assign_a_0_constructor_type_to_a_1_constructor_type, visibilityToString(sourceAccessibility), visibilityToString(targetAccessibility));
                    }
                    return false;
                }
            }
            function typeCouldHaveTopLevelSingletonTypes(type) {
                if (type.flags & 16 /* Boolean */) {
                    return false;
                }
                if (type.flags & 3145728 /* UnionOrIntersection */) {
                    return !!forEach(type.types, typeCouldHaveTopLevelSingletonTypes);
                }
                if (type.flags & 465829888 /* Instantiable */) {
                    const constraint = getConstraintOfType(type);
                    if (constraint && constraint !== type) {
                        return typeCouldHaveTopLevelSingletonTypes(constraint);
                    }
                }
                return isUnitType(type) || !!(type.flags & 134217728 /* TemplateLiteral */) || !!(type.flags & 268435456 /* StringMapping */);
            }
            function getExactOptionalUnassignableProperties(source, target) {
                if (isTupleType(source) && isTupleType(target))
                    return emptyArray;
                return getPropertiesOfType(target).filter((targetProp) => isExactOptionalPropertyMismatch(getTypeOfPropertyOfType(source, targetProp.escapedName), getTypeOfSymbol(targetProp)));
            }
            function isExactOptionalPropertyMismatch(source, target) {
                return !!source && !!target && maybeTypeOfKind(source, 32768 /* Undefined */) && !!containsMissingType(target);
            }
            function getExactOptionalProperties(type) {
                return getPropertiesOfType(type).filter((targetProp) => containsMissingType(getTypeOfSymbol(targetProp)));
            }
            function getBestMatchingType(source, target, isRelatedTo = compareTypesAssignable) {
                return findMatchingDiscriminantType(source, target, isRelatedTo) || findMatchingTypeReferenceOrTypeAliasReference(source, target) || findBestTypeForObjectLiteral(source, target) || findBestTypeForInvokable(source, target) || findMostOverlappyType(source, target);
            }
            function discriminateTypeByDiscriminableItems(target, discriminators, related) {
                const types = target.types;
                const include = types.map((t) => t.flags & 402784252 /* Primitive */ ? 0 /* False */ : -1 /* True */);
                for (const [getDiscriminatingType, propertyName] of discriminators) {
                    let matched = false;
                    for (let i = 0; i < types.length; i++) {
                        if (include[i]) {
                            const targetType = getTypeOfPropertyOrIndexSignatureOfType(types[i], propertyName);
                            if (targetType && related(getDiscriminatingType(), targetType)) {
                                matched = true;
                            }
                            else {
                                include[i] = 3 /* Maybe */;
                            }
                        }
                    }
                    for (let i = 0; i < types.length; i++) {
                        if (include[i] === 3 /* Maybe */) {
                            include[i] = matched ? 0 /* False */ : -1 /* True */;
                        }
                    }
                }
                const filtered = contains(include, 0 /* False */) ? getUnionType(types.filter((_, i) => include[i]), 0 /* None */) : target;
                return filtered.flags & 131072 /* Never */ ? target : filtered;
            }
            function isWeakType(type) {
                if (type.flags & 524288 /* Object */) {
                    const resolved = resolveStructuredTypeMembers(type);
                    return resolved.callSignatures.length === 0 && resolved.constructSignatures.length === 0 && resolved.indexInfos.length === 0 && resolved.properties.length > 0 && every(resolved.properties, (p) => !!(p.flags & 16777216 /* Optional */));
                }
                if (type.flags & 2097152 /* Intersection */) {
                    return every(type.types, isWeakType);
                }
                return false;
            }
            function hasCommonProperties(source, target, isComparingJsxAttributes) {
                for (const prop of getPropertiesOfType(source)) {
                    if (isKnownProperty(target, prop.escapedName, isComparingJsxAttributes)) {
                        return true;
                    }
                }
                return false;
            }
            function getVariances(type) {
                return type === globalArrayType || type === globalReadonlyArrayType || type.objectFlags & 8 /* Tuple */ ? arrayVariances : getVariancesWorker(type.symbol, type.typeParameters);
            }
            function getAliasVariances(symbol) {
                return getVariancesWorker(symbol, getSymbolLinks(symbol).typeParameters);
            }
            function getVariancesWorker(symbol, typeParameters = emptyArray) {
                var _a, _b;
                const links = getSymbolLinks(symbol);
                if (!links.variances) {
                    (_a = tracing) == null ? void 0 : _a.push(tracing.Phase.CheckTypes, "getVariancesWorker", { arity: typeParameters.length, id: getTypeId(getDeclaredTypeOfSymbol(symbol)) });
                    const oldVarianceComputation = inVarianceComputation;
                    if (!inVarianceComputation) {
                        inVarianceComputation = true;
                        resolutionStart = resolutionTargets.length;
                    }
                    links.variances = emptyArray;
                    const variances = [];
                    for (const tp of typeParameters) {
                        const modifiers = getTypeParameterModifiers(tp);
                        let variance = modifiers & 16384 /* Out */ ? modifiers & 8192 /* In */ ? 0 /* Invariant */ : 1 /* Covariant */ : modifiers & 8192 /* In */ ? 2 /* Contravariant */ : void 0;
                        if (variance === void 0) {
                            let unmeasurable = false;
                            let unreliable = false;
                            const oldHandler = outofbandVarianceMarkerHandler;
                            outofbandVarianceMarkerHandler = (onlyUnreliable) => onlyUnreliable ? unreliable = true : unmeasurable = true;
                            const typeWithSuper = createMarkerType(symbol, tp, markerSuperType);
                            const typeWithSub = createMarkerType(symbol, tp, markerSubType);
                            variance = (isTypeAssignableTo(typeWithSub, typeWithSuper) ? 1 /* Covariant */ : 0) | (isTypeAssignableTo(typeWithSuper, typeWithSub) ? 2 /* Contravariant */ : 0);
                            if (variance === 3 /* Bivariant */ && isTypeAssignableTo(createMarkerType(symbol, tp, markerOtherType), typeWithSuper)) {
                                variance = 4 /* Independent */;
                            }
                            outofbandVarianceMarkerHandler = oldHandler;
                            if (unmeasurable || unreliable) {
                                if (unmeasurable) {
                                    variance |= 8 /* Unmeasurable */;
                                }
                                if (unreliable) {
                                    variance |= 16 /* Unreliable */;
                                }
                            }
                        }
                        variances.push(variance);
                    }
                    if (!oldVarianceComputation) {
                        inVarianceComputation = false;
                        resolutionStart = 0;
                    }
                    links.variances = variances;
                    (_b = tracing) == null ? void 0 : _b.pop({ variances: variances.map(Debug.formatVariance) });
                }
                return links.variances;
            }
            function createMarkerType(symbol, source, target) {
                const mapper = makeUnaryTypeMapper(source, target);
                const type = getDeclaredTypeOfSymbol(symbol);
                if (isErrorType(type)) {
                    return type;
                }
                const result = symbol.flags & 524288 /* TypeAlias */ ? getTypeAliasInstantiation(symbol, instantiateTypes(getSymbolLinks(symbol).typeParameters, mapper)) : createTypeReference(type, instantiateTypes(type.typeParameters, mapper));
                markerTypes.add(getTypeId(result));
                return result;
            }
            function isMarkerType(type) {
                return markerTypes.has(getTypeId(type));
            }
            function getTypeParameterModifiers(tp) {
                var _a;
                return reduceLeft((_a = tp.symbol) == null ? void 0 : _a.declarations, (modifiers, d) => modifiers | getEffectiveModifierFlags(d), 0 /* None */) & (8192 /* In */ | 16384 /* Out */ | 4096 /* Const */);
            }
            function hasCovariantVoidArgument(typeArguments, variances) {
                for (let i = 0; i < variances.length; i++) {
                    if ((variances[i] & 7 /* VarianceMask */) === 1 /* Covariant */ && typeArguments[i].flags & 16384 /* Void */) {
                        return true;
                    }
                }
                return false;
            }
            function isUnconstrainedTypeParameter(type) {
                return type.flags & 262144 /* TypeParameter */ && !getConstraintOfTypeParameter(type);
            }
            function isNonDeferredTypeReference(type) {
                return !!(getObjectFlags(type) & 4 /* Reference */) && !type.node;
            }
            function isTypeReferenceWithGenericArguments(type) {
                return isNonDeferredTypeReference(type) && some(getTypeArguments(type), (t) => !!(t.flags & 262144 /* TypeParameter */) || isTypeReferenceWithGenericArguments(t));
            }
            function getGenericTypeReferenceRelationKey(source, target, postFix, ignoreConstraints) {
                const typeParameters = [];
                let constraintMarker = "";
                const sourceId = getTypeReferenceId(source, 0);
                const targetId = getTypeReferenceId(target, 0);
                return `${constraintMarker}${sourceId},${targetId}${postFix}`;
                function getTypeReferenceId(type, depth = 0) {
                    let result = "" + type.target.id;
                    for (const t of getTypeArguments(type)) {
                        if (t.flags & 262144 /* TypeParameter */) {
                            if (ignoreConstraints || isUnconstrainedTypeParameter(t)) {
                                let index = typeParameters.indexOf(t);
                                if (index < 0) {
                                    index = typeParameters.length;
                                    typeParameters.push(t);
                                }
                                result += "=" + index;
                                continue;
                            }
                            constraintMarker = "*";
                        }
                        else if (depth < 4 && isTypeReferenceWithGenericArguments(t)) {
                            result += "<" + getTypeReferenceId(t, depth + 1) + ">";
                            continue;
                        }
                        result += "-" + t.id;
                    }
                    return result;
                }
            }
            function getRelationKey(source, target, intersectionState, relation, ignoreConstraints) {
                if (relation === identityRelation && source.id > target.id) {
                    const temp = source;
                    source = target;
                    target = temp;
                }
                const postFix = intersectionState ? ":" + intersectionState : "";
                return isTypeReferenceWithGenericArguments(source) && isTypeReferenceWithGenericArguments(target) ? getGenericTypeReferenceRelationKey(source, target, postFix, ignoreConstraints) : `${source.id},${target.id}${postFix}`;
            }
            function forEachProperty2(prop, callback) {
                if (getCheckFlags(prop) & 6 /* Synthetic */) {
                    for (const t of prop.links.containingType.types) {
                        const p = getPropertyOfType(t, prop.escapedName);
                        const result = p && forEachProperty2(p, callback);
                        if (result) {
                            return result;
                        }
                    }
                    return void 0;
                }
                return callback(prop);
            }
            function getDeclaringClass(prop) {
                return prop.parent && prop.parent.flags & 32 /* Class */ ? getDeclaredTypeOfSymbol(getParentOfSymbol(prop)) : void 0;
            }
            function getTypeOfPropertyInBaseClass(property) {
                const classType = getDeclaringClass(property);
                const baseClassType = classType && getBaseTypes(classType)[0];
                return baseClassType && getTypeOfPropertyOfType(baseClassType, property.escapedName);
            }
            function isPropertyInClassDerivedFrom(prop, baseClass) {
                return forEachProperty2(prop, (sp) => {
                    const sourceClass = getDeclaringClass(sp);
                    return sourceClass ? hasBaseType(sourceClass, baseClass) : false;
                });
            }
            function isValidOverrideOf(sourceProp, targetProp) {
                return !forEachProperty2(targetProp, (tp) => getDeclarationModifierFlagsFromSymbol(tp) & 4 /* Protected */ ? !isPropertyInClassDerivedFrom(sourceProp, getDeclaringClass(tp)) : false);
            }
            function isClassDerivedFromDeclaringClasses(checkClass, prop, writing) {
                return forEachProperty2(prop, (p) => getDeclarationModifierFlagsFromSymbol(p, writing) & 4 /* Protected */ ? !hasBaseType(checkClass, getDeclaringClass(p)) : false) ? void 0 : checkClass;
            }
            function isDeeplyNestedType(type, stack, depth, maxDepth = 3) {
                if (depth >= maxDepth) {
                    if ((getObjectFlags(type) & 96 /* InstantiatedMapped */) === 96 /* InstantiatedMapped */) {
                        type = getMappedTargetWithSymbol(type);
                    }
                    if (type.flags & 2097152 /* Intersection */) {
                        return some(type.types, (t) => isDeeplyNestedType(t, stack, depth, maxDepth));
                    }
                    const identity2 = getRecursionIdentity(type);
                    let count = 0;
                    let lastTypeId = 0;
                    for (let i = 0; i < depth; i++) {
                        const t = stack[i];
                        if (hasMatchingRecursionIdentity(t, identity2)) {
                            if (t.id >= lastTypeId) {
                                count++;
                                if (count >= maxDepth) {
                                    return true;
                                }
                            }
                            lastTypeId = t.id;
                        }
                    }
                }
                return false;
            }
            function getMappedTargetWithSymbol(type) {
                let target;
                while ((getObjectFlags(type) & 96 /* InstantiatedMapped */) === 96 /* InstantiatedMapped */ && (target = getModifiersTypeFromMappedType(type)) && (target.symbol || target.flags & 2097152 /* Intersection */ && some(target.types, (t) => !!t.symbol))) {
                    type = target;
                }
                return type;
            }
            function hasMatchingRecursionIdentity(type, identity2) {
                if ((getObjectFlags(type) & 96 /* InstantiatedMapped */) === 96 /* InstantiatedMapped */) {
                    type = getMappedTargetWithSymbol(type);
                }
                if (type.flags & 2097152 /* Intersection */) {
                    return some(type.types, (t) => hasMatchingRecursionIdentity(t, identity2));
                }
                return getRecursionIdentity(type) === identity2;
            }
            function getRecursionIdentity(type) {
                if (type.flags & 524288 /* Object */ && !isObjectOrArrayLiteralType(type)) {
                    if (getObjectFlags(type) & 4 /* Reference */ && type.node) {
                        return type.node;
                    }
                    if (type.symbol && !(getObjectFlags(type) & 16 /* Anonymous */ && type.symbol.flags & 32 /* Class */)) {
                        return type.symbol;
                    }
                    if (isTupleType(type)) {
                        return type.target;
                    }
                }
                if (type.flags & 262144 /* TypeParameter */) {
                    return type.symbol;
                }
                if (type.flags & 8388608 /* IndexedAccess */) {
                    do {
                        type = type.objectType;
                    } while (type.flags & 8388608 /* IndexedAccess */);
                    return type;
                }
                if (type.flags & 16777216 /* Conditional */) {
                    return type.root;
                }
                return type;
            }
            function isPropertyIdenticalTo(sourceProp, targetProp) {
                return compareProperties2(sourceProp, targetProp, compareTypesIdentical) !== 0 /* False */;
            }
            function compareProperties2(sourceProp, targetProp, compareTypes) {
                if (sourceProp === targetProp) {
                    return -1 /* True */;
                }
                const sourcePropAccessibility = getDeclarationModifierFlagsFromSymbol(sourceProp) & 6 /* NonPublicAccessibilityModifier */;
                const targetPropAccessibility = getDeclarationModifierFlagsFromSymbol(targetProp) & 6 /* NonPublicAccessibilityModifier */;
                if (sourcePropAccessibility !== targetPropAccessibility) {
                    return 0 /* False */;
                }
                if (sourcePropAccessibility) {
                    if (getTargetSymbol(sourceProp) !== getTargetSymbol(targetProp)) {
                        return 0 /* False */;
                    }
                }
                else {
                    if ((sourceProp.flags & 16777216 /* Optional */) !== (targetProp.flags & 16777216 /* Optional */)) {
                        return 0 /* False */;
                    }
                }
                if (isReadonlySymbol(sourceProp) !== isReadonlySymbol(targetProp)) {
                    return 0 /* False */;
                }
                return compareTypes(getTypeOfSymbol(sourceProp), getTypeOfSymbol(targetProp));
            }
            function isMatchingSignature(source, target, partialMatch) {
                const sourceParameterCount = getParameterCount(source);
                const targetParameterCount = getParameterCount(target);
                const sourceMinArgumentCount = getMinArgumentCount(source);
                const targetMinArgumentCount = getMinArgumentCount(target);
                const sourceHasRestParameter = hasEffectiveRestParameter(source);
                const targetHasRestParameter = hasEffectiveRestParameter(target);
                if (sourceParameterCount === targetParameterCount && sourceMinArgumentCount === targetMinArgumentCount && sourceHasRestParameter === targetHasRestParameter) {
                    return true;
                }
                if (partialMatch && sourceMinArgumentCount <= targetMinArgumentCount) {
                    return true;
                }
                return false;
            }
            function compareSignaturesIdentical(source, target, partialMatch, ignoreThisTypes, ignoreReturnTypes, compareTypes) {
                if (source === target) {
                    return -1 /* True */;
                }
                if (!isMatchingSignature(source, target, partialMatch)) {
                    return 0 /* False */;
                }
                if (length(source.typeParameters) !== length(target.typeParameters)) {
                    return 0 /* False */;
                }
                if (target.typeParameters) {
                    const mapper = createTypeMapper(source.typeParameters, target.typeParameters);
                    for (let i = 0; i < target.typeParameters.length; i++) {
                        const s = source.typeParameters[i];
                        const t = target.typeParameters[i];
                        if (!(s === t || compareTypes(instantiateType(getConstraintFromTypeParameter(s), mapper) || unknownType, getConstraintFromTypeParameter(t) || unknownType) && compareTypes(instantiateType(getDefaultFromTypeParameter(s), mapper) || unknownType, getDefaultFromTypeParameter(t) || unknownType))) {
                            return 0 /* False */;
                        }
                    }
                    source = instantiateSignature(source, mapper, 
                    /*eraseTypeParameters*/
                    true);
                }
                let result = -1 /* True */;
                if (!ignoreThisTypes) {
                    const sourceThisType = getThisTypeOfSignature(source);
                    if (sourceThisType) {
                        const targetThisType = getThisTypeOfSignature(target);
                        if (targetThisType) {
                            const related = compareTypes(sourceThisType, targetThisType);
                            if (!related) {
                                return 0 /* False */;
                            }
                            result &= related;
                        }
                    }
                }
                const targetLen = getParameterCount(target);
                for (let i = 0; i < targetLen; i++) {
                    const s = getTypeAtPosition(source, i);
                    const t = getTypeAtPosition(target, i);
                    const related = compareTypes(t, s);
                    if (!related) {
                        return 0 /* False */;
                    }
                    result &= related;
                }
                if (!ignoreReturnTypes) {
                    const sourceTypePredicate = getTypePredicateOfSignature(source);
                    const targetTypePredicate = getTypePredicateOfSignature(target);
                    result &= sourceTypePredicate || targetTypePredicate ? compareTypePredicatesIdentical(sourceTypePredicate, targetTypePredicate, compareTypes) : compareTypes(getReturnTypeOfSignature(source), getReturnTypeOfSignature(target));
                }
                return result;
            }
            function compareTypePredicatesIdentical(source, target, compareTypes) {
                return !(source && target && typePredicateKindsMatch(source, target)) ? 0 /* False */ : source.type === target.type ? -1 /* True */ : source.type && target.type ? compareTypes(source.type, target.type) : 0 /* False */;
            }
            function literalTypesWithSameBaseType(types) {
                let commonBaseType;
                for (const t of types) {
                    if (!(t.flags & 131072 /* Never */)) {
                        const baseType = getBaseTypeOfLiteralType(t);
                        commonBaseType ?? (commonBaseType = baseType);
                        if (baseType === t || baseType !== commonBaseType) {
                            return false;
                        }
                    }
                }
                return true;
            }
            function getCombinedTypeFlags(types) {
                return reduceLeft(types, (flags, t) => flags | (t.flags & 1048576 /* Union */ ? getCombinedTypeFlags(t.types) : t.flags), 0);
            }
            function getCommonSupertype(types) {
                if (types.length === 1) {
                    return types[0];
                }
                const primaryTypes = strictNullChecks ? sameMap(types, (t) => filterType(t, (u) => !(u.flags & 98304 /* Nullable */))) : types;
                const superTypeOrUnion = literalTypesWithSameBaseType(primaryTypes) ? getUnionType(primaryTypes) : reduceLeft(primaryTypes, (s, t) => isTypeSubtypeOf(s, t) ? t : s);
                return primaryTypes === types ? superTypeOrUnion : getNullableType(superTypeOrUnion, getCombinedTypeFlags(types) & 98304 /* Nullable */);
            }
            function getCommonSubtype(types) {
                return reduceLeft(types, (s, t) => isTypeSubtypeOf(t, s) ? t : s);
            }
            function isArrayType(type) {
                return !!(getObjectFlags(type) & 4 /* Reference */) && (type.target === globalArrayType || type.target === globalReadonlyArrayType);
            }
            function isReadonlyArrayType(type) {
                return !!(getObjectFlags(type) & 4 /* Reference */) && type.target === globalReadonlyArrayType;
            }
            function isArrayOrTupleType(type) {
                return isArrayType(type) || isTupleType(type);
            }
            function isMutableArrayOrTuple(type) {
                return isArrayType(type) && !isReadonlyArrayType(type) || isTupleType(type) && !type.target.readonly;
            }
            function getElementTypeOfArrayType(type) {
                return isArrayType(type) ? getTypeArguments(type)[0] : void 0;
            }
            function isArrayLikeType(type) {
                return isArrayType(type) || !(type.flags & 98304 /* Nullable */) && isTypeAssignableTo(type, anyReadonlyArrayType);
            }
            function isMutableArrayLikeType(type) {
                return isMutableArrayOrTuple(type) || !(type.flags & (1 /* Any */ | 98304 /* Nullable */)) && isTypeAssignableTo(type, anyArrayType);
            }
            function getSingleBaseForNonAugmentingSubtype(type) {
                if (!(getObjectFlags(type) & 4 /* Reference */) || !(getObjectFlags(type.target) & 3 /* ClassOrInterface */)) {
                    return void 0;
                }
                if (getObjectFlags(type) & 33554432 /* IdenticalBaseTypeCalculated */) {
                    return getObjectFlags(type) & 67108864 /* IdenticalBaseTypeExists */ ? type.cachedEquivalentBaseType : void 0;
                }
                type.objectFlags |= 33554432 /* IdenticalBaseTypeCalculated */;
                const target = type.target;
                if (getObjectFlags(target) & 1 /* Class */) {
                    const baseTypeNode = getBaseTypeNodeOfClass(target);
                    if (baseTypeNode && baseTypeNode.expression.kind !== 80 /* Identifier */ && baseTypeNode.expression.kind !== 211 /* PropertyAccessExpression */) {
                        return void 0;
                    }
                }
                const bases = getBaseTypes(target);
                if (bases.length !== 1) {
                    return void 0;
                }
                if (getMembersOfSymbol(type.symbol).size) {
                    return void 0;
                }
                let instantiatedBase = !length(target.typeParameters) ? bases[0] : instantiateType(bases[0], createTypeMapper(target.typeParameters, getTypeArguments(type).slice(0, target.typeParameters.length)));
                if (length(getTypeArguments(type)) > length(target.typeParameters)) {
                    instantiatedBase = getTypeWithThisArgument(instantiatedBase, last(getTypeArguments(type)));
                }
                type.objectFlags |= 67108864 /* IdenticalBaseTypeExists */;
                return type.cachedEquivalentBaseType = instantiatedBase;
            }
            function isEmptyLiteralType(type) {
                return strictNullChecks ? type === implicitNeverType : type === undefinedWideningType;
            }
            function isEmptyArrayLiteralType(type) {
                const elementType = getElementTypeOfArrayType(type);
                return !!elementType && isEmptyLiteralType(elementType);
            }
            function isTupleLikeType(type) {
                let lengthType;
                return isTupleType(type) || !!getPropertyOfType(type, "0") || isArrayLikeType(type) && !!(lengthType = getTypeOfPropertyOfType(type, "length")) && everyType(lengthType, (t) => !!(t.flags & 256 /* NumberLiteral */));
            }
            function isArrayOrTupleLikeType(type) {
                return isArrayLikeType(type) || isTupleLikeType(type);
            }
            function getTupleElementType(type, index) {
                const propType = getTypeOfPropertyOfType(type, "" + index);
                if (propType) {
                    return propType;
                }
                if (everyType(type, isTupleType)) {
                    return getTupleElementTypeOutOfStartCount(type, index, compilerOptions.noUncheckedIndexedAccess ? undefinedType : void 0);
                }
                return void 0;
            }
            function isNeitherUnitTypeNorNever(type) {
                return !(type.flags & (109472 /* Unit */ | 131072 /* Never */));
            }
            function isUnitType(type) {
                return !!(type.flags & 109472 /* Unit */);
            }
            function isUnitLikeType(type) {
                const t = getBaseConstraintOrType(type);
                return t.flags & 2097152 /* Intersection */ ? some(t.types, isUnitType) : isUnitType(t);
            }
            function extractUnitType(type) {
                return type.flags & 2097152 /* Intersection */ ? find(type.types, isUnitType) || type : type;
            }
            function isLiteralType(type) {
                return type.flags & 16 /* Boolean */ ? true : type.flags & 1048576 /* Union */ ? type.flags & 1024 /* EnumLiteral */ ? true : every(type.types, isUnitType) : isUnitType(type);
            }
            function getBaseTypeOfLiteralType(type) {
                return type.flags & 1056 /* EnumLike */ ? getBaseTypeOfEnumLikeType(type) : type.flags & (128 /* StringLiteral */ | 134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */) ? stringType : type.flags & 256 /* NumberLiteral */ ? numberType : type.flags & 2048 /* BigIntLiteral */ ? bigintType : type.flags & 512 /* BooleanLiteral */ ? booleanType : type.flags & 1048576 /* Union */ ? getBaseTypeOfLiteralTypeUnion(type) : type;
            }
            function getBaseTypeOfLiteralTypeUnion(type) {
                const key = `B${getTypeId(type)}`;
                return getCachedType(key) ?? setCachedType(key, mapType(type, getBaseTypeOfLiteralType));
            }
            function getBaseTypeOfLiteralTypeForComparison(type) {
                return type.flags & (128 /* StringLiteral */ | 134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */) ? stringType : type.flags & (256 /* NumberLiteral */ | 32 /* Enum */) ? numberType : type.flags & 2048 /* BigIntLiteral */ ? bigintType : type.flags & 512 /* BooleanLiteral */ ? booleanType : type.flags & 1048576 /* Union */ ? mapType(type, getBaseTypeOfLiteralTypeForComparison) : type;
            }
            function getWidenedLiteralType(type) {
                return type.flags & 1056 /* EnumLike */ && isFreshLiteralType(type) ? getBaseTypeOfEnumLikeType(type) : type.flags & 128 /* StringLiteral */ && isFreshLiteralType(type) ? stringType : type.flags & 256 /* NumberLiteral */ && isFreshLiteralType(type) ? numberType : type.flags & 2048 /* BigIntLiteral */ && isFreshLiteralType(type) ? bigintType : type.flags & 512 /* BooleanLiteral */ && isFreshLiteralType(type) ? booleanType : type.flags & 1048576 /* Union */ ? mapType(type, getWidenedLiteralType) : type;
            }
            function getWidenedUniqueESSymbolType(type) {
                return type.flags & 8192 /* UniqueESSymbol */ ? esSymbolType : type.flags & 1048576 /* Union */ ? mapType(type, getWidenedUniqueESSymbolType) : type;
            }
            function getWidenedLiteralLikeTypeForContextualType(type, contextualType) {
                if (!isLiteralOfContextualType(type, contextualType)) {
                    type = getWidenedUniqueESSymbolType(getWidenedLiteralType(type));
                }
                return getRegularTypeOfLiteralType(type);
            }
            function getWidenedLiteralLikeTypeForContextualReturnTypeIfNeeded(type, contextualSignatureReturnType, isAsync) {
                if (type && isUnitType(type)) {
                    const contextualType = !contextualSignatureReturnType ? void 0 : isAsync ? getPromisedTypeOfPromise(contextualSignatureReturnType) : contextualSignatureReturnType;
                    type = getWidenedLiteralLikeTypeForContextualType(type, contextualType);
                }
                return type;
            }
            function getWidenedLiteralLikeTypeForContextualIterationTypeIfNeeded(type, contextualSignatureReturnType, kind, isAsyncGenerator) {
                if (type && isUnitType(type)) {
                    const contextualType = !contextualSignatureReturnType ? void 0 : getIterationTypeOfGeneratorFunctionReturnType(kind, contextualSignatureReturnType, isAsyncGenerator);
                    type = getWidenedLiteralLikeTypeForContextualType(type, contextualType);
                }
                return type;
            }
            function isTupleType(type) {
                return !!(getObjectFlags(type) & 4 /* Reference */ && type.target.objectFlags & 8 /* Tuple */);
            }
            function isGenericTupleType(type) {
                return isTupleType(type) && !!(type.target.combinedFlags & 8 /* Variadic */);
            }
            function isSingleElementGenericTupleType(type) {
                return isGenericTupleType(type) && type.target.elementFlags.length === 1;
            }
            function getRestTypeOfTupleType(type) {
                return getElementTypeOfSliceOfTupleType(type, type.target.fixedLength);
            }
            function getTupleElementTypeOutOfStartCount(type, index, undefinedOrMissingType2) {
                return mapType(type, (t) => {
                    const tupleType = t;
                    const restType = getRestTypeOfTupleType(tupleType);
                    if (!restType) {
                        return undefinedType;
                    }
                    if (undefinedOrMissingType2 && index >= getTotalFixedElementCount(tupleType.target)) {
                        return getUnionType([restType, undefinedOrMissingType2]);
                    }
                    return restType;
                });
            }
            function getRestArrayTypeOfTupleType(type) {
                const restType = getRestTypeOfTupleType(type);
                return restType && createArrayType(restType);
            }
            function getElementTypeOfSliceOfTupleType(type, index, endSkipCount = 0, writing = false, noReductions = false) {
                const length2 = getTypeReferenceArity(type) - endSkipCount;
                if (index < length2) {
                    const typeArguments = getTypeArguments(type);
                    const elementTypes = [];
                    for (let i = index; i < length2; i++) {
                        const t = typeArguments[i];
                        elementTypes.push(type.target.elementFlags[i] & 8 /* Variadic */ ? getIndexedAccessType(t, numberType) : t);
                    }
                    return writing ? getIntersectionType(elementTypes) : getUnionType(elementTypes, noReductions ? 0 /* None */ : 1 /* Literal */);
                }
                return void 0;
            }
            function isTupleTypeStructureMatching(t1, t2) {
                return getTypeReferenceArity(t1) === getTypeReferenceArity(t2) && every(t1.target.elementFlags, (f, i) => (f & 12 /* Variable */) === (t2.target.elementFlags[i] & 12 /* Variable */));
            }
            function isZeroBigInt({ value }) {
                return value.base10Value === "0";
            }
            function removeDefinitelyFalsyTypes(type) {
                return filterType(type, (t) => hasTypeFacts(t, 4194304 /* Truthy */));
            }
            function extractDefinitelyFalsyTypes(type) {
                return mapType(type, getDefinitelyFalsyPartOfType);
            }
            function getDefinitelyFalsyPartOfType(type) {
                return type.flags & 4 /* String */ ? emptyStringType : type.flags & 8 /* Number */ ? zeroType : type.flags & 64 /* BigInt */ ? zeroBigIntType : type === regularFalseType || type === falseType || type.flags & (16384 /* Void */ | 32768 /* Undefined */ | 65536 /* Null */ | 3 /* AnyOrUnknown */) || type.flags & 128 /* StringLiteral */ && type.value === "" || type.flags & 256 /* NumberLiteral */ && type.value === 0 || type.flags & 2048 /* BigIntLiteral */ && isZeroBigInt(type) ? type : neverType;
            }
            function getNullableType(type, flags) {
                const missing = flags & ~type.flags & (32768 /* Undefined */ | 65536 /* Null */);
                return missing === 0 ? type : missing === 32768 /* Undefined */ ? getUnionType([type, undefinedType]) : missing === 65536 /* Null */ ? getUnionType([type, nullType]) : getUnionType([type, undefinedType, nullType]);
            }
            function getOptionalType(type, isProperty = false) {
                Debug.assert(strictNullChecks);
                const missingOrUndefined = isProperty ? undefinedOrMissingType : undefinedType;
                return type === missingOrUndefined || type.flags & 1048576 /* Union */ && type.types[0] === missingOrUndefined ? type : getUnionType([type, missingOrUndefined]);
            }
            function getGlobalNonNullableTypeInstantiation(type) {
                if (!deferredGlobalNonNullableTypeAlias) {
                    deferredGlobalNonNullableTypeAlias = getGlobalSymbol("NonNullable", 524288 /* TypeAlias */, 
                    /*diagnostic*/
                    void 0) || unknownSymbol;
                }
                return deferredGlobalNonNullableTypeAlias !== unknownSymbol ? getTypeAliasInstantiation(deferredGlobalNonNullableTypeAlias, [type]) : getIntersectionType([type, emptyObjectType]);
            }
            function getNonNullableType(type) {
                return strictNullChecks ? getAdjustedTypeWithFacts(type, 2097152 /* NEUndefinedOrNull */) : type;
            }
            function addOptionalTypeMarker(type) {
                return strictNullChecks ? getUnionType([type, optionalType]) : type;
            }
            function removeOptionalTypeMarker(type) {
                return strictNullChecks ? removeType(type, optionalType) : type;
            }
            function propagateOptionalTypeMarker(type, node, wasOptional) {
                return wasOptional ? isOutermostOptionalChain(node) ? getOptionalType(type) : addOptionalTypeMarker(type) : type;
            }
            function getOptionalExpressionType(exprType, expression) {
                return isExpressionOfOptionalChainRoot(expression) ? getNonNullableType(exprType) : isOptionalChain(expression) ? removeOptionalTypeMarker(exprType) : exprType;
            }
            function removeMissingType(type, isOptional) {
                return exactOptionalPropertyTypes && isOptional ? removeType(type, missingType) : type;
            }
            function containsMissingType(type) {
                return type === missingType || !!(type.flags & 1048576 /* Union */) && type.types[0] === missingType;
            }
            function removeMissingOrUndefinedType(type) {
                return exactOptionalPropertyTypes ? removeType(type, missingType) : getTypeWithFacts(type, 524288 /* NEUndefined */);
            }
            function isCoercibleUnderDoubleEquals(source, target) {
                return (source.flags & (8 /* Number */ | 4 /* String */ | 512 /* BooleanLiteral */)) !== 0 && (target.flags & (8 /* Number */ | 4 /* String */ | 16 /* Boolean */)) !== 0;
            }
            function isObjectTypeWithInferableIndex(type) {
                const objectFlags = getObjectFlags(type);
                return type.flags & 2097152 /* Intersection */ ? every(type.types, isObjectTypeWithInferableIndex) : !!(type.symbol && (type.symbol.flags & (4096 /* ObjectLiteral */ | 2048 /* TypeLiteral */ | 384 /* Enum */ | 512 /* ValueModule */)) !== 0 && !(type.symbol.flags & 32 /* Class */) && !typeHasCallOrConstructSignatures(type)) || !!(objectFlags & 4194304 /* ObjectRestType */) || !!(objectFlags & 1024 /* ReverseMapped */ && isObjectTypeWithInferableIndex(type.source));
            }
            function createSymbolWithType(source, type) {
                const symbol = createSymbol(source.flags, source.escapedName, getCheckFlags(source) & 8 /* Readonly */);
                symbol.declarations = source.declarations;
                symbol.parent = source.parent;
                symbol.links.type = type;
                symbol.links.target = source;
                if (source.valueDeclaration) {
                    symbol.valueDeclaration = source.valueDeclaration;
                }
                const nameType = getSymbolLinks(source).nameType;
                if (nameType) {
                    symbol.links.nameType = nameType;
                }
                return symbol;
            }
            function transformTypeOfMembers(type, f) {
                const members = createSymbolTable();
                for (const property of getPropertiesOfObjectType(type)) {
                    const original = getTypeOfSymbol(property);
                    const updated = f(original);
                    members.set(property.escapedName, updated === original ? property : createSymbolWithType(property, updated));
                }
                return members;
            }
            function getRegularTypeOfObjectLiteral(type) {
                if (!(isObjectLiteralType2(type) && getObjectFlags(type) & 8192 /* FreshLiteral */)) {
                    return type;
                }
                const regularType = type.regularType;
                if (regularType) {
                    return regularType;
                }
                const resolved = type;
                const members = transformTypeOfMembers(type, getRegularTypeOfObjectLiteral);
                const regularNew = createAnonymousType(resolved.symbol, members, resolved.callSignatures, resolved.constructSignatures, resolved.indexInfos);
                regularNew.flags = resolved.flags;
                regularNew.objectFlags |= resolved.objectFlags & ~8192 /* FreshLiteral */;
                type.regularType = regularNew;
                return regularNew;
            }
            function createWideningContext(parent2, propertyName, siblings) {
                return { parent: parent2, propertyName, siblings, resolvedProperties: void 0 };
            }
            function getSiblingsOfContext(context) {
                if (!context.siblings) {
                    const siblings = [];
                    for (const type of getSiblingsOfContext(context.parent)) {
                        if (isObjectLiteralType2(type)) {
                            const prop = getPropertyOfObjectType(type, context.propertyName);
                            if (prop) {
                                forEachType(getTypeOfSymbol(prop), (t) => {
                                    siblings.push(t);
                                });
                            }
                        }
                    }
                    context.siblings = siblings;
                }
                return context.siblings;
            }
            function getPropertiesOfContext(context) {
                if (!context.resolvedProperties) {
                    const names = /* @__PURE__ */ new Map();
                    for (const t of getSiblingsOfContext(context)) {
                        if (isObjectLiteralType2(t) && !(getObjectFlags(t) & 2097152 /* ContainsSpread */)) {
                            for (const prop of getPropertiesOfType(t)) {
                                names.set(prop.escapedName, prop);
                            }
                        }
                    }
                    context.resolvedProperties = arrayFrom(names.values());
                }
                return context.resolvedProperties;
            }
            function getWidenedProperty(prop, context) {
                if (!(prop.flags & 4 /* Property */)) {
                    return prop;
                }
                const original = getTypeOfSymbol(prop);
                const propContext = context && createWideningContext(context, prop.escapedName, 
                /*siblings*/
                void 0);
                const widened = getWidenedTypeWithContext(original, propContext);
                return widened === original ? prop : createSymbolWithType(prop, widened);
            }
            function getUndefinedProperty(prop) {
                const cached = undefinedProperties.get(prop.escapedName);
                if (cached) {
                    return cached;
                }
                const result = createSymbolWithType(prop, undefinedOrMissingType);
                result.flags |= 16777216 /* Optional */;
                undefinedProperties.set(prop.escapedName, result);
                return result;
            }
            function getWidenedTypeOfObjectLiteral(type, context) {
                const members = createSymbolTable();
                for (const prop of getPropertiesOfObjectType(type)) {
                    members.set(prop.escapedName, getWidenedProperty(prop, context));
                }
                if (context) {
                    for (const prop of getPropertiesOfContext(context)) {
                        if (!members.has(prop.escapedName)) {
                            members.set(prop.escapedName, getUndefinedProperty(prop));
                        }
                    }
                }
                const result = createAnonymousType(type.symbol, members, emptyArray, emptyArray, sameMap(getIndexInfosOfType(type), (info) => createIndexInfo(info.keyType, getWidenedType(info.type), info.isReadonly)));
                result.objectFlags |= getObjectFlags(type) & (4096 /* JSLiteral */ | 262144 /* NonInferrableType */);
                return result;
            }
            function getWidenedType(type) {
                return getWidenedTypeWithContext(type, 
                /*context*/
                void 0);
            }
            function getWidenedTypeWithContext(type, context) {
                if (getObjectFlags(type) & 196608 /* RequiresWidening */) {
                    if (context === void 0 && type.widened) {
                        return type.widened;
                    }
                    let result;
                    if (type.flags & (1 /* Any */ | 98304 /* Nullable */)) {
                        result = anyType;
                    }
                    else if (isObjectLiteralType2(type)) {
                        result = getWidenedTypeOfObjectLiteral(type, context);
                    }
                    else if (type.flags & 1048576 /* Union */) {
                        const unionContext = context || createWideningContext(
                        /*parent*/
                        void 0, 
                        /*propertyName*/
                        void 0, type.types);
                        const widenedTypes = sameMap(type.types, (t) => t.flags & 98304 /* Nullable */ ? t : getWidenedTypeWithContext(t, unionContext));
                        result = getUnionType(widenedTypes, some(widenedTypes, isEmptyObjectType) ? 2 /* Subtype */ : 1 /* Literal */);
                    }
                    else if (type.flags & 2097152 /* Intersection */) {
                        result = getIntersectionType(sameMap(type.types, getWidenedType));
                    }
                    else if (isArrayOrTupleType(type)) {
                        result = createTypeReference(type.target, sameMap(getTypeArguments(type), getWidenedType));
                    }
                    if (result && context === void 0) {
                        type.widened = result;
                    }
                    return result || type;
                }
                return type;
            }
            function reportWideningErrorsInType(type) {
                let errorReported = false;
                if (getObjectFlags(type) & 65536 /* ContainsWideningType */) {
                    if (type.flags & 1048576 /* Union */) {
                        if (some(type.types, isEmptyObjectType)) {
                            errorReported = true;
                        }
                        else {
                            for (const t of type.types) {
                                if (reportWideningErrorsInType(t)) {
                                    errorReported = true;
                                }
                            }
                        }
                    }
                    if (isArrayOrTupleType(type)) {
                        for (const t of getTypeArguments(type)) {
                            if (reportWideningErrorsInType(t)) {
                                errorReported = true;
                            }
                        }
                    }
                    if (isObjectLiteralType2(type)) {
                        for (const p of getPropertiesOfObjectType(type)) {
                            const t = getTypeOfSymbol(p);
                            if (getObjectFlags(t) & 65536 /* ContainsWideningType */) {
                                if (!reportWideningErrorsInType(t)) {
                                    error2(p.valueDeclaration, Diagnostics.Object_literal_s_property_0_implicitly_has_an_1_type, symbolToString(p), typeToString(getWidenedType(t)));
                                }
                                errorReported = true;
                            }
                        }
                    }
                }
                return errorReported;
            }
            function reportImplicitAny(declaration, type, wideningKind) {
                const typeAsString = typeToString(getWidenedType(type));
                if (isInJSFile(declaration) && !isCheckJsEnabledForFile(getSourceFileOfNode(declaration), compilerOptions)) {
                    return;
                }
                let diagnostic;
                switch (declaration.kind) {
                    case 226 /* BinaryExpression */:
                    case 172 /* PropertyDeclaration */:
                    case 171 /* PropertySignature */:
                        diagnostic = noImplicitAny ? Diagnostics.Member_0_implicitly_has_an_1_type : Diagnostics.Member_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage;
                        break;
                    case 169 /* Parameter */:
                        const param = declaration;
                        if (isIdentifier(param.name)) {
                            const originalKeywordKind = identifierToKeywordKind(param.name);
                            if ((isCallSignatureDeclaration(param.parent) || isMethodSignature(param.parent) || isFunctionTypeNode(param.parent)) && param.parent.parameters.includes(param) && (resolveName(param, param.name.escapedText, 788968 /* Type */, 
                            /*nameNotFoundMessage*/
                            void 0, param.name.escapedText, 
                            /*isUse*/
                            true) || originalKeywordKind && isTypeNodeKind(originalKeywordKind))) {
                                const newName = "arg" + param.parent.parameters.indexOf(param);
                                const typeName = declarationNameToString(param.name) + (param.dotDotDotToken ? "[]" : "");
                                errorOrSuggestion(noImplicitAny, declaration, Diagnostics.Parameter_has_a_name_but_no_type_Did_you_mean_0_Colon_1, newName, typeName);
                                return;
                            }
                        }
                        diagnostic = declaration.dotDotDotToken ? noImplicitAny ? Diagnostics.Rest_parameter_0_implicitly_has_an_any_type : Diagnostics.Rest_parameter_0_implicitly_has_an_any_type_but_a_better_type_may_be_inferred_from_usage : noImplicitAny ? Diagnostics.Parameter_0_implicitly_has_an_1_type : Diagnostics.Parameter_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage;
                        break;
                    case 208 /* BindingElement */:
                        diagnostic = Diagnostics.Binding_element_0_implicitly_has_an_1_type;
                        if (!noImplicitAny) {
                            return;
                        }
                        break;
                    case 324 /* JSDocFunctionType */:
                        error2(declaration, Diagnostics.Function_type_which_lacks_return_type_annotation_implicitly_has_an_0_return_type, typeAsString);
                        return;
                    case 330 /* JSDocSignature */:
                        if (noImplicitAny && isJSDocOverloadTag(declaration.parent)) {
                            error2(declaration.parent.tagName, Diagnostics.This_overload_implicitly_returns_the_type_0_because_it_lacks_a_return_type_annotation, typeAsString);
                        }
                        return;
                    case 262 /* FunctionDeclaration */:
                    case 174 /* MethodDeclaration */:
                    case 173 /* MethodSignature */:
                    case 177 /* GetAccessor */:
                    case 178 /* SetAccessor */:
                    case 218 /* FunctionExpression */:
                    case 219 /* ArrowFunction */:
                        if (noImplicitAny && !declaration.name) {
                            if (wideningKind === 3 /* GeneratorYield */) {
                                error2(declaration, Diagnostics.Generator_implicitly_has_yield_type_0_because_it_does_not_yield_any_values_Consider_supplying_a_return_type_annotation, typeAsString);
                            }
                            else {
                                error2(declaration, Diagnostics.Function_expression_which_lacks_return_type_annotation_implicitly_has_an_0_return_type, typeAsString);
                            }
                            return;
                        }
                        diagnostic = !noImplicitAny ? Diagnostics._0_implicitly_has_an_1_return_type_but_a_better_type_may_be_inferred_from_usage : wideningKind === 3 /* GeneratorYield */ ? Diagnostics._0_which_lacks_return_type_annotation_implicitly_has_an_1_yield_type : Diagnostics._0_which_lacks_return_type_annotation_implicitly_has_an_1_return_type;
                        break;
                    case 200 /* MappedType */:
                        if (noImplicitAny) {
                            error2(declaration, Diagnostics.Mapped_object_type_implicitly_has_an_any_template_type);
                        }
                        return;
                    default:
                        diagnostic = noImplicitAny ? Diagnostics.Variable_0_implicitly_has_an_1_type : Diagnostics.Variable_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage;
                }
                errorOrSuggestion(noImplicitAny, declaration, diagnostic, declarationNameToString(getNameOfDeclaration(declaration)), typeAsString);
            }
            function reportErrorsFromWidening(declaration, type, wideningKind) {
                addLazyDiagnostic(() => {
                    if (noImplicitAny && getObjectFlags(type) & 65536 /* ContainsWideningType */ && (!wideningKind || !getContextualSignatureForFunctionLikeDeclaration(declaration))) {
                        if (!reportWideningErrorsInType(type)) {
                            reportImplicitAny(declaration, type, wideningKind);
                        }
                    }
                });
            }
            function applyToParameterTypes(source, target, callback) {
                const sourceCount = getParameterCount(source);
                const targetCount = getParameterCount(target);
                const sourceRestType = getEffectiveRestType(source);
                const targetRestType = getEffectiveRestType(target);
                const targetNonRestCount = targetRestType ? targetCount - 1 : targetCount;
                const paramCount = sourceRestType ? targetNonRestCount : Math.min(sourceCount, targetNonRestCount);
                const sourceThisType = getThisTypeOfSignature(source);
                if (sourceThisType) {
                    const targetThisType = getThisTypeOfSignature(target);
                    if (targetThisType) {
                        callback(sourceThisType, targetThisType);
                    }
                }
                for (let i = 0; i < paramCount; i++) {
                    callback(getTypeAtPosition(source, i), getTypeAtPosition(target, i));
                }
                if (targetRestType) {
                    callback(getRestTypeAtPosition(source, paramCount, 
                    /*readonly*/
                    isConstTypeVariable(targetRestType) && !someType(targetRestType, isMutableArrayLikeType)), targetRestType);
                }
            }
            function applyToReturnTypes(source, target, callback) {
                const sourceTypePredicate = getTypePredicateOfSignature(source);
                const targetTypePredicate = getTypePredicateOfSignature(target);
                if (sourceTypePredicate && targetTypePredicate && typePredicateKindsMatch(sourceTypePredicate, targetTypePredicate) && sourceTypePredicate.type && targetTypePredicate.type) {
                    callback(sourceTypePredicate.type, targetTypePredicate.type);
                }
                else {
                    callback(getReturnTypeOfSignature(source), getReturnTypeOfSignature(target));
                }
            }
            function createInferenceContext(typeParameters, signature, flags, compareTypes) {
                return createInferenceContextWorker(typeParameters.map(createInferenceInfo), signature, flags, compareTypes || compareTypesAssignable);
            }
            function cloneInferenceContext(context, extraFlags = 0) {
                return context && createInferenceContextWorker(map(context.inferences, cloneInferenceInfo), context.signature, context.flags | extraFlags, context.compareTypes);
            }
            function createInferenceContextWorker(inferences, signature, flags, compareTypes) {
                const context = {
                    inferences,
                    signature,
                    flags,
                    compareTypes,
                    mapper: reportUnmeasurableMapper,
                    // initialize to a noop mapper so the context object is available, but the underlying object shape is right upon construction
                    nonFixingMapper: reportUnmeasurableMapper
                };
                context.mapper = makeFixingMapperForContext(context);
                context.nonFixingMapper = makeNonFixingMapperForContext(context);
                return context;
            }
            function makeFixingMapperForContext(context) {
                return makeDeferredTypeMapper(map(context.inferences, (i) => i.typeParameter), map(context.inferences, (inference, i) => () => {
                    if (!inference.isFixed) {
                        inferFromIntraExpressionSites(context);
                        clearCachedInferences(context.inferences);
                        inference.isFixed = true;
                    }
                    return getInferredType(context, i);
                }));
            }
            function makeNonFixingMapperForContext(context) {
                return makeDeferredTypeMapper(map(context.inferences, (i) => i.typeParameter), map(context.inferences, (_, i) => () => {
                    return getInferredType(context, i);
                }));
            }
            function clearCachedInferences(inferences) {
                for (const inference of inferences) {
                    if (!inference.isFixed) {
                        inference.inferredType = void 0;
                    }
                }
            }
            function addIntraExpressionInferenceSite(context, node, type) {
                (context.intraExpressionInferenceSites ?? (context.intraExpressionInferenceSites = [])).push({ node, type });
            }
            function inferFromIntraExpressionSites(context) {
                if (context.intraExpressionInferenceSites) {
                    for (const { node, type } of context.intraExpressionInferenceSites) {
                        const contextualType = node.kind === 174 /* MethodDeclaration */ ? getContextualTypeForObjectLiteralMethod(node, 2 /* NoConstraints */) : getContextualType2(node, 2 /* NoConstraints */);
                        if (contextualType) {
                            inferTypes(context.inferences, type, contextualType);
                        }
                    }
                    context.intraExpressionInferenceSites = void 0;
                }
            }
            function createInferenceInfo(typeParameter) {
                return {
                    typeParameter,
                    candidates: void 0,
                    contraCandidates: void 0,
                    inferredType: void 0,
                    priority: void 0,
                    topLevel: true,
                    isFixed: false,
                    impliedArity: void 0
                };
            }
            function cloneInferenceInfo(inference) {
                return {
                    typeParameter: inference.typeParameter,
                    candidates: inference.candidates && inference.candidates.slice(),
                    contraCandidates: inference.contraCandidates && inference.contraCandidates.slice(),
                    inferredType: inference.inferredType,
                    priority: inference.priority,
                    topLevel: inference.topLevel,
                    isFixed: inference.isFixed,
                    impliedArity: inference.impliedArity
                };
            }
            function cloneInferredPartOfContext(context) {
                const inferences = filter(context.inferences, hasInferenceCandidates);
                return inferences.length ? createInferenceContextWorker(map(inferences, cloneInferenceInfo), context.signature, context.flags, context.compareTypes) : void 0;
            }
            function getMapperFromContext(context) {
                return context && context.mapper;
            }
            function couldContainTypeVariables(type) {
                const objectFlags = getObjectFlags(type);
                if (objectFlags & 524288 /* CouldContainTypeVariablesComputed */) {
                    return !!(objectFlags & 1048576 /* CouldContainTypeVariables */);
                }
                const result = !!(type.flags & 465829888 /* Instantiable */ || type.flags & 524288 /* Object */ && !isNonGenericTopLevelType(type) && (objectFlags & 4 /* Reference */ && (type.node || some(getTypeArguments(type), couldContainTypeVariables)) || objectFlags & 16 /* Anonymous */ && type.symbol && type.symbol.flags & (16 /* Function */ | 8192 /* Method */ | 32 /* Class */ | 2048 /* TypeLiteral */ | 4096 /* ObjectLiteral */) && type.symbol.declarations || objectFlags & (32 /* Mapped */ | 1024 /* ReverseMapped */ | 4194304 /* ObjectRestType */ | 8388608 /* InstantiationExpressionType */)) || type.flags & 3145728 /* UnionOrIntersection */ && !(type.flags & 1024 /* EnumLiteral */) && !isNonGenericTopLevelType(type) && some(type.types, couldContainTypeVariables));
                if (type.flags & 3899393 /* ObjectFlagsType */) {
                    type.objectFlags |= 524288 /* CouldContainTypeVariablesComputed */ | (result ? 1048576 /* CouldContainTypeVariables */ : 0);
                }
                return result;
            }
            function isNonGenericTopLevelType(type) {
                if (type.aliasSymbol && !type.aliasTypeArguments) {
                    const declaration = getDeclarationOfKind(type.aliasSymbol, 265 /* TypeAliasDeclaration */);
                    return !!(declaration && findAncestor(declaration.parent, (n) => n.kind === 312 /* SourceFile */ ? true : n.kind === 267 /* ModuleDeclaration */ ? false : "quit"));
                }
                return false;
            }
            function isTypeParameterAtTopLevel(type, tp, depth = 0) {
                return !!(type === tp || type.flags & 3145728 /* UnionOrIntersection */ && some(type.types, (t) => isTypeParameterAtTopLevel(t, tp, depth)) || depth < 3 && type.flags & 16777216 /* Conditional */ && (isTypeParameterAtTopLevel(getTrueTypeFromConditionalType(type), tp, depth + 1) || isTypeParameterAtTopLevel(getFalseTypeFromConditionalType(type), tp, depth + 1)));
            }
            function isTypeParameterAtTopLevelInReturnType(signature, typeParameter) {
                const typePredicate = getTypePredicateOfSignature(signature);
                return typePredicate ? !!typePredicate.type && isTypeParameterAtTopLevel(typePredicate.type, typeParameter) : isTypeParameterAtTopLevel(getReturnTypeOfSignature(signature), typeParameter);
            }
            function createEmptyObjectTypeFromStringLiteral(type) {
                const members = createSymbolTable();
                forEachType(type, (t) => {
                    if (!(t.flags & 128 /* StringLiteral */)) {
                        return;
                    }
                    const name = escapeLeadingUnderscores(t.value);
                    const literalProp = createSymbol(4 /* Property */, name);
                    literalProp.links.type = anyType;
                    if (t.symbol) {
                        literalProp.declarations = t.symbol.declarations;
                        literalProp.valueDeclaration = t.symbol.valueDeclaration;
                    }
                    members.set(name, literalProp);
                });
                const indexInfos = type.flags & 4 /* String */ ? [createIndexInfo(stringType, emptyObjectType, 
                    /*isReadonly*/
                    false)] : emptyArray;
                return createAnonymousType(
                /*symbol*/
                void 0, members, emptyArray, emptyArray, indexInfos);
            }
            function inferTypeForHomomorphicMappedType(source, target, constraint) {
                const cacheKey = source.id + "," + target.id + "," + constraint.id;
                if (reverseMappedCache.has(cacheKey)) {
                    return reverseMappedCache.get(cacheKey);
                }
                const recursionKey = source.id + "," + (target.target || target).id;
                if (contains(homomorphicMappedTypeInferenceStack, recursionKey)) {
                    return void 0;
                }
                homomorphicMappedTypeInferenceStack.push(recursionKey);
                const type = createReverseMappedType(source, target, constraint);
                homomorphicMappedTypeInferenceStack.pop();
                reverseMappedCache.set(cacheKey, type);
                return type;
            }
            function isPartiallyInferableType(type) {
                return !(getObjectFlags(type) & 262144 /* NonInferrableType */) || isObjectLiteralType2(type) && some(getPropertiesOfType(type), (prop) => isPartiallyInferableType(getTypeOfSymbol(prop))) || isTupleType(type) && some(getElementTypes(type), isPartiallyInferableType);
            }
            function createReverseMappedType(source, target, constraint) {
                if (!(getIndexInfoOfType(source, stringType) || getPropertiesOfType(source).length !== 0 && isPartiallyInferableType(source))) {
                    return void 0;
                }
                if (isArrayType(source)) {
                    return createArrayType(inferReverseMappedType(getTypeArguments(source)[0], target, constraint), isReadonlyArrayType(source));
                }
                if (isTupleType(source)) {
                    const elementTypes = map(getElementTypes(source), (t) => inferReverseMappedType(t, target, constraint));
                    const elementFlags = getMappedTypeModifiers(target) & 4 /* IncludeOptional */ ? sameMap(source.target.elementFlags, (f) => f & 2 /* Optional */ ? 1 /* Required */ : f) : source.target.elementFlags;
                    return createTupleType(elementTypes, elementFlags, source.target.readonly, source.target.labeledElementDeclarations);
                }
                const reversed = createObjectType(1024 /* ReverseMapped */ | 16 /* Anonymous */, 
                /*symbol*/
                void 0);
                reversed.source = source;
                reversed.mappedType = target;
                reversed.constraintType = constraint;
                return reversed;
            }
            function getTypeOfReverseMappedSymbol(symbol) {
                const links = getSymbolLinks(symbol);
                if (!links.type) {
                    links.type = inferReverseMappedType(symbol.links.propertyType, symbol.links.mappedType, symbol.links.constraintType);
                }
                return links.type;
            }
            function inferReverseMappedType(sourceType, target, constraint) {
                const typeParameter = getIndexedAccessType(constraint.type, getTypeParameterFromMappedType(target));
                const templateType = getTemplateTypeFromMappedType(target);
                const inference = createInferenceInfo(typeParameter);
                inferTypes([inference], sourceType, templateType);
                return getTypeFromInference(inference) || unknownType;
            }
            function* getUnmatchedProperties(source, target, requireOptionalProperties, matchDiscriminantProperties) {
                const properties = getPropertiesOfType(target);
                for (const targetProp of properties) {
                    if (isStaticPrivateIdentifierProperty(targetProp)) {
                        continue;
                    }
                    if (requireOptionalProperties || !(targetProp.flags & 16777216 /* Optional */ || getCheckFlags(targetProp) & 48 /* Partial */)) {
                        const sourceProp = getPropertyOfType(source, targetProp.escapedName);
                        if (!sourceProp) {
                            yield targetProp;
                        }
                        else if (matchDiscriminantProperties) {
                            const targetType = getTypeOfSymbol(targetProp);
                            if (targetType.flags & 109472 /* Unit */) {
                                const sourceType = getTypeOfSymbol(sourceProp);
                                if (!(sourceType.flags & 1 /* Any */ || getRegularTypeOfLiteralType(sourceType) === getRegularTypeOfLiteralType(targetType))) {
                                    yield targetProp;
                                }
                            }
                        }
                    }
                }
            }
            function getUnmatchedProperty(source, target, requireOptionalProperties, matchDiscriminantProperties) {
                return firstOrUndefinedIterator(getUnmatchedProperties(source, target, requireOptionalProperties, matchDiscriminantProperties));
            }
            function tupleTypesDefinitelyUnrelated(source, target) {
                return !(target.target.combinedFlags & 8 /* Variadic */) && target.target.minLength > source.target.minLength || !target.target.hasRestElement && (source.target.hasRestElement || target.target.fixedLength < source.target.fixedLength);
            }
            function typesDefinitelyUnrelated(source, target) {
                return isTupleType(source) && isTupleType(target) ? tupleTypesDefinitelyUnrelated(source, target) : !!getUnmatchedProperty(source, target, 
                /*requireOptionalProperties*/
                false, 
                /*matchDiscriminantProperties*/
                true) && !!getUnmatchedProperty(target, source, 
                /*requireOptionalProperties*/
                false, 
                /*matchDiscriminantProperties*/
                false);
            }
            function getTypeFromInference(inference) {
                return inference.candidates ? getUnionType(inference.candidates, 2 /* Subtype */) : inference.contraCandidates ? getIntersectionType(inference.contraCandidates) : void 0;
            }
            function hasSkipDirectInferenceFlag(node) {
                return !!getNodeLinks(node).skipDirectInference;
            }
            function isFromInferenceBlockedSource(type) {
                return !!(type.symbol && some(type.symbol.declarations, hasSkipDirectInferenceFlag));
            }
            function templateLiteralTypesDefinitelyUnrelated(source, target) {
                const sourceStart = source.texts[0];
                const targetStart = target.texts[0];
                const sourceEnd = source.texts[source.texts.length - 1];
                const targetEnd = target.texts[target.texts.length - 1];
                const startLen = Math.min(sourceStart.length, targetStart.length);
                const endLen = Math.min(sourceEnd.length, targetEnd.length);
                return sourceStart.slice(0, startLen) !== targetStart.slice(0, startLen) || sourceEnd.slice(sourceEnd.length - endLen) !== targetEnd.slice(targetEnd.length - endLen);
            }
            function isValidNumberString(s, roundTripOnly) {
                if (s === "")
                    return false;
                const n = +s;
                return isFinite(n) && (!roundTripOnly || "" + n === s);
            }
            function parseBigIntLiteralType(text) {
                return getBigIntLiteralType(parseValidBigInt(text));
            }
            function isMemberOfStringMapping(source, target) {
                if (target.flags & 1 /* Any */) {
                    return true;
                }
                if (target.flags & (4 /* String */ | 134217728 /* TemplateLiteral */)) {
                    return isTypeAssignableTo(source, target);
                }
                if (target.flags & 268435456 /* StringMapping */) {
                    const mappingStack = [];
                    while (target.flags & 268435456 /* StringMapping */) {
                        mappingStack.unshift(target.symbol);
                        target = target.type;
                    }
                    const mappedSource = reduceLeft(mappingStack, (memo, value) => getStringMappingType(value, memo), source);
                    return mappedSource === source && isMemberOfStringMapping(source, target);
                }
                return false;
            }
            function isValidTypeForTemplateLiteralPlaceholder(source, target) {
                if (target.flags & 2097152 /* Intersection */) {
                    return every(target.types, (t) => t === emptyTypeLiteralType || isValidTypeForTemplateLiteralPlaceholder(source, t));
                }
                if (target.flags & 4 /* String */ || isTypeAssignableTo(source, target)) {
                    return true;
                }
                if (source.flags & 128 /* StringLiteral */) {
                    const value = source.value;
                    return !!(target.flags & 8 /* Number */ && isValidNumberString(value, 
                    /*roundTripOnly*/
                    false) || target.flags & 64 /* BigInt */ && isValidBigIntString(value, 
                    /*roundTripOnly*/
                    false) || target.flags & (512 /* BooleanLiteral */ | 98304 /* Nullable */) && value === target.intrinsicName || target.flags & 268435456 /* StringMapping */ && isMemberOfStringMapping(getStringLiteralType(value), target) || target.flags & 134217728 /* TemplateLiteral */ && isTypeMatchedByTemplateLiteralType(source, target));
                }
                if (source.flags & 134217728 /* TemplateLiteral */) {
                    const texts = source.texts;
                    return texts.length === 2 && texts[0] === "" && texts[1] === "" && isTypeAssignableTo(source.types[0], target);
                }
                return false;
            }
            function inferTypesFromTemplateLiteralType(source, target) {
                return source.flags & 128 /* StringLiteral */ ? inferFromLiteralPartsToTemplateLiteral([source.value], emptyArray, target) : source.flags & 134217728 /* TemplateLiteral */ ? arraysEqual(source.texts, target.texts) ? map(source.types, getStringLikeTypeForType) : inferFromLiteralPartsToTemplateLiteral(source.texts, source.types, target) : void 0;
            }
            function isTypeMatchedByTemplateLiteralType(source, target) {
                const inferences = inferTypesFromTemplateLiteralType(source, target);
                return !!inferences && every(inferences, (r, i) => isValidTypeForTemplateLiteralPlaceholder(r, target.types[i]));
            }
            function getStringLikeTypeForType(type) {
                return type.flags & (1 /* Any */ | 402653316 /* StringLike */) ? type : getTemplateLiteralType(["", ""], [type]);
            }
            function inferFromLiteralPartsToTemplateLiteral(sourceTexts, sourceTypes, target) {
                const lastSourceIndex = sourceTexts.length - 1;
                const sourceStartText = sourceTexts[0];
                const sourceEndText = sourceTexts[lastSourceIndex];
                const targetTexts = target.texts;
                const lastTargetIndex = targetTexts.length - 1;
                const targetStartText = targetTexts[0];
                const targetEndText = targetTexts[lastTargetIndex];
                if (lastSourceIndex === 0 && sourceStartText.length < targetStartText.length + targetEndText.length || !sourceStartText.startsWith(targetStartText) || !sourceEndText.endsWith(targetEndText))
                    return void 0;
                const remainingEndText = sourceEndText.slice(0, sourceEndText.length - targetEndText.length);
                const matches = [];
                let seg = 0;
                let pos = targetStartText.length;
                for (let i = 1; i < lastTargetIndex; i++) {
                    const delim = targetTexts[i];
                    if (delim.length > 0) {
                        let s = seg;
                        let p = pos;
                        while (true) {
                            p = getSourceText(s).indexOf(delim, p);
                            if (p >= 0)
                                break;
                            s++;
                            if (s === sourceTexts.length)
                                return void 0;
                            p = 0;
                        }
                        addMatch(s, p);
                        pos += delim.length;
                    }
                    else if (pos < getSourceText(seg).length) {
                        addMatch(seg, pos + 1);
                    }
                    else if (seg < lastSourceIndex) {
                        addMatch(seg + 1, 0);
                    }
                    else {
                        return void 0;
                    }
                }
                addMatch(lastSourceIndex, getSourceText(lastSourceIndex).length);
                return matches;
                function getSourceText(index) {
                    return index < lastSourceIndex ? sourceTexts[index] : remainingEndText;
                }
                function addMatch(s, p) {
                    const matchType = s === seg ? getStringLiteralType(getSourceText(s).slice(pos, p)) : getTemplateLiteralType([sourceTexts[seg].slice(pos), ...sourceTexts.slice(seg + 1, s), getSourceText(s).slice(0, p)], sourceTypes.slice(seg, s));
                    matches.push(matchType);
                    seg = s;
                    pos = p;
                }
            }
            function inferTypes(inferences, originalSource, originalTarget, priority = 0 /* None */, contravariant = false) {
                let bivariant = false;
                let propagationType;
                let inferencePriority = 2048 /* MaxValue */;
                let visited;
                let sourceStack;
                let targetStack;
                let expandingFlags = 0 /* None */;
                inferFromTypes(originalSource, originalTarget);
                function inferFromTypes(source, target) {
                    if (!couldContainTypeVariables(target) || isNoInferType(target)) {
                        return;
                    }
                    if (source === wildcardType || source === blockedStringType) {
                        const savePropagationType = propagationType;
                        propagationType = source;
                        inferFromTypes(target, target);
                        propagationType = savePropagationType;
                        return;
                    }
                    if (source.aliasSymbol && source.aliasSymbol === target.aliasSymbol) {
                        if (source.aliasTypeArguments) {
                            const params = getSymbolLinks(source.aliasSymbol).typeParameters;
                            const minParams = getMinTypeArgumentCount(params);
                            const sourceTypes = fillMissingTypeArguments(source.aliasTypeArguments, params, minParams, isInJSFile(source.aliasSymbol.valueDeclaration));
                            const targetTypes = fillMissingTypeArguments(target.aliasTypeArguments, params, minParams, isInJSFile(source.aliasSymbol.valueDeclaration));
                            inferFromTypeArguments(sourceTypes, targetTypes, getAliasVariances(source.aliasSymbol));
                        }
                        return;
                    }
                    if (source === target && source.flags & 3145728 /* UnionOrIntersection */) {
                        for (const t of source.types) {
                            inferFromTypes(t, t);
                        }
                        return;
                    }
                    if (target.flags & 1048576 /* Union */) {
                        const [tempSources, tempTargets] = inferFromMatchingTypes(source.flags & 1048576 /* Union */ ? source.types : [source], target.types, isTypeOrBaseIdenticalTo);
                        const [sources, targets] = inferFromMatchingTypes(tempSources, tempTargets, isTypeCloselyMatchedBy);
                        if (targets.length === 0) {
                            return;
                        }
                        target = getUnionType(targets);
                        if (sources.length === 0) {
                            inferWithPriority(source, target, 1 /* NakedTypeVariable */);
                            return;
                        }
                        source = getUnionType(sources);
                    }
                    else if (target.flags & 2097152 /* Intersection */ && !every(target.types, isNonGenericObjectType)) {
                        if (!(source.flags & 1048576 /* Union */)) {
                            const [sources, targets] = inferFromMatchingTypes(source.flags & 2097152 /* Intersection */ ? source.types : [source], target.types, isTypeIdenticalTo);
                            if (sources.length === 0 || targets.length === 0) {
                                return;
                            }
                            source = getIntersectionType(sources);
                            target = getIntersectionType(targets);
                        }
                    }
                    if (target.flags & (8388608 /* IndexedAccess */ | 33554432 /* Substitution */)) {
                        if (isNoInferType(target)) {
                            return;
                        }
                        target = getActualTypeVariable(target);
                    }
                    if (target.flags & 8650752 /* TypeVariable */) {
                        if (isFromInferenceBlockedSource(source)) {
                            return;
                        }
                        const inference = getInferenceInfoForType(target);
                        if (inference) {
                            if (getObjectFlags(source) & 262144 /* NonInferrableType */ || source === nonInferrableAnyType) {
                                return;
                            }
                            if (!inference.isFixed) {
                                const candidate = propagationType || source;
                                if (candidate === blockedStringType) {
                                    return;
                                }
                                if (inference.priority === void 0 || priority < inference.priority) {
                                    inference.candidates = void 0;
                                    inference.contraCandidates = void 0;
                                    inference.topLevel = true;
                                    inference.priority = priority;
                                }
                                if (priority === inference.priority) {
                                    if (contravariant && !bivariant) {
                                        if (!contains(inference.contraCandidates, candidate)) {
                                            inference.contraCandidates = append(inference.contraCandidates, candidate);
                                            clearCachedInferences(inferences);
                                        }
                                    }
                                    else if (!contains(inference.candidates, candidate)) {
                                        inference.candidates = append(inference.candidates, candidate);
                                        clearCachedInferences(inferences);
                                    }
                                }
                                if (!(priority & 128 /* ReturnType */) && target.flags & 262144 /* TypeParameter */ && inference.topLevel && !isTypeParameterAtTopLevel(originalTarget, target)) {
                                    inference.topLevel = false;
                                    clearCachedInferences(inferences);
                                }
                            }
                            inferencePriority = Math.min(inferencePriority, priority);
                            return;
                        }
                        const simplified = getSimplifiedType(target, 
                        /*writing*/
                        false);
                        if (simplified !== target) {
                            inferFromTypes(source, simplified);
                        }
                        else if (target.flags & 8388608 /* IndexedAccess */) {
                            const indexType = getSimplifiedType(target.indexType, 
                            /*writing*/
                            false);
                            if (indexType.flags & 465829888 /* Instantiable */) {
                                const simplified2 = distributeIndexOverObjectType(getSimplifiedType(target.objectType, 
                                /*writing*/
                                false), indexType, 
                                /*writing*/
                                false);
                                if (simplified2 && simplified2 !== target) {
                                    inferFromTypes(source, simplified2);
                                }
                            }
                        }
                    }
                    if (getObjectFlags(source) & 4 /* Reference */ && getObjectFlags(target) & 4 /* Reference */ && (source.target === target.target || isArrayType(source) && isArrayType(target)) && !(source.node && target.node)) {
                        inferFromTypeArguments(getTypeArguments(source), getTypeArguments(target), getVariances(source.target));
                    }
                    else if (source.flags & 4194304 /* Index */ && target.flags & 4194304 /* Index */) {
                        inferFromContravariantTypes(source.type, target.type);
                    }
                    else if ((isLiteralType(source) || source.flags & 4 /* String */) && target.flags & 4194304 /* Index */) {
                        const empty = createEmptyObjectTypeFromStringLiteral(source);
                        inferFromContravariantTypesWithPriority(empty, target.type, 256 /* LiteralKeyof */);
                    }
                    else if (source.flags & 8388608 /* IndexedAccess */ && target.flags & 8388608 /* IndexedAccess */) {
                        inferFromTypes(source.objectType, target.objectType);
                        inferFromTypes(source.indexType, target.indexType);
                    }
                    else if (source.flags & 268435456 /* StringMapping */ && target.flags & 268435456 /* StringMapping */) {
                        if (source.symbol === target.symbol) {
                            inferFromTypes(source.type, target.type);
                        }
                    }
                    else if (source.flags & 33554432 /* Substitution */) {
                        inferFromTypes(source.baseType, target);
                        inferWithPriority(getSubstitutionIntersection(source), target, 4 /* SubstituteSource */);
                    }
                    else if (target.flags & 16777216 /* Conditional */) {
                        invokeOnce(source, target, inferToConditionalType);
                    }
                    else if (target.flags & 3145728 /* UnionOrIntersection */) {
                        inferToMultipleTypes(source, target.types, target.flags);
                    }
                    else if (source.flags & 1048576 /* Union */) {
                        const sourceTypes = source.types;
                        for (const sourceType of sourceTypes) {
                            inferFromTypes(sourceType, target);
                        }
                    }
                    else if (target.flags & 134217728 /* TemplateLiteral */) {
                        inferToTemplateLiteralType(source, target);
                    }
                    else {
                        source = getReducedType(source);
                        if (isGenericMappedType(source) && isGenericMappedType(target)) {
                            invokeOnce(source, target, inferFromGenericMappedTypes);
                        }
                        if (!(priority & 512 /* NoConstraints */ && source.flags & (2097152 /* Intersection */ | 465829888 /* Instantiable */))) {
                            const apparentSource = getApparentType(source);
                            if (apparentSource !== source && !(apparentSource.flags & (524288 /* Object */ | 2097152 /* Intersection */))) {
                                return inferFromTypes(apparentSource, target);
                            }
                            source = apparentSource;
                        }
                        if (source.flags & (524288 /* Object */ | 2097152 /* Intersection */)) {
                            invokeOnce(source, target, inferFromObjectTypes);
                        }
                    }
                }
                function inferWithPriority(source, target, newPriority) {
                    const savePriority = priority;
                    priority |= newPriority;
                    inferFromTypes(source, target);
                    priority = savePriority;
                }
                function inferFromContravariantTypesWithPriority(source, target, newPriority) {
                    const savePriority = priority;
                    priority |= newPriority;
                    inferFromContravariantTypes(source, target);
                    priority = savePriority;
                }
                function inferToMultipleTypesWithPriority(source, targets, targetFlags, newPriority) {
                    const savePriority = priority;
                    priority |= newPriority;
                    inferToMultipleTypes(source, targets, targetFlags);
                    priority = savePriority;
                }
                function invokeOnce(source, target, action) {
                    const key = source.id + "," + target.id;
                    const status = visited && visited.get(key);
                    if (status !== void 0) {
                        inferencePriority = Math.min(inferencePriority, status);
                        return;
                    }
                    (visited || (visited = /* @__PURE__ */ new Map())).set(key, -1 /* Circularity */);
                    const saveInferencePriority = inferencePriority;
                    inferencePriority = 2048 /* MaxValue */;
                    const saveExpandingFlags = expandingFlags;
                    (sourceStack ?? (sourceStack = [])).push(source);
                    (targetStack ?? (targetStack = [])).push(target);
                    if (isDeeplyNestedType(source, sourceStack, sourceStack.length, 2))
                        expandingFlags |= 1 /* Source */;
                    if (isDeeplyNestedType(target, targetStack, targetStack.length, 2))
                        expandingFlags |= 2 /* Target */;
                    if (expandingFlags !== 3 /* Both */) {
                        action(source, target);
                    }
                    else {
                        inferencePriority = -1 /* Circularity */;
                    }
                    targetStack.pop();
                    sourceStack.pop();
                    expandingFlags = saveExpandingFlags;
                    visited.set(key, inferencePriority);
                    inferencePriority = Math.min(inferencePriority, saveInferencePriority);
                }
                function inferFromMatchingTypes(sources, targets, matches) {
                    let matchedSources;
                    let matchedTargets;
                    for (const t of targets) {
                        for (const s of sources) {
                            if (matches(s, t)) {
                                inferFromTypes(s, t);
                                matchedSources = appendIfUnique(matchedSources, s);
                                matchedTargets = appendIfUnique(matchedTargets, t);
                            }
                        }
                    }
                    return [
                        matchedSources ? filter(sources, (t) => !contains(matchedSources, t)) : sources,
                        matchedTargets ? filter(targets, (t) => !contains(matchedTargets, t)) : targets
                    ];
                }
                function inferFromTypeArguments(sourceTypes, targetTypes, variances) {
                    const count = sourceTypes.length < targetTypes.length ? sourceTypes.length : targetTypes.length;
                    for (let i = 0; i < count; i++) {
                        if (i < variances.length && (variances[i] & 7 /* VarianceMask */) === 2 /* Contravariant */) {
                            inferFromContravariantTypes(sourceTypes[i], targetTypes[i]);
                        }
                        else {
                            inferFromTypes(sourceTypes[i], targetTypes[i]);
                        }
                    }
                }
                function inferFromContravariantTypes(source, target) {
                    contravariant = !contravariant;
                    inferFromTypes(source, target);
                    contravariant = !contravariant;
                }
                function inferFromContravariantTypesIfStrictFunctionTypes(source, target) {
                    if (strictFunctionTypes || priority & 1024 /* AlwaysStrict */) {
                        inferFromContravariantTypes(source, target);
                    }
                    else {
                        inferFromTypes(source, target);
                    }
                }
                function getInferenceInfoForType(type) {
                    if (type.flags & 8650752 /* TypeVariable */) {
                        for (const inference of inferences) {
                            if (type === inference.typeParameter) {
                                return inference;
                            }
                        }
                    }
                    return void 0;
                }
                function getSingleTypeVariableFromIntersectionTypes(types) {
                    let typeVariable;
                    for (const type of types) {
                        const t = type.flags & 2097152 /* Intersection */ && find(type.types, (t2) => !!getInferenceInfoForType(t2));
                        if (!t || typeVariable && t !== typeVariable) {
                            return void 0;
                        }
                        typeVariable = t;
                    }
                    return typeVariable;
                }
                function inferToMultipleTypes(source, targets, targetFlags) {
                    let typeVariableCount = 0;
                    if (targetFlags & 1048576 /* Union */) {
                        let nakedTypeVariable;
                        const sources = source.flags & 1048576 /* Union */ ? source.types : [source];
                        const matched = new Array(sources.length);
                        let inferenceCircularity = false;
                        for (const t of targets) {
                            if (getInferenceInfoForType(t)) {
                                nakedTypeVariable = t;
                                typeVariableCount++;
                            }
                            else {
                                for (let i = 0; i < sources.length; i++) {
                                    const saveInferencePriority = inferencePriority;
                                    inferencePriority = 2048 /* MaxValue */;
                                    inferFromTypes(sources[i], t);
                                    if (inferencePriority === priority)
                                        matched[i] = true;
                                    inferenceCircularity = inferenceCircularity || inferencePriority === -1 /* Circularity */;
                                    inferencePriority = Math.min(inferencePriority, saveInferencePriority);
                                }
                            }
                        }
                        if (typeVariableCount === 0) {
                            const intersectionTypeVariable = getSingleTypeVariableFromIntersectionTypes(targets);
                            if (intersectionTypeVariable) {
                                inferWithPriority(source, intersectionTypeVariable, 1 /* NakedTypeVariable */);
                            }
                            return;
                        }
                        if (typeVariableCount === 1 && !inferenceCircularity) {
                            const unmatched = flatMap(sources, (s, i) => matched[i] ? void 0 : s);
                            if (unmatched.length) {
                                inferFromTypes(getUnionType(unmatched), nakedTypeVariable);
                                return;
                            }
                        }
                    }
                    else {
                        for (const t of targets) {
                            if (getInferenceInfoForType(t)) {
                                typeVariableCount++;
                            }
                            else {
                                inferFromTypes(source, t);
                            }
                        }
                    }
                    if (targetFlags & 2097152 /* Intersection */ ? typeVariableCount === 1 : typeVariableCount > 0) {
                        for (const t of targets) {
                            if (getInferenceInfoForType(t)) {
                                inferWithPriority(source, t, 1 /* NakedTypeVariable */);
                            }
                        }
                    }
                }
                function inferToMappedType(source, target, constraintType) {
                    if (constraintType.flags & 1048576 /* Union */ || constraintType.flags & 2097152 /* Intersection */) {
                        let result = false;
                        for (const type of constraintType.types) {
                            result = inferToMappedType(source, target, type) || result;
                        }
                        return result;
                    }
                    if (constraintType.flags & 4194304 /* Index */) {
                        const inference = getInferenceInfoForType(constraintType.type);
                        if (inference && !inference.isFixed && !isFromInferenceBlockedSource(source)) {
                            const inferredType = inferTypeForHomomorphicMappedType(source, target, constraintType);
                            if (inferredType) {
                                inferWithPriority(inferredType, inference.typeParameter, getObjectFlags(source) & 262144 /* NonInferrableType */ ? 16 /* PartialHomomorphicMappedType */ : 8 /* HomomorphicMappedType */);
                            }
                        }
                        return true;
                    }
                    if (constraintType.flags & 262144 /* TypeParameter */) {
                        inferWithPriority(getIndexType(source, 
                        /*indexFlags*/
                        !!source.pattern ? 2 /* NoIndexSignatures */ : 0 /* None */), constraintType, 32 /* MappedTypeConstraint */);
                        const extendedConstraint = getConstraintOfType(constraintType);
                        if (extendedConstraint && inferToMappedType(source, target, extendedConstraint)) {
                            return true;
                        }
                        const propTypes = map(getPropertiesOfType(source), getTypeOfSymbol);
                        const indexTypes = map(getIndexInfosOfType(source), (info) => info !== enumNumberIndexInfo ? info.type : neverType);
                        inferFromTypes(getUnionType(concatenate(propTypes, indexTypes)), getTemplateTypeFromMappedType(target));
                        return true;
                    }
                    return false;
                }
                function inferToConditionalType(source, target) {
                    if (source.flags & 16777216 /* Conditional */) {
                        inferFromTypes(source.checkType, target.checkType);
                        inferFromTypes(source.extendsType, target.extendsType);
                        inferFromTypes(getTrueTypeFromConditionalType(source), getTrueTypeFromConditionalType(target));
                        inferFromTypes(getFalseTypeFromConditionalType(source), getFalseTypeFromConditionalType(target));
                    }
                    else {
                        const targetTypes = [getTrueTypeFromConditionalType(target), getFalseTypeFromConditionalType(target)];
                        inferToMultipleTypesWithPriority(source, targetTypes, target.flags, contravariant ? 64 /* ContravariantConditional */ : 0);
                    }
                }
                function inferToTemplateLiteralType(source, target) {
                    const matches = inferTypesFromTemplateLiteralType(source, target);
                    const types = target.types;
                    if (matches || every(target.texts, (s) => s.length === 0)) {
                        for (let i = 0; i < types.length; i++) {
                            const source2 = matches ? matches[i] : neverType;
                            const target2 = types[i];
                            if (source2.flags & 128 /* StringLiteral */ && target2.flags & 8650752 /* TypeVariable */) {
                                const inferenceContext = getInferenceInfoForType(target2);
                                const constraint = inferenceContext ? getBaseConstraintOfType(inferenceContext.typeParameter) : void 0;
                                if (constraint && !isTypeAny(constraint)) {
                                    const constraintTypes = constraint.flags & 1048576 /* Union */ ? constraint.types : [constraint];
                                    let allTypeFlags = reduceLeft(constraintTypes, (flags, t) => flags | t.flags, 0);
                                    if (!(allTypeFlags & 4 /* String */)) {
                                        const str = source2.value;
                                        if (allTypeFlags & 296 /* NumberLike */ && !isValidNumberString(str, 
                                        /*roundTripOnly*/
                                        true)) {
                                            allTypeFlags &= ~296 /* NumberLike */;
                                        }
                                        if (allTypeFlags & 2112 /* BigIntLike */ && !isValidBigIntString(str, 
                                        /*roundTripOnly*/
                                        true)) {
                                            allTypeFlags &= ~2112 /* BigIntLike */;
                                        }
                                        const matchingType = reduceLeft(constraintTypes, (left, right) => !(right.flags & allTypeFlags) ? left : left.flags & 4 /* String */ ? left : right.flags & 4 /* String */ ? source2 : left.flags & 134217728 /* TemplateLiteral */ ? left : right.flags & 134217728 /* TemplateLiteral */ && isTypeMatchedByTemplateLiteralType(source2, right) ? source2 : left.flags & 268435456 /* StringMapping */ ? left : right.flags & 268435456 /* StringMapping */ && str === applyStringMapping(right.symbol, str) ? source2 : left.flags & 128 /* StringLiteral */ ? left : right.flags & 128 /* StringLiteral */ && right.value === str ? right : left.flags & 8 /* Number */ ? left : right.flags & 8 /* Number */ ? getNumberLiteralType(+str) : left.flags & 32 /* Enum */ ? left : right.flags & 32 /* Enum */ ? getNumberLiteralType(+str) : left.flags & 256 /* NumberLiteral */ ? left : right.flags & 256 /* NumberLiteral */ && right.value === +str ? right : left.flags & 64 /* BigInt */ ? left : right.flags & 64 /* BigInt */ ? parseBigIntLiteralType(str) : left.flags & 2048 /* BigIntLiteral */ ? left : right.flags & 2048 /* BigIntLiteral */ && pseudoBigIntToString(right.value) === str ? right : left.flags & 16 /* Boolean */ ? left : right.flags & 16 /* Boolean */ ? str === "true" ? trueType : str === "false" ? falseType : booleanType : left.flags & 512 /* BooleanLiteral */ ? left : right.flags & 512 /* BooleanLiteral */ && right.intrinsicName === str ? right : left.flags & 32768 /* Undefined */ ? left : right.flags & 32768 /* Undefined */ && right.intrinsicName === str ? right : left.flags & 65536 /* Null */ ? left : right.flags & 65536 /* Null */ && right.intrinsicName === str ? right : left, neverType);
                                        if (!(matchingType.flags & 131072 /* Never */)) {
                                            inferFromTypes(matchingType, target2);
                                            continue;
                                        }
                                    }
                                }
                            }
                            inferFromTypes(source2, target2);
                        }
                    }
                }
                function inferFromGenericMappedTypes(source, target) {
                    inferFromTypes(getConstraintTypeFromMappedType(source), getConstraintTypeFromMappedType(target));
                    inferFromTypes(getTemplateTypeFromMappedType(source), getTemplateTypeFromMappedType(target));
                    const sourceNameType = getNameTypeFromMappedType(source);
                    const targetNameType = getNameTypeFromMappedType(target);
                    if (sourceNameType && targetNameType)
                        inferFromTypes(sourceNameType, targetNameType);
                }
                function inferFromObjectTypes(source, target) {
                    var _a, _b;
                    if (getObjectFlags(source) & 4 /* Reference */ && getObjectFlags(target) & 4 /* Reference */ && (source.target === target.target || isArrayType(source) && isArrayType(target))) {
                        inferFromTypeArguments(getTypeArguments(source), getTypeArguments(target), getVariances(source.target));
                        return;
                    }
                    if (isGenericMappedType(source) && isGenericMappedType(target)) {
                        inferFromGenericMappedTypes(source, target);
                    }
                    if (getObjectFlags(target) & 32 /* Mapped */ && !target.declaration.nameType) {
                        const constraintType = getConstraintTypeFromMappedType(target);
                        if (inferToMappedType(source, target, constraintType)) {
                            return;
                        }
                    }
                    if (!typesDefinitelyUnrelated(source, target)) {
                        if (isArrayOrTupleType(source)) {
                            if (isTupleType(target)) {
                                const sourceArity = getTypeReferenceArity(source);
                                const targetArity = getTypeReferenceArity(target);
                                const elementTypes = getTypeArguments(target);
                                const elementFlags = target.target.elementFlags;
                                if (isTupleType(source) && isTupleTypeStructureMatching(source, target)) {
                                    for (let i = 0; i < targetArity; i++) {
                                        inferFromTypes(getTypeArguments(source)[i], elementTypes[i]);
                                    }
                                    return;
                                }
                                const startLength = isTupleType(source) ? Math.min(source.target.fixedLength, target.target.fixedLength) : 0;
                                const endLength = Math.min(isTupleType(source) ? getEndElementCount(source.target, 3 /* Fixed */) : 0, target.target.hasRestElement ? getEndElementCount(target.target, 3 /* Fixed */) : 0);
                                for (let i = 0; i < startLength; i++) {
                                    inferFromTypes(getTypeArguments(source)[i], elementTypes[i]);
                                }
                                if (!isTupleType(source) || sourceArity - startLength - endLength === 1 && source.target.elementFlags[startLength] & 4 /* Rest */) {
                                    const restType = getTypeArguments(source)[startLength];
                                    for (let i = startLength; i < targetArity - endLength; i++) {
                                        inferFromTypes(elementFlags[i] & 8 /* Variadic */ ? createArrayType(restType) : restType, elementTypes[i]);
                                    }
                                }
                                else {
                                    const middleLength = targetArity - startLength - endLength;
                                    if (middleLength === 2) {
                                        if (elementFlags[startLength] & elementFlags[startLength + 1] & 8 /* Variadic */) {
                                            const targetInfo = getInferenceInfoForType(elementTypes[startLength]);
                                            if (targetInfo && targetInfo.impliedArity !== void 0) {
                                                inferFromTypes(sliceTupleType(source, startLength, endLength + sourceArity - targetInfo.impliedArity), elementTypes[startLength]);
                                                inferFromTypes(sliceTupleType(source, startLength + targetInfo.impliedArity, endLength), elementTypes[startLength + 1]);
                                            }
                                        }
                                        else if (elementFlags[startLength] & 8 /* Variadic */ && elementFlags[startLength + 1] & 4 /* Rest */) {
                                            const param = (_a = getInferenceInfoForType(elementTypes[startLength])) == null ? void 0 : _a.typeParameter;
                                            const constraint = param && getBaseConstraintOfType(param);
                                            if (constraint && isTupleType(constraint) && !constraint.target.hasRestElement) {
                                                const impliedArity = constraint.target.fixedLength;
                                                inferFromTypes(sliceTupleType(source, startLength, sourceArity - (startLength + impliedArity)), elementTypes[startLength]);
                                                inferFromTypes(getElementTypeOfSliceOfTupleType(source, startLength + impliedArity, endLength), elementTypes[startLength + 1]);
                                            }
                                        }
                                        else if (elementFlags[startLength] & 4 /* Rest */ && elementFlags[startLength + 1] & 8 /* Variadic */) {
                                            const param = (_b = getInferenceInfoForType(elementTypes[startLength + 1])) == null ? void 0 : _b.typeParameter;
                                            const constraint = param && getBaseConstraintOfType(param);
                                            if (constraint && isTupleType(constraint) && !constraint.target.hasRestElement) {
                                                const impliedArity = constraint.target.fixedLength;
                                                const endIndex = sourceArity - getEndElementCount(target.target, 3 /* Fixed */);
                                                const startIndex = endIndex - impliedArity;
                                                const trailingSlice = createTupleType(getTypeArguments(source).slice(startIndex, endIndex), source.target.elementFlags.slice(startIndex, endIndex), 
                                                /*readonly*/
                                                false, source.target.labeledElementDeclarations && source.target.labeledElementDeclarations.slice(startIndex, endIndex));
                                                inferFromTypes(getElementTypeOfSliceOfTupleType(source, startLength, endLength + impliedArity), elementTypes[startLength]);
                                                inferFromTypes(trailingSlice, elementTypes[startLength + 1]);
                                            }
                                        }
                                    }
                                    else if (middleLength === 1 && elementFlags[startLength] & 8 /* Variadic */) {
                                        const endsInOptional = target.target.elementFlags[targetArity - 1] & 2 /* Optional */;
                                        const sourceSlice = sliceTupleType(source, startLength, endLength);
                                        inferWithPriority(sourceSlice, elementTypes[startLength], endsInOptional ? 2 /* SpeculativeTuple */ : 0);
                                    }
                                    else if (middleLength === 1 && elementFlags[startLength] & 4 /* Rest */) {
                                        const restType = getElementTypeOfSliceOfTupleType(source, startLength, endLength);
                                        if (restType) {
                                            inferFromTypes(restType, elementTypes[startLength]);
                                        }
                                    }
                                }
                                for (let i = 0; i < endLength; i++) {
                                    inferFromTypes(getTypeArguments(source)[sourceArity - i - 1], elementTypes[targetArity - i - 1]);
                                }
                                return;
                            }
                            if (isArrayType(target)) {
                                inferFromIndexTypes(source, target);
                                return;
                            }
                        }
                        inferFromProperties(source, target);
                        inferFromSignatures(source, target, 0 /* Call */);
                        inferFromSignatures(source, target, 1 /* Construct */);
                        inferFromIndexTypes(source, target);
                    }
                }
                function inferFromProperties(source, target) {
                    const properties = getPropertiesOfObjectType(target);
                    for (const targetProp of properties) {
                        const sourceProp = getPropertyOfType(source, targetProp.escapedName);
                        if (sourceProp && !some(sourceProp.declarations, hasSkipDirectInferenceFlag)) {
                            inferFromTypes(getTypeOfSymbol(sourceProp), getTypeOfSymbol(targetProp));
                        }
                    }
                }
                function inferFromSignatures(source, target, kind) {
                    const sourceSignatures = getSignaturesOfType(source, kind);
                    const sourceLen = sourceSignatures.length;
                    if (sourceLen > 0) {
                        const targetSignatures = getSignaturesOfType(target, kind);
                        const targetLen = targetSignatures.length;
                        for (let i = 0; i < targetLen; i++) {
                            const sourceIndex = Math.max(sourceLen - targetLen + i, 0);
                            inferFromSignature(getBaseSignature(sourceSignatures[sourceIndex]), getErasedSignature(targetSignatures[i]));
                        }
                    }
                }
                function inferFromSignature(source, target) {
                    if (!(source.flags & 64 /* IsNonInferrable */)) {
                        const saveBivariant = bivariant;
                        const kind = target.declaration ? target.declaration.kind : 0 /* Unknown */;
                        bivariant = bivariant || kind === 174 /* MethodDeclaration */ || kind === 173 /* MethodSignature */ || kind === 176 /* Constructor */;
                        applyToParameterTypes(source, target, inferFromContravariantTypesIfStrictFunctionTypes);
                        bivariant = saveBivariant;
                    }
                    applyToReturnTypes(source, target, inferFromTypes);
                }
                function inferFromIndexTypes(source, target) {
                    const priority2 = getObjectFlags(source) & getObjectFlags(target) & 32 /* Mapped */ ? 8 /* HomomorphicMappedType */ : 0;
                    const indexInfos = getIndexInfosOfType(target);
                    if (isObjectTypeWithInferableIndex(source)) {
                        for (const targetInfo of indexInfos) {
                            const propTypes = [];
                            for (const prop of getPropertiesOfType(source)) {
                                if (isApplicableIndexType(getLiteralTypeFromProperty(prop, 8576 /* StringOrNumberLiteralOrUnique */), targetInfo.keyType)) {
                                    const propType = getTypeOfSymbol(prop);
                                    propTypes.push(prop.flags & 16777216 /* Optional */ ? removeMissingOrUndefinedType(propType) : propType);
                                }
                            }
                            for (const info of getIndexInfosOfType(source)) {
                                if (isApplicableIndexType(info.keyType, targetInfo.keyType)) {
                                    propTypes.push(info.type);
                                }
                            }
                            if (propTypes.length) {
                                inferWithPriority(getUnionType(propTypes), targetInfo.type, priority2);
                            }
                        }
                    }
                    for (const targetInfo of indexInfos) {
                        const sourceInfo = getApplicableIndexInfo(source, targetInfo.keyType);
                        if (sourceInfo) {
                            inferWithPriority(sourceInfo.type, targetInfo.type, priority2);
                        }
                    }
                }
            }
            function isTypeOrBaseIdenticalTo(s, t) {
                return t === missingType ? s === t : isTypeIdenticalTo(s, t) || !!(t.flags & 4 /* String */ && s.flags & 128 /* StringLiteral */ || t.flags & 8 /* Number */ && s.flags & 256 /* NumberLiteral */);
            }
            function isTypeCloselyMatchedBy(s, t) {
                return !!(s.flags & 524288 /* Object */ && t.flags & 524288 /* Object */ && s.symbol && s.symbol === t.symbol || s.aliasSymbol && s.aliasTypeArguments && s.aliasSymbol === t.aliasSymbol);
            }
            function hasPrimitiveConstraint(type) {
                const constraint = getConstraintOfTypeParameter(type);
                return !!constraint && maybeTypeOfKind(constraint.flags & 16777216 /* Conditional */ ? getDefaultConstraintOfConditionalType(constraint) : constraint, 402784252 /* Primitive */ | 4194304 /* Index */ | 134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */);
            }
            function isObjectLiteralType2(type) {
                return !!(getObjectFlags(type) & 128 /* ObjectLiteral */);
            }
            function isObjectOrArrayLiteralType(type) {
                return !!(getObjectFlags(type) & (128 /* ObjectLiteral */ | 16384 /* ArrayLiteral */));
            }
            function unionObjectAndArrayLiteralCandidates(candidates) {
                if (candidates.length > 1) {
                    const objectLiterals = filter(candidates, isObjectOrArrayLiteralType);
                    if (objectLiterals.length) {
                        const literalsType = getUnionType(objectLiterals, 2 /* Subtype */);
                        return concatenate(filter(candidates, (t) => !isObjectOrArrayLiteralType(t)), [literalsType]);
                    }
                }
                return candidates;
            }
            function getContravariantInference(inference) {
                return inference.priority & 416 /* PriorityImpliesCombination */ ? getIntersectionType(inference.contraCandidates) : getCommonSubtype(inference.contraCandidates);
            }
            function getCovariantInference(inference, signature) {
                const candidates = unionObjectAndArrayLiteralCandidates(inference.candidates);
                const primitiveConstraint = hasPrimitiveConstraint(inference.typeParameter) || isConstTypeVariable(inference.typeParameter);
                const widenLiteralTypes = !primitiveConstraint && inference.topLevel && (inference.isFixed || !isTypeParameterAtTopLevelInReturnType(signature, inference.typeParameter));
                const baseCandidates = primitiveConstraint ? sameMap(candidates, getRegularTypeOfLiteralType) : widenLiteralTypes ? sameMap(candidates, getWidenedLiteralType) : candidates;
                const unwidenedType = inference.priority & 416 /* PriorityImpliesCombination */ ? getUnionType(baseCandidates, 2 /* Subtype */) : getCommonSupertype(baseCandidates);
                return getWidenedType(unwidenedType);
            }
            function getInferredType(context, index) {
                const inference = context.inferences[index];
                if (!inference.inferredType) {
                    let inferredType;
                    let fallbackType;
                    if (context.signature) {
                        const inferredCovariantType = inference.candidates ? getCovariantInference(inference, context.signature) : void 0;
                        const inferredContravariantType = inference.contraCandidates ? getContravariantInference(inference) : void 0;
                        if (inferredCovariantType || inferredContravariantType) {
                            const preferCovariantType = inferredCovariantType && (!inferredContravariantType || !(inferredCovariantType.flags & 131072 /* Never */) && some(inference.contraCandidates, (t) => isTypeSubtypeOf(inferredCovariantType, t)) && every(context.inferences, (other) => other !== inference && getConstraintOfTypeParameter(other.typeParameter) !== inference.typeParameter || every(other.candidates, (t) => isTypeSubtypeOf(t, inferredCovariantType))));
                            inferredType = preferCovariantType ? inferredCovariantType : inferredContravariantType;
                            fallbackType = preferCovariantType ? inferredContravariantType : inferredCovariantType;
                        }
                        else if (context.flags & 1 /* NoDefault */) {
                            inferredType = silentNeverType;
                        }
                        else {
                            const defaultType = getDefaultFromTypeParameter(inference.typeParameter);
                            if (defaultType) {
                                inferredType = instantiateType(defaultType, mergeTypeMappers(createBackreferenceMapper(context, index), context.nonFixingMapper));
                            }
                        }
                    }
                    else {
                        inferredType = getTypeFromInference(inference);
                    }
                    inference.inferredType = inferredType || getDefaultTypeArgumentType(!!(context.flags & 2 /* AnyDefault */));
                    const constraint = getConstraintOfTypeParameter(inference.typeParameter);
                    if (constraint) {
                        const instantiatedConstraint = instantiateType(constraint, context.nonFixingMapper);
                        if (!inferredType || !context.compareTypes(inferredType, getTypeWithThisArgument(instantiatedConstraint, inferredType))) {
                            inference.inferredType = fallbackType && context.compareTypes(fallbackType, getTypeWithThisArgument(instantiatedConstraint, fallbackType)) ? fallbackType : instantiatedConstraint;
                        }
                    }
                }
                return inference.inferredType;
            }
            function getDefaultTypeArgumentType(isInJavaScriptFile) {
                return isInJavaScriptFile ? anyType : unknownType;
            }
            function getInferredTypes(context) {
                const result = [];
                for (let i = 0; i < context.inferences.length; i++) {
                    result.push(getInferredType(context, i));
                }
                return result;
            }
            function getCannotFindNameDiagnosticForName(node) {
                switch (node.escapedText) {
                    case "document":
                    case "console":
                        return Diagnostics.Cannot_find_name_0_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_include_dom;
                    case "$":
                        return compilerOptions.types ? Diagnostics.Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_jQuery_Try_npm_i_save_dev_types_Slashjquery_and_then_add_jquery_to_the_types_field_in_your_tsconfig : Diagnostics.Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_jQuery_Try_npm_i_save_dev_types_Slashjquery;
                    case "describe":
                    case "suite":
                    case "it":
                    case "test":
                        return compilerOptions.types ? Diagnostics.Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_a_test_runner_Try_npm_i_save_dev_types_Slashjest_or_npm_i_save_dev_types_Slashmocha_and_then_add_jest_or_mocha_to_the_types_field_in_your_tsconfig : Diagnostics.Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_a_test_runner_Try_npm_i_save_dev_types_Slashjest_or_npm_i_save_dev_types_Slashmocha;
                    case "process":
                    case "require":
                    case "Buffer":
                    case "module":
                        return compilerOptions.types ? Diagnostics.Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_node_Try_npm_i_save_dev_types_Slashnode_and_then_add_node_to_the_types_field_in_your_tsconfig : Diagnostics.Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_node_Try_npm_i_save_dev_types_Slashnode;
                    case "Bun":
                        return compilerOptions.types ? Diagnostics.Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_Bun_Try_npm_i_save_dev_types_Slashbun_and_then_add_bun_to_the_types_field_in_your_tsconfig : Diagnostics.Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_Bun_Try_npm_i_save_dev_types_Slashbun;
                    case "Map":
                    case "Set":
                    case "Promise":
                    case "Symbol":
                    case "WeakMap":
                    case "WeakSet":
                    case "Iterator":
                    case "AsyncIterator":
                    case "SharedArrayBuffer":
                    case "Atomics":
                    case "AsyncIterable":
                    case "AsyncIterableIterator":
                    case "AsyncGenerator":
                    case "AsyncGeneratorFunction":
                    case "BigInt":
                    case "Reflect":
                    case "BigInt64Array":
                    case "BigUint64Array":
                        return Diagnostics.Cannot_find_name_0_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_1_or_later;
                    case "await":
                        if (isCallExpression(node.parent)) {
                            return Diagnostics.Cannot_find_name_0_Did_you_mean_to_write_this_in_an_async_function;
                        }
                    default:
                        if (node.parent.kind === 304 /* ShorthandPropertyAssignment */) {
                            return Diagnostics.No_value_exists_in_scope_for_the_shorthand_property_0_Either_declare_one_or_provide_an_initializer;
                        }
                        else {
                            return Diagnostics.Cannot_find_name_0;
                        }
                }
            }
            function getResolvedSymbol(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedSymbol) {
                    links.resolvedSymbol = !nodeIsMissing(node) && resolveName(node, node.escapedText, 111551 /* Value */ | 1048576 /* ExportValue */, getCannotFindNameDiagnosticForName(node), node, !isWriteOnlyAccess(node), 
                    /*excludeGlobals*/
                    false) || unknownSymbol;
                }
                return links.resolvedSymbol;
            }
            function isInAmbientOrTypeNode(node) {
                return !!(node.flags & 33554432 /* Ambient */ || findAncestor(node, (n) => isInterfaceDeclaration(n) || isTypeAliasDeclaration(n) || isTypeLiteralNode(n)));
            }
            function getFlowCacheKey(node, declaredType, initialType, flowContainer) {
                switch (node.kind) {
                    case 80 /* Identifier */:
                        if (!isThisInTypeQuery(node)) {
                            const symbol = getResolvedSymbol(node);
                            return symbol !== unknownSymbol ? `${flowContainer ? getNodeId(flowContainer) : "-1"}|${getTypeId(declaredType)}|${getTypeId(initialType)}|${getSymbolId(symbol)}` : void 0;
                        }
                    case 110 /* ThisKeyword */:
                        return `0|${flowContainer ? getNodeId(flowContainer) : "-1"}|${getTypeId(declaredType)}|${getTypeId(initialType)}`;
                    case 235 /* NonNullExpression */:
                    case 217 /* ParenthesizedExpression */:
                        return getFlowCacheKey(node.expression, declaredType, initialType, flowContainer);
                    case 166 /* QualifiedName */:
                        const left = getFlowCacheKey(node.left, declaredType, initialType, flowContainer);
                        return left && left + "." + node.right.escapedText;
                    case 211 /* PropertyAccessExpression */:
                    case 212 /* ElementAccessExpression */:
                        const propName = getAccessedPropertyName(node);
                        if (propName !== void 0) {
                            const key = getFlowCacheKey(node.expression, declaredType, initialType, flowContainer);
                            return key && key + "." + propName;
                        }
                        break;
                    case 206 /* ObjectBindingPattern */:
                    case 207 /* ArrayBindingPattern */:
                    case 262 /* FunctionDeclaration */:
                    case 218 /* FunctionExpression */:
                    case 219 /* ArrowFunction */:
                    case 174 /* MethodDeclaration */:
                        return `${getNodeId(node)}#${getTypeId(declaredType)}`;
                }
                return void 0;
            }
            function isMatchingReference(source, target) {
                switch (target.kind) {
                    case 217 /* ParenthesizedExpression */:
                    case 235 /* NonNullExpression */:
                        return isMatchingReference(source, target.expression);
                    case 226 /* BinaryExpression */:
                        return isAssignmentExpression(target) && isMatchingReference(source, target.left) || isBinaryExpression(target) && target.operatorToken.kind === 28 /* CommaToken */ && isMatchingReference(source, target.right);
                }
                switch (source.kind) {
                    case 236 /* MetaProperty */:
                        return target.kind === 236 /* MetaProperty */ && source.keywordToken === target.keywordToken && source.name.escapedText === target.name.escapedText;
                    case 80 /* Identifier */:
                    case 81 /* PrivateIdentifier */:
                        return isThisInTypeQuery(source) ? target.kind === 110 /* ThisKeyword */ : target.kind === 80 /* Identifier */ && getResolvedSymbol(source) === getResolvedSymbol(target) || (isVariableDeclaration(target) || isBindingElement(target)) && getExportSymbolOfValueSymbolIfExported(getResolvedSymbol(source)) === getSymbolOfDeclaration(target);
                    case 110 /* ThisKeyword */:
                        return target.kind === 110 /* ThisKeyword */;
                    case 108 /* SuperKeyword */:
                        return target.kind === 108 /* SuperKeyword */;
                    case 235 /* NonNullExpression */:
                    case 217 /* ParenthesizedExpression */:
                        return isMatchingReference(source.expression, target);
                    case 211 /* PropertyAccessExpression */:
                    case 212 /* ElementAccessExpression */:
                        const sourcePropertyName = getAccessedPropertyName(source);
                        const targetPropertyName = isAccessExpression(target) ? getAccessedPropertyName(target) : void 0;
                        return sourcePropertyName !== void 0 && targetPropertyName !== void 0 && targetPropertyName === sourcePropertyName && isMatchingReference(source.expression, target.expression);
                    case 166 /* QualifiedName */:
                        return isAccessExpression(target) && source.right.escapedText === getAccessedPropertyName(target) && isMatchingReference(source.left, target.expression);
                    case 226 /* BinaryExpression */:
                        return isBinaryExpression(source) && source.operatorToken.kind === 28 /* CommaToken */ && isMatchingReference(source.right, target);
                }
                return false;
            }
            function getAccessedPropertyName(access) {
                if (isPropertyAccessExpression(access)) {
                    return access.name.escapedText;
                }
                if (isElementAccessExpression(access)) {
                    return tryGetElementAccessExpressionName(access);
                }
                if (isBindingElement(access)) {
                    const name = getDestructuringPropertyName(access);
                    return name ? escapeLeadingUnderscores(name) : void 0;
                }
                if (isParameter(access)) {
                    return "" + access.parent.parameters.indexOf(access);
                }
                return void 0;
            }
            function tryGetNameFromType(type) {
                return type.flags & 8192 /* UniqueESSymbol */ ? type.escapedName : type.flags & 384 /* StringOrNumberLiteral */ ? escapeLeadingUnderscores("" + type.value) : void 0;
            }
            function tryGetElementAccessExpressionName(node) {
                return isStringOrNumericLiteralLike(node.argumentExpression) ? escapeLeadingUnderscores(node.argumentExpression.text) : isEntityNameExpression(node.argumentExpression) ? tryGetNameFromEntityNameExpression(node.argumentExpression) : void 0;
            }
            function tryGetNameFromEntityNameExpression(node) {
                const symbol = resolveEntityName(node, 111551 /* Value */, 
                /*ignoreErrors*/
                true);
                if (!symbol || !(isConstantVariable(symbol) || symbol.flags & 8 /* EnumMember */))
                    return void 0;
                const declaration = symbol.valueDeclaration;
                if (declaration === void 0)
                    return void 0;
                const type = tryGetTypeFromEffectiveTypeNode(declaration);
                if (type) {
                    const name = tryGetNameFromType(type);
                    if (name !== void 0) {
                        return name;
                    }
                }
                if (hasOnlyExpressionInitializer(declaration) && isBlockScopedNameDeclaredBeforeUse(declaration, node)) {
                    const initializer = getEffectiveInitializer(declaration);
                    if (initializer) {
                        const initializerType = isBindingPattern(declaration.parent) ? getTypeForBindingElement(declaration) : getTypeOfExpression(initializer);
                        return initializerType && tryGetNameFromType(initializerType);
                    }
                    if (isEnumMember(declaration)) {
                        return getTextOfPropertyName(declaration.name);
                    }
                }
                return void 0;
            }
            function containsMatchingReference(source, target) {
                while (isAccessExpression(source)) {
                    source = source.expression;
                    if (isMatchingReference(source, target)) {
                        return true;
                    }
                }
                return false;
            }
            function optionalChainContainsReference(source, target) {
                while (isOptionalChain(source)) {
                    source = source.expression;
                    if (isMatchingReference(source, target)) {
                        return true;
                    }
                }
                return false;
            }
            function isDiscriminantProperty(type, name) {
                if (type && type.flags & 1048576 /* Union */) {
                    const prop = getUnionOrIntersectionProperty(type, name);
                    if (prop && getCheckFlags(prop) & 2 /* SyntheticProperty */) {
                        if (prop.links.isDiscriminantProperty === void 0) {
                            prop.links.isDiscriminantProperty = (prop.links.checkFlags & 192 /* Discriminant */) === 192 /* Discriminant */ && !isGenericType(getTypeOfSymbol(prop));
                        }
                        return !!prop.links.isDiscriminantProperty;
                    }
                }
                return false;
            }
            function findDiscriminantProperties(sourceProperties, target) {
                let result;
                for (const sourceProperty of sourceProperties) {
                    if (isDiscriminantProperty(target, sourceProperty.escapedName)) {
                        if (result) {
                            result.push(sourceProperty);
                            continue;
                        }
                        result = [sourceProperty];
                    }
                }
                return result;
            }
            function mapTypesByKeyProperty(types, name) {
                const map2 = /* @__PURE__ */ new Map();
                let count = 0;
                for (const type of types) {
                    if (type.flags & (524288 /* Object */ | 2097152 /* Intersection */ | 58982400 /* InstantiableNonPrimitive */)) {
                        const discriminant = getTypeOfPropertyOfType(type, name);
                        if (discriminant) {
                            if (!isLiteralType(discriminant)) {
                                return void 0;
                            }
                            let duplicate = false;
                            forEachType(discriminant, (t) => {
                                const id = getTypeId(getRegularTypeOfLiteralType(t));
                                const existing = map2.get(id);
                                if (!existing) {
                                    map2.set(id, type);
                                }
                                else if (existing !== unknownType) {
                                    map2.set(id, unknownType);
                                    duplicate = true;
                                }
                            });
                            if (!duplicate)
                                count++;
                        }
                    }
                }
                return count >= 10 && count * 2 >= types.length ? map2 : void 0;
            }
            function getKeyPropertyName(unionType) {
                const types = unionType.types;
                if (types.length < 10 || getObjectFlags(unionType) & 32768 /* PrimitiveUnion */ || countWhere(types, (t) => !!(t.flags & (524288 /* Object */ | 58982400 /* InstantiableNonPrimitive */))) < 10) {
                    return void 0;
                }
                if (unionType.keyPropertyName === void 0) {
                    const keyPropertyName = forEach(types, (t) => t.flags & (524288 /* Object */ | 58982400 /* InstantiableNonPrimitive */) ? forEach(getPropertiesOfType(t), (p) => isUnitType(getTypeOfSymbol(p)) ? p.escapedName : void 0) : void 0);
                    const mapByKeyProperty = keyPropertyName && mapTypesByKeyProperty(types, keyPropertyName);
                    unionType.keyPropertyName = mapByKeyProperty ? keyPropertyName : "";
                    unionType.constituentMap = mapByKeyProperty;
                }
                return unionType.keyPropertyName.length ? unionType.keyPropertyName : void 0;
            }
            function getConstituentTypeForKeyType(unionType, keyType) {
                var _a;
                const result = (_a = unionType.constituentMap) == null ? void 0 : _a.get(getTypeId(getRegularTypeOfLiteralType(keyType)));
                return result !== unknownType ? result : void 0;
            }
            function getMatchingUnionConstituentForType(unionType, type) {
                const keyPropertyName = getKeyPropertyName(unionType);
                const propType = keyPropertyName && getTypeOfPropertyOfType(type, keyPropertyName);
                return propType && getConstituentTypeForKeyType(unionType, propType);
            }
            function getMatchingUnionConstituentForObjectLiteral(unionType, node) {
                const keyPropertyName = getKeyPropertyName(unionType);
                const propNode = keyPropertyName && find(node.properties, (p) => p.symbol && p.kind === 303 /* PropertyAssignment */ && p.symbol.escapedName === keyPropertyName && isPossiblyDiscriminantValue(p.initializer));
                const propType = propNode && getContextFreeTypeOfExpression(propNode.initializer);
                return propType && getConstituentTypeForKeyType(unionType, propType);
            }
            function isOrContainsMatchingReference(source, target) {
                return isMatchingReference(source, target) || containsMatchingReference(source, target);
            }
            function hasMatchingArgument(expression, reference) {
                if (expression.arguments) {
                    for (const argument of expression.arguments) {
                        if (isOrContainsMatchingReference(reference, argument) || optionalChainContainsReference(argument, reference)) {
                            return true;
                        }
                    }
                }
                if (expression.expression.kind === 211 /* PropertyAccessExpression */ && isOrContainsMatchingReference(reference, expression.expression.expression)) {
                    return true;
                }
                return false;
            }
            function getFlowNodeId(flow) {
                if (!flow.id || flow.id < 0) {
                    flow.id = nextFlowId;
                    nextFlowId++;
                }
                return flow.id;
            }
            function typeMaybeAssignableTo(source, target) {
                if (!(source.flags & 1048576 /* Union */)) {
                    return isTypeAssignableTo(source, target);
                }
                for (const t of source.types) {
                    if (isTypeAssignableTo(t, target)) {
                        return true;
                    }
                }
                return false;
            }
            function getAssignmentReducedType(declaredType, assignedType) {
                if (declaredType === assignedType) {
                    return declaredType;
                }
                if (assignedType.flags & 131072 /* Never */) {
                    return assignedType;
                }
                const key = `A${getTypeId(declaredType)},${getTypeId(assignedType)}`;
                return getCachedType(key) ?? setCachedType(key, getAssignmentReducedTypeWorker(declaredType, assignedType));
            }
            function getAssignmentReducedTypeWorker(declaredType, assignedType) {
                const filteredType = filterType(declaredType, (t) => typeMaybeAssignableTo(assignedType, t));
                const reducedType = assignedType.flags & 512 /* BooleanLiteral */ && isFreshLiteralType(assignedType) ? mapType(filteredType, getFreshTypeOfLiteralType) : filteredType;
                return isTypeAssignableTo(assignedType, reducedType) ? reducedType : declaredType;
            }
            function isFunctionObjectType(type) {
                const resolved = resolveStructuredTypeMembers(type);
                return !!(resolved.callSignatures.length || resolved.constructSignatures.length || resolved.members.get("bind") && isTypeSubtypeOf(type, globalFunctionType));
            }
            function getTypeFacts(type, mask2) {
                return getTypeFactsWorker(type, mask2) & mask2;
            }
            function hasTypeFacts(type, mask2) {
                return getTypeFacts(type, mask2) !== 0;
            }
            function getTypeFactsWorker(type, callerOnlyNeeds) {
                if (type.flags & (2097152 /* Intersection */ | 465829888 /* Instantiable */)) {
                    type = getBaseConstraintOfType(type) || unknownType;
                }
                const flags = type.flags;
                if (flags & (4 /* String */ | 268435456 /* StringMapping */)) {
                    return strictNullChecks ? 16317953 /* StringStrictFacts */ : 16776705 /* StringFacts */;
                }
                if (flags & (128 /* StringLiteral */ | 134217728 /* TemplateLiteral */)) {
                    const isEmpty = flags & 128 /* StringLiteral */ && type.value === "";
                    return strictNullChecks ? isEmpty ? 12123649 /* EmptyStringStrictFacts */ : 7929345 /* NonEmptyStringStrictFacts */ : isEmpty ? 12582401 /* EmptyStringFacts */ : 16776705 /* NonEmptyStringFacts */;
                }
                if (flags & (8 /* Number */ | 32 /* Enum */)) {
                    return strictNullChecks ? 16317698 /* NumberStrictFacts */ : 16776450 /* NumberFacts */;
                }
                if (flags & 256 /* NumberLiteral */) {
                    const isZero = type.value === 0;
                    return strictNullChecks ? isZero ? 12123394 /* ZeroNumberStrictFacts */ : 7929090 /* NonZeroNumberStrictFacts */ : isZero ? 12582146 /* ZeroNumberFacts */ : 16776450 /* NonZeroNumberFacts */;
                }
                if (flags & 64 /* BigInt */) {
                    return strictNullChecks ? 16317188 /* BigIntStrictFacts */ : 16775940 /* BigIntFacts */;
                }
                if (flags & 2048 /* BigIntLiteral */) {
                    const isZero = isZeroBigInt(type);
                    return strictNullChecks ? isZero ? 12122884 /* ZeroBigIntStrictFacts */ : 7928580 /* NonZeroBigIntStrictFacts */ : isZero ? 12581636 /* ZeroBigIntFacts */ : 16775940 /* NonZeroBigIntFacts */;
                }
                if (flags & 16 /* Boolean */) {
                    return strictNullChecks ? 16316168 /* BooleanStrictFacts */ : 16774920 /* BooleanFacts */;
                }
                if (flags & 528 /* BooleanLike */) {
                    return strictNullChecks ? type === falseType || type === regularFalseType ? 12121864 /* FalseStrictFacts */ : 7927560 /* TrueStrictFacts */ : type === falseType || type === regularFalseType ? 12580616 /* FalseFacts */ : 16774920 /* TrueFacts */;
                }
                if (flags & 524288 /* Object */) {
                    const possibleFacts = strictNullChecks ? 83427327 /* EmptyObjectStrictFacts */ | 7880640 /* FunctionStrictFacts */ | 7888800 /* ObjectStrictFacts */ : 83886079 /* EmptyObjectFacts */ | 16728e3 /* FunctionFacts */ | 16736160 /* ObjectFacts */;
                    if ((callerOnlyNeeds & possibleFacts) === 0) {
                        return 0;
                    }
                    return getObjectFlags(type) & 16 /* Anonymous */ && isEmptyObjectType(type) ? strictNullChecks ? 83427327 /* EmptyObjectStrictFacts */ : 83886079 /* EmptyObjectFacts */ : isFunctionObjectType(type) ? strictNullChecks ? 7880640 /* FunctionStrictFacts */ : 16728e3 /* FunctionFacts */ : strictNullChecks ? 7888800 /* ObjectStrictFacts */ : 16736160 /* ObjectFacts */;
                }
                if (flags & 16384 /* Void */) {
                    return 9830144 /* VoidFacts */;
                }
                if (flags & 32768 /* Undefined */) {
                    return 26607360 /* UndefinedFacts */;
                }
                if (flags & 65536 /* Null */) {
                    return 42917664 /* NullFacts */;
                }
                if (flags & 12288 /* ESSymbolLike */) {
                    return strictNullChecks ? 7925520 /* SymbolStrictFacts */ : 16772880 /* SymbolFacts */;
                }
                if (flags & 67108864 /* NonPrimitive */) {
                    return strictNullChecks ? 7888800 /* ObjectStrictFacts */ : 16736160 /* ObjectFacts */;
                }
                if (flags & 131072 /* Never */) {
                    return 0 /* None */;
                }
                if (flags & 1048576 /* Union */) {
                    return reduceLeft(type.types, (facts, t) => facts | getTypeFactsWorker(t, callerOnlyNeeds), 0 /* None */);
                }
                if (flags & 2097152 /* Intersection */) {
                    return getIntersectionTypeFacts(type, callerOnlyNeeds);
                }
                return 83886079 /* UnknownFacts */;
            }
            function getIntersectionTypeFacts(type, callerOnlyNeeds) {
                const ignoreObjects = maybeTypeOfKind(type, 402784252 /* Primitive */);
                let oredFacts = 0 /* None */;
                let andedFacts = 134217727 /* All */;
                for (const t of type.types) {
                    if (!(ignoreObjects && t.flags & 524288 /* Object */)) {
                        const f = getTypeFactsWorker(t, callerOnlyNeeds);
                        oredFacts |= f;
                        andedFacts &= f;
                    }
                }
                return oredFacts & 8256 /* OrFactsMask */ | andedFacts & 134209471 /* AndFactsMask */;
            }
            function getTypeWithFacts(type, include) {
                return filterType(type, (t) => hasTypeFacts(t, include));
            }
            function getAdjustedTypeWithFacts(type, facts) {
                const reduced = recombineUnknownType(getTypeWithFacts(strictNullChecks && type.flags & 2 /* Unknown */ ? unknownUnionType : type, facts));
                if (strictNullChecks) {
                    switch (facts) {
                        case 524288 /* NEUndefined */:
                            return mapType(reduced, (t) => hasTypeFacts(t, 65536 /* EQUndefined */) ? getIntersectionType([t, hasTypeFacts(t, 131072 /* EQNull */) && !maybeTypeOfKind(reduced, 65536 /* Null */) ? getUnionType([emptyObjectType, nullType]) : emptyObjectType]) : t);
                        case 1048576 /* NENull */:
                            return mapType(reduced, (t) => hasTypeFacts(t, 131072 /* EQNull */) ? getIntersectionType([t, hasTypeFacts(t, 65536 /* EQUndefined */) && !maybeTypeOfKind(reduced, 32768 /* Undefined */) ? getUnionType([emptyObjectType, undefinedType]) : emptyObjectType]) : t);
                        case 2097152 /* NEUndefinedOrNull */:
                        case 4194304 /* Truthy */:
                            return mapType(reduced, (t) => hasTypeFacts(t, 262144 /* EQUndefinedOrNull */) ? getGlobalNonNullableTypeInstantiation(t) : t);
                    }
                }
                return reduced;
            }
            function recombineUnknownType(type) {
                return type === unknownUnionType ? unknownType : type;
            }
            function getTypeWithDefault(type, defaultExpression) {
                return defaultExpression ? getUnionType([getNonUndefinedType(type), getTypeOfExpression(defaultExpression)]) : type;
            }
            function getTypeOfDestructuredProperty(type, name) {
                var _a;
                const nameType = getLiteralTypeFromPropertyName(name);
                if (!isTypeUsableAsPropertyName(nameType))
                    return errorType;
                const text = getPropertyNameFromType(nameType);
                return getTypeOfPropertyOfType(type, text) || includeUndefinedInIndexSignature((_a = getApplicableIndexInfoForName(type, text)) == null ? void 0 : _a.type) || errorType;
            }
            function getTypeOfDestructuredArrayElement(type, index) {
                return everyType(type, isTupleLikeType) && getTupleElementType(type, index) || includeUndefinedInIndexSignature(checkIteratedTypeOrElementType(65 /* Destructuring */, type, undefinedType, 
                /*errorNode*/
                void 0)) || errorType;
            }
            function includeUndefinedInIndexSignature(type) {
                if (!type)
                    return type;
                return compilerOptions.noUncheckedIndexedAccess ? getUnionType([type, missingType]) : type;
            }
            function getTypeOfDestructuredSpreadExpression(type) {
                return createArrayType(checkIteratedTypeOrElementType(65 /* Destructuring */, type, undefinedType, 
                /*errorNode*/
                void 0) || errorType);
            }
            function getAssignedTypeOfBinaryExpression(node) {
                const isDestructuringDefaultAssignment = node.parent.kind === 209 /* ArrayLiteralExpression */ && isDestructuringAssignmentTarget(node.parent) || node.parent.kind === 303 /* PropertyAssignment */ && isDestructuringAssignmentTarget(node.parent.parent);
                return isDestructuringDefaultAssignment ? getTypeWithDefault(getAssignedType(node), node.right) : getTypeOfExpression(node.right);
            }
            function isDestructuringAssignmentTarget(parent2) {
                return parent2.parent.kind === 226 /* BinaryExpression */ && parent2.parent.left === parent2 || parent2.parent.kind === 250 /* ForOfStatement */ && parent2.parent.initializer === parent2;
            }
            function getAssignedTypeOfArrayLiteralElement(node, element) {
                return getTypeOfDestructuredArrayElement(getAssignedType(node), node.elements.indexOf(element));
            }
            function getAssignedTypeOfSpreadExpression(node) {
                return getTypeOfDestructuredSpreadExpression(getAssignedType(node.parent));
            }
            function getAssignedTypeOfPropertyAssignment(node) {
                return getTypeOfDestructuredProperty(getAssignedType(node.parent), node.name);
            }
            function getAssignedTypeOfShorthandPropertyAssignment(node) {
                return getTypeWithDefault(getAssignedTypeOfPropertyAssignment(node), node.objectAssignmentInitializer);
            }
            function getAssignedType(node) {
                const { parent: parent2 } = node;
                switch (parent2.kind) {
                    case 249 /* ForInStatement */:
                        return stringType;
                    case 250 /* ForOfStatement */:
                        return checkRightHandSideOfForOf(parent2) || errorType;
                    case 226 /* BinaryExpression */:
                        return getAssignedTypeOfBinaryExpression(parent2);
                    case 220 /* DeleteExpression */:
                        return undefinedType;
                    case 209 /* ArrayLiteralExpression */:
                        return getAssignedTypeOfArrayLiteralElement(parent2, node);
                    case 230 /* SpreadElement */:
                        return getAssignedTypeOfSpreadExpression(parent2);
                    case 303 /* PropertyAssignment */:
                        return getAssignedTypeOfPropertyAssignment(parent2);
                    case 304 /* ShorthandPropertyAssignment */:
                        return getAssignedTypeOfShorthandPropertyAssignment(parent2);
                }
                return errorType;
            }
            function getInitialTypeOfBindingElement(node) {
                const pattern = node.parent;
                const parentType = getInitialType(pattern.parent);
                const type = pattern.kind === 206 /* ObjectBindingPattern */ ? getTypeOfDestructuredProperty(parentType, node.propertyName || node.name) : !node.dotDotDotToken ? getTypeOfDestructuredArrayElement(parentType, pattern.elements.indexOf(node)) : getTypeOfDestructuredSpreadExpression(parentType);
                return getTypeWithDefault(type, node.initializer);
            }
            function getTypeOfInitializer(node) {
                const links = getNodeLinks(node);
                return links.resolvedType || getTypeOfExpression(node);
            }
            function getInitialTypeOfVariableDeclaration(node) {
                if (node.initializer) {
                    return getTypeOfInitializer(node.initializer);
                }
                if (node.parent.parent.kind === 249 /* ForInStatement */) {
                    return stringType;
                }
                if (node.parent.parent.kind === 250 /* ForOfStatement */) {
                    return checkRightHandSideOfForOf(node.parent.parent) || errorType;
                }
                return errorType;
            }
            function getInitialType(node) {
                return node.kind === 260 /* VariableDeclaration */ ? getInitialTypeOfVariableDeclaration(node) : getInitialTypeOfBindingElement(node);
            }
            function isEmptyArrayAssignment(node) {
                return node.kind === 260 /* VariableDeclaration */ && node.initializer && isEmptyArrayLiteral2(node.initializer) || node.kind !== 208 /* BindingElement */ && node.parent.kind === 226 /* BinaryExpression */ && isEmptyArrayLiteral2(node.parent.right);
            }
            function getReferenceCandidate(node) {
                switch (node.kind) {
                    case 217 /* ParenthesizedExpression */:
                        return getReferenceCandidate(node.expression);
                    case 226 /* BinaryExpression */:
                        switch (node.operatorToken.kind) {
                            case 64 /* EqualsToken */:
                            case 76 /* BarBarEqualsToken */:
                            case 77 /* AmpersandAmpersandEqualsToken */:
                            case 78 /* QuestionQuestionEqualsToken */:
                                return getReferenceCandidate(node.left);
                            case 28 /* CommaToken */:
                                return getReferenceCandidate(node.right);
                        }
                }
                return node;
            }
            function getReferenceRoot(node) {
                const { parent: parent2 } = node;
                return parent2.kind === 217 /* ParenthesizedExpression */ || parent2.kind === 226 /* BinaryExpression */ && parent2.operatorToken.kind === 64 /* EqualsToken */ && parent2.left === node || parent2.kind === 226 /* BinaryExpression */ && parent2.operatorToken.kind === 28 /* CommaToken */ && parent2.right === node ? getReferenceRoot(parent2) : node;
            }
            function getTypeOfSwitchClause(clause) {
                if (clause.kind === 296 /* CaseClause */) {
                    return getRegularTypeOfLiteralType(getTypeOfExpression(clause.expression));
                }
                return neverType;
            }
            function getSwitchClauseTypes(switchStatement) {
                const links = getNodeLinks(switchStatement);
                if (!links.switchTypes) {
                    links.switchTypes = [];
                    for (const clause of switchStatement.caseBlock.clauses) {
                        links.switchTypes.push(getTypeOfSwitchClause(clause));
                    }
                }
                return links.switchTypes;
            }
            function getSwitchClauseTypeOfWitnesses(switchStatement) {
                if (some(switchStatement.caseBlock.clauses, (clause) => clause.kind === 296 /* CaseClause */ && !isStringLiteralLike(clause.expression))) {
                    return void 0;
                }
                const witnesses = [];
                for (const clause of switchStatement.caseBlock.clauses) {
                    const text = clause.kind === 296 /* CaseClause */ ? clause.expression.text : void 0;
                    witnesses.push(text && !contains(witnesses, text) ? text : void 0);
                }
                return witnesses;
            }
            function eachTypeContainedIn(source, types) {
                return source.flags & 1048576 /* Union */ ? !forEach(source.types, (t) => !contains(types, t)) : contains(types, source);
            }
            function isTypeSubsetOf(source, target) {
                return !!(source === target || source.flags & 131072 /* Never */ || target.flags & 1048576 /* Union */ && isTypeSubsetOfUnion(source, target));
            }
            function isTypeSubsetOfUnion(source, target) {
                if (source.flags & 1048576 /* Union */) {
                    for (const t of source.types) {
                        if (!containsType(target.types, t)) {
                            return false;
                        }
                    }
                    return true;
                }
                if (source.flags & 1056 /* EnumLike */ && getBaseTypeOfEnumLikeType(source) === target) {
                    return true;
                }
                return containsType(target.types, source);
            }
            function forEachType(type, f) {
                return type.flags & 1048576 /* Union */ ? forEach(type.types, f) : f(type);
            }
            function someType(type, f) {
                return type.flags & 1048576 /* Union */ ? some(type.types, f) : f(type);
            }
            function everyType(type, f) {
                return type.flags & 1048576 /* Union */ ? every(type.types, f) : f(type);
            }
            function everyContainedType(type, f) {
                return type.flags & 3145728 /* UnionOrIntersection */ ? every(type.types, f) : f(type);
            }
            function filterType(type, f) {
                if (type.flags & 1048576 /* Union */) {
                    const types = type.types;
                    const filtered = filter(types, f);
                    if (filtered === types) {
                        return type;
                    }
                    const origin = type.origin;
                    let newOrigin;
                    if (origin && origin.flags & 1048576 /* Union */) {
                        const originTypes = origin.types;
                        const originFiltered = filter(originTypes, (t) => !!(t.flags & 1048576 /* Union */) || f(t));
                        if (originTypes.length - originFiltered.length === types.length - filtered.length) {
                            if (originFiltered.length === 1) {
                                return originFiltered[0];
                            }
                            newOrigin = createOriginUnionOrIntersectionType(1048576 /* Union */, originFiltered);
                        }
                    }
                    return getUnionTypeFromSortedList(filtered, type.objectFlags & (32768 /* PrimitiveUnion */ | 16777216 /* ContainsIntersections */), 
                    /*aliasSymbol*/
                    void 0, 
                    /*aliasTypeArguments*/
                    void 0, newOrigin);
                }
                return type.flags & 131072 /* Never */ || f(type) ? type : neverType;
            }
            function removeType(type, targetType) {
                return filterType(type, (t) => t !== targetType);
            }
            function countTypes(type) {
                return type.flags & 1048576 /* Union */ ? type.types.length : 1;
            }
            function mapType(type, mapper, noReductions) {
                if (type.flags & 131072 /* Never */) {
                    return type;
                }
                if (!(type.flags & 1048576 /* Union */)) {
                    return mapper(type);
                }
                const origin = type.origin;
                const types = origin && origin.flags & 1048576 /* Union */ ? origin.types : type.types;
                let mappedTypes;
                let changed = false;
                for (const t of types) {
                    const mapped = t.flags & 1048576 /* Union */ ? mapType(t, mapper, noReductions) : mapper(t);
                    changed || (changed = t !== mapped);
                    if (mapped) {
                        if (!mappedTypes) {
                            mappedTypes = [mapped];
                        }
                        else {
                            mappedTypes.push(mapped);
                        }
                    }
                }
                return changed ? mappedTypes && getUnionType(mappedTypes, noReductions ? 0 /* None */ : 1 /* Literal */) : type;
            }
            function mapTypeWithAlias(type, mapper, aliasSymbol, aliasTypeArguments) {
                return type.flags & 1048576 /* Union */ && aliasSymbol ? getUnionType(map(type.types, mapper), 1 /* Literal */, aliasSymbol, aliasTypeArguments) : mapType(type, mapper);
            }
            function extractTypesOfKind(type, kind) {
                return filterType(type, (t) => (t.flags & kind) !== 0);
            }
            function replacePrimitivesWithLiterals(typeWithPrimitives, typeWithLiterals) {
                if (maybeTypeOfKind(typeWithPrimitives, 4 /* String */ | 134217728 /* TemplateLiteral */ | 8 /* Number */ | 64 /* BigInt */) && maybeTypeOfKind(typeWithLiterals, 128 /* StringLiteral */ | 134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */ | 256 /* NumberLiteral */ | 2048 /* BigIntLiteral */)) {
                    return mapType(typeWithPrimitives, (t) => t.flags & 4 /* String */ ? extractTypesOfKind(typeWithLiterals, 4 /* String */ | 128 /* StringLiteral */ | 134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */) : isPatternLiteralType(t) && !maybeTypeOfKind(typeWithLiterals, 4 /* String */ | 134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */) ? extractTypesOfKind(typeWithLiterals, 128 /* StringLiteral */) : t.flags & 8 /* Number */ ? extractTypesOfKind(typeWithLiterals, 8 /* Number */ | 256 /* NumberLiteral */) : t.flags & 64 /* BigInt */ ? extractTypesOfKind(typeWithLiterals, 64 /* BigInt */ | 2048 /* BigIntLiteral */) : t);
                }
                return typeWithPrimitives;
            }
            function isIncomplete(flowType) {
                return flowType.flags === 0;
            }
            function getTypeFromFlowType(flowType) {
                return flowType.flags === 0 ? flowType.type : flowType;
            }
            function createFlowType(type, incomplete) {
                return incomplete ? { flags: 0, type: type.flags & 131072 /* Never */ ? silentNeverType : type } : type;
            }
            function createEvolvingArrayType(elementType) {
                const result = createObjectType(256 /* EvolvingArray */);
                result.elementType = elementType;
                return result;
            }
            function getEvolvingArrayType(elementType) {
                return evolvingArrayTypes[elementType.id] || (evolvingArrayTypes[elementType.id] = createEvolvingArrayType(elementType));
            }
            function addEvolvingArrayElementType(evolvingArrayType, node) {
                const elementType = getRegularTypeOfObjectLiteral(getBaseTypeOfLiteralType(getContextFreeTypeOfExpression(node)));
                return isTypeSubsetOf(elementType, evolvingArrayType.elementType) ? evolvingArrayType : getEvolvingArrayType(getUnionType([evolvingArrayType.elementType, elementType]));
            }
            function createFinalArrayType(elementType) {
                return elementType.flags & 131072 /* Never */ ? autoArrayType : createArrayType(elementType.flags & 1048576 /* Union */ ? getUnionType(elementType.types, 2 /* Subtype */) : elementType);
            }
            function getFinalArrayType(evolvingArrayType) {
                return evolvingArrayType.finalArrayType || (evolvingArrayType.finalArrayType = createFinalArrayType(evolvingArrayType.elementType));
            }
            function finalizeEvolvingArrayType(type) {
                return getObjectFlags(type) & 256 /* EvolvingArray */ ? getFinalArrayType(type) : type;
            }
            function getElementTypeOfEvolvingArrayType(type) {
                return getObjectFlags(type) & 256 /* EvolvingArray */ ? type.elementType : neverType;
            }
            function isEvolvingArrayTypeList(types) {
                let hasEvolvingArrayType = false;
                for (const t of types) {
                    if (!(t.flags & 131072 /* Never */)) {
                        if (!(getObjectFlags(t) & 256 /* EvolvingArray */)) {
                            return false;
                        }
                        hasEvolvingArrayType = true;
                    }
                }
                return hasEvolvingArrayType;
            }
            function isEvolvingArrayOperationTarget(node) {
                const root = getReferenceRoot(node);
                const parent2 = root.parent;
                const isLengthPushOrUnshift = isPropertyAccessExpression(parent2) && (parent2.name.escapedText === "length" || parent2.parent.kind === 213 /* CallExpression */ && isIdentifier(parent2.name) && isPushOrUnshiftIdentifier(parent2.name));
                const isElementAssignment = parent2.kind === 212 /* ElementAccessExpression */ && parent2.expression === root && parent2.parent.kind === 226 /* BinaryExpression */ && parent2.parent.operatorToken.kind === 64 /* EqualsToken */ && parent2.parent.left === parent2 && !isAssignmentTarget(parent2.parent) && isTypeAssignableToKind(getTypeOfExpression(parent2.argumentExpression), 296 /* NumberLike */);
                return isLengthPushOrUnshift || isElementAssignment;
            }
            function isDeclarationWithExplicitTypeAnnotation(node) {
                return (isVariableDeclaration(node) || isPropertyDeclaration(node) || isPropertySignature(node) || isParameter(node)) && !!(getEffectiveTypeAnnotationNode(node) || isInJSFile(node) && hasInitializer(node) && node.initializer && isFunctionExpressionOrArrowFunction(node.initializer) && getEffectiveReturnTypeNode(node.initializer));
            }
            function getExplicitTypeOfSymbol(symbol, diagnostic) {
                symbol = resolveSymbol(symbol);
                if (symbol.flags & (16 /* Function */ | 8192 /* Method */ | 32 /* Class */ | 512 /* ValueModule */)) {
                    return getTypeOfSymbol(symbol);
                }
                if (symbol.flags & (3 /* Variable */ | 4 /* Property */)) {
                    if (getCheckFlags(symbol) & 262144 /* Mapped */) {
                        const origin = symbol.links.syntheticOrigin;
                        if (origin && getExplicitTypeOfSymbol(origin)) {
                            return getTypeOfSymbol(symbol);
                        }
                    }
                    const declaration = symbol.valueDeclaration;
                    if (declaration) {
                        if (isDeclarationWithExplicitTypeAnnotation(declaration)) {
                            return getTypeOfSymbol(symbol);
                        }
                        if (isVariableDeclaration(declaration) && declaration.parent.parent.kind === 250 /* ForOfStatement */) {
                            const statement = declaration.parent.parent;
                            const expressionType = getTypeOfDottedName(statement.expression, 
                            /*diagnostic*/
                            void 0);
                            if (expressionType) {
                                const use = statement.awaitModifier ? 15 /* ForAwaitOf */ : 13 /* ForOf */;
                                return checkIteratedTypeOrElementType(use, expressionType, undefinedType, 
                                /*errorNode*/
                                void 0);
                            }
                        }
                        if (diagnostic) {
                            addRelatedInfo(diagnostic, createDiagnosticForNode(declaration, Diagnostics._0_needs_an_explicit_type_annotation, symbolToString(symbol)));
                        }
                    }
                }
            }
            function getTypeOfDottedName(node, diagnostic) {
                if (!(node.flags & 67108864 /* InWithStatement */)) {
                    switch (node.kind) {
                        case 80 /* Identifier */:
                            const symbol = getExportSymbolOfValueSymbolIfExported(getResolvedSymbol(node));
                            return getExplicitTypeOfSymbol(symbol, diagnostic);
                        case 110 /* ThisKeyword */:
                            return getExplicitThisType(node);
                        case 108 /* SuperKeyword */:
                            return checkSuperExpression(node);
                        case 211 /* PropertyAccessExpression */: {
                            const type = getTypeOfDottedName(node.expression, diagnostic);
                            if (type) {
                                const name = node.name;
                                let prop;
                                if (isPrivateIdentifier(name)) {
                                    if (!type.symbol) {
                                        return void 0;
                                    }
                                    prop = getPropertyOfType(type, getSymbolNameForPrivateIdentifier(type.symbol, name.escapedText));
                                }
                                else {
                                    prop = getPropertyOfType(type, name.escapedText);
                                }
                                return prop && getExplicitTypeOfSymbol(prop, diagnostic);
                            }
                            return void 0;
                        }
                        case 217 /* ParenthesizedExpression */:
                            return getTypeOfDottedName(node.expression, diagnostic);
                    }
                }
            }
            function getEffectsSignature(node) {
                const links = getNodeLinks(node);
                let signature = links.effectsSignature;
                if (signature === void 0) {
                    let funcType;
                    if (isBinaryExpression(node)) {
                        const rightType = checkNonNullExpression(node.right);
                        funcType = getSymbolHasInstanceMethodOfObjectType(rightType);
                    }
                    else if (node.parent.kind === 244 /* ExpressionStatement */) {
                        funcType = getTypeOfDottedName(node.expression, 
                        /*diagnostic*/
                        void 0);
                    }
                    else if (node.expression.kind !== 108 /* SuperKeyword */) {
                        if (isOptionalChain(node)) {
                            funcType = checkNonNullType(getOptionalExpressionType(checkExpression(node.expression), node.expression), node.expression);
                        }
                        else {
                            funcType = checkNonNullExpression(node.expression);
                        }
                    }
                    const signatures = getSignaturesOfType(funcType && getApparentType(funcType) || unknownType, 0 /* Call */);
                    const candidate = signatures.length === 1 && !signatures[0].typeParameters ? signatures[0] : some(signatures, hasTypePredicateOrNeverReturnType) ? getResolvedSignature(node) : void 0;
                    signature = links.effectsSignature = candidate && hasTypePredicateOrNeverReturnType(candidate) ? candidate : unknownSignature;
                }
                return signature === unknownSignature ? void 0 : signature;
            }
            function hasTypePredicateOrNeverReturnType(signature) {
                return !!(getTypePredicateOfSignature(signature) || signature.declaration && (getReturnTypeFromAnnotation(signature.declaration) || unknownType).flags & 131072 /* Never */);
            }
            function getTypePredicateArgument(predicate, callExpression) {
                if (predicate.kind === 1 /* Identifier */ || predicate.kind === 3 /* AssertsIdentifier */) {
                    return callExpression.arguments[predicate.parameterIndex];
                }
                const invokedExpression = skipParentheses(callExpression.expression);
                return isAccessExpression(invokedExpression) ? skipParentheses(invokedExpression.expression) : void 0;
            }
            function reportFlowControlError(node) {
                const block = findAncestor(node, isFunctionOrModuleBlock);
                const sourceFile = getSourceFileOfNode(node);
                const span = getSpanOfTokenAtPosition(sourceFile, block.statements.pos);
                diagnostics.add(createFileDiagnostic(sourceFile, span.start, span.length, Diagnostics.The_containing_function_or_module_body_is_too_large_for_control_flow_analysis));
            }
            function isReachableFlowNode(flow) {
                const result = isReachableFlowNodeWorker(flow, 
                /*noCacheCheck*/
                false);
                lastFlowNode = flow;
                lastFlowNodeReachable = result;
                return result;
            }
            function isFalseExpression(expr) {
                const node = skipParentheses(expr, 
                /*excludeJSDocTypeAssertions*/
                true);
                return node.kind === 97 /* FalseKeyword */ || node.kind === 226 /* BinaryExpression */ && (node.operatorToken.kind === 56 /* AmpersandAmpersandToken */ && (isFalseExpression(node.left) || isFalseExpression(node.right)) || node.operatorToken.kind === 57 /* BarBarToken */ && isFalseExpression(node.left) && isFalseExpression(node.right));
            }
            function isReachableFlowNodeWorker(flow, noCacheCheck) {
                while (true) {
                    if (flow === lastFlowNode) {
                        return lastFlowNodeReachable;
                    }
                    const flags = flow.flags;
                    if (flags & 4096 /* Shared */) {
                        if (!noCacheCheck) {
                            const id = getFlowNodeId(flow);
                            const reachable = flowNodeReachable[id];
                            return reachable !== void 0 ? reachable : flowNodeReachable[id] = isReachableFlowNodeWorker(flow, 
                            /*noCacheCheck*/
                            true);
                        }
                        noCacheCheck = false;
                    }
                    if (flags & (16 /* Assignment */ | 96 /* Condition */ | 256 /* ArrayMutation */)) {
                        flow = flow.antecedent;
                    }
                    else if (flags & 512 /* Call */) {
                        const signature = getEffectsSignature(flow.node);
                        if (signature) {
                            const predicate = getTypePredicateOfSignature(signature);
                            if (predicate && predicate.kind === 3 /* AssertsIdentifier */ && !predicate.type) {
                                const predicateArgument = flow.node.arguments[predicate.parameterIndex];
                                if (predicateArgument && isFalseExpression(predicateArgument)) {
                                    return false;
                                }
                            }
                            if (getReturnTypeOfSignature(signature).flags & 131072 /* Never */) {
                                return false;
                            }
                        }
                        flow = flow.antecedent;
                    }
                    else if (flags & 4 /* BranchLabel */) {
                        return some(flow.antecedents, (f) => isReachableFlowNodeWorker(f, 
                        /*noCacheCheck*/
                        false));
                    }
                    else if (flags & 8 /* LoopLabel */) {
                        const antecedents = flow.antecedents;
                        if (antecedents === void 0 || antecedents.length === 0) {
                            return false;
                        }
                        flow = antecedents[0];
                    }
                    else if (flags & 128 /* SwitchClause */) {
                        if (flow.clauseStart === flow.clauseEnd && isExhaustiveSwitchStatement(flow.switchStatement)) {
                            return false;
                        }
                        flow = flow.antecedent;
                    }
                    else if (flags & 1024 /* ReduceLabel */) {
                        lastFlowNode = void 0;
                        const target = flow.target;
                        const saveAntecedents = target.antecedents;
                        target.antecedents = flow.antecedents;
                        const result = isReachableFlowNodeWorker(flow.antecedent, 
                        /*noCacheCheck*/
                        false);
                        target.antecedents = saveAntecedents;
                        return result;
                    }
                    else {
                        return !(flags & 1 /* Unreachable */);
                    }
                }
            }
            function isPostSuperFlowNode(flow, noCacheCheck) {
                while (true) {
                    const flags = flow.flags;
                    if (flags & 4096 /* Shared */) {
                        if (!noCacheCheck) {
                            const id = getFlowNodeId(flow);
                            const postSuper = flowNodePostSuper[id];
                            return postSuper !== void 0 ? postSuper : flowNodePostSuper[id] = isPostSuperFlowNode(flow, 
                            /*noCacheCheck*/
                            true);
                        }
                        noCacheCheck = false;
                    }
                    if (flags & (16 /* Assignment */ | 96 /* Condition */ | 256 /* ArrayMutation */ | 128 /* SwitchClause */)) {
                        flow = flow.antecedent;
                    }
                    else if (flags & 512 /* Call */) {
                        if (flow.node.expression.kind === 108 /* SuperKeyword */) {
                            return true;
                        }
                        flow = flow.antecedent;
                    }
                    else if (flags & 4 /* BranchLabel */) {
                        return every(flow.antecedents, (f) => isPostSuperFlowNode(f, 
                        /*noCacheCheck*/
                        false));
                    }
                    else if (flags & 8 /* LoopLabel */) {
                        flow = flow.antecedents[0];
                    }
                    else if (flags & 1024 /* ReduceLabel */) {
                        const target = flow.target;
                        const saveAntecedents = target.antecedents;
                        target.antecedents = flow.antecedents;
                        const result = isPostSuperFlowNode(flow.antecedent, 
                        /*noCacheCheck*/
                        false);
                        target.antecedents = saveAntecedents;
                        return result;
                    }
                    else {
                        return !!(flags & 1 /* Unreachable */);
                    }
                }
            }
            function isConstantReference(node) {
                switch (node.kind) {
                    case 110 /* ThisKeyword */:
                        return true;
                    case 80 /* Identifier */:
                        if (!isThisInTypeQuery(node)) {
                            const symbol = getResolvedSymbol(node);
                            return isConstantVariable(symbol) || isParameterOrMutableLocalVariable(symbol) && !isSymbolAssigned(symbol);
                        }
                        break;
                    case 211 /* PropertyAccessExpression */:
                    case 212 /* ElementAccessExpression */:
                        return isConstantReference(node.expression) && isReadonlySymbol(getNodeLinks(node).resolvedSymbol || unknownSymbol);
                    case 206 /* ObjectBindingPattern */:
                    case 207 /* ArrayBindingPattern */:
                        const rootDeclaration = getRootDeclaration(node.parent);
                        return isParameter(rootDeclaration) || isCatchClauseVariableDeclaration(rootDeclaration) ? !isSomeSymbolAssigned(rootDeclaration) : isVariableDeclaration(rootDeclaration) && isVarConstLike(rootDeclaration);
                }
                return false;
            }
            function getFlowTypeOfReference(reference, declaredType, initialType = declaredType, flowContainer, flowNode = ((_a) => (_a = tryCast(reference, canHaveFlowNode)) == null ? void 0 : _a.flowNode)()) {
                let key;
                let isKeySet = false;
                let flowDepth = 0;
                if (flowAnalysisDisabled) {
                    return errorType;
                }
                if (!flowNode) {
                    return declaredType;
                }
                flowInvocationCount++;
                const sharedFlowStart = sharedFlowCount;
                const evolvedType = getTypeFromFlowType(getTypeAtFlowNode(flowNode));
                sharedFlowCount = sharedFlowStart;
                const resultType = getObjectFlags(evolvedType) & 256 /* EvolvingArray */ && isEvolvingArrayOperationTarget(reference) ? autoArrayType : finalizeEvolvingArrayType(evolvedType);
                if (resultType === unreachableNeverType || reference.parent && reference.parent.kind === 235 /* NonNullExpression */ && !(resultType.flags & 131072 /* Never */) && getTypeWithFacts(resultType, 2097152 /* NEUndefinedOrNull */).flags & 131072 /* Never */) {
                    return declaredType;
                }
                return resultType === nonNullUnknownType ? unknownType : resultType;
                function getOrSetCacheKey() {
                    if (isKeySet) {
                        return key;
                    }
                    isKeySet = true;
                    return key = getFlowCacheKey(reference, declaredType, initialType, flowContainer);
                }
                function getTypeAtFlowNode(flow) {
                    var _a2;
                    if (flowDepth === 2e3) {
                        (_a2 = tracing) == null ? void 0 : _a2.instant(tracing.Phase.CheckTypes, "getTypeAtFlowNode_DepthLimit", { flowId: flow.id });
                        flowAnalysisDisabled = true;
                        reportFlowControlError(reference);
                        return errorType;
                    }
                    flowDepth++;
                    let sharedFlow;
                    while (true) {
                        const flags = flow.flags;
                        if (flags & 4096 /* Shared */) {
                            for (let i = sharedFlowStart; i < sharedFlowCount; i++) {
                                if (sharedFlowNodes[i] === flow) {
                                    flowDepth--;
                                    return sharedFlowTypes[i];
                                }
                            }
                            sharedFlow = flow;
                        }
                        let type;
                        if (flags & 16 /* Assignment */) {
                            type = getTypeAtFlowAssignment(flow);
                            if (!type) {
                                flow = flow.antecedent;
                                continue;
                            }
                        }
                        else if (flags & 512 /* Call */) {
                            type = getTypeAtFlowCall(flow);
                            if (!type) {
                                flow = flow.antecedent;
                                continue;
                            }
                        }
                        else if (flags & 96 /* Condition */) {
                            type = getTypeAtFlowCondition(flow);
                        }
                        else if (flags & 128 /* SwitchClause */) {
                            type = getTypeAtSwitchClause(flow);
                        }
                        else if (flags & 12 /* Label */) {
                            if (flow.antecedents.length === 1) {
                                flow = flow.antecedents[0];
                                continue;
                            }
                            type = flags & 4 /* BranchLabel */ ? getTypeAtFlowBranchLabel(flow) : getTypeAtFlowLoopLabel(flow);
                        }
                        else if (flags & 256 /* ArrayMutation */) {
                            type = getTypeAtFlowArrayMutation(flow);
                            if (!type) {
                                flow = flow.antecedent;
                                continue;
                            }
                        }
                        else if (flags & 1024 /* ReduceLabel */) {
                            const target = flow.target;
                            const saveAntecedents = target.antecedents;
                            target.antecedents = flow.antecedents;
                            type = getTypeAtFlowNode(flow.antecedent);
                            target.antecedents = saveAntecedents;
                        }
                        else if (flags & 2 /* Start */) {
                            const container = flow.node;
                            if (container && container !== flowContainer && reference.kind !== 211 /* PropertyAccessExpression */ && reference.kind !== 212 /* ElementAccessExpression */ && !(reference.kind === 110 /* ThisKeyword */ && container.kind !== 219 /* ArrowFunction */)) {
                                flow = container.flowNode;
                                continue;
                            }
                            type = initialType;
                        }
                        else {
                            type = convertAutoToAny(declaredType);
                        }
                        if (sharedFlow) {
                            sharedFlowNodes[sharedFlowCount] = sharedFlow;
                            sharedFlowTypes[sharedFlowCount] = type;
                            sharedFlowCount++;
                        }
                        flowDepth--;
                        return type;
                    }
                }
                function getInitialOrAssignedType(flow) {
                    const node = flow.node;
                    return getNarrowableTypeForReference(node.kind === 260 /* VariableDeclaration */ || node.kind === 208 /* BindingElement */ ? getInitialType(node) : getAssignedType(node), reference);
                }
                function getTypeAtFlowAssignment(flow) {
                    const node = flow.node;
                    if (isMatchingReference(reference, node)) {
                        if (!isReachableFlowNode(flow)) {
                            return unreachableNeverType;
                        }
                        if (getAssignmentTargetKind(node) === 2 /* Compound */) {
                            const flowType = getTypeAtFlowNode(flow.antecedent);
                            return createFlowType(getBaseTypeOfLiteralType(getTypeFromFlowType(flowType)), isIncomplete(flowType));
                        }
                        if (declaredType === autoType || declaredType === autoArrayType) {
                            if (isEmptyArrayAssignment(node)) {
                                return getEvolvingArrayType(neverType);
                            }
                            const assignedType = getWidenedLiteralType(getInitialOrAssignedType(flow));
                            return isTypeAssignableTo(assignedType, declaredType) ? assignedType : anyArrayType;
                        }
                        const t = isInCompoundLikeAssignment(node) ? getBaseTypeOfLiteralType(declaredType) : declaredType;
                        if (t.flags & 1048576 /* Union */) {
                            return getAssignmentReducedType(t, getInitialOrAssignedType(flow));
                        }
                        return t;
                    }
                    if (containsMatchingReference(reference, node)) {
                        if (!isReachableFlowNode(flow)) {
                            return unreachableNeverType;
                        }
                        if (isVariableDeclaration(node) && (isInJSFile(node) || isVarConstLike(node))) {
                            const init = getDeclaredExpandoInitializer(node);
                            if (init && (init.kind === 218 /* FunctionExpression */ || init.kind === 219 /* ArrowFunction */)) {
                                return getTypeAtFlowNode(flow.antecedent);
                            }
                        }
                        return declaredType;
                    }
                    if (isVariableDeclaration(node) && node.parent.parent.kind === 249 /* ForInStatement */ && (isMatchingReference(reference, node.parent.parent.expression) || optionalChainContainsReference(node.parent.parent.expression, reference))) {
                        return getNonNullableTypeIfNeeded(finalizeEvolvingArrayType(getTypeFromFlowType(getTypeAtFlowNode(flow.antecedent))));
                    }
                    return void 0;
                }
                function narrowTypeByAssertion(type, expr) {
                    const node = skipParentheses(expr, 
                    /*excludeJSDocTypeAssertions*/
                    true);
                    if (node.kind === 97 /* FalseKeyword */) {
                        return unreachableNeverType;
                    }
                    if (node.kind === 226 /* BinaryExpression */) {
                        if (node.operatorToken.kind === 56 /* AmpersandAmpersandToken */) {
                            return narrowTypeByAssertion(narrowTypeByAssertion(type, node.left), node.right);
                        }
                        if (node.operatorToken.kind === 57 /* BarBarToken */) {
                            return getUnionType([narrowTypeByAssertion(type, node.left), narrowTypeByAssertion(type, node.right)]);
                        }
                    }
                    return narrowType(type, node, 
                    /*assumeTrue*/
                    true);
                }
                function getTypeAtFlowCall(flow) {
                    const signature = getEffectsSignature(flow.node);
                    if (signature) {
                        const predicate = getTypePredicateOfSignature(signature);
                        if (predicate && (predicate.kind === 2 /* AssertsThis */ || predicate.kind === 3 /* AssertsIdentifier */)) {
                            const flowType = getTypeAtFlowNode(flow.antecedent);
                            const type = finalizeEvolvingArrayType(getTypeFromFlowType(flowType));
                            const narrowedType = predicate.type ? narrowTypeByTypePredicate(type, predicate, flow.node, 
                            /*assumeTrue*/
                            true) : predicate.kind === 3 /* AssertsIdentifier */ && predicate.parameterIndex >= 0 && predicate.parameterIndex < flow.node.arguments.length ? narrowTypeByAssertion(type, flow.node.arguments[predicate.parameterIndex]) : type;
                            return narrowedType === type ? flowType : createFlowType(narrowedType, isIncomplete(flowType));
                        }
                        if (getReturnTypeOfSignature(signature).flags & 131072 /* Never */) {
                            return unreachableNeverType;
                        }
                    }
                    return void 0;
                }
                function getTypeAtFlowArrayMutation(flow) {
                    if (declaredType === autoType || declaredType === autoArrayType) {
                        const node = flow.node;
                        const expr = node.kind === 213 /* CallExpression */ ? node.expression.expression : node.left.expression;
                        if (isMatchingReference(reference, getReferenceCandidate(expr))) {
                            const flowType = getTypeAtFlowNode(flow.antecedent);
                            const type = getTypeFromFlowType(flowType);
                            if (getObjectFlags(type) & 256 /* EvolvingArray */) {
                                let evolvedType2 = type;
                                if (node.kind === 213 /* CallExpression */) {
                                    for (const arg of node.arguments) {
                                        evolvedType2 = addEvolvingArrayElementType(evolvedType2, arg);
                                    }
                                }
                                else {
                                    const indexType = getContextFreeTypeOfExpression(node.left.argumentExpression);
                                    if (isTypeAssignableToKind(indexType, 296 /* NumberLike */)) {
                                        evolvedType2 = addEvolvingArrayElementType(evolvedType2, node.right);
                                    }
                                }
                                return evolvedType2 === type ? flowType : createFlowType(evolvedType2, isIncomplete(flowType));
                            }
                            return flowType;
                        }
                    }
                    return void 0;
                }
                function getTypeAtFlowCondition(flow) {
                    const flowType = getTypeAtFlowNode(flow.antecedent);
                    const type = getTypeFromFlowType(flowType);
                    if (type.flags & 131072 /* Never */) {
                        return flowType;
                    }
                    const assumeTrue = (flow.flags & 32 /* TrueCondition */) !== 0;
                    const nonEvolvingType = finalizeEvolvingArrayType(type);
                    const narrowedType = narrowType(nonEvolvingType, flow.node, assumeTrue);
                    if (narrowedType === nonEvolvingType) {
                        return flowType;
                    }
                    return createFlowType(narrowedType, isIncomplete(flowType));
                }
                function getTypeAtSwitchClause(flow) {
                    const expr = skipParentheses(flow.switchStatement.expression);
                    const flowType = getTypeAtFlowNode(flow.antecedent);
                    let type = getTypeFromFlowType(flowType);
                    if (isMatchingReference(reference, expr)) {
                        type = narrowTypeBySwitchOnDiscriminant(type, flow.switchStatement, flow.clauseStart, flow.clauseEnd);
                    }
                    else if (expr.kind === 221 /* TypeOfExpression */ && isMatchingReference(reference, expr.expression)) {
                        type = narrowTypeBySwitchOnTypeOf(type, flow.switchStatement, flow.clauseStart, flow.clauseEnd);
                    }
                    else if (expr.kind === 112 /* TrueKeyword */) {
                        type = narrowTypeBySwitchOnTrue(type, flow.switchStatement, flow.clauseStart, flow.clauseEnd);
                    }
                    else {
                        if (strictNullChecks) {
                            if (optionalChainContainsReference(expr, reference)) {
                                type = narrowTypeBySwitchOptionalChainContainment(type, flow.switchStatement, flow.clauseStart, flow.clauseEnd, (t) => !(t.flags & (32768 /* Undefined */ | 131072 /* Never */)));
                            }
                            else if (expr.kind === 221 /* TypeOfExpression */ && optionalChainContainsReference(expr.expression, reference)) {
                                type = narrowTypeBySwitchOptionalChainContainment(type, flow.switchStatement, flow.clauseStart, flow.clauseEnd, (t) => !(t.flags & 131072 /* Never */ || t.flags & 128 /* StringLiteral */ && t.value === "undefined"));
                            }
                        }
                        const access = getDiscriminantPropertyAccess(expr, type);
                        if (access) {
                            type = narrowTypeBySwitchOnDiscriminantProperty(type, access, flow.switchStatement, flow.clauseStart, flow.clauseEnd);
                        }
                    }
                    return createFlowType(type, isIncomplete(flowType));
                }
                function getTypeAtFlowBranchLabel(flow) {
                    const antecedentTypes = [];
                    let subtypeReduction = false;
                    let seenIncomplete = false;
                    let bypassFlow;
                    for (const antecedent of flow.antecedents) {
                        if (!bypassFlow && antecedent.flags & 128 /* SwitchClause */ && antecedent.clauseStart === antecedent.clauseEnd) {
                            bypassFlow = antecedent;
                            continue;
                        }
                        const flowType = getTypeAtFlowNode(antecedent);
                        const type = getTypeFromFlowType(flowType);
                        if (type === declaredType && declaredType === initialType) {
                            return type;
                        }
                        pushIfUnique(antecedentTypes, type);
                        if (!isTypeSubsetOf(type, initialType)) {
                            subtypeReduction = true;
                        }
                        if (isIncomplete(flowType)) {
                            seenIncomplete = true;
                        }
                    }
                    if (bypassFlow) {
                        const flowType = getTypeAtFlowNode(bypassFlow);
                        const type = getTypeFromFlowType(flowType);
                        if (!(type.flags & 131072 /* Never */) && !contains(antecedentTypes, type) && !isExhaustiveSwitchStatement(bypassFlow.switchStatement)) {
                            if (type === declaredType && declaredType === initialType) {
                                return type;
                            }
                            antecedentTypes.push(type);
                            if (!isTypeSubsetOf(type, initialType)) {
                                subtypeReduction = true;
                            }
                            if (isIncomplete(flowType)) {
                                seenIncomplete = true;
                            }
                        }
                    }
                    return createFlowType(getUnionOrEvolvingArrayType(antecedentTypes, subtypeReduction ? 2 /* Subtype */ : 1 /* Literal */), seenIncomplete);
                }
                function getTypeAtFlowLoopLabel(flow) {
                    const id = getFlowNodeId(flow);
                    const cache = flowLoopCaches[id] || (flowLoopCaches[id] = /* @__PURE__ */ new Map());
                    const key2 = getOrSetCacheKey();
                    if (!key2) {
                        return declaredType;
                    }
                    const cached = cache.get(key2);
                    if (cached) {
                        return cached;
                    }
                    for (let i = flowLoopStart; i < flowLoopCount; i++) {
                        if (flowLoopNodes[i] === flow && flowLoopKeys[i] === key2 && flowLoopTypes[i].length) {
                            return createFlowType(getUnionOrEvolvingArrayType(flowLoopTypes[i], 1 /* Literal */), 
                            /*incomplete*/
                            true);
                        }
                    }
                    const antecedentTypes = [];
                    let subtypeReduction = false;
                    let firstAntecedentType;
                    for (const antecedent of flow.antecedents) {
                        let flowType;
                        if (!firstAntecedentType) {
                            flowType = firstAntecedentType = getTypeAtFlowNode(antecedent);
                        }
                        else {
                            flowLoopNodes[flowLoopCount] = flow;
                            flowLoopKeys[flowLoopCount] = key2;
                            flowLoopTypes[flowLoopCount] = antecedentTypes;
                            flowLoopCount++;
                            const saveFlowTypeCache = flowTypeCache;
                            flowTypeCache = void 0;
                            flowType = getTypeAtFlowNode(antecedent);
                            flowTypeCache = saveFlowTypeCache;
                            flowLoopCount--;
                            const cached2 = cache.get(key2);
                            if (cached2) {
                                return cached2;
                            }
                        }
                        const type = getTypeFromFlowType(flowType);
                        pushIfUnique(antecedentTypes, type);
                        if (!isTypeSubsetOf(type, initialType)) {
                            subtypeReduction = true;
                        }
                        if (type === declaredType) {
                            break;
                        }
                    }
                    const result = getUnionOrEvolvingArrayType(antecedentTypes, subtypeReduction ? 2 /* Subtype */ : 1 /* Literal */);
                    if (isIncomplete(firstAntecedentType)) {
                        return createFlowType(result, 
                        /*incomplete*/
                        true);
                    }
                    cache.set(key2, result);
                    return result;
                }
                function getUnionOrEvolvingArrayType(types, subtypeReduction) {
                    if (isEvolvingArrayTypeList(types)) {
                        return getEvolvingArrayType(getUnionType(map(types, getElementTypeOfEvolvingArrayType)));
                    }
                    const result = recombineUnknownType(getUnionType(sameMap(types, finalizeEvolvingArrayType), subtypeReduction));
                    if (result !== declaredType && result.flags & declaredType.flags & 1048576 /* Union */ && arraysEqual(result.types, declaredType.types)) {
                        return declaredType;
                    }
                    return result;
                }
                function getCandidateDiscriminantPropertyAccess(expr) {
                    if (isBindingPattern(reference) || isFunctionExpressionOrArrowFunction(reference) || isObjectLiteralMethod(reference)) {
                        if (isIdentifier(expr)) {
                            const symbol = getResolvedSymbol(expr);
                            const declaration = symbol.valueDeclaration;
                            if (declaration && (isBindingElement(declaration) || isParameter(declaration)) && reference === declaration.parent && !declaration.initializer && !declaration.dotDotDotToken) {
                                return declaration;
                            }
                        }
                    }
                    else if (isAccessExpression(expr)) {
                        if (isMatchingReference(reference, expr.expression)) {
                            return expr;
                        }
                    }
                    else if (isIdentifier(expr)) {
                        const symbol = getResolvedSymbol(expr);
                        if (isConstantVariable(symbol)) {
                            const declaration = symbol.valueDeclaration;
                            if (isVariableDeclaration(declaration) && !declaration.type && declaration.initializer && isAccessExpression(declaration.initializer) && isMatchingReference(reference, declaration.initializer.expression)) {
                                return declaration.initializer;
                            }
                            if (isBindingElement(declaration) && !declaration.initializer) {
                                const parent2 = declaration.parent.parent;
                                if (isVariableDeclaration(parent2) && !parent2.type && parent2.initializer && (isIdentifier(parent2.initializer) || isAccessExpression(parent2.initializer)) && isMatchingReference(reference, parent2.initializer)) {
                                    return declaration;
                                }
                            }
                        }
                    }
                    return void 0;
                }
                function getDiscriminantPropertyAccess(expr, computedType) {
                    if (declaredType.flags & 1048576 /* Union */ || computedType.flags & 1048576 /* Union */) {
                        const access = getCandidateDiscriminantPropertyAccess(expr);
                        if (access) {
                            const name = getAccessedPropertyName(access);
                            if (name) {
                                const type = declaredType.flags & 1048576 /* Union */ && isTypeSubsetOf(computedType, declaredType) ? declaredType : computedType;
                                if (isDiscriminantProperty(type, name)) {
                                    return access;
                                }
                            }
                        }
                    }
                    return void 0;
                }
                function narrowTypeByDiscriminant(type, access, narrowType2) {
                    const propName = getAccessedPropertyName(access);
                    if (propName === void 0) {
                        return type;
                    }
                    const optionalChain = isOptionalChain(access);
                    const removeNullable = strictNullChecks && (optionalChain || isNonNullAccess(access)) && maybeTypeOfKind(type, 98304 /* Nullable */);
                    let propType = getTypeOfPropertyOfType(removeNullable ? getTypeWithFacts(type, 2097152 /* NEUndefinedOrNull */) : type, propName);
                    if (!propType) {
                        return type;
                    }
                    propType = removeNullable && optionalChain ? getOptionalType(propType) : propType;
                    const narrowedPropType = narrowType2(propType);
                    return filterType(type, (t) => {
                        const discriminantType = getTypeOfPropertyOrIndexSignatureOfType(t, propName) || unknownType;
                        return !(discriminantType.flags & 131072 /* Never */) && !(narrowedPropType.flags & 131072 /* Never */) && areTypesComparable(narrowedPropType, discriminantType);
                    });
                }
                function narrowTypeByDiscriminantProperty(type, access, operator, value, assumeTrue) {
                    if ((operator === 37 /* EqualsEqualsEqualsToken */ || operator === 38 /* ExclamationEqualsEqualsToken */) && type.flags & 1048576 /* Union */) {
                        const keyPropertyName = getKeyPropertyName(type);
                        if (keyPropertyName && keyPropertyName === getAccessedPropertyName(access)) {
                            const candidate = getConstituentTypeForKeyType(type, getTypeOfExpression(value));
                            if (candidate) {
                                return operator === (assumeTrue ? 37 /* EqualsEqualsEqualsToken */ : 38 /* ExclamationEqualsEqualsToken */) ? candidate : isUnitType(getTypeOfPropertyOfType(candidate, keyPropertyName) || unknownType) ? removeType(type, candidate) : type;
                            }
                        }
                    }
                    return narrowTypeByDiscriminant(type, access, (t) => narrowTypeByEquality(t, operator, value, assumeTrue));
                }
                function narrowTypeBySwitchOnDiscriminantProperty(type, access, switchStatement, clauseStart, clauseEnd) {
                    if (clauseStart < clauseEnd && type.flags & 1048576 /* Union */ && getKeyPropertyName(type) === getAccessedPropertyName(access)) {
                        const clauseTypes = getSwitchClauseTypes(switchStatement).slice(clauseStart, clauseEnd);
                        const candidate = getUnionType(map(clauseTypes, (t) => getConstituentTypeForKeyType(type, t) || unknownType));
                        if (candidate !== unknownType) {
                            return candidate;
                        }
                    }
                    return narrowTypeByDiscriminant(type, access, (t) => narrowTypeBySwitchOnDiscriminant(t, switchStatement, clauseStart, clauseEnd));
                }
                function narrowTypeByTruthiness(type, expr, assumeTrue) {
                    if (isMatchingReference(reference, expr)) {
                        return getAdjustedTypeWithFacts(type, assumeTrue ? 4194304 /* Truthy */ : 8388608 /* Falsy */);
                    }
                    if (strictNullChecks && assumeTrue && optionalChainContainsReference(expr, reference)) {
                        type = getAdjustedTypeWithFacts(type, 2097152 /* NEUndefinedOrNull */);
                    }
                    const access = getDiscriminantPropertyAccess(expr, type);
                    if (access) {
                        return narrowTypeByDiscriminant(type, access, (t) => getTypeWithFacts(t, assumeTrue ? 4194304 /* Truthy */ : 8388608 /* Falsy */));
                    }
                    return type;
                }
                function isTypePresencePossible(type, propName, assumeTrue) {
                    const prop = getPropertyOfType(type, propName);
                    return prop ? !!(prop.flags & 16777216 /* Optional */ || getCheckFlags(prop) & 48 /* Partial */) || assumeTrue : !!getApplicableIndexInfoForName(type, propName) || !assumeTrue;
                }
                function narrowTypeByInKeyword(type, nameType, assumeTrue) {
                    const name = getPropertyNameFromType(nameType);
                    const isKnownProperty2 = someType(type, (t) => isTypePresencePossible(t, name, 
                    /*assumeTrue*/
                    true));
                    if (isKnownProperty2) {
                        return filterType(type, (t) => isTypePresencePossible(t, name, assumeTrue));
                    }
                    if (assumeTrue) {
                        const recordSymbol = getGlobalRecordSymbol();
                        if (recordSymbol) {
                            return getIntersectionType([type, getTypeAliasInstantiation(recordSymbol, [nameType, unknownType])]);
                        }
                    }
                    return type;
                }
                function narrowTypeByBooleanComparison(type, expr, bool, operator, assumeTrue) {
                    assumeTrue = assumeTrue !== (bool.kind === 112 /* TrueKeyword */) !== (operator !== 38 /* ExclamationEqualsEqualsToken */ && operator !== 36 /* ExclamationEqualsToken */);
                    return narrowType(type, expr, assumeTrue);
                }
                function narrowTypeByBinaryExpression(type, expr, assumeTrue) {
                    switch (expr.operatorToken.kind) {
                        case 64 /* EqualsToken */:
                        case 76 /* BarBarEqualsToken */:
                        case 77 /* AmpersandAmpersandEqualsToken */:
                        case 78 /* QuestionQuestionEqualsToken */:
                            return narrowTypeByTruthiness(narrowType(type, expr.right, assumeTrue), expr.left, assumeTrue);
                        case 35 /* EqualsEqualsToken */:
                        case 36 /* ExclamationEqualsToken */:
                        case 37 /* EqualsEqualsEqualsToken */:
                        case 38 /* ExclamationEqualsEqualsToken */:
                            const operator = expr.operatorToken.kind;
                            const left = getReferenceCandidate(expr.left);
                            const right = getReferenceCandidate(expr.right);
                            if (left.kind === 221 /* TypeOfExpression */ && isStringLiteralLike(right)) {
                                return narrowTypeByTypeof(type, left, operator, right, assumeTrue);
                            }
                            if (right.kind === 221 /* TypeOfExpression */ && isStringLiteralLike(left)) {
                                return narrowTypeByTypeof(type, right, operator, left, assumeTrue);
                            }
                            if (isMatchingReference(reference, left)) {
                                return narrowTypeByEquality(type, operator, right, assumeTrue);
                            }
                            if (isMatchingReference(reference, right)) {
                                return narrowTypeByEquality(type, operator, left, assumeTrue);
                            }
                            if (strictNullChecks) {
                                if (optionalChainContainsReference(left, reference)) {
                                    type = narrowTypeByOptionalChainContainment(type, operator, right, assumeTrue);
                                }
                                else if (optionalChainContainsReference(right, reference)) {
                                    type = narrowTypeByOptionalChainContainment(type, operator, left, assumeTrue);
                                }
                            }
                            const leftAccess = getDiscriminantPropertyAccess(left, type);
                            if (leftAccess) {
                                return narrowTypeByDiscriminantProperty(type, leftAccess, operator, right, assumeTrue);
                            }
                            const rightAccess = getDiscriminantPropertyAccess(right, type);
                            if (rightAccess) {
                                return narrowTypeByDiscriminantProperty(type, rightAccess, operator, left, assumeTrue);
                            }
                            if (isMatchingConstructorReference(left)) {
                                return narrowTypeByConstructor(type, operator, right, assumeTrue);
                            }
                            if (isMatchingConstructorReference(right)) {
                                return narrowTypeByConstructor(type, operator, left, assumeTrue);
                            }
                            if (isBooleanLiteral(right) && !isAccessExpression(left)) {
                                return narrowTypeByBooleanComparison(type, left, right, operator, assumeTrue);
                            }
                            if (isBooleanLiteral(left) && !isAccessExpression(right)) {
                                return narrowTypeByBooleanComparison(type, right, left, operator, assumeTrue);
                            }
                            break;
                        case 104 /* InstanceOfKeyword */:
                            return narrowTypeByInstanceof(type, expr, assumeTrue);
                        case 103 /* InKeyword */:
                            if (isPrivateIdentifier(expr.left)) {
                                return narrowTypeByPrivateIdentifierInInExpression(type, expr, assumeTrue);
                            }
                            const target = getReferenceCandidate(expr.right);
                            if (containsMissingType(type) && isAccessExpression(reference) && isMatchingReference(reference.expression, target)) {
                                const leftType = getTypeOfExpression(expr.left);
                                if (isTypeUsableAsPropertyName(leftType) && getAccessedPropertyName(reference) === getPropertyNameFromType(leftType)) {
                                    return getTypeWithFacts(type, assumeTrue ? 524288 /* NEUndefined */ : 65536 /* EQUndefined */);
                                }
                            }
                            if (isMatchingReference(reference, target)) {
                                const leftType = getTypeOfExpression(expr.left);
                                if (isTypeUsableAsPropertyName(leftType)) {
                                    return narrowTypeByInKeyword(type, leftType, assumeTrue);
                                }
                            }
                            break;
                        case 28 /* CommaToken */:
                            return narrowType(type, expr.right, assumeTrue);
                        case 56 /* AmpersandAmpersandToken */:
                            return assumeTrue ? narrowType(narrowType(type, expr.left, 
                            /*assumeTrue*/
                            true), expr.right, 
                            /*assumeTrue*/
                            true) : getUnionType([narrowType(type, expr.left, 
                                /*assumeTrue*/
                                false), narrowType(type, expr.right, 
                                /*assumeTrue*/
                                false)]);
                        case 57 /* BarBarToken */:
                            return assumeTrue ? getUnionType([narrowType(type, expr.left, 
                                /*assumeTrue*/
                                true), narrowType(type, expr.right, 
                                /*assumeTrue*/
                                true)]) : narrowType(narrowType(type, expr.left, 
                            /*assumeTrue*/
                            false), expr.right, 
                            /*assumeTrue*/
                            false);
                    }
                    return type;
                }
                function narrowTypeByPrivateIdentifierInInExpression(type, expr, assumeTrue) {
                    const target = getReferenceCandidate(expr.right);
                    if (!isMatchingReference(reference, target)) {
                        return type;
                    }
                    Debug.assertNode(expr.left, isPrivateIdentifier);
                    const symbol = getSymbolForPrivateIdentifierExpression(expr.left);
                    if (symbol === void 0) {
                        return type;
                    }
                    const classSymbol = symbol.parent;
                    const targetType = hasStaticModifier(Debug.checkDefined(symbol.valueDeclaration, "should always have a declaration")) ? getTypeOfSymbol(classSymbol) : getDeclaredTypeOfSymbol(classSymbol);
                    return getNarrowedType(type, targetType, assumeTrue, 
                    /*checkDerived*/
                    true);
                }
                function narrowTypeByOptionalChainContainment(type, operator, value, assumeTrue) {
                    const equalsOperator = operator === 35 /* EqualsEqualsToken */ || operator === 37 /* EqualsEqualsEqualsToken */;
                    const nullableFlags = operator === 35 /* EqualsEqualsToken */ || operator === 36 /* ExclamationEqualsToken */ ? 98304 /* Nullable */ : 32768 /* Undefined */;
                    const valueType = getTypeOfExpression(value);
                    const removeNullable = equalsOperator !== assumeTrue && everyType(valueType, (t) => !!(t.flags & nullableFlags)) || equalsOperator === assumeTrue && everyType(valueType, (t) => !(t.flags & (3 /* AnyOrUnknown */ | nullableFlags)));
                    return removeNullable ? getAdjustedTypeWithFacts(type, 2097152 /* NEUndefinedOrNull */) : type;
                }
                function narrowTypeByEquality(type, operator, value, assumeTrue) {
                    if (type.flags & 1 /* Any */) {
                        return type;
                    }
                    if (operator === 36 /* ExclamationEqualsToken */ || operator === 38 /* ExclamationEqualsEqualsToken */) {
                        assumeTrue = !assumeTrue;
                    }
                    const valueType = getTypeOfExpression(value);
                    const doubleEquals = operator === 35 /* EqualsEqualsToken */ || operator === 36 /* ExclamationEqualsToken */;
                    if (valueType.flags & 98304 /* Nullable */) {
                        if (!strictNullChecks) {
                            return type;
                        }
                        const facts = doubleEquals ? assumeTrue ? 262144 /* EQUndefinedOrNull */ : 2097152 /* NEUndefinedOrNull */ : valueType.flags & 65536 /* Null */ ? assumeTrue ? 131072 /* EQNull */ : 1048576 /* NENull */ : assumeTrue ? 65536 /* EQUndefined */ : 524288 /* NEUndefined */;
                        return getAdjustedTypeWithFacts(type, facts);
                    }
                    if (assumeTrue) {
                        if (!doubleEquals && (type.flags & 2 /* Unknown */ || someType(type, isEmptyAnonymousObjectType))) {
                            if (valueType.flags & (402784252 /* Primitive */ | 67108864 /* NonPrimitive */) || isEmptyAnonymousObjectType(valueType)) {
                                return valueType;
                            }
                            if (valueType.flags & 524288 /* Object */) {
                                return nonPrimitiveType;
                            }
                        }
                        const filteredType = filterType(type, (t) => areTypesComparable(t, valueType) || doubleEquals && isCoercibleUnderDoubleEquals(t, valueType));
                        return replacePrimitivesWithLiterals(filteredType, valueType);
                    }
                    if (isUnitType(valueType)) {
                        return filterType(type, (t) => !(isUnitLikeType(t) && areTypesComparable(t, valueType)));
                    }
                    return type;
                }
                function narrowTypeByTypeof(type, typeOfExpr, operator, literal, assumeTrue) {
                    if (operator === 36 /* ExclamationEqualsToken */ || operator === 38 /* ExclamationEqualsEqualsToken */) {
                        assumeTrue = !assumeTrue;
                    }
                    const target = getReferenceCandidate(typeOfExpr.expression);
                    if (!isMatchingReference(reference, target)) {
                        if (strictNullChecks && optionalChainContainsReference(target, reference) && assumeTrue === (literal.text !== "undefined")) {
                            type = getAdjustedTypeWithFacts(type, 2097152 /* NEUndefinedOrNull */);
                        }
                        const propertyAccess = getDiscriminantPropertyAccess(target, type);
                        if (propertyAccess) {
                            return narrowTypeByDiscriminant(type, propertyAccess, (t) => narrowTypeByLiteralExpression(t, literal, assumeTrue));
                        }
                        return type;
                    }
                    return narrowTypeByLiteralExpression(type, literal, assumeTrue);
                }
                function narrowTypeByLiteralExpression(type, literal, assumeTrue) {
                    return assumeTrue ? narrowTypeByTypeName(type, literal.text) : getAdjustedTypeWithFacts(type, typeofNEFacts.get(literal.text) || 32768 /* TypeofNEHostObject */);
                }
                function narrowTypeBySwitchOptionalChainContainment(type, switchStatement, clauseStart, clauseEnd, clauseCheck) {
                    const everyClauseChecks = clauseStart !== clauseEnd && every(getSwitchClauseTypes(switchStatement).slice(clauseStart, clauseEnd), clauseCheck);
                    return everyClauseChecks ? getTypeWithFacts(type, 2097152 /* NEUndefinedOrNull */) : type;
                }
                function narrowTypeBySwitchOnDiscriminant(type, switchStatement, clauseStart, clauseEnd) {
                    const switchTypes = getSwitchClauseTypes(switchStatement);
                    if (!switchTypes.length) {
                        return type;
                    }
                    const clauseTypes = switchTypes.slice(clauseStart, clauseEnd);
                    const hasDefaultClause = clauseStart === clauseEnd || contains(clauseTypes, neverType);
                    if (type.flags & 2 /* Unknown */ && !hasDefaultClause) {
                        let groundClauseTypes;
                        for (let i = 0; i < clauseTypes.length; i += 1) {
                            const t = clauseTypes[i];
                            if (t.flags & (402784252 /* Primitive */ | 67108864 /* NonPrimitive */)) {
                                if (groundClauseTypes !== void 0) {
                                    groundClauseTypes.push(t);
                                }
                            }
                            else if (t.flags & 524288 /* Object */) {
                                if (groundClauseTypes === void 0) {
                                    groundClauseTypes = clauseTypes.slice(0, i);
                                }
                                groundClauseTypes.push(nonPrimitiveType);
                            }
                            else {
                                return type;
                            }
                        }
                        return getUnionType(groundClauseTypes === void 0 ? clauseTypes : groundClauseTypes);
                    }
                    const discriminantType = getUnionType(clauseTypes);
                    const caseType = discriminantType.flags & 131072 /* Never */ ? neverType : replacePrimitivesWithLiterals(filterType(type, (t) => areTypesComparable(discriminantType, t)), discriminantType);
                    if (!hasDefaultClause) {
                        return caseType;
                    }
                    const defaultType = filterType(type, (t) => !(isUnitLikeType(t) && contains(switchTypes, getRegularTypeOfLiteralType(extractUnitType(t)))));
                    return caseType.flags & 131072 /* Never */ ? defaultType : getUnionType([caseType, defaultType]);
                }
                function narrowTypeByTypeName(type, typeName) {
                    switch (typeName) {
                        case "string":
                            return narrowTypeByTypeFacts(type, stringType, 1 /* TypeofEQString */);
                        case "number":
                            return narrowTypeByTypeFacts(type, numberType, 2 /* TypeofEQNumber */);
                        case "bigint":
                            return narrowTypeByTypeFacts(type, bigintType, 4 /* TypeofEQBigInt */);
                        case "boolean":
                            return narrowTypeByTypeFacts(type, booleanType, 8 /* TypeofEQBoolean */);
                        case "symbol":
                            return narrowTypeByTypeFacts(type, esSymbolType, 16 /* TypeofEQSymbol */);
                        case "object":
                            return type.flags & 1 /* Any */ ? type : getUnionType([narrowTypeByTypeFacts(type, nonPrimitiveType, 32 /* TypeofEQObject */), narrowTypeByTypeFacts(type, nullType, 131072 /* EQNull */)]);
                        case "function":
                            return type.flags & 1 /* Any */ ? type : narrowTypeByTypeFacts(type, globalFunctionType, 64 /* TypeofEQFunction */);
                        case "undefined":
                            return narrowTypeByTypeFacts(type, undefinedType, 65536 /* EQUndefined */);
                    }
                    return narrowTypeByTypeFacts(type, nonPrimitiveType, 128 /* TypeofEQHostObject */);
                }
                function narrowTypeByTypeFacts(type, impliedType, facts) {
                    return mapType(type, (t) => (
                    // We first check if a constituent is a subtype of the implied type. If so, we either keep or eliminate
                    // the constituent based on its type facts. We use the strict subtype relation because it treats `object`
                    // as a subtype of `{}`, and we need the type facts check because function types are subtypes of `object`,
                    // but are classified as "function" according to `typeof`.
                    isTypeRelatedTo(t, impliedType, strictSubtypeRelation) ? hasTypeFacts(t, facts) ? t : neverType : (
                    // We next check if the consituent is a supertype of the implied type. If so, we substitute the implied
                    // type. This handles top types like `unknown` and `{}`, and supertypes like `{ toString(): string }`.
                    isTypeSubtypeOf(impliedType, t) ? impliedType : (
                    // Neither the constituent nor the implied type is a subtype of the other, however their domains may still
                    // overlap. For example, an unconstrained type parameter and type `string`. If the type facts indicate
                    // possible overlap, we form an intersection. Otherwise, we eliminate the constituent.
                    hasTypeFacts(t, facts) ? getIntersectionType([t, impliedType]) : neverType))));
                }
                function narrowTypeBySwitchOnTypeOf(type, switchStatement, clauseStart, clauseEnd) {
                    const witnesses = getSwitchClauseTypeOfWitnesses(switchStatement);
                    if (!witnesses) {
                        return type;
                    }
                    const defaultIndex = findIndex(switchStatement.caseBlock.clauses, (clause) => clause.kind === 297 /* DefaultClause */);
                    const hasDefaultClause = clauseStart === clauseEnd || defaultIndex >= clauseStart && defaultIndex < clauseEnd;
                    if (hasDefaultClause) {
                        const notEqualFacts = getNotEqualFactsFromTypeofSwitch(clauseStart, clauseEnd, witnesses);
                        return filterType(type, (t) => getTypeFacts(t, notEqualFacts) === notEqualFacts);
                    }
                    const clauseWitnesses = witnesses.slice(clauseStart, clauseEnd);
                    return getUnionType(map(clauseWitnesses, (text) => text ? narrowTypeByTypeName(type, text) : neverType));
                }
                function narrowTypeBySwitchOnTrue(type, switchStatement, clauseStart, clauseEnd) {
                    const defaultIndex = findIndex(switchStatement.caseBlock.clauses, (clause) => clause.kind === 297 /* DefaultClause */);
                    const hasDefaultClause = clauseStart === clauseEnd || defaultIndex >= clauseStart && defaultIndex < clauseEnd;
                    for (let i = 0; i < clauseStart; i++) {
                        const clause = switchStatement.caseBlock.clauses[i];
                        if (clause.kind === 296 /* CaseClause */) {
                            type = narrowType(type, clause.expression, 
                            /*assumeTrue*/
                            false);
                        }
                    }
                    if (hasDefaultClause) {
                        for (let i = clauseEnd; i < switchStatement.caseBlock.clauses.length; i++) {
                            const clause = switchStatement.caseBlock.clauses[i];
                            if (clause.kind === 296 /* CaseClause */) {
                                type = narrowType(type, clause.expression, 
                                /*assumeTrue*/
                                false);
                            }
                        }
                        return type;
                    }
                    const clauses = switchStatement.caseBlock.clauses.slice(clauseStart, clauseEnd);
                    return getUnionType(map(clauses, (clause) => clause.kind === 296 /* CaseClause */ ? narrowType(type, clause.expression, 
                    /*assumeTrue*/
                    true) : neverType));
                }
                function isMatchingConstructorReference(expr) {
                    return (isPropertyAccessExpression(expr) && idText(expr.name) === "constructor" || isElementAccessExpression(expr) && isStringLiteralLike(expr.argumentExpression) && expr.argumentExpression.text === "constructor") && isMatchingReference(reference, expr.expression);
                }
                function narrowTypeByConstructor(type, operator, identifier, assumeTrue) {
                    if (assumeTrue ? operator !== 35 /* EqualsEqualsToken */ && operator !== 37 /* EqualsEqualsEqualsToken */ : operator !== 36 /* ExclamationEqualsToken */ && operator !== 38 /* ExclamationEqualsEqualsToken */) {
                        return type;
                    }
                    const identifierType = getTypeOfExpression(identifier);
                    if (!isFunctionType(identifierType) && !isConstructorType(identifierType)) {
                        return type;
                    }
                    const prototypeProperty = getPropertyOfType(identifierType, "prototype");
                    if (!prototypeProperty) {
                        return type;
                    }
                    const prototypeType = getTypeOfSymbol(prototypeProperty);
                    const candidate = !isTypeAny(prototypeType) ? prototypeType : void 0;
                    if (!candidate || candidate === globalObjectType || candidate === globalFunctionType) {
                        return type;
                    }
                    if (isTypeAny(type)) {
                        return candidate;
                    }
                    return filterType(type, (t) => isConstructedBy(t, candidate));
                    function isConstructedBy(source, target) {
                        if (source.flags & 524288 /* Object */ && getObjectFlags(source) & 1 /* Class */ || target.flags & 524288 /* Object */ && getObjectFlags(target) & 1 /* Class */) {
                            return source.symbol === target.symbol;
                        }
                        return isTypeSubtypeOf(source, target);
                    }
                }
                function narrowTypeByInstanceof(type, expr, assumeTrue) {
                    const left = getReferenceCandidate(expr.left);
                    if (!isMatchingReference(reference, left)) {
                        if (assumeTrue && strictNullChecks && optionalChainContainsReference(left, reference)) {
                            return getAdjustedTypeWithFacts(type, 2097152 /* NEUndefinedOrNull */);
                        }
                        return type;
                    }
                    const right = expr.right;
                    const rightType = getTypeOfExpression(right);
                    if (!isTypeDerivedFrom(rightType, globalObjectType)) {
                        return type;
                    }
                    const signature = getEffectsSignature(expr);
                    const predicate = signature && getTypePredicateOfSignature(signature);
                    if (predicate && predicate.kind === 1 /* Identifier */ && predicate.parameterIndex === 0) {
                        return getNarrowedType(type, predicate.type, assumeTrue, 
                        /*checkDerived*/
                        true);
                    }
                    if (!isTypeDerivedFrom(rightType, globalFunctionType)) {
                        return type;
                    }
                    const instanceType = mapType(rightType, getInstanceType);
                    if (isTypeAny(type) && (instanceType === globalObjectType || instanceType === globalFunctionType) || !assumeTrue && !(instanceType.flags & 524288 /* Object */ && !isEmptyAnonymousObjectType(instanceType))) {
                        return type;
                    }
                    return getNarrowedType(type, instanceType, assumeTrue, 
                    /*checkDerived*/
                    true);
                }
                function getInstanceType(constructorType) {
                    const prototypePropertyType = getTypeOfPropertyOfType(constructorType, "prototype");
                    if (prototypePropertyType && !isTypeAny(prototypePropertyType)) {
                        return prototypePropertyType;
                    }
                    const constructSignatures = getSignaturesOfType(constructorType, 1 /* Construct */);
                    if (constructSignatures.length) {
                        return getUnionType(map(constructSignatures, (signature) => getReturnTypeOfSignature(getErasedSignature(signature))));
                    }
                    return emptyObjectType;
                }
                function getNarrowedType(type, candidate, assumeTrue, checkDerived) {
                    const key2 = type.flags & 1048576 /* Union */ ? `N${getTypeId(type)},${getTypeId(candidate)},${(assumeTrue ? 1 : 0) | (checkDerived ? 2 : 0)}` : void 0;
                    return getCachedType(key2) ?? setCachedType(key2, getNarrowedTypeWorker(type, candidate, assumeTrue, checkDerived));
                }
                function getNarrowedTypeWorker(type, candidate, assumeTrue, checkDerived) {
                    if (!assumeTrue) {
                        if (type === candidate) {
                            return neverType;
                        }
                        if (checkDerived) {
                            return filterType(type, (t) => !isTypeDerivedFrom(t, candidate));
                        }
                        const trueType2 = getNarrowedType(type, candidate, 
                        /*assumeTrue*/
                        true, 
                        /*checkDerived*/
                        false);
                        return filterType(type, (t) => !isTypeSubsetOf(t, trueType2));
                    }
                    if (type.flags & 3 /* AnyOrUnknown */) {
                        return candidate;
                    }
                    if (type === candidate) {
                        return candidate;
                    }
                    const isRelated = checkDerived ? isTypeDerivedFrom : isTypeSubtypeOf;
                    const keyPropertyName = type.flags & 1048576 /* Union */ ? getKeyPropertyName(type) : void 0;
                    const narrowedType = mapType(candidate, (c) => {
                        const discriminant = keyPropertyName && getTypeOfPropertyOfType(c, keyPropertyName);
                        const matching = discriminant && getConstituentTypeForKeyType(type, discriminant);
                        const directlyRelated = mapType(matching || type, checkDerived ? (t) => isTypeDerivedFrom(t, c) ? t : isTypeDerivedFrom(c, t) ? c : neverType : (t) => isTypeStrictSubtypeOf(t, c) ? t : isTypeStrictSubtypeOf(c, t) ? c : isTypeSubtypeOf(t, c) ? t : isTypeSubtypeOf(c, t) ? c : neverType);
                        return directlyRelated.flags & 131072 /* Never */ ? mapType(type, (t) => maybeTypeOfKind(t, 465829888 /* Instantiable */) && isRelated(c, getBaseConstraintOfType(t) || unknownType) ? getIntersectionType([t, c]) : neverType) : directlyRelated;
                    });
                    return !(narrowedType.flags & 131072 /* Never */) ? narrowedType : isTypeSubtypeOf(candidate, type) ? candidate : isTypeAssignableTo(type, candidate) ? type : isTypeAssignableTo(candidate, type) ? candidate : getIntersectionType([type, candidate]);
                }
                function narrowTypeByCallExpression(type, callExpression, assumeTrue) {
                    if (hasMatchingArgument(callExpression, reference)) {
                        const signature = assumeTrue || !isCallChain(callExpression) ? getEffectsSignature(callExpression) : void 0;
                        const predicate = signature && getTypePredicateOfSignature(signature);
                        if (predicate && (predicate.kind === 0 /* This */ || predicate.kind === 1 /* Identifier */)) {
                            return narrowTypeByTypePredicate(type, predicate, callExpression, assumeTrue);
                        }
                    }
                    if (containsMissingType(type) && isAccessExpression(reference) && isPropertyAccessExpression(callExpression.expression)) {
                        const callAccess = callExpression.expression;
                        if (isMatchingReference(reference.expression, getReferenceCandidate(callAccess.expression)) && isIdentifier(callAccess.name) && callAccess.name.escapedText === "hasOwnProperty" && callExpression.arguments.length === 1) {
                            const argument = callExpression.arguments[0];
                            if (isStringLiteralLike(argument) && getAccessedPropertyName(reference) === escapeLeadingUnderscores(argument.text)) {
                                return getTypeWithFacts(type, assumeTrue ? 524288 /* NEUndefined */ : 65536 /* EQUndefined */);
                            }
                        }
                    }
                    return type;
                }
                function narrowTypeByTypePredicate(type, predicate, callExpression, assumeTrue) {
                    if (predicate.type && !(isTypeAny(type) && (predicate.type === globalObjectType || predicate.type === globalFunctionType))) {
                        const predicateArgument = getTypePredicateArgument(predicate, callExpression);
                        if (predicateArgument) {
                            if (isMatchingReference(reference, predicateArgument)) {
                                return getNarrowedType(type, predicate.type, assumeTrue, 
                                /*checkDerived*/
                                false);
                            }
                            if (strictNullChecks && optionalChainContainsReference(predicateArgument, reference) && (assumeTrue && !hasTypeFacts(predicate.type, 65536 /* EQUndefined */) || !assumeTrue && everyType(predicate.type, isNullableType))) {
                                type = getAdjustedTypeWithFacts(type, 2097152 /* NEUndefinedOrNull */);
                            }
                            const access = getDiscriminantPropertyAccess(predicateArgument, type);
                            if (access) {
                                return narrowTypeByDiscriminant(type, access, (t) => getNarrowedType(t, predicate.type, assumeTrue, 
                                /*checkDerived*/
                                false));
                            }
                        }
                    }
                    return type;
                }
                function narrowType(type, expr, assumeTrue) {
                    if (isExpressionOfOptionalChainRoot(expr) || isBinaryExpression(expr.parent) && (expr.parent.operatorToken.kind === 61 /* QuestionQuestionToken */ || expr.parent.operatorToken.kind === 78 /* QuestionQuestionEqualsToken */) && expr.parent.left === expr) {
                        return narrowTypeByOptionality(type, expr, assumeTrue);
                    }
                    switch (expr.kind) {
                        case 80 /* Identifier */:
                            if (!isMatchingReference(reference, expr) && inlineLevel < 5) {
                                const symbol = getResolvedSymbol(expr);
                                if (isConstantVariable(symbol)) {
                                    const declaration = symbol.valueDeclaration;
                                    if (declaration && isVariableDeclaration(declaration) && !declaration.type && declaration.initializer && isConstantReference(reference)) {
                                        inlineLevel++;
                                        const result = narrowType(type, declaration.initializer, assumeTrue);
                                        inlineLevel--;
                                        return result;
                                    }
                                }
                            }
                        case 110 /* ThisKeyword */:
                        case 108 /* SuperKeyword */:
                        case 211 /* PropertyAccessExpression */:
                        case 212 /* ElementAccessExpression */:
                            return narrowTypeByTruthiness(type, expr, assumeTrue);
                        case 213 /* CallExpression */:
                            return narrowTypeByCallExpression(type, expr, assumeTrue);
                        case 217 /* ParenthesizedExpression */:
                        case 235 /* NonNullExpression */:
                            return narrowType(type, expr.expression, assumeTrue);
                        case 226 /* BinaryExpression */:
                            return narrowTypeByBinaryExpression(type, expr, assumeTrue);
                        case 224 /* PrefixUnaryExpression */:
                            if (expr.operator === 54 /* ExclamationToken */) {
                                return narrowType(type, expr.operand, !assumeTrue);
                            }
                            break;
                    }
                    return type;
                }
                function narrowTypeByOptionality(type, expr, assumePresent) {
                    if (isMatchingReference(reference, expr)) {
                        return getAdjustedTypeWithFacts(type, assumePresent ? 2097152 /* NEUndefinedOrNull */ : 262144 /* EQUndefinedOrNull */);
                    }
                    const access = getDiscriminantPropertyAccess(expr, type);
                    if (access) {
                        return narrowTypeByDiscriminant(type, access, (t) => getTypeWithFacts(t, assumePresent ? 2097152 /* NEUndefinedOrNull */ : 262144 /* EQUndefinedOrNull */));
                    }
                    return type;
                }
            }
            function getTypeOfSymbolAtLocation(symbol, location) {
                symbol = getExportSymbolOfValueSymbolIfExported(symbol);
                if (location.kind === 80 /* Identifier */ || location.kind === 81 /* PrivateIdentifier */) {
                    if (isRightSideOfQualifiedNameOrPropertyAccess(location)) {
                        location = location.parent;
                    }
                    if (isExpressionNode(location) && (!isAssignmentTarget(location) || isWriteAccess(location))) {
                        const type = removeOptionalTypeMarker(isWriteAccess(location) && location.kind === 211 /* PropertyAccessExpression */ ? checkPropertyAccessExpression(location, 
                        /*checkMode*/
                        void 0, 
                        /*writeOnly*/
                        true) : getTypeOfExpression(location));
                        if (getExportSymbolOfValueSymbolIfExported(getNodeLinks(location).resolvedSymbol) === symbol) {
                            return type;
                        }
                    }
                }
                if (isDeclarationName(location) && isSetAccessor(location.parent) && getAnnotatedAccessorTypeNode(location.parent)) {
                    return getWriteTypeOfAccessors(location.parent.symbol);
                }
                return isRightSideOfAccessExpression(location) && isWriteAccess(location.parent) ? getWriteTypeOfSymbol(symbol) : getNonMissingTypeOfSymbol(symbol);
            }
            function getControlFlowContainer(node) {
                return findAncestor(node.parent, (node2) => isFunctionLike(node2) && !getImmediatelyInvokedFunctionExpression(node2) || node2.kind === 268 /* ModuleBlock */ || node2.kind === 312 /* SourceFile */ || node2.kind === 172 /* PropertyDeclaration */);
            }
            function isSymbolAssigned(symbol) {
                return !isPastLastAssignment(symbol, 
                /*location*/
                void 0);
            }
            function isPastLastAssignment(symbol, location) {
                const parent2 = findAncestor(symbol.valueDeclaration, isFunctionOrSourceFile);
                if (!parent2) {
                    return false;
                }
                const links = getNodeLinks(parent2);
                if (!(links.flags & 131072 /* AssignmentsMarked */)) {
                    links.flags |= 131072 /* AssignmentsMarked */;
                    if (!hasParentWithAssignmentsMarked(parent2)) {
                        markNodeAssignments(parent2);
                    }
                }
                return !symbol.lastAssignmentPos || location && symbol.lastAssignmentPos < location.pos;
            }
            function isSomeSymbolAssigned(rootDeclaration) {
                Debug.assert(isVariableDeclaration(rootDeclaration) || isParameter(rootDeclaration));
                return isSomeSymbolAssignedWorker(rootDeclaration.name);
            }
            function isSomeSymbolAssignedWorker(node) {
                if (node.kind === 80 /* Identifier */) {
                    return isSymbolAssigned(getSymbolOfDeclaration(node.parent));
                }
                return some(node.elements, (e) => e.kind !== 232 /* OmittedExpression */ && isSomeSymbolAssignedWorker(e.name));
            }
            function hasParentWithAssignmentsMarked(node) {
                return !!findAncestor(node.parent, (node2) => isFunctionOrSourceFile(node2) && !!(getNodeLinks(node2).flags & 131072 /* AssignmentsMarked */));
            }
            function isFunctionOrSourceFile(node) {
                return isFunctionLikeDeclaration(node) || isSourceFile(node);
            }
            function markNodeAssignments(node) {
                switch (node.kind) {
                    case 80 /* Identifier */:
                        if (isAssignmentTarget(node)) {
                            const symbol = getResolvedSymbol(node);
                            if (isParameterOrMutableLocalVariable(symbol) && symbol.lastAssignmentPos !== Number.MAX_VALUE) {
                                const referencingFunction = findAncestor(node, isFunctionOrSourceFile);
                                const declaringFunction = findAncestor(symbol.valueDeclaration, isFunctionOrSourceFile);
                                symbol.lastAssignmentPos = referencingFunction === declaringFunction ? extendAssignmentPosition(node, symbol.valueDeclaration) : Number.MAX_VALUE;
                            }
                        }
                        return;
                    case 281 /* ExportSpecifier */:
                        const exportDeclaration = node.parent.parent;
                        if (!node.isTypeOnly && !exportDeclaration.isTypeOnly && !exportDeclaration.moduleSpecifier) {
                            const symbol = resolveEntityName(node.propertyName || node.name, 111551 /* Value */, 
                            /*ignoreErrors*/
                            true, 
                            /*dontResolveAlias*/
                            true);
                            if (symbol && isParameterOrMutableLocalVariable(symbol)) {
                                symbol.lastAssignmentPos = Number.MAX_VALUE;
                            }
                        }
                        return;
                    case 264 /* InterfaceDeclaration */:
                    case 265 /* TypeAliasDeclaration */:
                    case 266 /* EnumDeclaration */:
                        return;
                }
                if (isTypeNode(node)) {
                    return;
                }
                forEachChild(node, markNodeAssignments);
            }
            function extendAssignmentPosition(node, declaration) {
                let pos = node.pos;
                while (node && node.pos > declaration.pos) {
                    switch (node.kind) {
                        case 243 /* VariableStatement */:
                        case 244 /* ExpressionStatement */:
                        case 245 /* IfStatement */:
                        case 246 /* DoStatement */:
                        case 247 /* WhileStatement */:
                        case 248 /* ForStatement */:
                        case 249 /* ForInStatement */:
                        case 250 /* ForOfStatement */:
                        case 254 /* WithStatement */:
                        case 255 /* SwitchStatement */:
                        case 258 /* TryStatement */:
                        case 263 /* ClassDeclaration */:
                            pos = node.end;
                    }
                    node = node.parent;
                }
                return pos;
            }
            function isConstantVariable(symbol) {
                return symbol.flags & 3 /* Variable */ && (getDeclarationNodeFlagsFromSymbol(symbol) & 6 /* Constant */) !== 0;
            }
            function isParameterOrMutableLocalVariable(symbol) {
                const declaration = symbol.valueDeclaration && getRootDeclaration(symbol.valueDeclaration);
                return !!declaration && (isParameter(declaration) || isVariableDeclaration(declaration) && (isCatchClause(declaration.parent) || isMutableLocalVariableDeclaration(declaration)));
            }
            function isMutableLocalVariableDeclaration(declaration) {
                return !!(declaration.parent.flags & 1 /* Let */) && !(getCombinedModifierFlags(declaration) & 32 /* Export */ || declaration.parent.parent.kind === 243 /* VariableStatement */ && isGlobalSourceFile(declaration.parent.parent.parent));
            }
            function parameterInitializerContainsUndefined(declaration) {
                const links = getNodeLinks(declaration);
                if (links.parameterInitializerContainsUndefined === void 0) {
                    if (!pushTypeResolution(declaration, 9 /* ParameterInitializerContainsUndefined */)) {
                        reportCircularityError(declaration.symbol);
                        return true;
                    }
                    const containsUndefined = !!hasTypeFacts(checkDeclarationInitializer(declaration, 0 /* Normal */), 16777216 /* IsUndefined */);
                    if (!popTypeResolution()) {
                        reportCircularityError(declaration.symbol);
                        return true;
                    }
                    links.parameterInitializerContainsUndefined = containsUndefined;
                }
                return links.parameterInitializerContainsUndefined;
            }
            function removeOptionalityFromDeclaredType(declaredType, declaration) {
                const removeUndefined = strictNullChecks && declaration.kind === 169 /* Parameter */ && declaration.initializer && hasTypeFacts(declaredType, 16777216 /* IsUndefined */) && !parameterInitializerContainsUndefined(declaration);
                return removeUndefined ? getTypeWithFacts(declaredType, 524288 /* NEUndefined */) : declaredType;
            }
            function isConstraintPosition(type, node) {
                const parent2 = node.parent;
                return parent2.kind === 211 /* PropertyAccessExpression */ || parent2.kind === 166 /* QualifiedName */ || parent2.kind === 213 /* CallExpression */ && parent2.expression === node || parent2.kind === 212 /* ElementAccessExpression */ && parent2.expression === node && !(someType(type, isGenericTypeWithoutNullableConstraint) && isGenericIndexType(getTypeOfExpression(parent2.argumentExpression)));
            }
            function isGenericTypeWithUnionConstraint(type) {
                return type.flags & 2097152 /* Intersection */ ? some(type.types, isGenericTypeWithUnionConstraint) : !!(type.flags & 465829888 /* Instantiable */ && getBaseConstraintOrType(type).flags & (98304 /* Nullable */ | 1048576 /* Union */));
            }
            function isGenericTypeWithoutNullableConstraint(type) {
                return type.flags & 2097152 /* Intersection */ ? some(type.types, isGenericTypeWithoutNullableConstraint) : !!(type.flags & 465829888 /* Instantiable */ && !maybeTypeOfKind(getBaseConstraintOrType(type), 98304 /* Nullable */));
            }
            function hasContextualTypeWithNoGenericTypes(node, checkMode) {
                const contextualType = (isIdentifier(node) || isPropertyAccessExpression(node) || isElementAccessExpression(node)) && !((isJsxOpeningElement(node.parent) || isJsxSelfClosingElement(node.parent)) && node.parent.tagName === node) && (checkMode && checkMode & 32 /* RestBindingElement */ ? getContextualType2(node, 8 /* SkipBindingPatterns */) : getContextualType2(node, 
                /*contextFlags*/
                void 0));
                return contextualType && !isGenericType(contextualType);
            }
            function getNarrowableTypeForReference(type, reference, checkMode) {
                const substituteConstraints = !(checkMode && checkMode & 2 /* Inferential */) && someType(type, isGenericTypeWithUnionConstraint) && (isConstraintPosition(type, reference) || hasContextualTypeWithNoGenericTypes(reference, checkMode));
                return substituteConstraints ? mapType(type, getBaseConstraintOrType) : type;
            }
            function isExportOrExportExpression(location) {
                return !!findAncestor(location, (n) => {
                    const parent2 = n.parent;
                    if (parent2 === void 0) {
                        return "quit";
                    }
                    if (isExportAssignment(parent2)) {
                        return parent2.expression === n && isEntityNameExpression(n);
                    }
                    if (isExportSpecifier(parent2)) {
                        return parent2.name === n || parent2.propertyName === n;
                    }
                    return false;
                });
            }
            function markAliasReferenced(symbol, location) {
                if (!canCollectSymbolAliasAccessabilityData) {
                    return;
                }
                if (isNonLocalAlias(symbol, 
                /*excludes*/
                111551 /* Value */) && !isInTypeQuery(location)) {
                    const target = resolveAlias(symbol);
                    if (getSymbolFlags(symbol, 
                    /*excludeTypeOnlyMeanings*/
                    true) & (111551 /* Value */ | 1048576 /* ExportValue */)) {
                        if (getIsolatedModules(compilerOptions) || shouldPreserveConstEnums(compilerOptions) && isExportOrExportExpression(location) || !isConstEnumOrConstEnumOnlyModule(getExportSymbolOfValueSymbolIfExported(target))) {
                            markAliasSymbolAsReferenced(symbol);
                        }
                        else {
                            markConstEnumAliasAsReferenced(symbol);
                        }
                    }
                }
            }
            function getNarrowedTypeOfSymbol(symbol, location, checkMode) {
                var _a;
                const type = getTypeOfSymbol(symbol, checkMode);
                const declaration = symbol.valueDeclaration;
                if (declaration) {
                    if (isBindingElement(declaration) && !declaration.initializer && !declaration.dotDotDotToken && declaration.parent.elements.length >= 2) {
                        const parent2 = declaration.parent.parent;
                        const rootDeclaration = getRootDeclaration(parent2);
                        if (rootDeclaration.kind === 260 /* VariableDeclaration */ && getCombinedNodeFlagsCached(rootDeclaration) & 6 /* Constant */ || rootDeclaration.kind === 169 /* Parameter */) {
                            const links = getNodeLinks(parent2);
                            if (!(links.flags & 4194304 /* InCheckIdentifier */)) {
                                links.flags |= 4194304 /* InCheckIdentifier */;
                                const parentType = getTypeForBindingElementParent(parent2, 0 /* Normal */);
                                const parentTypeConstraint = parentType && mapType(parentType, getBaseConstraintOrType);
                                links.flags &= ~4194304 /* InCheckIdentifier */;
                                if (parentTypeConstraint && parentTypeConstraint.flags & 1048576 /* Union */ && !(rootDeclaration.kind === 169 /* Parameter */ && isSomeSymbolAssigned(rootDeclaration))) {
                                    const pattern = declaration.parent;
                                    const narrowedType = getFlowTypeOfReference(pattern, parentTypeConstraint, parentTypeConstraint, 
                                    /*flowContainer*/
                                    void 0, location.flowNode);
                                    if (narrowedType.flags & 131072 /* Never */) {
                                        return neverType;
                                    }
                                    return getBindingElementTypeFromParentType(declaration, narrowedType, 
                                    /*noTupleBoundsCheck*/
                                    true);
                                }
                            }
                        }
                    }
                    if (isParameter(declaration) && !declaration.type && !declaration.initializer && !declaration.dotDotDotToken) {
                        const func = declaration.parent;
                        if (func.parameters.length >= 2 && isContextSensitiveFunctionOrObjectLiteralMethod(func)) {
                            const contextualSignature = getContextualSignature(func);
                            if (contextualSignature && contextualSignature.parameters.length === 1 && signatureHasRestParameter(contextualSignature)) {
                                const restType = getReducedApparentType(instantiateType(getTypeOfSymbol(contextualSignature.parameters[0]), (_a = getInferenceContext(func)) == null ? void 0 : _a.nonFixingMapper));
                                if (restType.flags & 1048576 /* Union */ && everyType(restType, isTupleType) && !some(func.parameters, isSomeSymbolAssigned)) {
                                    const narrowedType = getFlowTypeOfReference(func, restType, restType, 
                                    /*flowContainer*/
                                    void 0, location.flowNode);
                                    const index = func.parameters.indexOf(declaration) - (getThisParameter(func) ? 1 : 0);
                                    return getIndexedAccessType(narrowedType, getNumberLiteralType(index));
                                }
                            }
                        }
                    }
                }
                return type;
            }
            function checkIdentifier(node, checkMode) {
                if (isThisInTypeQuery(node)) {
                    return checkThisExpression(node);
                }
                const symbol = getResolvedSymbol(node);
                if (symbol === unknownSymbol) {
                    return errorType;
                }
                if (symbol === argumentsSymbol) {
                    if (isInPropertyInitializerOrClassStaticBlock(node)) {
                        error2(node, Diagnostics.arguments_cannot_be_referenced_in_property_initializers);
                        return errorType;
                    }
                    let container = getContainingFunction(node);
                    if (container) {
                        if (languageVersion < 2 /* ES2015 */) {
                            if (container.kind === 219 /* ArrowFunction */) {
                                error2(node, Diagnostics.The_arguments_object_cannot_be_referenced_in_an_arrow_function_in_ES3_and_ES5_Consider_using_a_standard_function_expression);
                            }
                            else if (hasSyntacticModifier(container, 1024 /* Async */)) {
                                error2(node, Diagnostics.The_arguments_object_cannot_be_referenced_in_an_async_function_or_method_in_ES3_and_ES5_Consider_using_a_standard_function_or_method);
                            }
                        }
                        getNodeLinks(container).flags |= 512 /* CaptureArguments */;
                        while (container && isArrowFunction(container)) {
                            container = getContainingFunction(container);
                            if (container) {
                                getNodeLinks(container).flags |= 512 /* CaptureArguments */;
                            }
                        }
                    }
                    return getTypeOfSymbol(symbol);
                }
                if (shouldMarkIdentifierAliasReferenced(node)) {
                    markAliasReferenced(symbol, node);
                }
                const localOrExportSymbol = getExportSymbolOfValueSymbolIfExported(symbol);
                const targetSymbol = resolveAliasWithDeprecationCheck(localOrExportSymbol, node);
                if (isDeprecatedSymbol(targetSymbol) && isUncalledFunctionReference(node, targetSymbol) && targetSymbol.declarations) {
                    addDeprecatedSuggestion(node, targetSymbol.declarations, node.escapedText);
                }
                let declaration = localOrExportSymbol.valueDeclaration;
                if (declaration && localOrExportSymbol.flags & 32 /* Class */) {
                    if (isClassLike(declaration) && declaration.name !== node) {
                        let container = getThisContainer(node, 
                        /*includeArrowFunctions*/
                        false, 
                        /*includeClassComputedPropertyName*/
                        false);
                        while (container.kind !== 312 /* SourceFile */ && container.parent !== declaration) {
                            container = getThisContainer(container, 
                            /*includeArrowFunctions*/
                            false, 
                            /*includeClassComputedPropertyName*/
                            false);
                        }
                        if (container.kind !== 312 /* SourceFile */) {
                            getNodeLinks(declaration).flags |= 262144 /* ContainsConstructorReference */;
                            getNodeLinks(container).flags |= 262144 /* ContainsConstructorReference */;
                            getNodeLinks(node).flags |= 536870912 /* ConstructorReference */;
                        }
                    }
                }
                checkNestedBlockScopedBinding(node, symbol);
                let type = getNarrowedTypeOfSymbol(localOrExportSymbol, node, checkMode);
                const assignmentKind = getAssignmentTargetKind(node);
                if (assignmentKind) {
                    if (!(localOrExportSymbol.flags & 3 /* Variable */) && !(isInJSFile(node) && localOrExportSymbol.flags & 512 /* ValueModule */)) {
                        const assignmentError = localOrExportSymbol.flags & 384 /* Enum */ ? Diagnostics.Cannot_assign_to_0_because_it_is_an_enum : localOrExportSymbol.flags & 32 /* Class */ ? Diagnostics.Cannot_assign_to_0_because_it_is_a_class : localOrExportSymbol.flags & 1536 /* Module */ ? Diagnostics.Cannot_assign_to_0_because_it_is_a_namespace : localOrExportSymbol.flags & 16 /* Function */ ? Diagnostics.Cannot_assign_to_0_because_it_is_a_function : localOrExportSymbol.flags & 2097152 /* Alias */ ? Diagnostics.Cannot_assign_to_0_because_it_is_an_import : Diagnostics.Cannot_assign_to_0_because_it_is_not_a_variable;
                        error2(node, assignmentError, symbolToString(symbol));
                        return errorType;
                    }
                    if (isReadonlySymbol(localOrExportSymbol)) {
                        if (localOrExportSymbol.flags & 3 /* Variable */) {
                            error2(node, Diagnostics.Cannot_assign_to_0_because_it_is_a_constant, symbolToString(symbol));
                        }
                        else {
                            error2(node, Diagnostics.Cannot_assign_to_0_because_it_is_a_read_only_property, symbolToString(symbol));
                        }
                        return errorType;
                    }
                }
                const isAlias = localOrExportSymbol.flags & 2097152 /* Alias */;
                if (localOrExportSymbol.flags & 3 /* Variable */) {
                    if (assignmentKind === 1 /* Definite */) {
                        return isInCompoundLikeAssignment(node) ? getBaseTypeOfLiteralType(type) : type;
                    }
                }
                else if (isAlias) {
                    declaration = getDeclarationOfAliasSymbol(symbol);
                }
                else {
                    return type;
                }
                if (!declaration) {
                    return type;
                }
                type = getNarrowableTypeForReference(type, node, checkMode);
                const isParameter2 = getRootDeclaration(declaration).kind === 169 /* Parameter */;
                const declarationContainer = getControlFlowContainer(declaration);
                let flowContainer = getControlFlowContainer(node);
                const isOuterVariable = flowContainer !== declarationContainer;
                const isSpreadDestructuringAssignmentTarget = node.parent && node.parent.parent && isSpreadAssignment(node.parent) && isDestructuringAssignmentTarget(node.parent.parent);
                const isModuleExports = symbol.flags & 134217728 /* ModuleExports */;
                const typeIsAutomatic = type === autoType || type === autoArrayType;
                const isAutomaticTypeInNonNull = typeIsAutomatic && node.parent.kind === 235 /* NonNullExpression */;
                while (flowContainer !== declarationContainer && (flowContainer.kind === 218 /* FunctionExpression */ || flowContainer.kind === 219 /* ArrowFunction */ || isObjectLiteralOrClassExpressionMethodOrAccessor(flowContainer)) && (isConstantVariable(localOrExportSymbol) && type !== autoArrayType || isParameterOrMutableLocalVariable(localOrExportSymbol) && isPastLastAssignment(localOrExportSymbol, node))) {
                    flowContainer = getControlFlowContainer(flowContainer);
                }
                const assumeInitialized = isParameter2 || isAlias || isOuterVariable || isSpreadDestructuringAssignmentTarget || isModuleExports || isSameScopedBindingElement(node, declaration) || type !== autoType && type !== autoArrayType && (!strictNullChecks || (type.flags & (3 /* AnyOrUnknown */ | 16384 /* Void */)) !== 0 || isInTypeQuery(node) || isInAmbientOrTypeNode(node) || node.parent.kind === 281 /* ExportSpecifier */) || node.parent.kind === 235 /* NonNullExpression */ || declaration.kind === 260 /* VariableDeclaration */ && declaration.exclamationToken || declaration.flags & 33554432 /* Ambient */;
                const initialType = isAutomaticTypeInNonNull ? undefinedType : assumeInitialized ? isParameter2 ? removeOptionalityFromDeclaredType(type, declaration) : type : typeIsAutomatic ? undefinedType : getOptionalType(type);
                const flowType = isAutomaticTypeInNonNull ? getNonNullableType(getFlowTypeOfReference(node, type, initialType, flowContainer)) : getFlowTypeOfReference(node, type, initialType, flowContainer);
                if (!isEvolvingArrayOperationTarget(node) && (type === autoType || type === autoArrayType)) {
                    if (flowType === autoType || flowType === autoArrayType) {
                        if (noImplicitAny) {
                            error2(getNameOfDeclaration(declaration), Diagnostics.Variable_0_implicitly_has_type_1_in_some_locations_where_its_type_cannot_be_determined, symbolToString(symbol), typeToString(flowType));
                            error2(node, Diagnostics.Variable_0_implicitly_has_an_1_type, symbolToString(symbol), typeToString(flowType));
                        }
                        return convertAutoToAny(flowType);
                    }
                }
                else if (!assumeInitialized && !containsUndefinedType(type) && containsUndefinedType(flowType)) {
                    error2(node, Diagnostics.Variable_0_is_used_before_being_assigned, symbolToString(symbol));
                    return type;
                }
                return assignmentKind ? getBaseTypeOfLiteralType(flowType) : flowType;
            }
            function isSameScopedBindingElement(node, declaration) {
                if (isBindingElement(declaration)) {
                    const bindingElement = findAncestor(node, isBindingElement);
                    return bindingElement && getRootDeclaration(bindingElement) === getRootDeclaration(declaration);
                }
            }
            function shouldMarkIdentifierAliasReferenced(node) {
                var _a;
                const parent2 = node.parent;
                if (parent2) {
                    if (isPropertyAccessExpression(parent2) && parent2.expression === node) {
                        return false;
                    }
                    if (isExportSpecifier(parent2) && parent2.isTypeOnly) {
                        return false;
                    }
                    const greatGrandparent = (_a = parent2.parent) == null ? void 0 : _a.parent;
                    if (greatGrandparent && isExportDeclaration(greatGrandparent) && greatGrandparent.isTypeOnly) {
                        return false;
                    }
                }
                return true;
            }
            function isInsideFunctionOrInstancePropertyInitializer(node, threshold) {
                return !!findAncestor(node, (n) => n === threshold ? "quit" : isFunctionLike(n) || n.parent && isPropertyDeclaration(n.parent) && !hasStaticModifier(n.parent) && n.parent.initializer === n);
            }
            function getPartOfForStatementContainingNode(node, container) {
                return findAncestor(node, (n) => n === container ? "quit" : n === container.initializer || n === container.condition || n === container.incrementor || n === container.statement);
            }
            function getEnclosingIterationStatement(node) {
                return findAncestor(node, (n) => !n || nodeStartsNewLexicalEnvironment(n) ? "quit" : isIterationStatement(n, 
                /*lookInLabeledStatements*/
                false));
            }
            function checkNestedBlockScopedBinding(node, symbol) {
                if (languageVersion >= 2 /* ES2015 */ || (symbol.flags & (2 /* BlockScopedVariable */ | 32 /* Class */)) === 0 || !symbol.valueDeclaration || isSourceFile(symbol.valueDeclaration) || symbol.valueDeclaration.parent.kind === 299 /* CatchClause */) {
                    return;
                }
                const container = getEnclosingBlockScopeContainer(symbol.valueDeclaration);
                const isCaptured = isInsideFunctionOrInstancePropertyInitializer(node, container);
                const enclosingIterationStatement = getEnclosingIterationStatement(container);
                if (enclosingIterationStatement) {
                    if (isCaptured) {
                        let capturesBlockScopeBindingInLoopBody = true;
                        if (isForStatement(container)) {
                            const varDeclList = getAncestor(symbol.valueDeclaration, 261 /* VariableDeclarationList */);
                            if (varDeclList && varDeclList.parent === container) {
                                const part = getPartOfForStatementContainingNode(node.parent, container);
                                if (part) {
                                    const links = getNodeLinks(part);
                                    links.flags |= 8192 /* ContainsCapturedBlockScopeBinding */;
                                    const capturedBindings = links.capturedBlockScopeBindings || (links.capturedBlockScopeBindings = []);
                                    pushIfUnique(capturedBindings, symbol);
                                    if (part === container.initializer) {
                                        capturesBlockScopeBindingInLoopBody = false;
                                    }
                                }
                            }
                        }
                        if (capturesBlockScopeBindingInLoopBody) {
                            getNodeLinks(enclosingIterationStatement).flags |= 4096 /* LoopWithCapturedBlockScopedBinding */;
                        }
                    }
                    if (isForStatement(container)) {
                        const varDeclList = getAncestor(symbol.valueDeclaration, 261 /* VariableDeclarationList */);
                        if (varDeclList && varDeclList.parent === container && isAssignedInBodyOfForStatement(node, container)) {
                            getNodeLinks(symbol.valueDeclaration).flags |= 65536 /* NeedsLoopOutParameter */;
                        }
                    }
                    getNodeLinks(symbol.valueDeclaration).flags |= 32768 /* BlockScopedBindingInLoop */;
                }
                if (isCaptured) {
                    getNodeLinks(symbol.valueDeclaration).flags |= 16384 /* CapturedBlockScopedBinding */;
                }
            }
            function isBindingCapturedByNode(node, decl) {
                const links = getNodeLinks(node);
                return !!links && contains(links.capturedBlockScopeBindings, getSymbolOfDeclaration(decl));
            }
            function isAssignedInBodyOfForStatement(node, container) {
                let current = node;
                while (current.parent.kind === 217 /* ParenthesizedExpression */) {
                    current = current.parent;
                }
                let isAssigned = false;
                if (isAssignmentTarget(current)) {
                    isAssigned = true;
                }
                else if (current.parent.kind === 224 /* PrefixUnaryExpression */ || current.parent.kind === 225 /* PostfixUnaryExpression */) {
                    const expr = current.parent;
                    isAssigned = expr.operator === 46 /* PlusPlusToken */ || expr.operator === 47 /* MinusMinusToken */;
                }
                if (!isAssigned) {
                    return false;
                }
                return !!findAncestor(current, (n) => n === container ? "quit" : n === container.statement);
            }
            function captureLexicalThis(node, container) {
                getNodeLinks(node).flags |= 2 /* LexicalThis */;
                if (container.kind === 172 /* PropertyDeclaration */ || container.kind === 176 /* Constructor */) {
                    const classNode = container.parent;
                    getNodeLinks(classNode).flags |= 4 /* CaptureThis */;
                }
                else {
                    getNodeLinks(container).flags |= 4 /* CaptureThis */;
                }
            }
            function findFirstSuperCall(node) {
                return isSuperCall(node) ? node : isFunctionLike(node) ? void 0 : forEachChild(node, findFirstSuperCall);
            }
            function classDeclarationExtendsNull(classDecl) {
                const classSymbol = getSymbolOfDeclaration(classDecl);
                const classInstanceType = getDeclaredTypeOfSymbol(classSymbol);
                const baseConstructorType = getBaseConstructorTypeOfClass(classInstanceType);
                return baseConstructorType === nullWideningType;
            }
            function checkThisBeforeSuper(node, container, diagnosticMessage) {
                const containingClassDecl = container.parent;
                const baseTypeNode = getClassExtendsHeritageElement(containingClassDecl);
                if (baseTypeNode && !classDeclarationExtendsNull(containingClassDecl)) {
                    if (canHaveFlowNode(node) && node.flowNode && !isPostSuperFlowNode(node.flowNode, 
                    /*noCacheCheck*/
                    false)) {
                        error2(node, diagnosticMessage);
                    }
                }
            }
            function checkThisInStaticClassFieldInitializerInDecoratedClass(thisExpression, container) {
                if (isPropertyDeclaration(container) && hasStaticModifier(container) && legacyDecorators && container.initializer && textRangeContainsPositionInclusive(container.initializer, thisExpression.pos) && hasDecorators(container.parent)) {
                    error2(thisExpression, Diagnostics.Cannot_use_this_in_a_static_property_initializer_of_a_decorated_class);
                }
            }
            function checkThisExpression(node) {
                const isNodeInTypeQuery = isInTypeQuery(node);
                let container = getThisContainer(node, 
                /*includeArrowFunctions*/
                true, 
                /*includeClassComputedPropertyName*/
                true);
                let capturedByArrowFunction = false;
                let thisInComputedPropertyName = false;
                if (container.kind === 176 /* Constructor */) {
                    checkThisBeforeSuper(node, container, Diagnostics.super_must_be_called_before_accessing_this_in_the_constructor_of_a_derived_class);
                }
                while (true) {
                    if (container.kind === 219 /* ArrowFunction */) {
                        container = getThisContainer(container, 
                        /*includeArrowFunctions*/
                        false, !thisInComputedPropertyName);
                        capturedByArrowFunction = true;
                    }
                    if (container.kind === 167 /* ComputedPropertyName */) {
                        container = getThisContainer(container, !capturedByArrowFunction, 
                        /*includeClassComputedPropertyName*/
                        false);
                        thisInComputedPropertyName = true;
                        continue;
                    }
                    break;
                }
                checkThisInStaticClassFieldInitializerInDecoratedClass(node, container);
                if (thisInComputedPropertyName) {
                    error2(node, Diagnostics.this_cannot_be_referenced_in_a_computed_property_name);
                }
                else {
                    switch (container.kind) {
                        case 267 /* ModuleDeclaration */:
                            error2(node, Diagnostics.this_cannot_be_referenced_in_a_module_or_namespace_body);
                            break;
                        case 266 /* EnumDeclaration */:
                            error2(node, Diagnostics.this_cannot_be_referenced_in_current_location);
                            break;
                        case 176 /* Constructor */:
                            if (isInConstructorArgumentInitializer(node, container)) {
                                error2(node, Diagnostics.this_cannot_be_referenced_in_constructor_arguments);
                            }
                            break;
                    }
                }
                if (!isNodeInTypeQuery && capturedByArrowFunction && languageVersion < 2 /* ES2015 */) {
                    captureLexicalThis(node, container);
                }
                const type = tryGetThisTypeAt(node, 
                /*includeGlobalThis*/
                true, container);
                if (noImplicitThis) {
                    const globalThisType2 = getTypeOfSymbol(globalThisSymbol);
                    if (type === globalThisType2 && capturedByArrowFunction) {
                        error2(node, Diagnostics.The_containing_arrow_function_captures_the_global_value_of_this);
                    }
                    else if (!type) {
                        const diag2 = error2(node, Diagnostics.this_implicitly_has_type_any_because_it_does_not_have_a_type_annotation);
                        if (!isSourceFile(container)) {
                            const outsideThis = tryGetThisTypeAt(container);
                            if (outsideThis && outsideThis !== globalThisType2) {
                                addRelatedInfo(diag2, createDiagnosticForNode(container, Diagnostics.An_outer_value_of_this_is_shadowed_by_this_container));
                            }
                        }
                    }
                }
                return type || anyType;
            }
            function tryGetThisTypeAt(node, includeGlobalThis = true, container = getThisContainer(node, 
            /*includeArrowFunctions*/
            false, 
            /*includeClassComputedPropertyName*/
            false)) {
                const isInJS = isInJSFile(node);
                if (isFunctionLike(container) && (!isInParameterInitializerBeforeContainingFunction(node) || getThisParameter(container))) {
                    let thisType = getThisTypeOfDeclaration(container) || isInJS && getTypeForThisExpressionFromJSDoc(container);
                    if (!thisType) {
                        const className = getClassNameFromPrototypeMethod(container);
                        if (isInJS && className) {
                            const classSymbol = checkExpression(className).symbol;
                            if (classSymbol && classSymbol.members && classSymbol.flags & 16 /* Function */) {
                                thisType = getDeclaredTypeOfSymbol(classSymbol).thisType;
                            }
                        }
                        else if (isJSConstructor(container)) {
                            thisType = getDeclaredTypeOfSymbol(getMergedSymbol(container.symbol)).thisType;
                        }
                        thisType || (thisType = getContextualThisParameterType(container));
                    }
                    if (thisType) {
                        return getFlowTypeOfReference(node, thisType);
                    }
                }
                if (isClassLike(container.parent)) {
                    const symbol = getSymbolOfDeclaration(container.parent);
                    const type = isStatic(container) ? getTypeOfSymbol(symbol) : getDeclaredTypeOfSymbol(symbol).thisType;
                    return getFlowTypeOfReference(node, type);
                }
                if (isSourceFile(container)) {
                    if (container.commonJsModuleIndicator) {
                        const fileSymbol = getSymbolOfDeclaration(container);
                        return fileSymbol && getTypeOfSymbol(fileSymbol);
                    }
                    else if (container.externalModuleIndicator) {
                        return undefinedType;
                    }
                    else if (includeGlobalThis) {
                        return getTypeOfSymbol(globalThisSymbol);
                    }
                }
            }
            function getExplicitThisType(node) {
                const container = getThisContainer(node, 
                /*includeArrowFunctions*/
                false, 
                /*includeClassComputedPropertyName*/
                false);
                if (isFunctionLike(container)) {
                    const signature = getSignatureFromDeclaration(container);
                    if (signature.thisParameter) {
                        return getExplicitTypeOfSymbol(signature.thisParameter);
                    }
                }
                if (isClassLike(container.parent)) {
                    const symbol = getSymbolOfDeclaration(container.parent);
                    return isStatic(container) ? getTypeOfSymbol(symbol) : getDeclaredTypeOfSymbol(symbol).thisType;
                }
            }
            function getClassNameFromPrototypeMethod(container) {
                if (container.kind === 218 /* FunctionExpression */ && isBinaryExpression(container.parent) && getAssignmentDeclarationKind(container.parent) === 3 /* PrototypeProperty */) {
                    return container.parent.left.expression.expression;
                }
                else if (container.kind === 174 /* MethodDeclaration */ && container.parent.kind === 210 /* ObjectLiteralExpression */ && isBinaryExpression(container.parent.parent) && getAssignmentDeclarationKind(container.parent.parent) === 6 /* Prototype */) {
                    return container.parent.parent.left.expression;
                }
                else if (container.kind === 218 /* FunctionExpression */ && container.parent.kind === 303 /* PropertyAssignment */ && container.parent.parent.kind === 210 /* ObjectLiteralExpression */ && isBinaryExpression(container.parent.parent.parent) && getAssignmentDeclarationKind(container.parent.parent.parent) === 6 /* Prototype */) {
                    return container.parent.parent.parent.left.expression;
                }
                else if (container.kind === 218 /* FunctionExpression */ && isPropertyAssignment(container.parent) && isIdentifier(container.parent.name) && (container.parent.name.escapedText === "value" || container.parent.name.escapedText === "get" || container.parent.name.escapedText === "set") && isObjectLiteralExpression(container.parent.parent) && isCallExpression(container.parent.parent.parent) && container.parent.parent.parent.arguments[2] === container.parent.parent && getAssignmentDeclarationKind(container.parent.parent.parent) === 9 /* ObjectDefinePrototypeProperty */) {
                    return container.parent.parent.parent.arguments[0].expression;
                }
                else if (isMethodDeclaration(container) && isIdentifier(container.name) && (container.name.escapedText === "value" || container.name.escapedText === "get" || container.name.escapedText === "set") && isObjectLiteralExpression(container.parent) && isCallExpression(container.parent.parent) && container.parent.parent.arguments[2] === container.parent && getAssignmentDeclarationKind(container.parent.parent) === 9 /* ObjectDefinePrototypeProperty */) {
                    return container.parent.parent.arguments[0].expression;
                }
            }
            function getTypeForThisExpressionFromJSDoc(node) {
                const thisTag = getJSDocThisTag(node);
                if (thisTag && thisTag.typeExpression) {
                    return getTypeFromTypeNode(thisTag.typeExpression);
                }
                const signature = getSignatureOfTypeTag(node);
                if (signature) {
                    return getThisTypeOfSignature(signature);
                }
            }
            function isInConstructorArgumentInitializer(node, constructorDecl) {
                return !!findAncestor(node, (n) => isFunctionLikeDeclaration(n) ? "quit" : n.kind === 169 /* Parameter */ && n.parent === constructorDecl);
            }
            function checkSuperExpression(node) {
                const isCallExpression2 = node.parent.kind === 213 /* CallExpression */ && node.parent.expression === node;
                const immediateContainer = getSuperContainer(node, 
                /*stopOnFunctions*/
                true);
                let container = immediateContainer;
                let needToCaptureLexicalThis = false;
                let inAsyncFunction = false;
                if (!isCallExpression2) {
                    while (container && container.kind === 219 /* ArrowFunction */) {
                        if (hasSyntacticModifier(container, 1024 /* Async */))
                            inAsyncFunction = true;
                        container = getSuperContainer(container, 
                        /*stopOnFunctions*/
                        true);
                        needToCaptureLexicalThis = languageVersion < 2 /* ES2015 */;
                    }
                    if (container && hasSyntacticModifier(container, 1024 /* Async */))
                        inAsyncFunction = true;
                }
                let nodeCheckFlag = 0;
                if (!container || !isLegalUsageOfSuperExpression(container)) {
                    const current = findAncestor(node, (n) => n === container ? "quit" : n.kind === 167 /* ComputedPropertyName */);
                    if (current && current.kind === 167 /* ComputedPropertyName */) {
                        error2(node, Diagnostics.super_cannot_be_referenced_in_a_computed_property_name);
                    }
                    else if (isCallExpression2) {
                        error2(node, Diagnostics.Super_calls_are_not_permitted_outside_constructors_or_in_nested_functions_inside_constructors);
                    }
                    else if (!container || !container.parent || !(isClassLike(container.parent) || container.parent.kind === 210 /* ObjectLiteralExpression */)) {
                        error2(node, Diagnostics.super_can_only_be_referenced_in_members_of_derived_classes_or_object_literal_expressions);
                    }
                    else {
                        error2(node, Diagnostics.super_property_access_is_permitted_only_in_a_constructor_member_function_or_member_accessor_of_a_derived_class);
                    }
                    return errorType;
                }
                if (!isCallExpression2 && immediateContainer.kind === 176 /* Constructor */) {
                    checkThisBeforeSuper(node, container, Diagnostics.super_must_be_called_before_accessing_a_property_of_super_in_the_constructor_of_a_derived_class);
                }
                if (isStatic(container) || isCallExpression2) {
                    nodeCheckFlag = 32 /* SuperStatic */;
                    if (!isCallExpression2 && languageVersion >= 2 /* ES2015 */ && languageVersion <= 8 /* ES2021 */ && (isPropertyDeclaration(container) || isClassStaticBlockDeclaration(container))) {
                        forEachEnclosingBlockScopeContainer(node.parent, (current) => {
                            if (!isSourceFile(current) || isExternalOrCommonJsModule(current)) {
                                getNodeLinks(current).flags |= 2097152 /* ContainsSuperPropertyInStaticInitializer */;
                            }
                        });
                    }
                }
                else {
                    nodeCheckFlag = 16 /* SuperInstance */;
                }
                getNodeLinks(node).flags |= nodeCheckFlag;
                if (container.kind === 174 /* MethodDeclaration */ && inAsyncFunction) {
                    if (isSuperProperty(node.parent) && isAssignmentTarget(node.parent)) {
                        getNodeLinks(container).flags |= 256 /* MethodWithSuperPropertyAssignmentInAsync */;
                    }
                    else {
                        getNodeLinks(container).flags |= 128 /* MethodWithSuperPropertyAccessInAsync */;
                    }
                }
                if (needToCaptureLexicalThis) {
                    captureLexicalThis(node.parent, container);
                }
                if (container.parent.kind === 210 /* ObjectLiteralExpression */) {
                    if (languageVersion < 2 /* ES2015 */) {
                        error2(node, Diagnostics.super_is_only_allowed_in_members_of_object_literal_expressions_when_option_target_is_ES2015_or_higher);
                        return errorType;
                    }
                    else {
                        return anyType;
                    }
                }
                const classLikeDeclaration = container.parent;
                if (!getClassExtendsHeritageElement(classLikeDeclaration)) {
                    error2(node, Diagnostics.super_can_only_be_referenced_in_a_derived_class);
                    return errorType;
                }
                if (classDeclarationExtendsNull(classLikeDeclaration)) {
                    return isCallExpression2 ? errorType : nullWideningType;
                }
                const classType = getDeclaredTypeOfSymbol(getSymbolOfDeclaration(classLikeDeclaration));
                const baseClassType = classType && getBaseTypes(classType)[0];
                if (!baseClassType) {
                    return errorType;
                }
                if (container.kind === 176 /* Constructor */ && isInConstructorArgumentInitializer(node, container)) {
                    error2(node, Diagnostics.super_cannot_be_referenced_in_constructor_arguments);
                    return errorType;
                }
                return nodeCheckFlag === 32 /* SuperStatic */ ? getBaseConstructorTypeOfClass(classType) : getTypeWithThisArgument(baseClassType, classType.thisType);
                function isLegalUsageOfSuperExpression(container2) {
                    if (isCallExpression2) {
                        return container2.kind === 176 /* Constructor */;
                    }
                    else {
                        if (isClassLike(container2.parent) || container2.parent.kind === 210 /* ObjectLiteralExpression */) {
                            if (isStatic(container2)) {
                                return container2.kind === 174 /* MethodDeclaration */ || container2.kind === 173 /* MethodSignature */ || container2.kind === 177 /* GetAccessor */ || container2.kind === 178 /* SetAccessor */ || container2.kind === 172 /* PropertyDeclaration */ || container2.kind === 175 /* ClassStaticBlockDeclaration */;
                            }
                            else {
                                return container2.kind === 174 /* MethodDeclaration */ || container2.kind === 173 /* MethodSignature */ || container2.kind === 177 /* GetAccessor */ || container2.kind === 178 /* SetAccessor */ || container2.kind === 172 /* PropertyDeclaration */ || container2.kind === 171 /* PropertySignature */ || container2.kind === 176 /* Constructor */;
                            }
                        }
                    }
                    return false;
                }
            }
            function getContainingObjectLiteral(func) {
                return (func.kind === 174 /* MethodDeclaration */ || func.kind === 177 /* GetAccessor */ || func.kind === 178 /* SetAccessor */) && func.parent.kind === 210 /* ObjectLiteralExpression */ ? func.parent : func.kind === 218 /* FunctionExpression */ && func.parent.kind === 303 /* PropertyAssignment */ ? func.parent.parent : void 0;
            }
            function getThisTypeArgument(type) {
                return getObjectFlags(type) & 4 /* Reference */ && type.target === globalThisType ? getTypeArguments(type)[0] : void 0;
            }
            function getThisTypeFromContextualType(type) {
                return mapType(type, (t) => {
                    return t.flags & 2097152 /* Intersection */ ? forEach(t.types, getThisTypeArgument) : getThisTypeArgument(t);
                });
            }
            function getThisTypeOfObjectLiteralFromContextualType(containingLiteral, contextualType) {
                let literal = containingLiteral;
                let type = contextualType;
                while (type) {
                    const thisType = getThisTypeFromContextualType(type);
                    if (thisType) {
                        return thisType;
                    }
                    if (literal.parent.kind !== 303 /* PropertyAssignment */) {
                        break;
                    }
                    literal = literal.parent.parent;
                    type = getApparentTypeOfContextualType(literal, 
                    /*contextFlags*/
                    void 0);
                }
            }
            function getContextualThisParameterType(func) {
                if (func.kind === 219 /* ArrowFunction */) {
                    return void 0;
                }
                if (isContextSensitiveFunctionOrObjectLiteralMethod(func)) {
                    const contextualSignature = getContextualSignature(func);
                    if (contextualSignature) {
                        const thisParameter = contextualSignature.thisParameter;
                        if (thisParameter) {
                            return getTypeOfSymbol(thisParameter);
                        }
                    }
                }
                const inJs = isInJSFile(func);
                if (noImplicitThis || inJs) {
                    const containingLiteral = getContainingObjectLiteral(func);
                    if (containingLiteral) {
                        const contextualType = getApparentTypeOfContextualType(containingLiteral, 
                        /*contextFlags*/
                        void 0);
                        const thisType = getThisTypeOfObjectLiteralFromContextualType(containingLiteral, contextualType);
                        if (thisType) {
                            return instantiateType(thisType, getMapperFromContext(getInferenceContext(containingLiteral)));
                        }
                        return getWidenedType(contextualType ? getNonNullableType(contextualType) : checkExpressionCached(containingLiteral));
                    }
                    const parent2 = walkUpParenthesizedExpressions(func.parent);
                    if (isAssignmentExpression(parent2)) {
                        const target = parent2.left;
                        if (isAccessExpression(target)) {
                            const { expression } = target;
                            if (inJs && isIdentifier(expression)) {
                                const sourceFile = getSourceFileOfNode(parent2);
                                if (sourceFile.commonJsModuleIndicator && getResolvedSymbol(expression) === sourceFile.symbol) {
                                    return void 0;
                                }
                            }
                            return getWidenedType(checkExpressionCached(expression));
                        }
                    }
                }
                return void 0;
            }
            function getContextuallyTypedParameterType(parameter) {
                const func = parameter.parent;
                if (!isContextSensitiveFunctionOrObjectLiteralMethod(func)) {
                    return void 0;
                }
                const iife = getImmediatelyInvokedFunctionExpression(func);
                if (iife && iife.arguments) {
                    const args = getEffectiveCallArguments(iife);
                    const indexOfParameter = func.parameters.indexOf(parameter);
                    if (parameter.dotDotDotToken) {
                        return getSpreadArgumentType(args, indexOfParameter, args.length, anyType, 
                        /*context*/
                        void 0, 0 /* Normal */);
                    }
                    const links = getNodeLinks(iife);
                    const cached = links.resolvedSignature;
                    links.resolvedSignature = anySignature;
                    const type = indexOfParameter < args.length ? getWidenedLiteralType(checkExpression(args[indexOfParameter])) : parameter.initializer ? void 0 : undefinedWideningType;
                    links.resolvedSignature = cached;
                    return type;
                }
                const contextualSignature = getContextualSignature(func);
                if (contextualSignature) {
                    const index = func.parameters.indexOf(parameter) - (getThisParameter(func) ? 1 : 0);
                    return parameter.dotDotDotToken && lastOrUndefined(func.parameters) === parameter ? getRestTypeAtPosition(contextualSignature, index) : tryGetTypeAtPosition(contextualSignature, index);
                }
            }
            function getContextualTypeForVariableLikeDeclaration(declaration, contextFlags) {
                const typeNode = getEffectiveTypeAnnotationNode(declaration) || (isInJSFile(declaration) ? tryGetJSDocSatisfiesTypeNode(declaration) : void 0);
                if (typeNode) {
                    return getTypeFromTypeNode(typeNode);
                }
                switch (declaration.kind) {
                    case 169 /* Parameter */:
                        return getContextuallyTypedParameterType(declaration);
                    case 208 /* BindingElement */:
                        return getContextualTypeForBindingElement(declaration, contextFlags);
                    case 172 /* PropertyDeclaration */:
                        if (isStatic(declaration)) {
                            return getContextualTypeForStaticPropertyDeclaration(declaration, contextFlags);
                        }
                }
            }
            function getContextualTypeForBindingElement(declaration, contextFlags) {
                const parent2 = declaration.parent.parent;
                const name = declaration.propertyName || declaration.name;
                const parentType = getContextualTypeForVariableLikeDeclaration(parent2, contextFlags) || parent2.kind !== 208 /* BindingElement */ && parent2.initializer && checkDeclarationInitializer(parent2, declaration.dotDotDotToken ? 32 /* RestBindingElement */ : 0 /* Normal */);
                if (!parentType || isBindingPattern(name) || isComputedNonLiteralName(name))
                    return void 0;
                if (parent2.name.kind === 207 /* ArrayBindingPattern */) {
                    const index = indexOfNode(declaration.parent.elements, declaration);
                    if (index < 0)
                        return void 0;
                    return getContextualTypeForElementExpression(parentType, index);
                }
                const nameType = getLiteralTypeFromPropertyName(name);
                if (isTypeUsableAsPropertyName(nameType)) {
                    const text = getPropertyNameFromType(nameType);
                    return getTypeOfPropertyOfType(parentType, text);
                }
            }
            function getContextualTypeForStaticPropertyDeclaration(declaration, contextFlags) {
                const parentType = isExpression(declaration.parent) && getContextualType2(declaration.parent, contextFlags);
                if (!parentType)
                    return void 0;
                return getTypeOfPropertyOfContextualType(parentType, getSymbolOfDeclaration(declaration).escapedName);
            }
            function getContextualTypeForInitializerExpression(node, contextFlags) {
                const declaration = node.parent;
                if (hasInitializer(declaration) && node === declaration.initializer) {
                    const result = getContextualTypeForVariableLikeDeclaration(declaration, contextFlags);
                    if (result) {
                        return result;
                    }
                    if (!(contextFlags & 8 /* SkipBindingPatterns */) && isBindingPattern(declaration.name) && declaration.name.elements.length > 0) {
                        return getTypeFromBindingPattern(declaration.name, 
                        /*includePatternInType*/
                        true, 
                        /*reportErrors*/
                        false);
                    }
                }
                return void 0;
            }
            function getContextualTypeForReturnExpression(node, contextFlags) {
                const func = getContainingFunction(node);
                if (func) {
                    let contextualReturnType = getContextualReturnType(func, contextFlags);
                    if (contextualReturnType) {
                        const functionFlags = getFunctionFlags(func);
                        if (functionFlags & 1 /* Generator */) {
                            const isAsyncGenerator = (functionFlags & 2 /* Async */) !== 0;
                            if (contextualReturnType.flags & 1048576 /* Union */) {
                                contextualReturnType = filterType(contextualReturnType, (type) => !!getIterationTypeOfGeneratorFunctionReturnType(1 /* Return */, type, isAsyncGenerator));
                            }
                            const iterationReturnType = getIterationTypeOfGeneratorFunctionReturnType(1 /* Return */, contextualReturnType, (functionFlags & 2 /* Async */) !== 0);
                            if (!iterationReturnType) {
                                return void 0;
                            }
                            contextualReturnType = iterationReturnType;
                        }
                        if (functionFlags & 2 /* Async */) {
                            const contextualAwaitedType = mapType(contextualReturnType, getAwaitedTypeNoAlias);
                            return contextualAwaitedType && getUnionType([contextualAwaitedType, createPromiseLikeType(contextualAwaitedType)]);
                        }
                        return contextualReturnType;
                    }
                }
                return void 0;
            }
            function getContextualTypeForAwaitOperand(node, contextFlags) {
                const contextualType = getContextualType2(node, contextFlags);
                if (contextualType) {
                    const contextualAwaitedType = getAwaitedTypeNoAlias(contextualType);
                    return contextualAwaitedType && getUnionType([contextualAwaitedType, createPromiseLikeType(contextualAwaitedType)]);
                }
                return void 0;
            }
            function getContextualTypeForYieldOperand(node, contextFlags) {
                const func = getContainingFunction(node);
                if (func) {
                    const functionFlags = getFunctionFlags(func);
                    let contextualReturnType = getContextualReturnType(func, contextFlags);
                    if (contextualReturnType) {
                        const isAsyncGenerator = (functionFlags & 2 /* Async */) !== 0;
                        if (!node.asteriskToken && contextualReturnType.flags & 1048576 /* Union */) {
                            contextualReturnType = filterType(contextualReturnType, (type) => !!getIterationTypeOfGeneratorFunctionReturnType(1 /* Return */, type, isAsyncGenerator));
                        }
                        return node.asteriskToken ? contextualReturnType : getIterationTypeOfGeneratorFunctionReturnType(0 /* Yield */, contextualReturnType, isAsyncGenerator);
                    }
                }
                return void 0;
            }
            function isInParameterInitializerBeforeContainingFunction(node) {
                let inBindingInitializer = false;
                while (node.parent && !isFunctionLike(node.parent)) {
                    if (isParameter(node.parent) && (inBindingInitializer || node.parent.initializer === node)) {
                        return true;
                    }
                    if (isBindingElement(node.parent) && node.parent.initializer === node) {
                        inBindingInitializer = true;
                    }
                    node = node.parent;
                }
                return false;
            }
            function getContextualIterationType(kind, functionDecl) {
                const isAsync = !!(getFunctionFlags(functionDecl) & 2 /* Async */);
                const contextualReturnType = getContextualReturnType(functionDecl, 
                /*contextFlags*/
                void 0);
                if (contextualReturnType) {
                    return getIterationTypeOfGeneratorFunctionReturnType(kind, contextualReturnType, isAsync) || void 0;
                }
                return void 0;
            }
            function getContextualReturnType(functionDecl, contextFlags) {
                const returnType = getReturnTypeFromAnnotation(functionDecl);
                if (returnType) {
                    return returnType;
                }
                const signature = getContextualSignatureForFunctionLikeDeclaration(functionDecl);
                if (signature && !isResolvingReturnTypeOfSignature(signature)) {
                    const returnType2 = getReturnTypeOfSignature(signature);
                    const functionFlags = getFunctionFlags(functionDecl);
                    if (functionFlags & 1 /* Generator */) {
                        return filterType(returnType2, (t) => {
                            return !!(t.flags & (3 /* AnyOrUnknown */ | 16384 /* Void */ | 58982400 /* InstantiableNonPrimitive */)) || checkGeneratorInstantiationAssignabilityToReturnType(t, functionFlags, 
                            /*errorNode*/
                            void 0);
                        });
                    }
                    if (functionFlags & 2 /* Async */) {
                        return filterType(returnType2, (t) => {
                            return !!(t.flags & (3 /* AnyOrUnknown */ | 16384 /* Void */ | 58982400 /* InstantiableNonPrimitive */)) || !!getAwaitedTypeOfPromise(t);
                        });
                    }
                    return returnType2;
                }
                const iife = getImmediatelyInvokedFunctionExpression(functionDecl);
                if (iife) {
                    return getContextualType2(iife, contextFlags);
                }
                return void 0;
            }
            function getContextualTypeForArgument(callTarget, arg) {
                const args = getEffectiveCallArguments(callTarget);
                const argIndex = args.indexOf(arg);
                return argIndex === -1 ? void 0 : getContextualTypeForArgumentAtIndex(callTarget, argIndex);
            }
            function getContextualTypeForArgumentAtIndex(callTarget, argIndex) {
                if (isImportCall(callTarget)) {
                    return argIndex === 0 ? stringType : argIndex === 1 ? getGlobalImportCallOptionsType(
                    /*reportErrors*/
                    false) : anyType;
                }
                const signature = getNodeLinks(callTarget).resolvedSignature === resolvingSignature ? resolvingSignature : getResolvedSignature(callTarget);
                if (isJsxOpeningLikeElement(callTarget) && argIndex === 0) {
                    return getEffectiveFirstArgumentForJsxSignature(signature, callTarget);
                }
                const restIndex = signature.parameters.length - 1;
                return signatureHasRestParameter(signature) && argIndex >= restIndex ? getIndexedAccessType(getTypeOfSymbol(signature.parameters[restIndex]), getNumberLiteralType(argIndex - restIndex), 256 /* Contextual */) : getTypeAtPosition(signature, argIndex);
            }
            function getContextualTypeForDecorator(decorator) {
                const signature = getDecoratorCallSignature(decorator);
                return signature ? getOrCreateTypeFromSignature(signature) : void 0;
            }
            function getContextualTypeForSubstitutionExpression(template, substitutionExpression) {
                if (template.parent.kind === 215 /* TaggedTemplateExpression */) {
                    return getContextualTypeForArgument(template.parent, substitutionExpression);
                }
                return void 0;
            }
            function getContextualTypeForBinaryOperand(node, contextFlags) {
                const binaryExpression = node.parent;
                const { left, operatorToken, right } = binaryExpression;
                switch (operatorToken.kind) {
                    case 64 /* EqualsToken */:
                    case 77 /* AmpersandAmpersandEqualsToken */:
                    case 76 /* BarBarEqualsToken */:
                    case 78 /* QuestionQuestionEqualsToken */:
                        return node === right ? getContextualTypeForAssignmentDeclaration(binaryExpression) : void 0;
                    case 57 /* BarBarToken */:
                    case 61 /* QuestionQuestionToken */:
                        const type = getContextualType2(binaryExpression, contextFlags);
                        return node === right && (type && type.pattern || !type && !isDefaultedExpandoInitializer(binaryExpression)) ? getTypeOfExpression(left) : type;
                    case 56 /* AmpersandAmpersandToken */:
                    case 28 /* CommaToken */:
                        return node === right ? getContextualType2(binaryExpression, contextFlags) : void 0;
                    default:
                        return void 0;
                }
            }
            function getSymbolForExpression(e) {
                if (canHaveSymbol(e) && e.symbol) {
                    return e.symbol;
                }
                if (isIdentifier(e)) {
                    return getResolvedSymbol(e);
                }
                if (isPropertyAccessExpression(e)) {
                    const lhsType = getTypeOfExpression(e.expression);
                    return isPrivateIdentifier(e.name) ? tryGetPrivateIdentifierPropertyOfType(lhsType, e.name) : getPropertyOfType(lhsType, e.name.escapedText);
                }
                if (isElementAccessExpression(e)) {
                    const propType = checkExpressionCached(e.argumentExpression);
                    if (!isTypeUsableAsPropertyName(propType)) {
                        return void 0;
                    }
                    const lhsType = getTypeOfExpression(e.expression);
                    return getPropertyOfType(lhsType, getPropertyNameFromType(propType));
                }
                return void 0;
                function tryGetPrivateIdentifierPropertyOfType(type, id) {
                    const lexicallyScopedSymbol = lookupSymbolForPrivateIdentifierDeclaration(id.escapedText, id);
                    return lexicallyScopedSymbol && getPrivateIdentifierPropertyOfType(type, lexicallyScopedSymbol);
                }
            }
            function getContextualTypeForAssignmentDeclaration(binaryExpression) {
                var _a, _b;
                const kind = getAssignmentDeclarationKind(binaryExpression);
                switch (kind) {
                    case 0 /* None */:
                    case 4 /* ThisProperty */:
                        const lhsSymbol = getSymbolForExpression(binaryExpression.left);
                        const decl = lhsSymbol && lhsSymbol.valueDeclaration;
                        if (decl && (isPropertyDeclaration(decl) || isPropertySignature(decl))) {
                            const overallAnnotation = getEffectiveTypeAnnotationNode(decl);
                            return overallAnnotation && instantiateType(getTypeFromTypeNode(overallAnnotation), getSymbolLinks(lhsSymbol).mapper) || (isPropertyDeclaration(decl) ? decl.initializer && getTypeOfExpression(binaryExpression.left) : void 0);
                        }
                        if (kind === 0 /* None */) {
                            return getTypeOfExpression(binaryExpression.left);
                        }
                        return getContextualTypeForThisPropertyAssignment(binaryExpression);
                    case 5 /* Property */:
                        if (isPossiblyAliasedThisProperty(binaryExpression, kind)) {
                            return getContextualTypeForThisPropertyAssignment(binaryExpression);
                        }
                        else if (!canHaveSymbol(binaryExpression.left) || !binaryExpression.left.symbol) {
                            return getTypeOfExpression(binaryExpression.left);
                        }
                        else {
                            const decl2 = binaryExpression.left.symbol.valueDeclaration;
                            if (!decl2) {
                                return void 0;
                            }
                            const lhs = cast(binaryExpression.left, isAccessExpression);
                            const overallAnnotation = getEffectiveTypeAnnotationNode(decl2);
                            if (overallAnnotation) {
                                return getTypeFromTypeNode(overallAnnotation);
                            }
                            else if (isIdentifier(lhs.expression)) {
                                const id = lhs.expression;
                                const parentSymbol = resolveName(id, id.escapedText, 111551 /* Value */, 
                                /*nameNotFoundMessage*/
                                void 0, id.escapedText, 
                                /*isUse*/
                                true);
                                if (parentSymbol) {
                                    const annotated2 = parentSymbol.valueDeclaration && getEffectiveTypeAnnotationNode(parentSymbol.valueDeclaration);
                                    if (annotated2) {
                                        const nameStr = getElementOrPropertyAccessName(lhs);
                                        if (nameStr !== void 0) {
                                            return getTypeOfPropertyOfContextualType(getTypeFromTypeNode(annotated2), nameStr);
                                        }
                                    }
                                    return void 0;
                                }
                            }
                            return isInJSFile(decl2) || decl2 === binaryExpression.left ? void 0 : getTypeOfExpression(binaryExpression.left);
                        }
                    case 1 /* ExportsProperty */:
                    case 6 /* Prototype */:
                    case 3 /* PrototypeProperty */:
                    case 2 /* ModuleExports */:
                        let valueDeclaration;
                        if (kind !== 2 /* ModuleExports */) {
                            valueDeclaration = canHaveSymbol(binaryExpression.left) ? (_a = binaryExpression.left.symbol) == null ? void 0 : _a.valueDeclaration : void 0;
                        }
                        valueDeclaration || (valueDeclaration = (_b = binaryExpression.symbol) == null ? void 0 : _b.valueDeclaration);
                        const annotated = valueDeclaration && getEffectiveTypeAnnotationNode(valueDeclaration);
                        return annotated ? getTypeFromTypeNode(annotated) : void 0;
                    case 7 /* ObjectDefinePropertyValue */:
                    case 8 /* ObjectDefinePropertyExports */:
                    case 9 /* ObjectDefinePrototypeProperty */:
                        return Debug.fail("Does not apply");
                    default:
                        return Debug.assertNever(kind);
                }
            }
            function isPossiblyAliasedThisProperty(declaration, kind = getAssignmentDeclarationKind(declaration)) {
                if (kind === 4 /* ThisProperty */) {
                    return true;
                }
                if (!isInJSFile(declaration) || kind !== 5 /* Property */ || !isIdentifier(declaration.left.expression)) {
                    return false;
                }
                const name = declaration.left.expression.escapedText;
                const symbol = resolveName(declaration.left, name, 111551 /* Value */, 
                /*nameNotFoundMessage*/
                void 0, 
                /*nameArg*/
                void 0, 
                /*isUse*/
                true, 
                /*excludeGlobals*/
                true);
                return isThisInitializedDeclaration(symbol == null ? void 0 : symbol.valueDeclaration);
            }
            function getContextualTypeForThisPropertyAssignment(binaryExpression) {
                if (!binaryExpression.symbol)
                    return getTypeOfExpression(binaryExpression.left);
                if (binaryExpression.symbol.valueDeclaration) {
                    const annotated = getEffectiveTypeAnnotationNode(binaryExpression.symbol.valueDeclaration);
                    if (annotated) {
                        const type = getTypeFromTypeNode(annotated);
                        if (type) {
                            return type;
                        }
                    }
                }
                const thisAccess = cast(binaryExpression.left, isAccessExpression);
                if (!isObjectLiteralMethod(getThisContainer(thisAccess.expression, 
                /*includeArrowFunctions*/
                false, 
                /*includeClassComputedPropertyName*/
                false))) {
                    return void 0;
                }
                const thisType = checkThisExpression(thisAccess.expression);
                const nameStr = getElementOrPropertyAccessName(thisAccess);
                return nameStr !== void 0 && getTypeOfPropertyOfContextualType(thisType, nameStr) || void 0;
            }
            function isCircularMappedProperty(symbol) {
                return !!(getCheckFlags(symbol) & 262144 /* Mapped */ && !symbol.links.type && findResolutionCycleStartIndex(symbol, 0 /* Type */) >= 0);
            }
            function getTypeOfPropertyOfContextualType(type, name, nameType) {
                return mapType(type, (t) => {
                    var _a;
                    if (isGenericMappedType(t) && !t.declaration.nameType) {
                        const constraint = getConstraintTypeFromMappedType(t);
                        const constraintOfConstraint = getBaseConstraintOfType(constraint) || constraint;
                        const propertyNameType = nameType || getStringLiteralType(unescapeLeadingUnderscores(name));
                        if (isTypeAssignableTo(propertyNameType, constraintOfConstraint)) {
                            return substituteIndexedMappedType(t, propertyNameType);
                        }
                    }
                    else if (t.flags & 3670016 /* StructuredType */) {
                        const prop = getPropertyOfType(t, name);
                        if (prop) {
                            return isCircularMappedProperty(prop) ? void 0 : removeMissingType(getTypeOfSymbol(prop), !!(prop && prop.flags & 16777216 /* Optional */));
                        }
                        if (isTupleType(t) && isNumericLiteralName(name) && +name >= 0) {
                            const restType = getElementTypeOfSliceOfTupleType(t, t.target.fixedLength, 
                            /*endSkipCount*/
                            0, 
                            /*writing*/
                            false, 
                            /*noReductions*/
                            true);
                            if (restType) {
                                return restType;
                            }
                        }
                        return (_a = findApplicableIndexInfo(getIndexInfosOfStructuredType(t), nameType || getStringLiteralType(unescapeLeadingUnderscores(name)))) == null ? void 0 : _a.type;
                    }
                    return void 0;
                }, 
                /*noReductions*/
                true);
            }
            function getContextualTypeForObjectLiteralMethod(node, contextFlags) {
                Debug.assert(isObjectLiteralMethod(node));
                if (node.flags & 67108864 /* InWithStatement */) {
                    return void 0;
                }
                return getContextualTypeForObjectLiteralElement(node, contextFlags);
            }
            function getContextualTypeForObjectLiteralElement(element, contextFlags) {
                const objectLiteral = element.parent;
                const propertyAssignmentType = isPropertyAssignment(element) && getContextualTypeForVariableLikeDeclaration(element, contextFlags);
                if (propertyAssignmentType) {
                    return propertyAssignmentType;
                }
                const type = getApparentTypeOfContextualType(objectLiteral, contextFlags);
                if (type) {
                    if (hasBindableName(element)) {
                        const symbol = getSymbolOfDeclaration(element);
                        return getTypeOfPropertyOfContextualType(type, symbol.escapedName, getSymbolLinks(symbol).nameType);
                    }
                    if (hasDynamicName(element)) {
                        const name = getNameOfDeclaration(element);
                        if (name && isComputedPropertyName(name)) {
                            const exprType = checkExpression(name.expression);
                            const propType = isTypeUsableAsPropertyName(exprType) && getTypeOfPropertyOfContextualType(type, getPropertyNameFromType(exprType));
                            if (propType) {
                                return propType;
                            }
                        }
                    }
                    if (element.name) {
                        const nameType = getLiteralTypeFromPropertyName(element.name);
                        return mapType(type, (t) => {
                            var _a;
                            return (_a = findApplicableIndexInfo(getIndexInfosOfStructuredType(t), nameType)) == null ? void 0 : _a.type;
                        }, 
                        /*noReductions*/
                        true);
                    }
                }
                return void 0;
            }
            function getSpreadIndices(elements) {
                let first2, last2;
                for (let i = 0; i < elements.length; i++) {
                    if (isSpreadElement(elements[i])) {
                        first2 ?? (first2 = i);
                        last2 = i;
                    }
                }
                return { first: first2, last: last2 };
            }
            function getContextualTypeForElementExpression(type, index, length2, firstSpreadIndex, lastSpreadIndex) {
                return type && mapType(type, (t) => {
                    if (isTupleType(t)) {
                        if ((firstSpreadIndex === void 0 || index < firstSpreadIndex) && index < t.target.fixedLength) {
                            return removeMissingType(getTypeArguments(t)[index], !!(t.target.elementFlags[index] && 2 /* Optional */));
                        }
                        const offset = length2 !== void 0 && (lastSpreadIndex === void 0 || index > lastSpreadIndex) ? length2 - index : 0;
                        const fixedEndLength = offset > 0 && t.target.hasRestElement ? getEndElementCount(t.target, 3 /* Fixed */) : 0;
                        if (offset > 0 && offset <= fixedEndLength) {
                            return getTypeArguments(t)[getTypeReferenceArity(t) - offset];
                        }
                        return getElementTypeOfSliceOfTupleType(t, firstSpreadIndex === void 0 ? t.target.fixedLength : Math.min(t.target.fixedLength, firstSpreadIndex), length2 === void 0 || lastSpreadIndex === void 0 ? fixedEndLength : Math.min(fixedEndLength, length2 - lastSpreadIndex), 
                        /*writing*/
                        false, 
                        /*noReductions*/
                        true);
                    }
                    return (!firstSpreadIndex || index < firstSpreadIndex) && getTypeOfPropertyOfContextualType(t, "" + index) || getIteratedTypeOrElementType(1 /* Element */, t, undefinedType, 
                    /*errorNode*/
                    void 0, 
                    /*checkAssignability*/
                    false);
                }, 
                /*noReductions*/
                true);
            }
            function getContextualTypeForConditionalOperand(node, contextFlags) {
                const conditional = node.parent;
                return node === conditional.whenTrue || node === conditional.whenFalse ? getContextualType2(conditional, contextFlags) : void 0;
            }
            function getContextualTypeForChildJsxExpression(node, child, contextFlags) {
                const attributesType = getApparentTypeOfContextualType(node.openingElement.attributes, contextFlags);
                const jsxChildrenPropertyName = getJsxElementChildrenPropertyName(getJsxNamespaceAt(node));
                if (!(attributesType && !isTypeAny(attributesType) && jsxChildrenPropertyName && jsxChildrenPropertyName !== "")) {
                    return void 0;
                }
                const realChildren = getSemanticJsxChildren(node.children);
                const childIndex = realChildren.indexOf(child);
                const childFieldType = getTypeOfPropertyOfContextualType(attributesType, jsxChildrenPropertyName);
                return childFieldType && (realChildren.length === 1 ? childFieldType : mapType(childFieldType, (t) => {
                    if (isArrayLikeType(t)) {
                        return getIndexedAccessType(t, getNumberLiteralType(childIndex));
                    }
                    else {
                        return t;
                    }
                }, 
                /*noReductions*/
                true));
            }
            function getContextualTypeForJsxExpression(node, contextFlags) {
                const exprParent = node.parent;
                return isJsxAttributeLike(exprParent) ? getContextualType2(node, contextFlags) : isJsxElement(exprParent) ? getContextualTypeForChildJsxExpression(exprParent, node, contextFlags) : void 0;
            }
            function getContextualTypeForJsxAttribute(attribute, contextFlags) {
                if (isJsxAttribute(attribute)) {
                    const attributesType = getApparentTypeOfContextualType(attribute.parent, contextFlags);
                    if (!attributesType || isTypeAny(attributesType)) {
                        return void 0;
                    }
                    return getTypeOfPropertyOfContextualType(attributesType, getEscapedTextOfJsxAttributeName(attribute.name));
                }
                else {
                    return getContextualType2(attribute.parent, contextFlags);
                }
            }
            function isPossiblyDiscriminantValue(node) {
                switch (node.kind) {
                    case 11 /* StringLiteral */:
                    case 9 /* NumericLiteral */:
                    case 10 /* BigIntLiteral */:
                    case 15 /* NoSubstitutionTemplateLiteral */:
                    case 228 /* TemplateExpression */:
                    case 112 /* TrueKeyword */:
                    case 97 /* FalseKeyword */:
                    case 106 /* NullKeyword */:
                    case 80 /* Identifier */:
                    case 157 /* UndefinedKeyword */:
                        return true;
                    case 211 /* PropertyAccessExpression */:
                    case 217 /* ParenthesizedExpression */:
                        return isPossiblyDiscriminantValue(node.expression);
                    case 294 /* JsxExpression */:
                        return !node.expression || isPossiblyDiscriminantValue(node.expression);
                }
                return false;
            }
            function discriminateContextualTypeByObjectMembers(node, contextualType) {
                return getMatchingUnionConstituentForObjectLiteral(contextualType, node) || discriminateTypeByDiscriminableItems(contextualType, concatenate(map(filter(node.properties, (p) => {
                    if (!p.symbol) {
                        return false;
                    }
                    if (p.kind === 303 /* PropertyAssignment */) {
                        return isPossiblyDiscriminantValue(p.initializer) && isDiscriminantProperty(contextualType, p.symbol.escapedName);
                    }
                    if (p.kind === 304 /* ShorthandPropertyAssignment */) {
                        return isDiscriminantProperty(contextualType, p.symbol.escapedName);
                    }
                    return false;
                }), (prop) => [() => getContextFreeTypeOfExpression(prop.kind === 303 /* PropertyAssignment */ ? prop.initializer : prop.name), prop.symbol.escapedName]), map(filter(getPropertiesOfType(contextualType), (s) => {
                    var _a;
                    return !!(s.flags & 16777216 /* Optional */) && !!((_a = node == null ? void 0 : node.symbol) == null ? void 0 : _a.members) && !node.symbol.members.has(s.escapedName) && isDiscriminantProperty(contextualType, s.escapedName);
                }), (s) => [() => undefinedType, s.escapedName])), isTypeAssignableTo);
            }
            function discriminateContextualTypeByJSXAttributes(node, contextualType) {
                const jsxChildrenPropertyName = getJsxElementChildrenPropertyName(getJsxNamespaceAt(node));
                return discriminateTypeByDiscriminableItems(contextualType, concatenate(map(filter(node.properties, (p) => !!p.symbol && p.kind === 291 /* JsxAttribute */ && isDiscriminantProperty(contextualType, p.symbol.escapedName) && (!p.initializer || isPossiblyDiscriminantValue(p.initializer))), (prop) => [!prop.initializer ? () => trueType : () => getContextFreeTypeOfExpression(prop.initializer), prop.symbol.escapedName]), map(filter(getPropertiesOfType(contextualType), (s) => {
                    var _a;
                    if (!(s.flags & 16777216 /* Optional */) || !((_a = node == null ? void 0 : node.symbol) == null ? void 0 : _a.members)) {
                        return false;
                    }
                    const element = node.parent.parent;
                    if (s.escapedName === jsxChildrenPropertyName && isJsxElement(element) && getSemanticJsxChildren(element.children).length) {
                        return false;
                    }
                    return !node.symbol.members.has(s.escapedName) && isDiscriminantProperty(contextualType, s.escapedName);
                }), (s) => [() => undefinedType, s.escapedName])), isTypeAssignableTo);
            }
            function getApparentTypeOfContextualType(node, contextFlags) {
                const contextualType = isObjectLiteralMethod(node) ? getContextualTypeForObjectLiteralMethod(node, contextFlags) : getContextualType2(node, contextFlags);
                const instantiatedType = instantiateContextualType(contextualType, node, contextFlags);
                if (instantiatedType && !(contextFlags && contextFlags & 2 /* NoConstraints */ && instantiatedType.flags & 8650752 /* TypeVariable */)) {
                    const apparentType = mapType(instantiatedType, 
                    // When obtaining apparent type of *contextual* type we don't want to get apparent type of mapped types.
                    // That would evaluate mapped types with array or tuple type constraints too eagerly
                    // and thus it would prevent `getTypeOfPropertyOfContextualType` from obtaining per-position contextual type for elements of array literal expressions.
                    // Apparent type of other mapped types is already the mapped type itself so we can just avoid calling `getApparentType` here for all mapped types.
                    (t) => getObjectFlags(t) & 32 /* Mapped */ ? t : getApparentType(t), 
                    /*noReductions*/
                    true);
                    return apparentType.flags & 1048576 /* Union */ && isObjectLiteralExpression(node) ? discriminateContextualTypeByObjectMembers(node, apparentType) : apparentType.flags & 1048576 /* Union */ && isJsxAttributes(node) ? discriminateContextualTypeByJSXAttributes(node, apparentType) : apparentType;
                }
            }
            function instantiateContextualType(contextualType, node, contextFlags) {
                if (contextualType && maybeTypeOfKind(contextualType, 465829888 /* Instantiable */)) {
                    const inferenceContext = getInferenceContext(node);
                    if (inferenceContext && contextFlags & 1 /* Signature */ && some(inferenceContext.inferences, hasInferenceCandidatesOrDefault)) {
                        return instantiateInstantiableTypes(contextualType, inferenceContext.nonFixingMapper);
                    }
                    if (inferenceContext == null ? void 0 : inferenceContext.returnMapper) {
                        const type = instantiateInstantiableTypes(contextualType, inferenceContext.returnMapper);
                        return type.flags & 1048576 /* Union */ && containsType(type.types, regularFalseType) && containsType(type.types, regularTrueType) ? filterType(type, (t) => t !== regularFalseType && t !== regularTrueType) : type;
                    }
                }
                return contextualType;
            }
            function instantiateInstantiableTypes(type, mapper) {
                if (type.flags & 465829888 /* Instantiable */) {
                    return instantiateType(type, mapper);
                }
                if (type.flags & 1048576 /* Union */) {
                    return getUnionType(map(type.types, (t) => instantiateInstantiableTypes(t, mapper)), 0 /* None */);
                }
                if (type.flags & 2097152 /* Intersection */) {
                    return getIntersectionType(map(type.types, (t) => instantiateInstantiableTypes(t, mapper)));
                }
                return type;
            }
            function getContextualType2(node, contextFlags) {
                var _a;
                if (node.flags & 67108864 /* InWithStatement */) {
                    return void 0;
                }
                const index = findContextualNode(node, 
                /*includeCaches*/
                !contextFlags);
                if (index >= 0) {
                    return contextualTypes[index];
                }
                const { parent: parent2 } = node;
                switch (parent2.kind) {
                    case 260 /* VariableDeclaration */:
                    case 169 /* Parameter */:
                    case 172 /* PropertyDeclaration */:
                    case 171 /* PropertySignature */:
                    case 208 /* BindingElement */:
                        return getContextualTypeForInitializerExpression(node, contextFlags);
                    case 219 /* ArrowFunction */:
                    case 253 /* ReturnStatement */:
                        return getContextualTypeForReturnExpression(node, contextFlags);
                    case 229 /* YieldExpression */:
                        return getContextualTypeForYieldOperand(parent2, contextFlags);
                    case 223 /* AwaitExpression */:
                        return getContextualTypeForAwaitOperand(parent2, contextFlags);
                    case 213 /* CallExpression */:
                    case 214 /* NewExpression */:
                        return getContextualTypeForArgument(parent2, node);
                    case 170 /* Decorator */:
                        return getContextualTypeForDecorator(parent2);
                    case 216 /* TypeAssertionExpression */:
                    case 234 /* AsExpression */:
                        return isConstTypeReference(parent2.type) ? getContextualType2(parent2, contextFlags) : getTypeFromTypeNode(parent2.type);
                    case 226 /* BinaryExpression */:
                        return getContextualTypeForBinaryOperand(node, contextFlags);
                    case 303 /* PropertyAssignment */:
                    case 304 /* ShorthandPropertyAssignment */:
                        return getContextualTypeForObjectLiteralElement(parent2, contextFlags);
                    case 305 /* SpreadAssignment */:
                        return getContextualType2(parent2.parent, contextFlags);
                    case 209 /* ArrayLiteralExpression */: {
                        const arrayLiteral = parent2;
                        const type = getApparentTypeOfContextualType(arrayLiteral, contextFlags);
                        const elementIndex = indexOfNode(arrayLiteral.elements, node);
                        const spreadIndices = (_a = getNodeLinks(arrayLiteral)).spreadIndices ?? (_a.spreadIndices = getSpreadIndices(arrayLiteral.elements));
                        return getContextualTypeForElementExpression(type, elementIndex, arrayLiteral.elements.length, spreadIndices.first, spreadIndices.last);
                    }
                    case 227 /* ConditionalExpression */:
                        return getContextualTypeForConditionalOperand(node, contextFlags);
                    case 239 /* TemplateSpan */:
                        Debug.assert(parent2.parent.kind === 228 /* TemplateExpression */);
                        return getContextualTypeForSubstitutionExpression(parent2.parent, node);
                    case 217 /* ParenthesizedExpression */: {
                        if (isInJSFile(parent2)) {
                            if (isJSDocSatisfiesExpression(parent2)) {
                                return getTypeFromTypeNode(getJSDocSatisfiesExpressionType(parent2));
                            }
                            const typeTag = getJSDocTypeTag(parent2);
                            if (typeTag && !isConstTypeReference(typeTag.typeExpression.type)) {
                                return getTypeFromTypeNode(typeTag.typeExpression.type);
                            }
                        }
                        return getContextualType2(parent2, contextFlags);
                    }
                    case 235 /* NonNullExpression */:
                        return getContextualType2(parent2, contextFlags);
                    case 238 /* SatisfiesExpression */:
                        return getTypeFromTypeNode(parent2.type);
                    case 277 /* ExportAssignment */:
                        return tryGetTypeFromEffectiveTypeNode(parent2);
                    case 294 /* JsxExpression */:
                        return getContextualTypeForJsxExpression(parent2, contextFlags);
                    case 291 /* JsxAttribute */:
                    case 293 /* JsxSpreadAttribute */:
                        return getContextualTypeForJsxAttribute(parent2, contextFlags);
                    case 286 /* JsxOpeningElement */:
                    case 285 /* JsxSelfClosingElement */:
                        return getContextualJsxElementAttributesType(parent2, contextFlags);
                    case 301 /* ImportAttribute */:
                        return getContextualImportAttributeType(parent2);
                }
                return void 0;
            }
            function pushCachedContextualType(node) {
                pushContextualType(node, getContextualType2(node, 
                /*contextFlags*/
                void 0), 
                /*isCache*/
                true);
            }
            function pushContextualType(node, type, isCache) {
                contextualTypeNodes[contextualTypeCount] = node;
                contextualTypes[contextualTypeCount] = type;
                contextualIsCache[contextualTypeCount] = isCache;
                contextualTypeCount++;
            }
            function popContextualType() {
                contextualTypeCount--;
            }
            function findContextualNode(node, includeCaches) {
                for (let i = contextualTypeCount - 1; i >= 0; i--) {
                    if (node === contextualTypeNodes[i] && (includeCaches || !contextualIsCache[i])) {
                        return i;
                    }
                }
                return -1;
            }
            function pushInferenceContext(node, inferenceContext) {
                inferenceContextNodes[inferenceContextCount] = node;
                inferenceContexts[inferenceContextCount] = inferenceContext;
                inferenceContextCount++;
            }
            function popInferenceContext() {
                inferenceContextCount--;
            }
            function getInferenceContext(node) {
                for (let i = inferenceContextCount - 1; i >= 0; i--) {
                    if (isNodeDescendantOf(node, inferenceContextNodes[i])) {
                        return inferenceContexts[i];
                    }
                }
            }
            function getContextualImportAttributeType(node) {
                return getTypeOfPropertyOfContextualType(getGlobalImportAttributesType(
                /*reportErrors*/
                false), getNameFromImportAttribute(node));
            }
            function getContextualJsxElementAttributesType(node, contextFlags) {
                if (isJsxOpeningElement(node) && contextFlags !== 4 /* Completions */) {
                    const index = findContextualNode(node.parent, 
                    /*includeCaches*/
                    !contextFlags);
                    if (index >= 0) {
                        return contextualTypes[index];
                    }
                }
                return getContextualTypeForArgumentAtIndex(node, 0);
            }
            function getEffectiveFirstArgumentForJsxSignature(signature, node) {
                return getJsxReferenceKind(node) !== 0 /* Component */ ? getJsxPropsTypeFromCallSignature(signature, node) : getJsxPropsTypeFromClassType(signature, node);
            }
            function getJsxPropsTypeFromCallSignature(sig, context) {
                let propsType = getTypeOfFirstParameterOfSignatureWithFallback(sig, unknownType);
                propsType = getJsxManagedAttributesFromLocatedAttributes(context, getJsxNamespaceAt(context), propsType);
                const intrinsicAttribs = getJsxType(JsxNames.IntrinsicAttributes, context);
                if (!isErrorType(intrinsicAttribs)) {
                    propsType = intersectTypes(intrinsicAttribs, propsType);
                }
                return propsType;
            }
            function getJsxPropsTypeForSignatureFromMember(sig, forcedLookupLocation) {
                if (sig.compositeSignatures) {
                    const results = [];
                    for (const signature of sig.compositeSignatures) {
                        const instance = getReturnTypeOfSignature(signature);
                        if (isTypeAny(instance)) {
                            return instance;
                        }
                        const propType = getTypeOfPropertyOfType(instance, forcedLookupLocation);
                        if (!propType) {
                            return;
                        }
                        results.push(propType);
                    }
                    return getIntersectionType(results);
                }
                const instanceType = getReturnTypeOfSignature(sig);
                return isTypeAny(instanceType) ? instanceType : getTypeOfPropertyOfType(instanceType, forcedLookupLocation);
            }
            function getStaticTypeOfReferencedJsxConstructor(context) {
                if (isJsxIntrinsicTagName(context.tagName)) {
                    const result = getIntrinsicAttributesTypeFromJsxOpeningLikeElement(context);
                    const fakeSignature = createSignatureForJSXIntrinsic(context, result);
                    return getOrCreateTypeFromSignature(fakeSignature);
                }
                const tagType = checkExpressionCached(context.tagName);
                if (tagType.flags & 128 /* StringLiteral */) {
                    const result = getIntrinsicAttributesTypeFromStringLiteralType(tagType, context);
                    if (!result) {
                        return errorType;
                    }
                    const fakeSignature = createSignatureForJSXIntrinsic(context, result);
                    return getOrCreateTypeFromSignature(fakeSignature);
                }
                return tagType;
            }
            function getJsxManagedAttributesFromLocatedAttributes(context, ns, attributesType) {
                const managedSym = getJsxLibraryManagedAttributes(ns);
                if (managedSym) {
                    const ctorType = getStaticTypeOfReferencedJsxConstructor(context);
                    const result = instantiateAliasOrInterfaceWithDefaults(managedSym, isInJSFile(context), ctorType, attributesType);
                    if (result) {
                        return result;
                    }
                }
                return attributesType;
            }
            function getJsxPropsTypeFromClassType(sig, context) {
                const ns = getJsxNamespaceAt(context);
                const forcedLookupLocation = getJsxElementPropertiesName(ns);
                let attributesType = forcedLookupLocation === void 0 ? getTypeOfFirstParameterOfSignatureWithFallback(sig, unknownType) : forcedLookupLocation === "" ? getReturnTypeOfSignature(sig) : getJsxPropsTypeForSignatureFromMember(sig, forcedLookupLocation);
                if (!attributesType) {
                    if (!!forcedLookupLocation && !!length(context.attributes.properties)) {
                        error2(context, Diagnostics.JSX_element_class_does_not_support_attributes_because_it_does_not_have_a_0_property, unescapeLeadingUnderscores(forcedLookupLocation));
                    }
                    return unknownType;
                }
                attributesType = getJsxManagedAttributesFromLocatedAttributes(context, ns, attributesType);
                if (isTypeAny(attributesType)) {
                    return attributesType;
                }
                else {
                    let apparentAttributesType = attributesType;
                    const intrinsicClassAttribs = getJsxType(JsxNames.IntrinsicClassAttributes, context);
                    if (!isErrorType(intrinsicClassAttribs)) {
                        const typeParams = getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(intrinsicClassAttribs.symbol);
                        const hostClassType = getReturnTypeOfSignature(sig);
                        let libraryManagedAttributeType;
                        if (typeParams) {
                            const inferredArgs = fillMissingTypeArguments([hostClassType], typeParams, getMinTypeArgumentCount(typeParams), isInJSFile(context));
                            libraryManagedAttributeType = instantiateType(intrinsicClassAttribs, createTypeMapper(typeParams, inferredArgs));
                        }
                        else
                            libraryManagedAttributeType = intrinsicClassAttribs;
                        apparentAttributesType = intersectTypes(libraryManagedAttributeType, apparentAttributesType);
                    }
                    const intrinsicAttribs = getJsxType(JsxNames.IntrinsicAttributes, context);
                    if (!isErrorType(intrinsicAttribs)) {
                        apparentAttributesType = intersectTypes(intrinsicAttribs, apparentAttributesType);
                    }
                    return apparentAttributesType;
                }
            }
            function getIntersectedSignatures(signatures) {
                return getStrictOptionValue(compilerOptions, "noImplicitAny") ? reduceLeft(signatures, (left, right) => left === right || !left ? left : compareTypeParametersIdentical(left.typeParameters, right.typeParameters) ? combineSignaturesOfIntersectionMembers(left, right) : void 0) : void 0;
            }
            function combineIntersectionThisParam(left, right, mapper) {
                if (!left || !right) {
                    return left || right;
                }
                const thisType = getUnionType([getTypeOfSymbol(left), instantiateType(getTypeOfSymbol(right), mapper)]);
                return createSymbolWithType(left, thisType);
            }
            function combineIntersectionParameters(left, right, mapper) {
                const leftCount = getParameterCount(left);
                const rightCount = getParameterCount(right);
                const longest = leftCount >= rightCount ? left : right;
                const shorter = longest === left ? right : left;
                const longestCount = longest === left ? leftCount : rightCount;
                const eitherHasEffectiveRest = hasEffectiveRestParameter(left) || hasEffectiveRestParameter(right);
                const needsExtraRestElement = eitherHasEffectiveRest && !hasEffectiveRestParameter(longest);
                const params = new Array(longestCount + (needsExtraRestElement ? 1 : 0));
                for (let i = 0; i < longestCount; i++) {
                    let longestParamType = tryGetTypeAtPosition(longest, i);
                    if (longest === right) {
                        longestParamType = instantiateType(longestParamType, mapper);
                    }
                    let shorterParamType = tryGetTypeAtPosition(shorter, i) || unknownType;
                    if (shorter === right) {
                        shorterParamType = instantiateType(shorterParamType, mapper);
                    }
                    const unionParamType = getUnionType([longestParamType, shorterParamType]);
                    const isRestParam = eitherHasEffectiveRest && !needsExtraRestElement && i === longestCount - 1;
                    const isOptional = i >= getMinArgumentCount(longest) && i >= getMinArgumentCount(shorter);
                    const leftName = i >= leftCount ? void 0 : getParameterNameAtPosition(left, i);
                    const rightName = i >= rightCount ? void 0 : getParameterNameAtPosition(right, i);
                    const paramName = leftName === rightName ? leftName : !leftName ? rightName : !rightName ? leftName : void 0;
                    const paramSymbol = createSymbol(1 /* FunctionScopedVariable */ | (isOptional && !isRestParam ? 16777216 /* Optional */ : 0), paramName || `arg${i}`);
                    paramSymbol.links.type = isRestParam ? createArrayType(unionParamType) : unionParamType;
                    params[i] = paramSymbol;
                }
                if (needsExtraRestElement) {
                    const restParamSymbol = createSymbol(1 /* FunctionScopedVariable */, "args");
                    restParamSymbol.links.type = createArrayType(getTypeAtPosition(shorter, longestCount));
                    if (shorter === right) {
                        restParamSymbol.links.type = instantiateType(restParamSymbol.links.type, mapper);
                    }
                    params[longestCount] = restParamSymbol;
                }
                return params;
            }
            function combineSignaturesOfIntersectionMembers(left, right) {
                const typeParams = left.typeParameters || right.typeParameters;
                let paramMapper;
                if (left.typeParameters && right.typeParameters) {
                    paramMapper = createTypeMapper(right.typeParameters, left.typeParameters);
                }
                const declaration = left.declaration;
                const params = combineIntersectionParameters(left, right, paramMapper);
                const thisParam = combineIntersectionThisParam(left.thisParameter, right.thisParameter, paramMapper);
                const minArgCount = Math.max(left.minArgumentCount, right.minArgumentCount);
                const result = createSignature(declaration, typeParams, thisParam, params, 
                /*resolvedReturnType*/
                void 0, 
                /*resolvedTypePredicate*/
                void 0, minArgCount, (left.flags | right.flags) & 167 /* PropagatingFlags */);
                result.compositeKind = 2097152 /* Intersection */;
                result.compositeSignatures = concatenate(left.compositeKind === 2097152 /* Intersection */ && left.compositeSignatures || [left], [right]);
                if (paramMapper) {
                    result.mapper = left.compositeKind === 2097152 /* Intersection */ && left.mapper && left.compositeSignatures ? combineTypeMappers(left.mapper, paramMapper) : paramMapper;
                }
                return result;
            }
            function getContextualCallSignature(type, node) {
                const signatures = getSignaturesOfType(type, 0 /* Call */);
                const applicableByArity = filter(signatures, (s) => !isAritySmaller(s, node));
                return applicableByArity.length === 1 ? applicableByArity[0] : getIntersectedSignatures(applicableByArity);
            }
            function isAritySmaller(signature, target) {
                let targetParameterCount = 0;
                for (; targetParameterCount < target.parameters.length; targetParameterCount++) {
                    const param = target.parameters[targetParameterCount];
                    if (param.initializer || param.questionToken || param.dotDotDotToken || isJSDocOptionalParameter(param)) {
                        break;
                    }
                }
                if (target.parameters.length && parameterIsThisKeyword(target.parameters[0])) {
                    targetParameterCount--;
                }
                return !hasEffectiveRestParameter(signature) && getParameterCount(signature) < targetParameterCount;
            }
            function getContextualSignatureForFunctionLikeDeclaration(node) {
                return isFunctionExpressionOrArrowFunction(node) || isObjectLiteralMethod(node) ? getContextualSignature(node) : void 0;
            }
            function getContextualSignature(node) {
                Debug.assert(node.kind !== 174 /* MethodDeclaration */ || isObjectLiteralMethod(node));
                const typeTagSignature = getSignatureOfTypeTag(node);
                if (typeTagSignature) {
                    return typeTagSignature;
                }
                const type = getApparentTypeOfContextualType(node, 1 /* Signature */);
                if (!type) {
                    return void 0;
                }
                if (!(type.flags & 1048576 /* Union */)) {
                    return getContextualCallSignature(type, node);
                }
                let signatureList;
                const types = type.types;
                for (const current of types) {
                    const signature = getContextualCallSignature(current, node);
                    if (signature) {
                        if (!signatureList) {
                            signatureList = [signature];
                        }
                        else if (!compareSignaturesIdentical(signatureList[0], signature, 
                        /*partialMatch*/
                        false, 
                        /*ignoreThisTypes*/
                        true, 
                        /*ignoreReturnTypes*/
                        true, compareTypesIdentical)) {
                            return void 0;
                        }
                        else {
                            signatureList.push(signature);
                        }
                    }
                }
                if (signatureList) {
                    return signatureList.length === 1 ? signatureList[0] : createUnionSignature(signatureList[0], signatureList);
                }
            }
            function checkSpreadExpression(node, checkMode) {
                if (languageVersion < 2 /* ES2015 */) {
                    checkExternalEmitHelpers(node, compilerOptions.downlevelIteration ? 1536 /* SpreadIncludes */ : 1024 /* SpreadArray */);
                }
                const arrayOrIterableType = checkExpression(node.expression, checkMode);
                return checkIteratedTypeOrElementType(33 /* Spread */, arrayOrIterableType, undefinedType, node.expression);
            }
            function checkSyntheticExpression(node) {
                return node.isSpread ? getIndexedAccessType(node.type, numberType) : node.type;
            }
            function hasDefaultValue(node) {
                return node.kind === 208 /* BindingElement */ && !!node.initializer || node.kind === 226 /* BinaryExpression */ && node.operatorToken.kind === 64 /* EqualsToken */;
            }
            function isSpreadIntoCallOrNew(node) {
                const parent2 = walkUpParenthesizedExpressions(node.parent);
                return isSpreadElement(parent2) && isCallOrNewExpression(parent2.parent);
            }
            function checkArrayLiteral(node, checkMode, forceTuple) {
                const elements = node.elements;
                const elementCount = elements.length;
                const elementTypes = [];
                const elementFlags = [];
                pushCachedContextualType(node);
                const inDestructuringPattern = isAssignmentTarget(node);
                const inConstContext = isConstContext(node);
                const contextualType = getApparentTypeOfContextualType(node, 
                /*contextFlags*/
                void 0);
                const inTupleContext = isSpreadIntoCallOrNew(node) || !!contextualType && someType(contextualType, (t) => isTupleLikeType(t) || isGenericMappedType(t) && !t.nameType && !!getHomomorphicTypeVariable(t.target || t));
                let hasOmittedExpression = false;
                for (let i = 0; i < elementCount; i++) {
                    const e = elements[i];
                    if (e.kind === 230 /* SpreadElement */) {
                        if (languageVersion < 2 /* ES2015 */) {
                            checkExternalEmitHelpers(e, compilerOptions.downlevelIteration ? 1536 /* SpreadIncludes */ : 1024 /* SpreadArray */);
                        }
                        const spreadType = checkExpression(e.expression, checkMode, forceTuple);
                        if (isArrayLikeType(spreadType)) {
                            elementTypes.push(spreadType);
                            elementFlags.push(8 /* Variadic */);
                        }
                        else if (inDestructuringPattern) {
                            const restElementType = getIndexTypeOfType(spreadType, numberType) || getIteratedTypeOrElementType(65 /* Destructuring */, spreadType, undefinedType, 
                            /*errorNode*/
                            void 0, 
                            /*checkAssignability*/
                            false) || unknownType;
                            elementTypes.push(restElementType);
                            elementFlags.push(4 /* Rest */);
                        }
                        else {
                            elementTypes.push(checkIteratedTypeOrElementType(33 /* Spread */, spreadType, undefinedType, e.expression));
                            elementFlags.push(4 /* Rest */);
                        }
                    }
                    else if (exactOptionalPropertyTypes && e.kind === 232 /* OmittedExpression */) {
                        hasOmittedExpression = true;
                        elementTypes.push(undefinedOrMissingType);
                        elementFlags.push(2 /* Optional */);
                    }
                    else {
                        const type = checkExpressionForMutableLocation(e, checkMode, forceTuple);
                        elementTypes.push(addOptionality(type, 
                        /*isProperty*/
                        true, hasOmittedExpression));
                        elementFlags.push(hasOmittedExpression ? 2 /* Optional */ : 1 /* Required */);
                        if (inTupleContext && checkMode && checkMode & 2 /* Inferential */ && !(checkMode & 4 /* SkipContextSensitive */) && isContextSensitive(e)) {
                            const inferenceContext = getInferenceContext(node);
                            Debug.assert(inferenceContext);
                            addIntraExpressionInferenceSite(inferenceContext, e, type);
                        }
                    }
                }
                popContextualType();
                if (inDestructuringPattern) {
                    return createTupleType(elementTypes, elementFlags);
                }
                if (forceTuple || inConstContext || inTupleContext) {
                    return createArrayLiteralType(createTupleType(elementTypes, elementFlags, 
                    /*readonly*/
                    inConstContext && !(contextualType && someType(contextualType, isMutableArrayLikeType))));
                }
                return createArrayLiteralType(createArrayType(elementTypes.length ? getUnionType(sameMap(elementTypes, (t, i) => elementFlags[i] & 8 /* Variadic */ ? getIndexedAccessTypeOrUndefined(t, numberType) || anyType : t), 2 /* Subtype */) : strictNullChecks ? implicitNeverType : undefinedWideningType, inConstContext));
            }
            function createArrayLiteralType(type) {
                if (!(getObjectFlags(type) & 4 /* Reference */)) {
                    return type;
                }
                let literalType = type.literalType;
                if (!literalType) {
                    literalType = type.literalType = cloneTypeReference(type);
                    literalType.objectFlags |= 16384 /* ArrayLiteral */ | 131072 /* ContainsObjectOrArrayLiteral */;
                }
                return literalType;
            }
            function isNumericName(name) {
                switch (name.kind) {
                    case 167 /* ComputedPropertyName */:
                        return isNumericComputedName(name);
                    case 80 /* Identifier */:
                        return isNumericLiteralName(name.escapedText);
                    case 9 /* NumericLiteral */:
                    case 11 /* StringLiteral */:
                        return isNumericLiteralName(name.text);
                    default:
                        return false;
                }
            }
            function isNumericComputedName(name) {
                return isTypeAssignableToKind(checkComputedPropertyName(name), 296 /* NumberLike */);
            }
            function checkComputedPropertyName(node) {
                const links = getNodeLinks(node.expression);
                if (!links.resolvedType) {
                    if ((isTypeLiteralNode(node.parent.parent) || isClassLike(node.parent.parent) || isInterfaceDeclaration(node.parent.parent)) && isBinaryExpression(node.expression) && node.expression.operatorToken.kind === 103 /* InKeyword */ && node.parent.kind !== 177 /* GetAccessor */ && node.parent.kind !== 178 /* SetAccessor */) {
                        return links.resolvedType = errorType;
                    }
                    links.resolvedType = checkExpression(node.expression);
                    if (isPropertyDeclaration(node.parent) && !hasStaticModifier(node.parent) && isClassExpression(node.parent.parent)) {
                        const container = getEnclosingBlockScopeContainer(node.parent.parent);
                        const enclosingIterationStatement = getEnclosingIterationStatement(container);
                        if (enclosingIterationStatement) {
                            getNodeLinks(enclosingIterationStatement).flags |= 4096 /* LoopWithCapturedBlockScopedBinding */;
                            getNodeLinks(node).flags |= 32768 /* BlockScopedBindingInLoop */;
                            getNodeLinks(node.parent.parent).flags |= 32768 /* BlockScopedBindingInLoop */;
                        }
                    }
                    if (links.resolvedType.flags & 98304 /* Nullable */ || !isTypeAssignableToKind(links.resolvedType, 402653316 /* StringLike */ | 296 /* NumberLike */ | 12288 /* ESSymbolLike */) && !isTypeAssignableTo(links.resolvedType, stringNumberSymbolType)) {
                        error2(node, Diagnostics.A_computed_property_name_must_be_of_type_string_number_symbol_or_any);
                    }
                }
                return links.resolvedType;
            }
            function isSymbolWithNumericName(symbol) {
                var _a;
                const firstDecl = (_a = symbol.declarations) == null ? void 0 : _a[0];
                return isNumericLiteralName(symbol.escapedName) || firstDecl && isNamedDeclaration(firstDecl) && isNumericName(firstDecl.name);
            }
            function isSymbolWithSymbolName(symbol) {
                var _a;
                const firstDecl = (_a = symbol.declarations) == null ? void 0 : _a[0];
                return isKnownSymbol(symbol) || firstDecl && isNamedDeclaration(firstDecl) && isComputedPropertyName(firstDecl.name) && isTypeAssignableToKind(checkComputedPropertyName(firstDecl.name), 4096 /* ESSymbol */);
            }
            function getObjectLiteralIndexInfo(node, offset, properties, keyType) {
                const propTypes = [];
                for (let i = offset; i < properties.length; i++) {
                    const prop = properties[i];
                    if (keyType === stringType && !isSymbolWithSymbolName(prop) || keyType === numberType && isSymbolWithNumericName(prop) || keyType === esSymbolType && isSymbolWithSymbolName(prop)) {
                        propTypes.push(getTypeOfSymbol(properties[i]));
                    }
                }
                const unionType = propTypes.length ? getUnionType(propTypes, 2 /* Subtype */) : undefinedType;
                return createIndexInfo(keyType, unionType, isConstContext(node));
            }
            function getImmediateAliasedSymbol(symbol) {
                Debug.assert((symbol.flags & 2097152 /* Alias */) !== 0, "Should only get Alias here.");
                const links = getSymbolLinks(symbol);
                if (!links.immediateTarget) {
                    const node = getDeclarationOfAliasSymbol(symbol);
                    if (!node)
                        return Debug.fail();
                    links.immediateTarget = getTargetOfAliasDeclaration(node, 
                    /*dontRecursivelyResolve*/
                    true);
                }
                return links.immediateTarget;
            }
            function checkObjectLiteral(node, checkMode = 0 /* Normal */) {
                var _a;
                const inDestructuringPattern = isAssignmentTarget(node);
                checkGrammarObjectLiteralExpression(node, inDestructuringPattern);
                const allPropertiesTable = strictNullChecks ? createSymbolTable() : void 0;
                let propertiesTable = createSymbolTable();
                let propertiesArray = [];
                let spread = emptyObjectType;
                pushCachedContextualType(node);
                const contextualType = getApparentTypeOfContextualType(node, 
                /*contextFlags*/
                void 0);
                const contextualTypeHasPattern = contextualType && contextualType.pattern && (contextualType.pattern.kind === 206 /* ObjectBindingPattern */ || contextualType.pattern.kind === 210 /* ObjectLiteralExpression */);
                const inConstContext = isConstContext(node);
                const checkFlags = inConstContext ? 8 /* Readonly */ : 0;
                const isInJavascript = isInJSFile(node) && !isInJsonFile(node);
                const enumTag = isInJavascript ? getJSDocEnumTag(node) : void 0;
                const isJSObjectLiteral = !contextualType && isInJavascript && !enumTag;
                let objectFlags = freshObjectLiteralFlag;
                let patternWithComputedProperties = false;
                let hasComputedStringProperty = false;
                let hasComputedNumberProperty = false;
                let hasComputedSymbolProperty = false;
                for (const elem of node.properties) {
                    if (elem.name && isComputedPropertyName(elem.name)) {
                        checkComputedPropertyName(elem.name);
                    }
                }
                let offset = 0;
                for (const memberDecl of node.properties) {
                    let member = getSymbolOfDeclaration(memberDecl);
                    const computedNameType = memberDecl.name && memberDecl.name.kind === 167 /* ComputedPropertyName */ ? checkComputedPropertyName(memberDecl.name) : void 0;
                    if (memberDecl.kind === 303 /* PropertyAssignment */ || memberDecl.kind === 304 /* ShorthandPropertyAssignment */ || isObjectLiteralMethod(memberDecl)) {
                        let type = memberDecl.kind === 303 /* PropertyAssignment */ ? checkPropertyAssignment(memberDecl, checkMode) : (
                        // avoid resolving the left side of the ShorthandPropertyAssignment outside of the destructuring
                        // for error recovery purposes. For example, if a user wrote `{ a = 100 }` instead of `{ a: 100 }`.
                        // we don't want to say "could not find 'a'".
                        memberDecl.kind === 304 /* ShorthandPropertyAssignment */ ? checkExpressionForMutableLocation(!inDestructuringPattern && memberDecl.objectAssignmentInitializer ? memberDecl.objectAssignmentInitializer : memberDecl.name, checkMode) : checkObjectLiteralMethod(memberDecl, checkMode));
                        if (isInJavascript) {
                            const jsDocType = getTypeForDeclarationFromJSDocComment(memberDecl);
                            if (jsDocType) {
                                checkTypeAssignableTo(type, jsDocType, memberDecl);
                                type = jsDocType;
                            }
                            else if (enumTag && enumTag.typeExpression) {
                                checkTypeAssignableTo(type, getTypeFromTypeNode(enumTag.typeExpression), memberDecl);
                            }
                        }
                        objectFlags |= getObjectFlags(type) & 458752 /* PropagatingFlags */;
                        const nameType = computedNameType && isTypeUsableAsPropertyName(computedNameType) ? computedNameType : void 0;
                        const prop = nameType ? createSymbol(4 /* Property */ | member.flags, getPropertyNameFromType(nameType), checkFlags | 4096 /* Late */) : createSymbol(4 /* Property */ | member.flags, member.escapedName, checkFlags);
                        if (nameType) {
                            prop.links.nameType = nameType;
                        }
                        if (inDestructuringPattern) {
                            const isOptional = memberDecl.kind === 303 /* PropertyAssignment */ && hasDefaultValue(memberDecl.initializer) || memberDecl.kind === 304 /* ShorthandPropertyAssignment */ && memberDecl.objectAssignmentInitializer;
                            if (isOptional) {
                                prop.flags |= 16777216 /* Optional */;
                            }
                        }
                        else if (contextualTypeHasPattern && !(getObjectFlags(contextualType) & 512 /* ObjectLiteralPatternWithComputedProperties */)) {
                            const impliedProp = getPropertyOfType(contextualType, member.escapedName);
                            if (impliedProp) {
                                prop.flags |= impliedProp.flags & 16777216 /* Optional */;
                            }
                            else if (!compilerOptions.suppressExcessPropertyErrors && !getIndexInfoOfType(contextualType, stringType)) {
                                error2(memberDecl.name, Diagnostics.Object_literal_may_only_specify_known_properties_and_0_does_not_exist_in_type_1, symbolToString(member), typeToString(contextualType));
                            }
                        }
                        prop.declarations = member.declarations;
                        prop.parent = member.parent;
                        if (member.valueDeclaration) {
                            prop.valueDeclaration = member.valueDeclaration;
                        }
                        prop.links.type = type;
                        prop.links.target = member;
                        member = prop;
                        allPropertiesTable == null ? void 0 : allPropertiesTable.set(prop.escapedName, prop);
                        if (contextualType && checkMode & 2 /* Inferential */ && !(checkMode & 4 /* SkipContextSensitive */) && (memberDecl.kind === 303 /* PropertyAssignment */ || memberDecl.kind === 174 /* MethodDeclaration */) && isContextSensitive(memberDecl)) {
                            const inferenceContext = getInferenceContext(node);
                            Debug.assert(inferenceContext);
                            const inferenceNode = memberDecl.kind === 303 /* PropertyAssignment */ ? memberDecl.initializer : memberDecl;
                            addIntraExpressionInferenceSite(inferenceContext, inferenceNode, type);
                        }
                    }
                    else if (memberDecl.kind === 305 /* SpreadAssignment */) {
                        if (languageVersion < 2 /* ES2015 */) {
                            checkExternalEmitHelpers(memberDecl, 2 /* Assign */);
                        }
                        if (propertiesArray.length > 0) {
                            spread = getSpreadType(spread, createObjectLiteralType(), node.symbol, objectFlags, inConstContext);
                            propertiesArray = [];
                            propertiesTable = createSymbolTable();
                            hasComputedStringProperty = false;
                            hasComputedNumberProperty = false;
                            hasComputedSymbolProperty = false;
                        }
                        const type = getReducedType(checkExpression(memberDecl.expression, checkMode & 2 /* Inferential */));
                        if (isValidSpreadType(type)) {
                            const mergedType = tryMergeUnionOfObjectTypeAndEmptyObject(type, inConstContext);
                            if (allPropertiesTable) {
                                checkSpreadPropOverrides(mergedType, allPropertiesTable, memberDecl);
                            }
                            offset = propertiesArray.length;
                            if (isErrorType(spread)) {
                                continue;
                            }
                            spread = getSpreadType(spread, mergedType, node.symbol, objectFlags, inConstContext);
                        }
                        else {
                            error2(memberDecl, Diagnostics.Spread_types_may_only_be_created_from_object_types);
                            spread = errorType;
                        }
                        continue;
                    }
                    else {
                        Debug.assert(memberDecl.kind === 177 /* GetAccessor */ || memberDecl.kind === 178 /* SetAccessor */);
                        checkNodeDeferred(memberDecl);
                    }
                    if (computedNameType && !(computedNameType.flags & 8576 /* StringOrNumberLiteralOrUnique */)) {
                        if (isTypeAssignableTo(computedNameType, stringNumberSymbolType)) {
                            if (isTypeAssignableTo(computedNameType, numberType)) {
                                hasComputedNumberProperty = true;
                            }
                            else if (isTypeAssignableTo(computedNameType, esSymbolType)) {
                                hasComputedSymbolProperty = true;
                            }
                            else {
                                hasComputedStringProperty = true;
                            }
                            if (inDestructuringPattern) {
                                patternWithComputedProperties = true;
                            }
                        }
                    }
                    else {
                        propertiesTable.set(member.escapedName, member);
                    }
                    propertiesArray.push(member);
                }
                popContextualType();
                if (contextualTypeHasPattern) {
                    const rootPatternParent = findAncestor(contextualType.pattern.parent, (n) => n.kind === 260 /* VariableDeclaration */ || n.kind === 226 /* BinaryExpression */ || n.kind === 169 /* Parameter */);
                    const spreadOrOutsideRootObject = findAncestor(node, (n) => n === rootPatternParent || n.kind === 305 /* SpreadAssignment */);
                    if (spreadOrOutsideRootObject.kind !== 305 /* SpreadAssignment */) {
                        for (const prop of getPropertiesOfType(contextualType)) {
                            if (!propertiesTable.get(prop.escapedName) && !getPropertyOfType(spread, prop.escapedName)) {
                                if (!(prop.flags & 16777216 /* Optional */)) {
                                    error2(prop.valueDeclaration || ((_a = tryCast(prop, isTransientSymbol)) == null ? void 0 : _a.links.bindingElement), Diagnostics.Initializer_provides_no_value_for_this_binding_element_and_the_binding_element_has_no_default_value);
                                }
                                propertiesTable.set(prop.escapedName, prop);
                                propertiesArray.push(prop);
                            }
                        }
                    }
                }
                if (isErrorType(spread)) {
                    return errorType;
                }
                if (spread !== emptyObjectType) {
                    if (propertiesArray.length > 0) {
                        spread = getSpreadType(spread, createObjectLiteralType(), node.symbol, objectFlags, inConstContext);
                        propertiesArray = [];
                        propertiesTable = createSymbolTable();
                        hasComputedStringProperty = false;
                        hasComputedNumberProperty = false;
                    }
                    return mapType(spread, (t) => t === emptyObjectType ? createObjectLiteralType() : t);
                }
                return createObjectLiteralType();
                function createObjectLiteralType() {
                    const indexInfos = [];
                    if (hasComputedStringProperty)
                        indexInfos.push(getObjectLiteralIndexInfo(node, offset, propertiesArray, stringType));
                    if (hasComputedNumberProperty)
                        indexInfos.push(getObjectLiteralIndexInfo(node, offset, propertiesArray, numberType));
                    if (hasComputedSymbolProperty)
                        indexInfos.push(getObjectLiteralIndexInfo(node, offset, propertiesArray, esSymbolType));
                    const result = createAnonymousType(node.symbol, propertiesTable, emptyArray, emptyArray, indexInfos);
                    result.objectFlags |= objectFlags | 128 /* ObjectLiteral */ | 131072 /* ContainsObjectOrArrayLiteral */;
                    if (isJSObjectLiteral) {
                        result.objectFlags |= 4096 /* JSLiteral */;
                    }
                    if (patternWithComputedProperties) {
                        result.objectFlags |= 512 /* ObjectLiteralPatternWithComputedProperties */;
                    }
                    if (inDestructuringPattern) {
                        result.pattern = node;
                    }
                    return result;
                }
            }
            function isValidSpreadType(type) {
                const t = removeDefinitelyFalsyTypes(mapType(type, getBaseConstraintOrType));
                return !!(t.flags & (1 /* Any */ | 67108864 /* NonPrimitive */ | 524288 /* Object */ | 58982400 /* InstantiableNonPrimitive */) || t.flags & 3145728 /* UnionOrIntersection */ && every(t.types, isValidSpreadType));
            }
            function checkJsxSelfClosingElementDeferred(node) {
                checkJsxOpeningLikeElementOrOpeningFragment(node);
            }
            function checkJsxSelfClosingElement(node, _checkMode) {
                checkNodeDeferred(node);
                return getJsxElementTypeAt(node) || anyType;
            }
            function checkJsxElementDeferred(node) {
                checkJsxOpeningLikeElementOrOpeningFragment(node.openingElement);
                if (isJsxIntrinsicTagName(node.closingElement.tagName)) {
                    getIntrinsicTagSymbol(node.closingElement);
                }
                else {
                    checkExpression(node.closingElement.tagName);
                }
                checkJsxChildren(node);
            }
            function checkJsxElement(node, _checkMode) {
                checkNodeDeferred(node);
                return getJsxElementTypeAt(node) || anyType;
            }
            function checkJsxFragment(node) {
                checkJsxOpeningLikeElementOrOpeningFragment(node.openingFragment);
                const nodeSourceFile = getSourceFileOfNode(node);
                if (getJSXTransformEnabled(compilerOptions) && (compilerOptions.jsxFactory || nodeSourceFile.pragmas.has("jsx")) && !compilerOptions.jsxFragmentFactory && !nodeSourceFile.pragmas.has("jsxfrag")) {
                    error2(node, compilerOptions.jsxFactory ? Diagnostics.The_jsxFragmentFactory_compiler_option_must_be_provided_to_use_JSX_fragments_with_the_jsxFactory_compiler_option : Diagnostics.An_jsxFrag_pragma_is_required_when_using_an_jsx_pragma_with_JSX_fragments);
                }
                checkJsxChildren(node);
                return getJsxElementTypeAt(node) || anyType;
            }
            function isHyphenatedJsxName(name) {
                return name.includes("-");
            }
            function isJsxIntrinsicTagName(tagName) {
                return isIdentifier(tagName) && isIntrinsicJsxName(tagName.escapedText) || isJsxNamespacedName(tagName);
            }
            function checkJsxAttribute(node, checkMode) {
                return node.initializer ? checkExpressionForMutableLocation(node.initializer, checkMode) : trueType;
            }
            function createJsxAttributesTypeFromAttributesProperty(openingLikeElement, checkMode = 0 /* Normal */) {
                const attributes = openingLikeElement.attributes;
                const contextualType = getContextualType2(attributes, 0 /* None */);
                const allAttributesTable = strictNullChecks ? createSymbolTable() : void 0;
                let attributesTable = createSymbolTable();
                let spread = emptyJsxObjectType;
                let hasSpreadAnyType = false;
                let typeToIntersect;
                let explicitlySpecifyChildrenAttribute = false;
                let objectFlags = 2048 /* JsxAttributes */;
                const jsxChildrenPropertyName = getJsxElementChildrenPropertyName(getJsxNamespaceAt(openingLikeElement));
                for (const attributeDecl of attributes.properties) {
                    const member = attributeDecl.symbol;
                    if (isJsxAttribute(attributeDecl)) {
                        const exprType = checkJsxAttribute(attributeDecl, checkMode);
                        objectFlags |= getObjectFlags(exprType) & 458752 /* PropagatingFlags */;
                        const attributeSymbol = createSymbol(4 /* Property */ | member.flags, member.escapedName);
                        attributeSymbol.declarations = member.declarations;
                        attributeSymbol.parent = member.parent;
                        if (member.valueDeclaration) {
                            attributeSymbol.valueDeclaration = member.valueDeclaration;
                        }
                        attributeSymbol.links.type = exprType;
                        attributeSymbol.links.target = member;
                        attributesTable.set(attributeSymbol.escapedName, attributeSymbol);
                        allAttributesTable == null ? void 0 : allAttributesTable.set(attributeSymbol.escapedName, attributeSymbol);
                        if (getEscapedTextOfJsxAttributeName(attributeDecl.name) === jsxChildrenPropertyName) {
                            explicitlySpecifyChildrenAttribute = true;
                        }
                        if (contextualType) {
                            const prop = getPropertyOfType(contextualType, member.escapedName);
                            if (prop && prop.declarations && isDeprecatedSymbol(prop) && isIdentifier(attributeDecl.name)) {
                                addDeprecatedSuggestion(attributeDecl.name, prop.declarations, attributeDecl.name.escapedText);
                            }
                        }
                        if (contextualType && checkMode & 2 /* Inferential */ && !(checkMode & 4 /* SkipContextSensitive */) && isContextSensitive(attributeDecl)) {
                            const inferenceContext = getInferenceContext(attributes);
                            Debug.assert(inferenceContext);
                            const inferenceNode = attributeDecl.initializer.expression;
                            addIntraExpressionInferenceSite(inferenceContext, inferenceNode, exprType);
                        }
                    }
                    else {
                        Debug.assert(attributeDecl.kind === 293 /* JsxSpreadAttribute */);
                        if (attributesTable.size > 0) {
                            spread = getSpreadType(spread, createJsxAttributesType(), attributes.symbol, objectFlags, 
                            /*readonly*/
                            false);
                            attributesTable = createSymbolTable();
                        }
                        const exprType = getReducedType(checkExpression(attributeDecl.expression, checkMode & 2 /* Inferential */));
                        if (isTypeAny(exprType)) {
                            hasSpreadAnyType = true;
                        }
                        if (isValidSpreadType(exprType)) {
                            spread = getSpreadType(spread, exprType, attributes.symbol, objectFlags, 
                            /*readonly*/
                            false);
                            if (allAttributesTable) {
                                checkSpreadPropOverrides(exprType, allAttributesTable, attributeDecl);
                            }
                        }
                        else {
                            error2(attributeDecl.expression, Diagnostics.Spread_types_may_only_be_created_from_object_types);
                            typeToIntersect = typeToIntersect ? getIntersectionType([typeToIntersect, exprType]) : exprType;
                        }
                    }
                }
                if (!hasSpreadAnyType) {
                    if (attributesTable.size > 0) {
                        spread = getSpreadType(spread, createJsxAttributesType(), attributes.symbol, objectFlags, 
                        /*readonly*/
                        false);
                    }
                }
                const parent2 = openingLikeElement.parent.kind === 284 /* JsxElement */ ? openingLikeElement.parent : void 0;
                if (parent2 && parent2.openingElement === openingLikeElement && getSemanticJsxChildren(parent2.children).length > 0) {
                    const childrenTypes = checkJsxChildren(parent2, checkMode);
                    if (!hasSpreadAnyType && jsxChildrenPropertyName && jsxChildrenPropertyName !== "") {
                        if (explicitlySpecifyChildrenAttribute) {
                            error2(attributes, Diagnostics._0_are_specified_twice_The_attribute_named_0_will_be_overwritten, unescapeLeadingUnderscores(jsxChildrenPropertyName));
                        }
                        const contextualType2 = getApparentTypeOfContextualType(openingLikeElement.attributes, 
                        /*contextFlags*/
                        void 0);
                        const childrenContextualType = contextualType2 && getTypeOfPropertyOfContextualType(contextualType2, jsxChildrenPropertyName);
                        const childrenPropSymbol = createSymbol(4 /* Property */, jsxChildrenPropertyName);
                        childrenPropSymbol.links.type = childrenTypes.length === 1 ? childrenTypes[0] : childrenContextualType && someType(childrenContextualType, isTupleLikeType) ? createTupleType(childrenTypes) : createArrayType(getUnionType(childrenTypes));
                        childrenPropSymbol.valueDeclaration = factory.createPropertySignature(
                        /*modifiers*/
                        void 0, unescapeLeadingUnderscores(jsxChildrenPropertyName), 
                        /*questionToken*/
                        void 0, 
                        /*type*/
                        void 0);
                        setParent(childrenPropSymbol.valueDeclaration, attributes);
                        childrenPropSymbol.valueDeclaration.symbol = childrenPropSymbol;
                        const childPropMap = createSymbolTable();
                        childPropMap.set(jsxChildrenPropertyName, childrenPropSymbol);
                        spread = getSpreadType(spread, createAnonymousType(attributes.symbol, childPropMap, emptyArray, emptyArray, emptyArray), attributes.symbol, objectFlags, 
                        /*readonly*/
                        false);
                    }
                }
                if (hasSpreadAnyType) {
                    return anyType;
                }
                if (typeToIntersect && spread !== emptyJsxObjectType) {
                    return getIntersectionType([typeToIntersect, spread]);
                }
                return typeToIntersect || (spread === emptyJsxObjectType ? createJsxAttributesType() : spread);
                function createJsxAttributesType() {
                    objectFlags |= freshObjectLiteralFlag;
                    const result = createAnonymousType(attributes.symbol, attributesTable, emptyArray, emptyArray, emptyArray);
                    result.objectFlags |= objectFlags | 128 /* ObjectLiteral */ | 131072 /* ContainsObjectOrArrayLiteral */;
                    return result;
                }
            }
            function checkJsxChildren(node, checkMode) {
                const childrenTypes = [];
                for (const child of node.children) {
                    if (child.kind === 12 /* JsxText */) {
                        if (!child.containsOnlyTriviaWhiteSpaces) {
                            childrenTypes.push(stringType);
                        }
                    }
                    else if (child.kind === 294 /* JsxExpression */ && !child.expression) {
                        continue;
                    }
                    else {
                        childrenTypes.push(checkExpressionForMutableLocation(child, checkMode));
                    }
                }
                return childrenTypes;
            }
            function checkSpreadPropOverrides(type, props, spread) {
                for (const right of getPropertiesOfType(type)) {
                    if (!(right.flags & 16777216 /* Optional */)) {
                        const left = props.get(right.escapedName);
                        if (left) {
                            const diagnostic = error2(left.valueDeclaration, Diagnostics._0_is_specified_more_than_once_so_this_usage_will_be_overwritten, unescapeLeadingUnderscores(left.escapedName));
                            addRelatedInfo(diagnostic, createDiagnosticForNode(spread, Diagnostics.This_spread_always_overwrites_this_property));
                        }
                    }
                }
            }
            function checkJsxAttributes(node, checkMode) {
                return createJsxAttributesTypeFromAttributesProperty(node.parent, checkMode);
            }
            function getJsxType(name, location) {
                const namespace = getJsxNamespaceAt(location);
                const exports = namespace && getExportsOfSymbol(namespace);
                const typeSymbol = exports && getSymbol2(exports, name, 788968 /* Type */);
                return typeSymbol ? getDeclaredTypeOfSymbol(typeSymbol) : errorType;
            }
            function getIntrinsicTagSymbol(node) {
                const links = getNodeLinks(node);
                if (!links.resolvedSymbol) {
                    const intrinsicElementsType = getJsxType(JsxNames.IntrinsicElements, node);
                    if (!isErrorType(intrinsicElementsType)) {
                        if (!isIdentifier(node.tagName) && !isJsxNamespacedName(node.tagName))
                            return Debug.fail();
                        const propName = isJsxNamespacedName(node.tagName) ? getEscapedTextOfJsxNamespacedName(node.tagName) : node.tagName.escapedText;
                        const intrinsicProp = getPropertyOfType(intrinsicElementsType, propName);
                        if (intrinsicProp) {
                            links.jsxFlags |= 1 /* IntrinsicNamedElement */;
                            return links.resolvedSymbol = intrinsicProp;
                        }
                        const indexSymbol = getApplicableIndexSymbol(intrinsicElementsType, getStringLiteralType(unescapeLeadingUnderscores(propName)));
                        if (indexSymbol) {
                            links.jsxFlags |= 2 /* IntrinsicIndexedElement */;
                            return links.resolvedSymbol = indexSymbol;
                        }
                        if (getTypeOfPropertyOrIndexSignatureOfType(intrinsicElementsType, propName)) {
                            links.jsxFlags |= 2 /* IntrinsicIndexedElement */;
                            return links.resolvedSymbol = intrinsicElementsType.symbol;
                        }
                        error2(node, Diagnostics.Property_0_does_not_exist_on_type_1, intrinsicTagNameToString(node.tagName), "JSX." + JsxNames.IntrinsicElements);
                        return links.resolvedSymbol = unknownSymbol;
                    }
                    else {
                        if (noImplicitAny) {
                            error2(node, Diagnostics.JSX_element_implicitly_has_type_any_because_no_interface_JSX_0_exists, unescapeLeadingUnderscores(JsxNames.IntrinsicElements));
                        }
                        return links.resolvedSymbol = unknownSymbol;
                    }
                }
                return links.resolvedSymbol;
            }
            function getJsxNamespaceContainerForImplicitImport(location) {
                const file = location && getSourceFileOfNode(location);
                const links = file && getNodeLinks(file);
                if (links && links.jsxImplicitImportContainer === false) {
                    return void 0;
                }
                if (links && links.jsxImplicitImportContainer) {
                    return links.jsxImplicitImportContainer;
                }
                const runtimeImportSpecifier = getJSXRuntimeImport(getJSXImplicitImportBase(compilerOptions, file), compilerOptions);
                if (!runtimeImportSpecifier) {
                    return void 0;
                }
                const isClassic = getEmitModuleResolutionKind(compilerOptions) === 1 /* Classic */;
                const errorMessage = isClassic ? Diagnostics.Cannot_find_module_0_Did_you_mean_to_set_the_moduleResolution_option_to_nodenext_or_to_add_aliases_to_the_paths_option : Diagnostics.Cannot_find_module_0_or_its_corresponding_type_declarations;
                const jsxImportIndex = compilerOptions.importHelpers ? 1 : 0;
                const specifier = file == null ? void 0 : file.imports[jsxImportIndex];
                if (specifier) {
                    Debug.assert(nodeIsSynthesized(specifier) && specifier.text === runtimeImportSpecifier, `Expected sourceFile.imports[${jsxImportIndex}] to be the synthesized JSX runtime import`);
                }
                const mod = resolveExternalModule(specifier || location, runtimeImportSpecifier, errorMessage, location);
                const result = mod && mod !== unknownSymbol ? getMergedSymbol(resolveSymbol(mod)) : void 0;
                if (links) {
                    links.jsxImplicitImportContainer = result || false;
                }
                return result;
            }
            function getJsxNamespaceAt(location) {
                const links = location && getNodeLinks(location);
                if (links && links.jsxNamespace) {
                    return links.jsxNamespace;
                }
                if (!links || links.jsxNamespace !== false) {
                    let resolvedNamespace = getJsxNamespaceContainerForImplicitImport(location);
                    if (!resolvedNamespace || resolvedNamespace === unknownSymbol) {
                        const namespaceName = getJsxNamespace(location);
                        resolvedNamespace = resolveName(location, namespaceName, 1920 /* Namespace */, 
                        /*nameNotFoundMessage*/
                        void 0, namespaceName, 
                        /*isUse*/
                        false);
                    }
                    if (resolvedNamespace) {
                        const candidate = resolveSymbol(getSymbol2(getExportsOfSymbol(resolveSymbol(resolvedNamespace)), JsxNames.JSX, 1920 /* Namespace */));
                        if (candidate && candidate !== unknownSymbol) {
                            if (links) {
                                links.jsxNamespace = candidate;
                            }
                            return candidate;
                        }
                    }
                    if (links) {
                        links.jsxNamespace = false;
                    }
                }
                const s = resolveSymbol(getGlobalSymbol(JsxNames.JSX, 1920 /* Namespace */, 
                /*diagnostic*/
                void 0));
                if (s === unknownSymbol) {
                    return void 0;
                }
                return s;
            }
            function getNameFromJsxElementAttributesContainer(nameOfAttribPropContainer, jsxNamespace) {
                const jsxElementAttribPropInterfaceSym = jsxNamespace && getSymbol2(jsxNamespace.exports, nameOfAttribPropContainer, 788968 /* Type */);
                const jsxElementAttribPropInterfaceType = jsxElementAttribPropInterfaceSym && getDeclaredTypeOfSymbol(jsxElementAttribPropInterfaceSym);
                const propertiesOfJsxElementAttribPropInterface = jsxElementAttribPropInterfaceType && getPropertiesOfType(jsxElementAttribPropInterfaceType);
                if (propertiesOfJsxElementAttribPropInterface) {
                    if (propertiesOfJsxElementAttribPropInterface.length === 0) {
                        return "";
                    }
                    else if (propertiesOfJsxElementAttribPropInterface.length === 1) {
                        return propertiesOfJsxElementAttribPropInterface[0].escapedName;
                    }
                    else if (propertiesOfJsxElementAttribPropInterface.length > 1 && jsxElementAttribPropInterfaceSym.declarations) {
                        error2(jsxElementAttribPropInterfaceSym.declarations[0], Diagnostics.The_global_type_JSX_0_may_not_have_more_than_one_property, unescapeLeadingUnderscores(nameOfAttribPropContainer));
                    }
                }
                return void 0;
            }
            function getJsxLibraryManagedAttributes(jsxNamespace) {
                return jsxNamespace && getSymbol2(jsxNamespace.exports, JsxNames.LibraryManagedAttributes, 788968 /* Type */);
            }
            function getJsxElementTypeSymbol(jsxNamespace) {
                return jsxNamespace && getSymbol2(jsxNamespace.exports, JsxNames.ElementType, 788968 /* Type */);
            }
            function getJsxElementPropertiesName(jsxNamespace) {
                return getNameFromJsxElementAttributesContainer(JsxNames.ElementAttributesPropertyNameContainer, jsxNamespace);
            }
            function getJsxElementChildrenPropertyName(jsxNamespace) {
                return getNameFromJsxElementAttributesContainer(JsxNames.ElementChildrenAttributeNameContainer, jsxNamespace);
            }
            function getUninstantiatedJsxSignaturesOfType(elementType, caller) {
                if (elementType.flags & 4 /* String */) {
                    return [anySignature];
                }
                else if (elementType.flags & 128 /* StringLiteral */) {
                    const intrinsicType = getIntrinsicAttributesTypeFromStringLiteralType(elementType, caller);
                    if (!intrinsicType) {
                        error2(caller, Diagnostics.Property_0_does_not_exist_on_type_1, elementType.value, "JSX." + JsxNames.IntrinsicElements);
                        return emptyArray;
                    }
                    else {
                        const fakeSignature = createSignatureForJSXIntrinsic(caller, intrinsicType);
                        return [fakeSignature];
                    }
                }
                const apparentElemType = getApparentType(elementType);
                let signatures = getSignaturesOfType(apparentElemType, 1 /* Construct */);
                if (signatures.length === 0) {
                    signatures = getSignaturesOfType(apparentElemType, 0 /* Call */);
                }
                if (signatures.length === 0 && apparentElemType.flags & 1048576 /* Union */) {
                    signatures = getUnionSignatures(map(apparentElemType.types, (t) => getUninstantiatedJsxSignaturesOfType(t, caller)));
                }
                return signatures;
            }
            function getIntrinsicAttributesTypeFromStringLiteralType(type, location) {
                const intrinsicElementsType = getJsxType(JsxNames.IntrinsicElements, location);
                if (!isErrorType(intrinsicElementsType)) {
                    const stringLiteralTypeName = type.value;
                    const intrinsicProp = getPropertyOfType(intrinsicElementsType, escapeLeadingUnderscores(stringLiteralTypeName));
                    if (intrinsicProp) {
                        return getTypeOfSymbol(intrinsicProp);
                    }
                    const indexSignatureType = getIndexTypeOfType(intrinsicElementsType, stringType);
                    if (indexSignatureType) {
                        return indexSignatureType;
                    }
                    return void 0;
                }
                return anyType;
            }
            function checkJsxReturnAssignableToAppropriateBound(refKind, elemInstanceType, openingLikeElement) {
                if (refKind === 1 /* Function */) {
                    const sfcReturnConstraint = getJsxStatelessElementTypeAt(openingLikeElement);
                    if (sfcReturnConstraint) {
                        checkTypeRelatedTo(elemInstanceType, sfcReturnConstraint, assignableRelation, openingLikeElement.tagName, Diagnostics.Its_return_type_0_is_not_a_valid_JSX_element, generateInitialErrorChain);
                    }
                }
                else if (refKind === 0 /* Component */) {
                    const classConstraint = getJsxElementClassTypeAt(openingLikeElement);
                    if (classConstraint) {
                        checkTypeRelatedTo(elemInstanceType, classConstraint, assignableRelation, openingLikeElement.tagName, Diagnostics.Its_instance_type_0_is_not_a_valid_JSX_element, generateInitialErrorChain);
                    }
                }
                else {
                    const sfcReturnConstraint = getJsxStatelessElementTypeAt(openingLikeElement);
                    const classConstraint = getJsxElementClassTypeAt(openingLikeElement);
                    if (!sfcReturnConstraint || !classConstraint) {
                        return;
                    }
                    const combined = getUnionType([sfcReturnConstraint, classConstraint]);
                    checkTypeRelatedTo(elemInstanceType, combined, assignableRelation, openingLikeElement.tagName, Diagnostics.Its_element_type_0_is_not_a_valid_JSX_element, generateInitialErrorChain);
                }
                function generateInitialErrorChain() {
                    const componentName = getTextOfNode(openingLikeElement.tagName);
                    return chainDiagnosticMessages(
                    /*details*/
                    void 0, Diagnostics._0_cannot_be_used_as_a_JSX_component, componentName);
                }
            }
            function getIntrinsicAttributesTypeFromJsxOpeningLikeElement(node) {
                var _a;
                Debug.assert(isJsxIntrinsicTagName(node.tagName));
                const links = getNodeLinks(node);
                if (!links.resolvedJsxElementAttributesType) {
                    const symbol = getIntrinsicTagSymbol(node);
                    if (links.jsxFlags & 1 /* IntrinsicNamedElement */) {
                        return links.resolvedJsxElementAttributesType = getTypeOfSymbol(symbol) || errorType;
                    }
                    else if (links.jsxFlags & 2 /* IntrinsicIndexedElement */) {
                        const propName = isJsxNamespacedName(node.tagName) ? getEscapedTextOfJsxNamespacedName(node.tagName) : node.tagName.escapedText;
                        return links.resolvedJsxElementAttributesType = ((_a = getApplicableIndexInfoForName(getJsxType(JsxNames.IntrinsicElements, node), propName)) == null ? void 0 : _a.type) || errorType;
                    }
                    else {
                        return links.resolvedJsxElementAttributesType = errorType;
                    }
                }
                return links.resolvedJsxElementAttributesType;
            }
            function getJsxElementClassTypeAt(location) {
                const type = getJsxType(JsxNames.ElementClass, location);
                if (isErrorType(type))
                    return void 0;
                return type;
            }
            function getJsxElementTypeAt(location) {
                return getJsxType(JsxNames.Element, location);
            }
            function getJsxStatelessElementTypeAt(location) {
                const jsxElementType = getJsxElementTypeAt(location);
                if (jsxElementType) {
                    return getUnionType([jsxElementType, nullType]);
                }
            }
            function getJsxElementTypeTypeAt(location) {
                const ns = getJsxNamespaceAt(location);
                if (!ns)
                    return void 0;
                const sym = getJsxElementTypeSymbol(ns);
                if (!sym)
                    return void 0;
                const type = instantiateAliasOrInterfaceWithDefaults(sym, isInJSFile(location));
                if (!type || isErrorType(type))
                    return void 0;
                return type;
            }
            function instantiateAliasOrInterfaceWithDefaults(managedSym, inJs, ...typeArguments) {
                const declaredManagedType = getDeclaredTypeOfSymbol(managedSym);
                if (managedSym.flags & 524288 /* TypeAlias */) {
                    const params = getSymbolLinks(managedSym).typeParameters;
                    if (length(params) >= typeArguments.length) {
                        const args = fillMissingTypeArguments(typeArguments, params, typeArguments.length, inJs);
                        return length(args) === 0 ? declaredManagedType : getTypeAliasInstantiation(managedSym, args);
                    }
                }
                if (length(declaredManagedType.typeParameters) >= typeArguments.length) {
                    const args = fillMissingTypeArguments(typeArguments, declaredManagedType.typeParameters, typeArguments.length, inJs);
                    return createTypeReference(declaredManagedType, args);
                }
                return void 0;
            }
            function getJsxIntrinsicTagNamesAt(location) {
                const intrinsics = getJsxType(JsxNames.IntrinsicElements, location);
                return intrinsics ? getPropertiesOfType(intrinsics) : emptyArray;
            }
            function checkJsxPreconditions(errorNode) {
                if ((compilerOptions.jsx || 0 /* None */) === 0 /* None */) {
                    error2(errorNode, Diagnostics.Cannot_use_JSX_unless_the_jsx_flag_is_provided);
                }
                if (getJsxElementTypeAt(errorNode) === void 0) {
                    if (noImplicitAny) {
                        error2(errorNode, Diagnostics.JSX_element_implicitly_has_type_any_because_the_global_type_JSX_Element_does_not_exist);
                    }
                }
            }
            function checkJsxOpeningLikeElementOrOpeningFragment(node) {
                const isNodeOpeningLikeElement = isJsxOpeningLikeElement(node);
                if (isNodeOpeningLikeElement) {
                    checkGrammarJsxElement(node);
                }
                checkJsxPreconditions(node);
                if (!getJsxNamespaceContainerForImplicitImport(node)) {
                    const jsxFactoryRefErr = diagnostics && compilerOptions.jsx === 2 /* React */ ? Diagnostics.Cannot_find_name_0 : void 0;
                    const jsxFactoryNamespace = getJsxNamespace(node);
                    const jsxFactoryLocation = isNodeOpeningLikeElement ? node.tagName : node;
                    let jsxFactorySym;
                    if (!(isJsxOpeningFragment(node) && jsxFactoryNamespace === "null")) {
                        jsxFactorySym = resolveName(jsxFactoryLocation, jsxFactoryNamespace, 111551 /* Value */, jsxFactoryRefErr, jsxFactoryNamespace, 
                        /*isUse*/
                        true);
                    }
                    if (jsxFactorySym) {
                        jsxFactorySym.isReferenced = -1 /* All */;
                        if (canCollectSymbolAliasAccessabilityData && jsxFactorySym.flags & 2097152 /* Alias */ && !getTypeOnlyAliasDeclaration(jsxFactorySym)) {
                            markAliasSymbolAsReferenced(jsxFactorySym);
                        }
                    }
                    if (isJsxOpeningFragment(node)) {
                        const file = getSourceFileOfNode(node);
                        const localJsxNamespace = getLocalJsxNamespace(file);
                        if (localJsxNamespace) {
                            resolveName(jsxFactoryLocation, localJsxNamespace, 111551 /* Value */, jsxFactoryRefErr, localJsxNamespace, 
                            /*isUse*/
                            true);
                        }
                    }
                }
                if (isNodeOpeningLikeElement) {
                    const jsxOpeningLikeNode = node;
                    const sig = getResolvedSignature(jsxOpeningLikeNode);
                    checkDeprecatedSignature(sig, node);
                    const elementTypeConstraint = getJsxElementTypeTypeAt(jsxOpeningLikeNode);
                    if (elementTypeConstraint !== void 0) {
                        const tagName = jsxOpeningLikeNode.tagName;
                        const tagType = isJsxIntrinsicTagName(tagName) ? getStringLiteralType(intrinsicTagNameToString(tagName)) : checkExpression(tagName);
                        checkTypeRelatedTo(tagType, elementTypeConstraint, assignableRelation, tagName, Diagnostics.Its_type_0_is_not_a_valid_JSX_element_type, () => {
                            const componentName = getTextOfNode(tagName);
                            return chainDiagnosticMessages(
                            /*details*/
                            void 0, Diagnostics._0_cannot_be_used_as_a_JSX_component, componentName);
                        });
                    }
                    else {
                        checkJsxReturnAssignableToAppropriateBound(getJsxReferenceKind(jsxOpeningLikeNode), getReturnTypeOfSignature(sig), jsxOpeningLikeNode);
                    }
                }
            }
            function isKnownProperty(targetType, name, isComparingJsxAttributes) {
                if (targetType.flags & 524288 /* Object */) {
                    if (getPropertyOfObjectType(targetType, name) || getApplicableIndexInfoForName(targetType, name) || isLateBoundName(name) && getIndexInfoOfType(targetType, stringType) || isComparingJsxAttributes && isHyphenatedJsxName(name)) {
                        return true;
                    }
                }
                else if (targetType.flags & 3145728 /* UnionOrIntersection */ && isExcessPropertyCheckTarget(targetType)) {
                    for (const t of targetType.types) {
                        if (isKnownProperty(t, name, isComparingJsxAttributes)) {
                            return true;
                        }
                    }
                }
                return false;
            }
            function isExcessPropertyCheckTarget(type) {
                return !!(type.flags & 524288 /* Object */ && !(getObjectFlags(type) & 512 /* ObjectLiteralPatternWithComputedProperties */) || type.flags & 67108864 /* NonPrimitive */ || type.flags & 1048576 /* Union */ && some(type.types, isExcessPropertyCheckTarget) || type.flags & 2097152 /* Intersection */ && every(type.types, isExcessPropertyCheckTarget));
            }
            function checkJsxExpression(node, checkMode) {
                checkGrammarJsxExpression(node);
                if (node.expression) {
                    const type = checkExpression(node.expression, checkMode);
                    if (node.dotDotDotToken && type !== anyType && !isArrayType(type)) {
                        error2(node, Diagnostics.JSX_spread_child_must_be_an_array_type);
                    }
                    return type;
                }
                else {
                    return errorType;
                }
            }
            function getDeclarationNodeFlagsFromSymbol(s) {
                return s.valueDeclaration ? getCombinedNodeFlagsCached(s.valueDeclaration) : 0;
            }
            function isPrototypeProperty(symbol) {
                if (symbol.flags & 8192 /* Method */ || getCheckFlags(symbol) & 4 /* SyntheticMethod */) {
                    return true;
                }
                if (isInJSFile(symbol.valueDeclaration)) {
                    const parent2 = symbol.valueDeclaration.parent;
                    return parent2 && isBinaryExpression(parent2) && getAssignmentDeclarationKind(parent2) === 3 /* PrototypeProperty */;
                }
            }
            function checkPropertyAccessibility(node, isSuper, writing, type, prop, reportError = true) {
                const errorNode = !reportError ? void 0 : node.kind === 166 /* QualifiedName */ ? node.right : node.kind === 205 /* ImportType */ ? node : node.kind === 208 /* BindingElement */ && node.propertyName ? node.propertyName : node.name;
                return checkPropertyAccessibilityAtLocation(node, isSuper, writing, type, prop, errorNode);
            }
            function checkPropertyAccessibilityAtLocation(location, isSuper, writing, containingType, prop, errorNode) {
                var _a;
                const flags = getDeclarationModifierFlagsFromSymbol(prop, writing);
                if (isSuper) {
                    if (languageVersion < 2 /* ES2015 */) {
                        if (symbolHasNonMethodDeclaration(prop)) {
                            if (errorNode) {
                                error2(errorNode, Diagnostics.Only_public_and_protected_methods_of_the_base_class_are_accessible_via_the_super_keyword);
                            }
                            return false;
                        }
                    }
                    if (flags & 64 /* Abstract */) {
                        if (errorNode) {
                            error2(errorNode, Diagnostics.Abstract_method_0_in_class_1_cannot_be_accessed_via_super_expression, symbolToString(prop), typeToString(getDeclaringClass(prop)));
                        }
                        return false;
                    }
                    if (!(flags & 256 /* Static */) && ((_a = prop.declarations) == null ? void 0 : _a.some(isClassInstanceProperty))) {
                        if (errorNode) {
                            error2(errorNode, Diagnostics.Class_field_0_defined_by_the_parent_class_is_not_accessible_in_the_child_class_via_super, symbolToString(prop));
                        }
                        return false;
                    }
                }
                if (flags & 64 /* Abstract */ && symbolHasNonMethodDeclaration(prop) && (isThisProperty(location) || isThisInitializedObjectBindingExpression(location) || isObjectBindingPattern(location.parent) && isThisInitializedDeclaration(location.parent.parent))) {
                    const declaringClassDeclaration = getClassLikeDeclarationOfSymbol(getParentOfSymbol(prop));
                    if (declaringClassDeclaration && isNodeUsedDuringClassInitialization(location)) {
                        if (errorNode) {
                            error2(errorNode, Diagnostics.Abstract_property_0_in_class_1_cannot_be_accessed_in_the_constructor, symbolToString(prop), getTextOfIdentifierOrLiteral(declaringClassDeclaration.name));
                        }
                        return false;
                    }
                }
                if (!(flags & 6 /* NonPublicAccessibilityModifier */)) {
                    return true;
                }
                if (flags & 2 /* Private */) {
                    const declaringClassDeclaration = getClassLikeDeclarationOfSymbol(getParentOfSymbol(prop));
                    if (!isNodeWithinClass(location, declaringClassDeclaration)) {
                        if (errorNode) {
                            error2(errorNode, Diagnostics.Property_0_is_private_and_only_accessible_within_class_1, symbolToString(prop), typeToString(getDeclaringClass(prop)));
                        }
                        return false;
                    }
                    return true;
                }
                if (isSuper) {
                    return true;
                }
                let enclosingClass = forEachEnclosingClass(location, (enclosingDeclaration) => {
                    const enclosingClass2 = getDeclaredTypeOfSymbol(getSymbolOfDeclaration(enclosingDeclaration));
                    return isClassDerivedFromDeclaringClasses(enclosingClass2, prop, writing);
                });
                if (!enclosingClass) {
                    enclosingClass = getEnclosingClassFromThisParameter(location);
                    enclosingClass = enclosingClass && isClassDerivedFromDeclaringClasses(enclosingClass, prop, writing);
                    if (flags & 256 /* Static */ || !enclosingClass) {
                        if (errorNode) {
                            error2(errorNode, Diagnostics.Property_0_is_protected_and_only_accessible_within_class_1_and_its_subclasses, symbolToString(prop), typeToString(getDeclaringClass(prop) || containingType));
                        }
                        return false;
                    }
                }
                if (flags & 256 /* Static */) {
                    return true;
                }
                if (containingType.flags & 262144 /* TypeParameter */) {
                    containingType = containingType.isThisType ? getConstraintOfTypeParameter(containingType) : getBaseConstraintOfType(containingType);
                }
                if (!containingType || !hasBaseType(containingType, enclosingClass)) {
                    if (errorNode) {
                        error2(errorNode, Diagnostics.Property_0_is_protected_and_only_accessible_through_an_instance_of_class_1_This_is_an_instance_of_class_2, symbolToString(prop), typeToString(enclosingClass), typeToString(containingType));
                    }
                    return false;
                }
                return true;
            }
            function getEnclosingClassFromThisParameter(node) {
                const thisParameter = getThisParameterFromNodeContext(node);
                let thisType = (thisParameter == null ? void 0 : thisParameter.type) && getTypeFromTypeNode(thisParameter.type);
                if (thisType && thisType.flags & 262144 /* TypeParameter */) {
                    thisType = getConstraintOfTypeParameter(thisType);
                }
                if (thisType && getObjectFlags(thisType) & (3 /* ClassOrInterface */ | 4 /* Reference */)) {
                    return getTargetType(thisType);
                }
                return void 0;
            }
            function getThisParameterFromNodeContext(node) {
                const thisContainer = getThisContainer(node, 
                /*includeArrowFunctions*/
                false, 
                /*includeClassComputedPropertyName*/
                false);
                return thisContainer && isFunctionLike(thisContainer) ? getThisParameter(thisContainer) : void 0;
            }
            function symbolHasNonMethodDeclaration(symbol) {
                return !!forEachProperty2(symbol, (prop) => !(prop.flags & 8192 /* Method */));
            }
            function checkNonNullExpression(node) {
                return checkNonNullType(checkExpression(node), node);
            }
            function isNullableType(type) {
                return hasTypeFacts(type, 50331648 /* IsUndefinedOrNull */);
            }
            function getNonNullableTypeIfNeeded(type) {
                return isNullableType(type) ? getNonNullableType(type) : type;
            }
            function reportObjectPossiblyNullOrUndefinedError(node, facts) {
                const nodeText2 = isEntityNameExpression(node) ? entityNameToString(node) : void 0;
                if (node.kind === 106 /* NullKeyword */) {
                    error2(node, Diagnostics.The_value_0_cannot_be_used_here, "null");
                    return;
                }
                if (nodeText2 !== void 0 && nodeText2.length < 100) {
                    if (isIdentifier(node) && nodeText2 === "undefined") {
                        error2(node, Diagnostics.The_value_0_cannot_be_used_here, "undefined");
                        return;
                    }
                    error2(node, facts & 16777216 /* IsUndefined */ ? facts & 33554432 /* IsNull */ ? Diagnostics._0_is_possibly_null_or_undefined : Diagnostics._0_is_possibly_undefined : Diagnostics._0_is_possibly_null, nodeText2);
                }
                else {
                    error2(node, facts & 16777216 /* IsUndefined */ ? facts & 33554432 /* IsNull */ ? Diagnostics.Object_is_possibly_null_or_undefined : Diagnostics.Object_is_possibly_undefined : Diagnostics.Object_is_possibly_null);
                }
            }
            function reportCannotInvokePossiblyNullOrUndefinedError(node, facts) {
                error2(node, facts & 16777216 /* IsUndefined */ ? facts & 33554432 /* IsNull */ ? Diagnostics.Cannot_invoke_an_object_which_is_possibly_null_or_undefined : Diagnostics.Cannot_invoke_an_object_which_is_possibly_undefined : Diagnostics.Cannot_invoke_an_object_which_is_possibly_null);
            }
            function checkNonNullTypeWithReporter(type, node, reportError) {
                if (strictNullChecks && type.flags & 2 /* Unknown */) {
                    if (isEntityNameExpression(node)) {
                        const nodeText2 = entityNameToString(node);
                        if (nodeText2.length < 100) {
                            error2(node, Diagnostics._0_is_of_type_unknown, nodeText2);
                            return errorType;
                        }
                    }
                    error2(node, Diagnostics.Object_is_of_type_unknown);
                    return errorType;
                }
                const facts = getTypeFacts(type, 50331648 /* IsUndefinedOrNull */);
                if (facts & 50331648 /* IsUndefinedOrNull */) {
                    reportError(node, facts);
                    const t = getNonNullableType(type);
                    return t.flags & (98304 /* Nullable */ | 131072 /* Never */) ? errorType : t;
                }
                return type;
            }
            function checkNonNullType(type, node) {
                return checkNonNullTypeWithReporter(type, node, reportObjectPossiblyNullOrUndefinedError);
            }
            function checkNonNullNonVoidType(type, node) {
                const nonNullType = checkNonNullType(type, node);
                if (nonNullType.flags & 16384 /* Void */) {
                    if (isEntityNameExpression(node)) {
                        const nodeText2 = entityNameToString(node);
                        if (isIdentifier(node) && nodeText2 === "undefined") {
                            error2(node, Diagnostics.The_value_0_cannot_be_used_here, nodeText2);
                            return nonNullType;
                        }
                        if (nodeText2.length < 100) {
                            error2(node, Diagnostics._0_is_possibly_undefined, nodeText2);
                            return nonNullType;
                        }
                    }
                    error2(node, Diagnostics.Object_is_possibly_undefined);
                }
                return nonNullType;
            }
            function checkPropertyAccessExpression(node, checkMode, writeOnly) {
                return node.flags & 64 /* OptionalChain */ ? checkPropertyAccessChain(node, checkMode) : checkPropertyAccessExpressionOrQualifiedName(node, node.expression, checkNonNullExpression(node.expression), node.name, checkMode, writeOnly);
            }
            function checkPropertyAccessChain(node, checkMode) {
                const leftType = checkExpression(node.expression);
                const nonOptionalType = getOptionalExpressionType(leftType, node.expression);
                return propagateOptionalTypeMarker(checkPropertyAccessExpressionOrQualifiedName(node, node.expression, checkNonNullType(nonOptionalType, node.expression), node.name, checkMode), node, nonOptionalType !== leftType);
            }
            function checkQualifiedName(node, checkMode) {
                const leftType = isPartOfTypeQuery(node) && isThisIdentifier(node.left) ? checkNonNullType(checkThisExpression(node.left), node.left) : checkNonNullExpression(node.left);
                return checkPropertyAccessExpressionOrQualifiedName(node, node.left, leftType, node.right, checkMode);
            }
            function isMethodAccessForCall(node) {
                while (node.parent.kind === 217 /* ParenthesizedExpression */) {
                    node = node.parent;
                }
                return isCallOrNewExpression(node.parent) && node.parent.expression === node;
            }
            function lookupSymbolForPrivateIdentifierDeclaration(propName, location) {
                for (let containingClass = getContainingClassExcludingClassDecorators(location); !!containingClass; containingClass = getContainingClass(containingClass)) {
                    const { symbol } = containingClass;
                    const name = getSymbolNameForPrivateIdentifier(symbol, propName);
                    const prop = symbol.members && symbol.members.get(name) || symbol.exports && symbol.exports.get(name);
                    if (prop) {
                        return prop;
                    }
                }
            }
            function checkGrammarPrivateIdentifierExpression(privId) {
                if (!getContainingClass(privId)) {
                    return grammarErrorOnNode(privId, Diagnostics.Private_identifiers_are_not_allowed_outside_class_bodies);
                }
                if (!isForInStatement(privId.parent)) {
                    if (!isExpressionNode(privId)) {
                        return grammarErrorOnNode(privId, Diagnostics.Private_identifiers_are_only_allowed_in_class_bodies_and_may_only_be_used_as_part_of_a_class_member_declaration_property_access_or_on_the_left_hand_side_of_an_in_expression);
                    }
                    const isInOperation = isBinaryExpression(privId.parent) && privId.parent.operatorToken.kind === 103 /* InKeyword */;
                    if (!getSymbolForPrivateIdentifierExpression(privId) && !isInOperation) {
                        return grammarErrorOnNode(privId, Diagnostics.Cannot_find_name_0, idText(privId));
                    }
                }
                return false;
            }
            function checkPrivateIdentifierExpression(privId) {
                checkGrammarPrivateIdentifierExpression(privId);
                const symbol = getSymbolForPrivateIdentifierExpression(privId);
                if (symbol) {
                    markPropertyAsReferenced(symbol, 
                    /*nodeForCheckWriteOnly*/
                    void 0, 
                    /*isSelfTypeAccess*/
                    false);
                }
                return anyType;
            }
            function getSymbolForPrivateIdentifierExpression(privId) {
                if (!isExpressionNode(privId)) {
                    return void 0;
                }
                const links = getNodeLinks(privId);
                if (links.resolvedSymbol === void 0) {
                    links.resolvedSymbol = lookupSymbolForPrivateIdentifierDeclaration(privId.escapedText, privId);
                }
                return links.resolvedSymbol;
            }
            function getPrivateIdentifierPropertyOfType(leftType, lexicallyScopedIdentifier) {
                return getPropertyOfType(leftType, lexicallyScopedIdentifier.escapedName);
            }
            function checkPrivateIdentifierPropertyAccess(leftType, right, lexicallyScopedIdentifier) {
                let propertyOnType;
                const properties = getPropertiesOfType(leftType);
                if (properties) {
                    forEach(properties, (symbol) => {
                        const decl = symbol.valueDeclaration;
                        if (decl && isNamedDeclaration(decl) && isPrivateIdentifier(decl.name) && decl.name.escapedText === right.escapedText) {
                            propertyOnType = symbol;
                            return true;
                        }
                    });
                }
                const diagName = diagnosticName(right);
                if (propertyOnType) {
                    const typeValueDecl = Debug.checkDefined(propertyOnType.valueDeclaration);
                    const typeClass = Debug.checkDefined(getContainingClass(typeValueDecl));
                    if (lexicallyScopedIdentifier == null ? void 0 : lexicallyScopedIdentifier.valueDeclaration) {
                        const lexicalValueDecl = lexicallyScopedIdentifier.valueDeclaration;
                        const lexicalClass = getContainingClass(lexicalValueDecl);
                        Debug.assert(!!lexicalClass);
                        if (findAncestor(lexicalClass, (n) => typeClass === n)) {
                            const diagnostic = error2(right, Diagnostics.The_property_0_cannot_be_accessed_on_type_1_within_this_class_because_it_is_shadowed_by_another_private_identifier_with_the_same_spelling, diagName, typeToString(leftType));
                            addRelatedInfo(diagnostic, createDiagnosticForNode(lexicalValueDecl, Diagnostics.The_shadowing_declaration_of_0_is_defined_here, diagName), createDiagnosticForNode(typeValueDecl, Diagnostics.The_declaration_of_0_that_you_probably_intended_to_use_is_defined_here, diagName));
                            return true;
                        }
                    }
                    error2(right, Diagnostics.Property_0_is_not_accessible_outside_class_1_because_it_has_a_private_identifier, diagName, diagnosticName(typeClass.name || anon));
                    return true;
                }
                return false;
            }
            function isThisPropertyAccessInConstructor(node, prop) {
                return (isConstructorDeclaredProperty(prop) || isThisProperty(node) && isAutoTypedProperty(prop)) && getThisContainer(node, 
                /*includeArrowFunctions*/
                true, 
                /*includeClassComputedPropertyName*/
                false) === getDeclaringConstructor(prop);
            }
            function checkPropertyAccessExpressionOrQualifiedName(node, left, leftType, right, checkMode, writeOnly) {
                const parentSymbol = getNodeLinks(left).resolvedSymbol;
                const assignmentKind = getAssignmentTargetKind(node);
                const apparentType = getApparentType(assignmentKind !== 0 /* None */ || isMethodAccessForCall(node) ? getWidenedType(leftType) : leftType);
                const isAnyLike = isTypeAny(apparentType) || apparentType === silentNeverType;
                let prop;
                if (isPrivateIdentifier(right)) {
                    if (languageVersion < 99 /* ESNext */) {
                        if (assignmentKind !== 0 /* None */) {
                            checkExternalEmitHelpers(node, 1048576 /* ClassPrivateFieldSet */);
                        }
                        if (assignmentKind !== 1 /* Definite */) {
                            checkExternalEmitHelpers(node, 524288 /* ClassPrivateFieldGet */);
                        }
                    }
                    const lexicallyScopedSymbol = lookupSymbolForPrivateIdentifierDeclaration(right.escapedText, right);
                    if (assignmentKind && lexicallyScopedSymbol && lexicallyScopedSymbol.valueDeclaration && isMethodDeclaration(lexicallyScopedSymbol.valueDeclaration)) {
                        grammarErrorOnNode(right, Diagnostics.Cannot_assign_to_private_method_0_Private_methods_are_not_writable, idText(right));
                    }
                    if (isAnyLike) {
                        if (lexicallyScopedSymbol) {
                            return isErrorType(apparentType) ? errorType : apparentType;
                        }
                        if (getContainingClassExcludingClassDecorators(right) === void 0) {
                            grammarErrorOnNode(right, Diagnostics.Private_identifiers_are_not_allowed_outside_class_bodies);
                            return anyType;
                        }
                    }
                    prop = lexicallyScopedSymbol && getPrivateIdentifierPropertyOfType(leftType, lexicallyScopedSymbol);
                    if (prop === void 0) {
                        if (checkPrivateIdentifierPropertyAccess(leftType, right, lexicallyScopedSymbol)) {
                            return errorType;
                        }
                        const containingClass = getContainingClassExcludingClassDecorators(right);
                        if (containingClass && isPlainJsFile(getSourceFileOfNode(containingClass), compilerOptions.checkJs)) {
                            grammarErrorOnNode(right, Diagnostics.Private_field_0_must_be_declared_in_an_enclosing_class, idText(right));
                        }
                    }
                    else {
                        const isSetonlyAccessor = prop.flags & 65536 /* SetAccessor */ && !(prop.flags & 32768 /* GetAccessor */);
                        if (isSetonlyAccessor && assignmentKind !== 1 /* Definite */) {
                            error2(node, Diagnostics.Private_accessor_was_defined_without_a_getter);
                        }
                    }
                }
                else {
                    if (isAnyLike) {
                        if (isIdentifier(left) && parentSymbol) {
                            markAliasReferenced(parentSymbol, node);
                        }
                        return isErrorType(apparentType) ? errorType : apparentType;
                    }
                    prop = getPropertyOfType(apparentType, right.escapedText, 
                    /*skipObjectFunctionPropertyAugment*/
                    isConstEnumObjectType(apparentType), 
                    /*includeTypeOnlyMembers*/
                    node.kind === 166 /* QualifiedName */);
                }
                if (isIdentifier(left) && parentSymbol && (getIsolatedModules(compilerOptions) || !(prop && (isConstEnumOrConstEnumOnlyModule(prop) || prop.flags & 8 /* EnumMember */ && node.parent.kind === 306 /* EnumMember */)) || shouldPreserveConstEnums(compilerOptions) && isExportOrExportExpression(node))) {
                    markAliasReferenced(parentSymbol, node);
                }
                let propType;
                if (!prop) {
                    const indexInfo = !isPrivateIdentifier(right) && (assignmentKind === 0 /* None */ || !isGenericObjectType(leftType) || isThisTypeParameter(leftType)) ? getApplicableIndexInfoForName(apparentType, right.escapedText) : void 0;
                    if (!(indexInfo && indexInfo.type)) {
                        const isUncheckedJS = isUncheckedJSSuggestion(node, leftType.symbol, 
                        /*excludeClasses*/
                        true);
                        if (!isUncheckedJS && isJSLiteralType(leftType)) {
                            return anyType;
                        }
                        if (leftType.symbol === globalThisSymbol) {
                            if (globalThisSymbol.exports.has(right.escapedText) && globalThisSymbol.exports.get(right.escapedText).flags & 418 /* BlockScoped */) {
                                error2(right, Diagnostics.Property_0_does_not_exist_on_type_1, unescapeLeadingUnderscores(right.escapedText), typeToString(leftType));
                            }
                            else if (noImplicitAny) {
                                error2(right, Diagnostics.Element_implicitly_has_an_any_type_because_type_0_has_no_index_signature, typeToString(leftType));
                            }
                            return anyType;
                        }
                        if (right.escapedText && !checkAndReportErrorForExtendingInterface(node)) {
                            reportNonexistentProperty(right, isThisTypeParameter(leftType) ? apparentType : leftType, isUncheckedJS);
                        }
                        return errorType;
                    }
                    if (indexInfo.isReadonly && (isAssignmentTarget(node) || isDeleteTarget(node))) {
                        error2(node, Diagnostics.Index_signature_in_type_0_only_permits_reading, typeToString(apparentType));
                    }
                    propType = compilerOptions.noUncheckedIndexedAccess && !isAssignmentTarget(node) ? getUnionType([indexInfo.type, missingType]) : indexInfo.type;
                    if (compilerOptions.noPropertyAccessFromIndexSignature && isPropertyAccessExpression(node)) {
                        error2(right, Diagnostics.Property_0_comes_from_an_index_signature_so_it_must_be_accessed_with_0, unescapeLeadingUnderscores(right.escapedText));
                    }
                    if (indexInfo.declaration && isDeprecatedDeclaration2(indexInfo.declaration)) {
                        addDeprecatedSuggestion(right, [indexInfo.declaration], right.escapedText);
                    }
                }
                else {
                    const targetPropSymbol = resolveAliasWithDeprecationCheck(prop, right);
                    if (isDeprecatedSymbol(targetPropSymbol) && isUncalledFunctionReference(node, targetPropSymbol) && targetPropSymbol.declarations) {
                        addDeprecatedSuggestion(right, targetPropSymbol.declarations, right.escapedText);
                    }
                    checkPropertyNotUsedBeforeDeclaration(prop, node, right);
                    markPropertyAsReferenced(prop, node, isSelfTypeAccess(left, parentSymbol));
                    getNodeLinks(node).resolvedSymbol = prop;
                    checkPropertyAccessibility(node, left.kind === 108 /* SuperKeyword */, isWriteAccess(node), apparentType, prop);
                    if (isAssignmentToReadonlyEntity(node, prop, assignmentKind)) {
                        error2(right, Diagnostics.Cannot_assign_to_0_because_it_is_a_read_only_property, idText(right));
                        return errorType;
                    }
                    propType = isThisPropertyAccessInConstructor(node, prop) ? autoType : writeOnly || isWriteOnlyAccess(node) ? getWriteTypeOfSymbol(prop) : getTypeOfSymbol(prop);
                }
                return getFlowTypeOfAccessExpression(node, prop, propType, right, checkMode);
            }
            function isUncheckedJSSuggestion(node, suggestion, excludeClasses) {
                var _a;
                const file = getSourceFileOfNode(node);
                if (file) {
                    if (compilerOptions.checkJs === void 0 && file.checkJsDirective === void 0 && (file.scriptKind === 1 /* JS */ || file.scriptKind === 2 /* JSX */)) {
                        const declarationFile = forEach(suggestion == null ? void 0 : suggestion.declarations, getSourceFileOfNode);
                        const suggestionHasNoExtendsOrDecorators = !(suggestion == null ? void 0 : suggestion.valueDeclaration) || !isClassLike(suggestion.valueDeclaration) || ((_a = suggestion.valueDeclaration.heritageClauses) == null ? void 0 : _a.length) || classOrConstructorParameterIsDecorated(
                        /*useLegacyDecorators*/
                        false, suggestion.valueDeclaration);
                        return !(file !== declarationFile && !!declarationFile && isGlobalSourceFile(declarationFile)) && !(excludeClasses && suggestion && suggestion.flags & 32 /* Class */ && suggestionHasNoExtendsOrDecorators) && !(!!node && excludeClasses && isPropertyAccessExpression(node) && node.expression.kind === 110 /* ThisKeyword */ && suggestionHasNoExtendsOrDecorators);
                    }
                }
                return false;
            }
            function getFlowTypeOfAccessExpression(node, prop, propType, errorNode, checkMode) {
                const assignmentKind = getAssignmentTargetKind(node);
                if (assignmentKind === 1 /* Definite */) {
                    return removeMissingType(propType, !!(prop && prop.flags & 16777216 /* Optional */));
                }
                if (prop && !(prop.flags & (3 /* Variable */ | 4 /* Property */ | 98304 /* Accessor */)) && !(prop.flags & 8192 /* Method */ && propType.flags & 1048576 /* Union */) && !isDuplicatedCommonJSExport(prop.declarations)) {
                    return propType;
                }
                if (propType === autoType) {
                    return getFlowTypeOfProperty(node, prop);
                }
                propType = getNarrowableTypeForReference(propType, node, checkMode);
                let assumeUninitialized = false;
                if (strictNullChecks && strictPropertyInitialization && isAccessExpression(node) && node.expression.kind === 110 /* ThisKeyword */) {
                    const declaration = prop && prop.valueDeclaration;
                    if (declaration && isPropertyWithoutInitializer(declaration)) {
                        if (!isStatic(declaration)) {
                            const flowContainer = getControlFlowContainer(node);
                            if (flowContainer.kind === 176 /* Constructor */ && flowContainer.parent === declaration.parent && !(declaration.flags & 33554432 /* Ambient */)) {
                                assumeUninitialized = true;
                            }
                        }
                    }
                }
                else if (strictNullChecks && prop && prop.valueDeclaration && isPropertyAccessExpression(prop.valueDeclaration) && getAssignmentDeclarationPropertyAccessKind(prop.valueDeclaration) && getControlFlowContainer(node) === getControlFlowContainer(prop.valueDeclaration)) {
                    assumeUninitialized = true;
                }
                const flowType = getFlowTypeOfReference(node, propType, assumeUninitialized ? getOptionalType(propType) : propType);
                if (assumeUninitialized && !containsUndefinedType(propType) && containsUndefinedType(flowType)) {
                    error2(errorNode, Diagnostics.Property_0_is_used_before_being_assigned, symbolToString(prop));
                    return propType;
                }
                return assignmentKind ? getBaseTypeOfLiteralType(flowType) : flowType;
            }
            function checkPropertyNotUsedBeforeDeclaration(prop, node, right) {
                const { valueDeclaration } = prop;
                if (!valueDeclaration || getSourceFileOfNode(node).isDeclarationFile) {
                    return;
                }
                let diagnosticMessage;
                const declarationName = idText(right);
                if (isInPropertyInitializerOrClassStaticBlock(node) && !isOptionalPropertyDeclaration(valueDeclaration) && !(isAccessExpression(node) && isAccessExpression(node.expression)) && !isBlockScopedNameDeclaredBeforeUse(valueDeclaration, right) && !(isMethodDeclaration(valueDeclaration) && getCombinedModifierFlagsCached(valueDeclaration) & 256 /* Static */) && (useDefineForClassFields || !isPropertyDeclaredInAncestorClass(prop))) {
                    diagnosticMessage = error2(right, Diagnostics.Property_0_is_used_before_its_initialization, declarationName);
                }
                else if (valueDeclaration.kind === 263 /* ClassDeclaration */ && node.parent.kind !== 183 /* TypeReference */ && !(valueDeclaration.flags & 33554432 /* Ambient */) && !isBlockScopedNameDeclaredBeforeUse(valueDeclaration, right)) {
                    diagnosticMessage = error2(right, Diagnostics.Class_0_used_before_its_declaration, declarationName);
                }
                if (diagnosticMessage) {
                    addRelatedInfo(diagnosticMessage, createDiagnosticForNode(valueDeclaration, Diagnostics._0_is_declared_here, declarationName));
                }
            }
            function isInPropertyInitializerOrClassStaticBlock(node) {
                return !!findAncestor(node, (node2) => {
                    switch (node2.kind) {
                        case 172 /* PropertyDeclaration */:
                            return true;
                        case 303 /* PropertyAssignment */:
                        case 174 /* MethodDeclaration */:
                        case 177 /* GetAccessor */:
                        case 178 /* SetAccessor */:
                        case 305 /* SpreadAssignment */:
                        case 167 /* ComputedPropertyName */:
                        case 239 /* TemplateSpan */:
                        case 294 /* JsxExpression */:
                        case 291 /* JsxAttribute */:
                        case 292 /* JsxAttributes */:
                        case 293 /* JsxSpreadAttribute */:
                        case 286 /* JsxOpeningElement */:
                        case 233 /* ExpressionWithTypeArguments */:
                        case 298 /* HeritageClause */:
                            return false;
                        case 219 /* ArrowFunction */:
                        case 244 /* ExpressionStatement */:
                            return isBlock(node2.parent) && isClassStaticBlockDeclaration(node2.parent.parent) ? true : "quit";
                        default:
                            return isExpressionNode(node2) ? false : "quit";
                    }
                });
            }
            function isPropertyDeclaredInAncestorClass(prop) {
                if (!(prop.parent.flags & 32 /* Class */)) {
                    return false;
                }
                let classType = getTypeOfSymbol(prop.parent);
                while (true) {
                    classType = classType.symbol && getSuperClass(classType);
                    if (!classType) {
                        return false;
                    }
                    const superProperty = getPropertyOfType(classType, prop.escapedName);
                    if (superProperty && superProperty.valueDeclaration) {
                        return true;
                    }
                }
            }
            function getSuperClass(classType) {
                const x = getBaseTypes(classType);
                if (x.length === 0) {
                    return void 0;
                }
                return getIntersectionType(x);
            }
            function reportNonexistentProperty(propNode, containingType, isUncheckedJS) {
                let errorInfo;
                let relatedInfo;
                if (!isPrivateIdentifier(propNode) && containingType.flags & 1048576 /* Union */ && !(containingType.flags & 402784252 /* Primitive */)) {
                    for (const subtype of containingType.types) {
                        if (!getPropertyOfType(subtype, propNode.escapedText) && !getApplicableIndexInfoForName(subtype, propNode.escapedText)) {
                            errorInfo = chainDiagnosticMessages(errorInfo, Diagnostics.Property_0_does_not_exist_on_type_1, declarationNameToString(propNode), typeToString(subtype));
                            break;
                        }
                    }
                }
                if (typeHasStaticProperty(propNode.escapedText, containingType)) {
                    const propName = declarationNameToString(propNode);
                    const typeName = typeToString(containingType);
                    errorInfo = chainDiagnosticMessages(errorInfo, Diagnostics.Property_0_does_not_exist_on_type_1_Did_you_mean_to_access_the_static_member_2_instead, propName, typeName, typeName + "." + propName);
                }
                else {
                    const promisedType = getPromisedTypeOfPromise(containingType);
                    if (promisedType && getPropertyOfType(promisedType, propNode.escapedText)) {
                        errorInfo = chainDiagnosticMessages(errorInfo, Diagnostics.Property_0_does_not_exist_on_type_1, declarationNameToString(propNode), typeToString(containingType));
                        relatedInfo = createDiagnosticForNode(propNode, Diagnostics.Did_you_forget_to_use_await);
                    }
                    else {
                        const missingProperty = declarationNameToString(propNode);
                        const container = typeToString(containingType);
                        const libSuggestion = getSuggestedLibForNonExistentProperty(missingProperty, containingType);
                        if (libSuggestion !== void 0) {
                            errorInfo = chainDiagnosticMessages(errorInfo, Diagnostics.Property_0_does_not_exist_on_type_1_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_2_or_later, missingProperty, container, libSuggestion);
                        }
                        else {
                            const suggestion = getSuggestedSymbolForNonexistentProperty(propNode, containingType);
                            if (suggestion !== void 0) {
                                const suggestedName = symbolName(suggestion);
                                const message = isUncheckedJS ? Diagnostics.Property_0_may_not_exist_on_type_1_Did_you_mean_2 : Diagnostics.Property_0_does_not_exist_on_type_1_Did_you_mean_2;
                                errorInfo = chainDiagnosticMessages(errorInfo, message, missingProperty, container, suggestedName);
                                relatedInfo = suggestion.valueDeclaration && createDiagnosticForNode(suggestion.valueDeclaration, Diagnostics._0_is_declared_here, suggestedName);
                            }
                            else {
                                const diagnostic = containerSeemsToBeEmptyDomElement(containingType) ? Diagnostics.Property_0_does_not_exist_on_type_1_Try_changing_the_lib_compiler_option_to_include_dom : Diagnostics.Property_0_does_not_exist_on_type_1;
                                errorInfo = chainDiagnosticMessages(elaborateNeverIntersection(errorInfo, containingType), diagnostic, missingProperty, container);
                            }
                        }
                    }
                }
                const resultDiagnostic = createDiagnosticForNodeFromMessageChain(getSourceFileOfNode(propNode), propNode, errorInfo);
                if (relatedInfo) {
                    addRelatedInfo(resultDiagnostic, relatedInfo);
                }
                addErrorOrSuggestion(!isUncheckedJS || errorInfo.code !== Diagnostics.Property_0_may_not_exist_on_type_1_Did_you_mean_2.code, resultDiagnostic);
            }
            function containerSeemsToBeEmptyDomElement(containingType) {
                return compilerOptions.lib && !compilerOptions.lib.includes("dom") && everyContainedType(containingType, (type) => type.symbol && /^(EventTarget|Node|((HTML[a-zA-Z]*)?Element))$/.test(unescapeLeadingUnderscores(type.symbol.escapedName))) && isEmptyObjectType(containingType);
            }
            function typeHasStaticProperty(propName, containingType) {
                const prop = containingType.symbol && getPropertyOfType(getTypeOfSymbol(containingType.symbol), propName);
                return prop !== void 0 && !!prop.valueDeclaration && isStatic(prop.valueDeclaration);
            }
            function getSuggestedLibForNonExistentName(name) {
                const missingName = diagnosticName(name);
                const allFeatures = getScriptTargetFeatures();
                const typeFeatures = allFeatures.get(missingName);
                return typeFeatures && firstIterator(typeFeatures.keys());
            }
            function getSuggestedLibForNonExistentProperty(missingProperty, containingType) {
                const container = getApparentType(containingType).symbol;
                if (!container) {
                    return void 0;
                }
                const containingTypeName = symbolName(container);
                const allFeatures = getScriptTargetFeatures();
                const typeFeatures = allFeatures.get(containingTypeName);
                if (typeFeatures) {
                    for (const [libTarget, featuresOfType] of typeFeatures) {
                        if (contains(featuresOfType, missingProperty)) {
                            return libTarget;
                        }
                    }
                }
            }
            function getSuggestedSymbolForNonexistentClassMember(name, baseType) {
                return getSpellingSuggestionForName(name, getPropertiesOfType(baseType), 106500 /* ClassMember */);
            }
            function getSuggestedSymbolForNonexistentProperty(name, containingType) {
                let props = getPropertiesOfType(containingType);
                if (typeof name !== "string") {
                    const parent2 = name.parent;
                    if (isPropertyAccessExpression(parent2)) {
                        props = filter(props, (prop) => isValidPropertyAccessForCompletions(parent2, containingType, prop));
                    }
                    name = idText(name);
                }
                return getSpellingSuggestionForName(name, props, 111551 /* Value */);
            }
            function getSuggestedSymbolForNonexistentJSXAttribute(name, containingType) {
                const strName = isString(name) ? name : idText(name);
                const properties = getPropertiesOfType(containingType);
                const jsxSpecific = strName === "for" ? find(properties, (x) => symbolName(x) === "htmlFor") : strName === "class" ? find(properties, (x) => symbolName(x) === "className") : void 0;
                return jsxSpecific ?? getSpellingSuggestionForName(strName, properties, 111551 /* Value */);
            }
            function getSuggestionForNonexistentProperty(name, containingType) {
                const suggestion = getSuggestedSymbolForNonexistentProperty(name, containingType);
                return suggestion && symbolName(suggestion);
            }
            function getSuggestedSymbolForNonexistentSymbol(location, outerName, meaning) {
                Debug.assert(outerName !== void 0, "outername should always be defined");
                const result = resolveNameHelper(location, outerName, meaning, 
                /*nameNotFoundMessage*/
                void 0, outerName, 
                /*isUse*/
                false, 
                /*excludeGlobals*/
                false, 
                /*getSpellingSuggestions*/
                true, (symbols, name, meaning2) => {
                    Debug.assertEqual(outerName, name, "name should equal outerName");
                    const symbol = getSymbol2(symbols, name, meaning2);
                    if (symbol)
                        return symbol;
                    let candidates;
                    if (symbols === globals) {
                        const primitives = mapDefined(["string", "number", "boolean", "object", "bigint", "symbol"], (s) => symbols.has(s.charAt(0).toUpperCase() + s.slice(1)) ? createSymbol(524288 /* TypeAlias */, s) : void 0);
                        candidates = primitives.concat(arrayFrom(symbols.values()));
                    }
                    else {
                        candidates = arrayFrom(symbols.values());
                    }
                    return getSpellingSuggestionForName(unescapeLeadingUnderscores(name), candidates, meaning2);
                });
                return result;
            }
            function getSuggestionForNonexistentSymbol(location, outerName, meaning) {
                const symbolResult = getSuggestedSymbolForNonexistentSymbol(location, outerName, meaning);
                return symbolResult && symbolName(symbolResult);
            }
            function getSuggestedSymbolForNonexistentModule(name, targetModule) {
                return targetModule.exports && getSpellingSuggestionForName(idText(name), getExportsOfModuleAsArray(targetModule), 2623475 /* ModuleMember */);
            }
            function getSuggestionForNonexistentExport(name, targetModule) {
                const suggestion = getSuggestedSymbolForNonexistentModule(name, targetModule);
                return suggestion && symbolName(suggestion);
            }
            function getSuggestionForNonexistentIndexSignature(objectType, expr, keyedType) {
                function hasProp(name) {
                    const prop = getPropertyOfObjectType(objectType, name);
                    if (prop) {
                        const s = getSingleCallSignature(getTypeOfSymbol(prop));
                        return !!s && getMinArgumentCount(s) >= 1 && isTypeAssignableTo(keyedType, getTypeAtPosition(s, 0));
                    }
                    return false;
                }
                const suggestedMethod = isAssignmentTarget(expr) ? "set" : "get";
                if (!hasProp(suggestedMethod)) {
                    return void 0;
                }
                let suggestion = tryGetPropertyAccessOrIdentifierToString(expr.expression);
                if (suggestion === void 0) {
                    suggestion = suggestedMethod;
                }
                else {
                    suggestion += "." + suggestedMethod;
                }
                return suggestion;
            }
            function getSuggestedTypeForNonexistentStringLiteralType(source, target) {
                const candidates = target.types.filter((type) => !!(type.flags & 128 /* StringLiteral */));
                return getSpellingSuggestion(source.value, candidates, (type) => type.value);
            }
            function getSpellingSuggestionForName(name, symbols, meaning) {
                return getSpellingSuggestion(name, symbols, getCandidateName);
                function getCandidateName(candidate) {
                    const candidateName = symbolName(candidate);
                    if (startsWith(candidateName, '"')) {
                        return void 0;
                    }
                    if (candidate.flags & meaning) {
                        return candidateName;
                    }
                    if (candidate.flags & 2097152 /* Alias */) {
                        const alias = tryResolveAlias(candidate);
                        if (alias && alias.flags & meaning) {
                            return candidateName;
                        }
                    }
                    return void 0;
                }
            }
            function markPropertyAsReferenced(prop, nodeForCheckWriteOnly, isSelfTypeAccess2) {
                const valueDeclaration = prop && prop.flags & 106500 /* ClassMember */ && prop.valueDeclaration;
                if (!valueDeclaration) {
                    return;
                }
                const hasPrivateModifier = hasEffectiveModifier(valueDeclaration, 2 /* Private */);
                const hasPrivateIdentifier = prop.valueDeclaration && isNamedDeclaration(prop.valueDeclaration) && isPrivateIdentifier(prop.valueDeclaration.name);
                if (!hasPrivateModifier && !hasPrivateIdentifier) {
                    return;
                }
                if (nodeForCheckWriteOnly && isWriteOnlyAccess(nodeForCheckWriteOnly) && !(prop.flags & 65536 /* SetAccessor */)) {
                    return;
                }
                if (isSelfTypeAccess2) {
                    const containingMethod = findAncestor(nodeForCheckWriteOnly, isFunctionLikeDeclaration);
                    if (containingMethod && containingMethod.symbol === prop) {
                        return;
                    }
                }
                (getCheckFlags(prop) & 1 /* Instantiated */ ? getSymbolLinks(prop).target : prop).isReferenced = -1 /* All */;
            }
            function isSelfTypeAccess(name, parent2) {
                return name.kind === 110 /* ThisKeyword */ || !!parent2 && isEntityNameExpression(name) && parent2 === getResolvedSymbol(getFirstIdentifier(name));
            }
            function isValidPropertyAccess(node, propertyName) {
                switch (node.kind) {
                    case 211 /* PropertyAccessExpression */:
                        return isValidPropertyAccessWithType(node, node.expression.kind === 108 /* SuperKeyword */, propertyName, getWidenedType(checkExpression(node.expression)));
                    case 166 /* QualifiedName */:
                        return isValidPropertyAccessWithType(node, 
                        /*isSuper*/
                        false, propertyName, getWidenedType(checkExpression(node.left)));
                    case 205 /* ImportType */:
                        return isValidPropertyAccessWithType(node, 
                        /*isSuper*/
                        false, propertyName, getTypeFromTypeNode(node));
                }
            }
            function isValidPropertyAccessForCompletions(node, type, property) {
                return isPropertyAccessible(node, node.kind === 211 /* PropertyAccessExpression */ && node.expression.kind === 108 /* SuperKeyword */, 
                /*isWrite*/
                false, type, property);
            }
            function isValidPropertyAccessWithType(node, isSuper, propertyName, type) {
                if (isTypeAny(type)) {
                    return true;
                }
                const prop = getPropertyOfType(type, propertyName);
                return !!prop && isPropertyAccessible(node, isSuper, 
                /*isWrite*/
                false, type, prop);
            }
            function isPropertyAccessible(node, isSuper, isWrite, containingType, property) {
                if (isTypeAny(containingType)) {
                    return true;
                }
                if (property.valueDeclaration && isPrivateIdentifierClassElementDeclaration(property.valueDeclaration)) {
                    const declClass = getContainingClass(property.valueDeclaration);
                    return !isOptionalChain(node) && !!findAncestor(node, (parent2) => parent2 === declClass);
                }
                return checkPropertyAccessibilityAtLocation(node, isSuper, isWrite, containingType, property);
            }
            function getForInVariableSymbol(node) {
                const initializer = node.initializer;
                if (initializer.kind === 261 /* VariableDeclarationList */) {
                    const variable = initializer.declarations[0];
                    if (variable && !isBindingPattern(variable.name)) {
                        return getSymbolOfDeclaration(variable);
                    }
                }
                else if (initializer.kind === 80 /* Identifier */) {
                    return getResolvedSymbol(initializer);
                }
                return void 0;
            }
            function hasNumericPropertyNames(type) {
                return getIndexInfosOfType(type).length === 1 && !!getIndexInfoOfType(type, numberType);
            }
            function isForInVariableForNumericPropertyNames(expr) {
                const e = skipParentheses(expr);
                if (e.kind === 80 /* Identifier */) {
                    const symbol = getResolvedSymbol(e);
                    if (symbol.flags & 3 /* Variable */) {
                        let child = expr;
                        let node = expr.parent;
                        while (node) {
                            if (node.kind === 249 /* ForInStatement */ && child === node.statement && getForInVariableSymbol(node) === symbol && hasNumericPropertyNames(getTypeOfExpression(node.expression))) {
                                return true;
                            }
                            child = node;
                            node = node.parent;
                        }
                    }
                }
                return false;
            }
            function checkIndexedAccess(node, checkMode) {
                return node.flags & 64 /* OptionalChain */ ? checkElementAccessChain(node, checkMode) : checkElementAccessExpression(node, checkNonNullExpression(node.expression), checkMode);
            }
            function checkElementAccessChain(node, checkMode) {
                const exprType = checkExpression(node.expression);
                const nonOptionalType = getOptionalExpressionType(exprType, node.expression);
                return propagateOptionalTypeMarker(checkElementAccessExpression(node, checkNonNullType(nonOptionalType, node.expression), checkMode), node, nonOptionalType !== exprType);
            }
            function checkElementAccessExpression(node, exprType, checkMode) {
                const objectType = getAssignmentTargetKind(node) !== 0 /* None */ || isMethodAccessForCall(node) ? getWidenedType(exprType) : exprType;
                const indexExpression = node.argumentExpression;
                const indexType = checkExpression(indexExpression);
                if (isErrorType(objectType) || objectType === silentNeverType) {
                    return objectType;
                }
                if (isConstEnumObjectType(objectType) && !isStringLiteralLike(indexExpression)) {
                    error2(indexExpression, Diagnostics.A_const_enum_member_can_only_be_accessed_using_a_string_literal);
                    return errorType;
                }
                const effectiveIndexType = isForInVariableForNumericPropertyNames(indexExpression) ? numberType : indexType;
                const accessFlags = isAssignmentTarget(node) ? 4 /* Writing */ | (isGenericObjectType(objectType) && !isThisTypeParameter(objectType) ? 2 /* NoIndexSignatures */ : 0) : 32 /* ExpressionPosition */;
                const indexedAccessType = getIndexedAccessTypeOrUndefined(objectType, effectiveIndexType, accessFlags, node) || errorType;
                return checkIndexedAccessIndexType(getFlowTypeOfAccessExpression(node, getNodeLinks(node).resolvedSymbol, indexedAccessType, indexExpression, checkMode), node);
            }
            function callLikeExpressionMayHaveTypeArguments(node) {
                return isCallOrNewExpression(node) || isTaggedTemplateExpression(node) || isJsxOpeningLikeElement(node);
            }
            function resolveUntypedCall(node) {
                if (callLikeExpressionMayHaveTypeArguments(node)) {
                    forEach(node.typeArguments, checkSourceElement);
                }
                if (node.kind === 215 /* TaggedTemplateExpression */) {
                    checkExpression(node.template);
                }
                else if (isJsxOpeningLikeElement(node)) {
                    checkExpression(node.attributes);
                }
                else if (isBinaryExpression(node)) {
                    checkExpression(node.left);
                }
                else if (isCallOrNewExpression(node)) {
                    forEach(node.arguments, (argument) => {
                        checkExpression(argument);
                    });
                }
                return anySignature;
            }
            function resolveErrorCall(node) {
                resolveUntypedCall(node);
                return unknownSignature;
            }
            function reorderCandidates(signatures, result, callChainFlags) {
                let lastParent;
                let lastSymbol;
                let cutoffIndex = 0;
                let index;
                let specializedIndex = -1;
                let spliceIndex;
                Debug.assert(!result.length);
                for (const signature of signatures) {
                    const symbol = signature.declaration && getSymbolOfDeclaration(signature.declaration);
                    const parent2 = signature.declaration && signature.declaration.parent;
                    if (!lastSymbol || symbol === lastSymbol) {
                        if (lastParent && parent2 === lastParent) {
                            index = index + 1;
                        }
                        else {
                            lastParent = parent2;
                            index = cutoffIndex;
                        }
                    }
                    else {
                        index = cutoffIndex = result.length;
                        lastParent = parent2;
                    }
                    lastSymbol = symbol;
                    if (signatureHasLiteralTypes(signature)) {
                        specializedIndex++;
                        spliceIndex = specializedIndex;
                        cutoffIndex++;
                    }
                    else {
                        spliceIndex = index;
                    }
                    result.splice(spliceIndex, 0, callChainFlags ? getOptionalCallSignature(signature, callChainFlags) : signature);
                }
            }
            function isSpreadArgument(arg) {
                return !!arg && (arg.kind === 230 /* SpreadElement */ || arg.kind === 237 /* SyntheticExpression */ && arg.isSpread);
            }
            function getSpreadArgumentIndex(args) {
                return findIndex(args, isSpreadArgument);
            }
            function acceptsVoid(t) {
                return !!(t.flags & 16384 /* Void */);
            }
            function acceptsVoidUndefinedUnknownOrAny(t) {
                return !!(t.flags & (16384 /* Void */ | 32768 /* Undefined */ | 2 /* Unknown */ | 1 /* Any */));
            }
            function hasCorrectArity(node, args, signature, signatureHelpTrailingComma = false) {
                let argCount;
                let callIsIncomplete = false;
                let effectiveParameterCount = getParameterCount(signature);
                let effectiveMinimumArguments = getMinArgumentCount(signature);
                if (node.kind === 215 /* TaggedTemplateExpression */) {
                    argCount = args.length;
                    if (node.template.kind === 228 /* TemplateExpression */) {
                        const lastSpan = last(node.template.templateSpans);
                        callIsIncomplete = nodeIsMissing(lastSpan.literal) || !!lastSpan.literal.isUnterminated;
                    }
                    else {
                        const templateLiteral = node.template;
                        Debug.assert(templateLiteral.kind === 15 /* NoSubstitutionTemplateLiteral */);
                        callIsIncomplete = !!templateLiteral.isUnterminated;
                    }
                }
                else if (node.kind === 170 /* Decorator */) {
                    argCount = getDecoratorArgumentCount(node, signature);
                }
                else if (node.kind === 226 /* BinaryExpression */) {
                    argCount = 1;
                }
                else if (isJsxOpeningLikeElement(node)) {
                    callIsIncomplete = node.attributes.end === node.end;
                    if (callIsIncomplete) {
                        return true;
                    }
                    argCount = effectiveMinimumArguments === 0 ? args.length : 1;
                    effectiveParameterCount = args.length === 0 ? effectiveParameterCount : 1;
                    effectiveMinimumArguments = Math.min(effectiveMinimumArguments, 1);
                }
                else if (!node.arguments) {
                    Debug.assert(node.kind === 214 /* NewExpression */);
                    return getMinArgumentCount(signature) === 0;
                }
                else {
                    argCount = signatureHelpTrailingComma ? args.length + 1 : args.length;
                    callIsIncomplete = node.arguments.end === node.end;
                    const spreadArgIndex = getSpreadArgumentIndex(args);
                    if (spreadArgIndex >= 0) {
                        return spreadArgIndex >= getMinArgumentCount(signature) && (hasEffectiveRestParameter(signature) || spreadArgIndex < getParameterCount(signature));
                    }
                }
                if (!hasEffectiveRestParameter(signature) && argCount > effectiveParameterCount) {
                    return false;
                }
                if (callIsIncomplete || argCount >= effectiveMinimumArguments) {
                    return true;
                }
                for (let i = argCount; i < effectiveMinimumArguments; i++) {
                    const type = getTypeAtPosition(signature, i);
                    if (filterType(type, isInJSFile(node) && !strictNullChecks ? acceptsVoidUndefinedUnknownOrAny : acceptsVoid).flags & 131072 /* Never */) {
                        return false;
                    }
                }
                return true;
            }
            function hasCorrectTypeArgumentArity(signature, typeArguments) {
                const numTypeParameters = length(signature.typeParameters);
                const minTypeArgumentCount = getMinTypeArgumentCount(signature.typeParameters);
                return !some(typeArguments) || typeArguments.length >= minTypeArgumentCount && typeArguments.length <= numTypeParameters;
            }
            function isInstantiatedGenericParameter(signature, pos) {
                let type;
                return !!(signature.target && (type = tryGetTypeAtPosition(signature.target, pos)) && isGenericType(type));
            }
            function getSingleCallSignature(type) {
                return getSingleSignature(type, 0 /* Call */, 
                /*allowMembers*/
                false);
            }
            function getSingleCallOrConstructSignature(type) {
                return getSingleSignature(type, 0 /* Call */, 
                /*allowMembers*/
                false) || getSingleSignature(type, 1 /* Construct */, 
                /*allowMembers*/
                false);
            }
            function getSingleSignature(type, kind, allowMembers) {
                if (type.flags & 524288 /* Object */) {
                    const resolved = resolveStructuredTypeMembers(type);
                    if (allowMembers || resolved.properties.length === 0 && resolved.indexInfos.length === 0) {
                        if (kind === 0 /* Call */ && resolved.callSignatures.length === 1 && resolved.constructSignatures.length === 0) {
                            return resolved.callSignatures[0];
                        }
                        if (kind === 1 /* Construct */ && resolved.constructSignatures.length === 1 && resolved.callSignatures.length === 0) {
                            return resolved.constructSignatures[0];
                        }
                    }
                }
                return void 0;
            }
            function instantiateSignatureInContextOf(signature, contextualSignature, inferenceContext, compareTypes) {
                const context = createInferenceContext(signature.typeParameters, signature, 0 /* None */, compareTypes);
                const restType = getEffectiveRestType(contextualSignature);
                const mapper = inferenceContext && (restType && restType.flags & 262144 /* TypeParameter */ ? inferenceContext.nonFixingMapper : inferenceContext.mapper);
                const sourceSignature = mapper ? instantiateSignature(contextualSignature, mapper) : contextualSignature;
                applyToParameterTypes(sourceSignature, signature, (source, target) => {
                    inferTypes(context.inferences, source, target);
                });
                if (!inferenceContext) {
                    applyToReturnTypes(contextualSignature, signature, (source, target) => {
                        inferTypes(context.inferences, source, target, 128 /* ReturnType */);
                    });
                }
                return getSignatureInstantiation(signature, getInferredTypes(context), isInJSFile(contextualSignature.declaration));
            }
            function inferJsxTypeArguments(node, signature, checkMode, context) {
                const paramType = getEffectiveFirstArgumentForJsxSignature(signature, node);
                const checkAttrType = checkExpressionWithContextualType(node.attributes, paramType, context, checkMode);
                inferTypes(context.inferences, checkAttrType, paramType);
                return getInferredTypes(context);
            }
            function getThisArgumentType(thisArgumentNode) {
                if (!thisArgumentNode) {
                    return voidType;
                }
                const thisArgumentType = checkExpression(thisArgumentNode);
                return isRightSideOfInstanceofExpression(thisArgumentNode) ? thisArgumentType : isOptionalChainRoot(thisArgumentNode.parent) ? getNonNullableType(thisArgumentType) : isOptionalChain(thisArgumentNode.parent) ? removeOptionalTypeMarker(thisArgumentType) : thisArgumentType;
            }
            function inferTypeArguments(node, signature, args, checkMode, context) {
                if (isJsxOpeningLikeElement(node)) {
                    return inferJsxTypeArguments(node, signature, checkMode, context);
                }
                if (node.kind !== 170 /* Decorator */ && node.kind !== 226 /* BinaryExpression */) {
                    const skipBindingPatterns = every(signature.typeParameters, (p) => !!getDefaultFromTypeParameter(p));
                    const contextualType = getContextualType2(node, skipBindingPatterns ? 8 /* SkipBindingPatterns */ : 0 /* None */);
                    if (contextualType) {
                        const inferenceTargetType = getReturnTypeOfSignature(signature);
                        if (couldContainTypeVariables(inferenceTargetType)) {
                            const outerContext = getInferenceContext(node);
                            const isFromBindingPattern = !skipBindingPatterns && getContextualType2(node, 8 /* SkipBindingPatterns */) !== contextualType;
                            if (!isFromBindingPattern) {
                                const outerMapper = getMapperFromContext(cloneInferenceContext(outerContext, 1 /* NoDefault */));
                                const instantiatedType = instantiateType(contextualType, outerMapper);
                                const contextualSignature = getSingleCallSignature(instantiatedType);
                                const inferenceSourceType = contextualSignature && contextualSignature.typeParameters ? getOrCreateTypeFromSignature(getSignatureInstantiationWithoutFillingInTypeArguments(contextualSignature, contextualSignature.typeParameters)) : instantiatedType;
                                inferTypes(context.inferences, inferenceSourceType, inferenceTargetType, 128 /* ReturnType */);
                            }
                            const returnContext = createInferenceContext(signature.typeParameters, signature, context.flags);
                            const returnSourceType = instantiateType(contextualType, outerContext && outerContext.returnMapper);
                            inferTypes(returnContext.inferences, returnSourceType, inferenceTargetType);
                            context.returnMapper = some(returnContext.inferences, hasInferenceCandidates) ? getMapperFromContext(cloneInferredPartOfContext(returnContext)) : void 0;
                        }
                    }
                }
                const restType = getNonArrayRestType(signature);
                const argCount = restType ? Math.min(getParameterCount(signature) - 1, args.length) : args.length;
                if (restType && restType.flags & 262144 /* TypeParameter */) {
                    const info = find(context.inferences, (info2) => info2.typeParameter === restType);
                    if (info) {
                        info.impliedArity = findIndex(args, isSpreadArgument, argCount) < 0 ? args.length - argCount : void 0;
                    }
                }
                const thisType = getThisTypeOfSignature(signature);
                if (thisType && couldContainTypeVariables(thisType)) {
                    const thisArgumentNode = getThisArgumentOfCall(node);
                    inferTypes(context.inferences, getThisArgumentType(thisArgumentNode), thisType);
                }
                for (let i = 0; i < argCount; i++) {
                    const arg = args[i];
                    if (arg.kind !== 232 /* OmittedExpression */) {
                        const paramType = getTypeAtPosition(signature, i);
                        if (couldContainTypeVariables(paramType)) {
                            const argType = checkExpressionWithContextualType(arg, paramType, context, checkMode);
                            inferTypes(context.inferences, argType, paramType);
                        }
                    }
                }
                if (restType && couldContainTypeVariables(restType)) {
                    const spreadType = getSpreadArgumentType(args, argCount, args.length, restType, context, checkMode);
                    inferTypes(context.inferences, spreadType, restType);
                }
                return getInferredTypes(context);
            }
            function getMutableArrayOrTupleType(type) {
                return type.flags & 1048576 /* Union */ ? mapType(type, getMutableArrayOrTupleType) : type.flags & 1 /* Any */ || isMutableArrayOrTuple(getBaseConstraintOfType(type) || type) ? type : isTupleType(type) ? createTupleType(getElementTypes(type), type.target.elementFlags, 
                /*readonly*/
                false, type.target.labeledElementDeclarations) : createTupleType([type], [8 /* Variadic */]);
            }
            function getSpreadArgumentType(args, index, argCount, restType, context, checkMode) {
                const inConstContext = isConstTypeVariable(restType);
                if (index >= argCount - 1) {
                    const arg = args[argCount - 1];
                    if (isSpreadArgument(arg)) {
                        const spreadType = arg.kind === 237 /* SyntheticExpression */ ? arg.type : checkExpressionWithContextualType(arg.expression, restType, context, checkMode);
                        if (isArrayLikeType(spreadType)) {
                            return getMutableArrayOrTupleType(spreadType);
                        }
                        return createArrayType(checkIteratedTypeOrElementType(33 /* Spread */, spreadType, undefinedType, arg.kind === 230 /* SpreadElement */ ? arg.expression : arg), inConstContext);
                    }
                }
                const types = [];
                const flags = [];
                const names = [];
                for (let i = index; i < argCount; i++) {
                    const arg = args[i];
                    if (isSpreadArgument(arg)) {
                        const spreadType = arg.kind === 237 /* SyntheticExpression */ ? arg.type : checkExpression(arg.expression);
                        if (isArrayLikeType(spreadType)) {
                            types.push(spreadType);
                            flags.push(8 /* Variadic */);
                        }
                        else {
                            types.push(checkIteratedTypeOrElementType(33 /* Spread */, spreadType, undefinedType, arg.kind === 230 /* SpreadElement */ ? arg.expression : arg));
                            flags.push(4 /* Rest */);
                        }
                    }
                    else {
                        const contextualType = isTupleType(restType) ? getContextualTypeForElementExpression(restType, i - index, argCount - index) || unknownType : getIndexedAccessType(restType, getNumberLiteralType(i - index), 256 /* Contextual */);
                        const argType = checkExpressionWithContextualType(arg, contextualType, context, checkMode);
                        const hasPrimitiveContextualType = inConstContext || maybeTypeOfKind(contextualType, 402784252 /* Primitive */ | 4194304 /* Index */ | 134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */);
                        types.push(hasPrimitiveContextualType ? getRegularTypeOfLiteralType(argType) : getWidenedLiteralType(argType));
                        flags.push(1 /* Required */);
                    }
                    if (arg.kind === 237 /* SyntheticExpression */ && arg.tupleNameSource) {
                        names.push(arg.tupleNameSource);
                    }
                    else {
                        names.push(void 0);
                    }
                }
                return createTupleType(types, flags, inConstContext && !someType(restType, isMutableArrayLikeType), names);
            }
            function checkTypeArguments(signature, typeArgumentNodes, reportErrors2, headMessage) {
                const isJavascript = isInJSFile(signature.declaration);
                const typeParameters = signature.typeParameters;
                const typeArgumentTypes = fillMissingTypeArguments(map(typeArgumentNodes, getTypeFromTypeNode), typeParameters, getMinTypeArgumentCount(typeParameters), isJavascript);
                let mapper;
                for (let i = 0; i < typeArgumentNodes.length; i++) {
                    Debug.assert(typeParameters[i] !== void 0, "Should not call checkTypeArguments with too many type arguments");
                    const constraint = getConstraintOfTypeParameter(typeParameters[i]);
                    if (constraint) {
                        const errorInfo = reportErrors2 && headMessage ? () => chainDiagnosticMessages(
                        /*details*/
                        void 0, Diagnostics.Type_0_does_not_satisfy_the_constraint_1) : void 0;
                        const typeArgumentHeadMessage = headMessage || Diagnostics.Type_0_does_not_satisfy_the_constraint_1;
                        if (!mapper) {
                            mapper = createTypeMapper(typeParameters, typeArgumentTypes);
                        }
                        const typeArgument = typeArgumentTypes[i];
                        if (!checkTypeAssignableTo(typeArgument, getTypeWithThisArgument(instantiateType(constraint, mapper), typeArgument), reportErrors2 ? typeArgumentNodes[i] : void 0, typeArgumentHeadMessage, errorInfo)) {
                            return void 0;
                        }
                    }
                }
                return typeArgumentTypes;
            }
            function getJsxReferenceKind(node) {
                if (isJsxIntrinsicTagName(node.tagName)) {
                    return 2 /* Mixed */;
                }
                const tagType = getApparentType(checkExpression(node.tagName));
                if (length(getSignaturesOfType(tagType, 1 /* Construct */))) {
                    return 0 /* Component */;
                }
                if (length(getSignaturesOfType(tagType, 0 /* Call */))) {
                    return 1 /* Function */;
                }
                return 2 /* Mixed */;
            }
            function checkApplicableSignatureForJsxOpeningLikeElement(node, signature, relation, checkMode, reportErrors2, containingMessageChain, errorOutputContainer) {
                const paramType = getEffectiveFirstArgumentForJsxSignature(signature, node);
                const attributesType = checkExpressionWithContextualType(node.attributes, paramType, 
                /*inferenceContext*/
                void 0, checkMode);
                const checkAttributesType = checkMode & 4 /* SkipContextSensitive */ ? getRegularTypeOfObjectLiteral(attributesType) : attributesType;
                return checkTagNameDoesNotExpectTooManyArguments() && checkTypeRelatedToAndOptionallyElaborate(checkAttributesType, paramType, relation, reportErrors2 ? node.tagName : void 0, node.attributes, 
                /*headMessage*/
                void 0, containingMessageChain, errorOutputContainer);
                function checkTagNameDoesNotExpectTooManyArguments() {
                    var _a;
                    if (getJsxNamespaceContainerForImplicitImport(node)) {
                        return true;
                    }
                    const tagType = (isJsxOpeningElement(node) || isJsxSelfClosingElement(node)) && !(isJsxIntrinsicTagName(node.tagName) || isJsxNamespacedName(node.tagName)) ? checkExpression(node.tagName) : void 0;
                    if (!tagType) {
                        return true;
                    }
                    const tagCallSignatures = getSignaturesOfType(tagType, 0 /* Call */);
                    if (!length(tagCallSignatures)) {
                        return true;
                    }
                    const factory2 = getJsxFactoryEntity(node);
                    if (!factory2) {
                        return true;
                    }
                    const factorySymbol = resolveEntityName(factory2, 111551 /* Value */, 
                    /*ignoreErrors*/
                    true, 
                    /*dontResolveAlias*/
                    false, node);
                    if (!factorySymbol) {
                        return true;
                    }
                    const factoryType = getTypeOfSymbol(factorySymbol);
                    const callSignatures = getSignaturesOfType(factoryType, 0 /* Call */);
                    if (!length(callSignatures)) {
                        return true;
                    }
                    let hasFirstParamSignatures = false;
                    let maxParamCount = 0;
                    for (const sig of callSignatures) {
                        const firstparam = getTypeAtPosition(sig, 0);
                        const signaturesOfParam = getSignaturesOfType(firstparam, 0 /* Call */);
                        if (!length(signaturesOfParam))
                            continue;
                        for (const paramSig of signaturesOfParam) {
                            hasFirstParamSignatures = true;
                            if (hasEffectiveRestParameter(paramSig)) {
                                return true;
                            }
                            const paramCount = getParameterCount(paramSig);
                            if (paramCount > maxParamCount) {
                                maxParamCount = paramCount;
                            }
                        }
                    }
                    if (!hasFirstParamSignatures) {
                        return true;
                    }
                    let absoluteMinArgCount = Infinity;
                    for (const tagSig of tagCallSignatures) {
                        const tagRequiredArgCount = getMinArgumentCount(tagSig);
                        if (tagRequiredArgCount < absoluteMinArgCount) {
                            absoluteMinArgCount = tagRequiredArgCount;
                        }
                    }
                    if (absoluteMinArgCount <= maxParamCount) {
                        return true;
                    }
                    if (reportErrors2) {
                        const diag2 = createDiagnosticForNode(node.tagName, Diagnostics.Tag_0_expects_at_least_1_arguments_but_the_JSX_factory_2_provides_at_most_3, entityNameToString(node.tagName), absoluteMinArgCount, entityNameToString(factory2), maxParamCount);
                        const tagNameDeclaration = (_a = getSymbolAtLocation(node.tagName)) == null ? void 0 : _a.valueDeclaration;
                        if (tagNameDeclaration) {
                            addRelatedInfo(diag2, createDiagnosticForNode(tagNameDeclaration, Diagnostics._0_is_declared_here, entityNameToString(node.tagName)));
                        }
                        if (errorOutputContainer && errorOutputContainer.skipLogging) {
                            (errorOutputContainer.errors || (errorOutputContainer.errors = [])).push(diag2);
                        }
                        if (!errorOutputContainer.skipLogging) {
                            diagnostics.add(diag2);
                        }
                    }
                    return false;
                }
            }
            function getEffectiveCheckNode(argument) {
                argument = skipParentheses(argument);
                return isSatisfiesExpression(argument) ? skipParentheses(argument.expression) : argument;
            }
            function getSignatureApplicabilityError(node, args, signature, relation, checkMode, reportErrors2, containingMessageChain) {
                const errorOutputContainer = { errors: void 0, skipLogging: true };
                if (isJsxOpeningLikeElement(node)) {
                    if (!checkApplicableSignatureForJsxOpeningLikeElement(node, signature, relation, checkMode, reportErrors2, containingMessageChain, errorOutputContainer)) {
                        Debug.assert(!reportErrors2 || !!errorOutputContainer.errors, "jsx should have errors when reporting errors");
                        return errorOutputContainer.errors || emptyArray;
                    }
                    return void 0;
                }
                const thisType = getThisTypeOfSignature(signature);
                if (thisType && thisType !== voidType && !(isNewExpression(node) || isCallExpression(node) && isSuperProperty(node.expression))) {
                    const thisArgumentNode = getThisArgumentOfCall(node);
                    const thisArgumentType = getThisArgumentType(thisArgumentNode);
                    const errorNode = reportErrors2 ? thisArgumentNode || node : void 0;
                    const headMessage2 = Diagnostics.The_this_context_of_type_0_is_not_assignable_to_method_s_this_of_type_1;
                    if (!checkTypeRelatedTo(thisArgumentType, thisType, relation, errorNode, headMessage2, containingMessageChain, errorOutputContainer)) {
                        Debug.assert(!reportErrors2 || !!errorOutputContainer.errors, "this parameter should have errors when reporting errors");
                        return errorOutputContainer.errors || emptyArray;
                    }
                }
                const headMessage = Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1;
                const restType = getNonArrayRestType(signature);
                const argCount = restType ? Math.min(getParameterCount(signature) - 1, args.length) : args.length;
                for (let i = 0; i < argCount; i++) {
                    const arg = args[i];
                    if (arg.kind !== 232 /* OmittedExpression */) {
                        const paramType = getTypeAtPosition(signature, i);
                        const argType = checkExpressionWithContextualType(arg, paramType, 
                        /*inferenceContext*/
                        void 0, checkMode);
                        const checkArgType = checkMode & 4 /* SkipContextSensitive */ ? getRegularTypeOfObjectLiteral(argType) : argType;
                        const effectiveCheckArgumentNode = getEffectiveCheckNode(arg);
                        if (!checkTypeRelatedToAndOptionallyElaborate(checkArgType, paramType, relation, reportErrors2 ? effectiveCheckArgumentNode : void 0, effectiveCheckArgumentNode, headMessage, containingMessageChain, errorOutputContainer)) {
                            Debug.assert(!reportErrors2 || !!errorOutputContainer.errors, "parameter should have errors when reporting errors");
                            maybeAddMissingAwaitInfo(arg, checkArgType, paramType);
                            return errorOutputContainer.errors || emptyArray;
                        }
                    }
                }
                if (restType) {
                    const spreadType = getSpreadArgumentType(args, argCount, args.length, restType, 
                    /*context*/
                    void 0, checkMode);
                    const restArgCount = args.length - argCount;
                    const errorNode = !reportErrors2 ? void 0 : restArgCount === 0 ? node : restArgCount === 1 ? getEffectiveCheckNode(args[argCount]) : setTextRangePosEnd(createSyntheticExpression(node, spreadType), args[argCount].pos, args[args.length - 1].end);
                    if (!checkTypeRelatedTo(spreadType, restType, relation, errorNode, headMessage, 
                    /*containingMessageChain*/
                    void 0, errorOutputContainer)) {
                        Debug.assert(!reportErrors2 || !!errorOutputContainer.errors, "rest parameter should have errors when reporting errors");
                        maybeAddMissingAwaitInfo(errorNode, spreadType, restType);
                        return errorOutputContainer.errors || emptyArray;
                    }
                }
                return void 0;
                function maybeAddMissingAwaitInfo(errorNode, source, target) {
                    if (errorNode && reportErrors2 && errorOutputContainer.errors && errorOutputContainer.errors.length) {
                        if (getAwaitedTypeOfPromise(target)) {
                            return;
                        }
                        const awaitedTypeOfSource = getAwaitedTypeOfPromise(source);
                        if (awaitedTypeOfSource && isTypeRelatedTo(awaitedTypeOfSource, target, relation)) {
                            addRelatedInfo(errorOutputContainer.errors[0], createDiagnosticForNode(errorNode, Diagnostics.Did_you_forget_to_use_await));
                        }
                    }
                }
            }
            function getThisArgumentOfCall(node) {
                if (node.kind === 226 /* BinaryExpression */) {
                    return node.right;
                }
                const expression = node.kind === 213 /* CallExpression */ ? node.expression : node.kind === 215 /* TaggedTemplateExpression */ ? node.tag : node.kind === 170 /* Decorator */ && !legacyDecorators ? node.expression : void 0;
                if (expression) {
                    const callee = skipOuterExpressions(expression);
                    if (isAccessExpression(callee)) {
                        return callee.expression;
                    }
                }
            }
            function createSyntheticExpression(parent2, type, isSpread, tupleNameSource) {
                const result = parseNodeFactory.createSyntheticExpression(type, isSpread, tupleNameSource);
                setTextRange(result, parent2);
                setParent(result, parent2);
                return result;
            }
            function getEffectiveCallArguments(node) {
                if (node.kind === 215 /* TaggedTemplateExpression */) {
                    const template = node.template;
                    const args2 = [createSyntheticExpression(template, getGlobalTemplateStringsArrayType())];
                    if (template.kind === 228 /* TemplateExpression */) {
                        forEach(template.templateSpans, (span) => {
                            args2.push(span.expression);
                        });
                    }
                    return args2;
                }
                if (node.kind === 170 /* Decorator */) {
                    return getEffectiveDecoratorArguments(node);
                }
                if (node.kind === 226 /* BinaryExpression */) {
                    return [node.left];
                }
                if (isJsxOpeningLikeElement(node)) {
                    return node.attributes.properties.length > 0 || isJsxOpeningElement(node) && node.parent.children.length > 0 ? [node.attributes] : emptyArray;
                }
                const args = node.arguments || emptyArray;
                const spreadIndex = getSpreadArgumentIndex(args);
                if (spreadIndex >= 0) {
                    const effectiveArgs = args.slice(0, spreadIndex);
                    for (let i = spreadIndex; i < args.length; i++) {
                        const arg = args[i];
                        const spreadType = arg.kind === 230 /* SpreadElement */ && (flowLoopCount ? checkExpression(arg.expression) : checkExpressionCached(arg.expression));
                        if (spreadType && isTupleType(spreadType)) {
                            forEach(getElementTypes(spreadType), (t, i2) => {
                                var _a;
                                const flags = spreadType.target.elementFlags[i2];
                                const syntheticArg = createSyntheticExpression(arg, flags & 4 /* Rest */ ? createArrayType(t) : t, !!(flags & 12 /* Variable */), (_a = spreadType.target.labeledElementDeclarations) == null ? void 0 : _a[i2]);
                                effectiveArgs.push(syntheticArg);
                            });
                        }
                        else {
                            effectiveArgs.push(arg);
                        }
                    }
                    return effectiveArgs;
                }
                return args;
            }
            function getEffectiveDecoratorArguments(node) {
                const expr = node.expression;
                const signature = getDecoratorCallSignature(node);
                if (signature) {
                    const args = [];
                    for (const param of signature.parameters) {
                        const type = getTypeOfSymbol(param);
                        args.push(createSyntheticExpression(expr, type));
                    }
                    return args;
                }
                return Debug.fail();
            }
            function getDecoratorArgumentCount(node, signature) {
                return compilerOptions.experimentalDecorators ? getLegacyDecoratorArgumentCount(node, signature) : 2;
            }
            function getLegacyDecoratorArgumentCount(node, signature) {
                switch (node.parent.kind) {
                    case 263 /* ClassDeclaration */:
                    case 231 /* ClassExpression */:
                        return 1;
                    case 172 /* PropertyDeclaration */:
                        return hasAccessorModifier(node.parent) ? 3 : 2;
                    case 174 /* MethodDeclaration */:
                    case 177 /* GetAccessor */:
                    case 178 /* SetAccessor */:
                        return languageVersion === 0 /* ES3 */ || signature.parameters.length <= 2 ? 2 : 3;
                    case 169 /* Parameter */:
                        return 3;
                    default:
                        return Debug.fail();
                }
            }
            function getDiagnosticSpanForCallNode(node) {
                const sourceFile = getSourceFileOfNode(node);
                const { start, length: length2 } = getErrorSpanForNode(sourceFile, isPropertyAccessExpression(node.expression) ? node.expression.name : node.expression);
                return { start, length: length2, sourceFile };
            }
            function getDiagnosticForCallNode(node, message, ...args) {
                if (isCallExpression(node)) {
                    const { sourceFile, start, length: length2 } = getDiagnosticSpanForCallNode(node);
                    if ("message" in message) {
                        return createFileDiagnostic(sourceFile, start, length2, message, ...args);
                    }
                    return createDiagnosticForFileFromMessageChain(sourceFile, message);
                }
                else {
                    if ("message" in message) {
                        return createDiagnosticForNode(node, message, ...args);
                    }
                    return createDiagnosticForNodeFromMessageChain(getSourceFileOfNode(node), node, message);
                }
            }
            function getErrorNodeForCallNode(callLike) {
                if (isCallOrNewExpression(callLike)) {
                    return isPropertyAccessExpression(callLike.expression) ? callLike.expression.name : callLike.expression;
                }
                if (isTaggedTemplateExpression(callLike)) {
                    return isPropertyAccessExpression(callLike.tag) ? callLike.tag.name : callLike.tag;
                }
                if (isJsxOpeningLikeElement(callLike)) {
                    return callLike.tagName;
                }
                return callLike;
            }
            function isPromiseResolveArityError(node) {
                if (!isCallExpression(node) || !isIdentifier(node.expression))
                    return false;
                const symbol = resolveName(node.expression, node.expression.escapedText, 111551 /* Value */, 
                /*nameNotFoundMessage*/
                void 0, 
                /*nameArg*/
                void 0, 
                /*isUse*/
                false);
                const decl = symbol == null ? void 0 : symbol.valueDeclaration;
                if (!decl || !isParameter(decl) || !isFunctionExpressionOrArrowFunction(decl.parent) || !isNewExpression(decl.parent.parent) || !isIdentifier(decl.parent.parent.expression)) {
                    return false;
                }
                const globalPromiseSymbol = getGlobalPromiseConstructorSymbol(
                /*reportErrors*/
                false);
                if (!globalPromiseSymbol)
                    return false;
                const constructorSymbol = getSymbolAtLocation(decl.parent.parent.expression, 
                /*ignoreErrors*/
                true);
                return constructorSymbol === globalPromiseSymbol;
            }
            function getArgumentArityError(node, signatures, args, headMessage) {
                var _a;
                const spreadIndex = getSpreadArgumentIndex(args);
                if (spreadIndex > -1) {
                    return createDiagnosticForNode(args[spreadIndex], Diagnostics.A_spread_argument_must_either_have_a_tuple_type_or_be_passed_to_a_rest_parameter);
                }
                let min2 = Number.POSITIVE_INFINITY;
                let max = Number.NEGATIVE_INFINITY;
                let maxBelow = Number.NEGATIVE_INFINITY;
                let minAbove = Number.POSITIVE_INFINITY;
                let closestSignature;
                for (const sig of signatures) {
                    const minParameter = getMinArgumentCount(sig);
                    const maxParameter = getParameterCount(sig);
                    if (minParameter < min2) {
                        min2 = minParameter;
                        closestSignature = sig;
                    }
                    max = Math.max(max, maxParameter);
                    if (minParameter < args.length && minParameter > maxBelow)
                        maxBelow = minParameter;
                    if (args.length < maxParameter && maxParameter < minAbove)
                        minAbove = maxParameter;
                }
                const hasRestParameter2 = some(signatures, hasEffectiveRestParameter);
                const parameterRange = hasRestParameter2 ? min2 : min2 < max ? min2 + "-" + max : min2;
                const isVoidPromiseError = !hasRestParameter2 && parameterRange === 1 && args.length === 0 && isPromiseResolveArityError(node);
                if (isVoidPromiseError && isInJSFile(node)) {
                    return getDiagnosticForCallNode(node, Diagnostics.Expected_1_argument_but_got_0_new_Promise_needs_a_JSDoc_hint_to_produce_a_resolve_that_can_be_called_without_arguments);
                }
                const error3 = isDecorator(node) ? hasRestParameter2 ? Diagnostics.The_runtime_will_invoke_the_decorator_with_1_arguments_but_the_decorator_expects_at_least_0 : Diagnostics.The_runtime_will_invoke_the_decorator_with_1_arguments_but_the_decorator_expects_0 : hasRestParameter2 ? Diagnostics.Expected_at_least_0_arguments_but_got_1 : isVoidPromiseError ? Diagnostics.Expected_0_arguments_but_got_1_Did_you_forget_to_include_void_in_your_type_argument_to_Promise : Diagnostics.Expected_0_arguments_but_got_1;
                if (min2 < args.length && args.length < max) {
                    if (headMessage) {
                        let chain = chainDiagnosticMessages(
                        /*details*/
                        void 0, Diagnostics.No_overload_expects_0_arguments_but_overloads_do_exist_that_expect_either_1_or_2_arguments, args.length, maxBelow, minAbove);
                        chain = chainDiagnosticMessages(chain, headMessage);
                        return getDiagnosticForCallNode(node, chain);
                    }
                    return getDiagnosticForCallNode(node, Diagnostics.No_overload_expects_0_arguments_but_overloads_do_exist_that_expect_either_1_or_2_arguments, args.length, maxBelow, minAbove);
                }
                else if (args.length < min2) {
                    let diagnostic;
                    if (headMessage) {
                        let chain = chainDiagnosticMessages(
                        /*details*/
                        void 0, error3, parameterRange, args.length);
                        chain = chainDiagnosticMessages(chain, headMessage);
                        diagnostic = getDiagnosticForCallNode(node, chain);
                    }
                    else {
                        diagnostic = getDiagnosticForCallNode(node, error3, parameterRange, args.length);
                    }
                    const parameter = (_a = closestSignature == null ? void 0 : closestSignature.declaration) == null ? void 0 : _a.parameters[closestSignature.thisParameter ? args.length + 1 : args.length];
                    if (parameter) {
                        const messageAndArgs = isBindingPattern(parameter.name) ? [Diagnostics.An_argument_matching_this_binding_pattern_was_not_provided] : isRestParameter(parameter) ? [Diagnostics.Arguments_for_the_rest_parameter_0_were_not_provided, idText(getFirstIdentifier(parameter.name))] : [Diagnostics.An_argument_for_0_was_not_provided, !parameter.name ? args.length : idText(getFirstIdentifier(parameter.name))];
                        const parameterError = createDiagnosticForNode(parameter, ...messageAndArgs);
                        return addRelatedInfo(diagnostic, parameterError);
                    }
                    return diagnostic;
                }
                else {
                    const errorSpan = factory.createNodeArray(args.slice(max));
                    const pos = first(errorSpan).pos;
                    let end = last(errorSpan).end;
                    if (end === pos) {
                        end++;
                    }
                    setTextRangePosEnd(errorSpan, pos, end);
                    if (headMessage) {
                        let chain = chainDiagnosticMessages(
                        /*details*/
                        void 0, error3, parameterRange, args.length);
                        chain = chainDiagnosticMessages(chain, headMessage);
                        return createDiagnosticForNodeArrayFromMessageChain(getSourceFileOfNode(node), errorSpan, chain);
                    }
                    return createDiagnosticForNodeArray(getSourceFileOfNode(node), errorSpan, error3, parameterRange, args.length);
                }
            }
            function getTypeArgumentArityError(node, signatures, typeArguments, headMessage) {
                const argCount = typeArguments.length;
                if (signatures.length === 1) {
                    const sig = signatures[0];
                    const min2 = getMinTypeArgumentCount(sig.typeParameters);
                    const max = length(sig.typeParameters);
                    if (headMessage) {
                        let chain = chainDiagnosticMessages(
                        /*details*/
                        void 0, Diagnostics.Expected_0_type_arguments_but_got_1, min2 < max ? min2 + "-" + max : min2, argCount);
                        chain = chainDiagnosticMessages(chain, headMessage);
                        return createDiagnosticForNodeArrayFromMessageChain(getSourceFileOfNode(node), typeArguments, chain);
                    }
                    return createDiagnosticForNodeArray(getSourceFileOfNode(node), typeArguments, Diagnostics.Expected_0_type_arguments_but_got_1, min2 < max ? min2 + "-" + max : min2, argCount);
                }
                let belowArgCount = -Infinity;
                let aboveArgCount = Infinity;
                for (const sig of signatures) {
                    const min2 = getMinTypeArgumentCount(sig.typeParameters);
                    const max = length(sig.typeParameters);
                    if (min2 > argCount) {
                        aboveArgCount = Math.min(aboveArgCount, min2);
                    }
                    else if (max < argCount) {
                        belowArgCount = Math.max(belowArgCount, max);
                    }
                }
                if (belowArgCount !== -Infinity && aboveArgCount !== Infinity) {
                    if (headMessage) {
                        let chain = chainDiagnosticMessages(
                        /*details*/
                        void 0, Diagnostics.No_overload_expects_0_type_arguments_but_overloads_do_exist_that_expect_either_1_or_2_type_arguments, argCount, belowArgCount, aboveArgCount);
                        chain = chainDiagnosticMessages(chain, headMessage);
                        return createDiagnosticForNodeArrayFromMessageChain(getSourceFileOfNode(node), typeArguments, chain);
                    }
                    return createDiagnosticForNodeArray(getSourceFileOfNode(node), typeArguments, Diagnostics.No_overload_expects_0_type_arguments_but_overloads_do_exist_that_expect_either_1_or_2_type_arguments, argCount, belowArgCount, aboveArgCount);
                }
                if (headMessage) {
                    let chain = chainDiagnosticMessages(
                    /*details*/
                    void 0, Diagnostics.Expected_0_type_arguments_but_got_1, belowArgCount === -Infinity ? aboveArgCount : belowArgCount, argCount);
                    chain = chainDiagnosticMessages(chain, headMessage);
                    return createDiagnosticForNodeArrayFromMessageChain(getSourceFileOfNode(node), typeArguments, chain);
                }
                return createDiagnosticForNodeArray(getSourceFileOfNode(node), typeArguments, Diagnostics.Expected_0_type_arguments_but_got_1, belowArgCount === -Infinity ? aboveArgCount : belowArgCount, argCount);
            }
            function resolveCall(node, signatures, candidatesOutArray, checkMode, callChainFlags, headMessage) {
                const isTaggedTemplate = node.kind === 215 /* TaggedTemplateExpression */;
                const isDecorator2 = node.kind === 170 /* Decorator */;
                const isJsxOpeningOrSelfClosingElement = isJsxOpeningLikeElement(node);
                const isInstanceof = node.kind === 226 /* BinaryExpression */;
                const reportErrors2 = !isInferencePartiallyBlocked && !candidatesOutArray;
                let typeArguments;
                if (!isDecorator2 && !isInstanceof && !isSuperCall(node)) {
                    typeArguments = node.typeArguments;
                    if (isTaggedTemplate || isJsxOpeningOrSelfClosingElement || node.expression.kind !== 108 /* SuperKeyword */) {
                        forEach(typeArguments, checkSourceElement);
                    }
                }
                const candidates = candidatesOutArray || [];
                reorderCandidates(signatures, candidates, callChainFlags);
                Debug.assert(candidates.length, "Revert #54442 and add a testcase with whatever triggered this");
                const args = getEffectiveCallArguments(node);
                const isSingleNonGenericCandidate = candidates.length === 1 && !candidates[0].typeParameters;
                let argCheckMode = !isDecorator2 && !isSingleNonGenericCandidate && some(args, isContextSensitive) ? 4 /* SkipContextSensitive */ : 0 /* Normal */;
                let candidatesForArgumentError;
                let candidateForArgumentArityError;
                let candidateForTypeArgumentError;
                let result;
                const signatureHelpTrailingComma = !!(checkMode & 16 /* IsForSignatureHelp */) && node.kind === 213 /* CallExpression */ && node.arguments.hasTrailingComma;
                if (candidates.length > 1) {
                    result = chooseOverload(candidates, subtypeRelation, isSingleNonGenericCandidate, signatureHelpTrailingComma);
                }
                if (!result) {
                    result = chooseOverload(candidates, assignableRelation, isSingleNonGenericCandidate, signatureHelpTrailingComma);
                }
                if (result) {
                    return result;
                }
                result = getCandidateForOverloadFailure(node, candidates, args, !!candidatesOutArray, checkMode);
                getNodeLinks(node).resolvedSignature = result;
                if (reportErrors2) {
                    if (!headMessage && isInstanceof) {
                        headMessage = Diagnostics.The_left_hand_side_of_an_instanceof_expression_must_be_assignable_to_the_first_argument_of_the_right_hand_side_s_Symbol_hasInstance_method;
                    }
                    if (candidatesForArgumentError) {
                        if (candidatesForArgumentError.length === 1 || candidatesForArgumentError.length > 3) {
                            const last2 = candidatesForArgumentError[candidatesForArgumentError.length - 1];
                            let chain;
                            if (candidatesForArgumentError.length > 3) {
                                chain = chainDiagnosticMessages(chain, Diagnostics.The_last_overload_gave_the_following_error);
                                chain = chainDiagnosticMessages(chain, Diagnostics.No_overload_matches_this_call);
                            }
                            if (headMessage) {
                                chain = chainDiagnosticMessages(chain, headMessage);
                            }
                            const diags = getSignatureApplicabilityError(node, args, last2, assignableRelation, 0 /* Normal */, 
                            /*reportErrors*/
                            true, () => chain);
                            if (diags) {
                                for (const d of diags) {
                                    if (last2.declaration && candidatesForArgumentError.length > 3) {
                                        addRelatedInfo(d, createDiagnosticForNode(last2.declaration, Diagnostics.The_last_overload_is_declared_here));
                                    }
                                    addImplementationSuccessElaboration(last2, d);
                                    diagnostics.add(d);
                                }
                            }
                            else {
                                Debug.fail("No error for last overload signature");
                            }
                        }
                        else {
                            const allDiagnostics = [];
                            let max = 0;
                            let min2 = Number.MAX_VALUE;
                            let minIndex = 0;
                            let i = 0;
                            for (const c of candidatesForArgumentError) {
                                const chain2 = () => chainDiagnosticMessages(
                                /*details*/
                                void 0, Diagnostics.Overload_0_of_1_2_gave_the_following_error, i + 1, candidates.length, signatureToString(c));
                                const diags2 = getSignatureApplicabilityError(node, args, c, assignableRelation, 0 /* Normal */, 
                                /*reportErrors*/
                                true, chain2);
                                if (diags2) {
                                    if (diags2.length <= min2) {
                                        min2 = diags2.length;
                                        minIndex = i;
                                    }
                                    max = Math.max(max, diags2.length);
                                    allDiagnostics.push(diags2);
                                }
                                else {
                                    Debug.fail("No error for 3 or fewer overload signatures");
                                }
                                i++;
                            }
                            const diags = max > 1 ? allDiagnostics[minIndex] : flatten(allDiagnostics);
                            Debug.assert(diags.length > 0, "No errors reported for 3 or fewer overload signatures");
                            let chain = chainDiagnosticMessages(map(diags, createDiagnosticMessageChainFromDiagnostic), Diagnostics.No_overload_matches_this_call);
                            if (headMessage) {
                                chain = chainDiagnosticMessages(chain, headMessage);
                            }
                            const related = [...flatMap(diags, (d) => d.relatedInformation)];
                            let diag2;
                            if (every(diags, (d) => d.start === diags[0].start && d.length === diags[0].length && d.file === diags[0].file)) {
                                const { file, start, length: length2 } = diags[0];
                                diag2 = { file, start, length: length2, code: chain.code, category: chain.category, messageText: chain, relatedInformation: related };
                            }
                            else {
                                diag2 = createDiagnosticForNodeFromMessageChain(getSourceFileOfNode(node), getErrorNodeForCallNode(node), chain, related);
                            }
                            addImplementationSuccessElaboration(candidatesForArgumentError[0], diag2);
                            diagnostics.add(diag2);
                        }
                    }
                    else if (candidateForArgumentArityError) {
                        diagnostics.add(getArgumentArityError(node, [candidateForArgumentArityError], args, headMessage));
                    }
                    else if (candidateForTypeArgumentError) {
                        checkTypeArguments(candidateForTypeArgumentError, node.typeArguments, 
                        /*reportErrors*/
                        true, headMessage);
                    }
                    else {
                        const signaturesWithCorrectTypeArgumentArity = filter(signatures, (s) => hasCorrectTypeArgumentArity(s, typeArguments));
                        if (signaturesWithCorrectTypeArgumentArity.length === 0) {
                            diagnostics.add(getTypeArgumentArityError(node, signatures, typeArguments, headMessage));
                        }
                        else {
                            diagnostics.add(getArgumentArityError(node, signaturesWithCorrectTypeArgumentArity, args, headMessage));
                        }
                    }
                }
                return result;
                function addImplementationSuccessElaboration(failed, diagnostic) {
                    var _a, _b;
                    const oldCandidatesForArgumentError = candidatesForArgumentError;
                    const oldCandidateForArgumentArityError = candidateForArgumentArityError;
                    const oldCandidateForTypeArgumentError = candidateForTypeArgumentError;
                    const failedSignatureDeclarations = ((_b = (_a = failed.declaration) == null ? void 0 : _a.symbol) == null ? void 0 : _b.declarations) || emptyArray;
                    const isOverload2 = failedSignatureDeclarations.length > 1;
                    const implDecl = isOverload2 ? find(failedSignatureDeclarations, (d) => isFunctionLikeDeclaration(d) && nodeIsPresent(d.body)) : void 0;
                    if (implDecl) {
                        const candidate = getSignatureFromDeclaration(implDecl);
                        const isSingleNonGenericCandidate2 = !candidate.typeParameters;
                        if (chooseOverload([candidate], assignableRelation, isSingleNonGenericCandidate2)) {
                            addRelatedInfo(diagnostic, createDiagnosticForNode(implDecl, Diagnostics.The_call_would_have_succeeded_against_this_implementation_but_implementation_signatures_of_overloads_are_not_externally_visible));
                        }
                    }
                    candidatesForArgumentError = oldCandidatesForArgumentError;
                    candidateForArgumentArityError = oldCandidateForArgumentArityError;
                    candidateForTypeArgumentError = oldCandidateForTypeArgumentError;
                }
                function chooseOverload(candidates2, relation, isSingleNonGenericCandidate2, signatureHelpTrailingComma2 = false) {
                    candidatesForArgumentError = void 0;
                    candidateForArgumentArityError = void 0;
                    candidateForTypeArgumentError = void 0;
                    if (isSingleNonGenericCandidate2) {
                        const candidate = candidates2[0];
                        if (some(typeArguments) || !hasCorrectArity(node, args, candidate, signatureHelpTrailingComma2)) {
                            return void 0;
                        }
                        if (getSignatureApplicabilityError(node, args, candidate, relation, 0 /* Normal */, 
                        /*reportErrors*/
                        false, 
                        /*containingMessageChain*/
                        void 0)) {
                            candidatesForArgumentError = [candidate];
                            return void 0;
                        }
                        return candidate;
                    }
                    for (let candidateIndex = 0; candidateIndex < candidates2.length; candidateIndex++) {
                        const candidate = candidates2[candidateIndex];
                        if (!hasCorrectTypeArgumentArity(candidate, typeArguments) || !hasCorrectArity(node, args, candidate, signatureHelpTrailingComma2)) {
                            continue;
                        }
                        let checkCandidate;
                        let inferenceContext;
                        if (candidate.typeParameters) {
                            let typeArgumentTypes;
                            if (some(typeArguments)) {
                                typeArgumentTypes = checkTypeArguments(candidate, typeArguments, 
                                /*reportErrors*/
                                false);
                                if (!typeArgumentTypes) {
                                    candidateForTypeArgumentError = candidate;
                                    continue;
                                }
                            }
                            else {
                                inferenceContext = createInferenceContext(candidate.typeParameters, candidate, 
                                /*flags*/
                                isInJSFile(node) ? 2 /* AnyDefault */ : 0 /* None */);
                                typeArgumentTypes = inferTypeArguments(node, candidate, args, argCheckMode | 8 /* SkipGenericFunctions */, inferenceContext);
                                argCheckMode |= inferenceContext.flags & 4 /* SkippedGenericFunction */ ? 8 /* SkipGenericFunctions */ : 0 /* Normal */;
                            }
                            checkCandidate = getSignatureInstantiation(candidate, typeArgumentTypes, isInJSFile(candidate.declaration), inferenceContext && inferenceContext.inferredTypeParameters);
                            if (getNonArrayRestType(candidate) && !hasCorrectArity(node, args, checkCandidate, signatureHelpTrailingComma2)) {
                                candidateForArgumentArityError = checkCandidate;
                                continue;
                            }
                        }
                        else {
                            checkCandidate = candidate;
                        }
                        if (getSignatureApplicabilityError(node, args, checkCandidate, relation, argCheckMode, 
                        /*reportErrors*/
                        false, 
                        /*containingMessageChain*/
                        void 0)) {
                            (candidatesForArgumentError || (candidatesForArgumentError = [])).push(checkCandidate);
                            continue;
                        }
                        if (argCheckMode) {
                            argCheckMode = 0 /* Normal */;
                            if (inferenceContext) {
                                const typeArgumentTypes = inferTypeArguments(node, candidate, args, argCheckMode, inferenceContext);
                                checkCandidate = getSignatureInstantiation(candidate, typeArgumentTypes, isInJSFile(candidate.declaration), inferenceContext.inferredTypeParameters);
                                if (getNonArrayRestType(candidate) && !hasCorrectArity(node, args, checkCandidate, signatureHelpTrailingComma2)) {
                                    candidateForArgumentArityError = checkCandidate;
                                    continue;
                                }
                            }
                            if (getSignatureApplicabilityError(node, args, checkCandidate, relation, argCheckMode, 
                            /*reportErrors*/
                            false, 
                            /*containingMessageChain*/
                            void 0)) {
                                (candidatesForArgumentError || (candidatesForArgumentError = [])).push(checkCandidate);
                                continue;
                            }
                        }
                        candidates2[candidateIndex] = checkCandidate;
                        return checkCandidate;
                    }
                    return void 0;
                }
            }
            function getCandidateForOverloadFailure(node, candidates, args, hasCandidatesOutArray, checkMode) {
                Debug.assert(candidates.length > 0);
                checkNodeDeferred(node);
                return hasCandidatesOutArray || candidates.length === 1 || candidates.some((c) => !!c.typeParameters) ? pickLongestCandidateSignature(node, candidates, args, checkMode) : createUnionOfSignaturesForOverloadFailure(candidates);
            }
            function createUnionOfSignaturesForOverloadFailure(candidates) {
                const thisParameters = mapDefined(candidates, (c) => c.thisParameter);
                let thisParameter;
                if (thisParameters.length) {
                    thisParameter = createCombinedSymbolFromTypes(thisParameters, thisParameters.map(getTypeOfParameter));
                }
                const { min: minArgumentCount, max: maxNonRestParam } = minAndMax(candidates, getNumNonRestParameters);
                const parameters = [];
                for (let i = 0; i < maxNonRestParam; i++) {
                    const symbols = mapDefined(candidates, (s) => signatureHasRestParameter(s) ? i < s.parameters.length - 1 ? s.parameters[i] : last(s.parameters) : i < s.parameters.length ? s.parameters[i] : void 0);
                    Debug.assert(symbols.length !== 0);
                    parameters.push(createCombinedSymbolFromTypes(symbols, mapDefined(candidates, (candidate) => tryGetTypeAtPosition(candidate, i))));
                }
                const restParameterSymbols = mapDefined(candidates, (c) => signatureHasRestParameter(c) ? last(c.parameters) : void 0);
                let flags = 128 /* IsSignatureCandidateForOverloadFailure */;
                if (restParameterSymbols.length !== 0) {
                    const type = createArrayType(getUnionType(mapDefined(candidates, tryGetRestTypeOfSignature), 2 /* Subtype */));
                    parameters.push(createCombinedSymbolForOverloadFailure(restParameterSymbols, type));
                    flags |= 1 /* HasRestParameter */;
                }
                if (candidates.some(signatureHasLiteralTypes)) {
                    flags |= 2 /* HasLiteralTypes */;
                }
                return createSignature(candidates[0].declaration, 
                /*typeParameters*/
                void 0, 
                // Before calling this we tested for `!candidates.some(c => !!c.typeParameters)`.
                thisParameter, parameters, 
                /*resolvedReturnType*/
                getIntersectionType(candidates.map(getReturnTypeOfSignature)), 
                /*resolvedTypePredicate*/
                void 0, minArgumentCount, flags);
            }
            function getNumNonRestParameters(signature) {
                const numParams = signature.parameters.length;
                return signatureHasRestParameter(signature) ? numParams - 1 : numParams;
            }
            function createCombinedSymbolFromTypes(sources, types) {
                return createCombinedSymbolForOverloadFailure(sources, getUnionType(types, 2 /* Subtype */));
            }
            function createCombinedSymbolForOverloadFailure(sources, type) {
                return createSymbolWithType(first(sources), type);
            }
            function pickLongestCandidateSignature(node, candidates, args, checkMode) {
                const bestIndex = getLongestCandidateIndex(candidates, apparentArgumentCount === void 0 ? args.length : apparentArgumentCount);
                const candidate = candidates[bestIndex];
                const { typeParameters } = candidate;
                if (!typeParameters) {
                    return candidate;
                }
                const typeArgumentNodes = callLikeExpressionMayHaveTypeArguments(node) ? node.typeArguments : void 0;
                const instantiated = typeArgumentNodes ? createSignatureInstantiation(candidate, getTypeArgumentsFromNodes(typeArgumentNodes, typeParameters, isInJSFile(node))) : inferSignatureInstantiationForOverloadFailure(node, typeParameters, candidate, args, checkMode);
                candidates[bestIndex] = instantiated;
                return instantiated;
            }
            function getTypeArgumentsFromNodes(typeArgumentNodes, typeParameters, isJs) {
                const typeArguments = typeArgumentNodes.map(getTypeOfNode);
                while (typeArguments.length > typeParameters.length) {
                    typeArguments.pop();
                }
                while (typeArguments.length < typeParameters.length) {
                    typeArguments.push(getDefaultFromTypeParameter(typeParameters[typeArguments.length]) || getConstraintOfTypeParameter(typeParameters[typeArguments.length]) || getDefaultTypeArgumentType(isJs));
                }
                return typeArguments;
            }
            function inferSignatureInstantiationForOverloadFailure(node, typeParameters, candidate, args, checkMode) {
                const inferenceContext = createInferenceContext(typeParameters, candidate, 
                /*flags*/
                isInJSFile(node) ? 2 /* AnyDefault */ : 0 /* None */);
                const typeArgumentTypes = inferTypeArguments(node, candidate, args, checkMode | 4 /* SkipContextSensitive */ | 8 /* SkipGenericFunctions */, inferenceContext);
                return createSignatureInstantiation(candidate, typeArgumentTypes);
            }
            function getLongestCandidateIndex(candidates, argsCount) {
                let maxParamsIndex = -1;
                let maxParams = -1;
                for (let i = 0; i < candidates.length; i++) {
                    const candidate = candidates[i];
                    const paramCount = getParameterCount(candidate);
                    if (hasEffectiveRestParameter(candidate) || paramCount >= argsCount) {
                        return i;
                    }
                    if (paramCount > maxParams) {
                        maxParams = paramCount;
                        maxParamsIndex = i;
                    }
                }
                return maxParamsIndex;
            }
            function resolveCallExpression(node, candidatesOutArray, checkMode) {
                if (node.expression.kind === 108 /* SuperKeyword */) {
                    const superType = checkSuperExpression(node.expression);
                    if (isTypeAny(superType)) {
                        for (const arg of node.arguments) {
                            checkExpression(arg);
                        }
                        return anySignature;
                    }
                    if (!isErrorType(superType)) {
                        const baseTypeNode = getEffectiveBaseTypeNode(getContainingClass(node));
                        if (baseTypeNode) {
                            const baseConstructors = getInstantiatedConstructorsForTypeArguments(superType, baseTypeNode.typeArguments, baseTypeNode);
                            return resolveCall(node, baseConstructors, candidatesOutArray, checkMode, 0 /* None */);
                        }
                    }
                    return resolveUntypedCall(node);
                }
                let callChainFlags;
                let funcType = checkExpression(node.expression);
                if (isCallChain(node)) {
                    const nonOptionalType = getOptionalExpressionType(funcType, node.expression);
                    callChainFlags = nonOptionalType === funcType ? 0 /* None */ : isOutermostOptionalChain(node) ? 16 /* IsOuterCallChain */ : 8 /* IsInnerCallChain */;
                    funcType = nonOptionalType;
                }
                else {
                    callChainFlags = 0 /* None */;
                }
                funcType = checkNonNullTypeWithReporter(funcType, node.expression, reportCannotInvokePossiblyNullOrUndefinedError);
                if (funcType === silentNeverType) {
                    return silentNeverSignature;
                }
                const apparentType = getApparentType(funcType);
                if (isErrorType(apparentType)) {
                    return resolveErrorCall(node);
                }
                const callSignatures = getSignaturesOfType(apparentType, 0 /* Call */);
                const numConstructSignatures = getSignaturesOfType(apparentType, 1 /* Construct */).length;
                if (isUntypedFunctionCall(funcType, apparentType, callSignatures.length, numConstructSignatures)) {
                    if (!isErrorType(funcType) && node.typeArguments) {
                        error2(node, Diagnostics.Untyped_function_calls_may_not_accept_type_arguments);
                    }
                    return resolveUntypedCall(node);
                }
                if (!callSignatures.length) {
                    if (numConstructSignatures) {
                        error2(node, Diagnostics.Value_of_type_0_is_not_callable_Did_you_mean_to_include_new, typeToString(funcType));
                    }
                    else {
                        let relatedInformation;
                        if (node.arguments.length === 1) {
                            const text = getSourceFileOfNode(node).text;
                            if (isLineBreak(text.charCodeAt(skipTrivia(text, node.expression.end, 
                            /*stopAfterLineBreak*/
                            true) - 1))) {
                                relatedInformation = createDiagnosticForNode(node.expression, Diagnostics.Are_you_missing_a_semicolon);
                            }
                        }
                        invocationError(node.expression, apparentType, 0 /* Call */, relatedInformation);
                    }
                    return resolveErrorCall(node);
                }
                if (checkMode & 8 /* SkipGenericFunctions */ && !node.typeArguments && callSignatures.some(isGenericFunctionReturningFunction)) {
                    skippedGenericFunction(node, checkMode);
                    return resolvingSignature;
                }
                if (callSignatures.some((sig) => isInJSFile(sig.declaration) && !!getJSDocClassTag(sig.declaration))) {
                    error2(node, Diagnostics.Value_of_type_0_is_not_callable_Did_you_mean_to_include_new, typeToString(funcType));
                    return resolveErrorCall(node);
                }
                return resolveCall(node, callSignatures, candidatesOutArray, checkMode, callChainFlags);
            }
            function isGenericFunctionReturningFunction(signature) {
                return !!(signature.typeParameters && isFunctionType(getReturnTypeOfSignature(signature)));
            }
            function isUntypedFunctionCall(funcType, apparentFuncType, numCallSignatures, numConstructSignatures) {
                return isTypeAny(funcType) || isTypeAny(apparentFuncType) && !!(funcType.flags & 262144 /* TypeParameter */) || !numCallSignatures && !numConstructSignatures && !(apparentFuncType.flags & 1048576 /* Union */) && !(getReducedType(apparentFuncType).flags & 131072 /* Never */) && isTypeAssignableTo(funcType, globalFunctionType);
            }
            function resolveNewExpression(node, candidatesOutArray, checkMode) {
                if (node.arguments && languageVersion < 1 /* ES5 */) {
                    const spreadIndex = getSpreadArgumentIndex(node.arguments);
                    if (spreadIndex >= 0) {
                        error2(node.arguments[spreadIndex], Diagnostics.Spread_operator_in_new_expressions_is_only_available_when_targeting_ECMAScript_5_and_higher);
                    }
                }
                let expressionType = checkNonNullExpression(node.expression);
                if (expressionType === silentNeverType) {
                    return silentNeverSignature;
                }
                expressionType = getApparentType(expressionType);
                if (isErrorType(expressionType)) {
                    return resolveErrorCall(node);
                }
                if (isTypeAny(expressionType)) {
                    if (node.typeArguments) {
                        error2(node, Diagnostics.Untyped_function_calls_may_not_accept_type_arguments);
                    }
                    return resolveUntypedCall(node);
                }
                const constructSignatures = getSignaturesOfType(expressionType, 1 /* Construct */);
                if (constructSignatures.length) {
                    if (!isConstructorAccessible(node, constructSignatures[0])) {
                        return resolveErrorCall(node);
                    }
                    if (someSignature(constructSignatures, (signature) => !!(signature.flags & 4 /* Abstract */))) {
                        error2(node, Diagnostics.Cannot_create_an_instance_of_an_abstract_class);
                        return resolveErrorCall(node);
                    }
                    const valueDecl = expressionType.symbol && getClassLikeDeclarationOfSymbol(expressionType.symbol);
                    if (valueDecl && hasSyntacticModifier(valueDecl, 64 /* Abstract */)) {
                        error2(node, Diagnostics.Cannot_create_an_instance_of_an_abstract_class);
                        return resolveErrorCall(node);
                    }
                    return resolveCall(node, constructSignatures, candidatesOutArray, checkMode, 0 /* None */);
                }
                const callSignatures = getSignaturesOfType(expressionType, 0 /* Call */);
                if (callSignatures.length) {
                    const signature = resolveCall(node, callSignatures, candidatesOutArray, checkMode, 0 /* None */);
                    if (!noImplicitAny) {
                        if (signature.declaration && !isJSConstructor(signature.declaration) && getReturnTypeOfSignature(signature) !== voidType) {
                            error2(node, Diagnostics.Only_a_void_function_can_be_called_with_the_new_keyword);
                        }
                        if (getThisTypeOfSignature(signature) === voidType) {
                            error2(node, Diagnostics.A_function_that_is_called_with_the_new_keyword_cannot_have_a_this_type_that_is_void);
                        }
                    }
                    return signature;
                }
                invocationError(node.expression, expressionType, 1 /* Construct */);
                return resolveErrorCall(node);
            }
            function someSignature(signatures, f) {
                if (isArray(signatures)) {
                    return some(signatures, (signature) => someSignature(signature, f));
                }
                return signatures.compositeKind === 1048576 /* Union */ ? some(signatures.compositeSignatures, f) : f(signatures);
            }
            function typeHasProtectedAccessibleBase(target, type) {
                const baseTypes = getBaseTypes(type);
                if (!length(baseTypes)) {
                    return false;
                }
                const firstBase = baseTypes[0];
                if (firstBase.flags & 2097152 /* Intersection */) {
                    const types = firstBase.types;
                    const mixinFlags = findMixins(types);
                    let i = 0;
                    for (const intersectionMember of firstBase.types) {
                        if (!mixinFlags[i]) {
                            if (getObjectFlags(intersectionMember) & (1 /* Class */ | 2 /* Interface */)) {
                                if (intersectionMember.symbol === target) {
                                    return true;
                                }
                                if (typeHasProtectedAccessibleBase(target, intersectionMember)) {
                                    return true;
                                }
                            }
                        }
                        i++;
                    }
                    return false;
                }
                if (firstBase.symbol === target) {
                    return true;
                }
                return typeHasProtectedAccessibleBase(target, firstBase);
            }
            function isConstructorAccessible(node, signature) {
                if (!signature || !signature.declaration) {
                    return true;
                }
                const declaration = signature.declaration;
                const modifiers = getSelectedEffectiveModifierFlags(declaration, 6 /* NonPublicAccessibilityModifier */);
                if (!modifiers || declaration.kind !== 176 /* Constructor */) {
                    return true;
                }
                const declaringClassDeclaration = getClassLikeDeclarationOfSymbol(declaration.parent.symbol);
                const declaringClass = getDeclaredTypeOfSymbol(declaration.parent.symbol);
                if (!isNodeWithinClass(node, declaringClassDeclaration)) {
                    const containingClass = getContainingClass(node);
                    if (containingClass && modifiers & 4 /* Protected */) {
                        const containingType = getTypeOfNode(containingClass);
                        if (typeHasProtectedAccessibleBase(declaration.parent.symbol, containingType)) {
                            return true;
                        }
                    }
                    if (modifiers & 2 /* Private */) {
                        error2(node, Diagnostics.Constructor_of_class_0_is_private_and_only_accessible_within_the_class_declaration, typeToString(declaringClass));
                    }
                    if (modifiers & 4 /* Protected */) {
                        error2(node, Diagnostics.Constructor_of_class_0_is_protected_and_only_accessible_within_the_class_declaration, typeToString(declaringClass));
                    }
                    return false;
                }
                return true;
            }
            function invocationErrorDetails(errorTarget, apparentType, kind) {
                let errorInfo;
                const isCall = kind === 0 /* Call */;
                const awaitedType = getAwaitedType(apparentType);
                const maybeMissingAwait = awaitedType && getSignaturesOfType(awaitedType, kind).length > 0;
                if (apparentType.flags & 1048576 /* Union */) {
                    const types = apparentType.types;
                    let hasSignatures = false;
                    for (const constituent of types) {
                        const signatures = getSignaturesOfType(constituent, kind);
                        if (signatures.length !== 0) {
                            hasSignatures = true;
                            if (errorInfo) {
                                break;
                            }
                        }
                        else {
                            if (!errorInfo) {
                                errorInfo = chainDiagnosticMessages(errorInfo, isCall ? Diagnostics.Type_0_has_no_call_signatures : Diagnostics.Type_0_has_no_construct_signatures, typeToString(constituent));
                                errorInfo = chainDiagnosticMessages(errorInfo, isCall ? Diagnostics.Not_all_constituents_of_type_0_are_callable : Diagnostics.Not_all_constituents_of_type_0_are_constructable, typeToString(apparentType));
                            }
                            if (hasSignatures) {
                                break;
                            }
                        }
                    }
                    if (!hasSignatures) {
                        errorInfo = chainDiagnosticMessages(
                        /*details*/
                        void 0, isCall ? Diagnostics.No_constituent_of_type_0_is_callable : Diagnostics.No_constituent_of_type_0_is_constructable, typeToString(apparentType));
                    }
                    if (!errorInfo) {
                        errorInfo = chainDiagnosticMessages(errorInfo, isCall ? Diagnostics.Each_member_of_the_union_type_0_has_signatures_but_none_of_those_signatures_are_compatible_with_each_other : Diagnostics.Each_member_of_the_union_type_0_has_construct_signatures_but_none_of_those_signatures_are_compatible_with_each_other, typeToString(apparentType));
                    }
                }
                else {
                    errorInfo = chainDiagnosticMessages(errorInfo, isCall ? Diagnostics.Type_0_has_no_call_signatures : Diagnostics.Type_0_has_no_construct_signatures, typeToString(apparentType));
                }
                let headMessage = isCall ? Diagnostics.This_expression_is_not_callable : Diagnostics.This_expression_is_not_constructable;
                if (isCallExpression(errorTarget.parent) && errorTarget.parent.arguments.length === 0) {
                    const { resolvedSymbol } = getNodeLinks(errorTarget);
                    if (resolvedSymbol && resolvedSymbol.flags & 32768 /* GetAccessor */) {
                        headMessage = Diagnostics.This_expression_is_not_callable_because_it_is_a_get_accessor_Did_you_mean_to_use_it_without;
                    }
                }
                return {
                    messageChain: chainDiagnosticMessages(errorInfo, headMessage),
                    relatedMessage: maybeMissingAwait ? Diagnostics.Did_you_forget_to_use_await : void 0
                };
            }
            function invocationError(errorTarget, apparentType, kind, relatedInformation) {
                const { messageChain, relatedMessage: relatedInfo } = invocationErrorDetails(errorTarget, apparentType, kind);
                const diagnostic = createDiagnosticForNodeFromMessageChain(getSourceFileOfNode(errorTarget), errorTarget, messageChain);
                if (relatedInfo) {
                    addRelatedInfo(diagnostic, createDiagnosticForNode(errorTarget, relatedInfo));
                }
                if (isCallExpression(errorTarget.parent)) {
                    const { start, length: length2 } = getDiagnosticSpanForCallNode(errorTarget.parent);
                    diagnostic.start = start;
                    diagnostic.length = length2;
                }
                diagnostics.add(diagnostic);
                invocationErrorRecovery(apparentType, kind, relatedInformation ? addRelatedInfo(diagnostic, relatedInformation) : diagnostic);
            }
            function invocationErrorRecovery(apparentType, kind, diagnostic) {
                if (!apparentType.symbol) {
                    return;
                }
                const importNode = getSymbolLinks(apparentType.symbol).originatingImport;
                if (importNode && !isImportCall(importNode)) {
                    const sigs = getSignaturesOfType(getTypeOfSymbol(getSymbolLinks(apparentType.symbol).target), kind);
                    if (!sigs || !sigs.length)
                        return;
                    addRelatedInfo(diagnostic, createDiagnosticForNode(importNode, Diagnostics.Type_originates_at_this_import_A_namespace_style_import_cannot_be_called_or_constructed_and_will_cause_a_failure_at_runtime_Consider_using_a_default_import_or_import_require_here_instead));
                }
            }
            function resolveTaggedTemplateExpression(node, candidatesOutArray, checkMode) {
                const tagType = checkExpression(node.tag);
                const apparentType = getApparentType(tagType);
                if (isErrorType(apparentType)) {
                    return resolveErrorCall(node);
                }
                const callSignatures = getSignaturesOfType(apparentType, 0 /* Call */);
                const numConstructSignatures = getSignaturesOfType(apparentType, 1 /* Construct */).length;
                if (isUntypedFunctionCall(tagType, apparentType, callSignatures.length, numConstructSignatures)) {
                    return resolveUntypedCall(node);
                }
                if (!callSignatures.length) {
                    if (isArrayLiteralExpression(node.parent)) {
                        const diagnostic = createDiagnosticForNode(node.tag, Diagnostics.It_is_likely_that_you_are_missing_a_comma_to_separate_these_two_template_expressions_They_form_a_tagged_template_expression_which_cannot_be_invoked);
                        diagnostics.add(diagnostic);
                        return resolveErrorCall(node);
                    }
                    invocationError(node.tag, apparentType, 0 /* Call */);
                    return resolveErrorCall(node);
                }
                return resolveCall(node, callSignatures, candidatesOutArray, checkMode, 0 /* None */);
            }
            function getDiagnosticHeadMessageForDecoratorResolution(node) {
                switch (node.parent.kind) {
                    case 263 /* ClassDeclaration */:
                    case 231 /* ClassExpression */:
                        return Diagnostics.Unable_to_resolve_signature_of_class_decorator_when_called_as_an_expression;
                    case 169 /* Parameter */:
                        return Diagnostics.Unable_to_resolve_signature_of_parameter_decorator_when_called_as_an_expression;
                    case 172 /* PropertyDeclaration */:
                        return Diagnostics.Unable_to_resolve_signature_of_property_decorator_when_called_as_an_expression;
                    case 174 /* MethodDeclaration */:
                    case 177 /* GetAccessor */:
                    case 178 /* SetAccessor */:
                        return Diagnostics.Unable_to_resolve_signature_of_method_decorator_when_called_as_an_expression;
                    default:
                        return Debug.fail();
                }
            }
            function resolveDecorator(node, candidatesOutArray, checkMode) {
                const funcType = checkExpression(node.expression);
                const apparentType = getApparentType(funcType);
                if (isErrorType(apparentType)) {
                    return resolveErrorCall(node);
                }
                const callSignatures = getSignaturesOfType(apparentType, 0 /* Call */);
                const numConstructSignatures = getSignaturesOfType(apparentType, 1 /* Construct */).length;
                if (isUntypedFunctionCall(funcType, apparentType, callSignatures.length, numConstructSignatures)) {
                    return resolveUntypedCall(node);
                }
                if (isPotentiallyUncalledDecorator(node, callSignatures) && !isParenthesizedExpression(node.expression)) {
                    const nodeStr = getTextOfNode(node.expression, 
                    /*includeTrivia*/
                    false);
                    error2(node, Diagnostics._0_accepts_too_few_arguments_to_be_used_as_a_decorator_here_Did_you_mean_to_call_it_first_and_write_0, nodeStr);
                    return resolveErrorCall(node);
                }
                const headMessage = getDiagnosticHeadMessageForDecoratorResolution(node);
                if (!callSignatures.length) {
                    const errorDetails = invocationErrorDetails(node.expression, apparentType, 0 /* Call */);
                    const messageChain = chainDiagnosticMessages(errorDetails.messageChain, headMessage);
                    const diag2 = createDiagnosticForNodeFromMessageChain(getSourceFileOfNode(node.expression), node.expression, messageChain);
                    if (errorDetails.relatedMessage) {
                        addRelatedInfo(diag2, createDiagnosticForNode(node.expression, errorDetails.relatedMessage));
                    }
                    diagnostics.add(diag2);
                    invocationErrorRecovery(apparentType, 0 /* Call */, diag2);
                    return resolveErrorCall(node);
                }
                return resolveCall(node, callSignatures, candidatesOutArray, checkMode, 0 /* None */, headMessage);
            }
            function createSignatureForJSXIntrinsic(node, result) {
                const namespace = getJsxNamespaceAt(node);
                const exports = namespace && getExportsOfSymbol(namespace);
                const typeSymbol = exports && getSymbol2(exports, JsxNames.Element, 788968 /* Type */);
                const returnNode = typeSymbol && nodeBuilder.symbolToEntityName(typeSymbol, 788968 /* Type */, node);
                const declaration = factory.createFunctionTypeNode(
                /*typeParameters*/
                void 0, [factory.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, "props", 
                    /*questionToken*/
                    void 0, nodeBuilder.typeToTypeNode(result, node))], returnNode ? factory.createTypeReferenceNode(returnNode, 
                /*typeArguments*/
                void 0) : factory.createKeywordTypeNode(133 /* AnyKeyword */));
                const parameterSymbol = createSymbol(1 /* FunctionScopedVariable */, "props");
                parameterSymbol.links.type = result;
                return createSignature(declaration, 
                /*typeParameters*/
                void 0, 
                /*thisParameter*/
                void 0, [parameterSymbol], typeSymbol ? getDeclaredTypeOfSymbol(typeSymbol) : errorType, 
                /*resolvedTypePredicate*/
                void 0, 1, 0 /* None */);
            }
            function resolveJsxOpeningLikeElement(node, candidatesOutArray, checkMode) {
                if (isJsxIntrinsicTagName(node.tagName)) {
                    const result = getIntrinsicAttributesTypeFromJsxOpeningLikeElement(node);
                    const fakeSignature = createSignatureForJSXIntrinsic(node, result);
                    checkTypeAssignableToAndOptionallyElaborate(checkExpressionWithContextualType(node.attributes, getEffectiveFirstArgumentForJsxSignature(fakeSignature, node), 
                    /*inferenceContext*/
                    void 0, 0 /* Normal */), result, node.tagName, node.attributes);
                    if (length(node.typeArguments)) {
                        forEach(node.typeArguments, checkSourceElement);
                        diagnostics.add(createDiagnosticForNodeArray(getSourceFileOfNode(node), node.typeArguments, Diagnostics.Expected_0_type_arguments_but_got_1, 0, length(node.typeArguments)));
                    }
                    return fakeSignature;
                }
                const exprTypes = checkExpression(node.tagName);
                const apparentType = getApparentType(exprTypes);
                if (isErrorType(apparentType)) {
                    return resolveErrorCall(node);
                }
                const signatures = getUninstantiatedJsxSignaturesOfType(exprTypes, node);
                if (isUntypedFunctionCall(exprTypes, apparentType, signatures.length, 
                /*constructSignatures*/
                0)) {
                    return resolveUntypedCall(node);
                }
                if (signatures.length === 0) {
                    error2(node.tagName, Diagnostics.JSX_element_type_0_does_not_have_any_construct_or_call_signatures, getTextOfNode(node.tagName));
                    return resolveErrorCall(node);
                }
                return resolveCall(node, signatures, candidatesOutArray, checkMode, 0 /* None */);
            }
            function resolveInstanceofExpression(node, candidatesOutArray, checkMode) {
                const rightType = checkExpression(node.right);
                if (!isTypeAny(rightType)) {
                    const hasInstanceMethodType = getSymbolHasInstanceMethodOfObjectType(rightType);
                    if (hasInstanceMethodType) {
                        const apparentType = getApparentType(hasInstanceMethodType);
                        if (isErrorType(apparentType)) {
                            return resolveErrorCall(node);
                        }
                        const callSignatures = getSignaturesOfType(apparentType, 0 /* Call */);
                        const constructSignatures = getSignaturesOfType(apparentType, 1 /* Construct */);
                        if (isUntypedFunctionCall(hasInstanceMethodType, apparentType, callSignatures.length, constructSignatures.length)) {
                            return resolveUntypedCall(node);
                        }
                        if (callSignatures.length) {
                            return resolveCall(node, callSignatures, candidatesOutArray, checkMode, 0 /* None */);
                        }
                    }
                    else if (!(typeHasCallOrConstructSignatures(rightType) || isTypeSubtypeOf(rightType, globalFunctionType))) {
                        error2(node.right, Diagnostics.The_right_hand_side_of_an_instanceof_expression_must_be_either_of_type_any_a_class_function_or_other_type_assignable_to_the_Function_interface_type_or_an_object_type_with_a_Symbol_hasInstance_method);
                        return resolveErrorCall(node);
                    }
                }
                return anySignature;
            }
            function isPotentiallyUncalledDecorator(decorator, signatures) {
                return signatures.length && every(signatures, (signature) => signature.minArgumentCount === 0 && !signatureHasRestParameter(signature) && signature.parameters.length < getDecoratorArgumentCount(decorator, signature));
            }
            function resolveSignature(node, candidatesOutArray, checkMode) {
                switch (node.kind) {
                    case 213 /* CallExpression */:
                        return resolveCallExpression(node, candidatesOutArray, checkMode);
                    case 214 /* NewExpression */:
                        return resolveNewExpression(node, candidatesOutArray, checkMode);
                    case 215 /* TaggedTemplateExpression */:
                        return resolveTaggedTemplateExpression(node, candidatesOutArray, checkMode);
                    case 170 /* Decorator */:
                        return resolveDecorator(node, candidatesOutArray, checkMode);
                    case 286 /* JsxOpeningElement */:
                    case 285 /* JsxSelfClosingElement */:
                        return resolveJsxOpeningLikeElement(node, candidatesOutArray, checkMode);
                    case 226 /* BinaryExpression */:
                        return resolveInstanceofExpression(node, candidatesOutArray, checkMode);
                }
                Debug.assertNever(node, "Branch in 'resolveSignature' should be unreachable.");
            }
            function getResolvedSignature(node, candidatesOutArray, checkMode) {
                const links = getNodeLinks(node);
                const cached = links.resolvedSignature;
                if (cached && cached !== resolvingSignature && !candidatesOutArray) {
                    return cached;
                }
                links.resolvedSignature = resolvingSignature;
                let result = resolveSignature(node, candidatesOutArray, checkMode || 0 /* Normal */);
                if (result !== resolvingSignature) {
                    if (links.resolvedSignature !== resolvingSignature) {
                        result = links.resolvedSignature;
                    }
                    links.resolvedSignature = flowLoopStart === flowLoopCount ? result : cached;
                }
                return result;
            }
            function isJSConstructor(node) {
                var _a;
                if (!node || !isInJSFile(node)) {
                    return false;
                }
                const func = isFunctionDeclaration(node) || isFunctionExpression(node) ? node : (isVariableDeclaration(node) || isPropertyAssignment(node)) && node.initializer && isFunctionExpression(node.initializer) ? node.initializer : void 0;
                if (func) {
                    if (getJSDocClassTag(node))
                        return true;
                    if (isPropertyAssignment(walkUpParenthesizedExpressions(func.parent)))
                        return false;
                    const symbol = getSymbolOfDeclaration(func);
                    return !!((_a = symbol == null ? void 0 : symbol.members) == null ? void 0 : _a.size);
                }
                return false;
            }
            function mergeJSSymbols(target, source) {
                var _a, _b;
                if (source) {
                    const links = getSymbolLinks(source);
                    if (!links.inferredClassSymbol || !links.inferredClassSymbol.has(getSymbolId(target))) {
                        const inferred = isTransientSymbol(target) ? target : cloneSymbol(target);
                        inferred.exports = inferred.exports || createSymbolTable();
                        inferred.members = inferred.members || createSymbolTable();
                        inferred.flags |= source.flags & 32 /* Class */;
                        if ((_a = source.exports) == null ? void 0 : _a.size) {
                            mergeSymbolTable(inferred.exports, source.exports);
                        }
                        if ((_b = source.members) == null ? void 0 : _b.size) {
                            mergeSymbolTable(inferred.members, source.members);
                        }
                        (links.inferredClassSymbol || (links.inferredClassSymbol = /* @__PURE__ */ new Map())).set(getSymbolId(inferred), inferred);
                        return inferred;
                    }
                    return links.inferredClassSymbol.get(getSymbolId(target));
                }
            }
            function getAssignedClassSymbol(decl) {
                var _a;
                const assignmentSymbol = decl && getSymbolOfExpando(decl, 
                /*allowDeclaration*/
                true);
                const prototype = (_a = assignmentSymbol == null ? void 0 : assignmentSymbol.exports) == null ? void 0 : _a.get("prototype");
                const init = (prototype == null ? void 0 : prototype.valueDeclaration) && getAssignedJSPrototype(prototype.valueDeclaration);
                return init ? getSymbolOfDeclaration(init) : void 0;
            }
            function getSymbolOfExpando(node, allowDeclaration) {
                if (!node.parent) {
                    return void 0;
                }
                let name;
                let decl;
                if (isVariableDeclaration(node.parent) && node.parent.initializer === node) {
                    if (!isInJSFile(node) && !(isVarConstLike(node.parent) && isFunctionLikeDeclaration(node))) {
                        return void 0;
                    }
                    name = node.parent.name;
                    decl = node.parent;
                }
                else if (isBinaryExpression(node.parent)) {
                    const parentNode = node.parent;
                    const parentNodeOperator = node.parent.operatorToken.kind;
                    if (parentNodeOperator === 64 /* EqualsToken */ && (allowDeclaration || parentNode.right === node)) {
                        name = parentNode.left;
                        decl = name;
                    }
                    else if (parentNodeOperator === 57 /* BarBarToken */ || parentNodeOperator === 61 /* QuestionQuestionToken */) {
                        if (isVariableDeclaration(parentNode.parent) && parentNode.parent.initializer === parentNode) {
                            name = parentNode.parent.name;
                            decl = parentNode.parent;
                        }
                        else if (isBinaryExpression(parentNode.parent) && parentNode.parent.operatorToken.kind === 64 /* EqualsToken */ && (allowDeclaration || parentNode.parent.right === parentNode)) {
                            name = parentNode.parent.left;
                            decl = name;
                        }
                        if (!name || !isBindableStaticNameExpression(name) || !isSameEntityName(name, parentNode.left)) {
                            return void 0;
                        }
                    }
                }
                else if (allowDeclaration && isFunctionDeclaration(node)) {
                    name = node.name;
                    decl = node;
                }
                if (!decl || !name || !allowDeclaration && !getExpandoInitializer(node, isPrototypeAccess(name))) {
                    return void 0;
                }
                return getSymbolOfNode(decl);
            }
            function getAssignedJSPrototype(node) {
                if (!node.parent) {
                    return false;
                }
                let parent2 = node.parent;
                while (parent2 && parent2.kind === 211 /* PropertyAccessExpression */) {
                    parent2 = parent2.parent;
                }
                if (parent2 && isBinaryExpression(parent2) && isPrototypeAccess(parent2.left) && parent2.operatorToken.kind === 64 /* EqualsToken */) {
                    const right = getInitializerOfBinaryExpression(parent2);
                    return isObjectLiteralExpression(right) && right;
                }
            }
            function checkCallExpression(node, checkMode) {
                var _a, _b, _c;
                checkGrammarTypeArguments(node, node.typeArguments);
                const signature = getResolvedSignature(node, 
                /*candidatesOutArray*/
                void 0, checkMode);
                if (signature === resolvingSignature) {
                    return silentNeverType;
                }
                checkDeprecatedSignature(signature, node);
                if (node.expression.kind === 108 /* SuperKeyword */) {
                    return voidType;
                }
                if (node.kind === 214 /* NewExpression */) {
                    const declaration = signature.declaration;
                    if (declaration && declaration.kind !== 176 /* Constructor */ && declaration.kind !== 180 /* ConstructSignature */ && declaration.kind !== 185 /* ConstructorType */ && !(isJSDocSignature(declaration) && ((_b = (_a = getJSDocRoot(declaration)) == null ? void 0 : _a.parent) == null ? void 0 : _b.kind) === 176 /* Constructor */) && !isJSDocConstructSignature(declaration) && !isJSConstructor(declaration)) {
                        if (noImplicitAny) {
                            error2(node, Diagnostics.new_expression_whose_target_lacks_a_construct_signature_implicitly_has_an_any_type);
                        }
                        return anyType;
                    }
                }
                if (isInJSFile(node) && isCommonJsRequire(node)) {
                    return resolveExternalModuleTypeByLiteral(node.arguments[0]);
                }
                const returnType = getReturnTypeOfSignature(signature);
                if (returnType.flags & 12288 /* ESSymbolLike */ && isSymbolOrSymbolForCall(node)) {
                    return getESSymbolLikeTypeForNode(walkUpParenthesizedExpressions(node.parent));
                }
                if (node.kind === 213 /* CallExpression */ && !node.questionDotToken && node.parent.kind === 244 /* ExpressionStatement */ && returnType.flags & 16384 /* Void */ && getTypePredicateOfSignature(signature)) {
                    if (!isDottedName(node.expression)) {
                        error2(node.expression, Diagnostics.Assertions_require_the_call_target_to_be_an_identifier_or_qualified_name);
                    }
                    else if (!getEffectsSignature(node)) {
                        const diagnostic = error2(node.expression, Diagnostics.Assertions_require_every_name_in_the_call_target_to_be_declared_with_an_explicit_type_annotation);
                        getTypeOfDottedName(node.expression, diagnostic);
                    }
                }
                if (isInJSFile(node)) {
                    const jsSymbol = getSymbolOfExpando(node, 
                    /*allowDeclaration*/
                    false);
                    if ((_c = jsSymbol == null ? void 0 : jsSymbol.exports) == null ? void 0 : _c.size) {
                        const jsAssignmentType = createAnonymousType(jsSymbol, jsSymbol.exports, emptyArray, emptyArray, emptyArray);
                        jsAssignmentType.objectFlags |= 4096 /* JSLiteral */;
                        return getIntersectionType([returnType, jsAssignmentType]);
                    }
                }
                return returnType;
            }
            function checkDeprecatedSignature(signature, node) {
                if (signature.flags & 128 /* IsSignatureCandidateForOverloadFailure */)
                    return;
                if (signature.declaration && signature.declaration.flags & 536870912 /* Deprecated */) {
                    const suggestionNode = getDeprecatedSuggestionNode(node);
                    const name = tryGetPropertyAccessOrIdentifierToString(getInvokedExpression(node));
                    addDeprecatedSuggestionWithSignature(suggestionNode, signature.declaration, name, signatureToString(signature));
                }
            }
            function getDeprecatedSuggestionNode(node) {
                node = skipParentheses(node);
                switch (node.kind) {
                    case 213 /* CallExpression */:
                    case 170 /* Decorator */:
                    case 214 /* NewExpression */:
                        return getDeprecatedSuggestionNode(node.expression);
                    case 215 /* TaggedTemplateExpression */:
                        return getDeprecatedSuggestionNode(node.tag);
                    case 286 /* JsxOpeningElement */:
                    case 285 /* JsxSelfClosingElement */:
                        return getDeprecatedSuggestionNode(node.tagName);
                    case 212 /* ElementAccessExpression */:
                        return node.argumentExpression;
                    case 211 /* PropertyAccessExpression */:
                        return node.name;
                    case 183 /* TypeReference */:
                        const typeReference = node;
                        return isQualifiedName(typeReference.typeName) ? typeReference.typeName.right : typeReference;
                    default:
                        return node;
                }
            }
            function isSymbolOrSymbolForCall(node) {
                if (!isCallExpression(node))
                    return false;
                let left = node.expression;
                if (isPropertyAccessExpression(left) && left.name.escapedText === "for") {
                    left = left.expression;
                }
                if (!isIdentifier(left) || left.escapedText !== "Symbol") {
                    return false;
                }
                const globalESSymbol = getGlobalESSymbolConstructorSymbol(
                /*reportErrors*/
                false);
                if (!globalESSymbol) {
                    return false;
                }
                return globalESSymbol === resolveName(left, "Symbol", 111551 /* Value */, 
                /*nameNotFoundMessage*/
                void 0, 
                /*nameArg*/
                void 0, 
                /*isUse*/
                false);
            }
            function checkImportCallExpression(node) {
                checkGrammarImportCallExpression(node);
                if (node.arguments.length === 0) {
                    return createPromiseReturnType(node, anyType);
                }
                const specifier = node.arguments[0];
                const specifierType = checkExpressionCached(specifier);
                const optionsType = node.arguments.length > 1 ? checkExpressionCached(node.arguments[1]) : void 0;
                for (let i = 2; i < node.arguments.length; ++i) {
                    checkExpressionCached(node.arguments[i]);
                }
                if (specifierType.flags & 32768 /* Undefined */ || specifierType.flags & 65536 /* Null */ || !isTypeAssignableTo(specifierType, stringType)) {
                    error2(specifier, Diagnostics.Dynamic_import_s_specifier_must_be_of_type_string_but_here_has_type_0, typeToString(specifierType));
                }
                if (optionsType) {
                    const importCallOptionsType = getGlobalImportCallOptionsType(
                    /*reportErrors*/
                    true);
                    if (importCallOptionsType !== emptyObjectType) {
                        checkTypeAssignableTo(optionsType, getNullableType(importCallOptionsType, 32768 /* Undefined */), node.arguments[1]);
                    }
                }
                const moduleSymbol = resolveExternalModuleName(node, specifier);
                if (moduleSymbol) {
                    const esModuleSymbol = resolveESModuleSymbol(moduleSymbol, specifier, 
                    /*dontResolveAlias*/
                    true, 
                    /*suppressInteropError*/
                    false);
                    if (esModuleSymbol) {
                        return createPromiseReturnType(node, getTypeWithSyntheticDefaultOnly(getTypeOfSymbol(esModuleSymbol), esModuleSymbol, moduleSymbol, specifier) || getTypeWithSyntheticDefaultImportType(getTypeOfSymbol(esModuleSymbol), esModuleSymbol, moduleSymbol, specifier));
                    }
                }
                return createPromiseReturnType(node, anyType);
            }
            function createDefaultPropertyWrapperForModule(symbol, originalSymbol, anonymousSymbol) {
                const memberTable = createSymbolTable();
                const newSymbol = createSymbol(2097152 /* Alias */, "default" /* Default */);
                newSymbol.parent = originalSymbol;
                newSymbol.links.nameType = getStringLiteralType("default");
                newSymbol.links.aliasTarget = resolveSymbol(symbol);
                memberTable.set("default" /* Default */, newSymbol);
                return createAnonymousType(anonymousSymbol, memberTable, emptyArray, emptyArray, emptyArray);
            }
            function getTypeWithSyntheticDefaultOnly(type, symbol, originalSymbol, moduleSpecifier) {
                const hasDefaultOnly = isOnlyImportedAsDefault(moduleSpecifier);
                if (hasDefaultOnly && type && !isErrorType(type)) {
                    const synthType = type;
                    if (!synthType.defaultOnlyType) {
                        const type2 = createDefaultPropertyWrapperForModule(symbol, originalSymbol);
                        synthType.defaultOnlyType = type2;
                    }
                    return synthType.defaultOnlyType;
                }
                return void 0;
            }
            function getTypeWithSyntheticDefaultImportType(type, symbol, originalSymbol, moduleSpecifier) {
                var _a;
                if (allowSyntheticDefaultImports && type && !isErrorType(type)) {
                    const synthType = type;
                    if (!synthType.syntheticType) {
                        const file = (_a = originalSymbol.declarations) == null ? void 0 : _a.find(isSourceFile);
                        const hasSyntheticDefault = canHaveSyntheticDefault(file, originalSymbol, 
                        /*dontResolveAlias*/
                        false, moduleSpecifier);
                        if (hasSyntheticDefault) {
                            const anonymousSymbol = createSymbol(2048 /* TypeLiteral */, "__type" /* Type */);
                            const defaultContainingObject = createDefaultPropertyWrapperForModule(symbol, originalSymbol, anonymousSymbol);
                            anonymousSymbol.links.type = defaultContainingObject;
                            synthType.syntheticType = isValidSpreadType(type) ? getSpreadType(type, defaultContainingObject, anonymousSymbol, 
                            /*objectFlags*/
                            0, 
                            /*readonly*/
                            false) : defaultContainingObject;
                        }
                        else {
                            synthType.syntheticType = type;
                        }
                    }
                    return synthType.syntheticType;
                }
                return type;
            }
            function isCommonJsRequire(node) {
                if (!isRequireCall(node, 
                /*requireStringLiteralLikeArgument*/
                true)) {
                    return false;
                }
                if (!isIdentifier(node.expression))
                    return Debug.fail();
                const resolvedRequire = resolveName(node.expression, node.expression.escapedText, 111551 /* Value */, 
                /*nameNotFoundMessage*/
                void 0, 
                /*nameArg*/
                void 0, 
                /*isUse*/
                true);
                if (resolvedRequire === requireSymbol) {
                    return true;
                }
                if (resolvedRequire.flags & 2097152 /* Alias */) {
                    return false;
                }
                const targetDeclarationKind = resolvedRequire.flags & 16 /* Function */ ? 262 /* FunctionDeclaration */ : resolvedRequire.flags & 3 /* Variable */ ? 260 /* VariableDeclaration */ : 0 /* Unknown */;
                if (targetDeclarationKind !== 0 /* Unknown */) {
                    const decl = getDeclarationOfKind(resolvedRequire, targetDeclarationKind);
                    return !!decl && !!(decl.flags & 33554432 /* Ambient */);
                }
                return false;
            }
            function checkTaggedTemplateExpression(node) {
                if (!checkGrammarTaggedTemplateChain(node))
                    checkGrammarTypeArguments(node, node.typeArguments);
                if (languageVersion < 2 /* ES2015 */) {
                    checkExternalEmitHelpers(node, 262144 /* MakeTemplateObject */);
                }
                const signature = getResolvedSignature(node);
                checkDeprecatedSignature(signature, node);
                return getReturnTypeOfSignature(signature);
            }
            function checkAssertion(node, checkMode) {
                if (node.kind === 216 /* TypeAssertionExpression */) {
                    const file = getSourceFileOfNode(node);
                    if (file && fileExtensionIsOneOf(file.fileName, [".cts" /* Cts */, ".mts" /* Mts */])) {
                        grammarErrorOnNode(node, Diagnostics.This_syntax_is_reserved_in_files_with_the_mts_or_cts_extension_Use_an_as_expression_instead);
                    }
                }
                return checkAssertionWorker(node, checkMode);
            }
            function isValidConstAssertionArgument(node) {
                switch (node.kind) {
                    case 11 /* StringLiteral */:
                    case 15 /* NoSubstitutionTemplateLiteral */:
                    case 9 /* NumericLiteral */:
                    case 10 /* BigIntLiteral */:
                    case 112 /* TrueKeyword */:
                    case 97 /* FalseKeyword */:
                    case 209 /* ArrayLiteralExpression */:
                    case 210 /* ObjectLiteralExpression */:
                    case 228 /* TemplateExpression */:
                        return true;
                    case 217 /* ParenthesizedExpression */:
                        return isValidConstAssertionArgument(node.expression);
                    case 224 /* PrefixUnaryExpression */:
                        const op = node.operator;
                        const arg = node.operand;
                        return op === 41 /* MinusToken */ && (arg.kind === 9 /* NumericLiteral */ || arg.kind === 10 /* BigIntLiteral */) || op === 40 /* PlusToken */ && arg.kind === 9 /* NumericLiteral */;
                    case 211 /* PropertyAccessExpression */:
                    case 212 /* ElementAccessExpression */:
                        const expr = skipParentheses(node.expression);
                        const symbol = isEntityNameExpression(expr) ? resolveEntityName(expr, 111551 /* Value */, 
                        /*ignoreErrors*/
                        true) : void 0;
                        return !!(symbol && symbol.flags & 384 /* Enum */);
                }
                return false;
            }
            function checkAssertionWorker(node, checkMode) {
                const { type, expression } = getAssertionTypeAndExpression(node);
                const exprType = checkExpression(expression, checkMode);
                if (isConstTypeReference(type)) {
                    if (!isValidConstAssertionArgument(expression)) {
                        error2(expression, Diagnostics.A_const_assertions_can_only_be_applied_to_references_to_enum_members_or_string_number_boolean_array_or_object_literals);
                    }
                    return getRegularTypeOfLiteralType(exprType);
                }
                const links = getNodeLinks(node);
                links.assertionExpressionType = exprType;
                checkSourceElement(type);
                checkNodeDeferred(node);
                return getTypeFromTypeNode(type);
            }
            function getAssertionTypeAndExpression(node) {
                let type;
                let expression;
                switch (node.kind) {
                    case 234 /* AsExpression */:
                    case 216 /* TypeAssertionExpression */:
                        type = node.type;
                        expression = node.expression;
                        break;
                    case 217 /* ParenthesizedExpression */:
                        type = getJSDocTypeAssertionType(node);
                        expression = node.expression;
                        break;
                }
                return { type, expression };
            }
            function checkAssertionDeferred(node) {
                const { type } = getAssertionTypeAndExpression(node);
                const errNode = isParenthesizedExpression(node) ? type : node;
                const links = getNodeLinks(node);
                Debug.assertIsDefined(links.assertionExpressionType);
                const exprType = getRegularTypeOfObjectLiteral(getBaseTypeOfLiteralType(links.assertionExpressionType));
                const targetType = getTypeFromTypeNode(type);
                if (!isErrorType(targetType)) {
                    addLazyDiagnostic(() => {
                        const widenedType = getWidenedType(exprType);
                        if (!isTypeComparableTo(targetType, widenedType)) {
                            checkTypeComparableTo(exprType, targetType, errNode, Diagnostics.Conversion_of_type_0_to_type_1_may_be_a_mistake_because_neither_type_sufficiently_overlaps_with_the_other_If_this_was_intentional_convert_the_expression_to_unknown_first);
                        }
                    });
                }
            }
            function checkNonNullChain(node) {
                const leftType = checkExpression(node.expression);
                const nonOptionalType = getOptionalExpressionType(leftType, node.expression);
                return propagateOptionalTypeMarker(getNonNullableType(nonOptionalType), node, nonOptionalType !== leftType);
            }
            function checkNonNullAssertion(node) {
                return node.flags & 64 /* OptionalChain */ ? checkNonNullChain(node) : getNonNullableType(checkExpression(node.expression));
            }
            function checkExpressionWithTypeArguments(node) {
                checkGrammarExpressionWithTypeArguments(node);
                forEach(node.typeArguments, checkSourceElement);
                if (node.kind === 233 /* ExpressionWithTypeArguments */) {
                    const parent2 = walkUpParenthesizedExpressions(node.parent);
                    if (parent2.kind === 226 /* BinaryExpression */ && parent2.operatorToken.kind === 104 /* InstanceOfKeyword */ && isNodeDescendantOf(node, parent2.right)) {
                        error2(node, Diagnostics.The_right_hand_side_of_an_instanceof_expression_must_not_be_an_instantiation_expression);
                    }
                }
                const exprType = node.kind === 233 /* ExpressionWithTypeArguments */ ? checkExpression(node.expression) : isThisIdentifier(node.exprName) ? checkThisExpression(node.exprName) : checkExpression(node.exprName);
                return getInstantiationExpressionType(exprType, node);
            }
            function getInstantiationExpressionType(exprType, node) {
                const typeArguments = node.typeArguments;
                if (exprType === silentNeverType || isErrorType(exprType) || !some(typeArguments)) {
                    return exprType;
                }
                let hasSomeApplicableSignature = false;
                let nonApplicableType;
                const result = getInstantiatedType(exprType);
                const errorType2 = hasSomeApplicableSignature ? nonApplicableType : exprType;
                if (errorType2) {
                    diagnostics.add(createDiagnosticForNodeArray(getSourceFileOfNode(node), typeArguments, Diagnostics.Type_0_has_no_signatures_for_which_the_type_argument_list_is_applicable, typeToString(errorType2)));
                }
                return result;
                function getInstantiatedType(type) {
                    let hasSignatures = false;
                    let hasApplicableSignature = false;
                    const result2 = getInstantiatedTypePart(type);
                    hasSomeApplicableSignature || (hasSomeApplicableSignature = hasApplicableSignature);
                    if (hasSignatures && !hasApplicableSignature) {
                        nonApplicableType ?? (nonApplicableType = type);
                    }
                    return result2;
                    function getInstantiatedTypePart(type2) {
                        if (type2.flags & 524288 /* Object */) {
                            const resolved = resolveStructuredTypeMembers(type2);
                            const callSignatures = getInstantiatedSignatures(resolved.callSignatures);
                            const constructSignatures = getInstantiatedSignatures(resolved.constructSignatures);
                            hasSignatures || (hasSignatures = resolved.callSignatures.length !== 0 || resolved.constructSignatures.length !== 0);
                            hasApplicableSignature || (hasApplicableSignature = callSignatures.length !== 0 || constructSignatures.length !== 0);
                            if (callSignatures !== resolved.callSignatures || constructSignatures !== resolved.constructSignatures) {
                                const result3 = createAnonymousType(createSymbol(0 /* None */, "__instantiationExpression" /* InstantiationExpression */), resolved.members, callSignatures, constructSignatures, resolved.indexInfos);
                                result3.objectFlags |= 8388608 /* InstantiationExpressionType */;
                                result3.node = node;
                                return result3;
                            }
                        }
                        else if (type2.flags & 58982400 /* InstantiableNonPrimitive */) {
                            const constraint = getBaseConstraintOfType(type2);
                            if (constraint) {
                                const instantiated = getInstantiatedTypePart(constraint);
                                if (instantiated !== constraint) {
                                    return instantiated;
                                }
                            }
                        }
                        else if (type2.flags & 1048576 /* Union */) {
                            return mapType(type2, getInstantiatedType);
                        }
                        else if (type2.flags & 2097152 /* Intersection */) {
                            return getIntersectionType(sameMap(type2.types, getInstantiatedTypePart));
                        }
                        return type2;
                    }
                }
                function getInstantiatedSignatures(signatures) {
                    const applicableSignatures = filter(signatures, (sig) => !!sig.typeParameters && hasCorrectTypeArgumentArity(sig, typeArguments));
                    return sameMap(applicableSignatures, (sig) => {
                        const typeArgumentTypes = checkTypeArguments(sig, typeArguments, 
                        /*reportErrors*/
                        true);
                        return typeArgumentTypes ? getSignatureInstantiation(sig, typeArgumentTypes, isInJSFile(sig.declaration)) : sig;
                    });
                }
            }
            function checkSatisfiesExpression(node) {
                checkSourceElement(node.type);
                return checkSatisfiesExpressionWorker(node.expression, node.type);
            }
            function checkSatisfiesExpressionWorker(expression, target, checkMode) {
                const exprType = checkExpression(expression, checkMode);
                const targetType = getTypeFromTypeNode(target);
                if (isErrorType(targetType)) {
                    return targetType;
                }
                const errorNode = findAncestor(target.parent, (n) => n.kind === 238 /* SatisfiesExpression */ || n.kind === 357 /* JSDocSatisfiesTag */);
                checkTypeAssignableToAndOptionallyElaborate(exprType, targetType, errorNode, expression, Diagnostics.Type_0_does_not_satisfy_the_expected_type_1);
                return exprType;
            }
            function checkMetaProperty(node) {
                checkGrammarMetaProperty(node);
                if (node.keywordToken === 105 /* NewKeyword */) {
                    return checkNewTargetMetaProperty(node);
                }
                if (node.keywordToken === 102 /* ImportKeyword */) {
                    return checkImportMetaProperty(node);
                }
                return Debug.assertNever(node.keywordToken);
            }
            function checkMetaPropertyKeyword(node) {
                switch (node.keywordToken) {
                    case 102 /* ImportKeyword */:
                        return getGlobalImportMetaExpressionType();
                    case 105 /* NewKeyword */:
                        const type = checkNewTargetMetaProperty(node);
                        return isErrorType(type) ? errorType : createNewTargetExpressionType(type);
                    default:
                        Debug.assertNever(node.keywordToken);
                }
            }
            function checkNewTargetMetaProperty(node) {
                const container = getNewTargetContainer(node);
                if (!container) {
                    error2(node, Diagnostics.Meta_property_0_is_only_allowed_in_the_body_of_a_function_declaration_function_expression_or_constructor, "new.target");
                    return errorType;
                }
                else if (container.kind === 176 /* Constructor */) {
                    const symbol = getSymbolOfDeclaration(container.parent);
                    return getTypeOfSymbol(symbol);
                }
                else {
                    const symbol = getSymbolOfDeclaration(container);
                    return getTypeOfSymbol(symbol);
                }
            }
            function checkImportMetaProperty(node) {
                if (moduleKind === 100 /* Node16 */ || moduleKind === 199 /* NodeNext */) {
                    if (getSourceFileOfNode(node).impliedNodeFormat !== 99 /* ESNext */) {
                        error2(node, Diagnostics.The_import_meta_meta_property_is_not_allowed_in_files_which_will_build_into_CommonJS_output);
                    }
                }
                else if (moduleKind < 6 /* ES2020 */ && moduleKind !== 4 /* System */) {
                    error2(node, Diagnostics.The_import_meta_meta_property_is_only_allowed_when_the_module_option_is_es2020_es2022_esnext_system_node16_or_nodenext);
                }
                const file = getSourceFileOfNode(node);
                Debug.assert(!!(file.flags & 8388608 /* PossiblyContainsImportMeta */), "Containing file is missing import meta node flag.");
                return node.name.escapedText === "meta" ? getGlobalImportMetaType() : errorType;
            }
            function getTypeOfParameter(symbol) {
                const declaration = symbol.valueDeclaration;
                return addOptionality(getTypeOfSymbol(symbol), 
                /*isProperty*/
                false, 
                /*isOptional*/
                !!declaration && (hasInitializer(declaration) || isOptionalDeclaration(declaration)));
            }
            function getTupleElementLabel(d, index, restParameterName = "arg") {
                if (!d) {
                    return `${restParameterName}_${index}`;
                }
                Debug.assert(isIdentifier(d.name));
                return d.name.escapedText;
            }
            function getParameterNameAtPosition(signature, pos, overrideRestType) {
                const paramCount = signature.parameters.length - (signatureHasRestParameter(signature) ? 1 : 0);
                if (pos < paramCount) {
                    return signature.parameters[pos].escapedName;
                }
                const restParameter = signature.parameters[paramCount] || unknownSymbol;
                const restType = overrideRestType || getTypeOfSymbol(restParameter);
                if (isTupleType(restType)) {
                    const associatedNames = restType.target.labeledElementDeclarations;
                    const index = pos - paramCount;
                    return getTupleElementLabel(associatedNames == null ? void 0 : associatedNames[index], index, restParameter.escapedName);
                }
                return restParameter.escapedName;
            }
            function getParameterIdentifierInfoAtPosition(signature, pos) {
                var _a;
                if (((_a = signature.declaration) == null ? void 0 : _a.kind) === 324 /* JSDocFunctionType */) {
                    return void 0;
                }
                const paramCount = signature.parameters.length - (signatureHasRestParameter(signature) ? 1 : 0);
                if (pos < paramCount) {
                    const param = signature.parameters[pos];
                    const paramIdent = getParameterDeclarationIdentifier(param);
                    return paramIdent ? {
                        parameter: paramIdent,
                        parameterName: param.escapedName,
                        isRestParameter: false
                    } : void 0;
                }
                const restParameter = signature.parameters[paramCount] || unknownSymbol;
                const restIdent = getParameterDeclarationIdentifier(restParameter);
                if (!restIdent) {
                    return void 0;
                }
                const restType = getTypeOfSymbol(restParameter);
                if (isTupleType(restType)) {
                    const associatedNames = restType.target.labeledElementDeclarations;
                    const index = pos - paramCount;
                    const associatedName = associatedNames == null ? void 0 : associatedNames[index];
                    const isRestTupleElement = !!(associatedName == null ? void 0 : associatedName.dotDotDotToken);
                    if (associatedName) {
                        Debug.assert(isIdentifier(associatedName.name));
                        return { parameter: associatedName.name, parameterName: associatedName.name.escapedText, isRestParameter: isRestTupleElement };
                    }
                    return void 0;
                }
                if (pos === paramCount) {
                    return { parameter: restIdent, parameterName: restParameter.escapedName, isRestParameter: true };
                }
                return void 0;
            }
            function getParameterDeclarationIdentifier(symbol) {
                return symbol.valueDeclaration && isParameter(symbol.valueDeclaration) && isIdentifier(symbol.valueDeclaration.name) && symbol.valueDeclaration.name;
            }
            function isValidDeclarationForTupleLabel(d) {
                return d.kind === 202 /* NamedTupleMember */ || isParameter(d) && d.name && isIdentifier(d.name);
            }
            function getNameableDeclarationAtPosition(signature, pos) {
                const paramCount = signature.parameters.length - (signatureHasRestParameter(signature) ? 1 : 0);
                if (pos < paramCount) {
                    const decl = signature.parameters[pos].valueDeclaration;
                    return decl && isValidDeclarationForTupleLabel(decl) ? decl : void 0;
                }
                const restParameter = signature.parameters[paramCount] || unknownSymbol;
                const restType = getTypeOfSymbol(restParameter);
                if (isTupleType(restType)) {
                    const associatedNames = restType.target.labeledElementDeclarations;
                    const index = pos - paramCount;
                    return associatedNames && associatedNames[index];
                }
                return restParameter.valueDeclaration && isValidDeclarationForTupleLabel(restParameter.valueDeclaration) ? restParameter.valueDeclaration : void 0;
            }
            function getTypeAtPosition(signature, pos) {
                return tryGetTypeAtPosition(signature, pos) || anyType;
            }
            function tryGetTypeAtPosition(signature, pos) {
                const paramCount = signature.parameters.length - (signatureHasRestParameter(signature) ? 1 : 0);
                if (pos < paramCount) {
                    return getTypeOfParameter(signature.parameters[pos]);
                }
                if (signatureHasRestParameter(signature)) {
                    const restType = getTypeOfSymbol(signature.parameters[paramCount]);
                    const index = pos - paramCount;
                    if (!isTupleType(restType) || restType.target.hasRestElement || index < restType.target.fixedLength) {
                        return getIndexedAccessType(restType, getNumberLiteralType(index));
                    }
                }
                return void 0;
            }
            function getRestTypeAtPosition(source, pos, readonly) {
                const parameterCount = getParameterCount(source);
                const minArgumentCount = getMinArgumentCount(source);
                const restType = getEffectiveRestType(source);
                if (restType && pos >= parameterCount - 1) {
                    return pos === parameterCount - 1 ? restType : createArrayType(getIndexedAccessType(restType, numberType));
                }
                const types = [];
                const flags = [];
                const names = [];
                for (let i = pos; i < parameterCount; i++) {
                    if (!restType || i < parameterCount - 1) {
                        types.push(getTypeAtPosition(source, i));
                        flags.push(i < minArgumentCount ? 1 /* Required */ : 2 /* Optional */);
                    }
                    else {
                        types.push(restType);
                        flags.push(8 /* Variadic */);
                    }
                    names.push(getNameableDeclarationAtPosition(source, i));
                }
                return createTupleType(types, flags, readonly, names);
            }
            function getRestOrAnyTypeAtPosition(source, pos) {
                const restType = getRestTypeAtPosition(source, pos);
                const elementType = restType && getElementTypeOfArrayType(restType);
                return elementType && isTypeAny(elementType) ? anyType : restType;
            }
            function getParameterCount(signature) {
                const length2 = signature.parameters.length;
                if (signatureHasRestParameter(signature)) {
                    const restType = getTypeOfSymbol(signature.parameters[length2 - 1]);
                    if (isTupleType(restType)) {
                        return length2 + restType.target.fixedLength - (restType.target.hasRestElement ? 0 : 1);
                    }
                }
                return length2;
            }
            function getMinArgumentCount(signature, flags) {
                const strongArityForUntypedJS = flags & 1 /* StrongArityForUntypedJS */;
                const voidIsNonOptional = flags & 2 /* VoidIsNonOptional */;
                if (voidIsNonOptional || signature.resolvedMinArgumentCount === void 0) {
                    let minArgumentCount;
                    if (signatureHasRestParameter(signature)) {
                        const restType = getTypeOfSymbol(signature.parameters[signature.parameters.length - 1]);
                        if (isTupleType(restType)) {
                            const firstOptionalIndex = findIndex(restType.target.elementFlags, (f) => !(f & 1 /* Required */));
                            const requiredCount = firstOptionalIndex < 0 ? restType.target.fixedLength : firstOptionalIndex;
                            if (requiredCount > 0) {
                                minArgumentCount = signature.parameters.length - 1 + requiredCount;
                            }
                        }
                    }
                    if (minArgumentCount === void 0) {
                        if (!strongArityForUntypedJS && signature.flags & 32 /* IsUntypedSignatureInJSFile */) {
                            return 0;
                        }
                        minArgumentCount = signature.minArgumentCount;
                    }
                    if (voidIsNonOptional) {
                        return minArgumentCount;
                    }
                    for (let i = minArgumentCount - 1; i >= 0; i--) {
                        const type = getTypeAtPosition(signature, i);
                        if (filterType(type, acceptsVoid).flags & 131072 /* Never */) {
                            break;
                        }
                        minArgumentCount = i;
                    }
                    signature.resolvedMinArgumentCount = minArgumentCount;
                }
                return signature.resolvedMinArgumentCount;
            }
            function hasEffectiveRestParameter(signature) {
                if (signatureHasRestParameter(signature)) {
                    const restType = getTypeOfSymbol(signature.parameters[signature.parameters.length - 1]);
                    return !isTupleType(restType) || restType.target.hasRestElement;
                }
                return false;
            }
            function getEffectiveRestType(signature) {
                if (signatureHasRestParameter(signature)) {
                    const restType = getTypeOfSymbol(signature.parameters[signature.parameters.length - 1]);
                    if (!isTupleType(restType)) {
                        return isTypeAny(restType) ? anyArrayType : restType;
                    }
                    if (restType.target.hasRestElement) {
                        return sliceTupleType(restType, restType.target.fixedLength);
                    }
                }
                return void 0;
            }
            function getNonArrayRestType(signature) {
                const restType = getEffectiveRestType(signature);
                return restType && !isArrayType(restType) && !isTypeAny(restType) ? restType : void 0;
            }
            function getTypeOfFirstParameterOfSignature(signature) {
                return getTypeOfFirstParameterOfSignatureWithFallback(signature, neverType);
            }
            function getTypeOfFirstParameterOfSignatureWithFallback(signature, fallbackType) {
                return signature.parameters.length > 0 ? getTypeAtPosition(signature, 0) : fallbackType;
            }
            function inferFromAnnotatedParameters(signature, context, inferenceContext) {
                const len = signature.parameters.length - (signatureHasRestParameter(signature) ? 1 : 0);
                for (let i = 0; i < len; i++) {
                    const declaration = signature.parameters[i].valueDeclaration;
                    const typeNode = getEffectiveTypeAnnotationNode(declaration);
                    if (typeNode) {
                        const source = addOptionality(getTypeFromTypeNode(typeNode), 
                        /*isProperty*/
                        false, isOptionalDeclaration(declaration));
                        const target = getTypeAtPosition(context, i);
                        inferTypes(inferenceContext.inferences, source, target);
                    }
                }
            }
            function assignContextualParameterTypes(signature, context) {
                if (context.typeParameters) {
                    if (!signature.typeParameters) {
                        signature.typeParameters = context.typeParameters;
                    }
                    else {
                        return;
                    }
                }
                if (context.thisParameter) {
                    const parameter = signature.thisParameter;
                    if (!parameter || parameter.valueDeclaration && !parameter.valueDeclaration.type) {
                        if (!parameter) {
                            signature.thisParameter = createSymbolWithType(context.thisParameter, 
                            /*type*/
                            void 0);
                        }
                        assignParameterType(signature.thisParameter, getTypeOfSymbol(context.thisParameter));
                    }
                }
                const len = signature.parameters.length - (signatureHasRestParameter(signature) ? 1 : 0);
                for (let i = 0; i < len; i++) {
                    const parameter = signature.parameters[i];
                    const declaration = parameter.valueDeclaration;
                    if (!getEffectiveTypeAnnotationNode(declaration)) {
                        let type = tryGetTypeAtPosition(context, i);
                        if (type && declaration.initializer) {
                            let initializerType = checkDeclarationInitializer(declaration, 0 /* Normal */);
                            if (!isTypeAssignableTo(initializerType, type) && isTypeAssignableTo(type, initializerType = widenTypeInferredFromInitializer(declaration, initializerType))) {
                                type = initializerType;
                            }
                        }
                        assignParameterType(parameter, type);
                    }
                }
                if (signatureHasRestParameter(signature)) {
                    const parameter = last(signature.parameters);
                    if (parameter.valueDeclaration ? !getEffectiveTypeAnnotationNode(parameter.valueDeclaration) : !!(getCheckFlags(parameter) & 65536 /* DeferredType */)) {
                        const contextualParameterType = getRestTypeAtPosition(context, len);
                        assignParameterType(parameter, contextualParameterType);
                    }
                }
            }
            function assignNonContextualParameterTypes(signature) {
                if (signature.thisParameter) {
                    assignParameterType(signature.thisParameter);
                }
                for (const parameter of signature.parameters) {
                    assignParameterType(parameter);
                }
            }
            function assignParameterType(parameter, contextualType) {
                const links = getSymbolLinks(parameter);
                if (!links.type) {
                    const declaration = parameter.valueDeclaration;
                    links.type = addOptionality(contextualType || (declaration ? getWidenedTypeForVariableLikeDeclaration(declaration, 
                    /*reportErrors*/
                    true) : getTypeOfSymbol(parameter)), 
                    /*isProperty*/
                    false, 
                    /*isOptional*/
                    !!declaration && !declaration.initializer && isOptionalDeclaration(declaration));
                    if (declaration && declaration.name.kind !== 80 /* Identifier */) {
                        if (links.type === unknownType) {
                            links.type = getTypeFromBindingPattern(declaration.name);
                        }
                        assignBindingElementTypes(declaration.name, links.type);
                    }
                }
                else if (contextualType) {
                    Debug.assertEqual(links.type, contextualType, "Parameter symbol already has a cached type which differs from newly assigned type");
                }
            }
            function assignBindingElementTypes(pattern, parentType) {
                for (const element of pattern.elements) {
                    if (!isOmittedExpression(element)) {
                        const type = getBindingElementTypeFromParentType(element, parentType, 
                        /*noTupleBoundsCheck*/
                        false);
                        if (element.name.kind === 80 /* Identifier */) {
                            getSymbolLinks(getSymbolOfDeclaration(element)).type = type;
                        }
                        else {
                            assignBindingElementTypes(element.name, type);
                        }
                    }
                }
            }
            function createClassDecoratorContextType(classType) {
                return tryCreateTypeReference(getGlobalClassDecoratorContextType(
                /*reportErrors*/
                true), [classType]);
            }
            function createClassMethodDecoratorContextType(thisType, valueType) {
                return tryCreateTypeReference(getGlobalClassMethodDecoratorContextType(
                /*reportErrors*/
                true), [thisType, valueType]);
            }
            function createClassGetterDecoratorContextType(thisType, valueType) {
                return tryCreateTypeReference(getGlobalClassGetterDecoratorContextType(
                /*reportErrors*/
                true), [thisType, valueType]);
            }
            function createClassSetterDecoratorContextType(thisType, valueType) {
                return tryCreateTypeReference(getGlobalClassSetterDecoratorContextType(
                /*reportErrors*/
                true), [thisType, valueType]);
            }
            function createClassAccessorDecoratorContextType(thisType, valueType) {
                return tryCreateTypeReference(getGlobalClassAccessorDecoratorContextType(
                /*reportErrors*/
                true), [thisType, valueType]);
            }
            function createClassFieldDecoratorContextType(thisType, valueType) {
                return tryCreateTypeReference(getGlobalClassFieldDecoratorContextType(
                /*reportErrors*/
                true), [thisType, valueType]);
            }
            function getClassMemberDecoratorContextOverrideType(nameType, isPrivate, isStatic2) {
                const key = `${isPrivate ? "p" : "P"}${isStatic2 ? "s" : "S"}${nameType.id}`;
                let overrideType = decoratorContextOverrideTypeCache.get(key);
                if (!overrideType) {
                    const members = createSymbolTable();
                    members.set("name", createProperty("name", nameType));
                    members.set("private", createProperty("private", isPrivate ? trueType : falseType));
                    members.set("static", createProperty("static", isStatic2 ? trueType : falseType));
                    overrideType = createAnonymousType(
                    /*symbol*/
                    void 0, members, emptyArray, emptyArray, emptyArray);
                    decoratorContextOverrideTypeCache.set(key, overrideType);
                }
                return overrideType;
            }
            function createClassMemberDecoratorContextTypeForNode(node, thisType, valueType) {
                const isStatic2 = hasStaticModifier(node);
                const isPrivate = isPrivateIdentifier(node.name);
                const nameType = isPrivate ? getStringLiteralType(idText(node.name)) : getLiteralTypeFromPropertyName(node.name);
                const contextType = isMethodDeclaration(node) ? createClassMethodDecoratorContextType(thisType, valueType) : isGetAccessorDeclaration(node) ? createClassGetterDecoratorContextType(thisType, valueType) : isSetAccessorDeclaration(node) ? createClassSetterDecoratorContextType(thisType, valueType) : isAutoAccessorPropertyDeclaration(node) ? createClassAccessorDecoratorContextType(thisType, valueType) : isPropertyDeclaration(node) ? createClassFieldDecoratorContextType(thisType, valueType) : Debug.failBadSyntaxKind(node);
                const overrideType = getClassMemberDecoratorContextOverrideType(nameType, isPrivate, isStatic2);
                return getIntersectionType([contextType, overrideType]);
            }
            function createClassAccessorDecoratorTargetType(thisType, valueType) {
                return tryCreateTypeReference(getGlobalClassAccessorDecoratorTargetType(
                /*reportErrors*/
                true), [thisType, valueType]);
            }
            function createClassAccessorDecoratorResultType(thisType, valueType) {
                return tryCreateTypeReference(getGlobalClassAccessorDecoratorResultType(
                /*reportErrors*/
                true), [thisType, valueType]);
            }
            function createClassFieldDecoratorInitializerMutatorType(thisType, valueType) {
                const thisParam = createParameter2("this", thisType);
                const valueParam = createParameter2("value", valueType);
                return createFunctionType(
                /*typeParameters*/
                void 0, thisParam, [valueParam], valueType, 
                /*typePredicate*/
                void 0, 1);
            }
            function createESDecoratorCallSignature(targetType, contextType, nonOptionalReturnType) {
                const targetParam = createParameter2("target", targetType);
                const contextParam = createParameter2("context", contextType);
                const returnType = getUnionType([nonOptionalReturnType, voidType]);
                return createCallSignature(
                /*typeParameters*/
                void 0, 
                /*thisParameter*/
                void 0, [targetParam, contextParam], returnType);
            }
            function getESDecoratorCallSignature(decorator) {
                const { parent: parent2 } = decorator;
                const links = getNodeLinks(parent2);
                if (!links.decoratorSignature) {
                    links.decoratorSignature = anySignature;
                    switch (parent2.kind) {
                        case 263 /* ClassDeclaration */:
                        case 231 /* ClassExpression */: {
                            const node = parent2;
                            const targetType = getTypeOfSymbol(getSymbolOfDeclaration(node));
                            const contextType = createClassDecoratorContextType(targetType);
                            links.decoratorSignature = createESDecoratorCallSignature(targetType, contextType, targetType);
                            break;
                        }
                        case 174 /* MethodDeclaration */:
                        case 177 /* GetAccessor */:
                        case 178 /* SetAccessor */: {
                            const node = parent2;
                            if (!isClassLike(node.parent))
                                break;
                            const valueType = isMethodDeclaration(node) ? getOrCreateTypeFromSignature(getSignatureFromDeclaration(node)) : getTypeOfNode(node);
                            const thisType = hasStaticModifier(node) ? getTypeOfSymbol(getSymbolOfDeclaration(node.parent)) : getDeclaredTypeOfClassOrInterface(getSymbolOfDeclaration(node.parent));
                            const targetType = isGetAccessorDeclaration(node) ? createGetterFunctionType(valueType) : isSetAccessorDeclaration(node) ? createSetterFunctionType(valueType) : valueType;
                            const contextType = createClassMemberDecoratorContextTypeForNode(node, thisType, valueType);
                            const returnType = isGetAccessorDeclaration(node) ? createGetterFunctionType(valueType) : isSetAccessorDeclaration(node) ? createSetterFunctionType(valueType) : valueType;
                            links.decoratorSignature = createESDecoratorCallSignature(targetType, contextType, returnType);
                            break;
                        }
                        case 172 /* PropertyDeclaration */: {
                            const node = parent2;
                            if (!isClassLike(node.parent))
                                break;
                            const valueType = getTypeOfNode(node);
                            const thisType = hasStaticModifier(node) ? getTypeOfSymbol(getSymbolOfDeclaration(node.parent)) : getDeclaredTypeOfClassOrInterface(getSymbolOfDeclaration(node.parent));
                            const targetType = hasAccessorModifier(node) ? createClassAccessorDecoratorTargetType(thisType, valueType) : undefinedType;
                            const contextType = createClassMemberDecoratorContextTypeForNode(node, thisType, valueType);
                            const returnType = hasAccessorModifier(node) ? createClassAccessorDecoratorResultType(thisType, valueType) : createClassFieldDecoratorInitializerMutatorType(thisType, valueType);
                            links.decoratorSignature = createESDecoratorCallSignature(targetType, contextType, returnType);
                            break;
                        }
                    }
                }
                return links.decoratorSignature === anySignature ? void 0 : links.decoratorSignature;
            }
            function getLegacyDecoratorCallSignature(decorator) {
                const { parent: parent2 } = decorator;
                const links = getNodeLinks(parent2);
                if (!links.decoratorSignature) {
                    links.decoratorSignature = anySignature;
                    switch (parent2.kind) {
                        case 263 /* ClassDeclaration */:
                        case 231 /* ClassExpression */: {
                            const node = parent2;
                            const targetType = getTypeOfSymbol(getSymbolOfDeclaration(node));
                            const targetParam = createParameter2("target", targetType);
                            links.decoratorSignature = createCallSignature(
                            /*typeParameters*/
                            void 0, 
                            /*thisParameter*/
                            void 0, [targetParam], getUnionType([targetType, voidType]));
                            break;
                        }
                        case 169 /* Parameter */: {
                            const node = parent2;
                            if (!isConstructorDeclaration(node.parent) && !(isMethodDeclaration(node.parent) || isSetAccessorDeclaration(node.parent) && isClassLike(node.parent.parent))) {
                                break;
                            }
                            if (getThisParameter(node.parent) === node) {
                                break;
                            }
                            const index = getThisParameter(node.parent) ? node.parent.parameters.indexOf(node) - 1 : node.parent.parameters.indexOf(node);
                            Debug.assert(index >= 0);
                            const targetType = isConstructorDeclaration(node.parent) ? getTypeOfSymbol(getSymbolOfDeclaration(node.parent.parent)) : getParentTypeOfClassElement(node.parent);
                            const keyType = isConstructorDeclaration(node.parent) ? undefinedType : getClassElementPropertyKeyType(node.parent);
                            const indexType = getNumberLiteralType(index);
                            const targetParam = createParameter2("target", targetType);
                            const keyParam = createParameter2("propertyKey", keyType);
                            const indexParam = createParameter2("parameterIndex", indexType);
                            links.decoratorSignature = createCallSignature(
                            /*typeParameters*/
                            void 0, 
                            /*thisParameter*/
                            void 0, [targetParam, keyParam, indexParam], voidType);
                            break;
                        }
                        case 174 /* MethodDeclaration */:
                        case 177 /* GetAccessor */:
                        case 178 /* SetAccessor */:
                        case 172 /* PropertyDeclaration */: {
                            const node = parent2;
                            if (!isClassLike(node.parent))
                                break;
                            const targetType = getParentTypeOfClassElement(node);
                            const targetParam = createParameter2("target", targetType);
                            const keyType = getClassElementPropertyKeyType(node);
                            const keyParam = createParameter2("propertyKey", keyType);
                            const returnType = isPropertyDeclaration(node) ? voidType : createTypedPropertyDescriptorType(getTypeOfNode(node));
                            const hasPropDesc = languageVersion !== 0 /* ES3 */ && (!isPropertyDeclaration(parent2) || hasAccessorModifier(parent2));
                            if (hasPropDesc) {
                                const descriptorType = createTypedPropertyDescriptorType(getTypeOfNode(node));
                                const descriptorParam = createParameter2("descriptor", descriptorType);
                                links.decoratorSignature = createCallSignature(
                                /*typeParameters*/
                                void 0, 
                                /*thisParameter*/
                                void 0, [targetParam, keyParam, descriptorParam], getUnionType([returnType, voidType]));
                            }
                            else {
                                links.decoratorSignature = createCallSignature(
                                /*typeParameters*/
                                void 0, 
                                /*thisParameter*/
                                void 0, [targetParam, keyParam], getUnionType([returnType, voidType]));
                            }
                            break;
                        }
                    }
                }
                return links.decoratorSignature === anySignature ? void 0 : links.decoratorSignature;
            }
            function getDecoratorCallSignature(decorator) {
                return legacyDecorators ? getLegacyDecoratorCallSignature(decorator) : getESDecoratorCallSignature(decorator);
            }
            function createPromiseType(promisedType) {
                const globalPromiseType = getGlobalPromiseType(
                /*reportErrors*/
                true);
                if (globalPromiseType !== emptyGenericType) {
                    promisedType = getAwaitedTypeNoAlias(unwrapAwaitedType(promisedType)) || unknownType;
                    return createTypeReference(globalPromiseType, [promisedType]);
                }
                return unknownType;
            }
            function createPromiseLikeType(promisedType) {
                const globalPromiseLikeType = getGlobalPromiseLikeType(
                /*reportErrors*/
                true);
                if (globalPromiseLikeType !== emptyGenericType) {
                    promisedType = getAwaitedTypeNoAlias(unwrapAwaitedType(promisedType)) || unknownType;
                    return createTypeReference(globalPromiseLikeType, [promisedType]);
                }
                return unknownType;
            }
            function createPromiseReturnType(func, promisedType) {
                const promiseType = createPromiseType(promisedType);
                if (promiseType === unknownType) {
                    error2(func, isImportCall(func) ? Diagnostics.A_dynamic_import_call_returns_a_Promise_Make_sure_you_have_a_declaration_for_Promise_or_include_ES2015_in_your_lib_option : Diagnostics.An_async_function_or_method_must_return_a_Promise_Make_sure_you_have_a_declaration_for_Promise_or_include_ES2015_in_your_lib_option);
                    return errorType;
                }
                else if (!getGlobalPromiseConstructorSymbol(
                /*reportErrors*/
                true)) {
                    error2(func, isImportCall(func) ? Diagnostics.A_dynamic_import_call_in_ES5_SlashES3_requires_the_Promise_constructor_Make_sure_you_have_a_declaration_for_the_Promise_constructor_or_include_ES2015_in_your_lib_option : Diagnostics.An_async_function_or_method_in_ES5_SlashES3_requires_the_Promise_constructor_Make_sure_you_have_a_declaration_for_the_Promise_constructor_or_include_ES2015_in_your_lib_option);
                }
                return promiseType;
            }
            function createNewTargetExpressionType(targetType) {
                const symbol = createSymbol(0 /* None */, "NewTargetExpression");
                const targetPropertySymbol = createSymbol(4 /* Property */, "target", 8 /* Readonly */);
                targetPropertySymbol.parent = symbol;
                targetPropertySymbol.links.type = targetType;
                const members = createSymbolTable([targetPropertySymbol]);
                symbol.members = members;
                return createAnonymousType(symbol, members, emptyArray, emptyArray, emptyArray);
            }
            function getReturnTypeFromBody(func, checkMode) {
                if (!func.body) {
                    return errorType;
                }
                const functionFlags = getFunctionFlags(func);
                const isAsync = (functionFlags & 2 /* Async */) !== 0;
                const isGenerator = (functionFlags & 1 /* Generator */) !== 0;
                let returnType;
                let yieldType;
                let nextType;
                let fallbackReturnType = voidType;
                if (func.body.kind !== 241 /* Block */) {
                    returnType = checkExpressionCached(func.body, checkMode && checkMode & ~8 /* SkipGenericFunctions */);
                    if (isAsync) {
                        returnType = unwrapAwaitedType(checkAwaitedType(returnType, 
                        /*withAlias*/
                        false, 
                        /*errorNode*/
                        func, Diagnostics.The_return_type_of_an_async_function_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member));
                    }
                }
                else if (isGenerator) {
                    const returnTypes = checkAndAggregateReturnExpressionTypes(func, checkMode);
                    if (!returnTypes) {
                        fallbackReturnType = neverType;
                    }
                    else if (returnTypes.length > 0) {
                        returnType = getUnionType(returnTypes, 2 /* Subtype */);
                    }
                    const { yieldTypes, nextTypes } = checkAndAggregateYieldOperandTypes(func, checkMode);
                    yieldType = some(yieldTypes) ? getUnionType(yieldTypes, 2 /* Subtype */) : void 0;
                    nextType = some(nextTypes) ? getIntersectionType(nextTypes) : void 0;
                }
                else {
                    const types = checkAndAggregateReturnExpressionTypes(func, checkMode);
                    if (!types) {
                        return functionFlags & 2 /* Async */ ? createPromiseReturnType(func, neverType) : neverType;
                    }
                    if (types.length === 0) {
                        const contextualReturnType = getContextualReturnType(func, 
                        /*contextFlags*/
                        void 0);
                        const returnType2 = contextualReturnType && (unwrapReturnType(contextualReturnType, functionFlags) || voidType).flags & 32768 /* Undefined */ ? undefinedType : voidType;
                        return functionFlags & 2 /* Async */ ? createPromiseReturnType(func, returnType2) : (
                        // Async function
                        returnType2);
                    }
                    returnType = getUnionType(types, 2 /* Subtype */);
                }
                if (returnType || yieldType || nextType) {
                    if (yieldType)
                        reportErrorsFromWidening(func, yieldType, 3 /* GeneratorYield */);
                    if (returnType)
                        reportErrorsFromWidening(func, returnType, 1 /* FunctionReturn */);
                    if (nextType)
                        reportErrorsFromWidening(func, nextType, 2 /* GeneratorNext */);
                    if (returnType && isUnitType(returnType) || yieldType && isUnitType(yieldType) || nextType && isUnitType(nextType)) {
                        const contextualSignature = getContextualSignatureForFunctionLikeDeclaration(func);
                        const contextualType = !contextualSignature ? void 0 : contextualSignature === getSignatureFromDeclaration(func) ? isGenerator ? void 0 : returnType : instantiateContextualType(getReturnTypeOfSignature(contextualSignature), func, 
                        /*contextFlags*/
                        void 0);
                        if (isGenerator) {
                            yieldType = getWidenedLiteralLikeTypeForContextualIterationTypeIfNeeded(yieldType, contextualType, 0 /* Yield */, isAsync);
                            returnType = getWidenedLiteralLikeTypeForContextualIterationTypeIfNeeded(returnType, contextualType, 1 /* Return */, isAsync);
                            nextType = getWidenedLiteralLikeTypeForContextualIterationTypeIfNeeded(nextType, contextualType, 2 /* Next */, isAsync);
                        }
                        else {
                            returnType = getWidenedLiteralLikeTypeForContextualReturnTypeIfNeeded(returnType, contextualType, isAsync);
                        }
                    }
                    if (yieldType)
                        yieldType = getWidenedType(yieldType);
                    if (returnType)
                        returnType = getWidenedType(returnType);
                    if (nextType)
                        nextType = getWidenedType(nextType);
                }
                if (isGenerator) {
                    return createGeneratorReturnType(yieldType || neverType, returnType || fallbackReturnType, nextType || getContextualIterationType(2 /* Next */, func) || unknownType, isAsync);
                }
                else {
                    return isAsync ? createPromiseType(returnType || fallbackReturnType) : returnType || fallbackReturnType;
                }
            }
            function createGeneratorReturnType(yieldType, returnType, nextType, isAsyncGenerator) {
                const resolver = isAsyncGenerator ? asyncIterationTypesResolver : syncIterationTypesResolver;
                const globalGeneratorType = resolver.getGlobalGeneratorType(
                /*reportErrors*/
                false);
                yieldType = resolver.resolveIterationType(yieldType, 
                /*errorNode*/
                void 0) || unknownType;
                returnType = resolver.resolveIterationType(returnType, 
                /*errorNode*/
                void 0) || unknownType;
                nextType = resolver.resolveIterationType(nextType, 
                /*errorNode*/
                void 0) || unknownType;
                if (globalGeneratorType === emptyGenericType) {
                    const globalType = resolver.getGlobalIterableIteratorType(
                    /*reportErrors*/
                    false);
                    const iterationTypes = globalType !== emptyGenericType ? getIterationTypesOfGlobalIterableType(globalType, resolver) : void 0;
                    const iterableIteratorReturnType = iterationTypes ? iterationTypes.returnType : anyType;
                    const iterableIteratorNextType = iterationTypes ? iterationTypes.nextType : undefinedType;
                    if (isTypeAssignableTo(returnType, iterableIteratorReturnType) && isTypeAssignableTo(iterableIteratorNextType, nextType)) {
                        if (globalType !== emptyGenericType) {
                            return createTypeFromGenericGlobalType(globalType, [yieldType]);
                        }
                        resolver.getGlobalIterableIteratorType(
                        /*reportErrors*/
                        true);
                        return emptyObjectType;
                    }
                    resolver.getGlobalGeneratorType(
                    /*reportErrors*/
                    true);
                    return emptyObjectType;
                }
                return createTypeFromGenericGlobalType(globalGeneratorType, [yieldType, returnType, nextType]);
            }
            function checkAndAggregateYieldOperandTypes(func, checkMode) {
                const yieldTypes = [];
                const nextTypes = [];
                const isAsync = (getFunctionFlags(func) & 2 /* Async */) !== 0;
                forEachYieldExpression(func.body, (yieldExpression) => {
                    const yieldExpressionType = yieldExpression.expression ? checkExpression(yieldExpression.expression, checkMode) : undefinedWideningType;
                    pushIfUnique(yieldTypes, getYieldedTypeOfYieldExpression(yieldExpression, yieldExpressionType, anyType, isAsync));
                    let nextType;
                    if (yieldExpression.asteriskToken) {
                        const iterationTypes = getIterationTypesOfIterable(yieldExpressionType, isAsync ? 19 /* AsyncYieldStar */ : 17 /* YieldStar */, yieldExpression.expression);
                        nextType = iterationTypes && iterationTypes.nextType;
                    }
                    else {
                        nextType = getContextualType2(yieldExpression, 
                        /*contextFlags*/
                        void 0);
                    }
                    if (nextType)
                        pushIfUnique(nextTypes, nextType);
                });
                return { yieldTypes, nextTypes };
            }
            function getYieldedTypeOfYieldExpression(node, expressionType, sentType, isAsync) {
                const errorNode = node.expression || node;
                const yieldedType = node.asteriskToken ? checkIteratedTypeOrElementType(isAsync ? 19 /* AsyncYieldStar */ : 17 /* YieldStar */, expressionType, sentType, errorNode) : expressionType;
                return !isAsync ? yieldedType : getAwaitedType(yieldedType, errorNode, node.asteriskToken ? Diagnostics.Type_of_iterated_elements_of_a_yield_Asterisk_operand_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member : Diagnostics.Type_of_yield_operand_in_an_async_generator_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member);
            }
            function getNotEqualFactsFromTypeofSwitch(start, end, witnesses) {
                let facts = 0 /* None */;
                for (let i = 0; i < witnesses.length; i++) {
                    const witness = i < start || i >= end ? witnesses[i] : void 0;
                    facts |= witness !== void 0 ? typeofNEFacts.get(witness) || 32768 /* TypeofNEHostObject */ : 0;
                }
                return facts;
            }
            function isExhaustiveSwitchStatement(node) {
                const links = getNodeLinks(node);
                if (links.isExhaustive === void 0) {
                    links.isExhaustive = 0;
                    const exhaustive = computeExhaustiveSwitchStatement(node);
                    if (links.isExhaustive === 0) {
                        links.isExhaustive = exhaustive;
                    }
                }
                else if (links.isExhaustive === 0) {
                    links.isExhaustive = false;
                }
                return links.isExhaustive;
            }
            function computeExhaustiveSwitchStatement(node) {
                if (node.expression.kind === 221 /* TypeOfExpression */) {
                    const witnesses = getSwitchClauseTypeOfWitnesses(node);
                    if (!witnesses) {
                        return false;
                    }
                    const operandConstraint = getBaseConstraintOrType(checkExpressionCached(node.expression.expression));
                    const notEqualFacts = getNotEqualFactsFromTypeofSwitch(0, 0, witnesses);
                    if (operandConstraint.flags & 3 /* AnyOrUnknown */) {
                        return (556800 /* AllTypeofNE */ & notEqualFacts) === 556800 /* AllTypeofNE */;
                    }
                    return !someType(operandConstraint, (t) => getTypeFacts(t, notEqualFacts) === notEqualFacts);
                }
                const type = checkExpressionCached(node.expression);
                if (!isLiteralType(type)) {
                    return false;
                }
                const switchTypes = getSwitchClauseTypes(node);
                if (!switchTypes.length || some(switchTypes, isNeitherUnitTypeNorNever)) {
                    return false;
                }
                return eachTypeContainedIn(mapType(type, getRegularTypeOfLiteralType), switchTypes);
            }
            function functionHasImplicitReturn(func) {
                return func.endFlowNode && isReachableFlowNode(func.endFlowNode);
            }
            function checkAndAggregateReturnExpressionTypes(func, checkMode) {
                const functionFlags = getFunctionFlags(func);
                const aggregatedTypes = [];
                let hasReturnWithNoExpression = functionHasImplicitReturn(func);
                let hasReturnOfTypeNever = false;
                forEachReturnStatement(func.body, (returnStatement) => {
                    let expr = returnStatement.expression;
                    if (expr) {
                        expr = skipParentheses(expr, 
                        /*excludeJSDocTypeAssertions*/
                        true);
                        if (functionFlags & 2 /* Async */ && expr.kind === 223 /* AwaitExpression */) {
                            expr = skipParentheses(expr.expression, 
                            /*excludeJSDocTypeAssertions*/
                            true);
                        }
                        if (expr.kind === 213 /* CallExpression */ && expr.expression.kind === 80 /* Identifier */ && checkExpressionCached(expr.expression).symbol === func.symbol) {
                            hasReturnOfTypeNever = true;
                            return;
                        }
                        let type = checkExpressionCached(expr, checkMode && checkMode & ~8 /* SkipGenericFunctions */);
                        if (functionFlags & 2 /* Async */) {
                            type = unwrapAwaitedType(checkAwaitedType(type, 
                            /*withAlias*/
                            false, func, Diagnostics.The_return_type_of_an_async_function_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member));
                        }
                        if (type.flags & 131072 /* Never */) {
                            hasReturnOfTypeNever = true;
                        }
                        pushIfUnique(aggregatedTypes, type);
                    }
                    else {
                        hasReturnWithNoExpression = true;
                    }
                });
                if (aggregatedTypes.length === 0 && !hasReturnWithNoExpression && (hasReturnOfTypeNever || mayReturnNever(func))) {
                    return void 0;
                }
                if (strictNullChecks && aggregatedTypes.length && hasReturnWithNoExpression && !(isJSConstructor(func) && aggregatedTypes.some((t) => t.symbol === func.symbol))) {
                    pushIfUnique(aggregatedTypes, undefinedType);
                }
                return aggregatedTypes;
            }
            function mayReturnNever(func) {
                switch (func.kind) {
                    case 218 /* FunctionExpression */:
                    case 219 /* ArrowFunction */:
                        return true;
                    case 174 /* MethodDeclaration */:
                        return func.parent.kind === 210 /* ObjectLiteralExpression */;
                    default:
                        return false;
                }
            }
            function checkAllCodePathsInNonVoidFunctionReturnOrThrow(func, returnType) {
                addLazyDiagnostic(checkAllCodePathsInNonVoidFunctionReturnOrThrowDiagnostics);
                return;
                function checkAllCodePathsInNonVoidFunctionReturnOrThrowDiagnostics() {
                    const functionFlags = getFunctionFlags(func);
                    const type = returnType && unwrapReturnType(returnType, functionFlags);
                    if (type && (maybeTypeOfKind(type, 16384 /* Void */) || type.flags & (1 /* Any */ | 32768 /* Undefined */))) {
                        return;
                    }
                    if (func.kind === 173 /* MethodSignature */ || nodeIsMissing(func.body) || func.body.kind !== 241 /* Block */ || !functionHasImplicitReturn(func)) {
                        return;
                    }
                    const hasExplicitReturn = func.flags & 1024 /* HasExplicitReturn */;
                    const errorNode = getEffectiveReturnTypeNode(func) || func;
                    if (type && type.flags & 131072 /* Never */) {
                        error2(errorNode, Diagnostics.A_function_returning_never_cannot_have_a_reachable_end_point);
                    }
                    else if (type && !hasExplicitReturn) {
                        error2(errorNode, Diagnostics.A_function_whose_declared_type_is_neither_undefined_void_nor_any_must_return_a_value);
                    }
                    else if (type && strictNullChecks && !isTypeAssignableTo(undefinedType, type)) {
                        error2(errorNode, Diagnostics.Function_lacks_ending_return_statement_and_return_type_does_not_include_undefined);
                    }
                    else if (compilerOptions.noImplicitReturns) {
                        if (!type) {
                            if (!hasExplicitReturn) {
                                return;
                            }
                            const inferredReturnType = getReturnTypeOfSignature(getSignatureFromDeclaration(func));
                            if (isUnwrappedReturnTypeUndefinedVoidOrAny(func, inferredReturnType)) {
                                return;
                            }
                        }
                        error2(errorNode, Diagnostics.Not_all_code_paths_return_a_value);
                    }
                }
            }
            function checkFunctionExpressionOrObjectLiteralMethod(node, checkMode) {
                Debug.assert(node.kind !== 174 /* MethodDeclaration */ || isObjectLiteralMethod(node));
                checkNodeDeferred(node);
                if (isFunctionExpression(node)) {
                    checkCollisionsForDeclarationName(node, node.name);
                }
                if (checkMode && checkMode & 4 /* SkipContextSensitive */ && isContextSensitive(node)) {
                    if (!getEffectiveReturnTypeNode(node) && !hasContextSensitiveParameters(node)) {
                        const contextualSignature = getContextualSignature(node);
                        if (contextualSignature && couldContainTypeVariables(getReturnTypeOfSignature(contextualSignature))) {
                            const links = getNodeLinks(node);
                            if (links.contextFreeType) {
                                return links.contextFreeType;
                            }
                            const returnType = getReturnTypeFromBody(node, checkMode);
                            const returnOnlySignature = createSignature(
                            /*declaration*/
                            void 0, 
                            /*typeParameters*/
                            void 0, 
                            /*thisParameter*/
                            void 0, emptyArray, returnType, 
                            /*resolvedTypePredicate*/
                            void 0, 0, 64 /* IsNonInferrable */);
                            const returnOnlyType = createAnonymousType(node.symbol, emptySymbols, [returnOnlySignature], emptyArray, emptyArray);
                            returnOnlyType.objectFlags |= 262144 /* NonInferrableType */;
                            return links.contextFreeType = returnOnlyType;
                        }
                    }
                    return anyFunctionType;
                }
                const hasGrammarError = checkGrammarFunctionLikeDeclaration(node);
                if (!hasGrammarError && node.kind === 218 /* FunctionExpression */) {
                    checkGrammarForGenerator(node);
                }
                contextuallyCheckFunctionExpressionOrObjectLiteralMethod(node, checkMode);
                return getTypeOfSymbol(getSymbolOfDeclaration(node));
            }
            function contextuallyCheckFunctionExpressionOrObjectLiteralMethod(node, checkMode) {
                const links = getNodeLinks(node);
                if (!(links.flags & 64 /* ContextChecked */)) {
                    const contextualSignature = getContextualSignature(node);
                    if (!(links.flags & 64 /* ContextChecked */)) {
                        links.flags |= 64 /* ContextChecked */;
                        const signature = firstOrUndefined(getSignaturesOfType(getTypeOfSymbol(getSymbolOfDeclaration(node)), 0 /* Call */));
                        if (!signature) {
                            return;
                        }
                        if (isContextSensitive(node)) {
                            if (contextualSignature) {
                                const inferenceContext = getInferenceContext(node);
                                let instantiatedContextualSignature;
                                if (checkMode && checkMode & 2 /* Inferential */) {
                                    inferFromAnnotatedParameters(signature, contextualSignature, inferenceContext);
                                    const restType = getEffectiveRestType(contextualSignature);
                                    if (restType && restType.flags & 262144 /* TypeParameter */) {
                                        instantiatedContextualSignature = instantiateSignature(contextualSignature, inferenceContext.nonFixingMapper);
                                    }
                                }
                                instantiatedContextualSignature || (instantiatedContextualSignature = inferenceContext ? instantiateSignature(contextualSignature, inferenceContext.mapper) : contextualSignature);
                                assignContextualParameterTypes(signature, instantiatedContextualSignature);
                            }
                            else {
                                assignNonContextualParameterTypes(signature);
                            }
                        }
                        else if (contextualSignature && !node.typeParameters && contextualSignature.parameters.length > node.parameters.length) {
                            const inferenceContext = getInferenceContext(node);
                            if (checkMode && checkMode & 2 /* Inferential */) {
                                inferFromAnnotatedParameters(signature, contextualSignature, inferenceContext);
                            }
                        }
                        if (contextualSignature && !getReturnTypeFromAnnotation(node) && !signature.resolvedReturnType) {
                            const returnType = getReturnTypeFromBody(node, checkMode);
                            if (!signature.resolvedReturnType) {
                                signature.resolvedReturnType = returnType;
                            }
                        }
                        checkSignatureDeclaration(node);
                    }
                }
            }
            function checkFunctionExpressionOrObjectLiteralMethodDeferred(node) {
                Debug.assert(node.kind !== 174 /* MethodDeclaration */ || isObjectLiteralMethod(node));
                const functionFlags = getFunctionFlags(node);
                const returnType = getReturnTypeFromAnnotation(node);
                checkAllCodePathsInNonVoidFunctionReturnOrThrow(node, returnType);
                if (node.body) {
                    if (!getEffectiveReturnTypeNode(node)) {
                        getReturnTypeOfSignature(getSignatureFromDeclaration(node));
                    }
                    if (node.body.kind === 241 /* Block */) {
                        checkSourceElement(node.body);
                    }
                    else {
                        const exprType = checkExpression(node.body);
                        const returnOrPromisedType = returnType && unwrapReturnType(returnType, functionFlags);
                        if (returnOrPromisedType) {
                            const effectiveCheckNode = getEffectiveCheckNode(node.body);
                            if ((functionFlags & 3 /* AsyncGenerator */) === 2 /* Async */) {
                                const awaitedType = checkAwaitedType(exprType, 
                                /*withAlias*/
                                false, effectiveCheckNode, Diagnostics.The_return_type_of_an_async_function_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member);
                                checkTypeAssignableToAndOptionallyElaborate(awaitedType, returnOrPromisedType, effectiveCheckNode, effectiveCheckNode);
                            }
                            else {
                                checkTypeAssignableToAndOptionallyElaborate(exprType, returnOrPromisedType, effectiveCheckNode, effectiveCheckNode);
                            }
                        }
                    }
                }
            }
            function checkArithmeticOperandType(operand, type, diagnostic, isAwaitValid = false) {
                if (!isTypeAssignableTo(type, numberOrBigIntType)) {
                    const awaitedType = isAwaitValid && getAwaitedTypeOfPromise(type);
                    errorAndMaybeSuggestAwait(operand, !!awaitedType && isTypeAssignableTo(awaitedType, numberOrBigIntType), diagnostic);
                    return false;
                }
                return true;
            }
            function isReadonlyAssignmentDeclaration(d) {
                if (!isCallExpression(d)) {
                    return false;
                }
                if (!isBindableObjectDefinePropertyCall(d)) {
                    return false;
                }
                const objectLitType = checkExpressionCached(d.arguments[2]);
                const valueType = getTypeOfPropertyOfType(objectLitType, "value");
                if (valueType) {
                    const writableProp = getPropertyOfType(objectLitType, "writable");
                    const writableType = writableProp && getTypeOfSymbol(writableProp);
                    if (!writableType || writableType === falseType || writableType === regularFalseType) {
                        return true;
                    }
                    if (writableProp && writableProp.valueDeclaration && isPropertyAssignment(writableProp.valueDeclaration)) {
                        const initializer = writableProp.valueDeclaration.initializer;
                        const rawOriginalType = checkExpression(initializer);
                        if (rawOriginalType === falseType || rawOriginalType === regularFalseType) {
                            return true;
                        }
                    }
                    return false;
                }
                const setProp = getPropertyOfType(objectLitType, "set");
                return !setProp;
            }
            function isReadonlySymbol(symbol) {
                return !!(getCheckFlags(symbol) & 8 /* Readonly */ || symbol.flags & 4 /* Property */ && getDeclarationModifierFlagsFromSymbol(symbol) & 8 /* Readonly */ || symbol.flags & 3 /* Variable */ && getDeclarationNodeFlagsFromSymbol(symbol) & 6 /* Constant */ || symbol.flags & 98304 /* Accessor */ && !(symbol.flags & 65536 /* SetAccessor */) || symbol.flags & 8 /* EnumMember */ || some(symbol.declarations, isReadonlyAssignmentDeclaration));
            }
            function isAssignmentToReadonlyEntity(expr, symbol, assignmentKind) {
                var _a, _b;
                if (assignmentKind === 0 /* None */) {
                    return false;
                }
                if (isReadonlySymbol(symbol)) {
                    if (symbol.flags & 4 /* Property */ && isAccessExpression(expr) && expr.expression.kind === 110 /* ThisKeyword */) {
                        const ctor = getContainingFunction(expr);
                        if (!(ctor && (ctor.kind === 176 /* Constructor */ || isJSConstructor(ctor)))) {
                            return true;
                        }
                        if (symbol.valueDeclaration) {
                            const isAssignmentDeclaration2 = isBinaryExpression(symbol.valueDeclaration);
                            const isLocalPropertyDeclaration = ctor.parent === symbol.valueDeclaration.parent;
                            const isLocalParameterProperty = ctor === symbol.valueDeclaration.parent;
                            const isLocalThisPropertyAssignment = isAssignmentDeclaration2 && ((_a = symbol.parent) == null ? void 0 : _a.valueDeclaration) === ctor.parent;
                            const isLocalThisPropertyAssignmentConstructorFunction = isAssignmentDeclaration2 && ((_b = symbol.parent) == null ? void 0 : _b.valueDeclaration) === ctor;
                            const isWriteableSymbol = isLocalPropertyDeclaration || isLocalParameterProperty || isLocalThisPropertyAssignment || isLocalThisPropertyAssignmentConstructorFunction;
                            return !isWriteableSymbol;
                        }
                    }
                    return true;
                }
                if (isAccessExpression(expr)) {
                    const node = skipParentheses(expr.expression);
                    if (node.kind === 80 /* Identifier */) {
                        const symbol2 = getNodeLinks(node).resolvedSymbol;
                        if (symbol2.flags & 2097152 /* Alias */) {
                            const declaration = getDeclarationOfAliasSymbol(symbol2);
                            return !!declaration && declaration.kind === 274 /* NamespaceImport */;
                        }
                    }
                }
                return false;
            }
            function checkReferenceExpression(expr, invalidReferenceMessage, invalidOptionalChainMessage) {
                const node = skipOuterExpressions(expr, 6 /* Assertions */ | 1 /* Parentheses */);
                if (node.kind !== 80 /* Identifier */ && !isAccessExpression(node)) {
                    error2(expr, invalidReferenceMessage);
                    return false;
                }
                if (node.flags & 64 /* OptionalChain */) {
                    error2(expr, invalidOptionalChainMessage);
                    return false;
                }
                return true;
            }
            function checkDeleteExpression(node) {
                checkExpression(node.expression);
                const expr = skipParentheses(node.expression);
                if (!isAccessExpression(expr)) {
                    error2(expr, Diagnostics.The_operand_of_a_delete_operator_must_be_a_property_reference);
                    return booleanType;
                }
                if (isPropertyAccessExpression(expr) && isPrivateIdentifier(expr.name)) {
                    error2(expr, Diagnostics.The_operand_of_a_delete_operator_cannot_be_a_private_identifier);
                }
                const links = getNodeLinks(expr);
                const symbol = getExportSymbolOfValueSymbolIfExported(links.resolvedSymbol);
                if (symbol) {
                    if (isReadonlySymbol(symbol)) {
                        error2(expr, Diagnostics.The_operand_of_a_delete_operator_cannot_be_a_read_only_property);
                    }
                    else {
                        checkDeleteExpressionMustBeOptional(expr, symbol);
                    }
                }
                return booleanType;
            }
            function checkDeleteExpressionMustBeOptional(expr, symbol) {
                const type = getTypeOfSymbol(symbol);
                if (strictNullChecks && !(type.flags & (3 /* AnyOrUnknown */ | 131072 /* Never */)) && !(exactOptionalPropertyTypes ? symbol.flags & 16777216 /* Optional */ : hasTypeFacts(type, 16777216 /* IsUndefined */))) {
                    error2(expr, Diagnostics.The_operand_of_a_delete_operator_must_be_optional);
                }
            }
            function checkTypeOfExpression(node) {
                checkExpression(node.expression);
                return typeofType;
            }
            function checkVoidExpression(node) {
                checkNodeDeferred(node);
                return undefinedWideningType;
            }
            function checkAwaitGrammar(node) {
                let hasError = false;
                const container = getContainingFunctionOrClassStaticBlock(node);
                if (container && isClassStaticBlockDeclaration(container)) {
                    const message = isAwaitExpression(node) ? Diagnostics.await_expression_cannot_be_used_inside_a_class_static_block : Diagnostics.await_using_statements_cannot_be_used_inside_a_class_static_block;
                    error2(node, message);
                    hasError = true;
                }
                else if (!(node.flags & 65536 /* AwaitContext */)) {
                    if (isInTopLevelContext(node)) {
                        const sourceFile = getSourceFileOfNode(node);
                        if (!hasParseDiagnostics(sourceFile)) {
                            let span;
                            if (!isEffectiveExternalModule(sourceFile, compilerOptions)) {
                                span ?? (span = getSpanOfTokenAtPosition(sourceFile, node.pos));
                                const message = isAwaitExpression(node) ? Diagnostics.await_expressions_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_has_no_imports_or_exports_Consider_adding_an_empty_export_to_make_this_file_a_module : Diagnostics.await_using_statements_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_has_no_imports_or_exports_Consider_adding_an_empty_export_to_make_this_file_a_module;
                                const diagnostic = createFileDiagnostic(sourceFile, span.start, span.length, message);
                                diagnostics.add(diagnostic);
                                hasError = true;
                            }
                            switch (moduleKind) {
                                case 100 /* Node16 */:
                                case 199 /* NodeNext */:
                                    if (sourceFile.impliedNodeFormat === 1 /* CommonJS */) {
                                        span ?? (span = getSpanOfTokenAtPosition(sourceFile, node.pos));
                                        diagnostics.add(createFileDiagnostic(sourceFile, span.start, span.length, Diagnostics.The_current_file_is_a_CommonJS_module_and_cannot_use_await_at_the_top_level));
                                        hasError = true;
                                        break;
                                    }
                                case 7 /* ES2022 */:
                                case 99 /* ESNext */:
                                case 200 /* Preserve */:
                                case 4 /* System */:
                                    if (languageVersion >= 4 /* ES2017 */) {
                                        break;
                                    }
                                default:
                                    span ?? (span = getSpanOfTokenAtPosition(sourceFile, node.pos));
                                    const message = isAwaitExpression(node) ? Diagnostics.Top_level_await_expressions_are_only_allowed_when_the_module_option_is_set_to_es2022_esnext_system_node16_nodenext_or_preserve_and_the_target_option_is_set_to_es2017_or_higher : Diagnostics.Top_level_await_using_statements_are_only_allowed_when_the_module_option_is_set_to_es2022_esnext_system_node16_nodenext_or_preserve_and_the_target_option_is_set_to_es2017_or_higher;
                                    diagnostics.add(createFileDiagnostic(sourceFile, span.start, span.length, message));
                                    hasError = true;
                                    break;
                            }
                        }
                    }
                    else {
                        const sourceFile = getSourceFileOfNode(node);
                        if (!hasParseDiagnostics(sourceFile)) {
                            const span = getSpanOfTokenAtPosition(sourceFile, node.pos);
                            const message = isAwaitExpression(node) ? Diagnostics.await_expressions_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules : Diagnostics.await_using_statements_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules;
                            const diagnostic = createFileDiagnostic(sourceFile, span.start, span.length, message);
                            if (container && container.kind !== 176 /* Constructor */ && (getFunctionFlags(container) & 2 /* Async */) === 0) {
                                const relatedInfo = createDiagnosticForNode(container, Diagnostics.Did_you_mean_to_mark_this_function_as_async);
                                addRelatedInfo(diagnostic, relatedInfo);
                            }
                            diagnostics.add(diagnostic);
                            hasError = true;
                        }
                    }
                }
                if (isAwaitExpression(node) && isInParameterInitializerBeforeContainingFunction(node)) {
                    error2(node, Diagnostics.await_expressions_cannot_be_used_in_a_parameter_initializer);
                    hasError = true;
                }
                return hasError;
            }
            function checkAwaitExpression(node) {
                addLazyDiagnostic(() => checkAwaitGrammar(node));
                const operandType = checkExpression(node.expression);
                const awaitedType = checkAwaitedType(operandType, 
                /*withAlias*/
                true, node, Diagnostics.Type_of_await_operand_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member);
                if (awaitedType === operandType && !isErrorType(awaitedType) && !(operandType.flags & 3 /* AnyOrUnknown */)) {
                    addErrorOrSuggestion(
                    /*isError*/
                    false, createDiagnosticForNode(node, Diagnostics.await_has_no_effect_on_the_type_of_this_expression));
                }
                return awaitedType;
            }
            function checkPrefixUnaryExpression(node) {
                const operandType = checkExpression(node.operand);
                if (operandType === silentNeverType) {
                    return silentNeverType;
                }
                switch (node.operand.kind) {
                    case 9 /* NumericLiteral */:
                        switch (node.operator) {
                            case 41 /* MinusToken */:
                                return getFreshTypeOfLiteralType(getNumberLiteralType(-node.operand.text));
                            case 40 /* PlusToken */:
                                return getFreshTypeOfLiteralType(getNumberLiteralType(+node.operand.text));
                        }
                        break;
                    case 10 /* BigIntLiteral */:
                        if (node.operator === 41 /* MinusToken */) {
                            return getFreshTypeOfLiteralType(getBigIntLiteralType({
                                negative: true,
                                base10Value: parsePseudoBigInt(node.operand.text)
                            }));
                        }
                }
                switch (node.operator) {
                    case 40 /* PlusToken */:
                    case 41 /* MinusToken */:
                    case 55 /* TildeToken */:
                        checkNonNullType(operandType, node.operand);
                        if (maybeTypeOfKindConsideringBaseConstraint(operandType, 12288 /* ESSymbolLike */)) {
                            error2(node.operand, Diagnostics.The_0_operator_cannot_be_applied_to_type_symbol, tokenToString(node.operator));
                        }
                        if (node.operator === 40 /* PlusToken */) {
                            if (maybeTypeOfKindConsideringBaseConstraint(operandType, 2112 /* BigIntLike */)) {
                                error2(node.operand, Diagnostics.Operator_0_cannot_be_applied_to_type_1, tokenToString(node.operator), typeToString(getBaseTypeOfLiteralType(operandType)));
                            }
                            return numberType;
                        }
                        return getUnaryResultType(operandType);
                    case 54 /* ExclamationToken */:
                        checkTruthinessOfType(operandType, node.operand);
                        const facts = getTypeFacts(operandType, 4194304 /* Truthy */ | 8388608 /* Falsy */);
                        return facts === 4194304 /* Truthy */ ? falseType : facts === 8388608 /* Falsy */ ? trueType : booleanType;
                    case 46 /* PlusPlusToken */:
                    case 47 /* MinusMinusToken */:
                        const ok = checkArithmeticOperandType(node.operand, checkNonNullType(operandType, node.operand), Diagnostics.An_arithmetic_operand_must_be_of_type_any_number_bigint_or_an_enum_type);
                        if (ok) {
                            checkReferenceExpression(node.operand, Diagnostics.The_operand_of_an_increment_or_decrement_operator_must_be_a_variable_or_a_property_access, Diagnostics.The_operand_of_an_increment_or_decrement_operator_may_not_be_an_optional_property_access);
                        }
                        return getUnaryResultType(operandType);
                }
                return errorType;
            }
            function checkPostfixUnaryExpression(node) {
                const operandType = checkExpression(node.operand);
                if (operandType === silentNeverType) {
                    return silentNeverType;
                }
                const ok = checkArithmeticOperandType(node.operand, checkNonNullType(operandType, node.operand), Diagnostics.An_arithmetic_operand_must_be_of_type_any_number_bigint_or_an_enum_type);
                if (ok) {
                    checkReferenceExpression(node.operand, Diagnostics.The_operand_of_an_increment_or_decrement_operator_must_be_a_variable_or_a_property_access, Diagnostics.The_operand_of_an_increment_or_decrement_operator_may_not_be_an_optional_property_access);
                }
                return getUnaryResultType(operandType);
            }
            function getUnaryResultType(operandType) {
                if (maybeTypeOfKind(operandType, 2112 /* BigIntLike */)) {
                    return isTypeAssignableToKind(operandType, 3 /* AnyOrUnknown */) || maybeTypeOfKind(operandType, 296 /* NumberLike */) ? numberOrBigIntType : bigintType;
                }
                return numberType;
            }
            function maybeTypeOfKindConsideringBaseConstraint(type, kind) {
                if (maybeTypeOfKind(type, kind)) {
                    return true;
                }
                const baseConstraint = getBaseConstraintOrType(type);
                return !!baseConstraint && maybeTypeOfKind(baseConstraint, kind);
            }
            function maybeTypeOfKind(type, kind) {
                if (type.flags & kind) {
                    return true;
                }
                if (type.flags & 3145728 /* UnionOrIntersection */) {
                    const types = type.types;
                    for (const t of types) {
                        if (maybeTypeOfKind(t, kind)) {
                            return true;
                        }
                    }
                }
                return false;
            }
            function isTypeAssignableToKind(source, kind, strict) {
                if (source.flags & kind) {
                    return true;
                }
                if (strict && source.flags & (3 /* AnyOrUnknown */ | 16384 /* Void */ | 32768 /* Undefined */ | 65536 /* Null */)) {
                    return false;
                }
                return !!(kind & 296 /* NumberLike */) && isTypeAssignableTo(source, numberType) || !!(kind & 2112 /* BigIntLike */) && isTypeAssignableTo(source, bigintType) || !!(kind & 402653316 /* StringLike */) && isTypeAssignableTo(source, stringType) || !!(kind & 528 /* BooleanLike */) && isTypeAssignableTo(source, booleanType) || !!(kind & 16384 /* Void */) && isTypeAssignableTo(source, voidType) || !!(kind & 131072 /* Never */) && isTypeAssignableTo(source, neverType) || !!(kind & 65536 /* Null */) && isTypeAssignableTo(source, nullType) || !!(kind & 32768 /* Undefined */) && isTypeAssignableTo(source, undefinedType) || !!(kind & 4096 /* ESSymbol */) && isTypeAssignableTo(source, esSymbolType) || !!(kind & 67108864 /* NonPrimitive */) && isTypeAssignableTo(source, nonPrimitiveType);
            }
            function allTypesAssignableToKind(source, kind, strict) {
                return source.flags & 1048576 /* Union */ ? every(source.types, (subType) => allTypesAssignableToKind(subType, kind, strict)) : isTypeAssignableToKind(source, kind, strict);
            }
            function isConstEnumObjectType(type) {
                return !!(getObjectFlags(type) & 16 /* Anonymous */) && !!type.symbol && isConstEnumSymbol(type.symbol);
            }
            function isConstEnumSymbol(symbol) {
                return (symbol.flags & 128 /* ConstEnum */) !== 0;
            }
            function getSymbolHasInstanceMethodOfObjectType(type) {
                const hasInstancePropertyName = getPropertyNameForKnownSymbolName("hasInstance");
                const hasInstanceProperty = getPropertyOfObjectType(type, hasInstancePropertyName);
                if (hasInstanceProperty) {
                    const hasInstancePropertyType = getTypeOfSymbol(hasInstanceProperty);
                    if (hasInstancePropertyType && getSignaturesOfType(hasInstancePropertyType, 0 /* Call */).length !== 0) {
                        return hasInstancePropertyType;
                    }
                }
            }
            function checkInstanceOfExpression(left, right, leftType, rightType, checkMode) {
                if (leftType === silentNeverType || rightType === silentNeverType) {
                    return silentNeverType;
                }
                if (!isTypeAny(leftType) && allTypesAssignableToKind(leftType, 402784252 /* Primitive */)) {
                    error2(left, Diagnostics.The_left_hand_side_of_an_instanceof_expression_must_be_of_type_any_an_object_type_or_a_type_parameter);
                }
                Debug.assert(isInstanceOfExpression(left.parent));
                const signature = getResolvedSignature(left.parent, 
                /*candidatesOutArray*/
                void 0, checkMode);
                if (signature === resolvingSignature) {
                    return silentNeverType;
                }
                const returnType = getReturnTypeOfSignature(signature);
                checkTypeAssignableTo(returnType, booleanType, right, Diagnostics.An_object_s_Symbol_hasInstance_method_must_return_a_boolean_value_for_it_to_be_used_on_the_right_hand_side_of_an_instanceof_expression);
                return booleanType;
            }
            function hasEmptyObjectIntersection(type) {
                return someType(type, (t) => t === unknownEmptyObjectType || !!(t.flags & 2097152 /* Intersection */) && isEmptyAnonymousObjectType(getBaseConstraintOrType(t)));
            }
            function checkInExpression(left, right, leftType, rightType) {
                if (leftType === silentNeverType || rightType === silentNeverType) {
                    return silentNeverType;
                }
                if (isPrivateIdentifier(left)) {
                    if (languageVersion < 99 /* ESNext */) {
                        checkExternalEmitHelpers(left, 2097152 /* ClassPrivateFieldIn */);
                    }
                    if (!getNodeLinks(left).resolvedSymbol && getContainingClass(left)) {
                        const isUncheckedJS = isUncheckedJSSuggestion(left, rightType.symbol, 
                        /*excludeClasses*/
                        true);
                        reportNonexistentProperty(left, rightType, isUncheckedJS);
                    }
                }
                else {
                    checkTypeAssignableTo(checkNonNullType(leftType, left), stringNumberSymbolType, left);
                }
                if (checkTypeAssignableTo(checkNonNullType(rightType, right), nonPrimitiveType, right)) {
                    if (hasEmptyObjectIntersection(rightType)) {
                        error2(right, Diagnostics.Type_0_may_represent_a_primitive_value_which_is_not_permitted_as_the_right_operand_of_the_in_operator, typeToString(rightType));
                    }
                }
                return booleanType;
            }
            function checkObjectLiteralAssignment(node, sourceType, rightIsThis) {
                const properties = node.properties;
                if (strictNullChecks && properties.length === 0) {
                    return checkNonNullType(sourceType, node);
                }
                for (let i = 0; i < properties.length; i++) {
                    checkObjectLiteralDestructuringPropertyAssignment(node, sourceType, i, properties, rightIsThis);
                }
                return sourceType;
            }
            function checkObjectLiteralDestructuringPropertyAssignment(node, objectLiteralType, propertyIndex, allProperties, rightIsThis = false) {
                const properties = node.properties;
                const property = properties[propertyIndex];
                if (property.kind === 303 /* PropertyAssignment */ || property.kind === 304 /* ShorthandPropertyAssignment */) {
                    const name = property.name;
                    const exprType = getLiteralTypeFromPropertyName(name);
                    if (isTypeUsableAsPropertyName(exprType)) {
                        const text = getPropertyNameFromType(exprType);
                        const prop = getPropertyOfType(objectLiteralType, text);
                        if (prop) {
                            markPropertyAsReferenced(prop, property, rightIsThis);
                            checkPropertyAccessibility(property, 
                            /*isSuper*/
                            false, 
                            /*writing*/
                            true, objectLiteralType, prop);
                        }
                    }
                    const elementType = getIndexedAccessType(objectLiteralType, exprType, 32 /* ExpressionPosition */, name);
                    const type = getFlowTypeOfDestructuring(property, elementType);
                    return checkDestructuringAssignment(property.kind === 304 /* ShorthandPropertyAssignment */ ? property : property.initializer, type);
                }
                else if (property.kind === 305 /* SpreadAssignment */) {
                    if (propertyIndex < properties.length - 1) {
                        error2(property, Diagnostics.A_rest_element_must_be_last_in_a_destructuring_pattern);
                    }
                    else {
                        if (languageVersion < 99 /* ESNext */) {
                            checkExternalEmitHelpers(property, 4 /* Rest */);
                        }
                        const nonRestNames = [];
                        if (allProperties) {
                            for (const otherProperty of allProperties) {
                                if (!isSpreadAssignment(otherProperty)) {
                                    nonRestNames.push(otherProperty.name);
                                }
                            }
                        }
                        const type = getRestType(objectLiteralType, nonRestNames, objectLiteralType.symbol);
                        checkGrammarForDisallowedTrailingComma(allProperties, Diagnostics.A_rest_parameter_or_binding_pattern_may_not_have_a_trailing_comma);
                        return checkDestructuringAssignment(property.expression, type);
                    }
                }
                else {
                    error2(property, Diagnostics.Property_assignment_expected);
                }
            }
            function checkArrayLiteralAssignment(node, sourceType, checkMode) {
                const elements = node.elements;
                if (languageVersion < 2 /* ES2015 */ && compilerOptions.downlevelIteration) {
                    checkExternalEmitHelpers(node, 512 /* Read */);
                }
                const possiblyOutOfBoundsType = checkIteratedTypeOrElementType(65 /* Destructuring */ | 128 /* PossiblyOutOfBounds */, sourceType, undefinedType, node) || errorType;
                let inBoundsType = compilerOptions.noUncheckedIndexedAccess ? void 0 : possiblyOutOfBoundsType;
                for (let i = 0; i < elements.length; i++) {
                    let type = possiblyOutOfBoundsType;
                    if (node.elements[i].kind === 230 /* SpreadElement */) {
                        type = inBoundsType = inBoundsType ?? (checkIteratedTypeOrElementType(65 /* Destructuring */, sourceType, undefinedType, node) || errorType);
                    }
                    checkArrayLiteralDestructuringElementAssignment(node, sourceType, i, type, checkMode);
                }
                return sourceType;
            }
            function checkArrayLiteralDestructuringElementAssignment(node, sourceType, elementIndex, elementType, checkMode) {
                const elements = node.elements;
                const element = elements[elementIndex];
                if (element.kind !== 232 /* OmittedExpression */) {
                    if (element.kind !== 230 /* SpreadElement */) {
                        const indexType = getNumberLiteralType(elementIndex);
                        if (isArrayLikeType(sourceType)) {
                            const accessFlags = 32 /* ExpressionPosition */ | (hasDefaultValue(element) ? 16 /* NoTupleBoundsCheck */ : 0);
                            const elementType2 = getIndexedAccessTypeOrUndefined(sourceType, indexType, accessFlags, createSyntheticExpression(element, indexType)) || errorType;
                            const assignedType = hasDefaultValue(element) ? getTypeWithFacts(elementType2, 524288 /* NEUndefined */) : elementType2;
                            const type = getFlowTypeOfDestructuring(element, assignedType);
                            return checkDestructuringAssignment(element, type, checkMode);
                        }
                        return checkDestructuringAssignment(element, elementType, checkMode);
                    }
                    if (elementIndex < elements.length - 1) {
                        error2(element, Diagnostics.A_rest_element_must_be_last_in_a_destructuring_pattern);
                    }
                    else {
                        const restExpression = element.expression;
                        if (restExpression.kind === 226 /* BinaryExpression */ && restExpression.operatorToken.kind === 64 /* EqualsToken */) {
                            error2(restExpression.operatorToken, Diagnostics.A_rest_element_cannot_have_an_initializer);
                        }
                        else {
                            checkGrammarForDisallowedTrailingComma(node.elements, Diagnostics.A_rest_parameter_or_binding_pattern_may_not_have_a_trailing_comma);
                            const type = everyType(sourceType, isTupleType) ? mapType(sourceType, (t) => sliceTupleType(t, elementIndex)) : createArrayType(elementType);
                            return checkDestructuringAssignment(restExpression, type, checkMode);
                        }
                    }
                }
                return void 0;
            }
            function checkDestructuringAssignment(exprOrAssignment, sourceType, checkMode, rightIsThis) {
                let target;
                if (exprOrAssignment.kind === 304 /* ShorthandPropertyAssignment */) {
                    const prop = exprOrAssignment;
                    if (prop.objectAssignmentInitializer) {
                        if (strictNullChecks && !hasTypeFacts(checkExpression(prop.objectAssignmentInitializer), 16777216 /* IsUndefined */)) {
                            sourceType = getTypeWithFacts(sourceType, 524288 /* NEUndefined */);
                        }
                        checkBinaryLikeExpression(prop.name, prop.equalsToken, prop.objectAssignmentInitializer, checkMode);
                    }
                    target = exprOrAssignment.name;
                }
                else {
                    target = exprOrAssignment;
                }
                if (target.kind === 226 /* BinaryExpression */ && target.operatorToken.kind === 64 /* EqualsToken */) {
                    checkBinaryExpression(target, checkMode);
                    target = target.left;
                    if (strictNullChecks) {
                        sourceType = getTypeWithFacts(sourceType, 524288 /* NEUndefined */);
                    }
                }
                if (target.kind === 210 /* ObjectLiteralExpression */) {
                    return checkObjectLiteralAssignment(target, sourceType, rightIsThis);
                }
                if (target.kind === 209 /* ArrayLiteralExpression */) {
                    return checkArrayLiteralAssignment(target, sourceType, checkMode);
                }
                return checkReferenceAssignment(target, sourceType, checkMode);
            }
            function checkReferenceAssignment(target, sourceType, checkMode) {
                const targetType = checkExpression(target, checkMode);
                const error3 = target.parent.kind === 305 /* SpreadAssignment */ ? Diagnostics.The_target_of_an_object_rest_assignment_must_be_a_variable_or_a_property_access : Diagnostics.The_left_hand_side_of_an_assignment_expression_must_be_a_variable_or_a_property_access;
                const optionalError = target.parent.kind === 305 /* SpreadAssignment */ ? Diagnostics.The_target_of_an_object_rest_assignment_may_not_be_an_optional_property_access : Diagnostics.The_left_hand_side_of_an_assignment_expression_may_not_be_an_optional_property_access;
                if (checkReferenceExpression(target, error3, optionalError)) {
                    checkTypeAssignableToAndOptionallyElaborate(sourceType, targetType, target, target);
                }
                if (isPrivateIdentifierPropertyAccessExpression(target)) {
                    checkExternalEmitHelpers(target.parent, 1048576 /* ClassPrivateFieldSet */);
                }
                return sourceType;
            }
            function isSideEffectFree(node) {
                node = skipParentheses(node);
                switch (node.kind) {
                    case 80 /* Identifier */:
                    case 11 /* StringLiteral */:
                    case 14 /* RegularExpressionLiteral */:
                    case 215 /* TaggedTemplateExpression */:
                    case 228 /* TemplateExpression */:
                    case 15 /* NoSubstitutionTemplateLiteral */:
                    case 9 /* NumericLiteral */:
                    case 10 /* BigIntLiteral */:
                    case 112 /* TrueKeyword */:
                    case 97 /* FalseKeyword */:
                    case 106 /* NullKeyword */:
                    case 157 /* UndefinedKeyword */:
                    case 218 /* FunctionExpression */:
                    case 231 /* ClassExpression */:
                    case 219 /* ArrowFunction */:
                    case 209 /* ArrayLiteralExpression */:
                    case 210 /* ObjectLiteralExpression */:
                    case 221 /* TypeOfExpression */:
                    case 235 /* NonNullExpression */:
                    case 285 /* JsxSelfClosingElement */:
                    case 284 /* JsxElement */:
                        return true;
                    case 227 /* ConditionalExpression */:
                        return isSideEffectFree(node.whenTrue) && isSideEffectFree(node.whenFalse);
                    case 226 /* BinaryExpression */:
                        if (isAssignmentOperator(node.operatorToken.kind)) {
                            return false;
                        }
                        return isSideEffectFree(node.left) && isSideEffectFree(node.right);
                    case 224 /* PrefixUnaryExpression */:
                    case 225 /* PostfixUnaryExpression */:
                        switch (node.operator) {
                            case 54 /* ExclamationToken */:
                            case 40 /* PlusToken */:
                            case 41 /* MinusToken */:
                            case 55 /* TildeToken */:
                                return true;
                        }
                        return false;
                    case 222 /* VoidExpression */:
                    case 216 /* TypeAssertionExpression */:
                    case 234 /* AsExpression */:
                    default:
                        return false;
                }
            }
            function isTypeEqualityComparableTo(source, target) {
                return (target.flags & 98304 /* Nullable */) !== 0 || isTypeComparableTo(source, target);
            }
            function createCheckBinaryExpression() {
                const trampoline = createBinaryExpressionTrampoline(onEnter, onLeft, onOperator, onRight, onExit, foldState);
                return (node, checkMode) => {
                    const result = trampoline(node, checkMode);
                    Debug.assertIsDefined(result);
                    return result;
                };
                function onEnter(node, state, checkMode) {
                    if (state) {
                        state.stackIndex++;
                        state.skip = false;
                        setLeftType(state, 
                        /*type*/
                        void 0);
                        setLastResult(state, 
                        /*type*/
                        void 0);
                    }
                    else {
                        state = {
                            checkMode,
                            skip: false,
                            stackIndex: 0,
                            typeStack: [void 0, void 0]
                        };
                    }
                    if (isInJSFile(node) && getAssignedExpandoInitializer(node)) {
                        state.skip = true;
                        setLastResult(state, checkExpression(node.right, checkMode));
                        return state;
                    }
                    checkGrammarNullishCoalesceWithLogicalExpression(node);
                    const operator = node.operatorToken.kind;
                    if (operator === 64 /* EqualsToken */ && (node.left.kind === 210 /* ObjectLiteralExpression */ || node.left.kind === 209 /* ArrayLiteralExpression */)) {
                        state.skip = true;
                        setLastResult(state, checkDestructuringAssignment(node.left, checkExpression(node.right, checkMode), checkMode, node.right.kind === 110 /* ThisKeyword */));
                        return state;
                    }
                    return state;
                }
                function onLeft(left, state, _node) {
                    if (!state.skip) {
                        return maybeCheckExpression(state, left);
                    }
                }
                function onOperator(operatorToken, state, node) {
                    if (!state.skip) {
                        const leftType = getLastResult(state);
                        Debug.assertIsDefined(leftType);
                        setLeftType(state, leftType);
                        setLastResult(state, 
                        /*type*/
                        void 0);
                        const operator = operatorToken.kind;
                        if (isLogicalOrCoalescingBinaryOperator(operator)) {
                            let parent2 = node.parent;
                            while (parent2.kind === 217 /* ParenthesizedExpression */ || isLogicalOrCoalescingBinaryExpression(parent2)) {
                                parent2 = parent2.parent;
                            }
                            if (operator === 56 /* AmpersandAmpersandToken */ || isIfStatement(parent2)) {
                                checkTestingKnownTruthyCallableOrAwaitableType(node.left, leftType, isIfStatement(parent2) ? parent2.thenStatement : void 0);
                            }
                            checkTruthinessOfType(leftType, node.left);
                        }
                    }
                }
                function onRight(right, state, _node) {
                    if (!state.skip) {
                        return maybeCheckExpression(state, right);
                    }
                }
                function onExit(node, state) {
                    let result;
                    if (state.skip) {
                        result = getLastResult(state);
                    }
                    else {
                        const leftType = getLeftType(state);
                        Debug.assertIsDefined(leftType);
                        const rightType = getLastResult(state);
                        Debug.assertIsDefined(rightType);
                        result = checkBinaryLikeExpressionWorker(node.left, node.operatorToken, node.right, leftType, rightType, state.checkMode, node);
                    }
                    state.skip = false;
                    setLeftType(state, 
                    /*type*/
                    void 0);
                    setLastResult(state, 
                    /*type*/
                    void 0);
                    state.stackIndex--;
                    return result;
                }
                function foldState(state, result, _side) {
                    setLastResult(state, result);
                    return state;
                }
                function maybeCheckExpression(state, node) {
                    if (isBinaryExpression(node)) {
                        return node;
                    }
                    setLastResult(state, checkExpression(node, state.checkMode));
                }
                function getLeftType(state) {
                    return state.typeStack[state.stackIndex];
                }
                function setLeftType(state, type) {
                    state.typeStack[state.stackIndex] = type;
                }
                function getLastResult(state) {
                    return state.typeStack[state.stackIndex + 1];
                }
                function setLastResult(state, type) {
                    state.typeStack[state.stackIndex + 1] = type;
                }
            }
            function checkGrammarNullishCoalesceWithLogicalExpression(node) {
                const { left, operatorToken, right } = node;
                if (operatorToken.kind === 61 /* QuestionQuestionToken */) {
                    if (isBinaryExpression(left) && (left.operatorToken.kind === 57 /* BarBarToken */ || left.operatorToken.kind === 56 /* AmpersandAmpersandToken */)) {
                        grammarErrorOnNode(left, Diagnostics._0_and_1_operations_cannot_be_mixed_without_parentheses, tokenToString(left.operatorToken.kind), tokenToString(operatorToken.kind));
                    }
                    if (isBinaryExpression(right) && (right.operatorToken.kind === 57 /* BarBarToken */ || right.operatorToken.kind === 56 /* AmpersandAmpersandToken */)) {
                        grammarErrorOnNode(right, Diagnostics._0_and_1_operations_cannot_be_mixed_without_parentheses, tokenToString(right.operatorToken.kind), tokenToString(operatorToken.kind));
                    }
                }
            }
            function checkBinaryLikeExpression(left, operatorToken, right, checkMode, errorNode) {
                const operator = operatorToken.kind;
                if (operator === 64 /* EqualsToken */ && (left.kind === 210 /* ObjectLiteralExpression */ || left.kind === 209 /* ArrayLiteralExpression */)) {
                    return checkDestructuringAssignment(left, checkExpression(right, checkMode), checkMode, right.kind === 110 /* ThisKeyword */);
                }
                let leftType;
                if (isLogicalOrCoalescingBinaryOperator(operator)) {
                    leftType = checkTruthinessExpression(left, checkMode);
                }
                else {
                    leftType = checkExpression(left, checkMode);
                }
                const rightType = checkExpression(right, checkMode);
                return checkBinaryLikeExpressionWorker(left, operatorToken, right, leftType, rightType, checkMode, errorNode);
            }
            function checkBinaryLikeExpressionWorker(left, operatorToken, right, leftType, rightType, checkMode, errorNode) {
                const operator = operatorToken.kind;
                switch (operator) {
                    case 42 /* AsteriskToken */:
                    case 43 /* AsteriskAsteriskToken */:
                    case 67 /* AsteriskEqualsToken */:
                    case 68 /* AsteriskAsteriskEqualsToken */:
                    case 44 /* SlashToken */:
                    case 69 /* SlashEqualsToken */:
                    case 45 /* PercentToken */:
                    case 70 /* PercentEqualsToken */:
                    case 41 /* MinusToken */:
                    case 66 /* MinusEqualsToken */:
                    case 48 /* LessThanLessThanToken */:
                    case 71 /* LessThanLessThanEqualsToken */:
                    case 49 /* GreaterThanGreaterThanToken */:
                    case 72 /* GreaterThanGreaterThanEqualsToken */:
                    case 50 /* GreaterThanGreaterThanGreaterThanToken */:
                    case 73 /* GreaterThanGreaterThanGreaterThanEqualsToken */:
                    case 52 /* BarToken */:
                    case 75 /* BarEqualsToken */:
                    case 53 /* CaretToken */:
                    case 79 /* CaretEqualsToken */:
                    case 51 /* AmpersandToken */:
                    case 74 /* AmpersandEqualsToken */:
                        if (leftType === silentNeverType || rightType === silentNeverType) {
                            return silentNeverType;
                        }
                        leftType = checkNonNullType(leftType, left);
                        rightType = checkNonNullType(rightType, right);
                        let suggestedOperator;
                        if (leftType.flags & 528 /* BooleanLike */ && rightType.flags & 528 /* BooleanLike */ && (suggestedOperator = getSuggestedBooleanOperator(operatorToken.kind)) !== void 0) {
                            error2(errorNode || operatorToken, Diagnostics.The_0_operator_is_not_allowed_for_boolean_types_Consider_using_1_instead, tokenToString(operatorToken.kind), tokenToString(suggestedOperator));
                            return numberType;
                        }
                        else {
                            const leftOk = checkArithmeticOperandType(left, leftType, Diagnostics.The_left_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type, 
                            /*isAwaitValid*/
                            true);
                            const rightOk = checkArithmeticOperandType(right, rightType, Diagnostics.The_right_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type, 
                            /*isAwaitValid*/
                            true);
                            let resultType2;
                            if (isTypeAssignableToKind(leftType, 3 /* AnyOrUnknown */) && isTypeAssignableToKind(rightType, 3 /* AnyOrUnknown */) || // Or, if neither could be bigint, implicit coercion results in a number result
                                !(maybeTypeOfKind(leftType, 2112 /* BigIntLike */) || maybeTypeOfKind(rightType, 2112 /* BigIntLike */))) {
                                resultType2 = numberType;
                            }
                            else if (bothAreBigIntLike(leftType, rightType)) {
                                switch (operator) {
                                    case 50 /* GreaterThanGreaterThanGreaterThanToken */:
                                    case 73 /* GreaterThanGreaterThanGreaterThanEqualsToken */:
                                        reportOperatorError();
                                        break;
                                    case 43 /* AsteriskAsteriskToken */:
                                    case 68 /* AsteriskAsteriskEqualsToken */:
                                        if (languageVersion < 3 /* ES2016 */) {
                                            error2(errorNode, Diagnostics.Exponentiation_cannot_be_performed_on_bigint_values_unless_the_target_option_is_set_to_es2016_or_later);
                                        }
                                }
                                resultType2 = bigintType;
                            }
                            else {
                                reportOperatorError(bothAreBigIntLike);
                                resultType2 = errorType;
                            }
                            if (leftOk && rightOk) {
                                checkAssignmentOperator(resultType2);
                            }
                            return resultType2;
                        }
                    case 40 /* PlusToken */:
                    case 65 /* PlusEqualsToken */:
                        if (leftType === silentNeverType || rightType === silentNeverType) {
                            return silentNeverType;
                        }
                        if (!isTypeAssignableToKind(leftType, 402653316 /* StringLike */) && !isTypeAssignableToKind(rightType, 402653316 /* StringLike */)) {
                            leftType = checkNonNullType(leftType, left);
                            rightType = checkNonNullType(rightType, right);
                        }
                        let resultType;
                        if (isTypeAssignableToKind(leftType, 296 /* NumberLike */, 
                        /*strict*/
                        true) && isTypeAssignableToKind(rightType, 296 /* NumberLike */, 
                        /*strict*/
                        true)) {
                            resultType = numberType;
                        }
                        else if (isTypeAssignableToKind(leftType, 2112 /* BigIntLike */, 
                        /*strict*/
                        true) && isTypeAssignableToKind(rightType, 2112 /* BigIntLike */, 
                        /*strict*/
                        true)) {
                            resultType = bigintType;
                        }
                        else if (isTypeAssignableToKind(leftType, 402653316 /* StringLike */, 
                        /*strict*/
                        true) || isTypeAssignableToKind(rightType, 402653316 /* StringLike */, 
                        /*strict*/
                        true)) {
                            resultType = stringType;
                        }
                        else if (isTypeAny(leftType) || isTypeAny(rightType)) {
                            resultType = isErrorType(leftType) || isErrorType(rightType) ? errorType : anyType;
                        }
                        if (resultType && !checkForDisallowedESSymbolOperand(operator)) {
                            return resultType;
                        }
                        if (!resultType) {
                            const closeEnoughKind = 296 /* NumberLike */ | 2112 /* BigIntLike */ | 402653316 /* StringLike */ | 3 /* AnyOrUnknown */;
                            reportOperatorError((left2, right2) => isTypeAssignableToKind(left2, closeEnoughKind) && isTypeAssignableToKind(right2, closeEnoughKind));
                            return anyType;
                        }
                        if (operator === 65 /* PlusEqualsToken */) {
                            checkAssignmentOperator(resultType);
                        }
                        return resultType;
                    case 30 /* LessThanToken */:
                    case 32 /* GreaterThanToken */:
                    case 33 /* LessThanEqualsToken */:
                    case 34 /* GreaterThanEqualsToken */:
                        if (checkForDisallowedESSymbolOperand(operator)) {
                            leftType = getBaseTypeOfLiteralTypeForComparison(checkNonNullType(leftType, left));
                            rightType = getBaseTypeOfLiteralTypeForComparison(checkNonNullType(rightType, right));
                            reportOperatorErrorUnless((left2, right2) => {
                                if (isTypeAny(left2) || isTypeAny(right2)) {
                                    return true;
                                }
                                const leftAssignableToNumber = isTypeAssignableTo(left2, numberOrBigIntType);
                                const rightAssignableToNumber = isTypeAssignableTo(right2, numberOrBigIntType);
                                return leftAssignableToNumber && rightAssignableToNumber || !leftAssignableToNumber && !rightAssignableToNumber && areTypesComparable(left2, right2);
                            });
                        }
                        return booleanType;
                    case 35 /* EqualsEqualsToken */:
                    case 36 /* ExclamationEqualsToken */:
                    case 37 /* EqualsEqualsEqualsToken */:
                    case 38 /* ExclamationEqualsEqualsToken */:
                        if (!(checkMode && checkMode & 64 /* TypeOnly */)) {
                            if ((isLiteralExpressionOfObject(left) || isLiteralExpressionOfObject(right)) && // only report for === and !== in JS, not == or !=
                                (!isInJSFile(left) || (operator === 37 /* EqualsEqualsEqualsToken */ || operator === 38 /* ExclamationEqualsEqualsToken */))) {
                                const eqType = operator === 35 /* EqualsEqualsToken */ || operator === 37 /* EqualsEqualsEqualsToken */;
                                error2(errorNode, Diagnostics.This_condition_will_always_return_0_since_JavaScript_compares_objects_by_reference_not_value, eqType ? "false" : "true");
                            }
                            checkNaNEquality(errorNode, operator, left, right);
                            reportOperatorErrorUnless((left2, right2) => isTypeEqualityComparableTo(left2, right2) || isTypeEqualityComparableTo(right2, left2));
                        }
                        return booleanType;
                    case 104 /* InstanceOfKeyword */:
                        return checkInstanceOfExpression(left, right, leftType, rightType, checkMode);
                    case 103 /* InKeyword */:
                        return checkInExpression(left, right, leftType, rightType);
                    case 56 /* AmpersandAmpersandToken */:
                    case 77 /* AmpersandAmpersandEqualsToken */: {
                        const resultType2 = hasTypeFacts(leftType, 4194304 /* Truthy */) ? getUnionType([extractDefinitelyFalsyTypes(strictNullChecks ? leftType : getBaseTypeOfLiteralType(rightType)), rightType]) : leftType;
                        if (operator === 77 /* AmpersandAmpersandEqualsToken */) {
                            checkAssignmentOperator(rightType);
                        }
                        return resultType2;
                    }
                    case 57 /* BarBarToken */:
                    case 76 /* BarBarEqualsToken */: {
                        const resultType2 = hasTypeFacts(leftType, 8388608 /* Falsy */) ? getUnionType([getNonNullableType(removeDefinitelyFalsyTypes(leftType)), rightType], 2 /* Subtype */) : leftType;
                        if (operator === 76 /* BarBarEqualsToken */) {
                            checkAssignmentOperator(rightType);
                        }
                        return resultType2;
                    }
                    case 61 /* QuestionQuestionToken */:
                    case 78 /* QuestionQuestionEqualsToken */: {
                        const resultType2 = hasTypeFacts(leftType, 262144 /* EQUndefinedOrNull */) ? getUnionType([getNonNullableType(leftType), rightType], 2 /* Subtype */) : leftType;
                        if (operator === 78 /* QuestionQuestionEqualsToken */) {
                            checkAssignmentOperator(rightType);
                        }
                        return resultType2;
                    }
                    case 64 /* EqualsToken */:
                        const declKind = isBinaryExpression(left.parent) ? getAssignmentDeclarationKind(left.parent) : 0 /* None */;
                        checkAssignmentDeclaration(declKind, rightType);
                        if (isAssignmentDeclaration2(declKind)) {
                            if (!(rightType.flags & 524288 /* Object */) || declKind !== 2 /* ModuleExports */ && declKind !== 6 /* Prototype */ && !isEmptyObjectType(rightType) && !isFunctionObjectType(rightType) && !(getObjectFlags(rightType) & 1 /* Class */)) {
                                checkAssignmentOperator(rightType);
                            }
                            return leftType;
                        }
                        else {
                            checkAssignmentOperator(rightType);
                            return rightType;
                        }
                    case 28 /* CommaToken */:
                        if (!compilerOptions.allowUnreachableCode && isSideEffectFree(left) && !isIndirectCall(left.parent)) {
                            const sf = getSourceFileOfNode(left);
                            const sourceText = sf.text;
                            const start = skipTrivia(sourceText, left.pos);
                            const isInDiag2657 = sf.parseDiagnostics.some((diag2) => {
                                if (diag2.code !== Diagnostics.JSX_expressions_must_have_one_parent_element.code)
                                    return false;
                                return textSpanContainsPosition(diag2, start);
                            });
                            if (!isInDiag2657)
                                error2(left, Diagnostics.Left_side_of_comma_operator_is_unused_and_has_no_side_effects);
                        }
                        return rightType;
                    default:
                        return Debug.fail();
                }
                function bothAreBigIntLike(left2, right2) {
                    return isTypeAssignableToKind(left2, 2112 /* BigIntLike */) && isTypeAssignableToKind(right2, 2112 /* BigIntLike */);
                }
                function checkAssignmentDeclaration(kind, rightType2) {
                    if (kind === 2 /* ModuleExports */) {
                        for (const prop of getPropertiesOfObjectType(rightType2)) {
                            const propType = getTypeOfSymbol(prop);
                            if (propType.symbol && propType.symbol.flags & 32 /* Class */) {
                                const name = prop.escapedName;
                                const symbol = resolveName(prop.valueDeclaration, name, 788968 /* Type */, 
                                /*nameNotFoundMessage*/
                                void 0, name, 
                                /*isUse*/
                                false);
                                if ((symbol == null ? void 0 : symbol.declarations) && symbol.declarations.some(isJSDocTypedefTag)) {
                                    addDuplicateDeclarationErrorsForSymbols(symbol, Diagnostics.Duplicate_identifier_0, unescapeLeadingUnderscores(name), prop);
                                    addDuplicateDeclarationErrorsForSymbols(prop, Diagnostics.Duplicate_identifier_0, unescapeLeadingUnderscores(name), symbol);
                                }
                            }
                        }
                    }
                }
                function isIndirectCall(node) {
                    return node.parent.kind === 217 /* ParenthesizedExpression */ && isNumericLiteral(node.left) && node.left.text === "0" && (isCallExpression(node.parent.parent) && node.parent.parent.expression === node.parent || node.parent.parent.kind === 215 /* TaggedTemplateExpression */) && // special-case for "eval" because it's the only non-access case where an indirect call actually affects behavior.
                        (isAccessExpression(node.right) || isIdentifier(node.right) && node.right.escapedText === "eval");
                }
                function checkForDisallowedESSymbolOperand(operator2) {
                    const offendingSymbolOperand = maybeTypeOfKindConsideringBaseConstraint(leftType, 12288 /* ESSymbolLike */) ? left : maybeTypeOfKindConsideringBaseConstraint(rightType, 12288 /* ESSymbolLike */) ? right : void 0;
                    if (offendingSymbolOperand) {
                        error2(offendingSymbolOperand, Diagnostics.The_0_operator_cannot_be_applied_to_type_symbol, tokenToString(operator2));
                        return false;
                    }
                    return true;
                }
                function getSuggestedBooleanOperator(operator2) {
                    switch (operator2) {
                        case 52 /* BarToken */:
                        case 75 /* BarEqualsToken */:
                            return 57 /* BarBarToken */;
                        case 53 /* CaretToken */:
                        case 79 /* CaretEqualsToken */:
                            return 38 /* ExclamationEqualsEqualsToken */;
                        case 51 /* AmpersandToken */:
                        case 74 /* AmpersandEqualsToken */:
                            return 56 /* AmpersandAmpersandToken */;
                        default:
                            return void 0;
                    }
                }
                function checkAssignmentOperator(valueType) {
                    if (isAssignmentOperator(operator)) {
                        addLazyDiagnostic(checkAssignmentOperatorWorker);
                    }
                    function checkAssignmentOperatorWorker() {
                        let assigneeType = leftType;
                        if (isCompoundAssignment(operatorToken.kind) && left.kind === 211 /* PropertyAccessExpression */) {
                            assigneeType = checkPropertyAccessExpression(left, 
                            /*checkMode*/
                            void 0, 
                            /*writeOnly*/
                            true);
                        }
                        if (checkReferenceExpression(left, Diagnostics.The_left_hand_side_of_an_assignment_expression_must_be_a_variable_or_a_property_access, Diagnostics.The_left_hand_side_of_an_assignment_expression_may_not_be_an_optional_property_access)) {
                            let headMessage;
                            if (exactOptionalPropertyTypes && isPropertyAccessExpression(left) && maybeTypeOfKind(valueType, 32768 /* Undefined */)) {
                                const target = getTypeOfPropertyOfType(getTypeOfExpression(left.expression), left.name.escapedText);
                                if (isExactOptionalPropertyMismatch(valueType, target)) {
                                    headMessage = Diagnostics.Type_0_is_not_assignable_to_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_type_of_the_target;
                                }
                            }
                            checkTypeAssignableToAndOptionallyElaborate(valueType, assigneeType, left, right, headMessage);
                        }
                    }
                }
                function isAssignmentDeclaration2(kind) {
                    var _a;
                    switch (kind) {
                        case 2 /* ModuleExports */:
                            return true;
                        case 1 /* ExportsProperty */:
                        case 5 /* Property */:
                        case 6 /* Prototype */:
                        case 3 /* PrototypeProperty */:
                        case 4 /* ThisProperty */:
                            const symbol = getSymbolOfNode(left);
                            const init = getAssignedExpandoInitializer(right);
                            return !!init && isObjectLiteralExpression(init) && !!((_a = symbol == null ? void 0 : symbol.exports) == null ? void 0 : _a.size);
                        default:
                            return false;
                    }
                }
                function reportOperatorErrorUnless(typesAreCompatible) {
                    if (!typesAreCompatible(leftType, rightType)) {
                        reportOperatorError(typesAreCompatible);
                        return true;
                    }
                    return false;
                }
                function reportOperatorError(isRelated) {
                    let wouldWorkWithAwait = false;
                    const errNode = errorNode || operatorToken;
                    if (isRelated) {
                        const awaitedLeftType = getAwaitedTypeNoAlias(leftType);
                        const awaitedRightType = getAwaitedTypeNoAlias(rightType);
                        wouldWorkWithAwait = !(awaitedLeftType === leftType && awaitedRightType === rightType) && !!(awaitedLeftType && awaitedRightType) && isRelated(awaitedLeftType, awaitedRightType);
                    }
                    let effectiveLeft = leftType;
                    let effectiveRight = rightType;
                    if (!wouldWorkWithAwait && isRelated) {
                        [effectiveLeft, effectiveRight] = getBaseTypesIfUnrelated(leftType, rightType, isRelated);
                    }
                    const [leftStr, rightStr] = getTypeNamesForErrorDisplay(effectiveLeft, effectiveRight);
                    if (!tryGiveBetterPrimaryError(errNode, wouldWorkWithAwait, leftStr, rightStr)) {
                        errorAndMaybeSuggestAwait(errNode, wouldWorkWithAwait, Diagnostics.Operator_0_cannot_be_applied_to_types_1_and_2, tokenToString(operatorToken.kind), leftStr, rightStr);
                    }
                }
                function tryGiveBetterPrimaryError(errNode, maybeMissingAwait, leftStr, rightStr) {
                    switch (operatorToken.kind) {
                        case 37 /* EqualsEqualsEqualsToken */:
                        case 35 /* EqualsEqualsToken */:
                        case 38 /* ExclamationEqualsEqualsToken */:
                        case 36 /* ExclamationEqualsToken */:
                            return errorAndMaybeSuggestAwait(errNode, maybeMissingAwait, Diagnostics.This_comparison_appears_to_be_unintentional_because_the_types_0_and_1_have_no_overlap, leftStr, rightStr);
                        default:
                            return void 0;
                    }
                }
                function checkNaNEquality(errorNode2, operator2, left2, right2) {
                    const isLeftNaN = isGlobalNaN(skipParentheses(left2));
                    const isRightNaN = isGlobalNaN(skipParentheses(right2));
                    if (isLeftNaN || isRightNaN) {
                        const err = error2(errorNode2, Diagnostics.This_condition_will_always_return_0, tokenToString(operator2 === 37 /* EqualsEqualsEqualsToken */ || operator2 === 35 /* EqualsEqualsToken */ ? 97 /* FalseKeyword */ : 112 /* TrueKeyword */));
                        if (isLeftNaN && isRightNaN)
                            return;
                        const operatorString = operator2 === 38 /* ExclamationEqualsEqualsToken */ || operator2 === 36 /* ExclamationEqualsToken */ ? tokenToString(54 /* ExclamationToken */) : "";
                        const location = isLeftNaN ? right2 : left2;
                        const expression = skipParentheses(location);
                        addRelatedInfo(err, createDiagnosticForNode(location, Diagnostics.Did_you_mean_0, `${operatorString}Number.isNaN(${isEntityNameExpression(expression) ? entityNameToString(expression) : "..."})`));
                    }
                }
                function isGlobalNaN(expr) {
                    if (isIdentifier(expr) && expr.escapedText === "NaN") {
                        const globalNaNSymbol = getGlobalNaNSymbol();
                        return !!globalNaNSymbol && globalNaNSymbol === getResolvedSymbol(expr);
                    }
                    return false;
                }
            }
            function getBaseTypesIfUnrelated(leftType, rightType, isRelated) {
                let effectiveLeft = leftType;
                let effectiveRight = rightType;
                const leftBase = getBaseTypeOfLiteralType(leftType);
                const rightBase = getBaseTypeOfLiteralType(rightType);
                if (!isRelated(leftBase, rightBase)) {
                    effectiveLeft = leftBase;
                    effectiveRight = rightBase;
                }
                return [effectiveLeft, effectiveRight];
            }
            function checkYieldExpression(node) {
                addLazyDiagnostic(checkYieldExpressionGrammar);
                const func = getContainingFunction(node);
                if (!func)
                    return anyType;
                const functionFlags = getFunctionFlags(func);
                if (!(functionFlags & 1 /* Generator */)) {
                    return anyType;
                }
                const isAsync = (functionFlags & 2 /* Async */) !== 0;
                if (node.asteriskToken) {
                    if (isAsync && languageVersion < 99 /* ESNext */) {
                        checkExternalEmitHelpers(node, 26624 /* AsyncDelegatorIncludes */);
                    }
                    if (!isAsync && languageVersion < 2 /* ES2015 */ && compilerOptions.downlevelIteration) {
                        checkExternalEmitHelpers(node, 256 /* Values */);
                    }
                }
                let returnType = getReturnTypeFromAnnotation(func);
                if (returnType && returnType.flags & 1048576 /* Union */) {
                    returnType = filterType(returnType, (t) => checkGeneratorInstantiationAssignabilityToReturnType(t, functionFlags, 
                    /*errorNode*/
                    void 0));
                }
                const iterationTypes = returnType && getIterationTypesOfGeneratorFunctionReturnType(returnType, isAsync);
                const signatureYieldType = iterationTypes && iterationTypes.yieldType || anyType;
                const signatureNextType = iterationTypes && iterationTypes.nextType || anyType;
                const resolvedSignatureNextType = isAsync ? getAwaitedType(signatureNextType) || anyType : signatureNextType;
                const yieldExpressionType = node.expression ? checkExpression(node.expression) : undefinedWideningType;
                const yieldedType = getYieldedTypeOfYieldExpression(node, yieldExpressionType, resolvedSignatureNextType, isAsync);
                if (returnType && yieldedType) {
                    checkTypeAssignableToAndOptionallyElaborate(yieldedType, signatureYieldType, node.expression || node, node.expression);
                }
                if (node.asteriskToken) {
                    const use = isAsync ? 19 /* AsyncYieldStar */ : 17 /* YieldStar */;
                    return getIterationTypeOfIterable(use, 1 /* Return */, yieldExpressionType, node.expression) || anyType;
                }
                else if (returnType) {
                    return getIterationTypeOfGeneratorFunctionReturnType(2 /* Next */, returnType, isAsync) || anyType;
                }
                let type = getContextualIterationType(2 /* Next */, func);
                if (!type) {
                    type = anyType;
                    addLazyDiagnostic(() => {
                        if (noImplicitAny && !expressionResultIsUnused(node)) {
                            const contextualType = getContextualType2(node, 
                            /*contextFlags*/
                            void 0);
                            if (!contextualType || isTypeAny(contextualType)) {
                                error2(node, Diagnostics.yield_expression_implicitly_results_in_an_any_type_because_its_containing_generator_lacks_a_return_type_annotation);
                            }
                        }
                    });
                }
                return type;
                function checkYieldExpressionGrammar() {
                    if (!(node.flags & 16384 /* YieldContext */)) {
                        grammarErrorOnFirstToken(node, Diagnostics.A_yield_expression_is_only_allowed_in_a_generator_body);
                    }
                    if (isInParameterInitializerBeforeContainingFunction(node)) {
                        error2(node, Diagnostics.yield_expressions_cannot_be_used_in_a_parameter_initializer);
                    }
                }
            }
            function checkConditionalExpression(node, checkMode) {
                const type = checkTruthinessExpression(node.condition, checkMode);
                checkTestingKnownTruthyCallableOrAwaitableType(node.condition, type, node.whenTrue);
                const type1 = checkExpression(node.whenTrue, checkMode);
                const type2 = checkExpression(node.whenFalse, checkMode);
                return getUnionType([type1, type2], 2 /* Subtype */);
            }
            function isTemplateLiteralContext(node) {
                const parent2 = node.parent;
                return isParenthesizedExpression(parent2) && isTemplateLiteralContext(parent2) || isElementAccessExpression(parent2) && parent2.argumentExpression === node;
            }
            function checkTemplateExpression(node) {
                const texts = [node.head.text];
                const types = [];
                for (const span of node.templateSpans) {
                    const type = checkExpression(span.expression);
                    if (maybeTypeOfKindConsideringBaseConstraint(type, 12288 /* ESSymbolLike */)) {
                        error2(span.expression, Diagnostics.Implicit_conversion_of_a_symbol_to_a_string_will_fail_at_runtime_Consider_wrapping_this_expression_in_String);
                    }
                    texts.push(span.literal.text);
                    types.push(isTypeAssignableTo(type, templateConstraintType) ? type : stringType);
                }
                if (isConstContext(node) || isTemplateLiteralContext(node) || someType(getContextualType2(node, 
                /*contextFlags*/
                void 0) || unknownType, isTemplateLiteralContextualType)) {
                    return getTemplateLiteralType(texts, types);
                }
                const evaluated = node.parent.kind !== 215 /* TaggedTemplateExpression */ && evaluateTemplateExpression(node);
                return evaluated ? getFreshTypeOfLiteralType(getStringLiteralType(evaluated)) : stringType;
            }
            function isTemplateLiteralContextualType(type) {
                return !!(type.flags & (128 /* StringLiteral */ | 134217728 /* TemplateLiteral */) || type.flags & 58982400 /* InstantiableNonPrimitive */ && maybeTypeOfKind(getBaseConstraintOfType(type) || unknownType, 402653316 /* StringLike */));
            }
            function getContextNode2(node) {
                if (isJsxAttributes(node) && !isJsxSelfClosingElement(node.parent)) {
                    return node.parent.parent;
                }
                return node;
            }
            function checkExpressionWithContextualType(node, contextualType, inferenceContext, checkMode) {
                const contextNode = getContextNode2(node);
                pushContextualType(contextNode, contextualType, 
                /*isCache*/
                false);
                pushInferenceContext(contextNode, inferenceContext);
                const type = checkExpression(node, checkMode | 1 /* Contextual */ | (inferenceContext ? 2 /* Inferential */ : 0));
                if (inferenceContext && inferenceContext.intraExpressionInferenceSites) {
                    inferenceContext.intraExpressionInferenceSites = void 0;
                }
                const result = maybeTypeOfKind(type, 2944 /* Literal */) && isLiteralOfContextualType(type, instantiateContextualType(contextualType, node, 
                /*contextFlags*/
                void 0)) ? getRegularTypeOfLiteralType(type) : type;
                popInferenceContext();
                popContextualType();
                return result;
            }
            function checkExpressionCached(node, checkMode) {
                if (checkMode) {
                    return checkExpression(node, checkMode);
                }
                const links = getNodeLinks(node);
                if (!links.resolvedType) {
                    const saveFlowLoopStart = flowLoopStart;
                    const saveFlowTypeCache = flowTypeCache;
                    flowLoopStart = flowLoopCount;
                    flowTypeCache = void 0;
                    links.resolvedType = checkExpression(node, checkMode);
                    flowTypeCache = saveFlowTypeCache;
                    flowLoopStart = saveFlowLoopStart;
                }
                return links.resolvedType;
            }
            function isTypeAssertion(node) {
                node = skipParentheses(node, 
                /*excludeJSDocTypeAssertions*/
                true);
                return node.kind === 216 /* TypeAssertionExpression */ || node.kind === 234 /* AsExpression */ || isJSDocTypeAssertion(node);
            }
            function checkDeclarationInitializer(declaration, checkMode, contextualType) {
                const initializer = getEffectiveInitializer(declaration);
                if (isInJSFile(declaration)) {
                    const typeNode = tryGetJSDocSatisfiesTypeNode(declaration);
                    if (typeNode) {
                        return checkSatisfiesExpressionWorker(initializer, typeNode, checkMode);
                    }
                }
                const type = getQuickTypeOfExpression(initializer) || (contextualType ? checkExpressionWithContextualType(initializer, contextualType, 
                /*inferenceContext*/
                void 0, checkMode || 0 /* Normal */) : checkExpressionCached(initializer, checkMode));
                return isParameter(declaration) && declaration.name.kind === 207 /* ArrayBindingPattern */ && isTupleType(type) && !type.target.hasRestElement && getTypeReferenceArity(type) < declaration.name.elements.length ? padTupleType(type, declaration.name) : type;
            }
            function padTupleType(type, pattern) {
                const patternElements = pattern.elements;
                const elementTypes = getElementTypes(type).slice();
                const elementFlags = type.target.elementFlags.slice();
                for (let i = getTypeReferenceArity(type); i < patternElements.length; i++) {
                    const e = patternElements[i];
                    if (i < patternElements.length - 1 || !(e.kind === 208 /* BindingElement */ && e.dotDotDotToken)) {
                        elementTypes.push(!isOmittedExpression(e) && hasDefaultValue(e) ? getTypeFromBindingElement(e, 
                        /*includePatternInType*/
                        false, 
                        /*reportErrors*/
                        false) : anyType);
                        elementFlags.push(2 /* Optional */);
                        if (!isOmittedExpression(e) && !hasDefaultValue(e)) {
                            reportImplicitAny(e, anyType);
                        }
                    }
                }
                return createTupleType(elementTypes, elementFlags, type.target.readonly);
            }
            function widenTypeInferredFromInitializer(declaration, type) {
                const widened = getCombinedNodeFlagsCached(declaration) & 6 /* Constant */ || isDeclarationReadonly(declaration) ? type : getWidenedLiteralType(type);
                if (isInJSFile(declaration)) {
                    if (isEmptyLiteralType(widened)) {
                        reportImplicitAny(declaration, anyType);
                        return anyType;
                    }
                    else if (isEmptyArrayLiteralType(widened)) {
                        reportImplicitAny(declaration, anyArrayType);
                        return anyArrayType;
                    }
                }
                return widened;
            }
            function isLiteralOfContextualType(candidateType, contextualType) {
                if (contextualType) {
                    if (contextualType.flags & 3145728 /* UnionOrIntersection */) {
                        const types = contextualType.types;
                        return some(types, (t) => isLiteralOfContextualType(candidateType, t));
                    }
                    if (contextualType.flags & 58982400 /* InstantiableNonPrimitive */) {
                        const constraint = getBaseConstraintOfType(contextualType) || unknownType;
                        return maybeTypeOfKind(constraint, 4 /* String */) && maybeTypeOfKind(candidateType, 128 /* StringLiteral */) || maybeTypeOfKind(constraint, 8 /* Number */) && maybeTypeOfKind(candidateType, 256 /* NumberLiteral */) || maybeTypeOfKind(constraint, 64 /* BigInt */) && maybeTypeOfKind(candidateType, 2048 /* BigIntLiteral */) || maybeTypeOfKind(constraint, 4096 /* ESSymbol */) && maybeTypeOfKind(candidateType, 8192 /* UniqueESSymbol */) || isLiteralOfContextualType(candidateType, constraint);
                    }
                    return !!(contextualType.flags & (128 /* StringLiteral */ | 4194304 /* Index */ | 134217728 /* TemplateLiteral */ | 268435456 /* StringMapping */) && maybeTypeOfKind(candidateType, 128 /* StringLiteral */) || contextualType.flags & 256 /* NumberLiteral */ && maybeTypeOfKind(candidateType, 256 /* NumberLiteral */) || contextualType.flags & 2048 /* BigIntLiteral */ && maybeTypeOfKind(candidateType, 2048 /* BigIntLiteral */) || contextualType.flags & 512 /* BooleanLiteral */ && maybeTypeOfKind(candidateType, 512 /* BooleanLiteral */) || contextualType.flags & 8192 /* UniqueESSymbol */ && maybeTypeOfKind(candidateType, 8192 /* UniqueESSymbol */));
                }
                return false;
            }
            function isConstContext(node) {
                const parent2 = node.parent;
                return isAssertionExpression(parent2) && isConstTypeReference(parent2.type) || isJSDocTypeAssertion(parent2) && isConstTypeReference(getJSDocTypeAssertionType(parent2)) || isValidConstAssertionArgument(node) && isConstTypeVariable(getContextualType2(node, 0 /* None */)) || (isParenthesizedExpression(parent2) || isArrayLiteralExpression(parent2) || isSpreadElement(parent2)) && isConstContext(parent2) || (isPropertyAssignment(parent2) || isShorthandPropertyAssignment(parent2) || isTemplateSpan(parent2)) && isConstContext(parent2.parent);
            }
            function checkExpressionForMutableLocation(node, checkMode, forceTuple) {
                const type = checkExpression(node, checkMode, forceTuple);
                return isConstContext(node) || isCommonJsExportedExpression(node) ? getRegularTypeOfLiteralType(type) : isTypeAssertion(node) ? type : getWidenedLiteralLikeTypeForContextualType(type, instantiateContextualType(getContextualType2(node, 
                /*contextFlags*/
                void 0), node, 
                /*contextFlags*/
                void 0));
            }
            function checkPropertyAssignment(node, checkMode) {
                if (node.name.kind === 167 /* ComputedPropertyName */) {
                    checkComputedPropertyName(node.name);
                }
                return checkExpressionForMutableLocation(node.initializer, checkMode);
            }
            function checkObjectLiteralMethod(node, checkMode) {
                checkGrammarMethod(node);
                if (node.name.kind === 167 /* ComputedPropertyName */) {
                    checkComputedPropertyName(node.name);
                }
                const uninstantiatedType = checkFunctionExpressionOrObjectLiteralMethod(node, checkMode);
                return instantiateTypeWithSingleGenericCallSignature(node, uninstantiatedType, checkMode);
            }
            function instantiateTypeWithSingleGenericCallSignature(node, type, checkMode) {
                if (checkMode && checkMode & (2 /* Inferential */ | 8 /* SkipGenericFunctions */)) {
                    const callSignature = getSingleSignature(type, 0 /* Call */, 
                    /*allowMembers*/
                    true);
                    const constructSignature = getSingleSignature(type, 1 /* Construct */, 
                    /*allowMembers*/
                    true);
                    const signature = callSignature || constructSignature;
                    if (signature && signature.typeParameters) {
                        const contextualType = getApparentTypeOfContextualType(node, 2 /* NoConstraints */);
                        if (contextualType) {
                            const contextualSignature = getSingleSignature(getNonNullableType(contextualType), callSignature ? 0 /* Call */ : 1 /* Construct */, 
                            /*allowMembers*/
                            false);
                            if (contextualSignature && !contextualSignature.typeParameters) {
                                if (checkMode & 8 /* SkipGenericFunctions */) {
                                    skippedGenericFunction(node, checkMode);
                                    return anyFunctionType;
                                }
                                const context = getInferenceContext(node);
                                const returnType = context.signature && getReturnTypeOfSignature(context.signature);
                                const returnSignature = returnType && getSingleCallOrConstructSignature(returnType);
                                if (returnSignature && !returnSignature.typeParameters && !every(context.inferences, hasInferenceCandidates)) {
                                    const uniqueTypeParameters = getUniqueTypeParameters(context, signature.typeParameters);
                                    const instantiatedSignature = getSignatureInstantiationWithoutFillingInTypeArguments(signature, uniqueTypeParameters);
                                    const inferences = map(context.inferences, (info) => createInferenceInfo(info.typeParameter));
                                    applyToParameterTypes(instantiatedSignature, contextualSignature, (source, target) => {
                                        inferTypes(inferences, source, target, 
                                        /*priority*/
                                        0, 
                                        /*contravariant*/
                                        true);
                                    });
                                    if (some(inferences, hasInferenceCandidates)) {
                                        applyToReturnTypes(instantiatedSignature, contextualSignature, (source, target) => {
                                            inferTypes(inferences, source, target);
                                        });
                                        if (!hasOverlappingInferences(context.inferences, inferences)) {
                                            mergeInferences(context.inferences, inferences);
                                            context.inferredTypeParameters = concatenate(context.inferredTypeParameters, uniqueTypeParameters);
                                            return getOrCreateTypeFromSignature(instantiatedSignature);
                                        }
                                    }
                                }
                                return getOrCreateTypeFromSignature(instantiateSignatureInContextOf(signature, contextualSignature, context));
                            }
                        }
                    }
                }
                return type;
            }
            function skippedGenericFunction(node, checkMode) {
                if (checkMode & 2 /* Inferential */) {
                    const context = getInferenceContext(node);
                    context.flags |= 4 /* SkippedGenericFunction */;
                }
            }
            function hasInferenceCandidates(info) {
                return !!(info.candidates || info.contraCandidates);
            }
            function hasInferenceCandidatesOrDefault(info) {
                return !!(info.candidates || info.contraCandidates || hasTypeParameterDefault(info.typeParameter));
            }
            function hasOverlappingInferences(a, b) {
                for (let i = 0; i < a.length; i++) {
                    if (hasInferenceCandidates(a[i]) && hasInferenceCandidates(b[i])) {
                        return true;
                    }
                }
                return false;
            }
            function mergeInferences(target, source) {
                for (let i = 0; i < target.length; i++) {
                    if (!hasInferenceCandidates(target[i]) && hasInferenceCandidates(source[i])) {
                        target[i] = source[i];
                    }
                }
            }
            function getUniqueTypeParameters(context, typeParameters) {
                const result = [];
                let oldTypeParameters;
                let newTypeParameters;
                for (const tp of typeParameters) {
                    const name = tp.symbol.escapedName;
                    if (hasTypeParameterByName(context.inferredTypeParameters, name) || hasTypeParameterByName(result, name)) {
                        const newName = getUniqueTypeParameterName(concatenate(context.inferredTypeParameters, result), name);
                        const symbol = createSymbol(262144 /* TypeParameter */, newName);
                        const newTypeParameter = createTypeParameter(symbol);
                        newTypeParameter.target = tp;
                        oldTypeParameters = append(oldTypeParameters, tp);
                        newTypeParameters = append(newTypeParameters, newTypeParameter);
                        result.push(newTypeParameter);
                    }
                    else {
                        result.push(tp);
                    }
                }
                if (newTypeParameters) {
                    const mapper = createTypeMapper(oldTypeParameters, newTypeParameters);
                    for (const tp of newTypeParameters) {
                        tp.mapper = mapper;
                    }
                }
                return result;
            }
            function hasTypeParameterByName(typeParameters, name) {
                return some(typeParameters, (tp) => tp.symbol.escapedName === name);
            }
            function getUniqueTypeParameterName(typeParameters, baseName) {
                let len = baseName.length;
                while (len > 1 && baseName.charCodeAt(len - 1) >= 48 /* _0 */ && baseName.charCodeAt(len - 1) <= 57 /* _9 */)
                    len--;
                const s = baseName.slice(0, len);
                for (let index = 1; true; index++) {
                    const augmentedName = s + index;
                    if (!hasTypeParameterByName(typeParameters, augmentedName)) {
                        return augmentedName;
                    }
                }
            }
            function getReturnTypeOfSingleNonGenericCallSignature(funcType) {
                const signature = getSingleCallSignature(funcType);
                if (signature && !signature.typeParameters) {
                    return getReturnTypeOfSignature(signature);
                }
            }
            function getReturnTypeOfSingleNonGenericSignatureOfCallChain(expr) {
                const funcType = checkExpression(expr.expression);
                const nonOptionalType = getOptionalExpressionType(funcType, expr.expression);
                const returnType = getReturnTypeOfSingleNonGenericCallSignature(funcType);
                return returnType && propagateOptionalTypeMarker(returnType, expr, nonOptionalType !== funcType);
            }
            function getTypeOfExpression(node) {
                const quickType = getQuickTypeOfExpression(node);
                if (quickType) {
                    return quickType;
                }
                if (node.flags & 268435456 /* TypeCached */ && flowTypeCache) {
                    const cachedType = flowTypeCache[getNodeId(node)];
                    if (cachedType) {
                        return cachedType;
                    }
                }
                const startInvocationCount = flowInvocationCount;
                const type = checkExpression(node, 64 /* TypeOnly */);
                if (flowInvocationCount !== startInvocationCount) {
                    const cache = flowTypeCache || (flowTypeCache = []);
                    cache[getNodeId(node)] = type;
                    setNodeFlags(node, node.flags | 268435456 /* TypeCached */);
                }
                return type;
            }
            function getQuickTypeOfExpression(node) {
                let expr = skipParentheses(node, 
                /*excludeJSDocTypeAssertions*/
                true);
                if (isJSDocTypeAssertion(expr)) {
                    const type = getJSDocTypeAssertionType(expr);
                    if (!isConstTypeReference(type)) {
                        return getTypeFromTypeNode(type);
                    }
                }
                expr = skipParentheses(node);
                if (isAwaitExpression(expr)) {
                    const type = getQuickTypeOfExpression(expr.expression);
                    return type ? getAwaitedType(type) : void 0;
                }
                if (isCallExpression(expr) && expr.expression.kind !== 108 /* SuperKeyword */ && !isRequireCall(expr, 
                /*requireStringLiteralLikeArgument*/
                true) && !isSymbolOrSymbolForCall(expr)) {
                    return isCallChain(expr) ? getReturnTypeOfSingleNonGenericSignatureOfCallChain(expr) : getReturnTypeOfSingleNonGenericCallSignature(checkNonNullExpression(expr.expression));
                }
                else if (isAssertionExpression(expr) && !isConstTypeReference(expr.type)) {
                    return getTypeFromTypeNode(expr.type);
                }
                else if (isLiteralExpression(node) || isBooleanLiteral(node)) {
                    return checkExpression(node);
                }
                return void 0;
            }
            function getContextFreeTypeOfExpression(node) {
                const links = getNodeLinks(node);
                if (links.contextFreeType) {
                    return links.contextFreeType;
                }
                pushContextualType(node, anyType, 
                /*isCache*/
                false);
                const type = links.contextFreeType = checkExpression(node, 4 /* SkipContextSensitive */);
                popContextualType();
                return type;
            }
            function checkExpression(node, checkMode, forceTuple) {
                var _a, _b;
                (_a = tracing) == null ? void 0 : _a.push(tracing.Phase.Check, "checkExpression", { kind: node.kind, pos: node.pos, end: node.end, path: node.tracingPath });
                const saveCurrentNode = currentNode;
                currentNode = node;
                instantiationCount = 0;
                const uninstantiatedType = checkExpressionWorker(node, checkMode, forceTuple);
                const type = instantiateTypeWithSingleGenericCallSignature(node, uninstantiatedType, checkMode);
                if (isConstEnumObjectType(type)) {
                    checkConstEnumAccess(node, type);
                }
                currentNode = saveCurrentNode;
                (_b = tracing) == null ? void 0 : _b.pop();
                return type;
            }
            function checkConstEnumAccess(node, type) {
                const ok = node.parent.kind === 211 /* PropertyAccessExpression */ && node.parent.expression === node || node.parent.kind === 212 /* ElementAccessExpression */ && node.parent.expression === node || ((node.kind === 80 /* Identifier */ || node.kind === 166 /* QualifiedName */) && isInRightSideOfImportOrExportAssignment(node) || node.parent.kind === 186 /* TypeQuery */ && node.parent.exprName === node) || node.parent.kind === 281 /* ExportSpecifier */;
                if (!ok) {
                    error2(node, Diagnostics.const_enums_can_only_be_used_in_property_or_index_access_expressions_or_the_right_hand_side_of_an_import_declaration_or_export_assignment_or_type_query);
                }
                if (getIsolatedModules(compilerOptions)) {
                    Debug.assert(!!(type.symbol.flags & 128 /* ConstEnum */));
                    const constEnumDeclaration = type.symbol.valueDeclaration;
                    if (constEnumDeclaration.flags & 33554432 /* Ambient */ && !isValidTypeOnlyAliasUseSite(node)) {
                        error2(node, Diagnostics.Cannot_access_ambient_const_enums_when_0_is_enabled, isolatedModulesLikeFlagName);
                    }
                }
            }
            function checkParenthesizedExpression(node, checkMode) {
                if (hasJSDocNodes(node)) {
                    if (isJSDocSatisfiesExpression(node)) {
                        return checkSatisfiesExpressionWorker(node.expression, getJSDocSatisfiesExpressionType(node), checkMode);
                    }
                    if (isJSDocTypeAssertion(node)) {
                        return checkAssertionWorker(node, checkMode);
                    }
                }
                return checkExpression(node.expression, checkMode);
            }
            function checkExpressionWorker(node, checkMode, forceTuple) {
                const kind = node.kind;
                if (cancellationToken) {
                    switch (kind) {
                        case 231 /* ClassExpression */:
                        case 218 /* FunctionExpression */:
                        case 219 /* ArrowFunction */:
                            cancellationToken.throwIfCancellationRequested();
                    }
                }
                switch (kind) {
                    case 80 /* Identifier */:
                        return checkIdentifier(node, checkMode);
                    case 81 /* PrivateIdentifier */:
                        return checkPrivateIdentifierExpression(node);
                    case 110 /* ThisKeyword */:
                        return checkThisExpression(node);
                    case 108 /* SuperKeyword */:
                        return checkSuperExpression(node);
                    case 106 /* NullKeyword */:
                        return nullWideningType;
                    case 15 /* NoSubstitutionTemplateLiteral */:
                    case 11 /* StringLiteral */:
                        return hasSkipDirectInferenceFlag(node) ? blockedStringType : getFreshTypeOfLiteralType(getStringLiteralType(node.text));
                    case 9 /* NumericLiteral */:
                        checkGrammarNumericLiteral(node);
                        return getFreshTypeOfLiteralType(getNumberLiteralType(+node.text));
                    case 10 /* BigIntLiteral */:
                        checkGrammarBigIntLiteral(node);
                        return getFreshTypeOfLiteralType(getBigIntLiteralType({
                            negative: false,
                            base10Value: parsePseudoBigInt(node.text)
                        }));
                    case 112 /* TrueKeyword */:
                        return trueType;
                    case 97 /* FalseKeyword */:
                        return falseType;
                    case 228 /* TemplateExpression */:
                        return checkTemplateExpression(node);
                    case 14 /* RegularExpressionLiteral */:
                        return globalRegExpType;
                    case 209 /* ArrayLiteralExpression */:
                        return checkArrayLiteral(node, checkMode, forceTuple);
                    case 210 /* ObjectLiteralExpression */:
                        return checkObjectLiteral(node, checkMode);
                    case 211 /* PropertyAccessExpression */:
                        return checkPropertyAccessExpression(node, checkMode);
                    case 166 /* QualifiedName */:
                        return checkQualifiedName(node, checkMode);
                    case 212 /* ElementAccessExpression */:
                        return checkIndexedAccess(node, checkMode);
                    case 213 /* CallExpression */:
                        if (node.expression.kind === 102 /* ImportKeyword */) {
                            return checkImportCallExpression(node);
                        }
                    case 214 /* NewExpression */:
                        return checkCallExpression(node, checkMode);
                    case 215 /* TaggedTemplateExpression */:
                        return checkTaggedTemplateExpression(node);
                    case 217 /* ParenthesizedExpression */:
                        return checkParenthesizedExpression(node, checkMode);
                    case 231 /* ClassExpression */:
                        return checkClassExpression(node);
                    case 218 /* FunctionExpression */:
                    case 219 /* ArrowFunction */:
                        return checkFunctionExpressionOrObjectLiteralMethod(node, checkMode);
                    case 221 /* TypeOfExpression */:
                        return checkTypeOfExpression(node);
                    case 216 /* TypeAssertionExpression */:
                    case 234 /* AsExpression */:
                        return checkAssertion(node, checkMode);
                    case 235 /* NonNullExpression */:
                        return checkNonNullAssertion(node);
                    case 233 /* ExpressionWithTypeArguments */:
                        return checkExpressionWithTypeArguments(node);
                    case 238 /* SatisfiesExpression */:
                        return checkSatisfiesExpression(node);
                    case 236 /* MetaProperty */:
                        return checkMetaProperty(node);
                    case 220 /* DeleteExpression */:
                        return checkDeleteExpression(node);
                    case 222 /* VoidExpression */:
                        return checkVoidExpression(node);
                    case 223 /* AwaitExpression */:
                        return checkAwaitExpression(node);
                    case 224 /* PrefixUnaryExpression */:
                        return checkPrefixUnaryExpression(node);
                    case 225 /* PostfixUnaryExpression */:
                        return checkPostfixUnaryExpression(node);
                    case 226 /* BinaryExpression */:
                        return checkBinaryExpression(node, checkMode);
                    case 227 /* ConditionalExpression */:
                        return checkConditionalExpression(node, checkMode);
                    case 230 /* SpreadElement */:
                        return checkSpreadExpression(node, checkMode);
                    case 232 /* OmittedExpression */:
                        return undefinedWideningType;
                    case 229 /* YieldExpression */:
                        return checkYieldExpression(node);
                    case 237 /* SyntheticExpression */:
                        return checkSyntheticExpression(node);
                    case 294 /* JsxExpression */:
                        return checkJsxExpression(node, checkMode);
                    case 284 /* JsxElement */:
                        return checkJsxElement(node, checkMode);
                    case 285 /* JsxSelfClosingElement */:
                        return checkJsxSelfClosingElement(node, checkMode);
                    case 288 /* JsxFragment */:
                        return checkJsxFragment(node);
                    case 292 /* JsxAttributes */:
                        return checkJsxAttributes(node, checkMode);
                    case 286 /* JsxOpeningElement */:
                        Debug.fail("Shouldn't ever directly check a JsxOpeningElement");
                }
                return errorType;
            }
            function checkTypeParameter(node) {
                checkGrammarModifiers(node);
                if (node.expression) {
                    grammarErrorOnFirstToken(node.expression, Diagnostics.Type_expected);
                }
                checkSourceElement(node.constraint);
                checkSourceElement(node.default);
                const typeParameter = getDeclaredTypeOfTypeParameter(getSymbolOfDeclaration(node));
                getBaseConstraintOfType(typeParameter);
                if (!hasNonCircularTypeParameterDefault(typeParameter)) {
                    error2(node.default, Diagnostics.Type_parameter_0_has_a_circular_default, typeToString(typeParameter));
                }
                const constraintType = getConstraintOfTypeParameter(typeParameter);
                const defaultType = getDefaultFromTypeParameter(typeParameter);
                if (constraintType && defaultType) {
                    checkTypeAssignableTo(defaultType, getTypeWithThisArgument(instantiateType(constraintType, makeUnaryTypeMapper(typeParameter, defaultType)), defaultType), node.default, Diagnostics.Type_0_does_not_satisfy_the_constraint_1);
                }
                checkNodeDeferred(node);
                addLazyDiagnostic(() => checkTypeNameIsReserved(node.name, Diagnostics.Type_parameter_name_cannot_be_0));
            }
            function checkTypeParameterDeferred(node) {
                var _a, _b;
                if (isInterfaceDeclaration(node.parent) || isClassLike(node.parent) || isTypeAliasDeclaration(node.parent)) {
                    const typeParameter = getDeclaredTypeOfTypeParameter(getSymbolOfDeclaration(node));
                    const modifiers = getTypeParameterModifiers(typeParameter) & (8192 /* In */ | 16384 /* Out */);
                    if (modifiers) {
                        const symbol = getSymbolOfDeclaration(node.parent);
                        if (isTypeAliasDeclaration(node.parent) && !(getObjectFlags(getDeclaredTypeOfSymbol(symbol)) & (4 /* Reference */ | 16 /* Anonymous */ | 32 /* Mapped */))) {
                            error2(node, Diagnostics.Variance_annotations_are_only_supported_in_type_aliases_for_object_function_constructor_and_mapped_types);
                        }
                        else if (modifiers === 8192 /* In */ || modifiers === 16384 /* Out */) {
                            (_a = tracing) == null ? void 0 : _a.push(tracing.Phase.CheckTypes, "checkTypeParameterDeferred", { parent: getTypeId(getDeclaredTypeOfSymbol(symbol)), id: getTypeId(typeParameter) });
                            const source = createMarkerType(symbol, typeParameter, modifiers === 16384 /* Out */ ? markerSubTypeForCheck : markerSuperTypeForCheck);
                            const target = createMarkerType(symbol, typeParameter, modifiers === 16384 /* Out */ ? markerSuperTypeForCheck : markerSubTypeForCheck);
                            const saveVarianceTypeParameter = typeParameter;
                            varianceTypeParameter = typeParameter;
                            checkTypeAssignableTo(source, target, node, Diagnostics.Type_0_is_not_assignable_to_type_1_as_implied_by_variance_annotation);
                            varianceTypeParameter = saveVarianceTypeParameter;
                            (_b = tracing) == null ? void 0 : _b.pop();
                        }
                    }
                }
            }
            function checkParameter(node) {
                checkGrammarModifiers(node);
                checkVariableLikeDeclaration(node);
                const func = getContainingFunction(node);
                if (hasSyntacticModifier(node, 31 /* ParameterPropertyModifier */)) {
                    if (!(func.kind === 176 /* Constructor */ && nodeIsPresent(func.body))) {
                        error2(node, Diagnostics.A_parameter_property_is_only_allowed_in_a_constructor_implementation);
                    }
                    if (func.kind === 176 /* Constructor */ && isIdentifier(node.name) && node.name.escapedText === "constructor") {
                        error2(node.name, Diagnostics.constructor_cannot_be_used_as_a_parameter_property_name);
                    }
                }
                if (!node.initializer && isOptionalDeclaration(node) && isBindingPattern(node.name) && func.body) {
                    error2(node, Diagnostics.A_binding_pattern_parameter_cannot_be_optional_in_an_implementation_signature);
                }
                if (node.name && isIdentifier(node.name) && (node.name.escapedText === "this" || node.name.escapedText === "new")) {
                    if (func.parameters.indexOf(node) !== 0) {
                        error2(node, Diagnostics.A_0_parameter_must_be_the_first_parameter, node.name.escapedText);
                    }
                    if (func.kind === 176 /* Constructor */ || func.kind === 180 /* ConstructSignature */ || func.kind === 185 /* ConstructorType */) {
                        error2(node, Diagnostics.A_constructor_cannot_have_a_this_parameter);
                    }
                    if (func.kind === 219 /* ArrowFunction */) {
                        error2(node, Diagnostics.An_arrow_function_cannot_have_a_this_parameter);
                    }
                    if (func.kind === 177 /* GetAccessor */ || func.kind === 178 /* SetAccessor */) {
                        error2(node, Diagnostics.get_and_set_accessors_cannot_declare_this_parameters);
                    }
                }
                if (node.dotDotDotToken && !isBindingPattern(node.name) && !isTypeAssignableTo(getReducedType(getTypeOfSymbol(node.symbol)), anyReadonlyArrayType)) {
                    error2(node, Diagnostics.A_rest_parameter_must_be_of_an_array_type);
                }
            }
            function checkTypePredicate(node) {
                const parent2 = getTypePredicateParent(node);
                if (!parent2) {
                    error2(node, Diagnostics.A_type_predicate_is_only_allowed_in_return_type_position_for_functions_and_methods);
                    return;
                }
                const signature = getSignatureFromDeclaration(parent2);
                const typePredicate = getTypePredicateOfSignature(signature);
                if (!typePredicate) {
                    return;
                }
                checkSourceElement(node.type);
                const { parameterName } = node;
                if (typePredicate.kind === 0 /* This */ || typePredicate.kind === 2 /* AssertsThis */) {
                    getTypeFromThisTypeNode(parameterName);
                }
                else {
                    if (typePredicate.parameterIndex >= 0) {
                        if (signatureHasRestParameter(signature) && typePredicate.parameterIndex === signature.parameters.length - 1) {
                            error2(parameterName, Diagnostics.A_type_predicate_cannot_reference_a_rest_parameter);
                        }
                        else {
                            if (typePredicate.type) {
                                const leadingError = () => chainDiagnosticMessages(
                                /*details*/
                                void 0, Diagnostics.A_type_predicate_s_type_must_be_assignable_to_its_parameter_s_type);
                                checkTypeAssignableTo(typePredicate.type, getTypeOfSymbol(signature.parameters[typePredicate.parameterIndex]), node.type, 
                                /*headMessage*/
                                void 0, leadingError);
                            }
                        }
                    }
                    else if (parameterName) {
                        let hasReportedError = false;
                        for (const { name } of parent2.parameters) {
                            if (isBindingPattern(name) && checkIfTypePredicateVariableIsDeclaredInBindingPattern(name, parameterName, typePredicate.parameterName)) {
                                hasReportedError = true;
                                break;
                            }
                        }
                        if (!hasReportedError) {
                            error2(node.parameterName, Diagnostics.Cannot_find_parameter_0, typePredicate.parameterName);
                        }
                    }
                }
            }
            function getTypePredicateParent(node) {
                switch (node.parent.kind) {
                    case 219 /* ArrowFunction */:
                    case 179 /* CallSignature */:
                    case 262 /* FunctionDeclaration */:
                    case 218 /* FunctionExpression */:
                    case 184 /* FunctionType */:
                    case 174 /* MethodDeclaration */:
                    case 173 /* MethodSignature */:
                        const parent2 = node.parent;
                        if (node === parent2.type) {
                            return parent2;
                        }
                }
            }
            function checkIfTypePredicateVariableIsDeclaredInBindingPattern(pattern, predicateVariableNode, predicateVariableName) {
                for (const element of pattern.elements) {
                    if (isOmittedExpression(element)) {
                        continue;
                    }
                    const name = element.name;
                    if (name.kind === 80 /* Identifier */ && name.escapedText === predicateVariableName) {
                        error2(predicateVariableNode, Diagnostics.A_type_predicate_cannot_reference_element_0_in_a_binding_pattern, predicateVariableName);
                        return true;
                    }
                    else if (name.kind === 207 /* ArrayBindingPattern */ || name.kind === 206 /* ObjectBindingPattern */) {
                        if (checkIfTypePredicateVariableIsDeclaredInBindingPattern(name, predicateVariableNode, predicateVariableName)) {
                            return true;
                        }
                    }
                }
            }
            function checkSignatureDeclaration(node) {
                if (node.kind === 181 /* IndexSignature */) {
                    checkGrammarIndexSignature(node);
                }
                else if (node.kind === 184 /* FunctionType */ || node.kind === 262 /* FunctionDeclaration */ || node.kind === 185 /* ConstructorType */ || node.kind === 179 /* CallSignature */ || node.kind === 176 /* Constructor */ || node.kind === 180 /* ConstructSignature */) {
                    checkGrammarFunctionLikeDeclaration(node);
                }
                const functionFlags = getFunctionFlags(node);
                if (!(functionFlags & 4 /* Invalid */)) {
                    if ((functionFlags & 3 /* AsyncGenerator */) === 3 /* AsyncGenerator */ && languageVersion < 99 /* ESNext */) {
                        checkExternalEmitHelpers(node, 6144 /* AsyncGeneratorIncludes */);
                    }
                    if ((functionFlags & 3 /* AsyncGenerator */) === 2 /* Async */ && languageVersion < 4 /* ES2017 */) {
                        checkExternalEmitHelpers(node, 64 /* Awaiter */);
                    }
                    if ((functionFlags & 3 /* AsyncGenerator */) !== 0 /* Normal */ && languageVersion < 2 /* ES2015 */) {
                        checkExternalEmitHelpers(node, 128 /* Generator */);
                    }
                }
                checkTypeParameters(getEffectiveTypeParameterDeclarations(node));
                checkUnmatchedJSDocParameters(node);
                forEach(node.parameters, checkParameter);
                if (node.type) {
                    checkSourceElement(node.type);
                }
                addLazyDiagnostic(checkSignatureDeclarationDiagnostics);
                function checkSignatureDeclarationDiagnostics() {
                    checkCollisionWithArgumentsInGeneratedCode(node);
                    let returnTypeNode = getEffectiveReturnTypeNode(node);
                    let returnTypeErrorLocation = returnTypeNode;
                    if (isInJSFile(node)) {
                        const typeTag = getJSDocTypeTag(node);
                        if (typeTag && typeTag.typeExpression && isTypeReferenceNode(typeTag.typeExpression.type)) {
                            const signature = getSingleCallSignature(getTypeFromTypeNode(typeTag.typeExpression));
                            if (signature && signature.declaration) {
                                returnTypeNode = getEffectiveReturnTypeNode(signature.declaration);
                                returnTypeErrorLocation = typeTag.typeExpression.type;
                            }
                        }
                    }
                    if (noImplicitAny && !returnTypeNode) {
                        switch (node.kind) {
                            case 180 /* ConstructSignature */:
                                error2(node, Diagnostics.Construct_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type);
                                break;
                            case 179 /* CallSignature */:
                                error2(node, Diagnostics.Call_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type);
                                break;
                        }
                    }
                    if (returnTypeNode && returnTypeErrorLocation) {
                        const functionFlags2 = getFunctionFlags(node);
                        if ((functionFlags2 & (4 /* Invalid */ | 1 /* Generator */)) === 1 /* Generator */) {
                            const returnType = getTypeFromTypeNode(returnTypeNode);
                            if (returnType === voidType) {
                                error2(returnTypeErrorLocation, Diagnostics.A_generator_cannot_have_a_void_type_annotation);
                            }
                            else {
                                checkGeneratorInstantiationAssignabilityToReturnType(returnType, functionFlags2, returnTypeErrorLocation);
                            }
                        }
                        else if ((functionFlags2 & 3 /* AsyncGenerator */) === 2 /* Async */) {
                            checkAsyncFunctionReturnType(node, returnTypeNode, returnTypeErrorLocation);
                        }
                    }
                    if (node.kind !== 181 /* IndexSignature */ && node.kind !== 324 /* JSDocFunctionType */) {
                        registerForUnusedIdentifiersCheck(node);
                    }
                }
            }
            function checkGeneratorInstantiationAssignabilityToReturnType(returnType, functionFlags, errorNode) {
                const generatorYieldType = getIterationTypeOfGeneratorFunctionReturnType(0 /* Yield */, returnType, (functionFlags & 2 /* Async */) !== 0) || anyType;
                const generatorReturnType = getIterationTypeOfGeneratorFunctionReturnType(1 /* Return */, returnType, (functionFlags & 2 /* Async */) !== 0) || generatorYieldType;
                const generatorNextType = getIterationTypeOfGeneratorFunctionReturnType(2 /* Next */, returnType, (functionFlags & 2 /* Async */) !== 0) || unknownType;
                const generatorInstantiation = createGeneratorReturnType(generatorYieldType, generatorReturnType, generatorNextType, !!(functionFlags & 2 /* Async */));
                return checkTypeAssignableTo(generatorInstantiation, returnType, errorNode);
            }
            function checkClassForDuplicateDeclarations(node) {
                const instanceNames = /* @__PURE__ */ new Map();
                const staticNames = /* @__PURE__ */ new Map();
                const privateIdentifiers = /* @__PURE__ */ new Map();
                for (const member of node.members) {
                    if (member.kind === 176 /* Constructor */) {
                        for (const param of member.parameters) {
                            if (isParameterPropertyDeclaration(param, member) && !isBindingPattern(param.name)) {
                                addName(instanceNames, param.name, param.name.escapedText, 3 /* GetOrSetAccessor */);
                            }
                        }
                    }
                    else {
                        const isStaticMember = isStatic(member);
                        const name = member.name;
                        if (!name) {
                            continue;
                        }
                        const isPrivate = isPrivateIdentifier(name);
                        const privateStaticFlags = isPrivate && isStaticMember ? 16 /* PrivateStatic */ : 0;
                        const names = isPrivate ? privateIdentifiers : isStaticMember ? staticNames : instanceNames;
                        const memberName = name && getEffectivePropertyNameForPropertyNameNode(name);
                        if (memberName) {
                            switch (member.kind) {
                                case 177 /* GetAccessor */:
                                    addName(names, name, memberName, 1 /* GetAccessor */ | privateStaticFlags);
                                    break;
                                case 178 /* SetAccessor */:
                                    addName(names, name, memberName, 2 /* SetAccessor */ | privateStaticFlags);
                                    break;
                                case 172 /* PropertyDeclaration */:
                                    addName(names, name, memberName, 3 /* GetOrSetAccessor */ | privateStaticFlags);
                                    break;
                                case 174 /* MethodDeclaration */:
                                    addName(names, name, memberName, 8 /* Method */ | privateStaticFlags);
                                    break;
                            }
                        }
                    }
                }
                function addName(names, location, name, meaning) {
                    const prev = names.get(name);
                    if (prev) {
                        if ((prev & 16 /* PrivateStatic */) !== (meaning & 16 /* PrivateStatic */)) {
                            error2(location, Diagnostics.Duplicate_identifier_0_Static_and_instance_elements_cannot_share_the_same_private_name, getTextOfNode(location));
                        }
                        else {
                            const prevIsMethod = !!(prev & 8 /* Method */);
                            const isMethod = !!(meaning & 8 /* Method */);
                            if (prevIsMethod || isMethod) {
                                if (prevIsMethod !== isMethod) {
                                    error2(location, Diagnostics.Duplicate_identifier_0, getTextOfNode(location));
                                }
                            }
                            else if (prev & meaning & ~16 /* PrivateStatic */) {
                                error2(location, Diagnostics.Duplicate_identifier_0, getTextOfNode(location));
                            }
                            else {
                                names.set(name, prev | meaning);
                            }
                        }
                    }
                    else {
                        names.set(name, meaning);
                    }
                }
            }
            function checkClassForStaticPropertyNameConflicts(node) {
                for (const member of node.members) {
                    const memberNameNode = member.name;
                    const isStaticMember = isStatic(member);
                    if (isStaticMember && memberNameNode) {
                        const memberName = getEffectivePropertyNameForPropertyNameNode(memberNameNode);
                        switch (memberName) {
                            case "name":
                            case "length":
                            case "caller":
                            case "arguments":
                                if (useDefineForClassFields) {
                                    break;
                                }
                            case "prototype":
                                const message = Diagnostics.Static_property_0_conflicts_with_built_in_property_Function_0_of_constructor_function_1;
                                const className = getNameOfSymbolAsWritten(getSymbolOfDeclaration(node));
                                error2(memberNameNode, message, memberName, className);
                                break;
                        }
                    }
                }
            }
            function checkObjectTypeForDuplicateDeclarations(node) {
                const names = /* @__PURE__ */ new Map();
                for (const member of node.members) {
                    if (member.kind === 171 /* PropertySignature */) {
                        let memberName;
                        const name = member.name;
                        switch (name.kind) {
                            case 11 /* StringLiteral */:
                            case 9 /* NumericLiteral */:
                                memberName = name.text;
                                break;
                            case 80 /* Identifier */:
                                memberName = idText(name);
                                break;
                            default:
                                continue;
                        }
                        if (names.get(memberName)) {
                            error2(getNameOfDeclaration(member.symbol.valueDeclaration), Diagnostics.Duplicate_identifier_0, memberName);
                            error2(member.name, Diagnostics.Duplicate_identifier_0, memberName);
                        }
                        else {
                            names.set(memberName, true);
                        }
                    }
                }
            }
            function checkTypeForDuplicateIndexSignatures(node) {
                if (node.kind === 264 /* InterfaceDeclaration */) {
                    const nodeSymbol = getSymbolOfDeclaration(node);
                    if (nodeSymbol.declarations && nodeSymbol.declarations.length > 0 && nodeSymbol.declarations[0] !== node) {
                        return;
                    }
                }
                const indexSymbol = getIndexSymbol(getSymbolOfDeclaration(node));
                if (indexSymbol == null ? void 0 : indexSymbol.declarations) {
                    const indexSignatureMap = /* @__PURE__ */ new Map();
                    for (const declaration of indexSymbol.declarations) {
                        if (declaration.parameters.length === 1 && declaration.parameters[0].type) {
                            forEachType(getTypeFromTypeNode(declaration.parameters[0].type), (type) => {
                                const entry = indexSignatureMap.get(getTypeId(type));
                                if (entry) {
                                    entry.declarations.push(declaration);
                                }
                                else {
                                    indexSignatureMap.set(getTypeId(type), { type, declarations: [declaration] });
                                }
                            });
                        }
                    }
                    indexSignatureMap.forEach((entry) => {
                        if (entry.declarations.length > 1) {
                            for (const declaration of entry.declarations) {
                                error2(declaration, Diagnostics.Duplicate_index_signature_for_type_0, typeToString(entry.type));
                            }
                        }
                    });
                }
            }
            function checkPropertyDeclaration(node) {
                if (!checkGrammarModifiers(node) && !checkGrammarProperty(node))
                    checkGrammarComputedPropertyName(node.name);
                checkVariableLikeDeclaration(node);
                setNodeLinksForPrivateIdentifierScope(node);
                if (hasSyntacticModifier(node, 64 /* Abstract */) && node.kind === 172 /* PropertyDeclaration */ && node.initializer) {
                    error2(node, Diagnostics.Property_0_cannot_have_an_initializer_because_it_is_marked_abstract, declarationNameToString(node.name));
                }
            }
            function checkPropertySignature(node) {
                if (isPrivateIdentifier(node.name)) {
                    error2(node, Diagnostics.Private_identifiers_are_not_allowed_outside_class_bodies);
                }
                return checkPropertyDeclaration(node);
            }
            function checkMethodDeclaration(node) {
                if (!checkGrammarMethod(node))
                    checkGrammarComputedPropertyName(node.name);
                if (isMethodDeclaration(node) && node.asteriskToken && isIdentifier(node.name) && idText(node.name) === "constructor") {
                    error2(node.name, Diagnostics.Class_constructor_may_not_be_a_generator);
                }
                checkFunctionOrMethodDeclaration(node);
                if (hasSyntacticModifier(node, 64 /* Abstract */) && node.kind === 174 /* MethodDeclaration */ && node.body) {
                    error2(node, Diagnostics.Method_0_cannot_have_an_implementation_because_it_is_marked_abstract, declarationNameToString(node.name));
                }
                if (isPrivateIdentifier(node.name) && !getContainingClass(node)) {
                    error2(node, Diagnostics.Private_identifiers_are_not_allowed_outside_class_bodies);
                }
                setNodeLinksForPrivateIdentifierScope(node);
            }
            function setNodeLinksForPrivateIdentifierScope(node) {
                if (isPrivateIdentifier(node.name) && languageVersion < 99 /* ESNext */) {
                    for (let lexicalScope = getEnclosingBlockScopeContainer(node); !!lexicalScope; lexicalScope = getEnclosingBlockScopeContainer(lexicalScope)) {
                        getNodeLinks(lexicalScope).flags |= 1048576 /* ContainsClassWithPrivateIdentifiers */;
                    }
                    if (isClassExpression(node.parent)) {
                        const enclosingIterationStatement = getEnclosingIterationStatement(node.parent);
                        if (enclosingIterationStatement) {
                            getNodeLinks(node.name).flags |= 32768 /* BlockScopedBindingInLoop */;
                            getNodeLinks(enclosingIterationStatement).flags |= 4096 /* LoopWithCapturedBlockScopedBinding */;
                        }
                    }
                }
            }
            function checkClassStaticBlockDeclaration(node) {
                checkGrammarModifiers(node);
                forEachChild(node, checkSourceElement);
            }
            function checkConstructorDeclaration(node) {
                checkSignatureDeclaration(node);
                if (!checkGrammarConstructorTypeParameters(node))
                    checkGrammarConstructorTypeAnnotation(node);
                checkSourceElement(node.body);
                const symbol = getSymbolOfDeclaration(node);
                const firstDeclaration = getDeclarationOfKind(symbol, node.kind);
                if (node === firstDeclaration) {
                    checkFunctionOrConstructorSymbol(symbol);
                }
                if (nodeIsMissing(node.body)) {
                    return;
                }
                addLazyDiagnostic(checkConstructorDeclarationDiagnostics);
                return;
                function isInstancePropertyWithInitializerOrPrivateIdentifierProperty(n) {
                    if (isPrivateIdentifierClassElementDeclaration(n)) {
                        return true;
                    }
                    return n.kind === 172 /* PropertyDeclaration */ && !isStatic(n) && !!n.initializer;
                }
                function checkConstructorDeclarationDiagnostics() {
                    const containingClassDecl = node.parent;
                    if (getClassExtendsHeritageElement(containingClassDecl)) {
                        captureLexicalThis(node.parent, containingClassDecl);
                        const classExtendsNull = classDeclarationExtendsNull(containingClassDecl);
                        const superCall = findFirstSuperCall(node.body);
                        if (superCall) {
                            if (classExtendsNull) {
                                error2(superCall, Diagnostics.A_constructor_cannot_contain_a_super_call_when_its_class_extends_null);
                            }
                            const superCallShouldBeRootLevel = !emitStandardClassFields && (some(node.parent.members, isInstancePropertyWithInitializerOrPrivateIdentifierProperty) || some(node.parameters, (p) => hasSyntacticModifier(p, 31 /* ParameterPropertyModifier */)));
                            if (superCallShouldBeRootLevel) {
                                if (!superCallIsRootLevelInConstructor(superCall, node.body)) {
                                    error2(superCall, Diagnostics.A_super_call_must_be_a_root_level_statement_within_a_constructor_of_a_derived_class_that_contains_initialized_properties_parameter_properties_or_private_identifiers);
                                }
                                else {
                                    let superCallStatement;
                                    for (const statement of node.body.statements) {
                                        if (isExpressionStatement(statement) && isSuperCall(skipOuterExpressions(statement.expression))) {
                                            superCallStatement = statement;
                                            break;
                                        }
                                        if (nodeImmediatelyReferencesSuperOrThis(statement)) {
                                            break;
                                        }
                                    }
                                    if (superCallStatement === void 0) {
                                        error2(node, Diagnostics.A_super_call_must_be_the_first_statement_in_the_constructor_to_refer_to_super_or_this_when_a_derived_class_contains_initialized_properties_parameter_properties_or_private_identifiers);
                                    }
                                }
                            }
                        }
                        else if (!classExtendsNull) {
                            error2(node, Diagnostics.Constructors_for_derived_classes_must_contain_a_super_call);
                        }
                    }
                }
            }
            function superCallIsRootLevelInConstructor(superCall, body) {
                const superCallParent = walkUpParenthesizedExpressions(superCall.parent);
                return isExpressionStatement(superCallParent) && superCallParent.parent === body;
            }
            function nodeImmediatelyReferencesSuperOrThis(node) {
                if (node.kind === 108 /* SuperKeyword */ || node.kind === 110 /* ThisKeyword */) {
                    return true;
                }
                if (isThisContainerOrFunctionBlock(node)) {
                    return false;
                }
                return !!forEachChild(node, nodeImmediatelyReferencesSuperOrThis);
            }
            function checkAccessorDeclaration(node) {
                if (isIdentifier(node.name) && idText(node.name) === "constructor" && isClassLike(node.parent)) {
                    error2(node.name, Diagnostics.Class_constructor_may_not_be_an_accessor);
                }
                addLazyDiagnostic(checkAccessorDeclarationDiagnostics);
                checkSourceElement(node.body);
                setNodeLinksForPrivateIdentifierScope(node);
                function checkAccessorDeclarationDiagnostics() {
                    if (!checkGrammarFunctionLikeDeclaration(node) && !checkGrammarAccessor(node))
                        checkGrammarComputedPropertyName(node.name);
                    checkDecorators(node);
                    checkSignatureDeclaration(node);
                    if (node.kind === 177 /* GetAccessor */) {
                        if (!(node.flags & 33554432 /* Ambient */) && nodeIsPresent(node.body) && node.flags & 512 /* HasImplicitReturn */) {
                            if (!(node.flags & 1024 /* HasExplicitReturn */)) {
                                error2(node.name, Diagnostics.A_get_accessor_must_return_a_value);
                            }
                        }
                    }
                    if (node.name.kind === 167 /* ComputedPropertyName */) {
                        checkComputedPropertyName(node.name);
                    }
                    if (hasBindableName(node)) {
                        const symbol = getSymbolOfDeclaration(node);
                        const getter = getDeclarationOfKind(symbol, 177 /* GetAccessor */);
                        const setter = getDeclarationOfKind(symbol, 178 /* SetAccessor */);
                        if (getter && setter && !(getNodeCheckFlags(getter) & 1 /* TypeChecked */)) {
                            getNodeLinks(getter).flags |= 1 /* TypeChecked */;
                            const getterFlags = getEffectiveModifierFlags(getter);
                            const setterFlags = getEffectiveModifierFlags(setter);
                            if ((getterFlags & 64 /* Abstract */) !== (setterFlags & 64 /* Abstract */)) {
                                error2(getter.name, Diagnostics.Accessors_must_both_be_abstract_or_non_abstract);
                                error2(setter.name, Diagnostics.Accessors_must_both_be_abstract_or_non_abstract);
                            }
                            if (getterFlags & 4 /* Protected */ && !(setterFlags & (4 /* Protected */ | 2 /* Private */)) || getterFlags & 2 /* Private */ && !(setterFlags & 2 /* Private */)) {
                                error2(getter.name, Diagnostics.A_get_accessor_must_be_at_least_as_accessible_as_the_setter);
                                error2(setter.name, Diagnostics.A_get_accessor_must_be_at_least_as_accessible_as_the_setter);
                            }
                        }
                    }
                    const returnType = getTypeOfAccessors(getSymbolOfDeclaration(node));
                    if (node.kind === 177 /* GetAccessor */) {
                        checkAllCodePathsInNonVoidFunctionReturnOrThrow(node, returnType);
                    }
                }
            }
            function checkMissingDeclaration(node) {
                checkDecorators(node);
            }
            function getEffectiveTypeArgumentAtIndex(node, typeParameters, index) {
                if (node.typeArguments && index < node.typeArguments.length) {
                    return getTypeFromTypeNode(node.typeArguments[index]);
                }
                return getEffectiveTypeArguments2(node, typeParameters)[index];
            }
            function getEffectiveTypeArguments2(node, typeParameters) {
                return fillMissingTypeArguments(map(node.typeArguments, getTypeFromTypeNode), typeParameters, getMinTypeArgumentCount(typeParameters), isInJSFile(node));
            }
            function checkTypeArgumentConstraints(node, typeParameters) {
                let typeArguments;
                let mapper;
                let result = true;
                for (let i = 0; i < typeParameters.length; i++) {
                    const constraint = getConstraintOfTypeParameter(typeParameters[i]);
                    if (constraint) {
                        if (!typeArguments) {
                            typeArguments = getEffectiveTypeArguments2(node, typeParameters);
                            mapper = createTypeMapper(typeParameters, typeArguments);
                        }
                        result = result && checkTypeAssignableTo(typeArguments[i], instantiateType(constraint, mapper), node.typeArguments[i], Diagnostics.Type_0_does_not_satisfy_the_constraint_1);
                    }
                }
                return result;
            }
            function getTypeParametersForTypeAndSymbol(type, symbol) {
                if (!isErrorType(type)) {
                    return symbol.flags & 524288 /* TypeAlias */ && getSymbolLinks(symbol).typeParameters || (getObjectFlags(type) & 4 /* Reference */ ? type.target.localTypeParameters : void 0);
                }
                return void 0;
            }
            function getTypeParametersForTypeReferenceOrImport(node) {
                const type = getTypeFromTypeNode(node);
                if (!isErrorType(type)) {
                    const symbol = getNodeLinks(node).resolvedSymbol;
                    if (symbol) {
                        return getTypeParametersForTypeAndSymbol(type, symbol);
                    }
                }
                return void 0;
            }
            function checkTypeReferenceNode(node) {
                checkGrammarTypeArguments(node, node.typeArguments);
                if (node.kind === 183 /* TypeReference */ && !isInJSFile(node) && !isInJSDoc(node) && node.typeArguments && node.typeName.end !== node.typeArguments.pos) {
                    const sourceFile = getSourceFileOfNode(node);
                    if (scanTokenAtPosition(sourceFile, node.typeName.end) === 25 /* DotToken */) {
                        grammarErrorAtPos(node, skipTrivia(sourceFile.text, node.typeName.end), 1, Diagnostics.JSDoc_types_can_only_be_used_inside_documentation_comments);
                    }
                }
                forEach(node.typeArguments, checkSourceElement);
                checkTypeReferenceOrImport(node);
            }
            function checkTypeReferenceOrImport(node) {
                const type = getTypeFromTypeNode(node);
                if (!isErrorType(type)) {
                    if (node.typeArguments) {
                        addLazyDiagnostic(() => {
                            const typeParameters = getTypeParametersForTypeReferenceOrImport(node);
                            if (typeParameters) {
                                checkTypeArgumentConstraints(node, typeParameters);
                            }
                        });
                    }
                    const symbol = getNodeLinks(node).resolvedSymbol;
                    if (symbol) {
                        if (some(symbol.declarations, (d) => isTypeDeclaration(d) && !!(d.flags & 536870912 /* Deprecated */))) {
                            addDeprecatedSuggestion(getDeprecatedSuggestionNode(node), symbol.declarations, symbol.escapedName);
                        }
                    }
                }
            }
            function getTypeArgumentConstraint(node) {
                const typeReferenceNode = tryCast(node.parent, isTypeReferenceType);
                if (!typeReferenceNode)
                    return void 0;
                const typeParameters = getTypeParametersForTypeReferenceOrImport(typeReferenceNode);
                if (!typeParameters)
                    return void 0;
                const constraint = getConstraintOfTypeParameter(typeParameters[typeReferenceNode.typeArguments.indexOf(node)]);
                return constraint && instantiateType(constraint, createTypeMapper(typeParameters, getEffectiveTypeArguments2(typeReferenceNode, typeParameters)));
            }
            function checkTypeQuery(node) {
                getTypeFromTypeQueryNode(node);
            }
            function checkTypeLiteral(node) {
                forEach(node.members, checkSourceElement);
                addLazyDiagnostic(checkTypeLiteralDiagnostics);
                function checkTypeLiteralDiagnostics() {
                    const type = getTypeFromTypeLiteralOrFunctionOrConstructorTypeNode(node);
                    checkIndexConstraints(type, type.symbol);
                    checkTypeForDuplicateIndexSignatures(node);
                    checkObjectTypeForDuplicateDeclarations(node);
                }
            }
            function checkArrayType(node) {
                checkSourceElement(node.elementType);
            }
            function checkTupleType(node) {
                let seenOptionalElement = false;
                let seenRestElement = false;
                for (const e of node.elements) {
                    let flags = getTupleElementFlags(e);
                    if (flags & 8 /* Variadic */) {
                        const type = getTypeFromTypeNode(e.type);
                        if (!isArrayLikeType(type)) {
                            error2(e, Diagnostics.A_rest_element_type_must_be_an_array_type);
                            break;
                        }
                        if (isArrayType(type) || isTupleType(type) && type.target.combinedFlags & 4 /* Rest */) {
                            flags |= 4 /* Rest */;
                        }
                    }
                    if (flags & 4 /* Rest */) {
                        if (seenRestElement) {
                            grammarErrorOnNode(e, Diagnostics.A_rest_element_cannot_follow_another_rest_element);
                            break;
                        }
                        seenRestElement = true;
                    }
                    else if (flags & 2 /* Optional */) {
                        if (seenRestElement) {
                            grammarErrorOnNode(e, Diagnostics.An_optional_element_cannot_follow_a_rest_element);
                            break;
                        }
                        seenOptionalElement = true;
                    }
                    else if (flags & 1 /* Required */ && seenOptionalElement) {
                        grammarErrorOnNode(e, Diagnostics.A_required_element_cannot_follow_an_optional_element);
                        break;
                    }
                }
                forEach(node.elements, checkSourceElement);
                getTypeFromTypeNode(node);
            }
            function checkUnionOrIntersectionType(node) {
                forEach(node.types, checkSourceElement);
                getTypeFromTypeNode(node);
            }
            function checkIndexedAccessIndexType(type, accessNode) {
                if (!(type.flags & 8388608 /* IndexedAccess */)) {
                    return type;
                }
                const objectType = type.objectType;
                const indexType = type.indexType;
                const objectIndexType = isGenericMappedType(objectType) && getMappedTypeNameTypeKind(objectType) === 2 /* Remapping */ ? getIndexTypeForMappedType(objectType, 0 /* None */) : getIndexType(objectType, 0 /* None */);
                const hasNumberIndexInfo = !!getIndexInfoOfType(objectType, numberType);
                if (everyType(indexType, (t) => isTypeAssignableTo(t, objectIndexType) || hasNumberIndexInfo && isApplicableIndexType(t, numberType))) {
                    if (accessNode.kind === 212 /* ElementAccessExpression */ && isAssignmentTarget(accessNode) && getObjectFlags(objectType) & 32 /* Mapped */ && getMappedTypeModifiers(objectType) & 1 /* IncludeReadonly */) {
                        error2(accessNode, Diagnostics.Index_signature_in_type_0_only_permits_reading, typeToString(objectType));
                    }
                    return type;
                }
                if (isGenericObjectType(objectType)) {
                    const propertyName = getPropertyNameFromIndex(indexType, accessNode);
                    if (propertyName) {
                        const propertySymbol = forEachType(getApparentType(objectType), (t) => getPropertyOfType(t, propertyName));
                        if (propertySymbol && getDeclarationModifierFlagsFromSymbol(propertySymbol) & 6 /* NonPublicAccessibilityModifier */) {
                            error2(accessNode, Diagnostics.Private_or_protected_member_0_cannot_be_accessed_on_a_type_parameter, unescapeLeadingUnderscores(propertyName));
                            return errorType;
                        }
                    }
                }
                error2(accessNode, Diagnostics.Type_0_cannot_be_used_to_index_type_1, typeToString(indexType), typeToString(objectType));
                return errorType;
            }
            function checkIndexedAccessType(node) {
                checkSourceElement(node.objectType);
                checkSourceElement(node.indexType);
                checkIndexedAccessIndexType(getTypeFromIndexedAccessTypeNode(node), node);
            }
            function checkMappedType(node) {
                checkGrammarMappedType(node);
                checkSourceElement(node.typeParameter);
                checkSourceElement(node.nameType);
                checkSourceElement(node.type);
                if (!node.type) {
                    reportImplicitAny(node, anyType);
                }
                const type = getTypeFromMappedTypeNode(node);
                const nameType = getNameTypeFromMappedType(type);
                if (nameType) {
                    checkTypeAssignableTo(nameType, keyofConstraintType, node.nameType);
                }
                else {
                    const constraintType = getConstraintTypeFromMappedType(type);
                    checkTypeAssignableTo(constraintType, keyofConstraintType, getEffectiveConstraintOfTypeParameter(node.typeParameter));
                }
            }
            function checkGrammarMappedType(node) {
                var _a;
                if ((_a = node.members) == null ? void 0 : _a.length) {
                    return grammarErrorOnNode(node.members[0], Diagnostics.A_mapped_type_may_not_declare_properties_or_methods);
                }
            }
            function checkThisType(node) {
                getTypeFromThisTypeNode(node);
            }
            function checkTypeOperator(node) {
                checkGrammarTypeOperatorNode(node);
                checkSourceElement(node.type);
            }
            function checkConditionalType(node) {
                forEachChild(node, checkSourceElement);
            }
            function checkInferType(node) {
                if (!findAncestor(node, (n) => n.parent && n.parent.kind === 194 /* ConditionalType */ && n.parent.extendsType === n)) {
                    grammarErrorOnNode(node, Diagnostics.infer_declarations_are_only_permitted_in_the_extends_clause_of_a_conditional_type);
                }
                checkSourceElement(node.typeParameter);
                const symbol = getSymbolOfDeclaration(node.typeParameter);
                if (symbol.declarations && symbol.declarations.length > 1) {
                    const links = getSymbolLinks(symbol);
                    if (!links.typeParametersChecked) {
                        links.typeParametersChecked = true;
                        const typeParameter = getDeclaredTypeOfTypeParameter(symbol);
                        const declarations = getDeclarationsOfKind(symbol, 168 /* TypeParameter */);
                        if (!areTypeParametersIdentical(declarations, [typeParameter], (decl) => [decl])) {
                            const name = symbolToString(symbol);
                            for (const declaration of declarations) {
                                error2(declaration.name, Diagnostics.All_declarations_of_0_must_have_identical_constraints, name);
                            }
                        }
                    }
                }
                registerForUnusedIdentifiersCheck(node);
            }
            function checkTemplateLiteralType(node) {
                for (const span of node.templateSpans) {
                    checkSourceElement(span.type);
                    const type = getTypeFromTypeNode(span.type);
                    checkTypeAssignableTo(type, templateConstraintType, span.type);
                }
                getTypeFromTypeNode(node);
            }
            function checkImportType(node) {
                checkSourceElement(node.argument);
                if (node.attributes) {
                    getResolutionModeOverride(node.attributes, grammarErrorOnNode);
                }
                checkTypeReferenceOrImport(node);
            }
            function checkNamedTupleMember(node) {
                if (node.dotDotDotToken && node.questionToken) {
                    grammarErrorOnNode(node, Diagnostics.A_tuple_member_cannot_be_both_optional_and_rest);
                }
                if (node.type.kind === 190 /* OptionalType */) {
                    grammarErrorOnNode(node.type, Diagnostics.A_labeled_tuple_element_is_declared_as_optional_with_a_question_mark_after_the_name_and_before_the_colon_rather_than_after_the_type);
                }
                if (node.type.kind === 191 /* RestType */) {
                    grammarErrorOnNode(node.type, Diagnostics.A_labeled_tuple_element_is_declared_as_rest_with_a_before_the_name_rather_than_before_the_type);
                }
                checkSourceElement(node.type);
                getTypeFromTypeNode(node);
            }
            function isPrivateWithinAmbient(node) {
                return (hasEffectiveModifier(node, 2 /* Private */) || isPrivateIdentifierClassElementDeclaration(node)) && !!(node.flags & 33554432 /* Ambient */);
            }
            function getEffectiveDeclarationFlags(n, flagsToCheck) {
                let flags = getCombinedModifierFlagsCached(n);
                if (n.parent.kind !== 264 /* InterfaceDeclaration */ && n.parent.kind !== 263 /* ClassDeclaration */ && n.parent.kind !== 231 /* ClassExpression */ && n.flags & 33554432 /* Ambient */) {
                    const container = getEnclosingContainer(n);
                    if (container && container.flags & 128 /* ExportContext */ && !(flags & 128 /* Ambient */) && !(isModuleBlock(n.parent) && isModuleDeclaration(n.parent.parent) && isGlobalScopeAugmentation(n.parent.parent))) {
                        flags |= 32 /* Export */;
                    }
                    flags |= 128 /* Ambient */;
                }
                return flags & flagsToCheck;
            }
            function checkFunctionOrConstructorSymbol(symbol) {
                addLazyDiagnostic(() => checkFunctionOrConstructorSymbolWorker(symbol));
            }
            function checkFunctionOrConstructorSymbolWorker(symbol) {
                function getCanonicalOverload(overloads, implementation) {
                    const implementationSharesContainerWithFirstOverload = implementation !== void 0 && implementation.parent === overloads[0].parent;
                    return implementationSharesContainerWithFirstOverload ? implementation : overloads[0];
                }
                function checkFlagAgreementBetweenOverloads(overloads, implementation, flagsToCheck2, someOverloadFlags, allOverloadFlags) {
                    const someButNotAllOverloadFlags = someOverloadFlags ^ allOverloadFlags;
                    if (someButNotAllOverloadFlags !== 0) {
                        const canonicalFlags = getEffectiveDeclarationFlags(getCanonicalOverload(overloads, implementation), flagsToCheck2);
                        forEach(overloads, (o) => {
                            const deviation = getEffectiveDeclarationFlags(o, flagsToCheck2) ^ canonicalFlags;
                            if (deviation & 32 /* Export */) {
                                error2(getNameOfDeclaration(o), Diagnostics.Overload_signatures_must_all_be_exported_or_non_exported);
                            }
                            else if (deviation & 128 /* Ambient */) {
                                error2(getNameOfDeclaration(o), Diagnostics.Overload_signatures_must_all_be_ambient_or_non_ambient);
                            }
                            else if (deviation & (2 /* Private */ | 4 /* Protected */)) {
                                error2(getNameOfDeclaration(o) || o, Diagnostics.Overload_signatures_must_all_be_public_private_or_protected);
                            }
                            else if (deviation & 64 /* Abstract */) {
                                error2(getNameOfDeclaration(o), Diagnostics.Overload_signatures_must_all_be_abstract_or_non_abstract);
                            }
                        });
                    }
                }
                function checkQuestionTokenAgreementBetweenOverloads(overloads, implementation, someHaveQuestionToken2, allHaveQuestionToken2) {
                    if (someHaveQuestionToken2 !== allHaveQuestionToken2) {
                        const canonicalHasQuestionToken = hasQuestionToken(getCanonicalOverload(overloads, implementation));
                        forEach(overloads, (o) => {
                            const deviation = hasQuestionToken(o) !== canonicalHasQuestionToken;
                            if (deviation) {
                                error2(getNameOfDeclaration(o), Diagnostics.Overload_signatures_must_all_be_optional_or_required);
                            }
                        });
                    }
                }
                const flagsToCheck = 32 /* Export */ | 128 /* Ambient */ | 2 /* Private */ | 4 /* Protected */ | 64 /* Abstract */;
                let someNodeFlags = 0 /* None */;
                let allNodeFlags = flagsToCheck;
                let someHaveQuestionToken = false;
                let allHaveQuestionToken = true;
                let hasOverloads = false;
                let bodyDeclaration;
                let lastSeenNonAmbientDeclaration;
                let previousDeclaration;
                const declarations = symbol.declarations;
                const isConstructor = (symbol.flags & 16384 /* Constructor */) !== 0;
                function reportImplementationExpectedError(node) {
                    if (node.name && nodeIsMissing(node.name)) {
                        return;
                    }
                    let seen = false;
                    const subsequentNode = forEachChild(node.parent, (c) => {
                        if (seen) {
                            return c;
                        }
                        else {
                            seen = c === node;
                        }
                    });
                    if (subsequentNode && subsequentNode.pos === node.end) {
                        if (subsequentNode.kind === node.kind) {
                            const errorNode2 = subsequentNode.name || subsequentNode;
                            const subsequentName = subsequentNode.name;
                            if (node.name && subsequentName && // both are private identifiers
                                (isPrivateIdentifier(node.name) && isPrivateIdentifier(subsequentName) && node.name.escapedText === subsequentName.escapedText || // Both are computed property names
                                    isComputedPropertyName(node.name) && isComputedPropertyName(subsequentName) && isTypeIdenticalTo(checkComputedPropertyName(node.name), checkComputedPropertyName(subsequentName)) || // Both are literal property names that are the same.
                                    isPropertyNameLiteral(node.name) && isPropertyNameLiteral(subsequentName) && getEscapedTextOfIdentifierOrLiteral(node.name) === getEscapedTextOfIdentifierOrLiteral(subsequentName))) {
                                const reportError = (node.kind === 174 /* MethodDeclaration */ || node.kind === 173 /* MethodSignature */) && isStatic(node) !== isStatic(subsequentNode);
                                if (reportError) {
                                    const diagnostic = isStatic(node) ? Diagnostics.Function_overload_must_be_static : Diagnostics.Function_overload_must_not_be_static;
                                    error2(errorNode2, diagnostic);
                                }
                                return;
                            }
                            if (nodeIsPresent(subsequentNode.body)) {
                                error2(errorNode2, Diagnostics.Function_implementation_name_must_be_0, declarationNameToString(node.name));
                                return;
                            }
                        }
                    }
                    const errorNode = node.name || node;
                    if (isConstructor) {
                        error2(errorNode, Diagnostics.Constructor_implementation_is_missing);
                    }
                    else {
                        if (hasSyntacticModifier(node, 64 /* Abstract */)) {
                            error2(errorNode, Diagnostics.All_declarations_of_an_abstract_method_must_be_consecutive);
                        }
                        else {
                            error2(errorNode, Diagnostics.Function_implementation_is_missing_or_not_immediately_following_the_declaration);
                        }
                    }
                }
                let duplicateFunctionDeclaration = false;
                let multipleConstructorImplementation = false;
                let hasNonAmbientClass = false;
                const functionDeclarations = [];
                if (declarations) {
                    for (const current of declarations) {
                        const node = current;
                        const inAmbientContext = node.flags & 33554432 /* Ambient */;
                        const inAmbientContextOrInterface = node.parent && (node.parent.kind === 264 /* InterfaceDeclaration */ || node.parent.kind === 187 /* TypeLiteral */) || inAmbientContext;
                        if (inAmbientContextOrInterface) {
                            previousDeclaration = void 0;
                        }
                        if ((node.kind === 263 /* ClassDeclaration */ || node.kind === 231 /* ClassExpression */) && !inAmbientContext) {
                            hasNonAmbientClass = true;
                        }
                        if (node.kind === 262 /* FunctionDeclaration */ || node.kind === 174 /* MethodDeclaration */ || node.kind === 173 /* MethodSignature */ || node.kind === 176 /* Constructor */) {
                            functionDeclarations.push(node);
                            const currentNodeFlags = getEffectiveDeclarationFlags(node, flagsToCheck);
                            someNodeFlags |= currentNodeFlags;
                            allNodeFlags &= currentNodeFlags;
                            someHaveQuestionToken = someHaveQuestionToken || hasQuestionToken(node);
                            allHaveQuestionToken = allHaveQuestionToken && hasQuestionToken(node);
                            const bodyIsPresent = nodeIsPresent(node.body);
                            if (bodyIsPresent && bodyDeclaration) {
                                if (isConstructor) {
                                    multipleConstructorImplementation = true;
                                }
                                else {
                                    duplicateFunctionDeclaration = true;
                                }
                            }
                            else if ((previousDeclaration == null ? void 0 : previousDeclaration.parent) === node.parent && previousDeclaration.end !== node.pos) {
                                reportImplementationExpectedError(previousDeclaration);
                            }
                            if (bodyIsPresent) {
                                if (!bodyDeclaration) {
                                    bodyDeclaration = node;
                                }
                            }
                            else {
                                hasOverloads = true;
                            }
                            previousDeclaration = node;
                            if (!inAmbientContextOrInterface) {
                                lastSeenNonAmbientDeclaration = node;
                            }
                        }
                        if (isInJSFile(current) && isFunctionLike(current) && current.jsDoc) {
                            hasOverloads = length(getJSDocOverloadTags(current)) > 0;
                        }
                    }
                }
                if (multipleConstructorImplementation) {
                    forEach(functionDeclarations, (declaration) => {
                        error2(declaration, Diagnostics.Multiple_constructor_implementations_are_not_allowed);
                    });
                }
                if (duplicateFunctionDeclaration) {
                    forEach(functionDeclarations, (declaration) => {
                        error2(getNameOfDeclaration(declaration) || declaration, Diagnostics.Duplicate_function_implementation);
                    });
                }
                if (hasNonAmbientClass && !isConstructor && symbol.flags & 16 /* Function */ && declarations) {
                    const relatedDiagnostics = filter(declarations, (d) => d.kind === 263 /* ClassDeclaration */).map((d) => createDiagnosticForNode(d, Diagnostics.Consider_adding_a_declare_modifier_to_this_class));
                    forEach(declarations, (declaration) => {
                        const diagnostic = declaration.kind === 263 /* ClassDeclaration */ ? Diagnostics.Class_declaration_cannot_implement_overload_list_for_0 : declaration.kind === 262 /* FunctionDeclaration */ ? Diagnostics.Function_with_bodies_can_only_merge_with_classes_that_are_ambient : void 0;
                        if (diagnostic) {
                            addRelatedInfo(error2(getNameOfDeclaration(declaration) || declaration, diagnostic, symbolName(symbol)), ...relatedDiagnostics);
                        }
                    });
                }
                if (lastSeenNonAmbientDeclaration && !lastSeenNonAmbientDeclaration.body && !hasSyntacticModifier(lastSeenNonAmbientDeclaration, 64 /* Abstract */) && !lastSeenNonAmbientDeclaration.questionToken) {
                    reportImplementationExpectedError(lastSeenNonAmbientDeclaration);
                }
                if (hasOverloads) {
                    if (declarations) {
                        checkFlagAgreementBetweenOverloads(declarations, bodyDeclaration, flagsToCheck, someNodeFlags, allNodeFlags);
                        checkQuestionTokenAgreementBetweenOverloads(declarations, bodyDeclaration, someHaveQuestionToken, allHaveQuestionToken);
                    }
                    if (bodyDeclaration) {
                        const signatures = getSignaturesOfSymbol(symbol);
                        const bodySignature = getSignatureFromDeclaration(bodyDeclaration);
                        for (const signature of signatures) {
                            if (!isImplementationCompatibleWithOverload(bodySignature, signature)) {
                                const errorNode = signature.declaration && isJSDocSignature(signature.declaration) ? signature.declaration.parent.tagName : signature.declaration;
                                addRelatedInfo(error2(errorNode, Diagnostics.This_overload_signature_is_not_compatible_with_its_implementation_signature), createDiagnosticForNode(bodyDeclaration, Diagnostics.The_implementation_signature_is_declared_here));
                                break;
                            }
                        }
                    }
                }
            }
            function checkExportsOnMergedDeclarations(node) {
                addLazyDiagnostic(() => checkExportsOnMergedDeclarationsWorker(node));
            }
            function checkExportsOnMergedDeclarationsWorker(node) {
                let symbol = node.localSymbol;
                if (!symbol) {
                    symbol = getSymbolOfDeclaration(node);
                    if (!symbol.exportSymbol) {
                        return;
                    }
                }
                if (getDeclarationOfKind(symbol, node.kind) !== node) {
                    return;
                }
                let exportedDeclarationSpaces = 0 /* None */;
                let nonExportedDeclarationSpaces = 0 /* None */;
                let defaultExportedDeclarationSpaces = 0 /* None */;
                for (const d of symbol.declarations) {
                    const declarationSpaces = getDeclarationSpaces(d);
                    const effectiveDeclarationFlags = getEffectiveDeclarationFlags(d, 32 /* Export */ | 2048 /* Default */);
                    if (effectiveDeclarationFlags & 32 /* Export */) {
                        if (effectiveDeclarationFlags & 2048 /* Default */) {
                            defaultExportedDeclarationSpaces |= declarationSpaces;
                        }
                        else {
                            exportedDeclarationSpaces |= declarationSpaces;
                        }
                    }
                    else {
                        nonExportedDeclarationSpaces |= declarationSpaces;
                    }
                }
                const nonDefaultExportedDeclarationSpaces = exportedDeclarationSpaces | nonExportedDeclarationSpaces;
                const commonDeclarationSpacesForExportsAndLocals = exportedDeclarationSpaces & nonExportedDeclarationSpaces;
                const commonDeclarationSpacesForDefaultAndNonDefault = defaultExportedDeclarationSpaces & nonDefaultExportedDeclarationSpaces;
                if (commonDeclarationSpacesForExportsAndLocals || commonDeclarationSpacesForDefaultAndNonDefault) {
                    for (const d of symbol.declarations) {
                        const declarationSpaces = getDeclarationSpaces(d);
                        const name = getNameOfDeclaration(d);
                        if (declarationSpaces & commonDeclarationSpacesForDefaultAndNonDefault) {
                            error2(name, Diagnostics.Merged_declaration_0_cannot_include_a_default_export_declaration_Consider_adding_a_separate_export_default_0_declaration_instead, declarationNameToString(name));
                        }
                        else if (declarationSpaces & commonDeclarationSpacesForExportsAndLocals) {
                            error2(name, Diagnostics.Individual_declarations_in_merged_declaration_0_must_be_all_exported_or_all_local, declarationNameToString(name));
                        }
                    }
                }
                function getDeclarationSpaces(decl) {
                    let d = decl;
                    switch (d.kind) {
                        case 264 /* InterfaceDeclaration */:
                        case 265 /* TypeAliasDeclaration */:
                        case 353 /* JSDocTypedefTag */:
                        case 345 /* JSDocCallbackTag */:
                        case 347 /* JSDocEnumTag */:
                            return 2 /* ExportType */;
                        case 267 /* ModuleDeclaration */:
                            return isAmbientModule(d) || getModuleInstanceState(d) !== 0 /* NonInstantiated */ ? 4 /* ExportNamespace */ | 1 /* ExportValue */ : 4 /* ExportNamespace */;
                        case 263 /* ClassDeclaration */:
                        case 266 /* EnumDeclaration */:
                        case 306 /* EnumMember */:
                            return 2 /* ExportType */ | 1 /* ExportValue */;
                        case 312 /* SourceFile */:
                            return 2 /* ExportType */ | 1 /* ExportValue */ | 4 /* ExportNamespace */;
                        case 277 /* ExportAssignment */:
                        case 226 /* BinaryExpression */:
                            const node2 = d;
                            const expression = isExportAssignment(node2) ? node2.expression : node2.right;
                            if (!isEntityNameExpression(expression)) {
                                return 1 /* ExportValue */;
                            }
                            d = expression;
                        case 271 /* ImportEqualsDeclaration */:
                        case 274 /* NamespaceImport */:
                        case 273 /* ImportClause */:
                            let result = 0 /* None */;
                            const target = resolveAlias(getSymbolOfDeclaration(d));
                            forEach(target.declarations, (d2) => {
                                result |= getDeclarationSpaces(d2);
                            });
                            return result;
                        case 260 /* VariableDeclaration */:
                        case 208 /* BindingElement */:
                        case 262 /* FunctionDeclaration */:
                        case 276 /* ImportSpecifier */:
                        case 80 /* Identifier */:
                            return 1 /* ExportValue */;
                        case 173 /* MethodSignature */:
                        case 171 /* PropertySignature */:
                            return 2 /* ExportType */;
                        default:
                            return Debug.failBadSyntaxKind(d);
                    }
                }
            }
            function getAwaitedTypeOfPromise(type, errorNode, diagnosticMessage, ...args) {
                const promisedType = getPromisedTypeOfPromise(type, errorNode);
                return promisedType && getAwaitedType(promisedType, errorNode, diagnosticMessage, ...args);
            }
            function getPromisedTypeOfPromise(type, errorNode, thisTypeForErrorOut) {
                if (isTypeAny(type)) {
                    return void 0;
                }
                const typeAsPromise = type;
                if (typeAsPromise.promisedTypeOfPromise) {
                    return typeAsPromise.promisedTypeOfPromise;
                }
                if (isReferenceToType2(type, getGlobalPromiseType(
                /*reportErrors*/
                false))) {
                    return typeAsPromise.promisedTypeOfPromise = getTypeArguments(type)[0];
                }
                if (allTypesAssignableToKind(getBaseConstraintOrType(type), 402784252 /* Primitive */ | 131072 /* Never */)) {
                    return void 0;
                }
                const thenFunction = getTypeOfPropertyOfType(type, "then");
                if (isTypeAny(thenFunction)) {
                    return void 0;
                }
                const thenSignatures = thenFunction ? getSignaturesOfType(thenFunction, 0 /* Call */) : emptyArray;
                if (thenSignatures.length === 0) {
                    if (errorNode) {
                        error2(errorNode, Diagnostics.A_promise_must_have_a_then_method);
                    }
                    return void 0;
                }
                let thisTypeForError;
                let candidates;
                for (const thenSignature of thenSignatures) {
                    const thisType = getThisTypeOfSignature(thenSignature);
                    if (thisType && thisType !== voidType && !isTypeRelatedTo(type, thisType, subtypeRelation)) {
                        thisTypeForError = thisType;
                    }
                    else {
                        candidates = append(candidates, thenSignature);
                    }
                }
                if (!candidates) {
                    Debug.assertIsDefined(thisTypeForError);
                    if (thisTypeForErrorOut) {
                        thisTypeForErrorOut.value = thisTypeForError;
                    }
                    if (errorNode) {
                        error2(errorNode, Diagnostics.The_this_context_of_type_0_is_not_assignable_to_method_s_this_of_type_1, typeToString(type), typeToString(thisTypeForError));
                    }
                    return void 0;
                }
                const onfulfilledParameterType = getTypeWithFacts(getUnionType(map(candidates, getTypeOfFirstParameterOfSignature)), 2097152 /* NEUndefinedOrNull */);
                if (isTypeAny(onfulfilledParameterType)) {
                    return void 0;
                }
                const onfulfilledParameterSignatures = getSignaturesOfType(onfulfilledParameterType, 0 /* Call */);
                if (onfulfilledParameterSignatures.length === 0) {
                    if (errorNode) {
                        error2(errorNode, Diagnostics.The_first_parameter_of_the_then_method_of_a_promise_must_be_a_callback);
                    }
                    return void 0;
                }
                return typeAsPromise.promisedTypeOfPromise = getUnionType(map(onfulfilledParameterSignatures, getTypeOfFirstParameterOfSignature), 2 /* Subtype */);
            }
            function checkAwaitedType(type, withAlias, errorNode, diagnosticMessage, ...args) {
                const awaitedType = withAlias ? getAwaitedType(type, errorNode, diagnosticMessage, ...args) : getAwaitedTypeNoAlias(type, errorNode, diagnosticMessage, ...args);
                return awaitedType || errorType;
            }
            function isThenableType(type) {
                if (allTypesAssignableToKind(getBaseConstraintOrType(type), 402784252 /* Primitive */ | 131072 /* Never */)) {
                    return false;
                }
                const thenFunction = getTypeOfPropertyOfType(type, "then");
                return !!thenFunction && getSignaturesOfType(getTypeWithFacts(thenFunction, 2097152 /* NEUndefinedOrNull */), 0 /* Call */).length > 0;
            }
            function isAwaitedTypeInstantiation(type) {
                var _a;
                if (type.flags & 16777216 /* Conditional */) {
                    const awaitedSymbol = getGlobalAwaitedSymbol(
                    /*reportErrors*/
                    false);
                    return !!awaitedSymbol && type.aliasSymbol === awaitedSymbol && ((_a = type.aliasTypeArguments) == null ? void 0 : _a.length) === 1;
                }
                return false;
            }
            function unwrapAwaitedType(type) {
                return type.flags & 1048576 /* Union */ ? mapType(type, unwrapAwaitedType) : isAwaitedTypeInstantiation(type) ? type.aliasTypeArguments[0] : type;
            }
            function isAwaitedTypeNeeded(type) {
                if (isTypeAny(type) || isAwaitedTypeInstantiation(type)) {
                    return false;
                }
                if (isGenericObjectType(type)) {
                    const baseConstraint = getBaseConstraintOfType(type);
                    if (baseConstraint ? baseConstraint.flags & 3 /* AnyOrUnknown */ || isEmptyObjectType(baseConstraint) || someType(baseConstraint, isThenableType) : maybeTypeOfKind(type, 8650752 /* TypeVariable */)) {
                        return true;
                    }
                }
                return false;
            }
            function tryCreateAwaitedType(type) {
                const awaitedSymbol = getGlobalAwaitedSymbol(
                /*reportErrors*/
                true);
                if (awaitedSymbol) {
                    return getTypeAliasInstantiation(awaitedSymbol, [unwrapAwaitedType(type)]);
                }
                return void 0;
            }
            function createAwaitedTypeIfNeeded(type) {
                if (isAwaitedTypeNeeded(type)) {
                    const awaitedType = tryCreateAwaitedType(type);
                    if (awaitedType) {
                        return awaitedType;
                    }
                }
                Debug.assert(isAwaitedTypeInstantiation(type) || getPromisedTypeOfPromise(type) === void 0, "type provided should not be a non-generic 'promise'-like.");
                return type;
            }
            function getAwaitedType(type, errorNode, diagnosticMessage, ...args) {
                const awaitedType = getAwaitedTypeNoAlias(type, errorNode, diagnosticMessage, ...args);
                return awaitedType && createAwaitedTypeIfNeeded(awaitedType);
            }
            function getAwaitedTypeNoAlias(type, errorNode, diagnosticMessage, ...args) {
                if (isTypeAny(type)) {
                    return type;
                }
                if (isAwaitedTypeInstantiation(type)) {
                    return type;
                }
                const typeAsAwaitable = type;
                if (typeAsAwaitable.awaitedTypeOfType) {
                    return typeAsAwaitable.awaitedTypeOfType;
                }
                if (type.flags & 1048576 /* Union */) {
                    if (awaitedTypeStack.lastIndexOf(type.id) >= 0) {
                        if (errorNode) {
                            error2(errorNode, Diagnostics.Type_is_referenced_directly_or_indirectly_in_the_fulfillment_callback_of_its_own_then_method);
                        }
                        return void 0;
                    }
                    const mapper = errorNode ? (constituentType) => getAwaitedTypeNoAlias(constituentType, errorNode, diagnosticMessage, ...args) : getAwaitedTypeNoAlias;
                    awaitedTypeStack.push(type.id);
                    const mapped = mapType(type, mapper);
                    awaitedTypeStack.pop();
                    return typeAsAwaitable.awaitedTypeOfType = mapped;
                }
                if (isAwaitedTypeNeeded(type)) {
                    return typeAsAwaitable.awaitedTypeOfType = type;
                }
                const thisTypeForErrorOut = { value: void 0 };
                const promisedType = getPromisedTypeOfPromise(type, 
                /*errorNode*/
                void 0, thisTypeForErrorOut);
                if (promisedType) {
                    if (type.id === promisedType.id || awaitedTypeStack.lastIndexOf(promisedType.id) >= 0) {
                        if (errorNode) {
                            error2(errorNode, Diagnostics.Type_is_referenced_directly_or_indirectly_in_the_fulfillment_callback_of_its_own_then_method);
                        }
                        return void 0;
                    }
                    awaitedTypeStack.push(type.id);
                    const awaitedType = getAwaitedTypeNoAlias(promisedType, errorNode, diagnosticMessage, ...args);
                    awaitedTypeStack.pop();
                    if (!awaitedType) {
                        return void 0;
                    }
                    return typeAsAwaitable.awaitedTypeOfType = awaitedType;
                }
                if (isThenableType(type)) {
                    if (errorNode) {
                        Debug.assertIsDefined(diagnosticMessage);
                        let chain;
                        if (thisTypeForErrorOut.value) {
                            chain = chainDiagnosticMessages(chain, Diagnostics.The_this_context_of_type_0_is_not_assignable_to_method_s_this_of_type_1, typeToString(type), typeToString(thisTypeForErrorOut.value));
                        }
                        chain = chainDiagnosticMessages(chain, diagnosticMessage, ...args);
                        diagnostics.add(createDiagnosticForNodeFromMessageChain(getSourceFileOfNode(errorNode), errorNode, chain));
                    }
                    return void 0;
                }
                return typeAsAwaitable.awaitedTypeOfType = type;
            }
            function checkAsyncFunctionReturnType(node, returnTypeNode, returnTypeErrorLocation) {
                const returnType = getTypeFromTypeNode(returnTypeNode);
                if (languageVersion >= 2 /* ES2015 */) {
                    if (isErrorType(returnType)) {
                        return;
                    }
                    const globalPromiseType = getGlobalPromiseType(
                    /*reportErrors*/
                    true);
                    if (globalPromiseType !== emptyGenericType && !isReferenceToType2(returnType, globalPromiseType)) {
                        reportErrorForInvalidReturnType(Diagnostics.The_return_type_of_an_async_function_or_method_must_be_the_global_Promise_T_type_Did_you_mean_to_write_Promise_0, returnTypeNode, returnTypeErrorLocation, typeToString(getAwaitedTypeNoAlias(returnType) || voidType));
                        return;
                    }
                }
                else {
                    markTypeNodeAsReferenced(returnTypeNode);
                    if (isErrorType(returnType)) {
                        return;
                    }
                    const promiseConstructorName = getEntityNameFromTypeNode(returnTypeNode);
                    if (promiseConstructorName === void 0) {
                        reportErrorForInvalidReturnType(Diagnostics.Type_0_is_not_a_valid_async_function_return_type_in_ES5_SlashES3_because_it_does_not_refer_to_a_Promise_compatible_constructor_value, returnTypeNode, returnTypeErrorLocation, typeToString(returnType));
                        return;
                    }
                    const promiseConstructorSymbol = resolveEntityName(promiseConstructorName, 111551 /* Value */, 
                    /*ignoreErrors*/
                    true);
                    const promiseConstructorType = promiseConstructorSymbol ? getTypeOfSymbol(promiseConstructorSymbol) : errorType;
                    if (isErrorType(promiseConstructorType)) {
                        if (promiseConstructorName.kind === 80 /* Identifier */ && promiseConstructorName.escapedText === "Promise" && getTargetType(returnType) === getGlobalPromiseType(
                        /*reportErrors*/
                        false)) {
                            error2(returnTypeErrorLocation, Diagnostics.An_async_function_or_method_in_ES5_SlashES3_requires_the_Promise_constructor_Make_sure_you_have_a_declaration_for_the_Promise_constructor_or_include_ES2015_in_your_lib_option);
                        }
                        else {
                            reportErrorForInvalidReturnType(Diagnostics.Type_0_is_not_a_valid_async_function_return_type_in_ES5_SlashES3_because_it_does_not_refer_to_a_Promise_compatible_constructor_value, returnTypeNode, returnTypeErrorLocation, entityNameToString(promiseConstructorName));
                        }
                        return;
                    }
                    const globalPromiseConstructorLikeType = getGlobalPromiseConstructorLikeType(
                    /*reportErrors*/
                    true);
                    if (globalPromiseConstructorLikeType === emptyObjectType) {
                        reportErrorForInvalidReturnType(Diagnostics.Type_0_is_not_a_valid_async_function_return_type_in_ES5_SlashES3_because_it_does_not_refer_to_a_Promise_compatible_constructor_value, returnTypeNode, returnTypeErrorLocation, entityNameToString(promiseConstructorName));
                        return;
                    }
                    const headMessage = Diagnostics.Type_0_is_not_a_valid_async_function_return_type_in_ES5_SlashES3_because_it_does_not_refer_to_a_Promise_compatible_constructor_value;
                    const errorInfo = () => returnTypeNode === returnTypeErrorLocation ? void 0 : chainDiagnosticMessages(
                    /*details*/
                    void 0, Diagnostics.The_return_type_of_an_async_function_or_method_must_be_the_global_Promise_T_type);
                    if (!checkTypeAssignableTo(promiseConstructorType, globalPromiseConstructorLikeType, returnTypeErrorLocation, headMessage, errorInfo)) {
                        return;
                    }
                    const rootName = promiseConstructorName && getFirstIdentifier(promiseConstructorName);
                    const collidingSymbol = getSymbol2(node.locals, rootName.escapedText, 111551 /* Value */);
                    if (collidingSymbol) {
                        error2(collidingSymbol.valueDeclaration, Diagnostics.Duplicate_identifier_0_Compiler_uses_declaration_1_to_support_async_functions, idText(rootName), entityNameToString(promiseConstructorName));
                        return;
                    }
                }
                checkAwaitedType(returnType, 
                /*withAlias*/
                false, node, Diagnostics.The_return_type_of_an_async_function_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member);
                function reportErrorForInvalidReturnType(message, returnTypeNode2, returnTypeErrorLocation2, typeName) {
                    if (returnTypeNode2 === returnTypeErrorLocation2) {
                        error2(returnTypeErrorLocation2, message, typeName);
                    }
                    else {
                        const diag2 = error2(returnTypeErrorLocation2, Diagnostics.The_return_type_of_an_async_function_or_method_must_be_the_global_Promise_T_type);
                        addRelatedInfo(diag2, createDiagnosticForNode(returnTypeNode2, message, typeName));
                    }
                }
            }
            function checkDecorator(node) {
                const signature = getResolvedSignature(node);
                checkDeprecatedSignature(signature, node);
                const returnType = getReturnTypeOfSignature(signature);
                if (returnType.flags & 1 /* Any */) {
                    return;
                }
                const decoratorSignature = getDecoratorCallSignature(node);
                if (!(decoratorSignature == null ? void 0 : decoratorSignature.resolvedReturnType))
                    return;
                let headMessage;
                const expectedReturnType = decoratorSignature.resolvedReturnType;
                switch (node.parent.kind) {
                    case 263 /* ClassDeclaration */:
                    case 231 /* ClassExpression */:
                        headMessage = Diagnostics.Decorator_function_return_type_0_is_not_assignable_to_type_1;
                        break;
                    case 172 /* PropertyDeclaration */:
                        if (!legacyDecorators) {
                            headMessage = Diagnostics.Decorator_function_return_type_0_is_not_assignable_to_type_1;
                            break;
                        }
                    case 169 /* Parameter */:
                        headMessage = Diagnostics.Decorator_function_return_type_is_0_but_is_expected_to_be_void_or_any;
                        break;
                    case 174 /* MethodDeclaration */:
                    case 177 /* GetAccessor */:
                    case 178 /* SetAccessor */:
                        headMessage = Diagnostics.Decorator_function_return_type_0_is_not_assignable_to_type_1;
                        break;
                    default:
                        return Debug.failBadSyntaxKind(node.parent);
                }
                checkTypeAssignableTo(returnType, expectedReturnType, node.expression, headMessage);
            }
            function createCallSignature(typeParameters, thisParameter, parameters, returnType, typePredicate, minArgumentCount = parameters.length, flags = 0 /* None */) {
                const decl = factory.createFunctionTypeNode(
                /*typeParameters*/
                void 0, emptyArray, factory.createKeywordTypeNode(133 /* AnyKeyword */));
                return createSignature(decl, typeParameters, thisParameter, parameters, returnType, typePredicate, minArgumentCount, flags);
            }
            function createFunctionType(typeParameters, thisParameter, parameters, returnType, typePredicate, minArgumentCount, flags) {
                const signature = createCallSignature(typeParameters, thisParameter, parameters, returnType, typePredicate, minArgumentCount, flags);
                return getOrCreateTypeFromSignature(signature);
            }
            function createGetterFunctionType(type) {
                return createFunctionType(
                /*typeParameters*/
                void 0, 
                /*thisParameter*/
                void 0, emptyArray, type);
            }
            function createSetterFunctionType(type) {
                const valueParam = createParameter2("value", type);
                return createFunctionType(
                /*typeParameters*/
                void 0, 
                /*thisParameter*/
                void 0, [valueParam], voidType);
            }
            function markTypeNodeAsReferenced(node) {
                markEntityNameOrEntityExpressionAsReference(node && getEntityNameFromTypeNode(node), 
                /*forDecoratorMetadata*/
                false);
            }
            function markEntityNameOrEntityExpressionAsReference(typeName, forDecoratorMetadata) {
                if (!typeName)
                    return;
                const rootName = getFirstIdentifier(typeName);
                const meaning = (typeName.kind === 80 /* Identifier */ ? 788968 /* Type */ : 1920 /* Namespace */) | 2097152 /* Alias */;
                const rootSymbol = resolveName(rootName, rootName.escapedText, meaning, 
                /*nameNotFoundMessage*/
                void 0, 
                /*nameArg*/
                void 0, 
                /*isUse*/
                true);
                if (rootSymbol && rootSymbol.flags & 2097152 /* Alias */) {
                    if (canCollectSymbolAliasAccessabilityData && symbolIsValue(rootSymbol) && !isConstEnumOrConstEnumOnlyModule(resolveAlias(rootSymbol)) && !getTypeOnlyAliasDeclaration(rootSymbol)) {
                        markAliasSymbolAsReferenced(rootSymbol);
                    }
                    else if (forDecoratorMetadata && getIsolatedModules(compilerOptions) && getEmitModuleKind(compilerOptions) >= 5 /* ES2015 */ && !symbolIsValue(rootSymbol) && !some(rootSymbol.declarations, isTypeOnlyImportOrExportDeclaration)) {
                        const diag2 = error2(typeName, Diagnostics.A_type_referenced_in_a_decorated_signature_must_be_imported_with_import_type_or_a_namespace_import_when_isolatedModules_and_emitDecoratorMetadata_are_enabled);
                        const aliasDeclaration = find(rootSymbol.declarations || emptyArray, isAliasSymbolDeclaration2);
                        if (aliasDeclaration) {
                            addRelatedInfo(diag2, createDiagnosticForNode(aliasDeclaration, Diagnostics._0_was_imported_here, idText(rootName)));
                        }
                    }
                }
            }
            function markDecoratorMedataDataTypeNodeAsReferenced(node) {
                const entityName = getEntityNameForDecoratorMetadata(node);
                if (entityName && isEntityName(entityName)) {
                    markEntityNameOrEntityExpressionAsReference(entityName, 
                    /*forDecoratorMetadata*/
                    true);
                }
            }
            function getEntityNameForDecoratorMetadata(node) {
                if (node) {
                    switch (node.kind) {
                        case 193 /* IntersectionType */:
                        case 192 /* UnionType */:
                            return getEntityNameForDecoratorMetadataFromTypeList(node.types);
                        case 194 /* ConditionalType */:
                            return getEntityNameForDecoratorMetadataFromTypeList([node.trueType, node.falseType]);
                        case 196 /* ParenthesizedType */:
                        case 202 /* NamedTupleMember */:
                            return getEntityNameForDecoratorMetadata(node.type);
                        case 183 /* TypeReference */:
                            return node.typeName;
                    }
                }
            }
            function getEntityNameForDecoratorMetadataFromTypeList(types) {
                let commonEntityName;
                for (let typeNode of types) {
                    while (typeNode.kind === 196 /* ParenthesizedType */ || typeNode.kind === 202 /* NamedTupleMember */) {
                        typeNode = typeNode.type;
                    }
                    if (typeNode.kind === 146 /* NeverKeyword */) {
                        continue;
                    }
                    if (!strictNullChecks && (typeNode.kind === 201 /* LiteralType */ && typeNode.literal.kind === 106 /* NullKeyword */ || typeNode.kind === 157 /* UndefinedKeyword */)) {
                        continue;
                    }
                    const individualEntityName = getEntityNameForDecoratorMetadata(typeNode);
                    if (!individualEntityName) {
                        return void 0;
                    }
                    if (commonEntityName) {
                        if (!isIdentifier(commonEntityName) || !isIdentifier(individualEntityName) || commonEntityName.escapedText !== individualEntityName.escapedText) {
                            return void 0;
                        }
                    }
                    else {
                        commonEntityName = individualEntityName;
                    }
                }
                return commonEntityName;
            }
            function getParameterTypeNodeForDecoratorCheck(node) {
                const typeNode = getEffectiveTypeAnnotationNode(node);
                return isRestParameter(node) ? getRestParameterElementType(typeNode) : typeNode;
            }
            function checkDecorators(node) {
                if (!canHaveDecorators(node) || !hasDecorators(node) || !node.modifiers || !nodeCanBeDecorated(legacyDecorators, node, node.parent, node.parent.parent)) {
                    return;
                }
                const firstDecorator = find(node.modifiers, isDecorator);
                if (!firstDecorator) {
                    return;
                }
                if (legacyDecorators) {
                    checkExternalEmitHelpers(firstDecorator, 8 /* Decorate */);
                    if (node.kind === 169 /* Parameter */) {
                        checkExternalEmitHelpers(firstDecorator, 32 /* Param */);
                    }
                }
                else if (languageVersion < 99 /* ESNext */) {
                    checkExternalEmitHelpers(firstDecorator, 8 /* ESDecorateAndRunInitializers */);
                    if (isClassDeclaration(node)) {
                        if (!node.name) {
                            checkExternalEmitHelpers(firstDecorator, 8388608 /* SetFunctionName */);
                        }
                        else {
                            const member = getFirstTransformableStaticClassElement(node);
                            if (member) {
                                checkExternalEmitHelpers(firstDecorator, 8388608 /* SetFunctionName */);
                            }
                        }
                    }
                    else if (!isClassExpression(node)) {
                        if (isPrivateIdentifier(node.name) && (isMethodDeclaration(node) || isAccessor(node) || isAutoAccessorPropertyDeclaration(node))) {
                            checkExternalEmitHelpers(firstDecorator, 8388608 /* SetFunctionName */);
                        }
                        if (isComputedPropertyName(node.name)) {
                            checkExternalEmitHelpers(firstDecorator, 16777216 /* PropKey */);
                        }
                    }
                }
                if (compilerOptions.emitDecoratorMetadata) {
                    checkExternalEmitHelpers(firstDecorator, 16 /* Metadata */);
                    switch (node.kind) {
                        case 263 /* ClassDeclaration */:
                            const constructor = getFirstConstructorWithBody(node);
                            if (constructor) {
                                for (const parameter of constructor.parameters) {
                                    markDecoratorMedataDataTypeNodeAsReferenced(getParameterTypeNodeForDecoratorCheck(parameter));
                                }
                            }
                            break;
                        case 177 /* GetAccessor */:
                        case 178 /* SetAccessor */:
                            const otherKind = node.kind === 177 /* GetAccessor */ ? 178 /* SetAccessor */ : 177 /* GetAccessor */;
                            const otherAccessor = getDeclarationOfKind(getSymbolOfDeclaration(node), otherKind);
                            markDecoratorMedataDataTypeNodeAsReferenced(getAnnotatedAccessorTypeNode(node) || otherAccessor && getAnnotatedAccessorTypeNode(otherAccessor));
                            break;
                        case 174 /* MethodDeclaration */:
                            for (const parameter of node.parameters) {
                                markDecoratorMedataDataTypeNodeAsReferenced(getParameterTypeNodeForDecoratorCheck(parameter));
                            }
                            markDecoratorMedataDataTypeNodeAsReferenced(getEffectiveReturnTypeNode(node));
                            break;
                        case 172 /* PropertyDeclaration */:
                            markDecoratorMedataDataTypeNodeAsReferenced(getEffectiveTypeAnnotationNode(node));
                            break;
                        case 169 /* Parameter */:
                            markDecoratorMedataDataTypeNodeAsReferenced(getParameterTypeNodeForDecoratorCheck(node));
                            const containingSignature = node.parent;
                            for (const parameter of containingSignature.parameters) {
                                markDecoratorMedataDataTypeNodeAsReferenced(getParameterTypeNodeForDecoratorCheck(parameter));
                            }
                            markDecoratorMedataDataTypeNodeAsReferenced(getEffectiveReturnTypeNode(containingSignature));
                            break;
                    }
                }
                for (const modifier of node.modifiers) {
                    if (isDecorator(modifier)) {
                        checkDecorator(modifier);
                    }
                }
            }
            function checkFunctionDeclaration(node) {
                addLazyDiagnostic(checkFunctionDeclarationDiagnostics);
                function checkFunctionDeclarationDiagnostics() {
                    checkFunctionOrMethodDeclaration(node);
                    checkGrammarForGenerator(node);
                    checkCollisionsForDeclarationName(node, node.name);
                }
            }
            function checkJSDocTypeAliasTag(node) {
                if (!node.typeExpression) {
                    error2(node.name, Diagnostics.JSDoc_typedef_tag_should_either_have_a_type_annotation_or_be_followed_by_property_or_member_tags);
                }
                if (node.name) {
                    checkTypeNameIsReserved(node.name, Diagnostics.Type_alias_name_cannot_be_0);
                }
                checkSourceElement(node.typeExpression);
                checkTypeParameters(getEffectiveTypeParameterDeclarations(node));
            }
            function checkJSDocTemplateTag(node) {
                checkSourceElement(node.constraint);
                for (const tp of node.typeParameters) {
                    checkSourceElement(tp);
                }
            }
            function checkJSDocTypeTag(node) {
                checkSourceElement(node.typeExpression);
            }
            function checkJSDocSatisfiesTag(node) {
                checkSourceElement(node.typeExpression);
                const host2 = getEffectiveJSDocHost(node);
                if (host2) {
                    const tags = getAllJSDocTags(host2, isJSDocSatisfiesTag);
                    if (length(tags) > 1) {
                        for (let i = 1; i < length(tags); i++) {
                            const tagName = tags[i].tagName;
                            error2(tagName, Diagnostics._0_tag_already_specified, idText(tagName));
                        }
                    }
                }
            }
            function checkJSDocLinkLikeTag(node) {
                if (node.name) {
                    resolveJSDocMemberName(node.name, 
                    /*ignoreErrors*/
                    true);
                }
            }
            function checkJSDocParameterTag(node) {
                checkSourceElement(node.typeExpression);
            }
            function checkJSDocPropertyTag(node) {
                checkSourceElement(node.typeExpression);
            }
            function checkJSDocFunctionType(node) {
                addLazyDiagnostic(checkJSDocFunctionTypeImplicitAny);
                checkSignatureDeclaration(node);
                function checkJSDocFunctionTypeImplicitAny() {
                    if (!node.type && !isJSDocConstructSignature(node)) {
                        reportImplicitAny(node, anyType);
                    }
                }
            }
            function checkJSDocThisTag(node) {
                const host2 = getEffectiveJSDocHost(node);
                if (host2 && isArrowFunction(host2)) {
                    error2(node.tagName, Diagnostics.An_arrow_function_cannot_have_a_this_parameter);
                }
            }
            function checkJSDocImplementsTag(node) {
                const classLike = getEffectiveJSDocHost(node);
                if (!classLike || !isClassDeclaration(classLike) && !isClassExpression(classLike)) {
                    error2(classLike, Diagnostics.JSDoc_0_is_not_attached_to_a_class, idText(node.tagName));
                }
            }
            function checkJSDocAugmentsTag(node) {
                const classLike = getEffectiveJSDocHost(node);
                if (!classLike || !isClassDeclaration(classLike) && !isClassExpression(classLike)) {
                    error2(classLike, Diagnostics.JSDoc_0_is_not_attached_to_a_class, idText(node.tagName));
                    return;
                }
                const augmentsTags = getJSDocTags(classLike).filter(isJSDocAugmentsTag);
                Debug.assert(augmentsTags.length > 0);
                if (augmentsTags.length > 1) {
                    error2(augmentsTags[1], Diagnostics.Class_declarations_cannot_have_more_than_one_augments_or_extends_tag);
                }
                const name = getIdentifierFromEntityNameExpression(node.class.expression);
                const extend2 = getClassExtendsHeritageElement(classLike);
                if (extend2) {
                    const className = getIdentifierFromEntityNameExpression(extend2.expression);
                    if (className && name.escapedText !== className.escapedText) {
                        error2(name, Diagnostics.JSDoc_0_1_does_not_match_the_extends_2_clause, idText(node.tagName), idText(name), idText(className));
                    }
                }
            }
            function checkJSDocAccessibilityModifiers(node) {
                const host2 = getJSDocHost(node);
                if (host2 && isPrivateIdentifierClassElementDeclaration(host2)) {
                    error2(node, Diagnostics.An_accessibility_modifier_cannot_be_used_with_a_private_identifier);
                }
            }
            function getIdentifierFromEntityNameExpression(node) {
                switch (node.kind) {
                    case 80 /* Identifier */:
                        return node;
                    case 211 /* PropertyAccessExpression */:
                        return node.name;
                    default:
                        return void 0;
                }
            }
            function checkFunctionOrMethodDeclaration(node) {
                var _a;
                checkDecorators(node);
                checkSignatureDeclaration(node);
                const functionFlags = getFunctionFlags(node);
                if (node.name && node.name.kind === 167 /* ComputedPropertyName */) {
                    checkComputedPropertyName(node.name);
                }
                if (hasBindableName(node)) {
                    const symbol = getSymbolOfDeclaration(node);
                    const localSymbol = node.localSymbol || symbol;
                    const firstDeclaration = (_a = localSymbol.declarations) == null ? void 0 : _a.find(
                    // Get first non javascript function declaration
                    (declaration) => declaration.kind === node.kind && !(declaration.flags & 524288 /* JavaScriptFile */));
                    if (node === firstDeclaration) {
                        checkFunctionOrConstructorSymbol(localSymbol);
                    }
                    if (symbol.parent) {
                        checkFunctionOrConstructorSymbol(symbol);
                    }
                }
                const body = node.kind === 173 /* MethodSignature */ ? void 0 : node.body;
                checkSourceElement(body);
                checkAllCodePathsInNonVoidFunctionReturnOrThrow(node, getReturnTypeFromAnnotation(node));
                addLazyDiagnostic(checkFunctionOrMethodDeclarationDiagnostics);
                if (isInJSFile(node)) {
                    const typeTag = getJSDocTypeTag(node);
                    if (typeTag && typeTag.typeExpression && !getContextualCallSignature(getTypeFromTypeNode(typeTag.typeExpression), node)) {
                        error2(typeTag.typeExpression.type, Diagnostics.The_type_of_a_function_declaration_must_match_the_function_s_signature);
                    }
                }
                function checkFunctionOrMethodDeclarationDiagnostics() {
                    if (!getEffectiveReturnTypeNode(node)) {
                        if (nodeIsMissing(body) && !isPrivateWithinAmbient(node)) {
                            reportImplicitAny(node, anyType);
                        }
                        if (functionFlags & 1 /* Generator */ && nodeIsPresent(body)) {
                            getReturnTypeOfSignature(getSignatureFromDeclaration(node));
                        }
                    }
                }
            }
            function registerForUnusedIdentifiersCheck(node) {
                addLazyDiagnostic(registerForUnusedIdentifiersCheckDiagnostics);
                function registerForUnusedIdentifiersCheckDiagnostics() {
                    const sourceFile = getSourceFileOfNode(node);
                    let potentiallyUnusedIdentifiers = allPotentiallyUnusedIdentifiers.get(sourceFile.path);
                    if (!potentiallyUnusedIdentifiers) {
                        potentiallyUnusedIdentifiers = [];
                        allPotentiallyUnusedIdentifiers.set(sourceFile.path, potentiallyUnusedIdentifiers);
                    }
                    potentiallyUnusedIdentifiers.push(node);
                }
            }
            function checkUnusedIdentifiers(potentiallyUnusedIdentifiers, addDiagnostic) {
                for (const node of potentiallyUnusedIdentifiers) {
                    switch (node.kind) {
                        case 263 /* ClassDeclaration */:
                        case 231 /* ClassExpression */:
                            checkUnusedClassMembers(node, addDiagnostic);
                            checkUnusedTypeParameters(node, addDiagnostic);
                            break;
                        case 312 /* SourceFile */:
                        case 267 /* ModuleDeclaration */:
                        case 241 /* Block */:
                        case 269 /* CaseBlock */:
                        case 248 /* ForStatement */:
                        case 249 /* ForInStatement */:
                        case 250 /* ForOfStatement */:
                            checkUnusedLocalsAndParameters(node, addDiagnostic);
                            break;
                        case 176 /* Constructor */:
                        case 218 /* FunctionExpression */:
                        case 262 /* FunctionDeclaration */:
                        case 219 /* ArrowFunction */:
                        case 174 /* MethodDeclaration */:
                        case 177 /* GetAccessor */:
                        case 178 /* SetAccessor */:
                            if (node.body) {
                                checkUnusedLocalsAndParameters(node, addDiagnostic);
                            }
                            checkUnusedTypeParameters(node, addDiagnostic);
                            break;
                        case 173 /* MethodSignature */:
                        case 179 /* CallSignature */:
                        case 180 /* ConstructSignature */:
                        case 184 /* FunctionType */:
                        case 185 /* ConstructorType */:
                        case 265 /* TypeAliasDeclaration */:
                        case 264 /* InterfaceDeclaration */:
                            checkUnusedTypeParameters(node, addDiagnostic);
                            break;
                        case 195 /* InferType */:
                            checkUnusedInferTypeParameter(node, addDiagnostic);
                            break;
                        default:
                            Debug.assertNever(node, "Node should not have been registered for unused identifiers check");
                    }
                }
            }
            function errorUnusedLocal(declaration, name, addDiagnostic) {
                const node = getNameOfDeclaration(declaration) || declaration;
                const message = isTypeDeclaration(declaration) ? Diagnostics._0_is_declared_but_never_used : Diagnostics._0_is_declared_but_its_value_is_never_read;
                addDiagnostic(declaration, 0 /* Local */, createDiagnosticForNode(node, message, name));
            }
            function isIdentifierThatStartsWithUnderscore(node) {
                return isIdentifier(node) && idText(node).charCodeAt(0) === 95 /* _ */;
            }
            function checkUnusedClassMembers(node, addDiagnostic) {
                for (const member of node.members) {
                    switch (member.kind) {
                        case 174 /* MethodDeclaration */:
                        case 172 /* PropertyDeclaration */:
                        case 177 /* GetAccessor */:
                        case 178 /* SetAccessor */:
                            if (member.kind === 178 /* SetAccessor */ && member.symbol.flags & 32768 /* GetAccessor */) {
                                break;
                            }
                            const symbol = getSymbolOfDeclaration(member);
                            if (!symbol.isReferenced && (hasEffectiveModifier(member, 2 /* Private */) || isNamedDeclaration(member) && isPrivateIdentifier(member.name)) && !(member.flags & 33554432 /* Ambient */)) {
                                addDiagnostic(member, 0 /* Local */, createDiagnosticForNode(member.name, Diagnostics._0_is_declared_but_its_value_is_never_read, symbolToString(symbol)));
                            }
                            break;
                        case 176 /* Constructor */:
                            for (const parameter of member.parameters) {
                                if (!parameter.symbol.isReferenced && hasSyntacticModifier(parameter, 2 /* Private */)) {
                                    addDiagnostic(parameter, 0 /* Local */, createDiagnosticForNode(parameter.name, Diagnostics.Property_0_is_declared_but_its_value_is_never_read, symbolName(parameter.symbol)));
                                }
                            }
                            break;
                        case 181 /* IndexSignature */:
                        case 240 /* SemicolonClassElement */:
                        case 175 /* ClassStaticBlockDeclaration */:
                            break;
                        default:
                            Debug.fail("Unexpected class member");
                    }
                }
            }
            function checkUnusedInferTypeParameter(node, addDiagnostic) {
                const { typeParameter } = node;
                if (isTypeParameterUnused(typeParameter)) {
                    addDiagnostic(node, 1 /* Parameter */, createDiagnosticForNode(node, Diagnostics._0_is_declared_but_its_value_is_never_read, idText(typeParameter.name)));
                }
            }
            function checkUnusedTypeParameters(node, addDiagnostic) {
                const declarations = getSymbolOfDeclaration(node).declarations;
                if (!declarations || last(declarations) !== node)
                    return;
                const typeParameters = getEffectiveTypeParameterDeclarations(node);
                const seenParentsWithEveryUnused = /* @__PURE__ */ new Set();
                for (const typeParameter of typeParameters) {
                    if (!isTypeParameterUnused(typeParameter))
                        continue;
                    const name = idText(typeParameter.name);
                    const { parent: parent2 } = typeParameter;
                    if (parent2.kind !== 195 /* InferType */ && parent2.typeParameters.every(isTypeParameterUnused)) {
                        if (tryAddToSet(seenParentsWithEveryUnused, parent2)) {
                            const sourceFile = getSourceFileOfNode(parent2);
                            const range = isJSDocTemplateTag(parent2) ? rangeOfNode(parent2) : rangeOfTypeParameters(sourceFile, parent2.typeParameters);
                            const only = parent2.typeParameters.length === 1;
                            const messageAndArg = only ? [Diagnostics._0_is_declared_but_its_value_is_never_read, name] : [Diagnostics.All_type_parameters_are_unused];
                            addDiagnostic(typeParameter, 1 /* Parameter */, createFileDiagnostic(sourceFile, range.pos, range.end - range.pos, ...messageAndArg));
                        }
                    }
                    else {
                        addDiagnostic(typeParameter, 1 /* Parameter */, createDiagnosticForNode(typeParameter, Diagnostics._0_is_declared_but_its_value_is_never_read, name));
                    }
                }
            }
            function isTypeParameterUnused(typeParameter) {
                return !(getMergedSymbol(typeParameter.symbol).isReferenced & 262144 /* TypeParameter */) && !isIdentifierThatStartsWithUnderscore(typeParameter.name);
            }
            function addToGroup(map2, key, value, getKey) {
                const keyString = String(getKey(key));
                const group2 = map2.get(keyString);
                if (group2) {
                    group2[1].push(value);
                }
                else {
                    map2.set(keyString, [key, [value]]);
                }
            }
            function tryGetRootParameterDeclaration(node) {
                return tryCast(getRootDeclaration(node), isParameter);
            }
            function isValidUnusedLocalDeclaration(declaration) {
                if (isBindingElement(declaration)) {
                    if (isObjectBindingPattern(declaration.parent)) {
                        return !!(declaration.propertyName && isIdentifierThatStartsWithUnderscore(declaration.name));
                    }
                    return isIdentifierThatStartsWithUnderscore(declaration.name);
                }
                return isAmbientModule(declaration) || (isVariableDeclaration(declaration) && isForInOrOfStatement(declaration.parent.parent) || isImportedDeclaration(declaration)) && isIdentifierThatStartsWithUnderscore(declaration.name);
            }
            function checkUnusedLocalsAndParameters(nodeWithLocals, addDiagnostic) {
                const unusedImports = /* @__PURE__ */ new Map();
                const unusedDestructures = /* @__PURE__ */ new Map();
                const unusedVariables = /* @__PURE__ */ new Map();
                nodeWithLocals.locals.forEach((local) => {
                    if (local.flags & 262144 /* TypeParameter */ ? !(local.flags & 3 /* Variable */ && !(local.isReferenced & 3 /* Variable */)) : local.isReferenced || local.exportSymbol) {
                        return;
                    }
                    if (local.declarations) {
                        for (const declaration of local.declarations) {
                            if (isValidUnusedLocalDeclaration(declaration)) {
                                continue;
                            }
                            if (isImportedDeclaration(declaration)) {
                                addToGroup(unusedImports, importClauseFromImported(declaration), declaration, getNodeId);
                            }
                            else if (isBindingElement(declaration) && isObjectBindingPattern(declaration.parent)) {
                                const lastElement = last(declaration.parent.elements);
                                if (declaration === lastElement || !last(declaration.parent.elements).dotDotDotToken) {
                                    addToGroup(unusedDestructures, declaration.parent, declaration, getNodeId);
                                }
                            }
                            else if (isVariableDeclaration(declaration)) {
                                const blockScopeKind = getCombinedNodeFlagsCached(declaration) & 7 /* BlockScoped */;
                                const name = getNameOfDeclaration(declaration);
                                if (blockScopeKind !== 4 /* Using */ && blockScopeKind !== 6 /* AwaitUsing */ || !name || !isIdentifierThatStartsWithUnderscore(name)) {
                                    addToGroup(unusedVariables, declaration.parent, declaration, getNodeId);
                                }
                            }
                            else {
                                const parameter = local.valueDeclaration && tryGetRootParameterDeclaration(local.valueDeclaration);
                                const name = local.valueDeclaration && getNameOfDeclaration(local.valueDeclaration);
                                if (parameter && name) {
                                    if (!isParameterPropertyDeclaration(parameter, parameter.parent) && !parameterIsThisKeyword(parameter) && !isIdentifierThatStartsWithUnderscore(name)) {
                                        if (isBindingElement(declaration) && isArrayBindingPattern(declaration.parent)) {
                                            addToGroup(unusedDestructures, declaration.parent, declaration, getNodeId);
                                        }
                                        else {
                                            addDiagnostic(parameter, 1 /* Parameter */, createDiagnosticForNode(name, Diagnostics._0_is_declared_but_its_value_is_never_read, symbolName(local)));
                                        }
                                    }
                                }
                                else {
                                    errorUnusedLocal(declaration, symbolName(local), addDiagnostic);
                                }
                            }
                        }
                    }
                });
                unusedImports.forEach(([importClause, unuseds]) => {
                    const importDecl = importClause.parent;
                    const nDeclarations = (importClause.name ? 1 : 0) + (importClause.namedBindings ? importClause.namedBindings.kind === 274 /* NamespaceImport */ ? 1 : importClause.namedBindings.elements.length : 0);
                    if (nDeclarations === unuseds.length) {
                        addDiagnostic(importDecl, 0 /* Local */, unuseds.length === 1 ? createDiagnosticForNode(importDecl, Diagnostics._0_is_declared_but_its_value_is_never_read, idText(first(unuseds).name)) : createDiagnosticForNode(importDecl, Diagnostics.All_imports_in_import_declaration_are_unused));
                    }
                    else {
                        for (const unused of unuseds)
                            errorUnusedLocal(unused, idText(unused.name), addDiagnostic);
                    }
                });
                unusedDestructures.forEach(([bindingPattern, bindingElements]) => {
                    const kind = tryGetRootParameterDeclaration(bindingPattern.parent) ? 1 /* Parameter */ : 0 /* Local */;
                    if (bindingPattern.elements.length === bindingElements.length) {
                        if (bindingElements.length === 1 && bindingPattern.parent.kind === 260 /* VariableDeclaration */ && bindingPattern.parent.parent.kind === 261 /* VariableDeclarationList */) {
                            addToGroup(unusedVariables, bindingPattern.parent.parent, bindingPattern.parent, getNodeId);
                        }
                        else {
                            addDiagnostic(bindingPattern, kind, bindingElements.length === 1 ? createDiagnosticForNode(bindingPattern, Diagnostics._0_is_declared_but_its_value_is_never_read, bindingNameText(first(bindingElements).name)) : createDiagnosticForNode(bindingPattern, Diagnostics.All_destructured_elements_are_unused));
                        }
                    }
                    else {
                        for (const e of bindingElements) {
                            addDiagnostic(e, kind, createDiagnosticForNode(e, Diagnostics._0_is_declared_but_its_value_is_never_read, bindingNameText(e.name)));
                        }
                    }
                });
                unusedVariables.forEach(([declarationList, declarations]) => {
                    if (declarationList.declarations.length === declarations.length) {
                        addDiagnostic(declarationList, 0 /* Local */, declarations.length === 1 ? createDiagnosticForNode(first(declarations).name, Diagnostics._0_is_declared_but_its_value_is_never_read, bindingNameText(first(declarations).name)) : createDiagnosticForNode(declarationList.parent.kind === 243 /* VariableStatement */ ? declarationList.parent : declarationList, Diagnostics.All_variables_are_unused));
                    }
                    else {
                        for (const decl of declarations) {
                            addDiagnostic(decl, 0 /* Local */, createDiagnosticForNode(decl, Diagnostics._0_is_declared_but_its_value_is_never_read, bindingNameText(decl.name)));
                        }
                    }
                });
            }
            function checkPotentialUncheckedRenamedBindingElementsInTypes() {
                var _a;
                for (const node of potentialUnusedRenamedBindingElementsInTypes) {
                    if (!((_a = getSymbolOfDeclaration(node)) == null ? void 0 : _a.isReferenced)) {
                        const wrappingDeclaration = walkUpBindingElementsAndPatterns(node);
                        Debug.assert(isParameterDeclaration(wrappingDeclaration), "Only parameter declaration should be checked here");
                        const diagnostic = createDiagnosticForNode(node.name, Diagnostics._0_is_an_unused_renaming_of_1_Did_you_intend_to_use_it_as_a_type_annotation, declarationNameToString(node.name), declarationNameToString(node.propertyName));
                        if (!wrappingDeclaration.type) {
                            addRelatedInfo(diagnostic, createFileDiagnostic(getSourceFileOfNode(wrappingDeclaration), wrappingDeclaration.end, 1, Diagnostics.We_can_only_write_a_type_for_0_by_adding_a_type_for_the_entire_parameter_here, declarationNameToString(node.propertyName)));
                        }
                        diagnostics.add(diagnostic);
                    }
                }
            }
            function bindingNameText(name) {
                switch (name.kind) {
                    case 80 /* Identifier */:
                        return idText(name);
                    case 207 /* ArrayBindingPattern */:
                    case 206 /* ObjectBindingPattern */:
                        return bindingNameText(cast(first(name.elements), isBindingElement).name);
                    default:
                        return Debug.assertNever(name);
                }
            }
            function isImportedDeclaration(node) {
                return node.kind === 273 /* ImportClause */ || node.kind === 276 /* ImportSpecifier */ || node.kind === 274 /* NamespaceImport */;
            }
            function importClauseFromImported(decl) {
                return decl.kind === 273 /* ImportClause */ ? decl : decl.kind === 274 /* NamespaceImport */ ? decl.parent : decl.parent.parent;
            }
            function checkBlock(node) {
                if (node.kind === 241 /* Block */) {
                    checkGrammarStatementInAmbientContext(node);
                }
                if (isFunctionOrModuleBlock(node)) {
                    const saveFlowAnalysisDisabled = flowAnalysisDisabled;
                    forEach(node.statements, checkSourceElement);
                    flowAnalysisDisabled = saveFlowAnalysisDisabled;
                }
                else {
                    forEach(node.statements, checkSourceElement);
                }
                if (node.locals) {
                    registerForUnusedIdentifiersCheck(node);
                }
            }
            function checkCollisionWithArgumentsInGeneratedCode(node) {
                if (languageVersion >= 2 /* ES2015 */ || !hasRestParameter(node) || node.flags & 33554432 /* Ambient */ || nodeIsMissing(node.body)) {
                    return;
                }
                forEach(node.parameters, (p) => {
                    if (p.name && !isBindingPattern(p.name) && p.name.escapedText === argumentsSymbol.escapedName) {
                        errorSkippedOn("noEmit", p, Diagnostics.Duplicate_identifier_arguments_Compiler_uses_arguments_to_initialize_rest_parameters);
                    }
                });
            }
            function needCollisionCheckForIdentifier(node, identifier, name) {
                if ((identifier == null ? void 0 : identifier.escapedText) !== name) {
                    return false;
                }
                if (node.kind === 172 /* PropertyDeclaration */ || node.kind === 171 /* PropertySignature */ || node.kind === 174 /* MethodDeclaration */ || node.kind === 173 /* MethodSignature */ || node.kind === 177 /* GetAccessor */ || node.kind === 178 /* SetAccessor */ || node.kind === 303 /* PropertyAssignment */) {
                    return false;
                }
                if (node.flags & 33554432 /* Ambient */) {
                    return false;
                }
                if (isImportClause(node) || isImportEqualsDeclaration(node) || isImportSpecifier(node)) {
                    if (isTypeOnlyImportOrExportDeclaration(node)) {
                        return false;
                    }
                }
                const root = getRootDeclaration(node);
                if (isParameter(root) && nodeIsMissing(root.parent.body)) {
                    return false;
                }
                return true;
            }
            function checkIfThisIsCapturedInEnclosingScope(node) {
                findAncestor(node, (current) => {
                    if (getNodeCheckFlags(current) & 4 /* CaptureThis */) {
                        const isDeclaration2 = node.kind !== 80 /* Identifier */;
                        if (isDeclaration2) {
                            error2(getNameOfDeclaration(node), Diagnostics.Duplicate_identifier_this_Compiler_uses_variable_declaration_this_to_capture_this_reference);
                        }
                        else {
                            error2(node, Diagnostics.Expression_resolves_to_variable_declaration_this_that_compiler_uses_to_capture_this_reference);
                        }
                        return true;
                    }
                    return false;
                });
            }
            function checkIfNewTargetIsCapturedInEnclosingScope(node) {
                findAncestor(node, (current) => {
                    if (getNodeCheckFlags(current) & 8 /* CaptureNewTarget */) {
                        const isDeclaration2 = node.kind !== 80 /* Identifier */;
                        if (isDeclaration2) {
                            error2(getNameOfDeclaration(node), Diagnostics.Duplicate_identifier_newTarget_Compiler_uses_variable_declaration_newTarget_to_capture_new_target_meta_property_reference);
                        }
                        else {
                            error2(node, Diagnostics.Expression_resolves_to_variable_declaration_newTarget_that_compiler_uses_to_capture_new_target_meta_property_reference);
                        }
                        return true;
                    }
                    return false;
                });
            }
            function checkCollisionWithRequireExportsInGeneratedCode(node, name) {
                if (moduleKind >= 5 /* ES2015 */ && !(moduleKind >= 100 /* Node16 */ && getSourceFileOfNode(node).impliedNodeFormat === 1 /* CommonJS */)) {
                    return;
                }
                if (!name || !needCollisionCheckForIdentifier(node, name, "require") && !needCollisionCheckForIdentifier(node, name, "exports")) {
                    return;
                }
                if (isModuleDeclaration(node) && getModuleInstanceState(node) !== 1 /* Instantiated */) {
                    return;
                }
                const parent2 = getDeclarationContainer(node);
                if (parent2.kind === 312 /* SourceFile */ && isExternalOrCommonJsModule(parent2)) {
                    errorSkippedOn("noEmit", name, Diagnostics.Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module, declarationNameToString(name), declarationNameToString(name));
                }
            }
            function checkCollisionWithGlobalPromiseInGeneratedCode(node, name) {
                if (!name || languageVersion >= 4 /* ES2017 */ || !needCollisionCheckForIdentifier(node, name, "Promise")) {
                    return;
                }
                if (isModuleDeclaration(node) && getModuleInstanceState(node) !== 1 /* Instantiated */) {
                    return;
                }
                const parent2 = getDeclarationContainer(node);
                if (parent2.kind === 312 /* SourceFile */ && isExternalOrCommonJsModule(parent2) && parent2.flags & 4096 /* HasAsyncFunctions */) {
                    errorSkippedOn("noEmit", name, Diagnostics.Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module_containing_async_functions, declarationNameToString(name), declarationNameToString(name));
                }
            }
            function recordPotentialCollisionWithWeakMapSetInGeneratedCode(node, name) {
                if (languageVersion <= 8 /* ES2021 */ && (needCollisionCheckForIdentifier(node, name, "WeakMap") || needCollisionCheckForIdentifier(node, name, "WeakSet"))) {
                    potentialWeakMapSetCollisions.push(node);
                }
            }
            function checkWeakMapSetCollision(node) {
                const enclosingBlockScope = getEnclosingBlockScopeContainer(node);
                if (getNodeCheckFlags(enclosingBlockScope) & 1048576 /* ContainsClassWithPrivateIdentifiers */) {
                    Debug.assert(isNamedDeclaration(node) && isIdentifier(node.name) && typeof node.name.escapedText === "string", "The target of a WeakMap/WeakSet collision check should be an identifier");
                    errorSkippedOn("noEmit", node, Diagnostics.Compiler_reserves_name_0_when_emitting_private_identifier_downlevel, node.name.escapedText);
                }
            }
            function recordPotentialCollisionWithReflectInGeneratedCode(node, name) {
                if (name && languageVersion >= 2 /* ES2015 */ && languageVersion <= 8 /* ES2021 */ && needCollisionCheckForIdentifier(node, name, "Reflect")) {
                    potentialReflectCollisions.push(node);
                }
            }
            function checkReflectCollision(node) {
                let hasCollision = false;
                if (isClassExpression(node)) {
                    for (const member of node.members) {
                        if (getNodeCheckFlags(member) & 2097152 /* ContainsSuperPropertyInStaticInitializer */) {
                            hasCollision = true;
                            break;
                        }
                    }
                }
                else if (isFunctionExpression(node)) {
                    if (getNodeCheckFlags(node) & 2097152 /* ContainsSuperPropertyInStaticInitializer */) {
                        hasCollision = true;
                    }
                }
                else {
                    const container = getEnclosingBlockScopeContainer(node);
                    if (container && getNodeCheckFlags(container) & 2097152 /* ContainsSuperPropertyInStaticInitializer */) {
                        hasCollision = true;
                    }
                }
                if (hasCollision) {
                    Debug.assert(isNamedDeclaration(node) && isIdentifier(node.name), "The target of a Reflect collision check should be an identifier");
                    errorSkippedOn("noEmit", node, Diagnostics.Duplicate_identifier_0_Compiler_reserves_name_1_when_emitting_super_references_in_static_initializers, declarationNameToString(node.name), "Reflect");
                }
            }
            function checkCollisionsForDeclarationName(node, name) {
                if (!name)
                    return;
                checkCollisionWithRequireExportsInGeneratedCode(node, name);
                checkCollisionWithGlobalPromiseInGeneratedCode(node, name);
                recordPotentialCollisionWithWeakMapSetInGeneratedCode(node, name);
                recordPotentialCollisionWithReflectInGeneratedCode(node, name);
                if (isClassLike(node)) {
                    checkTypeNameIsReserved(name, Diagnostics.Class_name_cannot_be_0);
                    if (!(node.flags & 33554432 /* Ambient */)) {
                        checkClassNameCollisionWithObject(name);
                    }
                }
                else if (isEnumDeclaration(node)) {
                    checkTypeNameIsReserved(name, Diagnostics.Enum_name_cannot_be_0);
                }
            }
            function checkVarDeclaredNamesNotShadowed(node) {
                if ((getCombinedNodeFlagsCached(node) & 7 /* BlockScoped */) !== 0 || isParameterDeclaration(node)) {
                    return;
                }
                const symbol = getSymbolOfDeclaration(node);
                if (symbol.flags & 1 /* FunctionScopedVariable */) {
                    if (!isIdentifier(node.name))
                        return Debug.fail();
                    const localDeclarationSymbol = resolveName(node, node.name.escapedText, 3 /* Variable */, 
                    /*nameNotFoundMessage*/
                    void 0, 
                    /*nameArg*/
                    void 0, 
                    /*isUse*/
                    false);
                    if (localDeclarationSymbol && localDeclarationSymbol !== symbol && localDeclarationSymbol.flags & 2 /* BlockScopedVariable */) {
                        if (getDeclarationNodeFlagsFromSymbol(localDeclarationSymbol) & 7 /* BlockScoped */) {
                            const varDeclList = getAncestor(localDeclarationSymbol.valueDeclaration, 261 /* VariableDeclarationList */);
                            const container = varDeclList.parent.kind === 243 /* VariableStatement */ && varDeclList.parent.parent ? varDeclList.parent.parent : void 0;
                            const namesShareScope = container && (container.kind === 241 /* Block */ && isFunctionLike(container.parent) || container.kind === 268 /* ModuleBlock */ || container.kind === 267 /* ModuleDeclaration */ || container.kind === 312 /* SourceFile */);
                            if (!namesShareScope) {
                                const name = symbolToString(localDeclarationSymbol);
                                error2(node, Diagnostics.Cannot_initialize_outer_scoped_variable_0_in_the_same_scope_as_block_scoped_declaration_1, name, name);
                            }
                        }
                    }
                }
            }
            function convertAutoToAny(type) {
                return type === autoType ? anyType : type === autoArrayType ? anyArrayType : type;
            }
            function checkVariableLikeDeclaration(node) {
                var _a;
                checkDecorators(node);
                if (!isBindingElement(node)) {
                    checkSourceElement(node.type);
                }
                if (!node.name) {
                    return;
                }
                if (node.name.kind === 167 /* ComputedPropertyName */) {
                    checkComputedPropertyName(node.name);
                    if (hasOnlyExpressionInitializer(node) && node.initializer) {
                        checkExpressionCached(node.initializer);
                    }
                }
                if (isBindingElement(node)) {
                    if (node.propertyName && isIdentifier(node.name) && isParameterDeclaration(node) && nodeIsMissing(getContainingFunction(node).body)) {
                        potentialUnusedRenamedBindingElementsInTypes.push(node);
                        return;
                    }
                    if (isObjectBindingPattern(node.parent) && node.dotDotDotToken && languageVersion < 5 /* ES2018 */) {
                        checkExternalEmitHelpers(node, 4 /* Rest */);
                    }
                    if (node.propertyName && node.propertyName.kind === 167 /* ComputedPropertyName */) {
                        checkComputedPropertyName(node.propertyName);
                    }
                    const parent2 = node.parent.parent;
                    const parentCheckMode = node.dotDotDotToken ? 32 /* RestBindingElement */ : 0 /* Normal */;
                    const parentType = getTypeForBindingElementParent(parent2, parentCheckMode);
                    const name = node.propertyName || node.name;
                    if (parentType && !isBindingPattern(name)) {
                        const exprType = getLiteralTypeFromPropertyName(name);
                        if (isTypeUsableAsPropertyName(exprType)) {
                            const nameText = getPropertyNameFromType(exprType);
                            const property = getPropertyOfType(parentType, nameText);
                            if (property) {
                                markPropertyAsReferenced(property, 
                                /*nodeForCheckWriteOnly*/
                                void 0, 
                                /*isSelfTypeAccess*/
                                false);
                                checkPropertyAccessibility(node, !!parent2.initializer && parent2.initializer.kind === 108 /* SuperKeyword */, 
                                /*writing*/
                                false, parentType, property);
                            }
                        }
                    }
                }
                if (isBindingPattern(node.name)) {
                    if (node.name.kind === 207 /* ArrayBindingPattern */ && languageVersion < 2 /* ES2015 */ && compilerOptions.downlevelIteration) {
                        checkExternalEmitHelpers(node, 512 /* Read */);
                    }
                    forEach(node.name.elements, checkSourceElement);
                }
                if (node.initializer && isParameterDeclaration(node) && nodeIsMissing(getContainingFunction(node).body)) {
                    error2(node, Diagnostics.A_parameter_initializer_is_only_allowed_in_a_function_or_constructor_implementation);
                    return;
                }
                if (isBindingPattern(node.name)) {
                    if (isInAmbientOrTypeNode(node)) {
                        return;
                    }
                    const needCheckInitializer = hasOnlyExpressionInitializer(node) && node.initializer && node.parent.parent.kind !== 249 /* ForInStatement */;
                    const needCheckWidenedType = !some(node.name.elements, not(isOmittedExpression));
                    if (needCheckInitializer || needCheckWidenedType) {
                        const widenedType = getWidenedTypeForVariableLikeDeclaration(node);
                        if (needCheckInitializer) {
                            const initializerType = checkExpressionCached(node.initializer);
                            if (strictNullChecks && needCheckWidenedType) {
                                checkNonNullNonVoidType(initializerType, node);
                            }
                            else {
                                checkTypeAssignableToAndOptionallyElaborate(initializerType, getWidenedTypeForVariableLikeDeclaration(node), node, node.initializer);
                            }
                        }
                        if (needCheckWidenedType) {
                            if (isArrayBindingPattern(node.name)) {
                                checkIteratedTypeOrElementType(65 /* Destructuring */, widenedType, undefinedType, node);
                            }
                            else if (strictNullChecks) {
                                checkNonNullNonVoidType(widenedType, node);
                            }
                        }
                    }
                    return;
                }
                const symbol = getSymbolOfDeclaration(node);
                if (symbol.flags & 2097152 /* Alias */ && (isVariableDeclarationInitializedToBareOrAccessedRequire(node) || isBindingElementOfBareOrAccessedRequire(node))) {
                    checkAliasSymbol(node);
                    return;
                }
                const type = convertAutoToAny(getTypeOfSymbol(symbol));
                if (node === symbol.valueDeclaration) {
                    const initializer = hasOnlyExpressionInitializer(node) && getEffectiveInitializer(node);
                    if (initializer) {
                        const isJSObjectLiteralInitializer = isInJSFile(node) && isObjectLiteralExpression(initializer) && (initializer.properties.length === 0 || isPrototypeAccess(node.name)) && !!((_a = symbol.exports) == null ? void 0 : _a.size);
                        if (!isJSObjectLiteralInitializer && node.parent.parent.kind !== 249 /* ForInStatement */) {
                            const initializerType = checkExpressionCached(initializer);
                            checkTypeAssignableToAndOptionallyElaborate(initializerType, type, node, initializer, 
                            /*headMessage*/
                            void 0);
                            const blockScopeKind = getCombinedNodeFlagsCached(node) & 7 /* BlockScoped */;
                            if (blockScopeKind === 6 /* AwaitUsing */) {
                                const globalAsyncDisposableType = getGlobalAsyncDisposableType(
                                /*reportErrors*/
                                true);
                                const globalDisposableType = getGlobalDisposableType(
                                /*reportErrors*/
                                true);
                                if (globalAsyncDisposableType !== emptyObjectType && globalDisposableType !== emptyObjectType) {
                                    const optionalDisposableType = getUnionType([globalAsyncDisposableType, globalDisposableType, nullType, undefinedType]);
                                    checkTypeAssignableTo(initializerType, optionalDisposableType, initializer, Diagnostics.The_initializer_of_an_await_using_declaration_must_be_either_an_object_with_a_Symbol_asyncDispose_or_Symbol_dispose_method_or_be_null_or_undefined);
                                }
                            }
                            else if (blockScopeKind === 4 /* Using */) {
                                const globalDisposableType = getGlobalDisposableType(
                                /*reportErrors*/
                                true);
                                if (globalDisposableType !== emptyObjectType) {
                                    const optionalDisposableType = getUnionType([globalDisposableType, nullType, undefinedType]);
                                    checkTypeAssignableTo(initializerType, optionalDisposableType, initializer, Diagnostics.The_initializer_of_a_using_declaration_must_be_either_an_object_with_a_Symbol_dispose_method_or_be_null_or_undefined);
                                }
                            }
                        }
                    }
                    if (symbol.declarations && symbol.declarations.length > 1) {
                        if (some(symbol.declarations, (d) => d !== node && isVariableLike(d) && !areDeclarationFlagsIdentical(d, node))) {
                            error2(node.name, Diagnostics.All_declarations_of_0_must_have_identical_modifiers, declarationNameToString(node.name));
                        }
                    }
                }
                else {
                    const declarationType = convertAutoToAny(getWidenedTypeForVariableLikeDeclaration(node));
                    if (!isErrorType(type) && !isErrorType(declarationType) && !isTypeIdenticalTo(type, declarationType) && !(symbol.flags & 67108864 /* Assignment */)) {
                        errorNextVariableOrPropertyDeclarationMustHaveSameType(symbol.valueDeclaration, type, node, declarationType);
                    }
                    if (hasOnlyExpressionInitializer(node) && node.initializer) {
                        checkTypeAssignableToAndOptionallyElaborate(checkExpressionCached(node.initializer), declarationType, node, node.initializer, 
                        /*headMessage*/
                        void 0);
                    }
                    if (symbol.valueDeclaration && !areDeclarationFlagsIdentical(node, symbol.valueDeclaration)) {
                        error2(node.name, Diagnostics.All_declarations_of_0_must_have_identical_modifiers, declarationNameToString(node.name));
                    }
                }
                if (node.kind !== 172 /* PropertyDeclaration */ && node.kind !== 171 /* PropertySignature */) {
                    checkExportsOnMergedDeclarations(node);
                    if (node.kind === 260 /* VariableDeclaration */ || node.kind === 208 /* BindingElement */) {
                        checkVarDeclaredNamesNotShadowed(node);
                    }
                    checkCollisionsForDeclarationName(node, node.name);
                }
            }
            function errorNextVariableOrPropertyDeclarationMustHaveSameType(firstDeclaration, firstType, nextDeclaration, nextType) {
                const nextDeclarationName = getNameOfDeclaration(nextDeclaration);
                const message = nextDeclaration.kind === 172 /* PropertyDeclaration */ || nextDeclaration.kind === 171 /* PropertySignature */ ? Diagnostics.Subsequent_property_declarations_must_have_the_same_type_Property_0_must_be_of_type_1_but_here_has_type_2 : Diagnostics.Subsequent_variable_declarations_must_have_the_same_type_Variable_0_must_be_of_type_1_but_here_has_type_2;
                const declName = declarationNameToString(nextDeclarationName);
                const err = error2(nextDeclarationName, message, declName, typeToString(firstType), typeToString(nextType));
                if (firstDeclaration) {
                    addRelatedInfo(err, createDiagnosticForNode(firstDeclaration, Diagnostics._0_was_also_declared_here, declName));
                }
            }
            function areDeclarationFlagsIdentical(left, right) {
                if (left.kind === 169 /* Parameter */ && right.kind === 260 /* VariableDeclaration */ || left.kind === 260 /* VariableDeclaration */ && right.kind === 169 /* Parameter */) {
                    return true;
                }
                if (hasQuestionToken(left) !== hasQuestionToken(right)) {
                    return false;
                }
                const interestingFlags = 2 /* Private */ | 4 /* Protected */ | 1024 /* Async */ | 64 /* Abstract */ | 8 /* Readonly */ | 256 /* Static */;
                return getSelectedEffectiveModifierFlags(left, interestingFlags) === getSelectedEffectiveModifierFlags(right, interestingFlags);
            }
            function checkVariableDeclaration(node) {
                var _a, _b;
                (_a = tracing) == null ? void 0 : _a.push(tracing.Phase.Check, "checkVariableDeclaration", { kind: node.kind, pos: node.pos, end: node.end, path: node.tracingPath });
                checkGrammarVariableDeclaration(node);
                checkVariableLikeDeclaration(node);
                (_b = tracing) == null ? void 0 : _b.pop();
            }
            function checkBindingElement(node) {
                checkGrammarBindingElement(node);
                return checkVariableLikeDeclaration(node);
            }
            function checkVariableDeclarationList(node) {
                const blockScopeKind = getCombinedNodeFlags(node) & 7 /* BlockScoped */;
                if (blockScopeKind === 4 /* Using */ || blockScopeKind === 6 /* AwaitUsing */) {
                    checkExternalEmitHelpers(node, 33554432 /* AddDisposableResourceAndDisposeResources */);
                }
                forEach(node.declarations, checkSourceElement);
            }
            function checkVariableStatement(node) {
                if (!checkGrammarModifiers(node) && !checkGrammarVariableDeclarationList(node.declarationList))
                    checkGrammarForDisallowedBlockScopedVariableStatement(node);
                checkVariableDeclarationList(node.declarationList);
            }
            function checkExpressionStatement(node) {
                checkGrammarStatementInAmbientContext(node);
                checkExpression(node.expression);
            }
            function checkIfStatement(node) {
                checkGrammarStatementInAmbientContext(node);
                const type = checkTruthinessExpression(node.expression);
                checkTestingKnownTruthyCallableOrAwaitableType(node.expression, type, node.thenStatement);
                checkSourceElement(node.thenStatement);
                if (node.thenStatement.kind === 242 /* EmptyStatement */) {
                    error2(node.thenStatement, Diagnostics.The_body_of_an_if_statement_cannot_be_the_empty_statement);
                }
                checkSourceElement(node.elseStatement);
            }
            function checkTestingKnownTruthyCallableOrAwaitableType(condExpr, condType, body) {
                if (!strictNullChecks)
                    return;
                bothHelper(condExpr, body);
                function bothHelper(condExpr2, body2) {
                    condExpr2 = skipParentheses(condExpr2);
                    helper(condExpr2, body2);
                    while (isBinaryExpression(condExpr2) && (condExpr2.operatorToken.kind === 57 /* BarBarToken */ || condExpr2.operatorToken.kind === 61 /* QuestionQuestionToken */)) {
                        condExpr2 = skipParentheses(condExpr2.left);
                        helper(condExpr2, body2);
                    }
                }
                function helper(condExpr2, body2) {
                    const location = isLogicalOrCoalescingBinaryExpression(condExpr2) ? skipParentheses(condExpr2.right) : condExpr2;
                    if (isModuleExportsAccessExpression(location)) {
                        return;
                    }
                    if (isLogicalOrCoalescingBinaryExpression(location)) {
                        bothHelper(location, body2);
                        return;
                    }
                    const type = location === condExpr2 ? condType : checkTruthinessExpression(location);
                    const isPropertyExpressionCast = isPropertyAccessExpression(location) && isTypeAssertion(location.expression);
                    if (!hasTypeFacts(type, 4194304 /* Truthy */) || isPropertyExpressionCast)
                        return;
                    const callSignatures = getSignaturesOfType(type, 0 /* Call */);
                    const isPromise = !!getAwaitedTypeOfPromise(type);
                    if (callSignatures.length === 0 && !isPromise) {
                        return;
                    }
                    const testedNode = isIdentifier(location) ? location : isPropertyAccessExpression(location) ? location.name : void 0;
                    const testedSymbol = testedNode && getSymbolAtLocation(testedNode);
                    if (!testedSymbol && !isPromise) {
                        return;
                    }
                    const isUsed = testedSymbol && isBinaryExpression(condExpr2.parent) && isSymbolUsedInBinaryExpressionChain(condExpr2.parent, testedSymbol) || testedSymbol && body2 && isSymbolUsedInConditionBody(condExpr2, body2, testedNode, testedSymbol);
                    if (!isUsed) {
                        if (isPromise) {
                            errorAndMaybeSuggestAwait(location, 
                            /*maybeMissingAwait*/
                            true, Diagnostics.This_condition_will_always_return_true_since_this_0_is_always_defined, getTypeNameForErrorDisplay(type));
                        }
                        else {
                            error2(location, Diagnostics.This_condition_will_always_return_true_since_this_function_is_always_defined_Did_you_mean_to_call_it_instead);
                        }
                    }
                }
            }
            function isSymbolUsedInConditionBody(expr, body, testedNode, testedSymbol) {
                return !!forEachChild(body, function check(childNode) {
                    if (isIdentifier(childNode)) {
                        const childSymbol = getSymbolAtLocation(childNode);
                        if (childSymbol && childSymbol === testedSymbol) {
                            if (isIdentifier(expr) || isIdentifier(testedNode) && isBinaryExpression(testedNode.parent)) {
                                return true;
                            }
                            let testedExpression = testedNode.parent;
                            let childExpression = childNode.parent;
                            while (testedExpression && childExpression) {
                                if (isIdentifier(testedExpression) && isIdentifier(childExpression) || testedExpression.kind === 110 /* ThisKeyword */ && childExpression.kind === 110 /* ThisKeyword */) {
                                    return getSymbolAtLocation(testedExpression) === getSymbolAtLocation(childExpression);
                                }
                                else if (isPropertyAccessExpression(testedExpression) && isPropertyAccessExpression(childExpression)) {
                                    if (getSymbolAtLocation(testedExpression.name) !== getSymbolAtLocation(childExpression.name)) {
                                        return false;
                                    }
                                    childExpression = childExpression.expression;
                                    testedExpression = testedExpression.expression;
                                }
                                else if (isCallExpression(testedExpression) && isCallExpression(childExpression)) {
                                    childExpression = childExpression.expression;
                                    testedExpression = testedExpression.expression;
                                }
                                else {
                                    return false;
                                }
                            }
                        }
                    }
                    return forEachChild(childNode, check);
                });
            }
            function isSymbolUsedInBinaryExpressionChain(node, testedSymbol) {
                while (isBinaryExpression(node) && node.operatorToken.kind === 56 /* AmpersandAmpersandToken */) {
                    const isUsed = forEachChild(node.right, function visit(child) {
                        if (isIdentifier(child)) {
                            const symbol = getSymbolAtLocation(child);
                            if (symbol && symbol === testedSymbol) {
                                return true;
                            }
                        }
                        return forEachChild(child, visit);
                    });
                    if (isUsed) {
                        return true;
                    }
                    node = node.parent;
                }
                return false;
            }
            function checkDoStatement(node) {
                checkGrammarStatementInAmbientContext(node);
                checkSourceElement(node.statement);
                checkTruthinessExpression(node.expression);
            }
            function checkWhileStatement(node) {
                checkGrammarStatementInAmbientContext(node);
                checkTruthinessExpression(node.expression);
                checkSourceElement(node.statement);
            }
            function checkTruthinessOfType(type, node) {
                if (type.flags & 16384 /* Void */) {
                    error2(node, Diagnostics.An_expression_of_type_void_cannot_be_tested_for_truthiness);
                }
                return type;
            }
            function checkTruthinessExpression(node, checkMode) {
                return checkTruthinessOfType(checkExpression(node, checkMode), node);
            }
            function checkForStatement(node) {
                if (!checkGrammarStatementInAmbientContext(node)) {
                    if (node.initializer && node.initializer.kind === 261 /* VariableDeclarationList */) {
                        checkGrammarVariableDeclarationList(node.initializer);
                    }
                }
                if (node.initializer) {
                    if (node.initializer.kind === 261 /* VariableDeclarationList */) {
                        checkVariableDeclarationList(node.initializer);
                    }
                    else {
                        checkExpression(node.initializer);
                    }
                }
                if (node.condition)
                    checkTruthinessExpression(node.condition);
                if (node.incrementor)
                    checkExpression(node.incrementor);
                checkSourceElement(node.statement);
                if (node.locals) {
                    registerForUnusedIdentifiersCheck(node);
                }
            }
            function checkForOfStatement(node) {
                checkGrammarForInOrForOfStatement(node);
                const container = getContainingFunctionOrClassStaticBlock(node);
                if (node.awaitModifier) {
                    if (container && isClassStaticBlockDeclaration(container)) {
                        grammarErrorOnNode(node.awaitModifier, Diagnostics.for_await_loops_cannot_be_used_inside_a_class_static_block);
                    }
                    else {
                        const functionFlags = getFunctionFlags(container);
                        if ((functionFlags & (4 /* Invalid */ | 2 /* Async */)) === 2 /* Async */ && languageVersion < 99 /* ESNext */) {
                            checkExternalEmitHelpers(node, 16384 /* ForAwaitOfIncludes */);
                        }
                    }
                }
                else if (compilerOptions.downlevelIteration && languageVersion < 2 /* ES2015 */) {
                    checkExternalEmitHelpers(node, 256 /* ForOfIncludes */);
                }
                if (node.initializer.kind === 261 /* VariableDeclarationList */) {
                    checkVariableDeclarationList(node.initializer);
                }
                else {
                    const varExpr = node.initializer;
                    const iteratedType = checkRightHandSideOfForOf(node);
                    if (varExpr.kind === 209 /* ArrayLiteralExpression */ || varExpr.kind === 210 /* ObjectLiteralExpression */) {
                        checkDestructuringAssignment(varExpr, iteratedType || errorType);
                    }
                    else {
                        const leftType = checkExpression(varExpr);
                        checkReferenceExpression(varExpr, Diagnostics.The_left_hand_side_of_a_for_of_statement_must_be_a_variable_or_a_property_access, Diagnostics.The_left_hand_side_of_a_for_of_statement_may_not_be_an_optional_property_access);
                        if (iteratedType) {
                            checkTypeAssignableToAndOptionallyElaborate(iteratedType, leftType, varExpr, node.expression);
                        }
                    }
                }
                checkSourceElement(node.statement);
                if (node.locals) {
                    registerForUnusedIdentifiersCheck(node);
                }
            }
            function checkForInStatement(node) {
                checkGrammarForInOrForOfStatement(node);
                const rightType = getNonNullableTypeIfNeeded(checkExpression(node.expression));
                if (node.initializer.kind === 261 /* VariableDeclarationList */) {
                    const variable = node.initializer.declarations[0];
                    if (variable && isBindingPattern(variable.name)) {
                        error2(variable.name, Diagnostics.The_left_hand_side_of_a_for_in_statement_cannot_be_a_destructuring_pattern);
                    }
                    checkVariableDeclarationList(node.initializer);
                }
                else {
                    const varExpr = node.initializer;
                    const leftType = checkExpression(varExpr);
                    if (varExpr.kind === 209 /* ArrayLiteralExpression */ || varExpr.kind === 210 /* ObjectLiteralExpression */) {
                        error2(varExpr, Diagnostics.The_left_hand_side_of_a_for_in_statement_cannot_be_a_destructuring_pattern);
                    }
                    else if (!isTypeAssignableTo(getIndexTypeOrString(rightType), leftType)) {
                        error2(varExpr, Diagnostics.The_left_hand_side_of_a_for_in_statement_must_be_of_type_string_or_any);
                    }
                    else {
                        checkReferenceExpression(varExpr, Diagnostics.The_left_hand_side_of_a_for_in_statement_must_be_a_variable_or_a_property_access, Diagnostics.The_left_hand_side_of_a_for_in_statement_may_not_be_an_optional_property_access);
                    }
                }
                if (rightType === neverType || !isTypeAssignableToKind(rightType, 67108864 /* NonPrimitive */ | 58982400 /* InstantiableNonPrimitive */)) {
                    error2(node.expression, Diagnostics.The_right_hand_side_of_a_for_in_statement_must_be_of_type_any_an_object_type_or_a_type_parameter_but_here_has_type_0, typeToString(rightType));
                }
                checkSourceElement(node.statement);
                if (node.locals) {
                    registerForUnusedIdentifiersCheck(node);
                }
            }
            function checkRightHandSideOfForOf(statement) {
                const use = statement.awaitModifier ? 15 /* ForAwaitOf */ : 13 /* ForOf */;
                return checkIteratedTypeOrElementType(use, checkNonNullExpression(statement.expression), undefinedType, statement.expression);
            }
            function checkIteratedTypeOrElementType(use, inputType, sentType, errorNode) {
                if (isTypeAny(inputType)) {
                    return inputType;
                }
                return getIteratedTypeOrElementType(use, inputType, sentType, errorNode, 
                /*checkAssignability*/
                true) || anyType;
            }
            function getIteratedTypeOrElementType(use, inputType, sentType, errorNode, checkAssignability) {
                const allowAsyncIterables = (use & 2 /* AllowsAsyncIterablesFlag */) !== 0;
                if (inputType === neverType) {
                    reportTypeNotIterableError(errorNode, inputType, allowAsyncIterables);
                    return void 0;
                }
                const uplevelIteration = languageVersion >= 2 /* ES2015 */;
                const downlevelIteration = !uplevelIteration && compilerOptions.downlevelIteration;
                const possibleOutOfBounds = compilerOptions.noUncheckedIndexedAccess && !!(use & 128 /* PossiblyOutOfBounds */);
                if (uplevelIteration || downlevelIteration || allowAsyncIterables) {
                    const iterationTypes = getIterationTypesOfIterable(inputType, use, uplevelIteration ? errorNode : void 0);
                    if (checkAssignability) {
                        if (iterationTypes) {
                            const diagnostic = use & 8 /* ForOfFlag */ ? Diagnostics.Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_for_of_will_always_send_0 : use & 32 /* SpreadFlag */ ? Diagnostics.Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_array_spread_will_always_send_0 : use & 64 /* DestructuringFlag */ ? Diagnostics.Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_array_destructuring_will_always_send_0 : use & 16 /* YieldStarFlag */ ? Diagnostics.Cannot_delegate_iteration_to_value_because_the_next_method_of_its_iterator_expects_type_1_but_the_containing_generator_will_always_send_0 : void 0;
                            if (diagnostic) {
                                checkTypeAssignableTo(sentType, iterationTypes.nextType, errorNode, diagnostic);
                            }
                        }
                    }
                    if (iterationTypes || uplevelIteration) {
                        return possibleOutOfBounds ? includeUndefinedInIndexSignature(iterationTypes && iterationTypes.yieldType) : iterationTypes && iterationTypes.yieldType;
                    }
                }
                let arrayType = inputType;
                let reportedError = false;
                let hasStringConstituent = false;
                if (use & 4 /* AllowsStringInputFlag */) {
                    if (arrayType.flags & 1048576 /* Union */) {
                        const arrayTypes = inputType.types;
                        const filteredTypes = filter(arrayTypes, (t) => !(t.flags & 402653316 /* StringLike */));
                        if (filteredTypes !== arrayTypes) {
                            arrayType = getUnionType(filteredTypes, 2 /* Subtype */);
                        }
                    }
                    else if (arrayType.flags & 402653316 /* StringLike */) {
                        arrayType = neverType;
                    }
                    hasStringConstituent = arrayType !== inputType;
                    if (hasStringConstituent) {
                        if (languageVersion < 1 /* ES5 */) {
                            if (errorNode) {
                                error2(errorNode, Diagnostics.Using_a_string_in_a_for_of_statement_is_only_supported_in_ECMAScript_5_and_higher);
                                reportedError = true;
                            }
                        }
                        if (arrayType.flags & 131072 /* Never */) {
                            return possibleOutOfBounds ? includeUndefinedInIndexSignature(stringType) : stringType;
                        }
                    }
                }
                if (!isArrayLikeType(arrayType)) {
                    if (errorNode && !reportedError) {
                        const allowsStrings = !!(use & 4 /* AllowsStringInputFlag */) && !hasStringConstituent;
                        const [defaultDiagnostic, maybeMissingAwait] = getIterationDiagnosticDetails(allowsStrings, downlevelIteration);
                        errorAndMaybeSuggestAwait(errorNode, maybeMissingAwait && !!getAwaitedTypeOfPromise(arrayType), defaultDiagnostic, typeToString(arrayType));
                    }
                    return hasStringConstituent ? possibleOutOfBounds ? includeUndefinedInIndexSignature(stringType) : stringType : void 0;
                }
                const arrayElementType = getIndexTypeOfType(arrayType, numberType);
                if (hasStringConstituent && arrayElementType) {
                    if (arrayElementType.flags & 402653316 /* StringLike */ && !compilerOptions.noUncheckedIndexedAccess) {
                        return stringType;
                    }
                    return getUnionType(possibleOutOfBounds ? [arrayElementType, stringType, undefinedType] : [arrayElementType, stringType], 2 /* Subtype */);
                }
                return use & 128 /* PossiblyOutOfBounds */ ? includeUndefinedInIndexSignature(arrayElementType) : arrayElementType;
                function getIterationDiagnosticDetails(allowsStrings, downlevelIteration2) {
                    var _a;
                    if (downlevelIteration2) {
                        return allowsStrings ? [Diagnostics.Type_0_is_not_an_array_type_or_a_string_type_or_does_not_have_a_Symbol_iterator_method_that_returns_an_iterator, true] : [Diagnostics.Type_0_is_not_an_array_type_or_does_not_have_a_Symbol_iterator_method_that_returns_an_iterator, true];
                    }
                    const yieldType = getIterationTypeOfIterable(use, 0 /* Yield */, inputType, 
                    /*errorNode*/
                    void 0);
                    if (yieldType) {
                        return [Diagnostics.Type_0_can_only_be_iterated_through_when_using_the_downlevelIteration_flag_or_with_a_target_of_es2015_or_higher, false];
                    }
                    if (isES2015OrLaterIterable((_a = inputType.symbol) == null ? void 0 : _a.escapedName)) {
                        return [Diagnostics.Type_0_can_only_be_iterated_through_when_using_the_downlevelIteration_flag_or_with_a_target_of_es2015_or_higher, true];
                    }
                    return allowsStrings ? [Diagnostics.Type_0_is_not_an_array_type_or_a_string_type, true] : [Diagnostics.Type_0_is_not_an_array_type, true];
                }
            }
            function isES2015OrLaterIterable(n) {
                switch (n) {
                    case "Float32Array":
                    case "Float64Array":
                    case "Int16Array":
                    case "Int32Array":
                    case "Int8Array":
                    case "NodeList":
                    case "Uint16Array":
                    case "Uint32Array":
                    case "Uint8Array":
                    case "Uint8ClampedArray":
                        return true;
                }
                return false;
            }
            function getIterationTypeOfIterable(use, typeKind, inputType, errorNode) {
                if (isTypeAny(inputType)) {
                    return void 0;
                }
                const iterationTypes = getIterationTypesOfIterable(inputType, use, errorNode);
                return iterationTypes && iterationTypes[getIterationTypesKeyFromIterationTypeKind(typeKind)];
            }
            function createIterationTypes(yieldType = neverType, returnType = neverType, nextType = unknownType) {
                if (yieldType.flags & 67359327 /* Intrinsic */ && returnType.flags & (1 /* Any */ | 131072 /* Never */ | 2 /* Unknown */ | 16384 /* Void */ | 32768 /* Undefined */) && nextType.flags & (1 /* Any */ | 131072 /* Never */ | 2 /* Unknown */ | 16384 /* Void */ | 32768 /* Undefined */)) {
                    const id = getTypeListId([yieldType, returnType, nextType]);
                    let iterationTypes = iterationTypesCache.get(id);
                    if (!iterationTypes) {
                        iterationTypes = { yieldType, returnType, nextType };
                        iterationTypesCache.set(id, iterationTypes);
                    }
                    return iterationTypes;
                }
                return { yieldType, returnType, nextType };
            }
            function combineIterationTypes(array) {
                let yieldTypes;
                let returnTypes;
                let nextTypes;
                for (const iterationTypes of array) {
                    if (iterationTypes === void 0 || iterationTypes === noIterationTypes) {
                        continue;
                    }
                    if (iterationTypes === anyIterationTypes) {
                        return anyIterationTypes;
                    }
                    yieldTypes = append(yieldTypes, iterationTypes.yieldType);
                    returnTypes = append(returnTypes, iterationTypes.returnType);
                    nextTypes = append(nextTypes, iterationTypes.nextType);
                }
                if (yieldTypes || returnTypes || nextTypes) {
                    return createIterationTypes(yieldTypes && getUnionType(yieldTypes), returnTypes && getUnionType(returnTypes), nextTypes && getIntersectionType(nextTypes));
                }
                return noIterationTypes;
            }
            function getCachedIterationTypes(type, cacheKey) {
                return type[cacheKey];
            }
            function setCachedIterationTypes(type, cacheKey, cachedTypes2) {
                return type[cacheKey] = cachedTypes2;
            }
            function getIterationTypesOfIterable(type, use, errorNode) {
                var _a, _b;
                if (isTypeAny(type)) {
                    return anyIterationTypes;
                }
                if (!(type.flags & 1048576 /* Union */)) {
                    const errorOutputContainer = errorNode ? { errors: void 0 } : void 0;
                    const iterationTypes2 = getIterationTypesOfIterableWorker(type, use, errorNode, errorOutputContainer);
                    if (iterationTypes2 === noIterationTypes) {
                        if (errorNode) {
                            const rootDiag = reportTypeNotIterableError(errorNode, type, !!(use & 2 /* AllowsAsyncIterablesFlag */));
                            if (errorOutputContainer == null ? void 0 : errorOutputContainer.errors) {
                                addRelatedInfo(rootDiag, ...errorOutputContainer.errors);
                            }
                        }
                        return void 0;
                    }
                    else if ((_a = errorOutputContainer == null ? void 0 : errorOutputContainer.errors) == null ? void 0 : _a.length) {
                        for (const diag2 of errorOutputContainer.errors) {
                            diagnostics.add(diag2);
                        }
                    }
                    return iterationTypes2;
                }
                const cacheKey = use & 2 /* AllowsAsyncIterablesFlag */ ? "iterationTypesOfAsyncIterable" : "iterationTypesOfIterable";
                const cachedTypes2 = getCachedIterationTypes(type, cacheKey);
                if (cachedTypes2)
                    return cachedTypes2 === noIterationTypes ? void 0 : cachedTypes2;
                let allIterationTypes;
                for (const constituent of type.types) {
                    const errorOutputContainer = errorNode ? { errors: void 0 } : void 0;
                    const iterationTypes2 = getIterationTypesOfIterableWorker(constituent, use, errorNode, errorOutputContainer);
                    if (iterationTypes2 === noIterationTypes) {
                        if (errorNode) {
                            const rootDiag = reportTypeNotIterableError(errorNode, type, !!(use & 2 /* AllowsAsyncIterablesFlag */));
                            if (errorOutputContainer == null ? void 0 : errorOutputContainer.errors) {
                                addRelatedInfo(rootDiag, ...errorOutputContainer.errors);
                            }
                        }
                        setCachedIterationTypes(type, cacheKey, noIterationTypes);
                        return void 0;
                    }
                    else if ((_b = errorOutputContainer == null ? void 0 : errorOutputContainer.errors) == null ? void 0 : _b.length) {
                        for (const diag2 of errorOutputContainer.errors) {
                            diagnostics.add(diag2);
                        }
                    }
                    allIterationTypes = append(allIterationTypes, iterationTypes2);
                }
                const iterationTypes = allIterationTypes ? combineIterationTypes(allIterationTypes) : noIterationTypes;
                setCachedIterationTypes(type, cacheKey, iterationTypes);
                return iterationTypes === noIterationTypes ? void 0 : iterationTypes;
            }
            function getAsyncFromSyncIterationTypes(iterationTypes, errorNode) {
                if (iterationTypes === noIterationTypes)
                    return noIterationTypes;
                if (iterationTypes === anyIterationTypes)
                    return anyIterationTypes;
                const { yieldType, returnType, nextType } = iterationTypes;
                if (errorNode) {
                    getGlobalAwaitedSymbol(
                    /*reportErrors*/
                    true);
                }
                return createIterationTypes(getAwaitedType(yieldType, errorNode) || anyType, getAwaitedType(returnType, errorNode) || anyType, nextType);
            }
            function getIterationTypesOfIterableWorker(type, use, errorNode, errorOutputContainer) {
                if (isTypeAny(type)) {
                    return anyIterationTypes;
                }
                let noCache = false;
                if (use & 2 /* AllowsAsyncIterablesFlag */) {
                    const iterationTypes = getIterationTypesOfIterableCached(type, asyncIterationTypesResolver) || getIterationTypesOfIterableFast(type, asyncIterationTypesResolver);
                    if (iterationTypes) {
                        if (iterationTypes === noIterationTypes && errorNode) {
                            noCache = true;
                        }
                        else {
                            return use & 8 /* ForOfFlag */ ? getAsyncFromSyncIterationTypes(iterationTypes, errorNode) : iterationTypes;
                        }
                    }
                }
                if (use & 1 /* AllowsSyncIterablesFlag */) {
                    let iterationTypes = getIterationTypesOfIterableCached(type, syncIterationTypesResolver) || getIterationTypesOfIterableFast(type, syncIterationTypesResolver);
                    if (iterationTypes) {
                        if (iterationTypes === noIterationTypes && errorNode) {
                            noCache = true;
                        }
                        else {
                            if (use & 2 /* AllowsAsyncIterablesFlag */) {
                                if (iterationTypes !== noIterationTypes) {
                                    iterationTypes = getAsyncFromSyncIterationTypes(iterationTypes, errorNode);
                                    return noCache ? iterationTypes : setCachedIterationTypes(type, "iterationTypesOfAsyncIterable", iterationTypes);
                                }
                            }
                            else {
                                return iterationTypes;
                            }
                        }
                    }
                }
                if (use & 2 /* AllowsAsyncIterablesFlag */) {
                    const iterationTypes = getIterationTypesOfIterableSlow(type, asyncIterationTypesResolver, errorNode, errorOutputContainer, noCache);
                    if (iterationTypes !== noIterationTypes) {
                        return iterationTypes;
                    }
                }
                if (use & 1 /* AllowsSyncIterablesFlag */) {
                    let iterationTypes = getIterationTypesOfIterableSlow(type, syncIterationTypesResolver, errorNode, errorOutputContainer, noCache);
                    if (iterationTypes !== noIterationTypes) {
                        if (use & 2 /* AllowsAsyncIterablesFlag */) {
                            iterationTypes = getAsyncFromSyncIterationTypes(iterationTypes, errorNode);
                            return noCache ? iterationTypes : setCachedIterationTypes(type, "iterationTypesOfAsyncIterable", iterationTypes);
                        }
                        else {
                            return iterationTypes;
                        }
                    }
                }
                return noIterationTypes;
            }
            function getIterationTypesOfIterableCached(type, resolver) {
                return getCachedIterationTypes(type, resolver.iterableCacheKey);
            }
            function getIterationTypesOfGlobalIterableType(globalType, resolver) {
                const globalIterationTypes = getIterationTypesOfIterableCached(globalType, resolver) || getIterationTypesOfIterableSlow(globalType, resolver, 
                /*errorNode*/
                void 0, 
                /*errorOutputContainer*/
                void 0, 
                /*noCache*/
                false);
                return globalIterationTypes === noIterationTypes ? defaultIterationTypes : globalIterationTypes;
            }
            function getIterationTypesOfIterableFast(type, resolver) {
                let globalType;
                if (isReferenceToType2(type, globalType = resolver.getGlobalIterableType(
                /*reportErrors*/
                false)) || isReferenceToType2(type, globalType = resolver.getGlobalIterableIteratorType(
                /*reportErrors*/
                false))) {
                    const [yieldType] = getTypeArguments(type);
                    const { returnType, nextType } = getIterationTypesOfGlobalIterableType(globalType, resolver);
                    return setCachedIterationTypes(type, resolver.iterableCacheKey, createIterationTypes(resolver.resolveIterationType(yieldType, 
                    /*errorNode*/
                    void 0) || yieldType, resolver.resolveIterationType(returnType, 
                    /*errorNode*/
                    void 0) || returnType, nextType));
                }
                if (isReferenceToType2(type, resolver.getGlobalGeneratorType(
                /*reportErrors*/
                false))) {
                    const [yieldType, returnType, nextType] = getTypeArguments(type);
                    return setCachedIterationTypes(type, resolver.iterableCacheKey, createIterationTypes(resolver.resolveIterationType(yieldType, 
                    /*errorNode*/
                    void 0) || yieldType, resolver.resolveIterationType(returnType, 
                    /*errorNode*/
                    void 0) || returnType, nextType));
                }
            }
            function getPropertyNameForKnownSymbolName(symbolName2) {
                const ctorType = getGlobalESSymbolConstructorSymbol(
                /*reportErrors*/
                false);
                const uniqueType = ctorType && getTypeOfPropertyOfType(getTypeOfSymbol(ctorType), escapeLeadingUnderscores(symbolName2));
                return uniqueType && isTypeUsableAsPropertyName(uniqueType) ? getPropertyNameFromType(uniqueType) : `__@${symbolName2}`;
            }
            function getIterationTypesOfIterableSlow(type, resolver, errorNode, errorOutputContainer, noCache) {
                const method = getPropertyOfType(type, getPropertyNameForKnownSymbolName(resolver.iteratorSymbolName));
                const methodType = method && !(method.flags & 16777216 /* Optional */) ? getTypeOfSymbol(method) : void 0;
                if (isTypeAny(methodType)) {
                    return noCache ? anyIterationTypes : setCachedIterationTypes(type, resolver.iterableCacheKey, anyIterationTypes);
                }
                const signatures = methodType ? getSignaturesOfType(methodType, 0 /* Call */) : void 0;
                if (!some(signatures)) {
                    return noCache ? noIterationTypes : setCachedIterationTypes(type, resolver.iterableCacheKey, noIterationTypes);
                }
                const iteratorType = getIntersectionType(map(signatures, getReturnTypeOfSignature));
                const iterationTypes = getIterationTypesOfIteratorWorker(iteratorType, resolver, errorNode, errorOutputContainer, noCache) ?? noIterationTypes;
                return noCache ? iterationTypes : setCachedIterationTypes(type, resolver.iterableCacheKey, iterationTypes);
            }
            function reportTypeNotIterableError(errorNode, type, allowAsyncIterables) {
                const message = allowAsyncIterables ? Diagnostics.Type_0_must_have_a_Symbol_asyncIterator_method_that_returns_an_async_iterator : Diagnostics.Type_0_must_have_a_Symbol_iterator_method_that_returns_an_iterator;
                const suggestAwait = (
                // for (const x of Promise<...>) or [...Promise<...>]
                !!getAwaitedTypeOfPromise(type) || !allowAsyncIterables && isForOfStatement(errorNode.parent) && errorNode.parent.expression === errorNode && getGlobalAsyncIterableType(
                /*reportErrors*/
                false) !== emptyGenericType && isTypeAssignableTo(type, getGlobalAsyncIterableType(
                /*reportErrors*/
                false)));
                return errorAndMaybeSuggestAwait(errorNode, suggestAwait, message, typeToString(type));
            }
            function getIterationTypesOfIterator(type, resolver, errorNode, errorOutputContainer) {
                return getIterationTypesOfIteratorWorker(type, resolver, errorNode, errorOutputContainer, 
                /*noCache*/
                false);
            }
            function getIterationTypesOfIteratorWorker(type, resolver, errorNode, errorOutputContainer, noCache) {
                if (isTypeAny(type)) {
                    return anyIterationTypes;
                }
                let iterationTypes = getIterationTypesOfIteratorCached(type, resolver) || getIterationTypesOfIteratorFast(type, resolver);
                if (iterationTypes === noIterationTypes && errorNode) {
                    iterationTypes = void 0;
                    noCache = true;
                }
                iterationTypes ?? (iterationTypes = getIterationTypesOfIteratorSlow(type, resolver, errorNode, errorOutputContainer, noCache));
                return iterationTypes === noIterationTypes ? void 0 : iterationTypes;
            }
            function getIterationTypesOfIteratorCached(type, resolver) {
                return getCachedIterationTypes(type, resolver.iteratorCacheKey);
            }
            function getIterationTypesOfIteratorFast(type, resolver) {
                const globalType = resolver.getGlobalIterableIteratorType(
                /*reportErrors*/
                false);
                if (isReferenceToType2(type, globalType)) {
                    const [yieldType] = getTypeArguments(type);
                    const globalIterationTypes = getIterationTypesOfIteratorCached(globalType, resolver) || getIterationTypesOfIteratorSlow(globalType, resolver, 
                    /*errorNode*/
                    void 0, 
                    /*errorOutputContainer*/
                    void 0, 
                    /*noCache*/
                    false);
                    const { returnType, nextType } = globalIterationTypes === noIterationTypes ? defaultIterationTypes : globalIterationTypes;
                    return setCachedIterationTypes(type, resolver.iteratorCacheKey, createIterationTypes(yieldType, returnType, nextType));
                }
                if (isReferenceToType2(type, resolver.getGlobalIteratorType(
                /*reportErrors*/
                false)) || isReferenceToType2(type, resolver.getGlobalGeneratorType(
                /*reportErrors*/
                false))) {
                    const [yieldType, returnType, nextType] = getTypeArguments(type);
                    return setCachedIterationTypes(type, resolver.iteratorCacheKey, createIterationTypes(yieldType, returnType, nextType));
                }
            }
            function isIteratorResult(type, kind) {
                const doneType = getTypeOfPropertyOfType(type, "done") || falseType;
                return isTypeAssignableTo(kind === 0 /* Yield */ ? falseType : trueType, doneType);
            }
            function isYieldIteratorResult(type) {
                return isIteratorResult(type, 0 /* Yield */);
            }
            function isReturnIteratorResult(type) {
                return isIteratorResult(type, 1 /* Return */);
            }
            function getIterationTypesOfIteratorResult(type) {
                if (isTypeAny(type)) {
                    return anyIterationTypes;
                }
                const cachedTypes2 = getCachedIterationTypes(type, "iterationTypesOfIteratorResult");
                if (cachedTypes2) {
                    return cachedTypes2;
                }
                if (isReferenceToType2(type, getGlobalIteratorYieldResultType(
                /*reportErrors*/
                false))) {
                    const yieldType2 = getTypeArguments(type)[0];
                    return setCachedIterationTypes(type, "iterationTypesOfIteratorResult", createIterationTypes(yieldType2, 
                    /*returnType*/
                    void 0, 
                    /*nextType*/
                    void 0));
                }
                if (isReferenceToType2(type, getGlobalIteratorReturnResultType(
                /*reportErrors*/
                false))) {
                    const returnType2 = getTypeArguments(type)[0];
                    return setCachedIterationTypes(type, "iterationTypesOfIteratorResult", createIterationTypes(
                    /*yieldType*/
                    void 0, returnType2, 
                    /*nextType*/
                    void 0));
                }
                const yieldIteratorResult = filterType(type, isYieldIteratorResult);
                const yieldType = yieldIteratorResult !== neverType ? getTypeOfPropertyOfType(yieldIteratorResult, "value") : void 0;
                const returnIteratorResult = filterType(type, isReturnIteratorResult);
                const returnType = returnIteratorResult !== neverType ? getTypeOfPropertyOfType(returnIteratorResult, "value") : void 0;
                if (!yieldType && !returnType) {
                    return setCachedIterationTypes(type, "iterationTypesOfIteratorResult", noIterationTypes);
                }
                return setCachedIterationTypes(type, "iterationTypesOfIteratorResult", createIterationTypes(yieldType, returnType || voidType, 
                /*nextType*/
                void 0));
            }
            function getIterationTypesOfMethod(type, resolver, methodName, errorNode, errorOutputContainer) {
                var _a, _b, _c, _d;
                const method = getPropertyOfType(type, methodName);
                if (!method && methodName !== "next") {
                    return void 0;
                }
                const methodType = method && !(methodName === "next" && method.flags & 16777216 /* Optional */) ? methodName === "next" ? getTypeOfSymbol(method) : getTypeWithFacts(getTypeOfSymbol(method), 2097152 /* NEUndefinedOrNull */) : void 0;
                if (isTypeAny(methodType)) {
                    return methodName === "next" ? anyIterationTypes : anyIterationTypesExceptNext;
                }
                const methodSignatures = methodType ? getSignaturesOfType(methodType, 0 /* Call */) : emptyArray;
                if (methodSignatures.length === 0) {
                    if (errorNode) {
                        const diagnostic = methodName === "next" ? resolver.mustHaveANextMethodDiagnostic : resolver.mustBeAMethodDiagnostic;
                        if (errorOutputContainer) {
                            errorOutputContainer.errors ?? (errorOutputContainer.errors = []);
                            errorOutputContainer.errors.push(createDiagnosticForNode(errorNode, diagnostic, methodName));
                        }
                        else {
                            error2(errorNode, diagnostic, methodName);
                        }
                    }
                    return methodName === "next" ? noIterationTypes : void 0;
                }
                if ((methodType == null ? void 0 : methodType.symbol) && methodSignatures.length === 1) {
                    const globalGeneratorType = resolver.getGlobalGeneratorType(
                    /*reportErrors*/
                    false);
                    const globalIteratorType = resolver.getGlobalIteratorType(
                    /*reportErrors*/
                    false);
                    const isGeneratorMethod = ((_b = (_a = globalGeneratorType.symbol) == null ? void 0 : _a.members) == null ? void 0 : _b.get(methodName)) === methodType.symbol;
                    const isIteratorMethod = !isGeneratorMethod && ((_d = (_c = globalIteratorType.symbol) == null ? void 0 : _c.members) == null ? void 0 : _d.get(methodName)) === methodType.symbol;
                    if (isGeneratorMethod || isIteratorMethod) {
                        const globalType = isGeneratorMethod ? globalGeneratorType : globalIteratorType;
                        const { mapper } = methodType;
                        return createIterationTypes(getMappedType(globalType.typeParameters[0], mapper), getMappedType(globalType.typeParameters[1], mapper), methodName === "next" ? getMappedType(globalType.typeParameters[2], mapper) : void 0);
                    }
                }
                let methodParameterTypes;
                let methodReturnTypes;
                for (const signature of methodSignatures) {
                    if (methodName !== "throw" && some(signature.parameters)) {
                        methodParameterTypes = append(methodParameterTypes, getTypeAtPosition(signature, 0));
                    }
                    methodReturnTypes = append(methodReturnTypes, getReturnTypeOfSignature(signature));
                }
                let returnTypes;
                let nextType;
                if (methodName !== "throw") {
                    const methodParameterType = methodParameterTypes ? getUnionType(methodParameterTypes) : unknownType;
                    if (methodName === "next") {
                        nextType = methodParameterType;
                    }
                    else if (methodName === "return") {
                        const resolvedMethodParameterType = resolver.resolveIterationType(methodParameterType, errorNode) || anyType;
                        returnTypes = append(returnTypes, resolvedMethodParameterType);
                    }
                }
                let yieldType;
                const methodReturnType = methodReturnTypes ? getIntersectionType(methodReturnTypes) : neverType;
                const resolvedMethodReturnType = resolver.resolveIterationType(methodReturnType, errorNode) || anyType;
                const iterationTypes = getIterationTypesOfIteratorResult(resolvedMethodReturnType);
                if (iterationTypes === noIterationTypes) {
                    if (errorNode) {
                        if (errorOutputContainer) {
                            errorOutputContainer.errors ?? (errorOutputContainer.errors = []);
                            errorOutputContainer.errors.push(createDiagnosticForNode(errorNode, resolver.mustHaveAValueDiagnostic, methodName));
                        }
                        else {
                            error2(errorNode, resolver.mustHaveAValueDiagnostic, methodName);
                        }
                    }
                    yieldType = anyType;
                    returnTypes = append(returnTypes, anyType);
                }
                else {
                    yieldType = iterationTypes.yieldType;
                    returnTypes = append(returnTypes, iterationTypes.returnType);
                }
                return createIterationTypes(yieldType, getUnionType(returnTypes), nextType);
            }
            function getIterationTypesOfIteratorSlow(type, resolver, errorNode, errorOutputContainer, noCache) {
                const iterationTypes = combineIterationTypes([
                    getIterationTypesOfMethod(type, resolver, "next", errorNode, errorOutputContainer),
                    getIterationTypesOfMethod(type, resolver, "return", errorNode, errorOutputContainer),
                    getIterationTypesOfMethod(type, resolver, "throw", errorNode, errorOutputContainer)
                ]);
                return noCache ? iterationTypes : setCachedIterationTypes(type, resolver.iteratorCacheKey, iterationTypes);
            }
            function getIterationTypeOfGeneratorFunctionReturnType(kind, returnType, isAsyncGenerator) {
                if (isTypeAny(returnType)) {
                    return void 0;
                }
                const iterationTypes = getIterationTypesOfGeneratorFunctionReturnType(returnType, isAsyncGenerator);
                return iterationTypes && iterationTypes[getIterationTypesKeyFromIterationTypeKind(kind)];
            }
            function getIterationTypesOfGeneratorFunctionReturnType(type, isAsyncGenerator) {
                if (isTypeAny(type)) {
                    return anyIterationTypes;
                }
                const use = isAsyncGenerator ? 2 /* AsyncGeneratorReturnType */ : 1 /* GeneratorReturnType */;
                const resolver = isAsyncGenerator ? asyncIterationTypesResolver : syncIterationTypesResolver;
                return getIterationTypesOfIterable(type, use, 
                /*errorNode*/
                void 0) || getIterationTypesOfIterator(type, resolver, 
                /*errorNode*/
                void 0, 
                /*errorOutputContainer*/
                void 0);
            }
            function checkBreakOrContinueStatement(node) {
                if (!checkGrammarStatementInAmbientContext(node))
                    checkGrammarBreakOrContinueStatement(node);
            }
            function unwrapReturnType(returnType, functionFlags) {
                const isGenerator = !!(functionFlags & 1 /* Generator */);
                const isAsync = !!(functionFlags & 2 /* Async */);
                if (isGenerator) {
                    const returnIterationType = getIterationTypeOfGeneratorFunctionReturnType(1 /* Return */, returnType, isAsync);
                    if (!returnIterationType) {
                        return errorType;
                    }
                    return isAsync ? getAwaitedTypeNoAlias(unwrapAwaitedType(returnIterationType)) : returnIterationType;
                }
                return isAsync ? getAwaitedTypeNoAlias(returnType) || errorType : returnType;
            }
            function isUnwrappedReturnTypeUndefinedVoidOrAny(func, returnType) {
                const type = unwrapReturnType(returnType, getFunctionFlags(func));
                return !!(type && (maybeTypeOfKind(type, 16384 /* Void */) || type.flags & (1 /* Any */ | 32768 /* Undefined */)));
            }
            function checkReturnStatement(node) {
                if (checkGrammarStatementInAmbientContext(node)) {
                    return;
                }
                const container = getContainingFunctionOrClassStaticBlock(node);
                if (container && isClassStaticBlockDeclaration(container)) {
                    grammarErrorOnFirstToken(node, Diagnostics.A_return_statement_cannot_be_used_inside_a_class_static_block);
                    return;
                }
                if (!container) {
                    grammarErrorOnFirstToken(node, Diagnostics.A_return_statement_can_only_be_used_within_a_function_body);
                    return;
                }
                const signature = getSignatureFromDeclaration(container);
                const returnType = getReturnTypeOfSignature(signature);
                const functionFlags = getFunctionFlags(container);
                if (strictNullChecks || node.expression || returnType.flags & 131072 /* Never */) {
                    const exprType = node.expression ? checkExpressionCached(node.expression) : undefinedType;
                    if (container.kind === 178 /* SetAccessor */) {
                        if (node.expression) {
                            error2(node, Diagnostics.Setters_cannot_return_a_value);
                        }
                    }
                    else if (container.kind === 176 /* Constructor */) {
                        if (node.expression && !checkTypeAssignableToAndOptionallyElaborate(exprType, returnType, node, node.expression)) {
                            error2(node, Diagnostics.Return_type_of_constructor_signature_must_be_assignable_to_the_instance_type_of_the_class);
                        }
                    }
                    else if (getReturnTypeFromAnnotation(container)) {
                        const unwrappedReturnType = unwrapReturnType(returnType, functionFlags) ?? returnType;
                        const unwrappedExprType = functionFlags & 2 /* Async */ ? checkAwaitedType(exprType, 
                        /*withAlias*/
                        false, node, Diagnostics.The_return_type_of_an_async_function_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member) : exprType;
                        if (unwrappedReturnType) {
                            checkTypeAssignableToAndOptionallyElaborate(unwrappedExprType, unwrappedReturnType, node, node.expression);
                        }
                    }
                }
                else if (container.kind !== 176 /* Constructor */ && compilerOptions.noImplicitReturns && !isUnwrappedReturnTypeUndefinedVoidOrAny(container, returnType)) {
                    error2(node, Diagnostics.Not_all_code_paths_return_a_value);
                }
            }
            function checkWithStatement(node) {
                if (!checkGrammarStatementInAmbientContext(node)) {
                    if (node.flags & 65536 /* AwaitContext */) {
                        grammarErrorOnFirstToken(node, Diagnostics.with_statements_are_not_allowed_in_an_async_function_block);
                    }
                }
                checkExpression(node.expression);
                const sourceFile = getSourceFileOfNode(node);
                if (!hasParseDiagnostics(sourceFile)) {
                    const start = getSpanOfTokenAtPosition(sourceFile, node.pos).start;
                    const end = node.statement.pos;
                    grammarErrorAtPos(sourceFile, start, end - start, Diagnostics.The_with_statement_is_not_supported_All_symbols_in_a_with_block_will_have_type_any);
                }
            }
            function checkSwitchStatement(node) {
                checkGrammarStatementInAmbientContext(node);
                let firstDefaultClause;
                let hasDuplicateDefaultClause = false;
                const expressionType = checkExpression(node.expression);
                forEach(node.caseBlock.clauses, (clause) => {
                    if (clause.kind === 297 /* DefaultClause */ && !hasDuplicateDefaultClause) {
                        if (firstDefaultClause === void 0) {
                            firstDefaultClause = clause;
                        }
                        else {
                            grammarErrorOnNode(clause, Diagnostics.A_default_clause_cannot_appear_more_than_once_in_a_switch_statement);
                            hasDuplicateDefaultClause = true;
                        }
                    }
                    if (clause.kind === 296 /* CaseClause */) {
                        addLazyDiagnostic(createLazyCaseClauseDiagnostics(clause));
                    }
                    forEach(clause.statements, checkSourceElement);
                    if (compilerOptions.noFallthroughCasesInSwitch && clause.fallthroughFlowNode && isReachableFlowNode(clause.fallthroughFlowNode)) {
                        error2(clause, Diagnostics.Fallthrough_case_in_switch);
                    }
                    function createLazyCaseClauseDiagnostics(clause2) {
                        return () => {
                            const caseType = checkExpression(clause2.expression);
                            if (!isTypeEqualityComparableTo(expressionType, caseType)) {
                                checkTypeComparableTo(caseType, expressionType, clause2.expression, 
                                /*headMessage*/
                                void 0);
                            }
                        };
                    }
                });
                if (node.caseBlock.locals) {
                    registerForUnusedIdentifiersCheck(node.caseBlock);
                }
            }
            function checkLabeledStatement(node) {
                if (!checkGrammarStatementInAmbientContext(node)) {
                    findAncestor(node.parent, (current) => {
                        if (isFunctionLike(current)) {
                            return "quit";
                        }
                        if (current.kind === 256 /* LabeledStatement */ && current.label.escapedText === node.label.escapedText) {
                            grammarErrorOnNode(node.label, Diagnostics.Duplicate_label_0, getTextOfNode(node.label));
                            return true;
                        }
                        return false;
                    });
                }
                checkSourceElement(node.statement);
            }
            function checkThrowStatement(node) {
                if (!checkGrammarStatementInAmbientContext(node)) {
                    if (isIdentifier(node.expression) && !node.expression.escapedText) {
                        grammarErrorAfterFirstToken(node, Diagnostics.Line_break_not_permitted_here);
                    }
                }
                if (node.expression) {
                    checkExpression(node.expression);
                }
            }
            function checkTryStatement(node) {
                checkGrammarStatementInAmbientContext(node);
                checkBlock(node.tryBlock);
                const catchClause = node.catchClause;
                if (catchClause) {
                    if (catchClause.variableDeclaration) {
                        const declaration = catchClause.variableDeclaration;
                        checkVariableLikeDeclaration(declaration);
                        const typeNode = getEffectiveTypeAnnotationNode(declaration);
                        if (typeNode) {
                            const type = getTypeFromTypeNode(typeNode);
                            if (type && !(type.flags & 3 /* AnyOrUnknown */)) {
                                grammarErrorOnFirstToken(typeNode, Diagnostics.Catch_clause_variable_type_annotation_must_be_any_or_unknown_if_specified);
                            }
                        }
                        else if (declaration.initializer) {
                            grammarErrorOnFirstToken(declaration.initializer, Diagnostics.Catch_clause_variable_cannot_have_an_initializer);
                        }
                        else {
                            const blockLocals = catchClause.block.locals;
                            if (blockLocals) {
                                forEachKey(catchClause.locals, (caughtName) => {
                                    const blockLocal = blockLocals.get(caughtName);
                                    if ((blockLocal == null ? void 0 : blockLocal.valueDeclaration) && (blockLocal.flags & 2 /* BlockScopedVariable */) !== 0) {
                                        grammarErrorOnNode(blockLocal.valueDeclaration, Diagnostics.Cannot_redeclare_identifier_0_in_catch_clause, unescapeLeadingUnderscores(caughtName));
                                    }
                                });
                            }
                        }
                    }
                    checkBlock(catchClause.block);
                }
                if (node.finallyBlock) {
                    checkBlock(node.finallyBlock);
                }
            }
            function checkIndexConstraints(type, symbol, isStaticIndex) {
                const indexInfos = getIndexInfosOfType(type);
                if (indexInfos.length === 0) {
                    return;
                }
                for (const prop of getPropertiesOfObjectType(type)) {
                    if (!(isStaticIndex && prop.flags & 4194304 /* Prototype */)) {
                        checkIndexConstraintForProperty(type, prop, getLiteralTypeFromProperty(prop, 8576 /* StringOrNumberLiteralOrUnique */, 
                        /*includeNonPublic*/
                        true), getNonMissingTypeOfSymbol(prop));
                    }
                }
                const typeDeclaration = symbol.valueDeclaration;
                if (typeDeclaration && isClassLike(typeDeclaration)) {
                    for (const member of typeDeclaration.members) {
                        if (!isStatic(member) && !hasBindableName(member)) {
                            const symbol2 = getSymbolOfDeclaration(member);
                            checkIndexConstraintForProperty(type, symbol2, getTypeOfExpression(member.name.expression), getNonMissingTypeOfSymbol(symbol2));
                        }
                    }
                }
                if (indexInfos.length > 1) {
                    for (const info of indexInfos) {
                        checkIndexConstraintForIndexSignature(type, info);
                    }
                }
            }
            function checkIndexConstraintForProperty(type, prop, propNameType, propType) {
                const declaration = prop.valueDeclaration;
                const name = getNameOfDeclaration(declaration);
                if (name && isPrivateIdentifier(name)) {
                    return;
                }
                const indexInfos = getApplicableIndexInfos(type, propNameType);
                const interfaceDeclaration = getObjectFlags(type) & 2 /* Interface */ ? getDeclarationOfKind(type.symbol, 264 /* InterfaceDeclaration */) : void 0;
                const propDeclaration = declaration && declaration.kind === 226 /* BinaryExpression */ || name && name.kind === 167 /* ComputedPropertyName */ ? declaration : void 0;
                const localPropDeclaration = getParentOfSymbol(prop) === type.symbol ? declaration : void 0;
                for (const info of indexInfos) {
                    const localIndexDeclaration = info.declaration && getParentOfSymbol(getSymbolOfDeclaration(info.declaration)) === type.symbol ? info.declaration : void 0;
                    const errorNode = localPropDeclaration || localIndexDeclaration || (interfaceDeclaration && !some(getBaseTypes(type), (base) => !!getPropertyOfObjectType(base, prop.escapedName) && !!getIndexTypeOfType(base, info.keyType)) ? interfaceDeclaration : void 0);
                    if (errorNode && !isTypeAssignableTo(propType, info.type)) {
                        const diagnostic = createError(errorNode, Diagnostics.Property_0_of_type_1_is_not_assignable_to_2_index_type_3, symbolToString(prop), typeToString(propType), typeToString(info.keyType), typeToString(info.type));
                        if (propDeclaration && errorNode !== propDeclaration) {
                            addRelatedInfo(diagnostic, createDiagnosticForNode(propDeclaration, Diagnostics._0_is_declared_here, symbolToString(prop)));
                        }
                        diagnostics.add(diagnostic);
                    }
                }
            }
            function checkIndexConstraintForIndexSignature(type, checkInfo) {
                const declaration = checkInfo.declaration;
                const indexInfos = getApplicableIndexInfos(type, checkInfo.keyType);
                const interfaceDeclaration = getObjectFlags(type) & 2 /* Interface */ ? getDeclarationOfKind(type.symbol, 264 /* InterfaceDeclaration */) : void 0;
                const localCheckDeclaration = declaration && getParentOfSymbol(getSymbolOfDeclaration(declaration)) === type.symbol ? declaration : void 0;
                for (const info of indexInfos) {
                    if (info === checkInfo)
                        continue;
                    const localIndexDeclaration = info.declaration && getParentOfSymbol(getSymbolOfDeclaration(info.declaration)) === type.symbol ? info.declaration : void 0;
                    const errorNode = localCheckDeclaration || localIndexDeclaration || (interfaceDeclaration && !some(getBaseTypes(type), (base) => !!getIndexInfoOfType(base, checkInfo.keyType) && !!getIndexTypeOfType(base, info.keyType)) ? interfaceDeclaration : void 0);
                    if (errorNode && !isTypeAssignableTo(checkInfo.type, info.type)) {
                        error2(errorNode, Diagnostics._0_index_type_1_is_not_assignable_to_2_index_type_3, typeToString(checkInfo.keyType), typeToString(checkInfo.type), typeToString(info.keyType), typeToString(info.type));
                    }
                }
            }
            function checkTypeNameIsReserved(name, message) {
                switch (name.escapedText) {
                    case "any":
                    case "unknown":
                    case "never":
                    case "number":
                    case "bigint":
                    case "boolean":
                    case "string":
                    case "symbol":
                    case "void":
                    case "object":
                        error2(name, message, name.escapedText);
                }
            }
            function checkClassNameCollisionWithObject(name) {
                if (languageVersion >= 1 /* ES5 */ && name.escapedText === "Object" && (moduleKind < 5 /* ES2015 */ || getSourceFileOfNode(name).impliedNodeFormat === 1 /* CommonJS */)) {
                    error2(name, Diagnostics.Class_name_cannot_be_Object_when_targeting_ES5_with_module_0, ModuleKind[moduleKind]);
                }
            }
            function checkUnmatchedJSDocParameters(node) {
                const jsdocParameters = filter(getJSDocTags(node), isJSDocParameterTag);
                if (!length(jsdocParameters))
                    return;
                const isJs = isInJSFile(node);
                const parameters = /* @__PURE__ */ new Set();
                const excludedParameters = /* @__PURE__ */ new Set();
                forEach(node.parameters, ({ name }, index) => {
                    if (isIdentifier(name)) {
                        parameters.add(name.escapedText);
                    }
                    if (isBindingPattern(name)) {
                        excludedParameters.add(index);
                    }
                });
                const containsArguments = containsArgumentsReference(node);
                if (containsArguments) {
                    const lastJSDocParamIndex = jsdocParameters.length - 1;
                    const lastJSDocParam = jsdocParameters[lastJSDocParamIndex];
                    if (isJs && lastJSDocParam && isIdentifier(lastJSDocParam.name) && lastJSDocParam.typeExpression && lastJSDocParam.typeExpression.type && !parameters.has(lastJSDocParam.name.escapedText) && !excludedParameters.has(lastJSDocParamIndex) && !isArrayType(getTypeFromTypeNode(lastJSDocParam.typeExpression.type))) {
                        error2(lastJSDocParam.name, Diagnostics.JSDoc_param_tag_has_name_0_but_there_is_no_parameter_with_that_name_It_would_match_arguments_if_it_had_an_array_type, idText(lastJSDocParam.name));
                    }
                }
                else {
                    forEach(jsdocParameters, ({ name, isNameFirst }, index) => {
                        if (excludedParameters.has(index) || isIdentifier(name) && parameters.has(name.escapedText)) {
                            return;
                        }
                        if (isQualifiedName(name)) {
                            if (isJs) {
                                error2(name, Diagnostics.Qualified_name_0_is_not_allowed_without_a_leading_param_object_1, entityNameToString(name), entityNameToString(name.left));
                            }
                        }
                        else {
                            if (!isNameFirst) {
                                errorOrSuggestion(isJs, name, Diagnostics.JSDoc_param_tag_has_name_0_but_there_is_no_parameter_with_that_name, idText(name));
                            }
                        }
                    });
                }
            }
            function checkTypeParameters(typeParameterDeclarations) {
                let seenDefault = false;
                if (typeParameterDeclarations) {
                    for (let i = 0; i < typeParameterDeclarations.length; i++) {
                        const node = typeParameterDeclarations[i];
                        checkTypeParameter(node);
                        addLazyDiagnostic(createCheckTypeParameterDiagnostic(node, i));
                    }
                }
                function createCheckTypeParameterDiagnostic(node, i) {
                    return () => {
                        if (node.default) {
                            seenDefault = true;
                            checkTypeParametersNotReferenced(node.default, typeParameterDeclarations, i);
                        }
                        else if (seenDefault) {
                            error2(node, Diagnostics.Required_type_parameters_may_not_follow_optional_type_parameters);
                        }
                        for (let j = 0; j < i; j++) {
                            if (typeParameterDeclarations[j].symbol === node.symbol) {
                                error2(node.name, Diagnostics.Duplicate_identifier_0, declarationNameToString(node.name));
                            }
                        }
                    };
                }
            }
            function checkTypeParametersNotReferenced(root, typeParameters, index) {
                visit(root);
                function visit(node) {
                    if (node.kind === 183 /* TypeReference */) {
                        const type = getTypeFromTypeReference(node);
                        if (type.flags & 262144 /* TypeParameter */) {
                            for (let i = index; i < typeParameters.length; i++) {
                                if (type.symbol === getSymbolOfDeclaration(typeParameters[i])) {
                                    error2(node, Diagnostics.Type_parameter_defaults_can_only_reference_previously_declared_type_parameters);
                                }
                            }
                        }
                    }
                    forEachChild(node, visit);
                }
            }
            function checkTypeParameterListsIdentical(symbol) {
                if (symbol.declarations && symbol.declarations.length === 1) {
                    return;
                }
                const links = getSymbolLinks(symbol);
                if (!links.typeParametersChecked) {
                    links.typeParametersChecked = true;
                    const declarations = getClassOrInterfaceDeclarationsOfSymbol(symbol);
                    if (!declarations || declarations.length <= 1) {
                        return;
                    }
                    const type = getDeclaredTypeOfSymbol(symbol);
                    if (!areTypeParametersIdentical(declarations, type.localTypeParameters, getEffectiveTypeParameterDeclarations)) {
                        const name = symbolToString(symbol);
                        for (const declaration of declarations) {
                            error2(declaration.name, Diagnostics.All_declarations_of_0_must_have_identical_type_parameters, name);
                        }
                    }
                }
            }
            function areTypeParametersIdentical(declarations, targetParameters, getTypeParameterDeclarations) {
                const maxTypeArgumentCount = length(targetParameters);
                const minTypeArgumentCount = getMinTypeArgumentCount(targetParameters);
                for (const declaration of declarations) {
                    const sourceParameters = getTypeParameterDeclarations(declaration);
                    const numTypeParameters = sourceParameters.length;
                    if (numTypeParameters < minTypeArgumentCount || numTypeParameters > maxTypeArgumentCount) {
                        return false;
                    }
                    for (let i = 0; i < numTypeParameters; i++) {
                        const source = sourceParameters[i];
                        const target = targetParameters[i];
                        if (source.name.escapedText !== target.symbol.escapedName) {
                            return false;
                        }
                        const constraint = getEffectiveConstraintOfTypeParameter(source);
                        const sourceConstraint = constraint && getTypeFromTypeNode(constraint);
                        const targetConstraint = getConstraintOfTypeParameter(target);
                        if (sourceConstraint && targetConstraint && !isTypeIdenticalTo(sourceConstraint, targetConstraint)) {
                            return false;
                        }
                        const sourceDefault = source.default && getTypeFromTypeNode(source.default);
                        const targetDefault = getDefaultFromTypeParameter(target);
                        if (sourceDefault && targetDefault && !isTypeIdenticalTo(sourceDefault, targetDefault)) {
                            return false;
                        }
                    }
                }
                return true;
            }
            function getFirstTransformableStaticClassElement(node) {
                const willTransformStaticElementsOfDecoratedClass = !legacyDecorators && languageVersion < 99 /* ESNext */ && classOrConstructorParameterIsDecorated(
                /*useLegacyDecorators*/
                false, node);
                const willTransformPrivateElementsOrClassStaticBlocks = languageVersion <= 9 /* ES2022 */;
                const willTransformInitializers = !emitStandardClassFields;
                if (willTransformStaticElementsOfDecoratedClass || willTransformPrivateElementsOrClassStaticBlocks) {
                    for (const member of node.members) {
                        if (willTransformStaticElementsOfDecoratedClass && classElementOrClassElementParameterIsDecorated(
                        /*useLegacyDecorators*/
                        false, member, node)) {
                            return firstOrUndefined(getDecorators(node)) ?? node;
                        }
                        else if (willTransformPrivateElementsOrClassStaticBlocks) {
                            if (isClassStaticBlockDeclaration(member)) {
                                return member;
                            }
                            else if (isStatic(member)) {
                                if (isPrivateIdentifierClassElementDeclaration(member) || willTransformInitializers && isInitializedProperty(member)) {
                                    return member;
                                }
                            }
                        }
                    }
                }
            }
            function checkClassExpressionExternalHelpers(node) {
                if (node.name)
                    return;
                const parent2 = walkUpOuterExpressions(node);
                if (!isNamedEvaluationSource(parent2))
                    return;
                const willTransformESDecorators = !legacyDecorators && languageVersion < 99 /* ESNext */;
                let location;
                if (willTransformESDecorators && classOrConstructorParameterIsDecorated(
                /*useLegacyDecorators*/
                false, node)) {
                    location = firstOrUndefined(getDecorators(node)) ?? node;
                }
                else {
                    location = getFirstTransformableStaticClassElement(node);
                }
                if (location) {
                    checkExternalEmitHelpers(location, 8388608 /* SetFunctionName */);
                    if ((isPropertyAssignment(parent2) || isPropertyDeclaration(parent2) || isBindingElement(parent2)) && isComputedPropertyName(parent2.name)) {
                        checkExternalEmitHelpers(location, 16777216 /* PropKey */);
                    }
                }
            }
            function checkClassExpression(node) {
                checkClassLikeDeclaration(node);
                checkNodeDeferred(node);
                checkClassExpressionExternalHelpers(node);
                return getTypeOfSymbol(getSymbolOfDeclaration(node));
            }
            function checkClassExpressionDeferred(node) {
                forEach(node.members, checkSourceElement);
                registerForUnusedIdentifiersCheck(node);
            }
            function checkClassDeclaration(node) {
                const firstDecorator = find(node.modifiers, isDecorator);
                if (legacyDecorators && firstDecorator && some(node.members, (p) => hasStaticModifier(p) && isPrivateIdentifierClassElementDeclaration(p))) {
                    grammarErrorOnNode(firstDecorator, Diagnostics.Class_decorators_can_t_be_used_with_static_private_identifier_Consider_removing_the_experimental_decorator);
                }
                if (!node.name && !hasSyntacticModifier(node, 2048 /* Default */)) {
                    grammarErrorOnFirstToken(node, Diagnostics.A_class_declaration_without_the_default_modifier_must_have_a_name);
                }
                checkClassLikeDeclaration(node);
                forEach(node.members, checkSourceElement);
                registerForUnusedIdentifiersCheck(node);
            }
            function checkClassLikeDeclaration(node) {
                checkGrammarClassLikeDeclaration(node);
                checkDecorators(node);
                checkCollisionsForDeclarationName(node, node.name);
                checkTypeParameters(getEffectiveTypeParameterDeclarations(node));
                checkExportsOnMergedDeclarations(node);
                const symbol = getSymbolOfDeclaration(node);
                const type = getDeclaredTypeOfSymbol(symbol);
                const typeWithThis = getTypeWithThisArgument(type);
                const staticType = getTypeOfSymbol(symbol);
                checkTypeParameterListsIdentical(symbol);
                checkFunctionOrConstructorSymbol(symbol);
                checkClassForDuplicateDeclarations(node);
                const nodeInAmbientContext = !!(node.flags & 33554432 /* Ambient */);
                if (!nodeInAmbientContext) {
                    checkClassForStaticPropertyNameConflicts(node);
                }
                const baseTypeNode = getEffectiveBaseTypeNode(node);
                if (baseTypeNode) {
                    forEach(baseTypeNode.typeArguments, checkSourceElement);
                    if (languageVersion < 2 /* ES2015 */) {
                        checkExternalEmitHelpers(baseTypeNode.parent, 1 /* Extends */);
                    }
                    const extendsNode = getClassExtendsHeritageElement(node);
                    if (extendsNode && extendsNode !== baseTypeNode) {
                        checkExpression(extendsNode.expression);
                    }
                    const baseTypes = getBaseTypes(type);
                    if (baseTypes.length) {
                        addLazyDiagnostic(() => {
                            const baseType = baseTypes[0];
                            const baseConstructorType = getBaseConstructorTypeOfClass(type);
                            const staticBaseType = getApparentType(baseConstructorType);
                            checkBaseTypeAccessibility(staticBaseType, baseTypeNode);
                            checkSourceElement(baseTypeNode.expression);
                            if (some(baseTypeNode.typeArguments)) {
                                forEach(baseTypeNode.typeArguments, checkSourceElement);
                                for (const constructor of getConstructorsForTypeArguments(staticBaseType, baseTypeNode.typeArguments, baseTypeNode)) {
                                    if (!checkTypeArgumentConstraints(baseTypeNode, constructor.typeParameters)) {
                                        break;
                                    }
                                }
                            }
                            const baseWithThis = getTypeWithThisArgument(baseType, type.thisType);
                            if (!checkTypeAssignableTo(typeWithThis, baseWithThis, 
                            /*errorNode*/
                            void 0)) {
                                issueMemberSpecificError(node, typeWithThis, baseWithThis, Diagnostics.Class_0_incorrectly_extends_base_class_1);
                            }
                            else {
                                checkTypeAssignableTo(staticType, getTypeWithoutSignatures(staticBaseType), node.name || node, Diagnostics.Class_static_side_0_incorrectly_extends_base_class_static_side_1);
                            }
                            if (baseConstructorType.flags & 8650752 /* TypeVariable */) {
                                if (!isMixinConstructorType(staticType)) {
                                    error2(node.name || node, Diagnostics.A_mixin_class_must_have_a_constructor_with_a_single_rest_parameter_of_type_any);
                                }
                                else {
                                    const constructSignatures = getSignaturesOfType(baseConstructorType, 1 /* Construct */);
                                    if (constructSignatures.some((signature) => signature.flags & 4 /* Abstract */) && !hasSyntacticModifier(node, 64 /* Abstract */)) {
                                        error2(node.name || node, Diagnostics.A_mixin_class_that_extends_from_a_type_variable_containing_an_abstract_construct_signature_must_also_be_declared_abstract);
                                    }
                                }
                            }
                            if (!(staticBaseType.symbol && staticBaseType.symbol.flags & 32 /* Class */) && !(baseConstructorType.flags & 8650752 /* TypeVariable */)) {
                                const constructors = getInstantiatedConstructorsForTypeArguments(staticBaseType, baseTypeNode.typeArguments, baseTypeNode);
                                if (forEach(constructors, (sig) => !isJSConstructor(sig.declaration) && !isTypeIdenticalTo(getReturnTypeOfSignature(sig), baseType))) {
                                    error2(baseTypeNode.expression, Diagnostics.Base_constructors_must_all_have_the_same_return_type);
                                }
                            }
                            checkKindsOfPropertyMemberOverrides(type, baseType);
                        });
                    }
                }
                checkMembersForOverrideModifier(node, type, typeWithThis, staticType);
                const implementedTypeNodes = getEffectiveImplementsTypeNodes(node);
                if (implementedTypeNodes) {
                    for (const typeRefNode of implementedTypeNodes) {
                        if (!isEntityNameExpression(typeRefNode.expression) || isOptionalChain(typeRefNode.expression)) {
                            error2(typeRefNode.expression, Diagnostics.A_class_can_only_implement_an_identifier_Slashqualified_name_with_optional_type_arguments);
                        }
                        checkTypeReferenceNode(typeRefNode);
                        addLazyDiagnostic(createImplementsDiagnostics(typeRefNode));
                    }
                }
                addLazyDiagnostic(() => {
                    checkIndexConstraints(type, symbol);
                    checkIndexConstraints(staticType, symbol, 
                    /*isStaticIndex*/
                    true);
                    checkTypeForDuplicateIndexSignatures(node);
                    checkPropertyInitialization(node);
                });
                function createImplementsDiagnostics(typeRefNode) {
                    return () => {
                        const t = getReducedType(getTypeFromTypeNode(typeRefNode));
                        if (!isErrorType(t)) {
                            if (isValidBaseType(t)) {
                                const genericDiag = t.symbol && t.symbol.flags & 32 /* Class */ ? Diagnostics.Class_0_incorrectly_implements_class_1_Did_you_mean_to_extend_1_and_inherit_its_members_as_a_subclass : Diagnostics.Class_0_incorrectly_implements_interface_1;
                                const baseWithThis = getTypeWithThisArgument(t, type.thisType);
                                if (!checkTypeAssignableTo(typeWithThis, baseWithThis, 
                                /*errorNode*/
                                void 0)) {
                                    issueMemberSpecificError(node, typeWithThis, baseWithThis, genericDiag);
                                }
                            }
                            else {
                                error2(typeRefNode, Diagnostics.A_class_can_only_implement_an_object_type_or_intersection_of_object_types_with_statically_known_members);
                            }
                        }
                    };
                }
            }
            function checkMembersForOverrideModifier(node, type, typeWithThis, staticType) {
                const baseTypeNode = getEffectiveBaseTypeNode(node);
                const baseTypes = baseTypeNode && getBaseTypes(type);
                const baseWithThis = (baseTypes == null ? void 0 : baseTypes.length) ? getTypeWithThisArgument(first(baseTypes), type.thisType) : void 0;
                const baseStaticType = getBaseConstructorTypeOfClass(type);
                for (const member of node.members) {
                    if (hasAmbientModifier(member)) {
                        continue;
                    }
                    if (isConstructorDeclaration(member)) {
                        forEach(member.parameters, (param) => {
                            if (isParameterPropertyDeclaration(param, member)) {
                                checkExistingMemberForOverrideModifier(node, staticType, baseStaticType, baseWithThis, type, typeWithThis, param, 
                                /*memberIsParameterProperty*/
                                true);
                            }
                        });
                    }
                    checkExistingMemberForOverrideModifier(node, staticType, baseStaticType, baseWithThis, type, typeWithThis, member, 
                    /*memberIsParameterProperty*/
                    false);
                }
            }
            function checkExistingMemberForOverrideModifier(node, staticType, baseStaticType, baseWithThis, type, typeWithThis, member, memberIsParameterProperty, reportErrors2 = true) {
                const declaredProp = member.name && getSymbolAtLocation(member.name) || getSymbolAtLocation(member);
                if (!declaredProp) {
                    return 0 /* Ok */;
                }
                return checkMemberForOverrideModifier(node, staticType, baseStaticType, baseWithThis, type, typeWithThis, hasOverrideModifier(member), hasAbstractModifier(member), isStatic(member), memberIsParameterProperty, symbolName(declaredProp), reportErrors2 ? member : void 0);
            }
            function checkMemberForOverrideModifier(node, staticType, baseStaticType, baseWithThis, type, typeWithThis, memberHasOverrideModifier, memberHasAbstractModifier, memberIsStatic, memberIsParameterProperty, memberName, errorNode) {
                const isJs = isInJSFile(node);
                const nodeInAmbientContext = !!(node.flags & 33554432 /* Ambient */);
                if (baseWithThis && (memberHasOverrideModifier || compilerOptions.noImplicitOverride)) {
                    const memberEscapedName = escapeLeadingUnderscores(memberName);
                    const thisType = memberIsStatic ? staticType : typeWithThis;
                    const baseType = memberIsStatic ? baseStaticType : baseWithThis;
                    const prop = getPropertyOfType(thisType, memberEscapedName);
                    const baseProp = getPropertyOfType(baseType, memberEscapedName);
                    const baseClassName = typeToString(baseWithThis);
                    if (prop && !baseProp && memberHasOverrideModifier) {
                        if (errorNode) {
                            const suggestion = getSuggestedSymbolForNonexistentClassMember(memberName, baseType);
                            suggestion ? error2(errorNode, isJs ? Diagnostics.This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_it_is_not_declared_in_the_base_class_0_Did_you_mean_1 : Diagnostics.This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0_Did_you_mean_1, baseClassName, symbolToString(suggestion)) : error2(errorNode, isJs ? Diagnostics.This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_it_is_not_declared_in_the_base_class_0 : Diagnostics.This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0, baseClassName);
                        }
                        return 2 /* HasInvalidOverride */;
                    }
                    else if (prop && (baseProp == null ? void 0 : baseProp.declarations) && compilerOptions.noImplicitOverride && !nodeInAmbientContext) {
                        const baseHasAbstract = some(baseProp.declarations, hasAbstractModifier);
                        if (memberHasOverrideModifier) {
                            return 0 /* Ok */;
                        }
                        if (!baseHasAbstract) {
                            if (errorNode) {
                                const diag2 = memberIsParameterProperty ? isJs ? Diagnostics.This_parameter_property_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_in_the_base_class_0 : Diagnostics.This_parameter_property_must_have_an_override_modifier_because_it_overrides_a_member_in_base_class_0 : isJs ? Diagnostics.This_member_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_in_the_base_class_0 : Diagnostics.This_member_must_have_an_override_modifier_because_it_overrides_a_member_in_the_base_class_0;
                                error2(errorNode, diag2, baseClassName);
                            }
                            return 1 /* NeedsOverride */;
                        }
                        else if (memberHasAbstractModifier && baseHasAbstract) {
                            if (errorNode) {
                                error2(errorNode, Diagnostics.This_member_must_have_an_override_modifier_because_it_overrides_an_abstract_method_that_is_declared_in_the_base_class_0, baseClassName);
                            }
                            return 1 /* NeedsOverride */;
                        }
                    }
                }
                else if (memberHasOverrideModifier) {
                    if (errorNode) {
                        const className = typeToString(type);
                        error2(errorNode, isJs ? Diagnostics.This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_its_containing_class_0_does_not_extend_another_class : Diagnostics.This_member_cannot_have_an_override_modifier_because_its_containing_class_0_does_not_extend_another_class, className);
                    }
                    return 2 /* HasInvalidOverride */;
                }
                return 0 /* Ok */;
            }
            function issueMemberSpecificError(node, typeWithThis, baseWithThis, broadDiag) {
                let issuedMemberError = false;
                for (const member of node.members) {
                    if (isStatic(member)) {
                        continue;
                    }
                    const declaredProp = member.name && getSymbolAtLocation(member.name) || getSymbolAtLocation(member);
                    if (declaredProp) {
                        const prop = getPropertyOfType(typeWithThis, declaredProp.escapedName);
                        const baseProp = getPropertyOfType(baseWithThis, declaredProp.escapedName);
                        if (prop && baseProp) {
                            const rootChain = () => chainDiagnosticMessages(
                            /*details*/
                            void 0, Diagnostics.Property_0_in_type_1_is_not_assignable_to_the_same_property_in_base_type_2, symbolToString(declaredProp), typeToString(typeWithThis), typeToString(baseWithThis));
                            if (!checkTypeAssignableTo(getTypeOfSymbol(prop), getTypeOfSymbol(baseProp), member.name || member, 
                            /*headMessage*/
                            void 0, rootChain)) {
                                issuedMemberError = true;
                            }
                        }
                    }
                }
                if (!issuedMemberError) {
                    checkTypeAssignableTo(typeWithThis, baseWithThis, node.name || node, broadDiag);
                }
            }
            function checkBaseTypeAccessibility(type, node) {
                const signatures = getSignaturesOfType(type, 1 /* Construct */);
                if (signatures.length) {
                    const declaration = signatures[0].declaration;
                    if (declaration && hasEffectiveModifier(declaration, 2 /* Private */)) {
                        const typeClassDeclaration = getClassLikeDeclarationOfSymbol(type.symbol);
                        if (!isNodeWithinClass(node, typeClassDeclaration)) {
                            error2(node, Diagnostics.Cannot_extend_a_class_0_Class_constructor_is_marked_as_private, getFullyQualifiedName(type.symbol));
                        }
                    }
                }
            }
            function getMemberOverrideModifierStatus(node, member, memberSymbol) {
                if (!member.name) {
                    return 0 /* Ok */;
                }
                const classSymbol = getSymbolOfDeclaration(node);
                const type = getDeclaredTypeOfSymbol(classSymbol);
                const typeWithThis = getTypeWithThisArgument(type);
                const staticType = getTypeOfSymbol(classSymbol);
                const baseTypeNode = getEffectiveBaseTypeNode(node);
                const baseTypes = baseTypeNode && getBaseTypes(type);
                const baseWithThis = (baseTypes == null ? void 0 : baseTypes.length) ? getTypeWithThisArgument(first(baseTypes), type.thisType) : void 0;
                const baseStaticType = getBaseConstructorTypeOfClass(type);
                const memberHasOverrideModifier = member.parent ? hasOverrideModifier(member) : hasSyntacticModifier(member, 16 /* Override */);
                return checkMemberForOverrideModifier(node, staticType, baseStaticType, baseWithThis, type, typeWithThis, memberHasOverrideModifier, hasAbstractModifier(member), isStatic(member), 
                /*memberIsParameterProperty*/
                false, symbolName(memberSymbol));
            }
            function getTargetSymbol(s) {
                return getCheckFlags(s) & 1 /* Instantiated */ ? s.links.target : s;
            }
            function getClassOrInterfaceDeclarationsOfSymbol(symbol) {
                return filter(symbol.declarations, (d) => d.kind === 263 /* ClassDeclaration */ || d.kind === 264 /* InterfaceDeclaration */);
            }
            function checkKindsOfPropertyMemberOverrides(type, baseType) {
                var _a, _b, _c, _d;
                const baseProperties = getPropertiesOfType(baseType);
                let inheritedAbstractMemberNotImplementedError;
                basePropertyCheck: for (const baseProperty of baseProperties) {
                    const base = getTargetSymbol(baseProperty);
                    if (base.flags & 4194304 /* Prototype */) {
                        continue;
                    }
                    const baseSymbol = getPropertyOfObjectType(type, base.escapedName);
                    if (!baseSymbol) {
                        continue;
                    }
                    const derived = getTargetSymbol(baseSymbol);
                    const baseDeclarationFlags = getDeclarationModifierFlagsFromSymbol(base);
                    Debug.assert(!!derived, "derived should point to something, even if it is the base class' declaration.");
                    if (derived === base) {
                        const derivedClassDecl = getClassLikeDeclarationOfSymbol(type.symbol);
                        if (baseDeclarationFlags & 64 /* Abstract */ && (!derivedClassDecl || !hasSyntacticModifier(derivedClassDecl, 64 /* Abstract */))) {
                            for (const otherBaseType of getBaseTypes(type)) {
                                if (otherBaseType === baseType)
                                    continue;
                                const baseSymbol2 = getPropertyOfObjectType(otherBaseType, base.escapedName);
                                const derivedElsewhere = baseSymbol2 && getTargetSymbol(baseSymbol2);
                                if (derivedElsewhere && derivedElsewhere !== base) {
                                    continue basePropertyCheck;
                                }
                            }
                            if (!inheritedAbstractMemberNotImplementedError) {
                                inheritedAbstractMemberNotImplementedError = error2(derivedClassDecl, Diagnostics.Non_abstract_class_0_does_not_implement_all_abstract_members_of_1, typeToString(type), typeToString(baseType));
                            }
                            if (derivedClassDecl.kind === 231 /* ClassExpression */) {
                                addRelatedInfo(inheritedAbstractMemberNotImplementedError, createDiagnosticForNode(baseProperty.valueDeclaration ?? (baseProperty.declarations && first(baseProperty.declarations)) ?? derivedClassDecl, Diagnostics.Non_abstract_class_expression_does_not_implement_inherited_abstract_member_0_from_class_1, symbolToString(baseProperty), typeToString(baseType)));
                            }
                            else {
                                addRelatedInfo(inheritedAbstractMemberNotImplementedError, createDiagnosticForNode(baseProperty.valueDeclaration ?? (baseProperty.declarations && first(baseProperty.declarations)) ?? derivedClassDecl, Diagnostics.Non_abstract_class_0_does_not_implement_inherited_abstract_member_1_from_class_2, typeToString(type), symbolToString(baseProperty), typeToString(baseType)));
                            }
                        }
                    }
                    else {
                        const derivedDeclarationFlags = getDeclarationModifierFlagsFromSymbol(derived);
                        if (baseDeclarationFlags & 2 /* Private */ || derivedDeclarationFlags & 2 /* Private */) {
                            continue;
                        }
                        let errorMessage;
                        const basePropertyFlags = base.flags & 98308 /* PropertyOrAccessor */;
                        const derivedPropertyFlags = derived.flags & 98308 /* PropertyOrAccessor */;
                        if (basePropertyFlags && derivedPropertyFlags) {
                            if ((getCheckFlags(base) & 6 /* Synthetic */ ? (_a = base.declarations) == null ? void 0 : _a.some((d) => isPropertyAbstractOrInterface(d, baseDeclarationFlags)) : (_b = base.declarations) == null ? void 0 : _b.every((d) => isPropertyAbstractOrInterface(d, baseDeclarationFlags))) || getCheckFlags(base) & 262144 /* Mapped */ || derived.valueDeclaration && isBinaryExpression(derived.valueDeclaration)) {
                                continue;
                            }
                            const overriddenInstanceProperty = basePropertyFlags !== 4 /* Property */ && derivedPropertyFlags === 4 /* Property */;
                            const overriddenInstanceAccessor = basePropertyFlags === 4 /* Property */ && derivedPropertyFlags !== 4 /* Property */;
                            if (overriddenInstanceProperty || overriddenInstanceAccessor) {
                                const errorMessage2 = overriddenInstanceProperty ? Diagnostics._0_is_defined_as_an_accessor_in_class_1_but_is_overridden_here_in_2_as_an_instance_property : Diagnostics._0_is_defined_as_a_property_in_class_1_but_is_overridden_here_in_2_as_an_accessor;
                                error2(getNameOfDeclaration(derived.valueDeclaration) || derived.valueDeclaration, errorMessage2, symbolToString(base), typeToString(baseType), typeToString(type));
                            }
                            else if (useDefineForClassFields) {
                                const uninitialized = (_c = derived.declarations) == null ? void 0 : _c.find((d) => d.kind === 172 /* PropertyDeclaration */ && !d.initializer);
                                if (uninitialized && !(derived.flags & 33554432 /* Transient */) && !(baseDeclarationFlags & 64 /* Abstract */) && !(derivedDeclarationFlags & 64 /* Abstract */) && !((_d = derived.declarations) == null ? void 0 : _d.some((d) => !!(d.flags & 33554432 /* Ambient */)))) {
                                    const constructor = findConstructorDeclaration(getClassLikeDeclarationOfSymbol(type.symbol));
                                    const propName = uninitialized.name;
                                    if (uninitialized.exclamationToken || !constructor || !isIdentifier(propName) || !strictNullChecks || !isPropertyInitializedInConstructor(propName, type, constructor)) {
                                        const errorMessage2 = Diagnostics.Property_0_will_overwrite_the_base_property_in_1_If_this_is_intentional_add_an_initializer_Otherwise_add_a_declare_modifier_or_remove_the_redundant_declaration;
                                        error2(getNameOfDeclaration(derived.valueDeclaration) || derived.valueDeclaration, errorMessage2, symbolToString(base), typeToString(baseType));
                                    }
                                }
                            }
                            continue;
                        }
                        else if (isPrototypeProperty(base)) {
                            if (isPrototypeProperty(derived) || derived.flags & 4 /* Property */) {
                                continue;
                            }
                            else {
                                Debug.assert(!!(derived.flags & 98304 /* Accessor */));
                                errorMessage = Diagnostics.Class_0_defines_instance_member_function_1_but_extended_class_2_defines_it_as_instance_member_accessor;
                            }
                        }
                        else if (base.flags & 98304 /* Accessor */) {
                            errorMessage = Diagnostics.Class_0_defines_instance_member_accessor_1_but_extended_class_2_defines_it_as_instance_member_function;
                        }
                        else {
                            errorMessage = Diagnostics.Class_0_defines_instance_member_property_1_but_extended_class_2_defines_it_as_instance_member_function;
                        }
                        error2(getNameOfDeclaration(derived.valueDeclaration) || derived.valueDeclaration, errorMessage, typeToString(baseType), symbolToString(base), typeToString(type));
                    }
                }
            }
            function isPropertyAbstractOrInterface(declaration, baseDeclarationFlags) {
                return baseDeclarationFlags & 64 /* Abstract */ && (!isPropertyDeclaration(declaration) || !declaration.initializer) || isInterfaceDeclaration(declaration.parent);
            }
            function getNonInheritedProperties(type, baseTypes, properties) {
                if (!length(baseTypes)) {
                    return properties;
                }
                const seen = /* @__PURE__ */ new Map();
                forEach(properties, (p) => {
                    seen.set(p.escapedName, p);
                });
                for (const base of baseTypes) {
                    const properties2 = getPropertiesOfType(getTypeWithThisArgument(base, type.thisType));
                    for (const prop of properties2) {
                        const existing = seen.get(prop.escapedName);
                        if (existing && prop.parent === existing.parent) {
                            seen.delete(prop.escapedName);
                        }
                    }
                }
                return arrayFrom(seen.values());
            }
            function checkInheritedPropertiesAreIdentical(type, typeNode) {
                const baseTypes = getBaseTypes(type);
                if (baseTypes.length < 2) {
                    return true;
                }
                const seen = /* @__PURE__ */ new Map();
                forEach(resolveDeclaredMembers(type).declaredProperties, (p) => {
                    seen.set(p.escapedName, { prop: p, containingType: type });
                });
                let ok = true;
                for (const base of baseTypes) {
                    const properties = getPropertiesOfType(getTypeWithThisArgument(base, type.thisType));
                    for (const prop of properties) {
                        const existing = seen.get(prop.escapedName);
                        if (!existing) {
                            seen.set(prop.escapedName, { prop, containingType: base });
                        }
                        else {
                            const isInheritedProperty = existing.containingType !== type;
                            if (isInheritedProperty && !isPropertyIdenticalTo(existing.prop, prop)) {
                                ok = false;
                                const typeName1 = typeToString(existing.containingType);
                                const typeName2 = typeToString(base);
                                let errorInfo = chainDiagnosticMessages(
                                /*details*/
                                void 0, Diagnostics.Named_property_0_of_types_1_and_2_are_not_identical, symbolToString(prop), typeName1, typeName2);
                                errorInfo = chainDiagnosticMessages(errorInfo, Diagnostics.Interface_0_cannot_simultaneously_extend_types_1_and_2, typeToString(type), typeName1, typeName2);
                                diagnostics.add(createDiagnosticForNodeFromMessageChain(getSourceFileOfNode(typeNode), typeNode, errorInfo));
                            }
                        }
                    }
                }
                return ok;
            }
            function checkPropertyInitialization(node) {
                if (!strictNullChecks || !strictPropertyInitialization || node.flags & 33554432 /* Ambient */) {
                    return;
                }
                const constructor = findConstructorDeclaration(node);
                for (const member of node.members) {
                    if (getEffectiveModifierFlags(member) & 128 /* Ambient */) {
                        continue;
                    }
                    if (!isStatic(member) && isPropertyWithoutInitializer(member)) {
                        const propName = member.name;
                        if (isIdentifier(propName) || isPrivateIdentifier(propName) || isComputedPropertyName(propName)) {
                            const type = getTypeOfSymbol(getSymbolOfDeclaration(member));
                            if (!(type.flags & 3 /* AnyOrUnknown */ || containsUndefinedType(type))) {
                                if (!constructor || !isPropertyInitializedInConstructor(propName, type, constructor)) {
                                    error2(member.name, Diagnostics.Property_0_has_no_initializer_and_is_not_definitely_assigned_in_the_constructor, declarationNameToString(propName));
                                }
                            }
                        }
                    }
                }
            }
            function isPropertyWithoutInitializer(node) {
                return node.kind === 172 /* PropertyDeclaration */ && !hasAbstractModifier(node) && !node.exclamationToken && !node.initializer;
            }
            function isPropertyInitializedInStaticBlocks(propName, propType, staticBlocks, startPos, endPos) {
                for (const staticBlock of staticBlocks) {
                    if (staticBlock.pos >= startPos && staticBlock.pos <= endPos) {
                        const reference = factory.createPropertyAccessExpression(factory.createThis(), propName);
                        setParent(reference.expression, reference);
                        setParent(reference, staticBlock);
                        reference.flowNode = staticBlock.returnFlowNode;
                        const flowType = getFlowTypeOfReference(reference, propType, getOptionalType(propType));
                        if (!containsUndefinedType(flowType)) {
                            return true;
                        }
                    }
                }
                return false;
            }
            function isPropertyInitializedInConstructor(propName, propType, constructor) {
                const reference = isComputedPropertyName(propName) ? factory.createElementAccessExpression(factory.createThis(), propName.expression) : factory.createPropertyAccessExpression(factory.createThis(), propName);
                setParent(reference.expression, reference);
                setParent(reference, constructor);
                reference.flowNode = constructor.returnFlowNode;
                const flowType = getFlowTypeOfReference(reference, propType, getOptionalType(propType));
                return !containsUndefinedType(flowType);
            }
            function checkInterfaceDeclaration(node) {
                if (!checkGrammarModifiers(node))
                    checkGrammarInterfaceDeclaration(node);
                checkTypeParameters(node.typeParameters);
                addLazyDiagnostic(() => {
                    checkTypeNameIsReserved(node.name, Diagnostics.Interface_name_cannot_be_0);
                    checkExportsOnMergedDeclarations(node);
                    const symbol = getSymbolOfDeclaration(node);
                    checkTypeParameterListsIdentical(symbol);
                    const firstInterfaceDecl = getDeclarationOfKind(symbol, 264 /* InterfaceDeclaration */);
                    if (node === firstInterfaceDecl) {
                        const type = getDeclaredTypeOfSymbol(symbol);
                        const typeWithThis = getTypeWithThisArgument(type);
                        if (checkInheritedPropertiesAreIdentical(type, node.name)) {
                            for (const baseType of getBaseTypes(type)) {
                                checkTypeAssignableTo(typeWithThis, getTypeWithThisArgument(baseType, type.thisType), node.name, Diagnostics.Interface_0_incorrectly_extends_interface_1);
                            }
                            checkIndexConstraints(type, symbol);
                        }
                    }
                    checkObjectTypeForDuplicateDeclarations(node);
                });
                forEach(getInterfaceBaseTypeNodes(node), (heritageElement) => {
                    if (!isEntityNameExpression(heritageElement.expression) || isOptionalChain(heritageElement.expression)) {
                        error2(heritageElement.expression, Diagnostics.An_interface_can_only_extend_an_identifier_Slashqualified_name_with_optional_type_arguments);
                    }
                    checkTypeReferenceNode(heritageElement);
                });
                forEach(node.members, checkSourceElement);
                addLazyDiagnostic(() => {
                    checkTypeForDuplicateIndexSignatures(node);
                    registerForUnusedIdentifiersCheck(node);
                });
            }
            function checkTypeAliasDeclaration(node) {
                checkGrammarModifiers(node);
                checkTypeNameIsReserved(node.name, Diagnostics.Type_alias_name_cannot_be_0);
                checkExportsOnMergedDeclarations(node);
                checkTypeParameters(node.typeParameters);
                if (node.type.kind === 141 /* IntrinsicKeyword */) {
                    if (!intrinsicTypeKinds.has(node.name.escapedText) || length(node.typeParameters) !== 1) {
                        error2(node.type, Diagnostics.The_intrinsic_keyword_can_only_be_used_to_declare_compiler_provided_intrinsic_types);
                    }
                }
                else {
                    checkSourceElement(node.type);
                    registerForUnusedIdentifiersCheck(node);
                }
            }
            function computeEnumMemberValues(node) {
                const nodeLinks2 = getNodeLinks(node);
                if (!(nodeLinks2.flags & 1024 /* EnumValuesComputed */)) {
                    nodeLinks2.flags |= 1024 /* EnumValuesComputed */;
                    let autoValue = 0;
                    for (const member of node.members) {
                        const value = computeMemberValue(member, autoValue);
                        getNodeLinks(member).enumMemberValue = value;
                        autoValue = typeof value === "number" ? value + 1 : void 0;
                    }
                }
            }
            function computeMemberValue(member, autoValue) {
                if (isComputedNonLiteralName(member.name)) {
                    error2(member.name, Diagnostics.Computed_property_names_are_not_allowed_in_enums);
                }
                else {
                    const text = getTextOfPropertyName(member.name);
                    if (isNumericLiteralName(text) && !isInfinityOrNaNString(text)) {
                        error2(member.name, Diagnostics.An_enum_member_cannot_have_a_numeric_name);
                    }
                }
                if (member.initializer) {
                    return computeConstantValue(member);
                }
                if (member.parent.flags & 33554432 /* Ambient */ && !isEnumConst(member.parent)) {
                    return void 0;
                }
                if (autoValue !== void 0) {
                    return autoValue;
                }
                error2(member.name, Diagnostics.Enum_member_must_have_initializer);
                return void 0;
            }
            function computeConstantValue(member) {
                const isConstEnum = isEnumConst(member.parent);
                const initializer = member.initializer;
                const value = evaluate(initializer, member);
                if (value !== void 0) {
                    if (isConstEnum && typeof value === "number" && !isFinite(value)) {
                        error2(initializer, isNaN(value) ? Diagnostics.const_enum_member_initializer_was_evaluated_to_disallowed_value_NaN : Diagnostics.const_enum_member_initializer_was_evaluated_to_a_non_finite_value);
                    }
                }
                else if (isConstEnum) {
                    error2(initializer, Diagnostics.const_enum_member_initializers_must_be_constant_expressions);
                }
                else if (member.parent.flags & 33554432 /* Ambient */) {
                    error2(initializer, Diagnostics.In_ambient_enum_declarations_member_initializer_must_be_constant_expression);
                }
                else {
                    checkTypeAssignableTo(checkExpression(initializer), numberType, initializer, Diagnostics.Type_0_is_not_assignable_to_type_1_as_required_for_computed_enum_member_values);
                }
                return value;
            }
            function evaluate(expr, location) {
                switch (expr.kind) {
                    case 224 /* PrefixUnaryExpression */:
                        const value = evaluate(expr.operand, location);
                        if (typeof value === "number") {
                            switch (expr.operator) {
                                case 40 /* PlusToken */:
                                    return value;
                                case 41 /* MinusToken */:
                                    return -value;
                                case 55 /* TildeToken */:
                                    return ~value;
                            }
                        }
                        break;
                    case 226 /* BinaryExpression */:
                        const left = evaluate(expr.left, location);
                        const right = evaluate(expr.right, location);
                        if (typeof left === "number" && typeof right === "number") {
                            switch (expr.operatorToken.kind) {
                                case 52 /* BarToken */:
                                    return left | right;
                                case 51 /* AmpersandToken */:
                                    return left & right;
                                case 49 /* GreaterThanGreaterThanToken */:
                                    return left >> right;
                                case 50 /* GreaterThanGreaterThanGreaterThanToken */:
                                    return left >>> right;
                                case 48 /* LessThanLessThanToken */:
                                    return left << right;
                                case 53 /* CaretToken */:
                                    return left ^ right;
                                case 42 /* AsteriskToken */:
                                    return left * right;
                                case 44 /* SlashToken */:
                                    return left / right;
                                case 40 /* PlusToken */:
                                    return left + right;
                                case 41 /* MinusToken */:
                                    return left - right;
                                case 45 /* PercentToken */:
                                    return left % right;
                                case 43 /* AsteriskAsteriskToken */:
                                    return left ** right;
                            }
                        }
                        else if ((typeof left === "string" || typeof left === "number") && (typeof right === "string" || typeof right === "number") && expr.operatorToken.kind === 40 /* PlusToken */) {
                            return "" + left + right;
                        }
                        break;
                    case 11 /* StringLiteral */:
                    case 15 /* NoSubstitutionTemplateLiteral */:
                        return expr.text;
                    case 228 /* TemplateExpression */:
                        return evaluateTemplateExpression(expr, location);
                    case 9 /* NumericLiteral */:
                        checkGrammarNumericLiteral(expr);
                        return +expr.text;
                    case 217 /* ParenthesizedExpression */:
                        return evaluate(expr.expression, location);
                    case 80 /* Identifier */: {
                        const identifier = expr;
                        if (isInfinityOrNaNString(identifier.escapedText) && resolveEntityName(identifier, 111551 /* Value */, 
                        /*ignoreErrors*/
                        true) === getGlobalSymbol(identifier.escapedText, 111551 /* Value */, 
                        /*diagnostic*/
                        void 0)) {
                            return +identifier.escapedText;
                        }
                    }
                    case 211 /* PropertyAccessExpression */:
                        if (isEntityNameExpression(expr)) {
                            const symbol = resolveEntityName(expr, 111551 /* Value */, 
                            /*ignoreErrors*/
                            true);
                            if (symbol) {
                                if (symbol.flags & 8 /* EnumMember */) {
                                    return location ? evaluateEnumMember(expr, symbol, location) : getEnumMemberValue(symbol.valueDeclaration);
                                }
                                if (isConstantVariable(symbol)) {
                                    const declaration = symbol.valueDeclaration;
                                    if (declaration && isVariableDeclaration(declaration) && !declaration.type && declaration.initializer && (!location || declaration !== location && isBlockScopedNameDeclaredBeforeUse(declaration, location))) {
                                        return evaluate(declaration.initializer, declaration);
                                    }
                                }
                            }
                        }
                        break;
                    case 212 /* ElementAccessExpression */:
                        const root = expr.expression;
                        if (isEntityNameExpression(root) && isStringLiteralLike(expr.argumentExpression)) {
                            const rootSymbol = resolveEntityName(root, 111551 /* Value */, 
                            /*ignoreErrors*/
                            true);
                            if (rootSymbol && rootSymbol.flags & 384 /* Enum */) {
                                const name = escapeLeadingUnderscores(expr.argumentExpression.text);
                                const member = rootSymbol.exports.get(name);
                                if (member) {
                                    return location ? evaluateEnumMember(expr, member, location) : getEnumMemberValue(member.valueDeclaration);
                                }
                            }
                        }
                        break;
                }
                return void 0;
            }
            function evaluateEnumMember(expr, symbol, location) {
                const declaration = symbol.valueDeclaration;
                if (!declaration || declaration === location) {
                    error2(expr, Diagnostics.Property_0_is_used_before_being_assigned, symbolToString(symbol));
                    return void 0;
                }
                if (!isBlockScopedNameDeclaredBeforeUse(declaration, location)) {
                    error2(expr, Diagnostics.A_member_initializer_in_a_enum_declaration_cannot_reference_members_declared_after_it_including_members_defined_in_other_enums);
                    return 0;
                }
                return getEnumMemberValue(declaration);
            }
            function evaluateTemplateExpression(expr, location) {
                let result = expr.head.text;
                for (const span of expr.templateSpans) {
                    const value = evaluate(span.expression, location);
                    if (value === void 0) {
                        return void 0;
                    }
                    result += value;
                    result += span.literal.text;
                }
                return result;
            }
            function checkEnumDeclaration(node) {
                addLazyDiagnostic(() => checkEnumDeclarationWorker(node));
            }
            function checkEnumDeclarationWorker(node) {
                checkGrammarModifiers(node);
                checkCollisionsForDeclarationName(node, node.name);
                checkExportsOnMergedDeclarations(node);
                node.members.forEach(checkEnumMember);
                computeEnumMemberValues(node);
                const enumSymbol = getSymbolOfDeclaration(node);
                const firstDeclaration = getDeclarationOfKind(enumSymbol, node.kind);
                if (node === firstDeclaration) {
                    if (enumSymbol.declarations && enumSymbol.declarations.length > 1) {
                        const enumIsConst = isEnumConst(node);
                        forEach(enumSymbol.declarations, (decl) => {
                            if (isEnumDeclaration(decl) && isEnumConst(decl) !== enumIsConst) {
                                error2(getNameOfDeclaration(decl), Diagnostics.Enum_declarations_must_all_be_const_or_non_const);
                            }
                        });
                    }
                    let seenEnumMissingInitialInitializer = false;
                    forEach(enumSymbol.declarations, (declaration) => {
                        if (declaration.kind !== 266 /* EnumDeclaration */) {
                            return false;
                        }
                        const enumDeclaration = declaration;
                        if (!enumDeclaration.members.length) {
                            return false;
                        }
                        const firstEnumMember = enumDeclaration.members[0];
                        if (!firstEnumMember.initializer) {
                            if (seenEnumMissingInitialInitializer) {
                                error2(firstEnumMember.name, Diagnostics.In_an_enum_with_multiple_declarations_only_one_declaration_can_omit_an_initializer_for_its_first_enum_element);
                            }
                            else {
                                seenEnumMissingInitialInitializer = true;
                            }
                        }
                    });
                }
            }
            function checkEnumMember(node) {
                if (isPrivateIdentifier(node.name)) {
                    error2(node, Diagnostics.An_enum_member_cannot_be_named_with_a_private_identifier);
                }
                if (node.initializer) {
                    checkExpression(node.initializer);
                }
            }
            function getFirstNonAmbientClassOrFunctionDeclaration(symbol) {
                const declarations = symbol.declarations;
                if (declarations) {
                    for (const declaration of declarations) {
                        if ((declaration.kind === 263 /* ClassDeclaration */ || declaration.kind === 262 /* FunctionDeclaration */ && nodeIsPresent(declaration.body)) && !(declaration.flags & 33554432 /* Ambient */)) {
                            return declaration;
                        }
                    }
                }
                return void 0;
            }
            function inSameLexicalScope(node1, node2) {
                const container1 = getEnclosingBlockScopeContainer(node1);
                const container2 = getEnclosingBlockScopeContainer(node2);
                if (isGlobalSourceFile(container1)) {
                    return isGlobalSourceFile(container2);
                }
                else if (isGlobalSourceFile(container2)) {
                    return false;
                }
                else {
                    return container1 === container2;
                }
            }
            function checkModuleDeclaration(node) {
                if (node.body) {
                    checkSourceElement(node.body);
                    if (!isGlobalScopeAugmentation(node)) {
                        registerForUnusedIdentifiersCheck(node);
                    }
                }
                addLazyDiagnostic(checkModuleDeclarationDiagnostics);
                function checkModuleDeclarationDiagnostics() {
                    var _a, _b;
                    const isGlobalAugmentation = isGlobalScopeAugmentation(node);
                    const inAmbientContext = node.flags & 33554432 /* Ambient */;
                    if (isGlobalAugmentation && !inAmbientContext) {
                        error2(node.name, Diagnostics.Augmentations_for_the_global_scope_should_have_declare_modifier_unless_they_appear_in_already_ambient_context);
                    }
                    const isAmbientExternalModule = isAmbientModule(node);
                    const contextErrorMessage = isAmbientExternalModule ? Diagnostics.An_ambient_module_declaration_is_only_allowed_at_the_top_level_in_a_file : Diagnostics.A_namespace_declaration_is_only_allowed_at_the_top_level_of_a_namespace_or_module;
                    if (checkGrammarModuleElementContext(node, contextErrorMessage)) {
                        return;
                    }
                    if (!checkGrammarModifiers(node)) {
                        if (!inAmbientContext && node.name.kind === 11 /* StringLiteral */) {
                            grammarErrorOnNode(node.name, Diagnostics.Only_ambient_modules_can_use_quoted_names);
                        }
                    }
                    if (isIdentifier(node.name)) {
                        checkCollisionsForDeclarationName(node, node.name);
                    }
                    checkExportsOnMergedDeclarations(node);
                    const symbol = getSymbolOfDeclaration(node);
                    if (symbol.flags & 512 /* ValueModule */ && !inAmbientContext && isInstantiatedModule(node, shouldPreserveConstEnums(compilerOptions))) {
                        if (getIsolatedModules(compilerOptions) && !getSourceFileOfNode(node).externalModuleIndicator) {
                            error2(node.name, Diagnostics.Namespaces_are_not_allowed_in_global_script_files_when_0_is_enabled_If_this_file_is_not_intended_to_be_a_global_script_set_moduleDetection_to_force_or_add_an_empty_export_statement, isolatedModulesLikeFlagName);
                        }
                        if (((_a = symbol.declarations) == null ? void 0 : _a.length) > 1) {
                            const firstNonAmbientClassOrFunc = getFirstNonAmbientClassOrFunctionDeclaration(symbol);
                            if (firstNonAmbientClassOrFunc) {
                                if (getSourceFileOfNode(node) !== getSourceFileOfNode(firstNonAmbientClassOrFunc)) {
                                    error2(node.name, Diagnostics.A_namespace_declaration_cannot_be_in_a_different_file_from_a_class_or_function_with_which_it_is_merged);
                                }
                                else if (node.pos < firstNonAmbientClassOrFunc.pos) {
                                    error2(node.name, Diagnostics.A_namespace_declaration_cannot_be_located_prior_to_a_class_or_function_with_which_it_is_merged);
                                }
                            }
                            const mergedClass = getDeclarationOfKind(symbol, 263 /* ClassDeclaration */);
                            if (mergedClass && inSameLexicalScope(node, mergedClass)) {
                                getNodeLinks(node).flags |= 2048 /* LexicalModuleMergesWithClass */;
                            }
                        }
                        if (compilerOptions.verbatimModuleSyntax && node.parent.kind === 312 /* SourceFile */ && (moduleKind === 1 /* CommonJS */ || node.parent.impliedNodeFormat === 1 /* CommonJS */)) {
                            const exportModifier = (_b = node.modifiers) == null ? void 0 : _b.find((m) => m.kind === 95 /* ExportKeyword */);
                            if (exportModifier) {
                                error2(exportModifier, Diagnostics.A_top_level_export_modifier_cannot_be_used_on_value_declarations_in_a_CommonJS_module_when_verbatimModuleSyntax_is_enabled);
                            }
                        }
                    }
                    if (isAmbientExternalModule) {
                        if (isExternalModuleAugmentation(node)) {
                            const checkBody = isGlobalAugmentation || getSymbolOfDeclaration(node).flags & 33554432 /* Transient */;
                            if (checkBody && node.body) {
                                for (const statement of node.body.statements) {
                                    checkModuleAugmentationElement(statement, isGlobalAugmentation);
                                }
                            }
                        }
                        else if (isGlobalSourceFile(node.parent)) {
                            if (isGlobalAugmentation) {
                                error2(node.name, Diagnostics.Augmentations_for_the_global_scope_can_only_be_directly_nested_in_external_modules_or_ambient_module_declarations);
                            }
                            else if (isExternalModuleNameRelative(getTextOfIdentifierOrLiteral(node.name))) {
                                error2(node.name, Diagnostics.Ambient_module_declaration_cannot_specify_relative_module_name);
                            }
                        }
                        else {
                            if (isGlobalAugmentation) {
                                error2(node.name, Diagnostics.Augmentations_for_the_global_scope_can_only_be_directly_nested_in_external_modules_or_ambient_module_declarations);
                            }
                            else {
                                error2(node.name, Diagnostics.Ambient_modules_cannot_be_nested_in_other_modules_or_namespaces);
                            }
                        }
                    }
                }
            }
            function checkModuleAugmentationElement(node, isGlobalAugmentation) {
                switch (node.kind) {
                    case 243 /* VariableStatement */:
                        for (const decl of node.declarationList.declarations) {
                            checkModuleAugmentationElement(decl, isGlobalAugmentation);
                        }
                        break;
                    case 277 /* ExportAssignment */:
                    case 278 /* ExportDeclaration */:
                        grammarErrorOnFirstToken(node, Diagnostics.Exports_and_export_assignments_are_not_permitted_in_module_augmentations);
                        break;
                    case 271 /* ImportEqualsDeclaration */:
                    case 272 /* ImportDeclaration */:
                        grammarErrorOnFirstToken(node, Diagnostics.Imports_are_not_permitted_in_module_augmentations_Consider_moving_them_to_the_enclosing_external_module);
                        break;
                    case 208 /* BindingElement */:
                    case 260 /* VariableDeclaration */:
                        const name = node.name;
                        if (isBindingPattern(name)) {
                            for (const el of name.elements) {
                                checkModuleAugmentationElement(el, isGlobalAugmentation);
                            }
                            break;
                        }
                    case 263 /* ClassDeclaration */:
                    case 266 /* EnumDeclaration */:
                    case 262 /* FunctionDeclaration */:
                    case 264 /* InterfaceDeclaration */:
                    case 267 /* ModuleDeclaration */:
                    case 265 /* TypeAliasDeclaration */:
                        if (isGlobalAugmentation) {
                            return;
                        }
                        break;
                }
            }
            function getFirstNonModuleExportsIdentifier(node) {
                switch (node.kind) {
                    case 80 /* Identifier */:
                        return node;
                    case 166 /* QualifiedName */:
                        do {
                            node = node.left;
                        } while (node.kind !== 80 /* Identifier */);
                        return node;
                    case 211 /* PropertyAccessExpression */:
                        do {
                            if (isModuleExportsAccessExpression(node.expression) && !isPrivateIdentifier(node.name)) {
                                return node.name;
                            }
                            node = node.expression;
                        } while (node.kind !== 80 /* Identifier */);
                        return node;
                }
            }
            function checkExternalImportOrExportDeclaration(node) {
                const moduleName = getExternalModuleName(node);
                if (!moduleName || nodeIsMissing(moduleName)) {
                    return false;
                }
                if (!isStringLiteral(moduleName)) {
                    error2(moduleName, Diagnostics.String_literal_expected);
                    return false;
                }
                const inAmbientExternalModule = node.parent.kind === 268 /* ModuleBlock */ && isAmbientModule(node.parent.parent);
                if (node.parent.kind !== 312 /* SourceFile */ && !inAmbientExternalModule) {
                    error2(moduleName, node.kind === 278 /* ExportDeclaration */ ? Diagnostics.Export_declarations_are_not_permitted_in_a_namespace : Diagnostics.Import_declarations_in_a_namespace_cannot_reference_a_module);
                    return false;
                }
                if (inAmbientExternalModule && isExternalModuleNameRelative(moduleName.text)) {
                    if (!isTopLevelInExternalModuleAugmentation(node)) {
                        error2(node, Diagnostics.Import_or_export_declaration_in_an_ambient_module_declaration_cannot_reference_module_through_relative_module_name);
                        return false;
                    }
                }
                if (!isImportEqualsDeclaration(node) && node.attributes) {
                    const diagnostic = node.attributes.token === 118 /* WithKeyword */ ? Diagnostics.Import_attribute_values_must_be_string_literal_expressions : Diagnostics.Import_assertion_values_must_be_string_literal_expressions;
                    let hasError = false;
                    for (const attr of node.attributes.elements) {
                        if (!isStringLiteral(attr.value)) {
                            hasError = true;
                            error2(attr.value, diagnostic);
                        }
                    }
                    return !hasError;
                }
                return true;
            }
            function checkAliasSymbol(node) {
                var _a, _b, _c, _d;
                let symbol = getSymbolOfDeclaration(node);
                const target = resolveAlias(symbol);
                if (target !== unknownSymbol) {
                    symbol = getMergedSymbol(symbol.exportSymbol || symbol);
                    if (isInJSFile(node) && !(target.flags & 111551 /* Value */) && !isTypeOnlyImportOrExportDeclaration(node)) {
                        const errorNode = isImportOrExportSpecifier(node) ? node.propertyName || node.name : isNamedDeclaration(node) ? node.name : node;
                        Debug.assert(node.kind !== 280 /* NamespaceExport */);
                        if (node.kind === 281 /* ExportSpecifier */) {
                            const diag2 = error2(errorNode, Diagnostics.Types_cannot_appear_in_export_declarations_in_JavaScript_files);
                            const alreadyExportedSymbol = (_b = (_a = getSourceFileOfNode(node).symbol) == null ? void 0 : _a.exports) == null ? void 0 : _b.get((node.propertyName || node.name).escapedText);
                            if (alreadyExportedSymbol === target) {
                                const exportingDeclaration = (_c = alreadyExportedSymbol.declarations) == null ? void 0 : _c.find(isJSDocNode);
                                if (exportingDeclaration) {
                                    addRelatedInfo(diag2, createDiagnosticForNode(exportingDeclaration, Diagnostics._0_is_automatically_exported_here, unescapeLeadingUnderscores(alreadyExportedSymbol.escapedName)));
                                }
                            }
                        }
                        else {
                            Debug.assert(node.kind !== 260 /* VariableDeclaration */);
                            const importDeclaration = findAncestor(node, or(isImportDeclaration, isImportEqualsDeclaration));
                            const moduleSpecifier = (importDeclaration && ((_d = tryGetModuleSpecifierFromDeclaration(importDeclaration)) == null ? void 0 : _d.text)) ?? "...";
                            const importedIdentifier = unescapeLeadingUnderscores(isIdentifier(errorNode) ? errorNode.escapedText : symbol.escapedName);
                            error2(errorNode, Diagnostics._0_is_a_type_and_cannot_be_imported_in_JavaScript_files_Use_1_in_a_JSDoc_type_annotation, importedIdentifier, `import("${moduleSpecifier}").${importedIdentifier}`);
                        }
                        return;
                    }
                    const targetFlags = getSymbolFlags(target);
                    const excludedMeanings = (symbol.flags & (111551 /* Value */ | 1048576 /* ExportValue */) ? 111551 /* Value */ : 0) | (symbol.flags & 788968 /* Type */ ? 788968 /* Type */ : 0) | (symbol.flags & 1920 /* Namespace */ ? 1920 /* Namespace */ : 0);
                    if (targetFlags & excludedMeanings) {
                        const message = node.kind === 281 /* ExportSpecifier */ ? Diagnostics.Export_declaration_conflicts_with_exported_declaration_of_0 : Diagnostics.Import_declaration_conflicts_with_local_declaration_of_0;
                        error2(node, message, symbolToString(symbol));
                    }
                    else if (node.kind !== 281 /* ExportSpecifier */) {
                        const appearsValueyToTranspiler = compilerOptions.isolatedModules && !findAncestor(node, isTypeOnlyImportOrExportDeclaration);
                        if (appearsValueyToTranspiler && symbol.flags & (111551 /* Value */ | 1048576 /* ExportValue */)) {
                            error2(node, Diagnostics.Import_0_conflicts_with_local_value_so_must_be_declared_with_a_type_only_import_when_isolatedModules_is_enabled, symbolToString(symbol), isolatedModulesLikeFlagName);
                        }
                    }
                    if (getIsolatedModules(compilerOptions) && !isTypeOnlyImportOrExportDeclaration(node) && !(node.flags & 33554432 /* Ambient */)) {
                        const typeOnlyAlias = getTypeOnlyAliasDeclaration(symbol);
                        const isType = !(targetFlags & 111551 /* Value */);
                        if (isType || typeOnlyAlias) {
                            switch (node.kind) {
                                case 273 /* ImportClause */:
                                case 276 /* ImportSpecifier */:
                                case 271 /* ImportEqualsDeclaration */: {
                                    if (compilerOptions.preserveValueImports || compilerOptions.verbatimModuleSyntax) {
                                        Debug.assertIsDefined(node.name, "An ImportClause with a symbol should have a name");
                                        const message = compilerOptions.verbatimModuleSyntax && isInternalModuleImportEqualsDeclaration(node) ? Diagnostics.An_import_alias_cannot_resolve_to_a_type_or_type_only_declaration_when_verbatimModuleSyntax_is_enabled : isType ? compilerOptions.verbatimModuleSyntax ? Diagnostics._0_is_a_type_and_must_be_imported_using_a_type_only_import_when_verbatimModuleSyntax_is_enabled : Diagnostics._0_is_a_type_and_must_be_imported_using_a_type_only_import_when_preserveValueImports_and_isolatedModules_are_both_enabled : compilerOptions.verbatimModuleSyntax ? Diagnostics._0_resolves_to_a_type_only_declaration_and_must_be_imported_using_a_type_only_import_when_verbatimModuleSyntax_is_enabled : Diagnostics._0_resolves_to_a_type_only_declaration_and_must_be_imported_using_a_type_only_import_when_preserveValueImports_and_isolatedModules_are_both_enabled;
                                        const name = idText(node.kind === 276 /* ImportSpecifier */ ? node.propertyName || node.name : node.name);
                                        addTypeOnlyDeclarationRelatedInfo(error2(node, message, name), isType ? void 0 : typeOnlyAlias, name);
                                    }
                                    if (isType && node.kind === 271 /* ImportEqualsDeclaration */ && hasEffectiveModifier(node, 32 /* Export */)) {
                                        error2(node, Diagnostics.Cannot_use_export_import_on_a_type_or_type_only_namespace_when_0_is_enabled, isolatedModulesLikeFlagName);
                                    }
                                    break;
                                }
                                case 281 /* ExportSpecifier */: {
                                    if (compilerOptions.verbatimModuleSyntax || getSourceFileOfNode(typeOnlyAlias) !== getSourceFileOfNode(node)) {
                                        const name = idText(node.propertyName || node.name);
                                        const diagnostic = isType ? error2(node, Diagnostics.Re_exporting_a_type_when_0_is_enabled_requires_using_export_type, isolatedModulesLikeFlagName) : error2(node, Diagnostics._0_resolves_to_a_type_only_declaration_and_must_be_re_exported_using_a_type_only_re_export_when_1_is_enabled, name, isolatedModulesLikeFlagName);
                                        addTypeOnlyDeclarationRelatedInfo(diagnostic, isType ? void 0 : typeOnlyAlias, name);
                                        break;
                                    }
                                }
                            }
                        }
                        if (compilerOptions.verbatimModuleSyntax && node.kind !== 271 /* ImportEqualsDeclaration */ && !isInJSFile(node) && (moduleKind === 1 /* CommonJS */ || getSourceFileOfNode(node).impliedNodeFormat === 1 /* CommonJS */)) {
                            error2(node, Diagnostics.ESM_syntax_is_not_allowed_in_a_CommonJS_module_when_verbatimModuleSyntax_is_enabled);
                        }
                    }
                    if (isImportSpecifier(node)) {
                        const targetSymbol = resolveAliasWithDeprecationCheck(symbol, node);
                        if (isDeprecatedSymbol(targetSymbol) && targetSymbol.declarations) {
                            addDeprecatedSuggestion(node, targetSymbol.declarations, targetSymbol.escapedName);
                        }
                    }
                }
            }
            function resolveAliasWithDeprecationCheck(symbol, location) {
                if (!(symbol.flags & 2097152 /* Alias */) || isDeprecatedSymbol(symbol) || !getDeclarationOfAliasSymbol(symbol)) {
                    return symbol;
                }
                const targetSymbol = resolveAlias(symbol);
                if (targetSymbol === unknownSymbol)
                    return targetSymbol;
                while (symbol.flags & 2097152 /* Alias */) {
                    const target = getImmediateAliasedSymbol(symbol);
                    if (target) {
                        if (target === targetSymbol)
                            break;
                        if (target.declarations && length(target.declarations)) {
                            if (isDeprecatedSymbol(target)) {
                                addDeprecatedSuggestion(location, target.declarations, target.escapedName);
                                break;
                            }
                            else {
                                if (symbol === targetSymbol)
                                    break;
                                symbol = target;
                            }
                        }
                    }
                    else {
                        break;
                    }
                }
                return targetSymbol;
            }
            function checkImportBinding(node) {
                checkCollisionsForDeclarationName(node, node.name);
                checkAliasSymbol(node);
                if (node.kind === 276 /* ImportSpecifier */ && idText(node.propertyName || node.name) === "default" && getESModuleInterop(compilerOptions) && moduleKind !== 4 /* System */ && (moduleKind < 5 /* ES2015 */ || getSourceFileOfNode(node).impliedNodeFormat === 1 /* CommonJS */)) {
                    checkExternalEmitHelpers(node, 131072 /* ImportDefault */);
                }
            }
            function checkImportAttributes(declaration) {
                var _a;
                const node = declaration.attributes;
                if (node) {
                    const importAttributesType = getGlobalImportAttributesType(
                    /*reportErrors*/
                    true);
                    if (importAttributesType !== emptyObjectType) {
                        checkTypeAssignableTo(getTypeFromImportAttributes(node), getNullableType(importAttributesType, 32768 /* Undefined */), node);
                    }
                    const validForTypeAttributes = isExclusivelyTypeOnlyImportOrExport(declaration);
                    const override = getResolutionModeOverride(node, validForTypeAttributes ? grammarErrorOnNode : void 0);
                    const isImportAttributes2 = declaration.attributes.token === 118 /* WithKeyword */;
                    if (validForTypeAttributes && override) {
                        return;
                    }
                    const mode = moduleKind === 199 /* NodeNext */ && declaration.moduleSpecifier && getUsageModeForExpression(declaration.moduleSpecifier);
                    if (mode !== 99 /* ESNext */ && moduleKind !== 99 /* ESNext */ && moduleKind !== 200 /* Preserve */) {
                        const message = isImportAttributes2 ? moduleKind === 199 /* NodeNext */ ? Diagnostics.Import_attributes_are_not_allowed_on_statements_that_compile_to_CommonJS_require_calls : Diagnostics.Import_attributes_are_only_supported_when_the_module_option_is_set_to_esnext_nodenext_or_preserve : moduleKind === 199 /* NodeNext */ ? Diagnostics.Import_assertions_are_not_allowed_on_statements_that_compile_to_CommonJS_require_calls : Diagnostics.Import_assertions_are_only_supported_when_the_module_option_is_set_to_esnext_nodenext_or_preserve;
                        return grammarErrorOnNode(node, message);
                    }
                    if (isImportDeclaration(declaration) ? (_a = declaration.importClause) == null ? void 0 : _a.isTypeOnly : declaration.isTypeOnly) {
                        return grammarErrorOnNode(node, isImportAttributes2 ? Diagnostics.Import_attributes_cannot_be_used_with_type_only_imports_or_exports : Diagnostics.Import_assertions_cannot_be_used_with_type_only_imports_or_exports);
                    }
                    if (override) {
                        return grammarErrorOnNode(node, Diagnostics.resolution_mode_can_only_be_set_for_type_only_imports);
                    }
                }
            }
            function checkImportAttribute(node) {
                return getRegularTypeOfLiteralType(checkExpressionCached(node.value));
            }
            function checkImportDeclaration(node) {
                if (checkGrammarModuleElementContext(node, isInJSFile(node) ? Diagnostics.An_import_declaration_can_only_be_used_at_the_top_level_of_a_module : Diagnostics.An_import_declaration_can_only_be_used_at_the_top_level_of_a_namespace_or_module)) {
                    return;
                }
                if (!checkGrammarModifiers(node) && hasEffectiveModifiers(node)) {
                    grammarErrorOnFirstToken(node, Diagnostics.An_import_declaration_cannot_have_modifiers);
                }
                if (checkExternalImportOrExportDeclaration(node)) {
                    const importClause = node.importClause;
                    if (importClause && !checkGrammarImportClause(importClause)) {
                        if (importClause.name) {
                            checkImportBinding(importClause);
                        }
                        if (importClause.namedBindings) {
                            if (importClause.namedBindings.kind === 274 /* NamespaceImport */) {
                                checkImportBinding(importClause.namedBindings);
                                if (moduleKind !== 4 /* System */ && (moduleKind < 5 /* ES2015 */ || getSourceFileOfNode(node).impliedNodeFormat === 1 /* CommonJS */) && getESModuleInterop(compilerOptions)) {
                                    checkExternalEmitHelpers(node, 65536 /* ImportStar */);
                                }
                            }
                            else {
                                const moduleExisted = resolveExternalModuleName(node, node.moduleSpecifier);
                                if (moduleExisted) {
                                    forEach(importClause.namedBindings.elements, checkImportBinding);
                                }
                            }
                        }
                    }
                }
                checkImportAttributes(node);
            }
            function checkImportEqualsDeclaration(node) {
                if (checkGrammarModuleElementContext(node, isInJSFile(node) ? Diagnostics.An_import_declaration_can_only_be_used_at_the_top_level_of_a_module : Diagnostics.An_import_declaration_can_only_be_used_at_the_top_level_of_a_namespace_or_module)) {
                    return;
                }
                checkGrammarModifiers(node);
                if (isInternalModuleImportEqualsDeclaration(node) || checkExternalImportOrExportDeclaration(node)) {
                    checkImportBinding(node);
                    if (hasSyntacticModifier(node, 32 /* Export */)) {
                        markExportAsReferenced(node);
                    }
                    if (node.moduleReference.kind !== 283 /* ExternalModuleReference */) {
                        const target = resolveAlias(getSymbolOfDeclaration(node));
                        if (target !== unknownSymbol) {
                            const targetFlags = getSymbolFlags(target);
                            if (targetFlags & 111551 /* Value */) {
                                const moduleName = getFirstIdentifier(node.moduleReference);
                                if (!(resolveEntityName(moduleName, 111551 /* Value */ | 1920 /* Namespace */).flags & 1920 /* Namespace */)) {
                                    error2(moduleName, Diagnostics.Module_0_is_hidden_by_a_local_declaration_with_the_same_name, declarationNameToString(moduleName));
                                }
                            }
                            if (targetFlags & 788968 /* Type */) {
                                checkTypeNameIsReserved(node.name, Diagnostics.Import_name_cannot_be_0);
                            }
                        }
                        if (node.isTypeOnly) {
                            grammarErrorOnNode(node, Diagnostics.An_import_alias_cannot_use_import_type);
                        }
                    }
                    else {
                        if (moduleKind >= 5 /* ES2015 */ && moduleKind !== 200 /* Preserve */ && getSourceFileOfNode(node).impliedNodeFormat === void 0 && !node.isTypeOnly && !(node.flags & 33554432 /* Ambient */)) {
                            grammarErrorOnNode(node, Diagnostics.Import_assignment_cannot_be_used_when_targeting_ECMAScript_modules_Consider_using_import_Asterisk_as_ns_from_mod_import_a_from_mod_import_d_from_mod_or_another_module_format_instead);
                        }
                    }
                }
            }
            function checkExportDeclaration(node) {
                if (checkGrammarModuleElementContext(node, isInJSFile(node) ? Diagnostics.An_export_declaration_can_only_be_used_at_the_top_level_of_a_module : Diagnostics.An_export_declaration_can_only_be_used_at_the_top_level_of_a_namespace_or_module)) {
                    return;
                }
                if (!checkGrammarModifiers(node) && hasSyntacticModifiers(node)) {
                    grammarErrorOnFirstToken(node, Diagnostics.An_export_declaration_cannot_have_modifiers);
                }
                if (node.moduleSpecifier && node.exportClause && isNamedExports(node.exportClause) && length(node.exportClause.elements) && languageVersion === 0 /* ES3 */) {
                    checkExternalEmitHelpers(node, 4194304 /* CreateBinding */);
                }
                checkGrammarExportDeclaration(node);
                if (!node.moduleSpecifier || checkExternalImportOrExportDeclaration(node)) {
                    if (node.exportClause && !isNamespaceExport(node.exportClause)) {
                        forEach(node.exportClause.elements, checkExportSpecifier);
                        const inAmbientExternalModule = node.parent.kind === 268 /* ModuleBlock */ && isAmbientModule(node.parent.parent);
                        const inAmbientNamespaceDeclaration = !inAmbientExternalModule && node.parent.kind === 268 /* ModuleBlock */ && !node.moduleSpecifier && node.flags & 33554432 /* Ambient */;
                        if (node.parent.kind !== 312 /* SourceFile */ && !inAmbientExternalModule && !inAmbientNamespaceDeclaration) {
                            error2(node, Diagnostics.Export_declarations_are_not_permitted_in_a_namespace);
                        }
                    }
                    else {
                        const moduleSymbol = resolveExternalModuleName(node, node.moduleSpecifier);
                        if (moduleSymbol && hasExportAssignmentSymbol(moduleSymbol)) {
                            error2(node.moduleSpecifier, Diagnostics.Module_0_uses_export_and_cannot_be_used_with_export_Asterisk, symbolToString(moduleSymbol));
                        }
                        else if (node.exportClause) {
                            checkAliasSymbol(node.exportClause);
                        }
                        if (moduleKind !== 4 /* System */ && (moduleKind < 5 /* ES2015 */ || getSourceFileOfNode(node).impliedNodeFormat === 1 /* CommonJS */)) {
                            if (node.exportClause) {
                                if (getESModuleInterop(compilerOptions)) {
                                    checkExternalEmitHelpers(node, 65536 /* ImportStar */);
                                }
                            }
                            else {
                                checkExternalEmitHelpers(node, 32768 /* ExportStar */);
                            }
                        }
                    }
                }
                checkImportAttributes(node);
            }
            function checkGrammarExportDeclaration(node) {
                var _a;
                if (node.isTypeOnly && ((_a = node.exportClause) == null ? void 0 : _a.kind) === 279 /* NamedExports */) {
                    return checkGrammarNamedImportsOrExports(node.exportClause);
                }
                return false;
            }
            function checkGrammarModuleElementContext(node, errorMessage) {
                const isInAppropriateContext = node.parent.kind === 312 /* SourceFile */ || node.parent.kind === 268 /* ModuleBlock */ || node.parent.kind === 267 /* ModuleDeclaration */;
                if (!isInAppropriateContext) {
                    grammarErrorOnFirstToken(node, errorMessage);
                }
                return !isInAppropriateContext;
            }
            function importClauseContainsReferencedImport(importClause) {
                return forEachImportClauseDeclaration(importClause, (declaration) => {
                    return !!getSymbolOfDeclaration(declaration).isReferenced;
                });
            }
            function importClauseContainsConstEnumUsedAsValue(importClause) {
                return forEachImportClauseDeclaration(importClause, (declaration) => {
                    return !!getSymbolLinks(getSymbolOfDeclaration(declaration)).constEnumReferenced;
                });
            }
            function canConvertImportDeclarationToTypeOnly(statement) {
                return isImportDeclaration(statement) && statement.importClause && !statement.importClause.isTypeOnly && importClauseContainsReferencedImport(statement.importClause) && !isReferencedAliasDeclaration(statement.importClause, 
                /*checkChildren*/
                true) && !importClauseContainsConstEnumUsedAsValue(statement.importClause);
            }
            function canConvertImportEqualsDeclarationToTypeOnly(statement) {
                return isImportEqualsDeclaration(statement) && isExternalModuleReference(statement.moduleReference) && !statement.isTypeOnly && getSymbolOfDeclaration(statement).isReferenced && !isReferencedAliasDeclaration(statement, 
                /*checkChildren*/
                false) && !getSymbolLinks(getSymbolOfDeclaration(statement)).constEnumReferenced;
            }
            function checkImportsForTypeOnlyConversion(sourceFile) {
                if (!canCollectSymbolAliasAccessabilityData) {
                    return;
                }
                for (const statement of sourceFile.statements) {
                    if (canConvertImportDeclarationToTypeOnly(statement) || canConvertImportEqualsDeclarationToTypeOnly(statement)) {
                        error2(statement, Diagnostics.This_import_is_never_used_as_a_value_and_must_use_import_type_because_importsNotUsedAsValues_is_set_to_error);
                    }
                }
            }
            function checkExportSpecifier(node) {
                checkAliasSymbol(node);
                if (getEmitDeclarations(compilerOptions)) {
                    collectLinkedAliases(node.propertyName || node.name, 
                    /*setVisibility*/
                    true);
                }
                if (!node.parent.parent.moduleSpecifier) {
                    const exportedName = node.propertyName || node.name;
                    const symbol = resolveName(exportedName, exportedName.escapedText, 111551 /* Value */ | 788968 /* Type */ | 1920 /* Namespace */ | 2097152 /* Alias */, 
                    /*nameNotFoundMessage*/
                    void 0, 
                    /*nameArg*/
                    void 0, 
                    /*isUse*/
                    true);
                    if (symbol && (symbol === undefinedSymbol || symbol === globalThisSymbol || symbol.declarations && isGlobalSourceFile(getDeclarationContainer(symbol.declarations[0])))) {
                        error2(exportedName, Diagnostics.Cannot_export_0_Only_local_declarations_can_be_exported_from_a_module, idText(exportedName));
                    }
                    else {
                        if (!node.isTypeOnly && !node.parent.parent.isTypeOnly) {
                            markExportAsReferenced(node);
                        }
                        const target = symbol && (symbol.flags & 2097152 /* Alias */ ? resolveAlias(symbol) : symbol);
                        if (!target || getSymbolFlags(target) & 111551 /* Value */) {
                            checkExpressionCached(node.propertyName || node.name);
                        }
                    }
                }
                else {
                    if (getESModuleInterop(compilerOptions) && moduleKind !== 4 /* System */ && (moduleKind < 5 /* ES2015 */ || getSourceFileOfNode(node).impliedNodeFormat === 1 /* CommonJS */) && idText(node.propertyName || node.name) === "default") {
                        checkExternalEmitHelpers(node, 131072 /* ImportDefault */);
                    }
                }
            }
            function checkExportAssignment(node) {
                const illegalContextMessage = node.isExportEquals ? Diagnostics.An_export_assignment_must_be_at_the_top_level_of_a_file_or_module_declaration : Diagnostics.A_default_export_must_be_at_the_top_level_of_a_file_or_module_declaration;
                if (checkGrammarModuleElementContext(node, illegalContextMessage)) {
                    return;
                }
                const container = node.parent.kind === 312 /* SourceFile */ ? node.parent : node.parent.parent;
                if (container.kind === 267 /* ModuleDeclaration */ && !isAmbientModule(container)) {
                    if (node.isExportEquals) {
                        error2(node, Diagnostics.An_export_assignment_cannot_be_used_in_a_namespace);
                    }
                    else {
                        error2(node, Diagnostics.A_default_export_can_only_be_used_in_an_ECMAScript_style_module);
                    }
                    return;
                }
                if (!checkGrammarModifiers(node) && hasEffectiveModifiers(node)) {
                    grammarErrorOnFirstToken(node, Diagnostics.An_export_assignment_cannot_have_modifiers);
                }
                const typeAnnotationNode = getEffectiveTypeAnnotationNode(node);
                if (typeAnnotationNode) {
                    checkTypeAssignableTo(checkExpressionCached(node.expression), getTypeFromTypeNode(typeAnnotationNode), node.expression);
                }
                const isIllegalExportDefaultInCJS = !node.isExportEquals && !(node.flags & 33554432 /* Ambient */) && compilerOptions.verbatimModuleSyntax && (moduleKind === 1 /* CommonJS */ || getSourceFileOfNode(node).impliedNodeFormat === 1 /* CommonJS */);
                if (node.expression.kind === 80 /* Identifier */) {
                    const id = node.expression;
                    const sym = getExportSymbolOfValueSymbolIfExported(resolveEntityName(id, -1 /* All */, 
                    /*ignoreErrors*/
                    true, 
                    /*dontResolveAlias*/
                    true, node));
                    if (sym) {
                        const typeOnlyDeclaration = getTypeOnlyAliasDeclaration(sym, 111551 /* Value */);
                        markAliasReferenced(sym, id);
                        if (getSymbolFlags(sym) & 111551 /* Value */) {
                            checkExpressionCached(id);
                            if (!isIllegalExportDefaultInCJS && !(node.flags & 33554432 /* Ambient */) && compilerOptions.verbatimModuleSyntax && typeOnlyDeclaration) {
                                error2(id, node.isExportEquals ? Diagnostics.An_export_declaration_must_reference_a_real_value_when_verbatimModuleSyntax_is_enabled_but_0_resolves_to_a_type_only_declaration : Diagnostics.An_export_default_must_reference_a_real_value_when_verbatimModuleSyntax_is_enabled_but_0_resolves_to_a_type_only_declaration, idText(id));
                            }
                        }
                        else if (!isIllegalExportDefaultInCJS && !(node.flags & 33554432 /* Ambient */) && compilerOptions.verbatimModuleSyntax) {
                            error2(id, node.isExportEquals ? Diagnostics.An_export_declaration_must_reference_a_value_when_verbatimModuleSyntax_is_enabled_but_0_only_refers_to_a_type : Diagnostics.An_export_default_must_reference_a_value_when_verbatimModuleSyntax_is_enabled_but_0_only_refers_to_a_type, idText(id));
                        }
                        if (!isIllegalExportDefaultInCJS && !(node.flags & 33554432 /* Ambient */) && getIsolatedModules(compilerOptions) && !(sym.flags & 111551 /* Value */)) {
                            const nonLocalMeanings = getSymbolFlags(sym, 
                            /*excludeTypeOnlyMeanings*/
                            false, 
                            /*excludeLocalMeanings*/
                            true);
                            if (sym.flags & 2097152 /* Alias */ && nonLocalMeanings & 788968 /* Type */ && !(nonLocalMeanings & 111551 /* Value */) && (!typeOnlyDeclaration || getSourceFileOfNode(typeOnlyDeclaration) !== getSourceFileOfNode(node))) {
                                error2(id, node.isExportEquals ? Diagnostics._0_resolves_to_a_type_and_must_be_marked_type_only_in_this_file_before_re_exporting_when_1_is_enabled_Consider_using_import_type_where_0_is_imported : Diagnostics._0_resolves_to_a_type_and_must_be_marked_type_only_in_this_file_before_re_exporting_when_1_is_enabled_Consider_using_export_type_0_as_default, idText(id), isolatedModulesLikeFlagName);
                            }
                            else if (typeOnlyDeclaration && getSourceFileOfNode(typeOnlyDeclaration) !== getSourceFileOfNode(node)) {
                                addTypeOnlyDeclarationRelatedInfo(error2(id, node.isExportEquals ? Diagnostics._0_resolves_to_a_type_only_declaration_and_must_be_marked_type_only_in_this_file_before_re_exporting_when_1_is_enabled_Consider_using_import_type_where_0_is_imported : Diagnostics._0_resolves_to_a_type_only_declaration_and_must_be_marked_type_only_in_this_file_before_re_exporting_when_1_is_enabled_Consider_using_export_type_0_as_default, idText(id), isolatedModulesLikeFlagName), typeOnlyDeclaration, idText(id));
                            }
                        }
                    }
                    else {
                        checkExpressionCached(id);
                    }
                    if (getEmitDeclarations(compilerOptions)) {
                        collectLinkedAliases(id, 
                        /*setVisibility*/
                        true);
                    }
                }
                else {
                    checkExpressionCached(node.expression);
                }
                if (isIllegalExportDefaultInCJS) {
                    error2(node, Diagnostics.ESM_syntax_is_not_allowed_in_a_CommonJS_module_when_verbatimModuleSyntax_is_enabled);
                }
                checkExternalModuleExports(container);
                if (node.flags & 33554432 /* Ambient */ && !isEntityNameExpression(node.expression)) {
                    grammarErrorOnNode(node.expression, Diagnostics.The_expression_of_an_export_assignment_must_be_an_identifier_or_qualified_name_in_an_ambient_context);
                }
                if (node.isExportEquals) {
                    if (moduleKind >= 5 /* ES2015 */ && moduleKind !== 200 /* Preserve */ && (node.flags & 33554432 /* Ambient */ && getSourceFileOfNode(node).impliedNodeFormat === 99 /* ESNext */ || !(node.flags & 33554432 /* Ambient */) && getSourceFileOfNode(node).impliedNodeFormat !== 1 /* CommonJS */)) {
                        grammarErrorOnNode(node, Diagnostics.Export_assignment_cannot_be_used_when_targeting_ECMAScript_modules_Consider_using_export_default_or_another_module_format_instead);
                    }
                    else if (moduleKind === 4 /* System */ && !(node.flags & 33554432 /* Ambient */)) {
                        grammarErrorOnNode(node, Diagnostics.Export_assignment_is_not_supported_when_module_flag_is_system);
                    }
                }
            }
            function hasExportedMembers(moduleSymbol) {
                return forEachEntry(moduleSymbol.exports, (_, id) => id !== "export=");
            }
            function checkExternalModuleExports(node) {
                const moduleSymbol = getSymbolOfDeclaration(node);
                const links = getSymbolLinks(moduleSymbol);
                if (!links.exportsChecked) {
                    const exportEqualsSymbol = moduleSymbol.exports.get("export=");
                    if (exportEqualsSymbol && hasExportedMembers(moduleSymbol)) {
                        const declaration = getDeclarationOfAliasSymbol(exportEqualsSymbol) || exportEqualsSymbol.valueDeclaration;
                        if (declaration && !isTopLevelInExternalModuleAugmentation(declaration) && !isInJSFile(declaration)) {
                            error2(declaration, Diagnostics.An_export_assignment_cannot_be_used_in_a_module_with_other_exported_elements);
                        }
                    }
                    const exports = getExportsOfModule(moduleSymbol);
                    if (exports) {
                        exports.forEach(({ declarations, flags }, id) => {
                            if (id === "__export") {
                                return;
                            }
                            if (flags & (1920 /* Namespace */ | 384 /* Enum */)) {
                                return;
                            }
                            const exportedDeclarationsCount = countWhere(declarations, and(isNotOverloadAndNotAccessor, not(isInterfaceDeclaration)));
                            if (flags & 524288 /* TypeAlias */ && exportedDeclarationsCount <= 2) {
                                return;
                            }
                            if (exportedDeclarationsCount > 1) {
                                if (!isDuplicatedCommonJSExport(declarations)) {
                                    for (const declaration of declarations) {
                                        if (isNotOverload(declaration)) {
                                            diagnostics.add(createDiagnosticForNode(declaration, Diagnostics.Cannot_redeclare_exported_variable_0, unescapeLeadingUnderscores(id)));
                                        }
                                    }
                                }
                            }
                        });
                    }
                    links.exportsChecked = true;
                }
            }
            function isDuplicatedCommonJSExport(declarations) {
                return declarations && declarations.length > 1 && declarations.every((d) => isInJSFile(d) && isAccessExpression(d) && (isExportsIdentifier(d.expression) || isModuleExportsAccessExpression(d.expression)));
            }
            function checkSourceElement(node) {
                if (node) {
                    const saveCurrentNode = currentNode;
                    currentNode = node;
                    instantiationCount = 0;
                    checkSourceElementWorker(node);
                    currentNode = saveCurrentNode;
                }
            }
            function checkSourceElementWorker(node) {
                if (canHaveJSDoc(node)) {
                    forEach(node.jsDoc, ({ comment, tags }) => {
                        checkJSDocCommentWorker(comment);
                        forEach(tags, (tag) => {
                            checkJSDocCommentWorker(tag.comment);
                            if (isInJSFile(node)) {
                                checkSourceElement(tag);
                            }
                        });
                    });
                }
                const kind = node.kind;
                if (cancellationToken) {
                    switch (kind) {
                        case 267 /* ModuleDeclaration */:
                        case 263 /* ClassDeclaration */:
                        case 264 /* InterfaceDeclaration */:
                        case 262 /* FunctionDeclaration */:
                            cancellationToken.throwIfCancellationRequested();
                    }
                }
                if (kind >= 243 /* FirstStatement */ && kind <= 259 /* LastStatement */ && canHaveFlowNode(node) && node.flowNode && !isReachableFlowNode(node.flowNode)) {
                    errorOrSuggestion(compilerOptions.allowUnreachableCode === false, node, Diagnostics.Unreachable_code_detected);
                }
                switch (kind) {
                    case 168 /* TypeParameter */:
                        return checkTypeParameter(node);
                    case 169 /* Parameter */:
                        return checkParameter(node);
                    case 172 /* PropertyDeclaration */:
                        return checkPropertyDeclaration(node);
                    case 171 /* PropertySignature */:
                        return checkPropertySignature(node);
                    case 185 /* ConstructorType */:
                    case 184 /* FunctionType */:
                    case 179 /* CallSignature */:
                    case 180 /* ConstructSignature */:
                    case 181 /* IndexSignature */:
                        return checkSignatureDeclaration(node);
                    case 174 /* MethodDeclaration */:
                    case 173 /* MethodSignature */:
                        return checkMethodDeclaration(node);
                    case 175 /* ClassStaticBlockDeclaration */:
                        return checkClassStaticBlockDeclaration(node);
                    case 176 /* Constructor */:
                        return checkConstructorDeclaration(node);
                    case 177 /* GetAccessor */:
                    case 178 /* SetAccessor */:
                        return checkAccessorDeclaration(node);
                    case 183 /* TypeReference */:
                        return checkTypeReferenceNode(node);
                    case 182 /* TypePredicate */:
                        return checkTypePredicate(node);
                    case 186 /* TypeQuery */:
                        return checkTypeQuery(node);
                    case 187 /* TypeLiteral */:
                        return checkTypeLiteral(node);
                    case 188 /* ArrayType */:
                        return checkArrayType(node);
                    case 189 /* TupleType */:
                        return checkTupleType(node);
                    case 192 /* UnionType */:
                    case 193 /* IntersectionType */:
                        return checkUnionOrIntersectionType(node);
                    case 196 /* ParenthesizedType */:
                    case 190 /* OptionalType */:
                    case 191 /* RestType */:
                        return checkSourceElement(node.type);
                    case 197 /* ThisType */:
                        return checkThisType(node);
                    case 198 /* TypeOperator */:
                        return checkTypeOperator(node);
                    case 194 /* ConditionalType */:
                        return checkConditionalType(node);
                    case 195 /* InferType */:
                        return checkInferType(node);
                    case 203 /* TemplateLiteralType */:
                        return checkTemplateLiteralType(node);
                    case 205 /* ImportType */:
                        return checkImportType(node);
                    case 202 /* NamedTupleMember */:
                        return checkNamedTupleMember(node);
                    case 335 /* JSDocAugmentsTag */:
                        return checkJSDocAugmentsTag(node);
                    case 336 /* JSDocImplementsTag */:
                        return checkJSDocImplementsTag(node);
                    case 353 /* JSDocTypedefTag */:
                    case 345 /* JSDocCallbackTag */:
                    case 347 /* JSDocEnumTag */:
                        return checkJSDocTypeAliasTag(node);
                    case 352 /* JSDocTemplateTag */:
                        return checkJSDocTemplateTag(node);
                    case 351 /* JSDocTypeTag */:
                        return checkJSDocTypeTag(node);
                    case 331 /* JSDocLink */:
                    case 332 /* JSDocLinkCode */:
                    case 333 /* JSDocLinkPlain */:
                        return checkJSDocLinkLikeTag(node);
                    case 348 /* JSDocParameterTag */:
                        return checkJSDocParameterTag(node);
                    case 355 /* JSDocPropertyTag */:
                        return checkJSDocPropertyTag(node);
                    case 324 /* JSDocFunctionType */:
                        checkJSDocFunctionType(node);
                    case 322 /* JSDocNonNullableType */:
                    case 321 /* JSDocNullableType */:
                    case 319 /* JSDocAllType */:
                    case 320 /* JSDocUnknownType */:
                    case 329 /* JSDocTypeLiteral */:
                        checkJSDocTypeIsInJsFile(node);
                        forEachChild(node, checkSourceElement);
                        return;
                    case 325 /* JSDocVariadicType */:
                        checkJSDocVariadicType(node);
                        return;
                    case 316 /* JSDocTypeExpression */:
                        return checkSourceElement(node.type);
                    case 340 /* JSDocPublicTag */:
                    case 342 /* JSDocProtectedTag */:
                    case 341 /* JSDocPrivateTag */:
                        return checkJSDocAccessibilityModifiers(node);
                    case 357 /* JSDocSatisfiesTag */:
                        return checkJSDocSatisfiesTag(node);
                    case 350 /* JSDocThisTag */:
                        return checkJSDocThisTag(node);
                    case 199 /* IndexedAccessType */:
                        return checkIndexedAccessType(node);
                    case 200 /* MappedType */:
                        return checkMappedType(node);
                    case 262 /* FunctionDeclaration */:
                        return checkFunctionDeclaration(node);
                    case 241 /* Block */:
                    case 268 /* ModuleBlock */:
                        return checkBlock(node);
                    case 243 /* VariableStatement */:
                        return checkVariableStatement(node);
                    case 244 /* ExpressionStatement */:
                        return checkExpressionStatement(node);
                    case 245 /* IfStatement */:
                        return checkIfStatement(node);
                    case 246 /* DoStatement */:
                        return checkDoStatement(node);
                    case 247 /* WhileStatement */:
                        return checkWhileStatement(node);
                    case 248 /* ForStatement */:
                        return checkForStatement(node);
                    case 249 /* ForInStatement */:
                        return checkForInStatement(node);
                    case 250 /* ForOfStatement */:
                        return checkForOfStatement(node);
                    case 251 /* ContinueStatement */:
                    case 252 /* BreakStatement */:
                        return checkBreakOrContinueStatement(node);
                    case 253 /* ReturnStatement */:
                        return checkReturnStatement(node);
                    case 254 /* WithStatement */:
                        return checkWithStatement(node);
                    case 255 /* SwitchStatement */:
                        return checkSwitchStatement(node);
                    case 256 /* LabeledStatement */:
                        return checkLabeledStatement(node);
                    case 257 /* ThrowStatement */:
                        return checkThrowStatement(node);
                    case 258 /* TryStatement */:
                        return checkTryStatement(node);
                    case 260 /* VariableDeclaration */:
                        return checkVariableDeclaration(node);
                    case 208 /* BindingElement */:
                        return checkBindingElement(node);
                    case 263 /* ClassDeclaration */:
                        return checkClassDeclaration(node);
                    case 264 /* InterfaceDeclaration */:
                        return checkInterfaceDeclaration(node);
                    case 265 /* TypeAliasDeclaration */:
                        return checkTypeAliasDeclaration(node);
                    case 266 /* EnumDeclaration */:
                        return checkEnumDeclaration(node);
                    case 267 /* ModuleDeclaration */:
                        return checkModuleDeclaration(node);
                    case 272 /* ImportDeclaration */:
                        return checkImportDeclaration(node);
                    case 271 /* ImportEqualsDeclaration */:
                        return checkImportEqualsDeclaration(node);
                    case 278 /* ExportDeclaration */:
                        return checkExportDeclaration(node);
                    case 277 /* ExportAssignment */:
                        return checkExportAssignment(node);
                    case 242 /* EmptyStatement */:
                    case 259 /* DebuggerStatement */:
                        checkGrammarStatementInAmbientContext(node);
                        return;
                    case 282 /* MissingDeclaration */:
                        return checkMissingDeclaration(node);
                }
            }
            function checkJSDocCommentWorker(node) {
                if (isArray(node)) {
                    forEach(node, (tag) => {
                        if (isJSDocLinkLike(tag)) {
                            checkSourceElement(tag);
                        }
                    });
                }
            }
            function checkJSDocTypeIsInJsFile(node) {
                if (!isInJSFile(node)) {
                    if (isJSDocNonNullableType(node) || isJSDocNullableType(node)) {
                        const token = tokenToString(isJSDocNonNullableType(node) ? 54 /* ExclamationToken */ : 58 /* QuestionToken */);
                        const diagnostic = node.postfix ? Diagnostics._0_at_the_end_of_a_type_is_not_valid_TypeScript_syntax_Did_you_mean_to_write_1 : Diagnostics._0_at_the_start_of_a_type_is_not_valid_TypeScript_syntax_Did_you_mean_to_write_1;
                        const typeNode = node.type;
                        const type = getTypeFromTypeNode(typeNode);
                        grammarErrorOnNode(node, diagnostic, token, typeToString(isJSDocNullableType(node) && !(type === neverType || type === voidType) ? getUnionType(append([type, undefinedType], node.postfix ? void 0 : nullType)) : type));
                    }
                    else {
                        grammarErrorOnNode(node, Diagnostics.JSDoc_types_can_only_be_used_inside_documentation_comments);
                    }
                }
            }
            function checkJSDocVariadicType(node) {
                checkJSDocTypeIsInJsFile(node);
                checkSourceElement(node.type);
                const { parent: parent2 } = node;
                if (isParameter(parent2) && isJSDocFunctionType(parent2.parent)) {
                    if (last(parent2.parent.parameters) !== parent2) {
                        error2(node, Diagnostics.A_rest_parameter_must_be_last_in_a_parameter_list);
                    }
                    return;
                }
                if (!isJSDocTypeExpression(parent2)) {
                    error2(node, Diagnostics.JSDoc_may_only_appear_in_the_last_parameter_of_a_signature);
                }
                const paramTag = node.parent.parent;
                if (!isJSDocParameterTag(paramTag)) {
                    error2(node, Diagnostics.JSDoc_may_only_appear_in_the_last_parameter_of_a_signature);
                    return;
                }
                const param = getParameterSymbolFromJSDoc(paramTag);
                if (!param) {
                    return;
                }
                const host2 = getHostSignatureFromJSDoc(paramTag);
                if (!host2 || last(host2.parameters).symbol !== param) {
                    error2(node, Diagnostics.A_rest_parameter_must_be_last_in_a_parameter_list);
                }
            }
            function getTypeFromJSDocVariadicType(node) {
                const type = getTypeFromTypeNode(node.type);
                const { parent: parent2 } = node;
                const paramTag = node.parent.parent;
                if (isJSDocTypeExpression(node.parent) && isJSDocParameterTag(paramTag)) {
                    const host2 = getHostSignatureFromJSDoc(paramTag);
                    const isCallbackTag = isJSDocCallbackTag(paramTag.parent.parent);
                    if (host2 || isCallbackTag) {
                        const lastParamDeclaration = isCallbackTag ? lastOrUndefined(paramTag.parent.parent.typeExpression.parameters) : lastOrUndefined(host2.parameters);
                        const symbol = getParameterSymbolFromJSDoc(paramTag);
                        if (!lastParamDeclaration || symbol && lastParamDeclaration.symbol === symbol && isRestParameter(lastParamDeclaration)) {
                            return createArrayType(type);
                        }
                    }
                }
                if (isParameter(parent2) && isJSDocFunctionType(parent2.parent)) {
                    return createArrayType(type);
                }
                return addOptionality(type);
            }
            function checkNodeDeferred(node) {
                const enclosingFile = getSourceFileOfNode(node);
                const links = getNodeLinks(enclosingFile);
                if (!(links.flags & 1 /* TypeChecked */)) {
                    links.deferredNodes || (links.deferredNodes = /* @__PURE__ */ new Set());
                    links.deferredNodes.add(node);
                }
                else {
                    Debug.assert(!links.deferredNodes, "A type-checked file should have no deferred nodes.");
                }
            }
            function checkDeferredNodes(context) {
                const links = getNodeLinks(context);
                if (links.deferredNodes) {
                    links.deferredNodes.forEach(checkDeferredNode);
                }
                links.deferredNodes = void 0;
            }
            function checkDeferredNode(node) {
                var _a, _b;
                (_a = tracing) == null ? void 0 : _a.push(tracing.Phase.Check, "checkDeferredNode", { kind: node.kind, pos: node.pos, end: node.end, path: node.tracingPath });
                const saveCurrentNode = currentNode;
                currentNode = node;
                instantiationCount = 0;
                switch (node.kind) {
                    case 213 /* CallExpression */:
                    case 214 /* NewExpression */:
                    case 215 /* TaggedTemplateExpression */:
                    case 170 /* Decorator */:
                    case 286 /* JsxOpeningElement */:
                        resolveUntypedCall(node);
                        break;
                    case 218 /* FunctionExpression */:
                    case 219 /* ArrowFunction */:
                    case 174 /* MethodDeclaration */:
                    case 173 /* MethodSignature */:
                        checkFunctionExpressionOrObjectLiteralMethodDeferred(node);
                        break;
                    case 177 /* GetAccessor */:
                    case 178 /* SetAccessor */:
                        checkAccessorDeclaration(node);
                        break;
                    case 231 /* ClassExpression */:
                        checkClassExpressionDeferred(node);
                        break;
                    case 168 /* TypeParameter */:
                        checkTypeParameterDeferred(node);
                        break;
                    case 285 /* JsxSelfClosingElement */:
                        checkJsxSelfClosingElementDeferred(node);
                        break;
                    case 284 /* JsxElement */:
                        checkJsxElementDeferred(node);
                        break;
                    case 216 /* TypeAssertionExpression */:
                    case 234 /* AsExpression */:
                    case 217 /* ParenthesizedExpression */:
                        checkAssertionDeferred(node);
                        break;
                    case 222 /* VoidExpression */:
                        checkExpression(node.expression);
                        break;
                    case 226 /* BinaryExpression */:
                        if (isInstanceOfExpression(node)) {
                            resolveUntypedCall(node);
                        }
                        break;
                }
                currentNode = saveCurrentNode;
                (_b = tracing) == null ? void 0 : _b.pop();
            }
            function checkSourceFile(node) {
                var _a, _b;
                (_a = tracing) == null ? void 0 : _a.push(tracing.Phase.Check, "checkSourceFile", { path: node.path }, 
                /*separateBeginAndEnd*/
                true);
                mark("beforeCheck");
                checkSourceFileWorker(node);
                mark("afterCheck");
                measure("Check", "beforeCheck", "afterCheck");
                (_b = tracing) == null ? void 0 : _b.pop();
            }
            function unusedIsError(kind, isAmbient) {
                if (isAmbient) {
                    return false;
                }
                switch (kind) {
                    case 0 /* Local */:
                        return !!compilerOptions.noUnusedLocals;
                    case 1 /* Parameter */:
                        return !!compilerOptions.noUnusedParameters;
                    default:
                        return Debug.assertNever(kind);
                }
            }
            function getPotentiallyUnusedIdentifiers(sourceFile) {
                return allPotentiallyUnusedIdentifiers.get(sourceFile.path) || emptyArray;
            }
            function checkSourceFileWorker(node) {
                const links = getNodeLinks(node);
                if (!(links.flags & 1 /* TypeChecked */)) {
                    if (skipTypeChecking(node, compilerOptions, host)) {
                        return;
                    }
                    checkGrammarSourceFile(node);
                    clear(potentialThisCollisions);
                    clear(potentialNewTargetCollisions);
                    clear(potentialWeakMapSetCollisions);
                    clear(potentialReflectCollisions);
                    clear(potentialUnusedRenamedBindingElementsInTypes);
                    forEach(node.statements, checkSourceElement);
                    checkSourceElement(node.endOfFileToken);
                    checkDeferredNodes(node);
                    if (isExternalOrCommonJsModule(node)) {
                        registerForUnusedIdentifiersCheck(node);
                    }
                    addLazyDiagnostic(() => {
                        if (!node.isDeclarationFile && (compilerOptions.noUnusedLocals || compilerOptions.noUnusedParameters)) {
                            checkUnusedIdentifiers(getPotentiallyUnusedIdentifiers(node), (containingNode, kind, diag2) => {
                                if (!containsParseError(containingNode) && unusedIsError(kind, !!(containingNode.flags & 33554432 /* Ambient */))) {
                                    diagnostics.add(diag2);
                                }
                            });
                        }
                        if (!node.isDeclarationFile) {
                            checkPotentialUncheckedRenamedBindingElementsInTypes();
                        }
                    });
                    if (compilerOptions.importsNotUsedAsValues === 2 /* Error */ && !node.isDeclarationFile && isExternalModule(node)) {
                        checkImportsForTypeOnlyConversion(node);
                    }
                    if (isExternalOrCommonJsModule(node)) {
                        checkExternalModuleExports(node);
                    }
                    if (potentialThisCollisions.length) {
                        forEach(potentialThisCollisions, checkIfThisIsCapturedInEnclosingScope);
                        clear(potentialThisCollisions);
                    }
                    if (potentialNewTargetCollisions.length) {
                        forEach(potentialNewTargetCollisions, checkIfNewTargetIsCapturedInEnclosingScope);
                        clear(potentialNewTargetCollisions);
                    }
                    if (potentialWeakMapSetCollisions.length) {
                        forEach(potentialWeakMapSetCollisions, checkWeakMapSetCollision);
                        clear(potentialWeakMapSetCollisions);
                    }
                    if (potentialReflectCollisions.length) {
                        forEach(potentialReflectCollisions, checkReflectCollision);
                        clear(potentialReflectCollisions);
                    }
                    links.flags |= 1 /* TypeChecked */;
                }
            }
            function getDiagnostics2(sourceFile, ct) {
                try {
                    cancellationToken = ct;
                    return getDiagnosticsWorker(sourceFile);
                }
                finally {
                    cancellationToken = void 0;
                }
            }
            function ensurePendingDiagnosticWorkComplete() {
                for (const cb of deferredDiagnosticsCallbacks) {
                    cb();
                }
                deferredDiagnosticsCallbacks = [];
            }
            function checkSourceFileWithEagerDiagnostics(sourceFile) {
                ensurePendingDiagnosticWorkComplete();
                const oldAddLazyDiagnostics = addLazyDiagnostic;
                addLazyDiagnostic = (cb) => cb();
                checkSourceFile(sourceFile);
                addLazyDiagnostic = oldAddLazyDiagnostics;
            }
            function getDiagnosticsWorker(sourceFile) {
                if (sourceFile) {
                    ensurePendingDiagnosticWorkComplete();
                    const previousGlobalDiagnostics = diagnostics.getGlobalDiagnostics();
                    const previousGlobalDiagnosticsSize = previousGlobalDiagnostics.length;
                    checkSourceFileWithEagerDiagnostics(sourceFile);
                    const semanticDiagnostics = diagnostics.getDiagnostics(sourceFile.fileName);
                    const currentGlobalDiagnostics = diagnostics.getGlobalDiagnostics();
                    if (currentGlobalDiagnostics !== previousGlobalDiagnostics) {
                        const deferredGlobalDiagnostics = relativeComplement(previousGlobalDiagnostics, currentGlobalDiagnostics, compareDiagnostics);
                        return concatenate(deferredGlobalDiagnostics, semanticDiagnostics);
                    }
                    else if (previousGlobalDiagnosticsSize === 0 && currentGlobalDiagnostics.length > 0) {
                        return concatenate(currentGlobalDiagnostics, semanticDiagnostics);
                    }
                    return semanticDiagnostics;
                }
                forEach(host.getSourceFiles(), checkSourceFileWithEagerDiagnostics);
                return diagnostics.getDiagnostics();
            }
            function getGlobalDiagnostics() {
                ensurePendingDiagnosticWorkComplete();
                return diagnostics.getGlobalDiagnostics();
            }
            function getSymbolsInScope(location, meaning) {
                if (location.flags & 67108864 /* InWithStatement */) {
                    return [];
                }
                const symbols = createSymbolTable();
                let isStaticSymbol = false;
                populateSymbols();
                symbols.delete("this" /* This */);
                return symbolsToArray(symbols);
                function populateSymbols() {
                    while (location) {
                        if (canHaveLocals(location) && location.locals && !isGlobalSourceFile(location)) {
                            copySymbols(location.locals, meaning);
                        }
                        switch (location.kind) {
                            case 312 /* SourceFile */:
                                if (!isExternalModule(location))
                                    break;
                            case 267 /* ModuleDeclaration */:
                                copyLocallyVisibleExportSymbols(getSymbolOfDeclaration(location).exports, meaning & 2623475 /* ModuleMember */);
                                break;
                            case 266 /* EnumDeclaration */:
                                copySymbols(getSymbolOfDeclaration(location).exports, meaning & 8 /* EnumMember */);
                                break;
                            case 231 /* ClassExpression */:
                                const className = location.name;
                                if (className) {
                                    copySymbol(location.symbol, meaning);
                                }
                            case 263 /* ClassDeclaration */:
                            case 264 /* InterfaceDeclaration */:
                                if (!isStaticSymbol) {
                                    copySymbols(getMembersOfSymbol(getSymbolOfDeclaration(location)), meaning & 788968 /* Type */);
                                }
                                break;
                            case 218 /* FunctionExpression */:
                                const funcName = location.name;
                                if (funcName) {
                                    copySymbol(location.symbol, meaning);
                                }
                                break;
                        }
                        if (introducesArgumentsExoticObject(location)) {
                            copySymbol(argumentsSymbol, meaning);
                        }
                        isStaticSymbol = isStatic(location);
                        location = location.parent;
                    }
                    copySymbols(globals, meaning);
                }
                function copySymbol(symbol, meaning2) {
                    if (getCombinedLocalAndExportSymbolFlags(symbol) & meaning2) {
                        const id = symbol.escapedName;
                        if (!symbols.has(id)) {
                            symbols.set(id, symbol);
                        }
                    }
                }
                function copySymbols(source, meaning2) {
                    if (meaning2) {
                        source.forEach((symbol) => {
                            copySymbol(symbol, meaning2);
                        });
                    }
                }
                function copyLocallyVisibleExportSymbols(source, meaning2) {
                    if (meaning2) {
                        source.forEach((symbol) => {
                            if (!getDeclarationOfKind(symbol, 281 /* ExportSpecifier */) && !getDeclarationOfKind(symbol, 280 /* NamespaceExport */) && symbol.escapedName !== "default" /* Default */) {
                                copySymbol(symbol, meaning2);
                            }
                        });
                    }
                }
            }
            function isTypeDeclarationName(name) {
                return name.kind === 80 /* Identifier */ && isTypeDeclaration(name.parent) && getNameOfDeclaration(name.parent) === name;
            }
            function isTypeReferenceIdentifier(node) {
                while (node.parent.kind === 166 /* QualifiedName */) {
                    node = node.parent;
                }
                return node.parent.kind === 183 /* TypeReference */;
            }
            function isInNameOfExpressionWithTypeArguments(node) {
                while (node.parent.kind === 211 /* PropertyAccessExpression */) {
                    node = node.parent;
                }
                return node.parent.kind === 233 /* ExpressionWithTypeArguments */;
            }
            function forEachEnclosingClass(node, callback) {
                let result;
                let containingClass = getContainingClass(node);
                while (containingClass) {
                    if (result = callback(containingClass))
                        break;
                    containingClass = getContainingClass(containingClass);
                }
                return result;
            }
            function isNodeUsedDuringClassInitialization(node) {
                return !!findAncestor(node, (element) => {
                    if (isConstructorDeclaration(element) && nodeIsPresent(element.body) || isPropertyDeclaration(element)) {
                        return true;
                    }
                    else if (isClassLike(element) || isFunctionLikeDeclaration(element)) {
                        return "quit";
                    }
                    return false;
                });
            }
            function isNodeWithinClass(node, classDeclaration) {
                return !!forEachEnclosingClass(node, (n) => n === classDeclaration);
            }
            function getLeftSideOfImportEqualsOrExportAssignment(nodeOnRightSide) {
                while (nodeOnRightSide.parent.kind === 166 /* QualifiedName */) {
                    nodeOnRightSide = nodeOnRightSide.parent;
                }
                if (nodeOnRightSide.parent.kind === 271 /* ImportEqualsDeclaration */) {
                    return nodeOnRightSide.parent.moduleReference === nodeOnRightSide ? nodeOnRightSide.parent : void 0;
                }
                if (nodeOnRightSide.parent.kind === 277 /* ExportAssignment */) {
                    return nodeOnRightSide.parent.expression === nodeOnRightSide ? nodeOnRightSide.parent : void 0;
                }
                return void 0;
            }
            function isInRightSideOfImportOrExportAssignment(node) {
                return getLeftSideOfImportEqualsOrExportAssignment(node) !== void 0;
            }
            function getSpecialPropertyAssignmentSymbolFromEntityName(entityName) {
                const specialPropertyAssignmentKind = getAssignmentDeclarationKind(entityName.parent.parent);
                switch (specialPropertyAssignmentKind) {
                    case 1 /* ExportsProperty */:
                    case 3 /* PrototypeProperty */:
                        return getSymbolOfNode(entityName.parent);
                    case 5 /* Property */:
                        if (isPropertyAccessExpression(entityName.parent) && getLeftmostAccessExpression(entityName.parent) === entityName) {
                            return void 0;
                        }
                    case 4 /* ThisProperty */:
                    case 2 /* ModuleExports */:
                        return getSymbolOfDeclaration(entityName.parent.parent);
                }
            }
            function isImportTypeQualifierPart(node) {
                let parent2 = node.parent;
                while (isQualifiedName(parent2)) {
                    node = parent2;
                    parent2 = parent2.parent;
                }
                if (parent2 && parent2.kind === 205 /* ImportType */ && parent2.qualifier === node) {
                    return parent2;
                }
                return void 0;
            }
            function isThisPropertyAndThisTyped(node) {
                if (node.expression.kind === 110 /* ThisKeyword */) {
                    const container = getThisContainer(node, 
                    /*includeArrowFunctions*/
                    false, 
                    /*includeClassComputedPropertyName*/
                    false);
                    if (isFunctionLike(container)) {
                        const containingLiteral = getContainingObjectLiteral(container);
                        if (containingLiteral) {
                            const contextualType = getApparentTypeOfContextualType(containingLiteral, 
                            /*contextFlags*/
                            void 0);
                            const type = getThisTypeOfObjectLiteralFromContextualType(containingLiteral, contextualType);
                            return type && !isTypeAny(type);
                        }
                    }
                }
            }
            function getSymbolOfNameOrPropertyAccessExpression(name) {
                if (isDeclarationName(name)) {
                    return getSymbolOfNode(name.parent);
                }
                if (isInJSFile(name) && name.parent.kind === 211 /* PropertyAccessExpression */ && name.parent === name.parent.parent.left) {
                    if (!isPrivateIdentifier(name) && !isJSDocMemberName(name) && !isThisPropertyAndThisTyped(name.parent)) {
                        const specialPropertyAssignmentSymbol = getSpecialPropertyAssignmentSymbolFromEntityName(name);
                        if (specialPropertyAssignmentSymbol) {
                            return specialPropertyAssignmentSymbol;
                        }
                    }
                }
                if (name.parent.kind === 277 /* ExportAssignment */ && isEntityNameExpression(name)) {
                    const success = resolveEntityName(name, 
                    /*all meanings*/
                    111551 /* Value */ | 788968 /* Type */ | 1920 /* Namespace */ | 2097152 /* Alias */, 
                    /*ignoreErrors*/
                    true);
                    if (success && success !== unknownSymbol) {
                        return success;
                    }
                }
                else if (isEntityName(name) && isInRightSideOfImportOrExportAssignment(name)) {
                    const importEqualsDeclaration = getAncestor(name, 271 /* ImportEqualsDeclaration */);
                    Debug.assert(importEqualsDeclaration !== void 0);
                    return getSymbolOfPartOfRightHandSideOfImportEquals(name, 
                    /*dontResolveAlias*/
                    true);
                }
                if (isEntityName(name)) {
                    const possibleImportNode = isImportTypeQualifierPart(name);
                    if (possibleImportNode) {
                        getTypeFromTypeNode(possibleImportNode);
                        const sym = getNodeLinks(name).resolvedSymbol;
                        return sym === unknownSymbol ? void 0 : sym;
                    }
                }
                while (isRightSideOfQualifiedNameOrPropertyAccessOrJSDocMemberName(name)) {
                    name = name.parent;
                }
                if (isInNameOfExpressionWithTypeArguments(name)) {
                    let meaning = 0 /* None */;
                    if (name.parent.kind === 233 /* ExpressionWithTypeArguments */) {
                        meaning = isPartOfTypeNode(name) ? 788968 /* Type */ : 111551 /* Value */;
                        if (isExpressionWithTypeArgumentsInClassExtendsClause(name.parent)) {
                            meaning |= 111551 /* Value */;
                        }
                    }
                    else {
                        meaning = 1920 /* Namespace */;
                    }
                    meaning |= 2097152 /* Alias */;
                    const entityNameSymbol = isEntityNameExpression(name) ? resolveEntityName(name, meaning, 
                    /*ignoreErrors*/
                    true) : void 0;
                    if (entityNameSymbol) {
                        return entityNameSymbol;
                    }
                }
                if (name.parent.kind === 348 /* JSDocParameterTag */) {
                    return getParameterSymbolFromJSDoc(name.parent);
                }
                if (name.parent.kind === 168 /* TypeParameter */ && name.parent.parent.kind === 352 /* JSDocTemplateTag */) {
                    Debug.assert(!isInJSFile(name));
                    const typeParameter = getTypeParameterFromJsDoc(name.parent);
                    return typeParameter && typeParameter.symbol;
                }
                if (isExpressionNode(name)) {
                    if (nodeIsMissing(name)) {
                        return void 0;
                    }
                    const isJSDoc2 = findAncestor(name, or(isJSDocLinkLike, isJSDocNameReference, isJSDocMemberName));
                    const meaning = isJSDoc2 ? 788968 /* Type */ | 1920 /* Namespace */ | 111551 /* Value */ : 111551 /* Value */;
                    if (name.kind === 80 /* Identifier */) {
                        if (isJSXTagName(name) && isJsxIntrinsicTagName(name)) {
                            const symbol = getIntrinsicTagSymbol(name.parent);
                            return symbol === unknownSymbol ? void 0 : symbol;
                        }
                        const result = resolveEntityName(name, meaning, 
                        /*ignoreErrors*/
                        true, 
                        /*dontResolveAlias*/
                        true, getHostSignatureFromJSDoc(name));
                        if (!result && isJSDoc2) {
                            const container = findAncestor(name, or(isClassLike, isInterfaceDeclaration));
                            if (container) {
                                return resolveJSDocMemberName(name, 
                                /*ignoreErrors*/
                                true, getSymbolOfDeclaration(container));
                            }
                        }
                        if (result && isJSDoc2) {
                            const container = getJSDocHost(name);
                            if (container && isEnumMember(container) && container === result.valueDeclaration) {
                                return resolveEntityName(name, meaning, 
                                /*ignoreErrors*/
                                true, 
                                /*dontResolveAlias*/
                                true, getSourceFileOfNode(container)) || result;
                            }
                        }
                        return result;
                    }
                    else if (isPrivateIdentifier(name)) {
                        return getSymbolForPrivateIdentifierExpression(name);
                    }
                    else if (name.kind === 211 /* PropertyAccessExpression */ || name.kind === 166 /* QualifiedName */) {
                        const links = getNodeLinks(name);
                        if (links.resolvedSymbol) {
                            return links.resolvedSymbol;
                        }
                        if (name.kind === 211 /* PropertyAccessExpression */) {
                            checkPropertyAccessExpression(name, 0 /* Normal */);
                            if (!links.resolvedSymbol) {
                                links.resolvedSymbol = getApplicableIndexSymbol(checkExpressionCached(name.expression), getLiteralTypeFromPropertyName(name.name));
                            }
                        }
                        else {
                            checkQualifiedName(name, 0 /* Normal */);
                        }
                        if (!links.resolvedSymbol && isJSDoc2 && isQualifiedName(name)) {
                            return resolveJSDocMemberName(name);
                        }
                        return links.resolvedSymbol;
                    }
                    else if (isJSDocMemberName(name)) {
                        return resolveJSDocMemberName(name);
                    }
                }
                else if (isTypeReferenceIdentifier(name)) {
                    const meaning = name.parent.kind === 183 /* TypeReference */ ? 788968 /* Type */ : 1920 /* Namespace */;
                    const symbol = resolveEntityName(name, meaning, 
                    /*ignoreErrors*/
                    false, 
                    /*dontResolveAlias*/
                    true);
                    return symbol && symbol !== unknownSymbol ? symbol : getUnresolvedSymbolForEntityName(name);
                }
                if (name.parent.kind === 182 /* TypePredicate */) {
                    return resolveEntityName(name, 
                    /*meaning*/
                    1 /* FunctionScopedVariable */);
                }
                return void 0;
            }
            function getApplicableIndexSymbol(type, keyType) {
                const infos = getApplicableIndexInfos(type, keyType);
                if (infos.length && type.members) {
                    const symbol = getIndexSymbolFromSymbolTable(resolveStructuredTypeMembers(type).members);
                    if (infos === getIndexInfosOfType(type)) {
                        return symbol;
                    }
                    else if (symbol) {
                        const symbolLinks2 = getSymbolLinks(symbol);
                        const declarationList = mapDefined(infos, (i) => i.declaration);
                        const nodeListId = map(declarationList, getNodeId).join(",");
                        if (!symbolLinks2.filteredIndexSymbolCache) {
                            symbolLinks2.filteredIndexSymbolCache = /* @__PURE__ */ new Map();
                        }
                        if (symbolLinks2.filteredIndexSymbolCache.has(nodeListId)) {
                            return symbolLinks2.filteredIndexSymbolCache.get(nodeListId);
                        }
                        else {
                            const copy = createSymbol(131072 /* Signature */, "__index" /* Index */);
                            copy.declarations = mapDefined(infos, (i) => i.declaration);
                            copy.parent = type.aliasSymbol ? type.aliasSymbol : type.symbol ? type.symbol : getSymbolAtLocation(copy.declarations[0].parent);
                            symbolLinks2.filteredIndexSymbolCache.set(nodeListId, copy);
                            return copy;
                        }
                    }
                }
            }
            function resolveJSDocMemberName(name, ignoreErrors, container) {
                if (isEntityName(name)) {
                    const meaning = 788968 /* Type */ | 1920 /* Namespace */ | 111551 /* Value */;
                    let symbol = resolveEntityName(name, meaning, ignoreErrors, 
                    /*dontResolveAlias*/
                    true, getHostSignatureFromJSDoc(name));
                    if (!symbol && isIdentifier(name) && container) {
                        symbol = getMergedSymbol(getSymbol2(getExportsOfSymbol(container), name.escapedText, meaning));
                    }
                    if (symbol) {
                        return symbol;
                    }
                }
                const left = isIdentifier(name) ? container : resolveJSDocMemberName(name.left, ignoreErrors, container);
                const right = isIdentifier(name) ? name.escapedText : name.right.escapedText;
                if (left) {
                    const proto = left.flags & 111551 /* Value */ && getPropertyOfType(getTypeOfSymbol(left), "prototype");
                    const t = proto ? getTypeOfSymbol(proto) : getDeclaredTypeOfSymbol(left);
                    return getPropertyOfType(t, right);
                }
            }
            function getSymbolAtLocation(node, ignoreErrors) {
                if (isSourceFile(node)) {
                    return isExternalModule(node) ? getMergedSymbol(node.symbol) : void 0;
                }
                const { parent: parent2 } = node;
                const grandParent = parent2.parent;
                if (node.flags & 67108864 /* InWithStatement */) {
                    return void 0;
                }
                if (isDeclarationNameOrImportPropertyName(node)) {
                    const parentSymbol = getSymbolOfDeclaration(parent2);
                    return isImportOrExportSpecifier(node.parent) && node.parent.propertyName === node ? getImmediateAliasedSymbol(parentSymbol) : parentSymbol;
                }
                else if (isLiteralComputedPropertyDeclarationName(node)) {
                    return getSymbolOfDeclaration(parent2.parent);
                }
                if (node.kind === 80 /* Identifier */) {
                    if (isInRightSideOfImportOrExportAssignment(node)) {
                        return getSymbolOfNameOrPropertyAccessExpression(node);
                    }
                    else if (parent2.kind === 208 /* BindingElement */ && grandParent.kind === 206 /* ObjectBindingPattern */ && node === parent2.propertyName) {
                        const typeOfPattern = getTypeOfNode(grandParent);
                        const propertyDeclaration = getPropertyOfType(typeOfPattern, node.escapedText);
                        if (propertyDeclaration) {
                            return propertyDeclaration;
                        }
                    }
                    else if (isMetaProperty(parent2) && parent2.name === node) {
                        if (parent2.keywordToken === 105 /* NewKeyword */ && idText(node) === "target") {
                            return checkNewTargetMetaProperty(parent2).symbol;
                        }
                        if (parent2.keywordToken === 102 /* ImportKeyword */ && idText(node) === "meta") {
                            return getGlobalImportMetaExpressionType().members.get("meta");
                        }
                        return void 0;
                    }
                }
                switch (node.kind) {
                    case 80 /* Identifier */:
                    case 81 /* PrivateIdentifier */:
                    case 211 /* PropertyAccessExpression */:
                    case 166 /* QualifiedName */:
                        if (!isThisInTypeQuery(node)) {
                            return getSymbolOfNameOrPropertyAccessExpression(node);
                        }
                    case 110 /* ThisKeyword */:
                        const container = getThisContainer(node, 
                        /*includeArrowFunctions*/
                        false, 
                        /*includeClassComputedPropertyName*/
                        false);
                        if (isFunctionLike(container)) {
                            const sig = getSignatureFromDeclaration(container);
                            if (sig.thisParameter) {
                                return sig.thisParameter;
                            }
                        }
                        if (isInExpressionContext(node)) {
                            return checkExpression(node).symbol;
                        }
                    case 197 /* ThisType */:
                        return getTypeFromThisTypeNode(node).symbol;
                    case 108 /* SuperKeyword */:
                        return checkExpression(node).symbol;
                    case 137 /* ConstructorKeyword */:
                        const constructorDeclaration = node.parent;
                        if (constructorDeclaration && constructorDeclaration.kind === 176 /* Constructor */) {
                            return constructorDeclaration.parent.symbol;
                        }
                        return void 0;
                    case 11 /* StringLiteral */:
                    case 15 /* NoSubstitutionTemplateLiteral */:
                        if (isExternalModuleImportEqualsDeclaration(node.parent.parent) && getExternalModuleImportEqualsDeclarationExpression(node.parent.parent) === node || (node.parent.kind === 272 /* ImportDeclaration */ || node.parent.kind === 278 /* ExportDeclaration */) && node.parent.moduleSpecifier === node || (isInJSFile(node) && isRequireCall(node.parent, 
                        /*requireStringLiteralLikeArgument*/
                        false) || isImportCall(node.parent)) || isLiteralTypeNode(node.parent) && isLiteralImportTypeNode(node.parent.parent) && node.parent.parent.argument === node.parent) {
                            return resolveExternalModuleName(node, node, ignoreErrors);
                        }
                        if (isCallExpression(parent2) && isBindableObjectDefinePropertyCall(parent2) && parent2.arguments[1] === node) {
                            return getSymbolOfDeclaration(parent2);
                        }
                    case 9 /* NumericLiteral */:
                        const objectType = isElementAccessExpression(parent2) ? parent2.argumentExpression === node ? getTypeOfExpression(parent2.expression) : void 0 : isLiteralTypeNode(parent2) && isIndexedAccessTypeNode(grandParent) ? getTypeFromTypeNode(grandParent.objectType) : void 0;
                        return objectType && getPropertyOfType(objectType, escapeLeadingUnderscores(node.text));
                    case 90 /* DefaultKeyword */:
                    case 100 /* FunctionKeyword */:
                    case 39 /* EqualsGreaterThanToken */:
                    case 86 /* ClassKeyword */:
                        return getSymbolOfNode(node.parent);
                    case 205 /* ImportType */:
                        return isLiteralImportTypeNode(node) ? getSymbolAtLocation(node.argument.literal, ignoreErrors) : void 0;
                    case 95 /* ExportKeyword */:
                        return isExportAssignment(node.parent) ? Debug.checkDefined(node.parent.symbol) : void 0;
                    case 102 /* ImportKeyword */:
                    case 105 /* NewKeyword */:
                        return isMetaProperty(node.parent) ? checkMetaPropertyKeyword(node.parent).symbol : void 0;
                    case 104 /* InstanceOfKeyword */:
                        if (isBinaryExpression(node.parent)) {
                            const type = getTypeOfExpression(node.parent.right);
                            const hasInstanceMethodType = getSymbolHasInstanceMethodOfObjectType(type);
                            return (hasInstanceMethodType == null ? void 0 : hasInstanceMethodType.symbol) ?? type.symbol;
                        }
                        return void 0;
                    case 236 /* MetaProperty */:
                        return checkExpression(node).symbol;
                    case 295 /* JsxNamespacedName */:
                        if (isJSXTagName(node) && isJsxIntrinsicTagName(node)) {
                            const symbol = getIntrinsicTagSymbol(node.parent);
                            return symbol === unknownSymbol ? void 0 : symbol;
                        }
                    default:
                        return void 0;
                }
            }
            function getIndexInfosAtLocation(node) {
                if (isIdentifier(node) && isPropertyAccessExpression(node.parent) && node.parent.name === node) {
                    const keyType = getLiteralTypeFromPropertyName(node);
                    const objectType = getTypeOfExpression(node.parent.expression);
                    const objectTypes = objectType.flags & 1048576 /* Union */ ? objectType.types : [objectType];
                    return flatMap(objectTypes, (t) => filter(getIndexInfosOfType(t), (info) => isApplicableIndexType(keyType, info.keyType)));
                }
                return void 0;
            }
            function getShorthandAssignmentValueSymbol(location) {
                if (location && location.kind === 304 /* ShorthandPropertyAssignment */) {
                    return resolveEntityName(location.name, 111551 /* Value */ | 2097152 /* Alias */);
                }
                return void 0;
            }
            function getExportSpecifierLocalTargetSymbol(node) {
                if (isExportSpecifier(node)) {
                    return node.parent.parent.moduleSpecifier ? getExternalModuleMember(node.parent.parent, node) : resolveEntityName(node.propertyName || node.name, 111551 /* Value */ | 788968 /* Type */ | 1920 /* Namespace */ | 2097152 /* Alias */);
                }
                else {
                    return resolveEntityName(node, 111551 /* Value */ | 788968 /* Type */ | 1920 /* Namespace */ | 2097152 /* Alias */);
                }
            }
            function getTypeOfNode(node) {
                if (isSourceFile(node) && !isExternalModule(node)) {
                    return errorType;
                }
                if (node.flags & 67108864 /* InWithStatement */) {
                    return errorType;
                }
                const classDecl = tryGetClassImplementingOrExtendingExpressionWithTypeArguments(node);
                const classType = classDecl && getDeclaredTypeOfClassOrInterface(getSymbolOfDeclaration(classDecl.class));
                if (isPartOfTypeNode(node)) {
                    const typeFromTypeNode = getTypeFromTypeNode(node);
                    return classType ? getTypeWithThisArgument(typeFromTypeNode, classType.thisType) : typeFromTypeNode;
                }
                if (isExpressionNode(node)) {
                    return getRegularTypeOfExpression(node);
                }
                if (classType && !classDecl.isImplements) {
                    const baseType = firstOrUndefined(getBaseTypes(classType));
                    return baseType ? getTypeWithThisArgument(baseType, classType.thisType) : errorType;
                }
                if (isTypeDeclaration(node)) {
                    const symbol = getSymbolOfDeclaration(node);
                    return getDeclaredTypeOfSymbol(symbol);
                }
                if (isTypeDeclarationName(node)) {
                    const symbol = getSymbolAtLocation(node);
                    return symbol ? getDeclaredTypeOfSymbol(symbol) : errorType;
                }
                if (isBindingElement(node)) {
                    return getTypeForVariableLikeDeclaration(node, 
                    /*includeOptionality*/
                    true, 0 /* Normal */) || errorType;
                }
                if (isDeclaration(node)) {
                    const symbol = getSymbolOfDeclaration(node);
                    return symbol ? getTypeOfSymbol(symbol) : errorType;
                }
                if (isDeclarationNameOrImportPropertyName(node)) {
                    const symbol = getSymbolAtLocation(node);
                    if (symbol) {
                        return getTypeOfSymbol(symbol);
                    }
                    return errorType;
                }
                if (isBindingPattern(node)) {
                    return getTypeForVariableLikeDeclaration(node.parent, 
                    /*includeOptionality*/
                    true, 0 /* Normal */) || errorType;
                }
                if (isInRightSideOfImportOrExportAssignment(node)) {
                    const symbol = getSymbolAtLocation(node);
                    if (symbol) {
                        const declaredType = getDeclaredTypeOfSymbol(symbol);
                        return !isErrorType(declaredType) ? declaredType : getTypeOfSymbol(symbol);
                    }
                }
                if (isMetaProperty(node.parent) && node.parent.keywordToken === node.kind) {
                    return checkMetaPropertyKeyword(node.parent);
                }
                if (isImportAttributes(node)) {
                    return getGlobalImportAttributesType(
                    /*reportErrors*/
                    false);
                }
                return errorType;
            }
            function getTypeOfAssignmentPattern(expr) {
                Debug.assert(expr.kind === 210 /* ObjectLiteralExpression */ || expr.kind === 209 /* ArrayLiteralExpression */);
                if (expr.parent.kind === 250 /* ForOfStatement */) {
                    const iteratedType = checkRightHandSideOfForOf(expr.parent);
                    return checkDestructuringAssignment(expr, iteratedType || errorType);
                }
                if (expr.parent.kind === 226 /* BinaryExpression */) {
                    const iteratedType = getTypeOfExpression(expr.parent.right);
                    return checkDestructuringAssignment(expr, iteratedType || errorType);
                }
                if (expr.parent.kind === 303 /* PropertyAssignment */) {
                    const node2 = cast(expr.parent.parent, isObjectLiteralExpression);
                    const typeOfParentObjectLiteral = getTypeOfAssignmentPattern(node2) || errorType;
                    const propertyIndex = indexOfNode(node2.properties, expr.parent);
                    return checkObjectLiteralDestructuringPropertyAssignment(node2, typeOfParentObjectLiteral, propertyIndex);
                }
                const node = cast(expr.parent, isArrayLiteralExpression);
                const typeOfArrayLiteral = getTypeOfAssignmentPattern(node) || errorType;
                const elementType = checkIteratedTypeOrElementType(65 /* Destructuring */, typeOfArrayLiteral, undefinedType, expr.parent) || errorType;
                return checkArrayLiteralDestructuringElementAssignment(node, typeOfArrayLiteral, node.elements.indexOf(expr), elementType);
            }
            function getPropertySymbolOfDestructuringAssignment(location) {
                const typeOfObjectLiteral = getTypeOfAssignmentPattern(cast(location.parent.parent, isAssignmentPattern));
                return typeOfObjectLiteral && getPropertyOfType(typeOfObjectLiteral, location.escapedText);
            }
            function getRegularTypeOfExpression(expr) {
                if (isRightSideOfQualifiedNameOrPropertyAccess(expr)) {
                    expr = expr.parent;
                }
                return getRegularTypeOfLiteralType(getTypeOfExpression(expr));
            }
            function getParentTypeOfClassElement(node) {
                const classSymbol = getSymbolOfNode(node.parent);
                return isStatic(node) ? getTypeOfSymbol(classSymbol) : getDeclaredTypeOfSymbol(classSymbol);
            }
            function getClassElementPropertyKeyType(element) {
                const name = element.name;
                switch (name.kind) {
                    case 80 /* Identifier */:
                        return getStringLiteralType(idText(name));
                    case 9 /* NumericLiteral */:
                    case 11 /* StringLiteral */:
                        return getStringLiteralType(name.text);
                    case 167 /* ComputedPropertyName */:
                        const nameType = checkComputedPropertyName(name);
                        return isTypeAssignableToKind(nameType, 12288 /* ESSymbolLike */) ? nameType : stringType;
                    default:
                        return Debug.fail("Unsupported property name.");
                }
            }
            function getAugmentedPropertiesOfType(type) {
                type = getApparentType(type);
                const propsByName = createSymbolTable(getPropertiesOfType(type));
                const functionType = getSignaturesOfType(type, 0 /* Call */).length ? globalCallableFunctionType : getSignaturesOfType(type, 1 /* Construct */).length ? globalNewableFunctionType : void 0;
                if (functionType) {
                    forEach(getPropertiesOfType(functionType), (p) => {
                        if (!propsByName.has(p.escapedName)) {
                            propsByName.set(p.escapedName, p);
                        }
                    });
                }
                return getNamedMembers(propsByName);
            }
            function typeHasCallOrConstructSignatures(type) {
                return getSignaturesOfType(type, 0 /* Call */).length !== 0 || getSignaturesOfType(type, 1 /* Construct */).length !== 0;
            }
            function getRootSymbols(symbol) {
                const roots = getImmediateRootSymbols(symbol);
                return roots ? flatMap(roots, getRootSymbols) : [symbol];
            }
            function getImmediateRootSymbols(symbol) {
                if (getCheckFlags(symbol) & 6 /* Synthetic */) {
                    return mapDefined(getSymbolLinks(symbol).containingType.types, (type) => getPropertyOfType(type, symbol.escapedName));
                }
                else if (symbol.flags & 33554432 /* Transient */) {
                    const { links: { leftSpread, rightSpread, syntheticOrigin } } = symbol;
                    return leftSpread ? [leftSpread, rightSpread] : syntheticOrigin ? [syntheticOrigin] : singleElementArray(tryGetTarget(symbol));
                }
                return void 0;
            }
            function tryGetTarget(symbol) {
                let target;
                let next = symbol;
                while (next = getSymbolLinks(next).target) {
                    target = next;
                }
                return target;
            }
            function isArgumentsLocalBinding(nodeIn) {
                if (isGeneratedIdentifier(nodeIn))
                    return false;
                const node = getParseTreeNode(nodeIn, isIdentifier);
                if (!node)
                    return false;
                const parent2 = node.parent;
                if (!parent2)
                    return false;
                const isPropertyName2 = (isPropertyAccessExpression(parent2) || isPropertyAssignment(parent2)) && parent2.name === node;
                return !isPropertyName2 && getReferencedValueSymbol(node) === argumentsSymbol;
            }
            function moduleExportsSomeValue(moduleReferenceExpression) {
                let moduleSymbol = resolveExternalModuleName(moduleReferenceExpression.parent, moduleReferenceExpression);
                if (!moduleSymbol || isShorthandAmbientModuleSymbol(moduleSymbol)) {
                    return true;
                }
                const hasExportAssignment = hasExportAssignmentSymbol(moduleSymbol);
                moduleSymbol = resolveExternalModuleSymbol(moduleSymbol);
                const symbolLinks2 = getSymbolLinks(moduleSymbol);
                if (symbolLinks2.exportsSomeValue === void 0) {
                    symbolLinks2.exportsSomeValue = hasExportAssignment ? !!(moduleSymbol.flags & 111551 /* Value */) : forEachEntry(getExportsOfModule(moduleSymbol), isValue);
                }
                return symbolLinks2.exportsSomeValue;
                function isValue(s) {
                    s = resolveSymbol(s);
                    return s && !!(getSymbolFlags(s) & 111551 /* Value */);
                }
            }
            function isNameOfModuleOrEnumDeclaration(node) {
                return isModuleOrEnumDeclaration(node.parent) && node === node.parent.name;
            }
            function getReferencedExportContainer(nodeIn, prefixLocals) {
                var _a;
                const node = getParseTreeNode(nodeIn, isIdentifier);
                if (node) {
                    let symbol = getReferencedValueSymbol(node, 
                    /*startInDeclarationContainer*/
                    isNameOfModuleOrEnumDeclaration(node));
                    if (symbol) {
                        if (symbol.flags & 1048576 /* ExportValue */) {
                            const exportSymbol = getMergedSymbol(symbol.exportSymbol);
                            if (!prefixLocals && exportSymbol.flags & 944 /* ExportHasLocal */ && !(exportSymbol.flags & 3 /* Variable */)) {
                                return void 0;
                            }
                            symbol = exportSymbol;
                        }
                        const parentSymbol = getParentOfSymbol(symbol);
                        if (parentSymbol) {
                            if (parentSymbol.flags & 512 /* ValueModule */ && ((_a = parentSymbol.valueDeclaration) == null ? void 0 : _a.kind) === 312 /* SourceFile */) {
                                const symbolFile = parentSymbol.valueDeclaration;
                                const referenceFile = getSourceFileOfNode(node);
                                const symbolIsUmdExport = symbolFile !== referenceFile;
                                return symbolIsUmdExport ? void 0 : symbolFile;
                            }
                            return findAncestor(node.parent, (n) => isModuleOrEnumDeclaration(n) && getSymbolOfDeclaration(n) === parentSymbol);
                        }
                    }
                }
            }
            function getReferencedImportDeclaration(nodeIn) {
                const specifier = getIdentifierGeneratedImportReference(nodeIn);
                if (specifier) {
                    return specifier;
                }
                const node = getParseTreeNode(nodeIn, isIdentifier);
                if (node) {
                    const symbol = getReferencedValueOrAliasSymbol(node);
                    if (isNonLocalAlias(symbol, 
                    /*excludes*/
                    111551 /* Value */) && !getTypeOnlyAliasDeclaration(symbol, 111551 /* Value */)) {
                        return getDeclarationOfAliasSymbol(symbol);
                    }
                }
                return void 0;
            }
            function isSymbolOfDestructuredElementOfCatchBinding(symbol) {
                return symbol.valueDeclaration && isBindingElement(symbol.valueDeclaration) && walkUpBindingElementsAndPatterns(symbol.valueDeclaration).parent.kind === 299 /* CatchClause */;
            }
            function isSymbolOfDeclarationWithCollidingName(symbol) {
                if (symbol.flags & 418 /* BlockScoped */ && symbol.valueDeclaration && !isSourceFile(symbol.valueDeclaration)) {
                    const links = getSymbolLinks(symbol);
                    if (links.isDeclarationWithCollidingName === void 0) {
                        const container = getEnclosingBlockScopeContainer(symbol.valueDeclaration);
                        if (isStatementWithLocals(container) || isSymbolOfDestructuredElementOfCatchBinding(symbol)) {
                            const nodeLinks2 = getNodeLinks(symbol.valueDeclaration);
                            if (resolveName(container.parent, symbol.escapedName, 111551 /* Value */, 
                            /*nameNotFoundMessage*/
                            void 0, 
                            /*nameArg*/
                            void 0, 
                            /*isUse*/
                            false)) {
                                links.isDeclarationWithCollidingName = true;
                            }
                            else if (nodeLinks2.flags & 16384 /* CapturedBlockScopedBinding */) {
                                const isDeclaredInLoop = nodeLinks2.flags & 32768 /* BlockScopedBindingInLoop */;
                                const inLoopInitializer = isIterationStatement(container, 
                                /*lookInLabeledStatements*/
                                false);
                                const inLoopBodyBlock = container.kind === 241 /* Block */ && isIterationStatement(container.parent, 
                                /*lookInLabeledStatements*/
                                false);
                                links.isDeclarationWithCollidingName = !isBlockScopedContainerTopLevel(container) && (!isDeclaredInLoop || !inLoopInitializer && !inLoopBodyBlock);
                            }
                            else {
                                links.isDeclarationWithCollidingName = false;
                            }
                        }
                    }
                    return links.isDeclarationWithCollidingName;
                }
                return false;
            }
            function getReferencedDeclarationWithCollidingName(nodeIn) {
                if (!isGeneratedIdentifier(nodeIn)) {
                    const node = getParseTreeNode(nodeIn, isIdentifier);
                    if (node) {
                        const symbol = getReferencedValueSymbol(node);
                        if (symbol && isSymbolOfDeclarationWithCollidingName(symbol)) {
                            return symbol.valueDeclaration;
                        }
                    }
                }
                return void 0;
            }
            function isDeclarationWithCollidingName(nodeIn) {
                const node = getParseTreeNode(nodeIn, isDeclaration);
                if (node) {
                    const symbol = getSymbolOfDeclaration(node);
                    if (symbol) {
                        return isSymbolOfDeclarationWithCollidingName(symbol);
                    }
                }
                return false;
            }
            function isValueAliasDeclaration(node) {
                Debug.assert(canCollectSymbolAliasAccessabilityData);
                switch (node.kind) {
                    case 271 /* ImportEqualsDeclaration */:
                        return isAliasResolvedToValue(getSymbolOfDeclaration(node));
                    case 273 /* ImportClause */:
                    case 274 /* NamespaceImport */:
                    case 276 /* ImportSpecifier */:
                    case 281 /* ExportSpecifier */:
                        const symbol = getSymbolOfDeclaration(node);
                        return !!symbol && isAliasResolvedToValue(symbol, 
                        /*excludeTypeOnlyValues*/
                        true);
                    case 278 /* ExportDeclaration */:
                        const exportClause = node.exportClause;
                        return !!exportClause && (isNamespaceExport(exportClause) || some(exportClause.elements, isValueAliasDeclaration));
                    case 277 /* ExportAssignment */:
                        return node.expression && node.expression.kind === 80 /* Identifier */ ? isAliasResolvedToValue(getSymbolOfDeclaration(node), 
                        /*excludeTypeOnlyValues*/
                        true) : true;
                }
                return false;
            }
            function isTopLevelValueImportEqualsWithEntityName(nodeIn) {
                const node = getParseTreeNode(nodeIn, isImportEqualsDeclaration);
                if (node === void 0 || node.parent.kind !== 312 /* SourceFile */ || !isInternalModuleImportEqualsDeclaration(node)) {
                    return false;
                }
                const isValue = isAliasResolvedToValue(getSymbolOfDeclaration(node));
                return isValue && node.moduleReference && !nodeIsMissing(node.moduleReference);
            }
            function isAliasResolvedToValue(symbol, excludeTypeOnlyValues) {
                if (!symbol) {
                    return false;
                }
                const target = getExportSymbolOfValueSymbolIfExported(resolveAlias(symbol));
                if (target === unknownSymbol) {
                    return !excludeTypeOnlyValues || !getTypeOnlyAliasDeclaration(symbol);
                }
                return !!(getSymbolFlags(symbol, excludeTypeOnlyValues, 
                /*excludeLocalMeanings*/
                true) & 111551 /* Value */) && (shouldPreserveConstEnums(compilerOptions) || !isConstEnumOrConstEnumOnlyModule(target));
            }
            function isConstEnumOrConstEnumOnlyModule(s) {
                return isConstEnumSymbol(s) || !!s.constEnumOnlyModule;
            }
            function isReferencedAliasDeclaration(node, checkChildren) {
                Debug.assert(canCollectSymbolAliasAccessabilityData);
                if (isAliasSymbolDeclaration2(node)) {
                    const symbol = getSymbolOfDeclaration(node);
                    const links = symbol && getSymbolLinks(symbol);
                    if (links == null ? void 0 : links.referenced) {
                        return true;
                    }
                    const target = getSymbolLinks(symbol).aliasTarget;
                    if (target && getEffectiveModifierFlags(node) & 32 /* Export */ && getSymbolFlags(target) & 111551 /* Value */ && (shouldPreserveConstEnums(compilerOptions) || !isConstEnumOrConstEnumOnlyModule(target))) {
                        return true;
                    }
                }
                if (checkChildren) {
                    return !!forEachChild(node, (node2) => isReferencedAliasDeclaration(node2, checkChildren));
                }
                return false;
            }
            function isImplementationOfOverload(node) {
                if (nodeIsPresent(node.body)) {
                    if (isGetAccessor(node) || isSetAccessor(node))
                        return false;
                    const symbol = getSymbolOfDeclaration(node);
                    const signaturesOfSymbol = getSignaturesOfSymbol(symbol);
                    return signaturesOfSymbol.length > 1 || // If there is single signature for the symbol, it is overload if that signature isn't coming from the node
                        // e.g.: function foo(a: string): string;
                        //       function foo(a: any) { // This is implementation of the overloads
                        //           return a;
                        //       }
                        signaturesOfSymbol.length === 1 && signaturesOfSymbol[0].declaration !== node;
                }
                return false;
            }
            function isRequiredInitializedParameter(parameter) {
                return !!strictNullChecks && !isOptionalParameter(parameter) && !isJSDocParameterTag(parameter) && !!parameter.initializer && !hasSyntacticModifier(parameter, 31 /* ParameterPropertyModifier */);
            }
            function isOptionalUninitializedParameterProperty(parameter) {
                return strictNullChecks && isOptionalParameter(parameter) && !parameter.initializer && hasSyntacticModifier(parameter, 31 /* ParameterPropertyModifier */);
            }
            function isExpandoFunctionDeclaration(node) {
                const declaration = getParseTreeNode(node, isFunctionDeclaration);
                if (!declaration) {
                    return false;
                }
                const symbol = getSymbolOfDeclaration(declaration);
                if (!symbol || !(symbol.flags & 16 /* Function */)) {
                    return false;
                }
                return !!forEachEntry(getExportsOfSymbol(symbol), (p) => p.flags & 111551 /* Value */ && isExpandoPropertyDeclaration(p.valueDeclaration));
            }
            function getPropertiesOfContainerFunction(node) {
                const declaration = getParseTreeNode(node, isFunctionDeclaration);
                if (!declaration) {
                    return emptyArray;
                }
                const symbol = getSymbolOfDeclaration(declaration);
                return symbol && getPropertiesOfType(getTypeOfSymbol(symbol)) || emptyArray;
            }
            function getNodeCheckFlags(node) {
                var _a;
                const nodeId = node.id || 0;
                if (nodeId < 0 || nodeId >= nodeLinks.length)
                    return 0;
                return ((_a = nodeLinks[nodeId]) == null ? void 0 : _a.flags) || 0;
            }
            function getEnumMemberValue(node) {
                computeEnumMemberValues(node.parent);
                return getNodeLinks(node).enumMemberValue;
            }
            function canHaveConstantValue(node) {
                switch (node.kind) {
                    case 306 /* EnumMember */:
                    case 211 /* PropertyAccessExpression */:
                    case 212 /* ElementAccessExpression */:
                        return true;
                }
                return false;
            }
            function getConstantValue2(node) {
                if (node.kind === 306 /* EnumMember */) {
                    return getEnumMemberValue(node);
                }
                const symbol = getNodeLinks(node).resolvedSymbol;
                if (symbol && symbol.flags & 8 /* EnumMember */) {
                    const member = symbol.valueDeclaration;
                    if (isEnumConst(member.parent)) {
                        return getEnumMemberValue(member);
                    }
                }
                return void 0;
            }
            function isFunctionType(type) {
                return !!(type.flags & 524288 /* Object */) && getSignaturesOfType(type, 0 /* Call */).length > 0;
            }
            function getTypeReferenceSerializationKind(typeNameIn, location) {
                var _a;
                const typeName = getParseTreeNode(typeNameIn, isEntityName);
                if (!typeName)
                    return 0 /* Unknown */;
                if (location) {
                    location = getParseTreeNode(location);
                    if (!location)
                        return 0 /* Unknown */;
                }
                let isTypeOnly = false;
                if (isQualifiedName(typeName)) {
                    const rootValueSymbol = resolveEntityName(getFirstIdentifier(typeName), 111551 /* Value */, 
                    /*ignoreErrors*/
                    true, 
                    /*dontResolveAlias*/
                    true, location);
                    isTypeOnly = !!((_a = rootValueSymbol == null ? void 0 : rootValueSymbol.declarations) == null ? void 0 : _a.every(isTypeOnlyImportOrExportDeclaration));
                }
                const valueSymbol = resolveEntityName(typeName, 111551 /* Value */, 
                /*ignoreErrors*/
                true, 
                /*dontResolveAlias*/
                true, location);
                const resolvedValueSymbol = valueSymbol && valueSymbol.flags & 2097152 /* Alias */ ? resolveAlias(valueSymbol) : valueSymbol;
                isTypeOnly || (isTypeOnly = !!(valueSymbol && getTypeOnlyAliasDeclaration(valueSymbol, 111551 /* Value */)));
                const typeSymbol = resolveEntityName(typeName, 788968 /* Type */, 
                /*ignoreErrors*/
                true, 
                /*dontResolveAlias*/
                true, location);
                const resolvedTypeSymbol = typeSymbol && typeSymbol.flags & 2097152 /* Alias */ ? resolveAlias(typeSymbol) : typeSymbol;
                if (!valueSymbol) {
                    isTypeOnly || (isTypeOnly = !!(typeSymbol && getTypeOnlyAliasDeclaration(typeSymbol, 788968 /* Type */)));
                }
                if (resolvedValueSymbol && resolvedValueSymbol === resolvedTypeSymbol) {
                    const globalPromiseSymbol = getGlobalPromiseConstructorSymbol(
                    /*reportErrors*/
                    false);
                    if (globalPromiseSymbol && resolvedValueSymbol === globalPromiseSymbol) {
                        return 9 /* Promise */;
                    }
                    const constructorType = getTypeOfSymbol(resolvedValueSymbol);
                    if (constructorType && isConstructorType(constructorType)) {
                        return isTypeOnly ? 10 /* TypeWithCallSignature */ : 1 /* TypeWithConstructSignatureAndValue */;
                    }
                }
                if (!resolvedTypeSymbol) {
                    return isTypeOnly ? 11 /* ObjectType */ : 0 /* Unknown */;
                }
                const type = getDeclaredTypeOfSymbol(resolvedTypeSymbol);
                if (isErrorType(type)) {
                    return isTypeOnly ? 11 /* ObjectType */ : 0 /* Unknown */;
                }
                else if (type.flags & 3 /* AnyOrUnknown */) {
                    return 11 /* ObjectType */;
                }
                else if (isTypeAssignableToKind(type, 16384 /* Void */ | 98304 /* Nullable */ | 131072 /* Never */)) {
                    return 2 /* VoidNullableOrNeverType */;
                }
                else if (isTypeAssignableToKind(type, 528 /* BooleanLike */)) {
                    return 6 /* BooleanType */;
                }
                else if (isTypeAssignableToKind(type, 296 /* NumberLike */)) {
                    return 3 /* NumberLikeType */;
                }
                else if (isTypeAssignableToKind(type, 2112 /* BigIntLike */)) {
                    return 4 /* BigIntLikeType */;
                }
                else if (isTypeAssignableToKind(type, 402653316 /* StringLike */)) {
                    return 5 /* StringLikeType */;
                }
                else if (isTupleType(type)) {
                    return 7 /* ArrayLikeType */;
                }
                else if (isTypeAssignableToKind(type, 12288 /* ESSymbolLike */)) {
                    return 8 /* ESSymbolType */;
                }
                else if (isFunctionType(type)) {
                    return 10 /* TypeWithCallSignature */;
                }
                else if (isArrayType(type)) {
                    return 7 /* ArrayLikeType */;
                }
                else {
                    return 11 /* ObjectType */;
                }
            }
            function createTypeOfDeclaration(declarationIn, enclosingDeclaration, flags, tracker, addUndefined) {
                const declaration = getParseTreeNode(declarationIn, isVariableLikeOrAccessor);
                if (!declaration) {
                    return factory.createToken(133 /* AnyKeyword */);
                }
                const symbol = getSymbolOfDeclaration(declaration);
                let type = symbol && !(symbol.flags & (2048 /* TypeLiteral */ | 131072 /* Signature */)) ? getWidenedLiteralType(getTypeOfSymbol(symbol)) : errorType;
                if (type.flags & 8192 /* UniqueESSymbol */ && type.symbol === symbol) {
                    flags |= 1048576 /* AllowUniqueESSymbolType */;
                }
                if (addUndefined) {
                    type = getOptionalType(type);
                }
                return nodeBuilder.typeToTypeNode(type, enclosingDeclaration, flags | 1024 /* MultilineObjectLiterals */, tracker);
            }
            function createReturnTypeOfSignatureDeclaration(signatureDeclarationIn, enclosingDeclaration, flags, tracker) {
                const signatureDeclaration = getParseTreeNode(signatureDeclarationIn, isFunctionLike);
                if (!signatureDeclaration) {
                    return factory.createToken(133 /* AnyKeyword */);
                }
                const signature = getSignatureFromDeclaration(signatureDeclaration);
                return nodeBuilder.typeToTypeNode(getReturnTypeOfSignature(signature), enclosingDeclaration, flags | 1024 /* MultilineObjectLiterals */, tracker);
            }
            function createTypeOfExpression(exprIn, enclosingDeclaration, flags, tracker) {
                const expr = getParseTreeNode(exprIn, isExpression);
                if (!expr) {
                    return factory.createToken(133 /* AnyKeyword */);
                }
                const type = getWidenedType(getRegularTypeOfExpression(expr));
                return nodeBuilder.typeToTypeNode(type, enclosingDeclaration, flags | 1024 /* MultilineObjectLiterals */, tracker);
            }
            function hasGlobalName(name) {
                return globals.has(escapeLeadingUnderscores(name));
            }
            function getReferencedValueSymbol(reference, startInDeclarationContainer) {
                const resolvedSymbol = getNodeLinks(reference).resolvedSymbol;
                if (resolvedSymbol) {
                    return resolvedSymbol;
                }
                let location = reference;
                if (startInDeclarationContainer) {
                    const parent2 = reference.parent;
                    if (isDeclaration(parent2) && reference === parent2.name) {
                        location = getDeclarationContainer(parent2);
                    }
                }
                return resolveName(location, reference.escapedText, 111551 /* Value */ | 1048576 /* ExportValue */ | 2097152 /* Alias */, 
                /*nameNotFoundMessage*/
                void 0, 
                /*nameArg*/
                void 0, 
                /*isUse*/
                true);
            }
            function getReferencedValueOrAliasSymbol(reference) {
                const resolvedSymbol = getNodeLinks(reference).resolvedSymbol;
                if (resolvedSymbol && resolvedSymbol !== unknownSymbol) {
                    return resolvedSymbol;
                }
                return resolveName(reference, reference.escapedText, 111551 /* Value */ | 1048576 /* ExportValue */ | 2097152 /* Alias */, 
                /*nameNotFoundMessage*/
                void 0, 
                /*nameArg*/
                void 0, 
                /*isUse*/
                true, 
                /*excludeGlobals*/
                void 0, 
                /*getSpellingSuggestions*/
                void 0);
            }
            function getReferencedValueDeclaration(referenceIn) {
                if (!isGeneratedIdentifier(referenceIn)) {
                    const reference = getParseTreeNode(referenceIn, isIdentifier);
                    if (reference) {
                        const symbol = getReferencedValueSymbol(reference);
                        if (symbol) {
                            return getExportSymbolOfValueSymbolIfExported(symbol).valueDeclaration;
                        }
                    }
                }
                return void 0;
            }
            function getReferencedValueDeclarations(referenceIn) {
                if (!isGeneratedIdentifier(referenceIn)) {
                    const reference = getParseTreeNode(referenceIn, isIdentifier);
                    if (reference) {
                        const symbol = getReferencedValueSymbol(reference);
                        if (symbol) {
                            return filter(getExportSymbolOfValueSymbolIfExported(symbol).declarations, (declaration) => {
                                switch (declaration.kind) {
                                    case 260 /* VariableDeclaration */:
                                    case 169 /* Parameter */:
                                    case 208 /* BindingElement */:
                                    case 172 /* PropertyDeclaration */:
                                    case 303 /* PropertyAssignment */:
                                    case 304 /* ShorthandPropertyAssignment */:
                                    case 306 /* EnumMember */:
                                    case 210 /* ObjectLiteralExpression */:
                                    case 262 /* FunctionDeclaration */:
                                    case 218 /* FunctionExpression */:
                                    case 219 /* ArrowFunction */:
                                    case 263 /* ClassDeclaration */:
                                    case 231 /* ClassExpression */:
                                    case 266 /* EnumDeclaration */:
                                    case 174 /* MethodDeclaration */:
                                    case 177 /* GetAccessor */:
                                    case 178 /* SetAccessor */:
                                    case 267 /* ModuleDeclaration */:
                                        return true;
                                }
                                return false;
                            });
                        }
                    }
                }
                return void 0;
            }
            function isLiteralConstDeclaration(node) {
                if (isDeclarationReadonly(node) || isVariableDeclaration(node) && isVarConstLike(node)) {
                    return isFreshLiteralType(getTypeOfSymbol(getSymbolOfDeclaration(node)));
                }
                return false;
            }
            function literalTypeToNode(type, enclosing, tracker) {
                const enumResult = type.flags & 1056 /* EnumLike */ ? nodeBuilder.symbolToExpression(type.symbol, 111551 /* Value */, enclosing, 
                /*flags*/
                void 0, tracker) : type === trueType ? factory.createTrue() : type === falseType && factory.createFalse();
                if (enumResult)
                    return enumResult;
                const literalValue = type.value;
                return typeof literalValue === "object" ? factory.createBigIntLiteral(literalValue) : typeof literalValue === "string" ? factory.createStringLiteral(literalValue) : literalValue < 0 ? factory.createPrefixUnaryExpression(41 /* MinusToken */, factory.createNumericLiteral(-literalValue)) : factory.createNumericLiteral(literalValue);
            }
            function createLiteralConstValue(node, tracker) {
                const type = getTypeOfSymbol(getSymbolOfDeclaration(node));
                return literalTypeToNode(type, node, tracker);
            }
            function getJsxFactoryEntity(location) {
                return location ? (getJsxNamespace(location), getSourceFileOfNode(location).localJsxFactory || _jsxFactoryEntity) : _jsxFactoryEntity;
            }
            function getJsxFragmentFactoryEntity(location) {
                if (location) {
                    const file = getSourceFileOfNode(location);
                    if (file) {
                        if (file.localJsxFragmentFactory) {
                            return file.localJsxFragmentFactory;
                        }
                        const jsxFragPragmas = file.pragmas.get("jsxfrag");
                        const jsxFragPragma = isArray(jsxFragPragmas) ? jsxFragPragmas[0] : jsxFragPragmas;
                        if (jsxFragPragma) {
                            file.localJsxFragmentFactory = parseIsolatedEntityName(jsxFragPragma.arguments.factory, languageVersion);
                            return file.localJsxFragmentFactory;
                        }
                    }
                }
                if (compilerOptions.jsxFragmentFactory) {
                    return parseIsolatedEntityName(compilerOptions.jsxFragmentFactory, languageVersion);
                }
            }
            function createResolver() {
                const resolvedTypeReferenceDirectives = host.getResolvedTypeReferenceDirectives();
                let fileToDirective;
                if (resolvedTypeReferenceDirectives) {
                    fileToDirective = /* @__PURE__ */ new Map();
                    resolvedTypeReferenceDirectives.forEach(({ resolvedTypeReferenceDirective }, key, mode) => {
                        if (!(resolvedTypeReferenceDirective == null ? void 0 : resolvedTypeReferenceDirective.resolvedFileName)) {
                            return;
                        }
                        const file = host.getSourceFile(resolvedTypeReferenceDirective.resolvedFileName);
                        if (file) {
                            addReferencedFilesToTypeDirective(file, key, mode);
                        }
                    });
                }
                return {
                    getReferencedExportContainer,
                    getReferencedImportDeclaration,
                    getReferencedDeclarationWithCollidingName,
                    isDeclarationWithCollidingName,
                    isValueAliasDeclaration: (nodeIn) => {
                        const node = getParseTreeNode(nodeIn);
                        return node && canCollectSymbolAliasAccessabilityData ? isValueAliasDeclaration(node) : true;
                    },
                    hasGlobalName,
                    isReferencedAliasDeclaration: (nodeIn, checkChildren) => {
                        const node = getParseTreeNode(nodeIn);
                        return node && canCollectSymbolAliasAccessabilityData ? isReferencedAliasDeclaration(node, checkChildren) : true;
                    },
                    getNodeCheckFlags: (nodeIn) => {
                        const node = getParseTreeNode(nodeIn);
                        return node ? getNodeCheckFlags(node) : 0;
                    },
                    isTopLevelValueImportEqualsWithEntityName,
                    isDeclarationVisible,
                    isImplementationOfOverload,
                    isRequiredInitializedParameter,
                    isOptionalUninitializedParameterProperty,
                    isExpandoFunctionDeclaration,
                    getPropertiesOfContainerFunction,
                    createTypeOfDeclaration,
                    createReturnTypeOfSignatureDeclaration,
                    createTypeOfExpression,
                    createLiteralConstValue,
                    isSymbolAccessible,
                    isEntityNameVisible,
                    getConstantValue: (nodeIn) => {
                        const node = getParseTreeNode(nodeIn, canHaveConstantValue);
                        return node ? getConstantValue2(node) : void 0;
                    },
                    collectLinkedAliases,
                    getReferencedValueDeclaration,
                    getReferencedValueDeclarations,
                    getTypeReferenceSerializationKind,
                    isOptionalParameter,
                    moduleExportsSomeValue,
                    isArgumentsLocalBinding,
                    getExternalModuleFileFromDeclaration: (nodeIn) => {
                        const node = getParseTreeNode(nodeIn, hasPossibleExternalModuleReference);
                        return node && getExternalModuleFileFromDeclaration(node);
                    },
                    getTypeReferenceDirectivesForEntityName,
                    getTypeReferenceDirectivesForSymbol,
                    isLiteralConstDeclaration,
                    isLateBound: (nodeIn) => {
                        const node = getParseTreeNode(nodeIn, isDeclaration);
                        const symbol = node && getSymbolOfDeclaration(node);
                        return !!(symbol && getCheckFlags(symbol) & 4096 /* Late */);
                    },
                    getJsxFactoryEntity,
                    getJsxFragmentFactoryEntity,
                    getAllAccessorDeclarations(accessor) {
                        accessor = getParseTreeNode(accessor, isGetOrSetAccessorDeclaration);
                        const otherKind = accessor.kind === 178 /* SetAccessor */ ? 177 /* GetAccessor */ : 178 /* SetAccessor */;
                        const otherAccessor = getDeclarationOfKind(getSymbolOfDeclaration(accessor), otherKind);
                        const firstAccessor = otherAccessor && otherAccessor.pos < accessor.pos ? otherAccessor : accessor;
                        const secondAccessor = otherAccessor && otherAccessor.pos < accessor.pos ? accessor : otherAccessor;
                        const setAccessor = accessor.kind === 178 /* SetAccessor */ ? accessor : otherAccessor;
                        const getAccessor = accessor.kind === 177 /* GetAccessor */ ? accessor : otherAccessor;
                        return {
                            firstAccessor,
                            secondAccessor,
                            setAccessor,
                            getAccessor
                        };
                    },
                    getSymbolOfExternalModuleSpecifier: (moduleName) => resolveExternalModuleNameWorker(moduleName, moduleName, 
                    /*moduleNotFoundError*/
                    void 0),
                    isBindingCapturedByNode: (node, decl) => {
                        const parseNode = getParseTreeNode(node);
                        const parseDecl = getParseTreeNode(decl);
                        return !!parseNode && !!parseDecl && (isVariableDeclaration(parseDecl) || isBindingElement(parseDecl)) && isBindingCapturedByNode(parseNode, parseDecl);
                    },
                    getDeclarationStatementsForSourceFile: (node, flags, tracker, bundled) => {
                        const n = getParseTreeNode(node);
                        Debug.assert(n && n.kind === 312 /* SourceFile */, "Non-sourcefile node passed into getDeclarationsForSourceFile");
                        const sym = getSymbolOfDeclaration(node);
                        if (!sym) {
                            return !node.locals ? [] : nodeBuilder.symbolTableToDeclarationStatements(node.locals, node, flags, tracker, bundled);
                        }
                        return !sym.exports ? [] : nodeBuilder.symbolTableToDeclarationStatements(sym.exports, node, flags, tracker, bundled);
                    },
                    isImportRequiredByAugmentation,
                    tryFindAmbientModule: (moduleReferenceExpression) => {
                        const node = getParseTreeNode(moduleReferenceExpression);
                        const moduleSpecifier = node && isStringLiteralLike(node) ? node.text : void 0;
                        return moduleSpecifier !== void 0 ? tryFindAmbientModule(moduleSpecifier, 
                        /*withAugmentations*/
                        true) : void 0;
                    }
                };
                function isImportRequiredByAugmentation(node) {
                    const file = getSourceFileOfNode(node);
                    if (!file.symbol)
                        return false;
                    const importTarget = getExternalModuleFileFromDeclaration(node);
                    if (!importTarget)
                        return false;
                    if (importTarget === file)
                        return false;
                    const exports = getExportsOfModule(file.symbol);
                    for (const s of arrayFrom(exports.values())) {
                        if (s.mergeId) {
                            const merged = getMergedSymbol(s);
                            if (merged.declarations) {
                                for (const d of merged.declarations) {
                                    const declFile = getSourceFileOfNode(d);
                                    if (declFile === importTarget) {
                                        return true;
                                    }
                                }
                            }
                        }
                    }
                    return false;
                }
                function isInHeritageClause(node) {
                    return node.parent && node.parent.kind === 233 /* ExpressionWithTypeArguments */ && node.parent.parent && node.parent.parent.kind === 298 /* HeritageClause */;
                }
                function getTypeReferenceDirectivesForEntityName(node) {
                    if (!fileToDirective) {
                        return void 0;
                    }
                    let meaning;
                    if (node.parent.kind === 167 /* ComputedPropertyName */) {
                        meaning = 111551 /* Value */ | 1048576 /* ExportValue */;
                    }
                    else {
                        meaning = 788968 /* Type */ | 1920 /* Namespace */;
                        if (node.kind === 80 /* Identifier */ && isInTypeQuery(node) || node.kind === 211 /* PropertyAccessExpression */ && !isInHeritageClause(node)) {
                            meaning = 111551 /* Value */ | 1048576 /* ExportValue */;
                        }
                    }
                    const symbol = resolveEntityName(node, meaning, 
                    /*ignoreErrors*/
                    true);
                    return symbol && symbol !== unknownSymbol ? getTypeReferenceDirectivesForSymbol(symbol, meaning) : void 0;
                }
                function getTypeReferenceDirectivesForSymbol(symbol, meaning) {
                    if (!fileToDirective || !isSymbolFromTypeDeclarationFile(symbol)) {
                        return void 0;
                    }
                    let typeReferenceDirectives;
                    for (const decl of symbol.declarations) {
                        if (decl.symbol && decl.symbol.flags & meaning) {
                            const file = getSourceFileOfNode(decl);
                            const typeReferenceDirective = fileToDirective.get(file.path);
                            if (typeReferenceDirective) {
                                (typeReferenceDirectives || (typeReferenceDirectives = [])).push(typeReferenceDirective);
                            }
                            else {
                                return void 0;
                            }
                        }
                    }
                    return typeReferenceDirectives;
                }
                function isSymbolFromTypeDeclarationFile(symbol) {
                    if (!symbol.declarations) {
                        return false;
                    }
                    let current = symbol;
                    while (true) {
                        const parent2 = getParentOfSymbol(current);
                        if (parent2) {
                            current = parent2;
                        }
                        else {
                            break;
                        }
                    }
                    if (current.valueDeclaration && current.valueDeclaration.kind === 312 /* SourceFile */ && current.flags & 512 /* ValueModule */) {
                        return false;
                    }
                    for (const decl of symbol.declarations) {
                        const file = getSourceFileOfNode(decl);
                        if (fileToDirective.has(file.path)) {
                            return true;
                        }
                    }
                    return false;
                }
                function addReferencedFilesToTypeDirective(file, key, mode) {
                    if (fileToDirective.has(file.path))
                        return;
                    fileToDirective.set(file.path, [key, mode]);
                    for (const { fileName } of file.referencedFiles) {
                        const resolvedFile = resolveTripleslashReference(fileName, file.fileName);
                        const referencedFile = host.getSourceFile(resolvedFile);
                        if (referencedFile) {
                            addReferencedFilesToTypeDirective(referencedFile, key, mode || file.impliedNodeFormat);
                        }
                    }
                }
            }
            function getExternalModuleFileFromDeclaration(declaration) {
                const specifier = declaration.kind === 267 /* ModuleDeclaration */ ? tryCast(declaration.name, isStringLiteral) : getExternalModuleName(declaration);
                const moduleSymbol = resolveExternalModuleNameWorker(specifier, specifier, 
                /*moduleNotFoundError*/
                void 0);
                if (!moduleSymbol) {
                    return void 0;
                }
                return getDeclarationOfKind(moduleSymbol, 312 /* SourceFile */);
            }
            function initializeTypeChecker() {
                for (const file of host.getSourceFiles()) {
                    bindSourceFile(file, compilerOptions);
                }
                amalgamatedDuplicates = /* @__PURE__ */ new Map();
                let augmentations;
                for (const file of host.getSourceFiles()) {
                    if (file.redirectInfo) {
                        continue;
                    }
                    if (!isExternalOrCommonJsModule(file)) {
                        const fileGlobalThisSymbol = file.locals.get("globalThis");
                        if (fileGlobalThisSymbol == null ? void 0 : fileGlobalThisSymbol.declarations) {
                            for (const declaration of fileGlobalThisSymbol.declarations) {
                                diagnostics.add(createDiagnosticForNode(declaration, Diagnostics.Declaration_name_conflicts_with_built_in_global_identifier_0, "globalThis"));
                            }
                        }
                        mergeSymbolTable(globals, file.locals);
                    }
                    if (file.jsGlobalAugmentations) {
                        mergeSymbolTable(globals, file.jsGlobalAugmentations);
                    }
                    if (file.patternAmbientModules && file.patternAmbientModules.length) {
                        patternAmbientModules = concatenate(patternAmbientModules, file.patternAmbientModules);
                    }
                    if (file.moduleAugmentations.length) {
                        (augmentations || (augmentations = [])).push(file.moduleAugmentations);
                    }
                    if (file.symbol && file.symbol.globalExports) {
                        const source = file.symbol.globalExports;
                        source.forEach((sourceSymbol, id) => {
                            if (!globals.has(id)) {
                                globals.set(id, sourceSymbol);
                            }
                        });
                    }
                }
                if (augmentations) {
                    for (const list of augmentations) {
                        for (const augmentation of list) {
                            if (!isGlobalScopeAugmentation(augmentation.parent))
                                continue;
                            mergeModuleAugmentation(augmentation);
                        }
                    }
                }
                addToSymbolTable(globals, builtinGlobals, Diagnostics.Declaration_name_conflicts_with_built_in_global_identifier_0);
                getSymbolLinks(undefinedSymbol).type = undefinedWideningType;
                getSymbolLinks(argumentsSymbol).type = getGlobalType("IArguments", 
                /*arity*/
                0, 
                /*reportErrors*/
                true);
                getSymbolLinks(unknownSymbol).type = errorType;
                getSymbolLinks(globalThisSymbol).type = createObjectType(16 /* Anonymous */, globalThisSymbol);
                globalArrayType = getGlobalType("Array", 
                /*arity*/
                1, 
                /*reportErrors*/
                true);
                globalObjectType = getGlobalType("Object", 
                /*arity*/
                0, 
                /*reportErrors*/
                true);
                globalFunctionType = getGlobalType("Function", 
                /*arity*/
                0, 
                /*reportErrors*/
                true);
                globalCallableFunctionType = strictBindCallApply && getGlobalType("CallableFunction", 
                /*arity*/
                0, 
                /*reportErrors*/
                true) || globalFunctionType;
                globalNewableFunctionType = strictBindCallApply && getGlobalType("NewableFunction", 
                /*arity*/
                0, 
                /*reportErrors*/
                true) || globalFunctionType;
                globalStringType = getGlobalType("String", 
                /*arity*/
                0, 
                /*reportErrors*/
                true);
                globalNumberType = getGlobalType("Number", 
                /*arity*/
                0, 
                /*reportErrors*/
                true);
                globalBooleanType = getGlobalType("Boolean", 
                /*arity*/
                0, 
                /*reportErrors*/
                true);
                globalRegExpType = getGlobalType("RegExp", 
                /*arity*/
                0, 
                /*reportErrors*/
                true);
                anyArrayType = createArrayType(anyType);
                autoArrayType = createArrayType(autoType);
                if (autoArrayType === emptyObjectType) {
                    autoArrayType = createAnonymousType(
                    /*symbol*/
                    void 0, emptySymbols, emptyArray, emptyArray, emptyArray);
                }
                globalReadonlyArrayType = getGlobalTypeOrUndefined("ReadonlyArray", 
                /*arity*/
                1) || globalArrayType;
                anyReadonlyArrayType = globalReadonlyArrayType ? createTypeFromGenericGlobalType(globalReadonlyArrayType, [anyType]) : anyArrayType;
                globalThisType = getGlobalTypeOrUndefined("ThisType", 
                /*arity*/
                1);
                if (augmentations) {
                    for (const list of augmentations) {
                        for (const augmentation of list) {
                            if (isGlobalScopeAugmentation(augmentation.parent))
                                continue;
                            mergeModuleAugmentation(augmentation);
                        }
                    }
                }
                amalgamatedDuplicates.forEach(({ firstFile, secondFile, conflictingSymbols }) => {
                    if (conflictingSymbols.size < 8) {
                        conflictingSymbols.forEach(({ isBlockScoped, firstFileLocations, secondFileLocations }, symbolName2) => {
                            const message = isBlockScoped ? Diagnostics.Cannot_redeclare_block_scoped_variable_0 : Diagnostics.Duplicate_identifier_0;
                            for (const node of firstFileLocations) {
                                addDuplicateDeclarationError(node, message, symbolName2, secondFileLocations);
                            }
                            for (const node of secondFileLocations) {
                                addDuplicateDeclarationError(node, message, symbolName2, firstFileLocations);
                            }
                        });
                    }
                    else {
                        const list = arrayFrom(conflictingSymbols.keys()).join(", ");
                        diagnostics.add(addRelatedInfo(createDiagnosticForNode(firstFile, Diagnostics.Definitions_of_the_following_identifiers_conflict_with_those_in_another_file_Colon_0, list), createDiagnosticForNode(secondFile, Diagnostics.Conflicts_are_in_this_file)));
                        diagnostics.add(addRelatedInfo(createDiagnosticForNode(secondFile, Diagnostics.Definitions_of_the_following_identifiers_conflict_with_those_in_another_file_Colon_0, list), createDiagnosticForNode(firstFile, Diagnostics.Conflicts_are_in_this_file)));
                    }
                });
                amalgamatedDuplicates = void 0;
            }
            function checkExternalEmitHelpers(location, helpers) {
                if ((requestedExternalEmitHelpers & helpers) !== helpers && compilerOptions.importHelpers) {
                    const sourceFile = getSourceFileOfNode(location);
                    if (isEffectiveExternalModule(sourceFile, compilerOptions) && !(location.flags & 33554432 /* Ambient */)) {
                        const helpersModule = resolveHelpersModule(sourceFile, location);
                        if (helpersModule !== unknownSymbol) {
                            const uncheckedHelpers = helpers & ~requestedExternalEmitHelpers;
                            for (let helper = 1 /* FirstEmitHelper */; helper <= 33554432 /* LastEmitHelper */; helper <<= 1) {
                                if (uncheckedHelpers & helper) {
                                    for (const name of getHelperNames(helper)) {
                                        if (requestedExternalEmitHelperNames.has(name))
                                            continue;
                                        requestedExternalEmitHelperNames.add(name);
                                        const symbol = resolveSymbol(getSymbol2(getExportsOfModule(helpersModule), escapeLeadingUnderscores(name), 111551 /* Value */));
                                        if (!symbol) {
                                            error2(location, Diagnostics.This_syntax_requires_an_imported_helper_named_1_which_does_not_exist_in_0_Consider_upgrading_your_version_of_0, externalHelpersModuleNameText, name);
                                        }
                                        else if (helper & 524288 /* ClassPrivateFieldGet */) {
                                            if (!some(getSignaturesOfSymbol(symbol), (signature) => getParameterCount(signature) > 3)) {
                                                error2(location, Diagnostics.This_syntax_requires_an_imported_helper_named_1_with_2_parameters_which_is_not_compatible_with_the_one_in_0_Consider_upgrading_your_version_of_0, externalHelpersModuleNameText, name, 4);
                                            }
                                        }
                                        else if (helper & 1048576 /* ClassPrivateFieldSet */) {
                                            if (!some(getSignaturesOfSymbol(symbol), (signature) => getParameterCount(signature) > 4)) {
                                                error2(location, Diagnostics.This_syntax_requires_an_imported_helper_named_1_with_2_parameters_which_is_not_compatible_with_the_one_in_0_Consider_upgrading_your_version_of_0, externalHelpersModuleNameText, name, 5);
                                            }
                                        }
                                        else if (helper & 1024 /* SpreadArray */) {
                                            if (!some(getSignaturesOfSymbol(symbol), (signature) => getParameterCount(signature) > 2)) {
                                                error2(location, Diagnostics.This_syntax_requires_an_imported_helper_named_1_with_2_parameters_which_is_not_compatible_with_the_one_in_0_Consider_upgrading_your_version_of_0, externalHelpersModuleNameText, name, 3);
                                            }
                                        }
                                    }
                                }
                            }
                        }
                        requestedExternalEmitHelpers |= helpers;
                    }
                }
            }
            function getHelperNames(helper) {
                switch (helper) {
                    case 1 /* Extends */:
                        return ["__extends"];
                    case 2 /* Assign */:
                        return ["__assign"];
                    case 4 /* Rest */:
                        return ["__rest"];
                    case 8 /* Decorate */:
                        return legacyDecorators ? ["__decorate"] : ["__esDecorate", "__runInitializers"];
                    case 16 /* Metadata */:
                        return ["__metadata"];
                    case 32 /* Param */:
                        return ["__param"];
                    case 64 /* Awaiter */:
                        return ["__awaiter"];
                    case 128 /* Generator */:
                        return ["__generator"];
                    case 256 /* Values */:
                        return ["__values"];
                    case 512 /* Read */:
                        return ["__read"];
                    case 1024 /* SpreadArray */:
                        return ["__spreadArray"];
                    case 2048 /* Await */:
                        return ["__await"];
                    case 4096 /* AsyncGenerator */:
                        return ["__asyncGenerator"];
                    case 8192 /* AsyncDelegator */:
                        return ["__asyncDelegator"];
                    case 16384 /* AsyncValues */:
                        return ["__asyncValues"];
                    case 32768 /* ExportStar */:
                        return ["__exportStar"];
                    case 65536 /* ImportStar */:
                        return ["__importStar"];
                    case 131072 /* ImportDefault */:
                        return ["__importDefault"];
                    case 262144 /* MakeTemplateObject */:
                        return ["__makeTemplateObject"];
                    case 524288 /* ClassPrivateFieldGet */:
                        return ["__classPrivateFieldGet"];
                    case 1048576 /* ClassPrivateFieldSet */:
                        return ["__classPrivateFieldSet"];
                    case 2097152 /* ClassPrivateFieldIn */:
                        return ["__classPrivateFieldIn"];
                    case 4194304 /* CreateBinding */:
                        return ["__createBinding"];
                    case 8388608 /* SetFunctionName */:
                        return ["__setFunctionName"];
                    case 16777216 /* PropKey */:
                        return ["__propKey"];
                    case 33554432 /* AddDisposableResourceAndDisposeResources */:
                        return ["__addDisposableResource", "__disposeResources"];
                    default:
                        return Debug.fail("Unrecognized helper");
                }
            }
            function resolveHelpersModule(node, errorNode) {
                if (!externalHelpersModule) {
                    externalHelpersModule = resolveExternalModule(node, externalHelpersModuleNameText, Diagnostics.This_syntax_requires_an_imported_helper_but_module_0_cannot_be_found, errorNode) || unknownSymbol;
                }
                return externalHelpersModule;
            }
            function checkGrammarModifiers(node) {
                var _a;
                const quickResult = reportObviousDecoratorErrors(node) || reportObviousModifierErrors(node);
                if (quickResult !== void 0) {
                    return quickResult;
                }
                if (isParameter(node) && parameterIsThisKeyword(node)) {
                    return grammarErrorOnFirstToken(node, Diagnostics.Neither_decorators_nor_modifiers_may_be_applied_to_this_parameters);
                }
                const blockScopeKind = isVariableStatement(node) ? node.declarationList.flags & 7 /* BlockScoped */ : 0 /* None */;
                let lastStatic, lastDeclare, lastAsync, lastOverride, firstDecorator;
                let flags = 0 /* None */;
                let sawExportBeforeDecorators = false;
                let hasLeadingDecorators = false;
                for (const modifier of node.modifiers) {
                    if (isDecorator(modifier)) {
                        if (!nodeCanBeDecorated(legacyDecorators, node, node.parent, node.parent.parent)) {
                            if (node.kind === 174 /* MethodDeclaration */ && !nodeIsPresent(node.body)) {
                                return grammarErrorOnFirstToken(node, Diagnostics.A_decorator_can_only_decorate_a_method_implementation_not_an_overload);
                            }
                            else {
                                return grammarErrorOnFirstToken(node, Diagnostics.Decorators_are_not_valid_here);
                            }
                        }
                        else if (legacyDecorators && (node.kind === 177 /* GetAccessor */ || node.kind === 178 /* SetAccessor */)) {
                            const accessors = getAllAccessorDeclarations(node.parent.members, node);
                            if (hasDecorators(accessors.firstAccessor) && node === accessors.secondAccessor) {
                                return grammarErrorOnFirstToken(node, Diagnostics.Decorators_cannot_be_applied_to_multiple_get_Slashset_accessors_of_the_same_name);
                            }
                        }
                        if (flags & ~(2080 /* ExportDefault */ | 32768 /* Decorator */)) {
                            return grammarErrorOnNode(modifier, Diagnostics.Decorators_are_not_valid_here);
                        }
                        if (hasLeadingDecorators && flags & 98303 /* Modifier */) {
                            Debug.assertIsDefined(firstDecorator);
                            const sourceFile = getSourceFileOfNode(modifier);
                            if (!hasParseDiagnostics(sourceFile)) {
                                addRelatedInfo(error2(modifier, Diagnostics.Decorators_may_not_appear_after_export_or_export_default_if_they_also_appear_before_export), createDiagnosticForNode(firstDecorator, Diagnostics.Decorator_used_before_export_here));
                                return true;
                            }
                            return false;
                        }
                        flags |= 32768 /* Decorator */;
                        if (!(flags & 98303 /* Modifier */)) {
                            hasLeadingDecorators = true;
                        }
                        else if (flags & 32 /* Export */) {
                            sawExportBeforeDecorators = true;
                        }
                        firstDecorator ?? (firstDecorator = modifier);
                    }
                    else {
                        if (modifier.kind !== 148 /* ReadonlyKeyword */) {
                            if (node.kind === 171 /* PropertySignature */ || node.kind === 173 /* MethodSignature */) {
                                return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_appear_on_a_type_member, tokenToString(modifier.kind));
                            }
                            if (node.kind === 181 /* IndexSignature */ && (modifier.kind !== 126 /* StaticKeyword */ || !isClassLike(node.parent))) {
                                return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_appear_on_an_index_signature, tokenToString(modifier.kind));
                            }
                        }
                        if (modifier.kind !== 103 /* InKeyword */ && modifier.kind !== 147 /* OutKeyword */ && modifier.kind !== 87 /* ConstKeyword */) {
                            if (node.kind === 168 /* TypeParameter */) {
                                return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_appear_on_a_type_parameter, tokenToString(modifier.kind));
                            }
                        }
                        switch (modifier.kind) {
                            case 87 /* ConstKeyword */: {
                                if (node.kind !== 266 /* EnumDeclaration */ && node.kind !== 168 /* TypeParameter */) {
                                    return grammarErrorOnNode(node, Diagnostics.A_class_member_cannot_have_the_0_keyword, tokenToString(87 /* ConstKeyword */));
                                }
                                const parent2 = isJSDocTemplateTag(node.parent) && getEffectiveJSDocHost(node.parent) || node.parent;
                                if (node.kind === 168 /* TypeParameter */ && !(isFunctionLikeDeclaration(parent2) || isClassLike(parent2) || isFunctionTypeNode(parent2) || isConstructorTypeNode(parent2) || isCallSignatureDeclaration(parent2) || isConstructSignatureDeclaration(parent2) || isMethodSignature(parent2))) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_can_only_appear_on_a_type_parameter_of_a_function_method_or_class, tokenToString(modifier.kind));
                                }
                                break;
                            }
                            case 164 /* OverrideKeyword */:
                                if (flags & 16 /* Override */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_already_seen, "override");
                                }
                                else if (flags & 128 /* Ambient */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_be_used_with_1_modifier, "override", "declare");
                                }
                                else if (flags & 8 /* Readonly */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, "override", "readonly");
                                }
                                else if (flags & 512 /* Accessor */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, "override", "accessor");
                                }
                                else if (flags & 1024 /* Async */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, "override", "async");
                                }
                                flags |= 16 /* Override */;
                                lastOverride = modifier;
                                break;
                            case 125 /* PublicKeyword */:
                            case 124 /* ProtectedKeyword */:
                            case 123 /* PrivateKeyword */:
                                const text = visibilityToString(modifierToFlag(modifier.kind));
                                if (flags & 7 /* AccessibilityModifier */) {
                                    return grammarErrorOnNode(modifier, Diagnostics.Accessibility_modifier_already_seen);
                                }
                                else if (flags & 16 /* Override */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, text, "override");
                                }
                                else if (flags & 256 /* Static */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, text, "static");
                                }
                                else if (flags & 512 /* Accessor */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, text, "accessor");
                                }
                                else if (flags & 8 /* Readonly */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, text, "readonly");
                                }
                                else if (flags & 1024 /* Async */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, text, "async");
                                }
                                else if (node.parent.kind === 268 /* ModuleBlock */ || node.parent.kind === 312 /* SourceFile */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_appear_on_a_module_or_namespace_element, text);
                                }
                                else if (flags & 64 /* Abstract */) {
                                    if (modifier.kind === 123 /* PrivateKeyword */) {
                                        return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_be_used_with_1_modifier, text, "abstract");
                                    }
                                    else {
                                        return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, text, "abstract");
                                    }
                                }
                                else if (isPrivateIdentifierClassElementDeclaration(node)) {
                                    return grammarErrorOnNode(modifier, Diagnostics.An_accessibility_modifier_cannot_be_used_with_a_private_identifier);
                                }
                                flags |= modifierToFlag(modifier.kind);
                                break;
                            case 126 /* StaticKeyword */:
                                if (flags & 256 /* Static */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_already_seen, "static");
                                }
                                else if (flags & 8 /* Readonly */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, "static", "readonly");
                                }
                                else if (flags & 1024 /* Async */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, "static", "async");
                                }
                                else if (flags & 512 /* Accessor */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, "static", "accessor");
                                }
                                else if (node.parent.kind === 268 /* ModuleBlock */ || node.parent.kind === 312 /* SourceFile */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_appear_on_a_module_or_namespace_element, "static");
                                }
                                else if (node.kind === 169 /* Parameter */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_appear_on_a_parameter, "static");
                                }
                                else if (flags & 64 /* Abstract */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_be_used_with_1_modifier, "static", "abstract");
                                }
                                else if (flags & 16 /* Override */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, "static", "override");
                                }
                                flags |= 256 /* Static */;
                                lastStatic = modifier;
                                break;
                            case 129 /* AccessorKeyword */:
                                if (flags & 512 /* Accessor */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_already_seen, "accessor");
                                }
                                else if (flags & 8 /* Readonly */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_be_used_with_1_modifier, "accessor", "readonly");
                                }
                                else if (flags & 128 /* Ambient */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_be_used_with_1_modifier, "accessor", "declare");
                                }
                                else if (node.kind !== 172 /* PropertyDeclaration */) {
                                    return grammarErrorOnNode(modifier, Diagnostics.accessor_modifier_can_only_appear_on_a_property_declaration);
                                }
                                flags |= 512 /* Accessor */;
                                break;
                            case 148 /* ReadonlyKeyword */:
                                if (flags & 8 /* Readonly */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_already_seen, "readonly");
                                }
                                else if (node.kind !== 172 /* PropertyDeclaration */ && node.kind !== 171 /* PropertySignature */ && node.kind !== 181 /* IndexSignature */ && node.kind !== 169 /* Parameter */) {
                                    return grammarErrorOnNode(modifier, Diagnostics.readonly_modifier_can_only_appear_on_a_property_declaration_or_index_signature);
                                }
                                else if (flags & 512 /* Accessor */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_be_used_with_1_modifier, "readonly", "accessor");
                                }
                                flags |= 8 /* Readonly */;
                                break;
                            case 95 /* ExportKeyword */:
                                if (compilerOptions.verbatimModuleSyntax && !(node.flags & 33554432 /* Ambient */) && node.kind !== 265 /* TypeAliasDeclaration */ && node.kind !== 264 /* InterfaceDeclaration */ && // ModuleDeclaration needs to be checked that it is uninstantiated later
                                    node.kind !== 267 /* ModuleDeclaration */ && node.parent.kind === 312 /* SourceFile */ && (moduleKind === 1 /* CommonJS */ || getSourceFileOfNode(node).impliedNodeFormat === 1 /* CommonJS */)) {
                                    return grammarErrorOnNode(modifier, Diagnostics.A_top_level_export_modifier_cannot_be_used_on_value_declarations_in_a_CommonJS_module_when_verbatimModuleSyntax_is_enabled);
                                }
                                if (flags & 32 /* Export */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_already_seen, "export");
                                }
                                else if (flags & 128 /* Ambient */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, "export", "declare");
                                }
                                else if (flags & 64 /* Abstract */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, "export", "abstract");
                                }
                                else if (flags & 1024 /* Async */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, "export", "async");
                                }
                                else if (isClassLike(node.parent)) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_appear_on_class_elements_of_this_kind, "export");
                                }
                                else if (node.kind === 169 /* Parameter */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_appear_on_a_parameter, "export");
                                }
                                else if (blockScopeKind === 4 /* Using */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_appear_on_a_using_declaration, "export");
                                }
                                else if (blockScopeKind === 6 /* AwaitUsing */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_appear_on_an_await_using_declaration, "export");
                                }
                                flags |= 32 /* Export */;
                                break;
                            case 90 /* DefaultKeyword */:
                                const container = node.parent.kind === 312 /* SourceFile */ ? node.parent : node.parent.parent;
                                if (container.kind === 267 /* ModuleDeclaration */ && !isAmbientModule(container)) {
                                    return grammarErrorOnNode(modifier, Diagnostics.A_default_export_can_only_be_used_in_an_ECMAScript_style_module);
                                }
                                else if (blockScopeKind === 4 /* Using */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_appear_on_a_using_declaration, "default");
                                }
                                else if (blockScopeKind === 6 /* AwaitUsing */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_appear_on_an_await_using_declaration, "default");
                                }
                                else if (!(flags & 32 /* Export */)) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, "export", "default");
                                }
                                else if (sawExportBeforeDecorators) {
                                    return grammarErrorOnNode(firstDecorator, Diagnostics.Decorators_are_not_valid_here);
                                }
                                flags |= 2048 /* Default */;
                                break;
                            case 138 /* DeclareKeyword */:
                                if (flags & 128 /* Ambient */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_already_seen, "declare");
                                }
                                else if (flags & 1024 /* Async */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_be_used_in_an_ambient_context, "async");
                                }
                                else if (flags & 16 /* Override */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_be_used_in_an_ambient_context, "override");
                                }
                                else if (isClassLike(node.parent) && !isPropertyDeclaration(node)) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_appear_on_class_elements_of_this_kind, "declare");
                                }
                                else if (node.kind === 169 /* Parameter */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_appear_on_a_parameter, "declare");
                                }
                                else if (blockScopeKind === 4 /* Using */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_appear_on_a_using_declaration, "declare");
                                }
                                else if (blockScopeKind === 6 /* AwaitUsing */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_appear_on_an_await_using_declaration, "declare");
                                }
                                else if (node.parent.flags & 33554432 /* Ambient */ && node.parent.kind === 268 /* ModuleBlock */) {
                                    return grammarErrorOnNode(modifier, Diagnostics.A_declare_modifier_cannot_be_used_in_an_already_ambient_context);
                                }
                                else if (isPrivateIdentifierClassElementDeclaration(node)) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_be_used_with_a_private_identifier, "declare");
                                }
                                else if (flags & 512 /* Accessor */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_be_used_with_1_modifier, "declare", "accessor");
                                }
                                flags |= 128 /* Ambient */;
                                lastDeclare = modifier;
                                break;
                            case 128 /* AbstractKeyword */:
                                if (flags & 64 /* Abstract */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_already_seen, "abstract");
                                }
                                if (node.kind !== 263 /* ClassDeclaration */ && node.kind !== 185 /* ConstructorType */) {
                                    if (node.kind !== 174 /* MethodDeclaration */ && node.kind !== 172 /* PropertyDeclaration */ && node.kind !== 177 /* GetAccessor */ && node.kind !== 178 /* SetAccessor */) {
                                        return grammarErrorOnNode(modifier, Diagnostics.abstract_modifier_can_only_appear_on_a_class_method_or_property_declaration);
                                    }
                                    if (!(node.parent.kind === 263 /* ClassDeclaration */ && hasSyntacticModifier(node.parent, 64 /* Abstract */))) {
                                        const message = node.kind === 172 /* PropertyDeclaration */ ? Diagnostics.Abstract_properties_can_only_appear_within_an_abstract_class : Diagnostics.Abstract_methods_can_only_appear_within_an_abstract_class;
                                        return grammarErrorOnNode(modifier, message);
                                    }
                                    if (flags & 256 /* Static */) {
                                        return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_be_used_with_1_modifier, "static", "abstract");
                                    }
                                    if (flags & 2 /* Private */) {
                                        return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_be_used_with_1_modifier, "private", "abstract");
                                    }
                                    if (flags & 1024 /* Async */ && lastAsync) {
                                        return grammarErrorOnNode(lastAsync, Diagnostics._0_modifier_cannot_be_used_with_1_modifier, "async", "abstract");
                                    }
                                    if (flags & 16 /* Override */) {
                                        return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, "abstract", "override");
                                    }
                                    if (flags & 512 /* Accessor */) {
                                        return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, "abstract", "accessor");
                                    }
                                }
                                if (isNamedDeclaration(node) && node.name.kind === 81 /* PrivateIdentifier */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_be_used_with_a_private_identifier, "abstract");
                                }
                                flags |= 64 /* Abstract */;
                                break;
                            case 134 /* AsyncKeyword */:
                                if (flags & 1024 /* Async */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_already_seen, "async");
                                }
                                else if (flags & 128 /* Ambient */ || node.parent.flags & 33554432 /* Ambient */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_be_used_in_an_ambient_context, "async");
                                }
                                else if (node.kind === 169 /* Parameter */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_appear_on_a_parameter, "async");
                                }
                                if (flags & 64 /* Abstract */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_cannot_be_used_with_1_modifier, "async", "abstract");
                                }
                                flags |= 1024 /* Async */;
                                lastAsync = modifier;
                                break;
                            case 103 /* InKeyword */:
                            case 147 /* OutKeyword */: {
                                const inOutFlag = modifier.kind === 103 /* InKeyword */ ? 8192 /* In */ : 16384 /* Out */;
                                const inOutText = modifier.kind === 103 /* InKeyword */ ? "in" : "out";
                                const parent2 = isJSDocTemplateTag(node.parent) && (getEffectiveJSDocHost(node.parent) || find((_a = getJSDocRoot(node.parent)) == null ? void 0 : _a.tags, isJSDocTypedefTag)) || node.parent;
                                if (node.kind !== 168 /* TypeParameter */ || parent2 && !(isInterfaceDeclaration(parent2) || isClassLike(parent2) || isTypeAliasDeclaration(parent2) || isJSDocTypedefTag(parent2))) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_can_only_appear_on_a_type_parameter_of_a_class_interface_or_type_alias, inOutText);
                                }
                                if (flags & inOutFlag) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_already_seen, inOutText);
                                }
                                if (inOutFlag & 8192 /* In */ && flags & 16384 /* Out */) {
                                    return grammarErrorOnNode(modifier, Diagnostics._0_modifier_must_precede_1_modifier, "in", "out");
                                }
                                flags |= inOutFlag;
                                break;
                            }
                        }
                    }
                }
                if (node.kind === 176 /* Constructor */) {
                    if (flags & 256 /* Static */) {
                        return grammarErrorOnNode(lastStatic, Diagnostics._0_modifier_cannot_appear_on_a_constructor_declaration, "static");
                    }
                    if (flags & 16 /* Override */) {
                        return grammarErrorOnNode(lastOverride, Diagnostics._0_modifier_cannot_appear_on_a_constructor_declaration, "override");
                    }
                    if (flags & 1024 /* Async */) {
                        return grammarErrorOnNode(lastAsync, Diagnostics._0_modifier_cannot_appear_on_a_constructor_declaration, "async");
                    }
                    return false;
                }
                else if ((node.kind === 272 /* ImportDeclaration */ || node.kind === 271 /* ImportEqualsDeclaration */) && flags & 128 /* Ambient */) {
                    return grammarErrorOnNode(lastDeclare, Diagnostics.A_0_modifier_cannot_be_used_with_an_import_declaration, "declare");
                }
                else if (node.kind === 169 /* Parameter */ && flags & 31 /* ParameterPropertyModifier */ && isBindingPattern(node.name)) {
                    return grammarErrorOnNode(node, Diagnostics.A_parameter_property_may_not_be_declared_using_a_binding_pattern);
                }
                else if (node.kind === 169 /* Parameter */ && flags & 31 /* ParameterPropertyModifier */ && node.dotDotDotToken) {
                    return grammarErrorOnNode(node, Diagnostics.A_parameter_property_cannot_be_declared_using_a_rest_parameter);
                }
                if (flags & 1024 /* Async */) {
                    return checkGrammarAsyncModifier(node, lastAsync);
                }
                return false;
            }
            function reportObviousModifierErrors(node) {
                if (!node.modifiers)
                    return false;
                const modifier = findFirstIllegalModifier(node);
                return modifier && grammarErrorOnFirstToken(modifier, Diagnostics.Modifiers_cannot_appear_here);
            }
            function findFirstModifierExcept(node, allowedModifier) {
                const modifier = find(node.modifiers, isModifier);
                return modifier && modifier.kind !== allowedModifier ? modifier : void 0;
            }
            function findFirstIllegalModifier(node) {
                switch (node.kind) {
                    case 177 /* GetAccessor */:
                    case 178 /* SetAccessor */:
                    case 176 /* Constructor */:
                    case 172 /* PropertyDeclaration */:
                    case 171 /* PropertySignature */:
                    case 174 /* MethodDeclaration */:
                    case 173 /* MethodSignature */:
                    case 181 /* IndexSignature */:
                    case 267 /* ModuleDeclaration */:
                    case 272 /* ImportDeclaration */:
                    case 271 /* ImportEqualsDeclaration */:
                    case 278 /* ExportDeclaration */:
                    case 277 /* ExportAssignment */:
                    case 218 /* FunctionExpression */:
                    case 219 /* ArrowFunction */:
                    case 169 /* Parameter */:
                    case 168 /* TypeParameter */:
                        return void 0;
                    case 175 /* ClassStaticBlockDeclaration */:
                    case 303 /* PropertyAssignment */:
                    case 304 /* ShorthandPropertyAssignment */:
                    case 270 /* NamespaceExportDeclaration */:
                    case 282 /* MissingDeclaration */:
                        return find(node.modifiers, isModifier);
                    default:
                        if (node.parent.kind === 268 /* ModuleBlock */ || node.parent.kind === 312 /* SourceFile */) {
                            return void 0;
                        }
                        switch (node.kind) {
                            case 262 /* FunctionDeclaration */:
                                return findFirstModifierExcept(node, 134 /* AsyncKeyword */);
                            case 263 /* ClassDeclaration */:
                            case 185 /* ConstructorType */:
                                return findFirstModifierExcept(node, 128 /* AbstractKeyword */);
                            case 231 /* ClassExpression */:
                            case 264 /* InterfaceDeclaration */:
                            case 265 /* TypeAliasDeclaration */:
                                return find(node.modifiers, isModifier);
                            case 243 /* VariableStatement */:
                                return node.declarationList.flags & 4 /* Using */ ? findFirstModifierExcept(node, 135 /* AwaitKeyword */) : find(node.modifiers, isModifier);
                            case 266 /* EnumDeclaration */:
                                return findFirstModifierExcept(node, 87 /* ConstKeyword */);
                            default:
                                Debug.assertNever(node);
                        }
                }
            }
            function reportObviousDecoratorErrors(node) {
                const decorator = findFirstIllegalDecorator(node);
                return decorator && grammarErrorOnFirstToken(decorator, Diagnostics.Decorators_are_not_valid_here);
            }
            function findFirstIllegalDecorator(node) {
                return canHaveIllegalDecorators(node) ? find(node.modifiers, isDecorator) : void 0;
            }
            function checkGrammarAsyncModifier(node, asyncModifier) {
                switch (node.kind) {
                    case 174 /* MethodDeclaration */:
                    case 262 /* FunctionDeclaration */:
                    case 218 /* FunctionExpression */:
                    case 219 /* ArrowFunction */:
                        return false;
                }
                return grammarErrorOnNode(asyncModifier, Diagnostics._0_modifier_cannot_be_used_here, "async");
            }
            function checkGrammarForDisallowedTrailingComma(list, diag2 = Diagnostics.Trailing_comma_not_allowed) {
                if (list && list.hasTrailingComma) {
                    return grammarErrorAtPos(list[0], list.end - ",".length, ",".length, diag2);
                }
                return false;
            }
            function checkGrammarTypeParameterList(typeParameters, file) {
                if (typeParameters && typeParameters.length === 0) {
                    const start = typeParameters.pos - "<".length;
                    const end = skipTrivia(file.text, typeParameters.end) + ">".length;
                    return grammarErrorAtPos(file, start, end - start, Diagnostics.Type_parameter_list_cannot_be_empty);
                }
                return false;
            }
            function checkGrammarParameterList(parameters) {
                let seenOptionalParameter = false;
                const parameterCount = parameters.length;
                for (let i = 0; i < parameterCount; i++) {
                    const parameter = parameters[i];
                    if (parameter.dotDotDotToken) {
                        if (i !== parameterCount - 1) {
                            return grammarErrorOnNode(parameter.dotDotDotToken, Diagnostics.A_rest_parameter_must_be_last_in_a_parameter_list);
                        }
                        if (!(parameter.flags & 33554432 /* Ambient */)) {
                            checkGrammarForDisallowedTrailingComma(parameters, Diagnostics.A_rest_parameter_or_binding_pattern_may_not_have_a_trailing_comma);
                        }
                        if (parameter.questionToken) {
                            return grammarErrorOnNode(parameter.questionToken, Diagnostics.A_rest_parameter_cannot_be_optional);
                        }
                        if (parameter.initializer) {
                            return grammarErrorOnNode(parameter.name, Diagnostics.A_rest_parameter_cannot_have_an_initializer);
                        }
                    }
                    else if (isOptionalParameter(parameter)) {
                        seenOptionalParameter = true;
                        if (parameter.questionToken && parameter.initializer) {
                            return grammarErrorOnNode(parameter.name, Diagnostics.Parameter_cannot_have_question_mark_and_initializer);
                        }
                    }
                    else if (seenOptionalParameter && !parameter.initializer) {
                        return grammarErrorOnNode(parameter.name, Diagnostics.A_required_parameter_cannot_follow_an_optional_parameter);
                    }
                }
            }
            function getNonSimpleParameters(parameters) {
                return filter(parameters, (parameter) => !!parameter.initializer || isBindingPattern(parameter.name) || isRestParameter(parameter));
            }
            function checkGrammarForUseStrictSimpleParameterList(node) {
                if (languageVersion >= 3 /* ES2016 */) {
                    const useStrictDirective = node.body && isBlock(node.body) && findUseStrictPrologue(node.body.statements);
                    if (useStrictDirective) {
                        const nonSimpleParameters = getNonSimpleParameters(node.parameters);
                        if (length(nonSimpleParameters)) {
                            forEach(nonSimpleParameters, (parameter) => {
                                addRelatedInfo(error2(parameter, Diagnostics.This_parameter_is_not_allowed_with_use_strict_directive), createDiagnosticForNode(useStrictDirective, Diagnostics.use_strict_directive_used_here));
                            });
                            const diagnostics2 = nonSimpleParameters.map((parameter, index) => index === 0 ? createDiagnosticForNode(parameter, Diagnostics.Non_simple_parameter_declared_here) : createDiagnosticForNode(parameter, Diagnostics.and_here));
                            addRelatedInfo(error2(useStrictDirective, Diagnostics.use_strict_directive_cannot_be_used_with_non_simple_parameter_list), ...diagnostics2);
                            return true;
                        }
                    }
                }
                return false;
            }
            function checkGrammarFunctionLikeDeclaration(node) {
                const file = getSourceFileOfNode(node);
                return checkGrammarModifiers(node) || checkGrammarTypeParameterList(node.typeParameters, file) || checkGrammarParameterList(node.parameters) || checkGrammarArrowFunction(node, file) || isFunctionLikeDeclaration(node) && checkGrammarForUseStrictSimpleParameterList(node);
            }
            function checkGrammarClassLikeDeclaration(node) {
                const file = getSourceFileOfNode(node);
                return checkGrammarClassDeclarationHeritageClauses(node) || checkGrammarTypeParameterList(node.typeParameters, file);
            }
            function checkGrammarArrowFunction(node, file) {
                if (!isArrowFunction(node)) {
                    return false;
                }
                if (node.typeParameters && !(length(node.typeParameters) > 1 || node.typeParameters.hasTrailingComma || node.typeParameters[0].constraint)) {
                    if (file && fileExtensionIsOneOf(file.fileName, [".mts" /* Mts */, ".cts" /* Cts */])) {
                        grammarErrorOnNode(node.typeParameters[0], Diagnostics.This_syntax_is_reserved_in_files_with_the_mts_or_cts_extension_Add_a_trailing_comma_or_explicit_constraint);
                    }
                }
                const { equalsGreaterThanToken } = node;
                const startLine = getLineAndCharacterOfPosition(file, equalsGreaterThanToken.pos).line;
                const endLine = getLineAndCharacterOfPosition(file, equalsGreaterThanToken.end).line;
                return startLine !== endLine && grammarErrorOnNode(equalsGreaterThanToken, Diagnostics.Line_terminator_not_permitted_before_arrow);
            }
            function checkGrammarIndexSignatureParameters(node) {
                const parameter = node.parameters[0];
                if (node.parameters.length !== 1) {
                    if (parameter) {
                        return grammarErrorOnNode(parameter.name, Diagnostics.An_index_signature_must_have_exactly_one_parameter);
                    }
                    else {
                        return grammarErrorOnNode(node, Diagnostics.An_index_signature_must_have_exactly_one_parameter);
                    }
                }
                checkGrammarForDisallowedTrailingComma(node.parameters, Diagnostics.An_index_signature_cannot_have_a_trailing_comma);
                if (parameter.dotDotDotToken) {
                    return grammarErrorOnNode(parameter.dotDotDotToken, Diagnostics.An_index_signature_cannot_have_a_rest_parameter);
                }
                if (hasEffectiveModifiers(parameter)) {
                    return grammarErrorOnNode(parameter.name, Diagnostics.An_index_signature_parameter_cannot_have_an_accessibility_modifier);
                }
                if (parameter.questionToken) {
                    return grammarErrorOnNode(parameter.questionToken, Diagnostics.An_index_signature_parameter_cannot_have_a_question_mark);
                }
                if (parameter.initializer) {
                    return grammarErrorOnNode(parameter.name, Diagnostics.An_index_signature_parameter_cannot_have_an_initializer);
                }
                if (!parameter.type) {
                    return grammarErrorOnNode(parameter.name, Diagnostics.An_index_signature_parameter_must_have_a_type_annotation);
                }
                const type = getTypeFromTypeNode(parameter.type);
                if (someType(type, (t) => !!(t.flags & 8576 /* StringOrNumberLiteralOrUnique */)) || isGenericType(type)) {
                    return grammarErrorOnNode(parameter.name, Diagnostics.An_index_signature_parameter_type_cannot_be_a_literal_type_or_generic_type_Consider_using_a_mapped_object_type_instead);
                }
                if (!everyType(type, isValidIndexKeyType)) {
                    return grammarErrorOnNode(parameter.name, Diagnostics.An_index_signature_parameter_type_must_be_string_number_symbol_or_a_template_literal_type);
                }
                if (!node.type) {
                    return grammarErrorOnNode(node, Diagnostics.An_index_signature_must_have_a_type_annotation);
                }
                return false;
            }
            function checkGrammarIndexSignature(node) {
                return checkGrammarModifiers(node) || checkGrammarIndexSignatureParameters(node);
            }
            function checkGrammarForAtLeastOneTypeArgument(node, typeArguments) {
                if (typeArguments && typeArguments.length === 0) {
                    const sourceFile = getSourceFileOfNode(node);
                    const start = typeArguments.pos - "<".length;
                    const end = skipTrivia(sourceFile.text, typeArguments.end) + ">".length;
                    return grammarErrorAtPos(sourceFile, start, end - start, Diagnostics.Type_argument_list_cannot_be_empty);
                }
                return false;
            }
            function checkGrammarTypeArguments(node, typeArguments) {
                return checkGrammarForDisallowedTrailingComma(typeArguments) || checkGrammarForAtLeastOneTypeArgument(node, typeArguments);
            }
            function checkGrammarTaggedTemplateChain(node) {
                if (node.questionDotToken || node.flags & 64 /* OptionalChain */) {
                    return grammarErrorOnNode(node.template, Diagnostics.Tagged_template_expressions_are_not_permitted_in_an_optional_chain);
                }
                return false;
            }
            function checkGrammarHeritageClause(node) {
                const types = node.types;
                if (checkGrammarForDisallowedTrailingComma(types)) {
                    return true;
                }
                if (types && types.length === 0) {
                    const listType = tokenToString(node.token);
                    return grammarErrorAtPos(node, types.pos, 0, Diagnostics._0_list_cannot_be_empty, listType);
                }
                return some(types, checkGrammarExpressionWithTypeArguments);
            }
            function checkGrammarExpressionWithTypeArguments(node) {
                if (isExpressionWithTypeArguments(node) && isImportKeyword(node.expression) && node.typeArguments) {
                    return grammarErrorOnNode(node, Diagnostics.This_use_of_import_is_invalid_import_calls_can_be_written_but_they_must_have_parentheses_and_cannot_have_type_arguments);
                }
                return checkGrammarTypeArguments(node, node.typeArguments);
            }
            function checkGrammarClassDeclarationHeritageClauses(node) {
                let seenExtendsClause = false;
                let seenImplementsClause = false;
                if (!checkGrammarModifiers(node) && node.heritageClauses) {
                    for (const heritageClause of node.heritageClauses) {
                        if (heritageClause.token === 96 /* ExtendsKeyword */) {
                            if (seenExtendsClause) {
                                return grammarErrorOnFirstToken(heritageClause, Diagnostics.extends_clause_already_seen);
                            }
                            if (seenImplementsClause) {
                                return grammarErrorOnFirstToken(heritageClause, Diagnostics.extends_clause_must_precede_implements_clause);
                            }
                            if (heritageClause.types.length > 1) {
                                return grammarErrorOnFirstToken(heritageClause.types[1], Diagnostics.Classes_can_only_extend_a_single_class);
                            }
                            seenExtendsClause = true;
                        }
                        else {
                            Debug.assert(heritageClause.token === 119 /* ImplementsKeyword */);
                            if (seenImplementsClause) {
                                return grammarErrorOnFirstToken(heritageClause, Diagnostics.implements_clause_already_seen);
                            }
                            seenImplementsClause = true;
                        }
                        checkGrammarHeritageClause(heritageClause);
                    }
                }
            }
            function checkGrammarInterfaceDeclaration(node) {
                let seenExtendsClause = false;
                if (node.heritageClauses) {
                    for (const heritageClause of node.heritageClauses) {
                        if (heritageClause.token === 96 /* ExtendsKeyword */) {
                            if (seenExtendsClause) {
                                return grammarErrorOnFirstToken(heritageClause, Diagnostics.extends_clause_already_seen);
                            }
                            seenExtendsClause = true;
                        }
                        else {
                            Debug.assert(heritageClause.token === 119 /* ImplementsKeyword */);
                            return grammarErrorOnFirstToken(heritageClause, Diagnostics.Interface_declaration_cannot_have_implements_clause);
                        }
                        checkGrammarHeritageClause(heritageClause);
                    }
                }
                return false;
            }
            function checkGrammarComputedPropertyName(node) {
                if (node.kind !== 167 /* ComputedPropertyName */) {
                    return false;
                }
                const computedPropertyName = node;
                if (computedPropertyName.expression.kind === 226 /* BinaryExpression */ && computedPropertyName.expression.operatorToken.kind === 28 /* CommaToken */) {
                    return grammarErrorOnNode(computedPropertyName.expression, Diagnostics.A_comma_expression_is_not_allowed_in_a_computed_property_name);
                }
                return false;
            }
            function checkGrammarForGenerator(node) {
                if (node.asteriskToken) {
                    Debug.assert(node.kind === 262 /* FunctionDeclaration */ || node.kind === 218 /* FunctionExpression */ || node.kind === 174 /* MethodDeclaration */);
                    if (node.flags & 33554432 /* Ambient */) {
                        return grammarErrorOnNode(node.asteriskToken, Diagnostics.Generators_are_not_allowed_in_an_ambient_context);
                    }
                    if (!node.body) {
                        return grammarErrorOnNode(node.asteriskToken, Diagnostics.An_overload_signature_cannot_be_declared_as_a_generator);
                    }
                }
            }
            function checkGrammarForInvalidQuestionMark(questionToken, message) {
                return !!questionToken && grammarErrorOnNode(questionToken, message);
            }
            function checkGrammarForInvalidExclamationToken(exclamationToken, message) {
                return !!exclamationToken && grammarErrorOnNode(exclamationToken, message);
            }
            function checkGrammarObjectLiteralExpression(node, inDestructuring) {
                const seen = /* @__PURE__ */ new Map();
                for (const prop of node.properties) {
                    if (prop.kind === 305 /* SpreadAssignment */) {
                        if (inDestructuring) {
                            const expression = skipParentheses(prop.expression);
                            if (isArrayLiteralExpression(expression) || isObjectLiteralExpression(expression)) {
                                return grammarErrorOnNode(prop.expression, Diagnostics.A_rest_element_cannot_contain_a_binding_pattern);
                            }
                        }
                        continue;
                    }
                    const name = prop.name;
                    if (name.kind === 167 /* ComputedPropertyName */) {
                        checkGrammarComputedPropertyName(name);
                    }
                    if (prop.kind === 304 /* ShorthandPropertyAssignment */ && !inDestructuring && prop.objectAssignmentInitializer) {
                        grammarErrorOnNode(prop.equalsToken, Diagnostics.Did_you_mean_to_use_a_Colon_An_can_only_follow_a_property_name_when_the_containing_object_literal_is_part_of_a_destructuring_pattern);
                    }
                    if (name.kind === 81 /* PrivateIdentifier */) {
                        grammarErrorOnNode(name, Diagnostics.Private_identifiers_are_not_allowed_outside_class_bodies);
                    }
                    if (canHaveModifiers(prop) && prop.modifiers) {
                        for (const mod of prop.modifiers) {
                            if (isModifier(mod) && (mod.kind !== 134 /* AsyncKeyword */ || prop.kind !== 174 /* MethodDeclaration */)) {
                                grammarErrorOnNode(mod, Diagnostics._0_modifier_cannot_be_used_here, getTextOfNode(mod));
                            }
                        }
                    }
                    else if (canHaveIllegalModifiers(prop) && prop.modifiers) {
                        for (const mod of prop.modifiers) {
                            if (isModifier(mod)) {
                                grammarErrorOnNode(mod, Diagnostics._0_modifier_cannot_be_used_here, getTextOfNode(mod));
                            }
                        }
                    }
                    let currentKind;
                    switch (prop.kind) {
                        case 304 /* ShorthandPropertyAssignment */:
                        case 303 /* PropertyAssignment */:
                            checkGrammarForInvalidExclamationToken(prop.exclamationToken, Diagnostics.A_definite_assignment_assertion_is_not_permitted_in_this_context);
                            checkGrammarForInvalidQuestionMark(prop.questionToken, Diagnostics.An_object_member_cannot_be_declared_optional);
                            if (name.kind === 9 /* NumericLiteral */) {
                                checkGrammarNumericLiteral(name);
                            }
                            currentKind = 4 /* PropertyAssignment */;
                            break;
                        case 174 /* MethodDeclaration */:
                            currentKind = 8 /* Method */;
                            break;
                        case 177 /* GetAccessor */:
                            currentKind = 1 /* GetAccessor */;
                            break;
                        case 178 /* SetAccessor */:
                            currentKind = 2 /* SetAccessor */;
                            break;
                        default:
                            Debug.assertNever(prop, "Unexpected syntax kind:" + prop.kind);
                    }
                    if (!inDestructuring) {
                        const effectiveName = getEffectivePropertyNameForPropertyNameNode(name);
                        if (effectiveName === void 0) {
                            continue;
                        }
                        const existingKind = seen.get(effectiveName);
                        if (!existingKind) {
                            seen.set(effectiveName, currentKind);
                        }
                        else {
                            if (currentKind & 8 /* Method */ && existingKind & 8 /* Method */) {
                                grammarErrorOnNode(name, Diagnostics.Duplicate_identifier_0, getTextOfNode(name));
                            }
                            else if (currentKind & 4 /* PropertyAssignment */ && existingKind & 4 /* PropertyAssignment */) {
                                grammarErrorOnNode(name, Diagnostics.An_object_literal_cannot_have_multiple_properties_with_the_same_name, getTextOfNode(name));
                            }
                            else if (currentKind & 3 /* GetOrSetAccessor */ && existingKind & 3 /* GetOrSetAccessor */) {
                                if (existingKind !== 3 /* GetOrSetAccessor */ && currentKind !== existingKind) {
                                    seen.set(effectiveName, currentKind | existingKind);
                                }
                                else {
                                    return grammarErrorOnNode(name, Diagnostics.An_object_literal_cannot_have_multiple_get_Slashset_accessors_with_the_same_name);
                                }
                            }
                            else {
                                return grammarErrorOnNode(name, Diagnostics.An_object_literal_cannot_have_property_and_accessor_with_the_same_name);
                            }
                        }
                    }
                }
            }
            function checkGrammarJsxElement(node) {
                checkGrammarJsxName(node.tagName);
                checkGrammarTypeArguments(node, node.typeArguments);
                const seen = /* @__PURE__ */ new Map();
                for (const attr of node.attributes.properties) {
                    if (attr.kind === 293 /* JsxSpreadAttribute */) {
                        continue;
                    }
                    const { name, initializer } = attr;
                    const escapedText = getEscapedTextOfJsxAttributeName(name);
                    if (!seen.get(escapedText)) {
                        seen.set(escapedText, true);
                    }
                    else {
                        return grammarErrorOnNode(name, Diagnostics.JSX_elements_cannot_have_multiple_attributes_with_the_same_name);
                    }
                    if (initializer && initializer.kind === 294 /* JsxExpression */ && !initializer.expression) {
                        return grammarErrorOnNode(initializer, Diagnostics.JSX_attributes_must_only_be_assigned_a_non_empty_expression);
                    }
                }
            }
            function checkGrammarJsxName(node) {
                if (isPropertyAccessExpression(node) && isJsxNamespacedName(node.expression)) {
                    return grammarErrorOnNode(node.expression, Diagnostics.JSX_property_access_expressions_cannot_include_JSX_namespace_names);
                }
                if (isJsxNamespacedName(node) && getJSXTransformEnabled(compilerOptions) && !isIntrinsicJsxName(node.namespace.escapedText)) {
                    return grammarErrorOnNode(node, Diagnostics.React_components_cannot_include_JSX_namespace_names);
                }
            }
            function checkGrammarJsxExpression(node) {
                if (node.expression && isCommaSequence(node.expression)) {
                    return grammarErrorOnNode(node.expression, Diagnostics.JSX_expressions_may_not_use_the_comma_operator_Did_you_mean_to_write_an_array);
                }
            }
            function checkGrammarForInOrForOfStatement(forInOrOfStatement) {
                if (checkGrammarStatementInAmbientContext(forInOrOfStatement)) {
                    return true;
                }
                if (forInOrOfStatement.kind === 250 /* ForOfStatement */ && forInOrOfStatement.awaitModifier) {
                    if (!(forInOrOfStatement.flags & 65536 /* AwaitContext */)) {
                        const sourceFile = getSourceFileOfNode(forInOrOfStatement);
                        if (isInTopLevelContext(forInOrOfStatement)) {
                            if (!hasParseDiagnostics(sourceFile)) {
                                if (!isEffectiveExternalModule(sourceFile, compilerOptions)) {
                                    diagnostics.add(createDiagnosticForNode(forInOrOfStatement.awaitModifier, Diagnostics.for_await_loops_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_has_no_imports_or_exports_Consider_adding_an_empty_export_to_make_this_file_a_module));
                                }
                                switch (moduleKind) {
                                    case 100 /* Node16 */:
                                    case 199 /* NodeNext */:
                                        if (sourceFile.impliedNodeFormat === 1 /* CommonJS */) {
                                            diagnostics.add(createDiagnosticForNode(forInOrOfStatement.awaitModifier, Diagnostics.The_current_file_is_a_CommonJS_module_and_cannot_use_await_at_the_top_level));
                                            break;
                                        }
                                    case 7 /* ES2022 */:
                                    case 99 /* ESNext */:
                                    case 4 /* System */:
                                        if (languageVersion >= 4 /* ES2017 */) {
                                            break;
                                        }
                                    default:
                                        diagnostics.add(createDiagnosticForNode(forInOrOfStatement.awaitModifier, Diagnostics.Top_level_for_await_loops_are_only_allowed_when_the_module_option_is_set_to_es2022_esnext_system_node16_nodenext_or_preserve_and_the_target_option_is_set_to_es2017_or_higher));
                                        break;
                                }
                            }
                        }
                        else {
                            if (!hasParseDiagnostics(sourceFile)) {
                                const diagnostic = createDiagnosticForNode(forInOrOfStatement.awaitModifier, Diagnostics.for_await_loops_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules);
                                const func = getContainingFunction(forInOrOfStatement);
                                if (func && func.kind !== 176 /* Constructor */) {
                                    Debug.assert((getFunctionFlags(func) & 2 /* Async */) === 0, "Enclosing function should never be an async function.");
                                    const relatedInfo = createDiagnosticForNode(func, Diagnostics.Did_you_mean_to_mark_this_function_as_async);
                                    addRelatedInfo(diagnostic, relatedInfo);
                                }
                                diagnostics.add(diagnostic);
                                return true;
                            }
                        }
                        return false;
                    }
                }
                if (isForOfStatement(forInOrOfStatement) && !(forInOrOfStatement.flags & 65536 /* AwaitContext */) && isIdentifier(forInOrOfStatement.initializer) && forInOrOfStatement.initializer.escapedText === "async") {
                    grammarErrorOnNode(forInOrOfStatement.initializer, Diagnostics.The_left_hand_side_of_a_for_of_statement_may_not_be_async);
                    return false;
                }
                if (forInOrOfStatement.initializer.kind === 261 /* VariableDeclarationList */) {
                    const variableList = forInOrOfStatement.initializer;
                    if (!checkGrammarVariableDeclarationList(variableList)) {
                        const declarations = variableList.declarations;
                        if (!declarations.length) {
                            return false;
                        }
                        if (declarations.length > 1) {
                            const diagnostic = forInOrOfStatement.kind === 249 /* ForInStatement */ ? Diagnostics.Only_a_single_variable_declaration_is_allowed_in_a_for_in_statement : Diagnostics.Only_a_single_variable_declaration_is_allowed_in_a_for_of_statement;
                            return grammarErrorOnFirstToken(variableList.declarations[1], diagnostic);
                        }
                        const firstDeclaration = declarations[0];
                        if (firstDeclaration.initializer) {
                            const diagnostic = forInOrOfStatement.kind === 249 /* ForInStatement */ ? Diagnostics.The_variable_declaration_of_a_for_in_statement_cannot_have_an_initializer : Diagnostics.The_variable_declaration_of_a_for_of_statement_cannot_have_an_initializer;
                            return grammarErrorOnNode(firstDeclaration.name, diagnostic);
                        }
                        if (firstDeclaration.type) {
                            const diagnostic = forInOrOfStatement.kind === 249 /* ForInStatement */ ? Diagnostics.The_left_hand_side_of_a_for_in_statement_cannot_use_a_type_annotation : Diagnostics.The_left_hand_side_of_a_for_of_statement_cannot_use_a_type_annotation;
                            return grammarErrorOnNode(firstDeclaration, diagnostic);
                        }
                    }
                }
                return false;
            }
            function checkGrammarAccessor(accessor) {
                if (!(accessor.flags & 33554432 /* Ambient */) && accessor.parent.kind !== 187 /* TypeLiteral */ && accessor.parent.kind !== 264 /* InterfaceDeclaration */) {
                    if (languageVersion < 1 /* ES5 */) {
                        return grammarErrorOnNode(accessor.name, Diagnostics.Accessors_are_only_available_when_targeting_ECMAScript_5_and_higher);
                    }
                    if (languageVersion < 2 /* ES2015 */ && isPrivateIdentifier(accessor.name)) {
                        return grammarErrorOnNode(accessor.name, Diagnostics.Private_identifiers_are_only_available_when_targeting_ECMAScript_2015_and_higher);
                    }
                    if (accessor.body === void 0 && !hasSyntacticModifier(accessor, 64 /* Abstract */)) {
                        return grammarErrorAtPos(accessor, accessor.end - 1, ";".length, Diagnostics._0_expected, "{");
                    }
                }
                if (accessor.body) {
                    if (hasSyntacticModifier(accessor, 64 /* Abstract */)) {
                        return grammarErrorOnNode(accessor, Diagnostics.An_abstract_accessor_cannot_have_an_implementation);
                    }
                    if (accessor.parent.kind === 187 /* TypeLiteral */ || accessor.parent.kind === 264 /* InterfaceDeclaration */) {
                        return grammarErrorOnNode(accessor.body, Diagnostics.An_implementation_cannot_be_declared_in_ambient_contexts);
                    }
                }
                if (accessor.typeParameters) {
                    return grammarErrorOnNode(accessor.name, Diagnostics.An_accessor_cannot_have_type_parameters);
                }
                if (!doesAccessorHaveCorrectParameterCount(accessor)) {
                    return grammarErrorOnNode(accessor.name, accessor.kind === 177 /* GetAccessor */ ? Diagnostics.A_get_accessor_cannot_have_parameters : Diagnostics.A_set_accessor_must_have_exactly_one_parameter);
                }
                if (accessor.kind === 178 /* SetAccessor */) {
                    if (accessor.type) {
                        return grammarErrorOnNode(accessor.name, Diagnostics.A_set_accessor_cannot_have_a_return_type_annotation);
                    }
                    const parameter = Debug.checkDefined(getSetAccessorValueParameter(accessor), "Return value does not match parameter count assertion.");
                    if (parameter.dotDotDotToken) {
                        return grammarErrorOnNode(parameter.dotDotDotToken, Diagnostics.A_set_accessor_cannot_have_rest_parameter);
                    }
                    if (parameter.questionToken) {
                        return grammarErrorOnNode(parameter.questionToken, Diagnostics.A_set_accessor_cannot_have_an_optional_parameter);
                    }
                    if (parameter.initializer) {
                        return grammarErrorOnNode(accessor.name, Diagnostics.A_set_accessor_parameter_cannot_have_an_initializer);
                    }
                }
                return false;
            }
            function doesAccessorHaveCorrectParameterCount(accessor) {
                return getAccessorThisParameter(accessor) || accessor.parameters.length === (accessor.kind === 177 /* GetAccessor */ ? 0 : 1);
            }
            function getAccessorThisParameter(accessor) {
                if (accessor.parameters.length === (accessor.kind === 177 /* GetAccessor */ ? 1 : 2)) {
                    return getThisParameter(accessor);
                }
            }
            function checkGrammarTypeOperatorNode(node) {
                if (node.operator === 158 /* UniqueKeyword */) {
                    if (node.type.kind !== 155 /* SymbolKeyword */) {
                        return grammarErrorOnNode(node.type, Diagnostics._0_expected, tokenToString(155 /* SymbolKeyword */));
                    }
                    let parent2 = walkUpParenthesizedTypes(node.parent);
                    if (isInJSFile(parent2) && isJSDocTypeExpression(parent2)) {
                        const host2 = getJSDocHost(parent2);
                        if (host2) {
                            parent2 = getSingleVariableOfVariableStatement(host2) || host2;
                        }
                    }
                    switch (parent2.kind) {
                        case 260 /* VariableDeclaration */:
                            const decl = parent2;
                            if (decl.name.kind !== 80 /* Identifier */) {
                                return grammarErrorOnNode(node, Diagnostics.unique_symbol_types_may_not_be_used_on_a_variable_declaration_with_a_binding_name);
                            }
                            if (!isVariableDeclarationInVariableStatement(decl)) {
                                return grammarErrorOnNode(node, Diagnostics.unique_symbol_types_are_only_allowed_on_variables_in_a_variable_statement);
                            }
                            if (!(decl.parent.flags & 2 /* Const */)) {
                                return grammarErrorOnNode(parent2.name, Diagnostics.A_variable_whose_type_is_a_unique_symbol_type_must_be_const);
                            }
                            break;
                        case 172 /* PropertyDeclaration */:
                            if (!isStatic(parent2) || !hasEffectiveReadonlyModifier(parent2)) {
                                return grammarErrorOnNode(parent2.name, Diagnostics.A_property_of_a_class_whose_type_is_a_unique_symbol_type_must_be_both_static_and_readonly);
                            }
                            break;
                        case 171 /* PropertySignature */:
                            if (!hasSyntacticModifier(parent2, 8 /* Readonly */)) {
                                return grammarErrorOnNode(parent2.name, Diagnostics.A_property_of_an_interface_or_type_literal_whose_type_is_a_unique_symbol_type_must_be_readonly);
                            }
                            break;
                        default:
                            return grammarErrorOnNode(node, Diagnostics.unique_symbol_types_are_not_allowed_here);
                    }
                }
                else if (node.operator === 148 /* ReadonlyKeyword */) {
                    if (node.type.kind !== 188 /* ArrayType */ && node.type.kind !== 189 /* TupleType */) {
                        return grammarErrorOnFirstToken(node, Diagnostics.readonly_type_modifier_is_only_permitted_on_array_and_tuple_literal_types, tokenToString(155 /* SymbolKeyword */));
                    }
                }
            }
            function checkGrammarForInvalidDynamicName(node, message) {
                if (isNonBindableDynamicName(node)) {
                    return grammarErrorOnNode(node, message);
                }
            }
            function checkGrammarMethod(node) {
                if (checkGrammarFunctionLikeDeclaration(node)) {
                    return true;
                }
                if (node.kind === 174 /* MethodDeclaration */) {
                    if (node.parent.kind === 210 /* ObjectLiteralExpression */) {
                        if (node.modifiers && !(node.modifiers.length === 1 && first(node.modifiers).kind === 134 /* AsyncKeyword */)) {
                            return grammarErrorOnFirstToken(node, Diagnostics.Modifiers_cannot_appear_here);
                        }
                        else if (checkGrammarForInvalidQuestionMark(node.questionToken, Diagnostics.An_object_member_cannot_be_declared_optional)) {
                            return true;
                        }
                        else if (checkGrammarForInvalidExclamationToken(node.exclamationToken, Diagnostics.A_definite_assignment_assertion_is_not_permitted_in_this_context)) {
                            return true;
                        }
                        else if (node.body === void 0) {
                            return grammarErrorAtPos(node, node.end - 1, ";".length, Diagnostics._0_expected, "{");
                        }
                    }
                    if (checkGrammarForGenerator(node)) {
                        return true;
                    }
                }
                if (isClassLike(node.parent)) {
                    if (languageVersion < 2 /* ES2015 */ && isPrivateIdentifier(node.name)) {
                        return grammarErrorOnNode(node.name, Diagnostics.Private_identifiers_are_only_available_when_targeting_ECMAScript_2015_and_higher);
                    }
                    if (node.flags & 33554432 /* Ambient */) {
                        return checkGrammarForInvalidDynamicName(node.name, Diagnostics.A_computed_property_name_in_an_ambient_context_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type);
                    }
                    else if (node.kind === 174 /* MethodDeclaration */ && !node.body) {
                        return checkGrammarForInvalidDynamicName(node.name, Diagnostics.A_computed_property_name_in_a_method_overload_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type);
                    }
                }
                else if (node.parent.kind === 264 /* InterfaceDeclaration */) {
                    return checkGrammarForInvalidDynamicName(node.name, Diagnostics.A_computed_property_name_in_an_interface_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type);
                }
                else if (node.parent.kind === 187 /* TypeLiteral */) {
                    return checkGrammarForInvalidDynamicName(node.name, Diagnostics.A_computed_property_name_in_a_type_literal_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type);
                }
            }
            function checkGrammarBreakOrContinueStatement(node) {
                let current = node;
                while (current) {
                    if (isFunctionLikeOrClassStaticBlockDeclaration(current)) {
                        return grammarErrorOnNode(node, Diagnostics.Jump_target_cannot_cross_function_boundary);
                    }
                    switch (current.kind) {
                        case 256 /* LabeledStatement */:
                            if (node.label && current.label.escapedText === node.label.escapedText) {
                                const isMisplacedContinueLabel = node.kind === 251 /* ContinueStatement */ && !isIterationStatement(current.statement, 
                                /*lookInLabeledStatements*/
                                true);
                                if (isMisplacedContinueLabel) {
                                    return grammarErrorOnNode(node, Diagnostics.A_continue_statement_can_only_jump_to_a_label_of_an_enclosing_iteration_statement);
                                }
                                return false;
                            }
                            break;
                        case 255 /* SwitchStatement */:
                            if (node.kind === 252 /* BreakStatement */ && !node.label) {
                                return false;
                            }
                            break;
                        default:
                            if (isIterationStatement(current, 
                            /*lookInLabeledStatements*/
                            false) && !node.label) {
                                return false;
                            }
                            break;
                    }
                    current = current.parent;
                }
                if (node.label) {
                    const message = node.kind === 252 /* BreakStatement */ ? Diagnostics.A_break_statement_can_only_jump_to_a_label_of_an_enclosing_statement : Diagnostics.A_continue_statement_can_only_jump_to_a_label_of_an_enclosing_iteration_statement;
                    return grammarErrorOnNode(node, message);
                }
                else {
                    const message = node.kind === 252 /* BreakStatement */ ? Diagnostics.A_break_statement_can_only_be_used_within_an_enclosing_iteration_or_switch_statement : Diagnostics.A_continue_statement_can_only_be_used_within_an_enclosing_iteration_statement;
                    return grammarErrorOnNode(node, message);
                }
            }
            function checkGrammarBindingElement(node) {
                if (node.dotDotDotToken) {
                    const elements = node.parent.elements;
                    if (node !== last(elements)) {
                        return grammarErrorOnNode(node, Diagnostics.A_rest_element_must_be_last_in_a_destructuring_pattern);
                    }
                    checkGrammarForDisallowedTrailingComma(elements, Diagnostics.A_rest_parameter_or_binding_pattern_may_not_have_a_trailing_comma);
                    if (node.propertyName) {
                        return grammarErrorOnNode(node.name, Diagnostics.A_rest_element_cannot_have_a_property_name);
                    }
                }
                if (node.dotDotDotToken && node.initializer) {
                    return grammarErrorAtPos(node, node.initializer.pos - 1, 1, Diagnostics.A_rest_element_cannot_have_an_initializer);
                }
            }
            function isStringOrNumberLiteralExpression(expr) {
                return isStringOrNumericLiteralLike(expr) || expr.kind === 224 /* PrefixUnaryExpression */ && expr.operator === 41 /* MinusToken */ && expr.operand.kind === 9 /* NumericLiteral */;
            }
            function isBigIntLiteralExpression(expr) {
                return expr.kind === 10 /* BigIntLiteral */ || expr.kind === 224 /* PrefixUnaryExpression */ && expr.operator === 41 /* MinusToken */ && expr.operand.kind === 10 /* BigIntLiteral */;
            }
            function isSimpleLiteralEnumReference(expr) {
                if ((isPropertyAccessExpression(expr) || isElementAccessExpression(expr) && isStringOrNumberLiteralExpression(expr.argumentExpression)) && isEntityNameExpression(expr.expression)) {
                    return !!(checkExpressionCached(expr).flags & 1056 /* EnumLike */);
                }
            }
            function checkAmbientInitializer(node) {
                const initializer = node.initializer;
                if (initializer) {
                    const isInvalidInitializer = !(isStringOrNumberLiteralExpression(initializer) || isSimpleLiteralEnumReference(initializer) || initializer.kind === 112 /* TrueKeyword */ || initializer.kind === 97 /* FalseKeyword */ || isBigIntLiteralExpression(initializer));
                    const isConstOrReadonly = isDeclarationReadonly(node) || isVariableDeclaration(node) && isVarConstLike(node);
                    if (isConstOrReadonly && !node.type) {
                        if (isInvalidInitializer) {
                            return grammarErrorOnNode(initializer, Diagnostics.A_const_initializer_in_an_ambient_context_must_be_a_string_or_numeric_literal_or_literal_enum_reference);
                        }
                    }
                    else {
                        return grammarErrorOnNode(initializer, Diagnostics.Initializers_are_not_allowed_in_ambient_contexts);
                    }
                }
            }
            function checkGrammarVariableDeclaration(node) {
                const nodeFlags = getCombinedNodeFlagsCached(node);
                const blockScopeKind = nodeFlags & 7 /* BlockScoped */;
                if (isBindingPattern(node.name)) {
                    switch (blockScopeKind) {
                        case 6 /* AwaitUsing */:
                            return grammarErrorOnNode(node, Diagnostics._0_declarations_may_not_have_binding_patterns, "await using");
                        case 4 /* Using */:
                            return grammarErrorOnNode(node, Diagnostics._0_declarations_may_not_have_binding_patterns, "using");
                    }
                }
                if (node.parent.parent.kind !== 249 /* ForInStatement */ && node.parent.parent.kind !== 250 /* ForOfStatement */) {
                    if (nodeFlags & 33554432 /* Ambient */) {
                        checkAmbientInitializer(node);
                    }
                    else if (!node.initializer) {
                        if (isBindingPattern(node.name) && !isBindingPattern(node.parent)) {
                            return grammarErrorOnNode(node, Diagnostics.A_destructuring_declaration_must_have_an_initializer);
                        }
                        switch (blockScopeKind) {
                            case 6 /* AwaitUsing */:
                                return grammarErrorOnNode(node, Diagnostics._0_declarations_must_be_initialized, "await using");
                            case 4 /* Using */:
                                return grammarErrorOnNode(node, Diagnostics._0_declarations_must_be_initialized, "using");
                            case 2 /* Const */:
                                return grammarErrorOnNode(node, Diagnostics._0_declarations_must_be_initialized, "const");
                        }
                    }
                }
                if (node.exclamationToken && (node.parent.parent.kind !== 243 /* VariableStatement */ || !node.type || node.initializer || nodeFlags & 33554432 /* Ambient */)) {
                    const message = node.initializer ? Diagnostics.Declarations_with_initializers_cannot_also_have_definite_assignment_assertions : !node.type ? Diagnostics.Declarations_with_definite_assignment_assertions_must_also_have_type_annotations : Diagnostics.A_definite_assignment_assertion_is_not_permitted_in_this_context;
                    return grammarErrorOnNode(node.exclamationToken, message);
                }
                if ((moduleKind < 5 /* ES2015 */ || getSourceFileOfNode(node).impliedNodeFormat === 1 /* CommonJS */) && moduleKind !== 4 /* System */ && !(node.parent.parent.flags & 33554432 /* Ambient */) && hasSyntacticModifier(node.parent.parent, 32 /* Export */)) {
                    checkESModuleMarker(node.name);
                }
                return !!blockScopeKind && checkGrammarNameInLetOrConstDeclarations(node.name);
            }
            function checkESModuleMarker(name) {
                if (name.kind === 80 /* Identifier */) {
                    if (idText(name) === "__esModule") {
                        return grammarErrorOnNodeSkippedOn("noEmit", name, Diagnostics.Identifier_expected_esModule_is_reserved_as_an_exported_marker_when_transforming_ECMAScript_modules);
                    }
                }
                else {
                    const elements = name.elements;
                    for (const element of elements) {
                        if (!isOmittedExpression(element)) {
                            return checkESModuleMarker(element.name);
                        }
                    }
                }
                return false;
            }
            function checkGrammarNameInLetOrConstDeclarations(name) {
                if (name.kind === 80 /* Identifier */) {
                    if (name.escapedText === "let") {
                        return grammarErrorOnNode(name, Diagnostics.let_is_not_allowed_to_be_used_as_a_name_in_let_or_const_declarations);
                    }
                }
                else {
                    const elements = name.elements;
                    for (const element of elements) {
                        if (!isOmittedExpression(element)) {
                            checkGrammarNameInLetOrConstDeclarations(element.name);
                        }
                    }
                }
                return false;
            }
            function checkGrammarVariableDeclarationList(declarationList) {
                const declarations = declarationList.declarations;
                if (checkGrammarForDisallowedTrailingComma(declarationList.declarations)) {
                    return true;
                }
                if (!declarationList.declarations.length) {
                    return grammarErrorAtPos(declarationList, declarations.pos, declarations.end - declarations.pos, Diagnostics.Variable_declaration_list_cannot_be_empty);
                }
                const blockScopeFlags = declarationList.flags & 7 /* BlockScoped */;
                if ((blockScopeFlags === 4 /* Using */ || blockScopeFlags === 6 /* AwaitUsing */) && isForInStatement(declarationList.parent)) {
                    return grammarErrorOnNode(declarationList, blockScopeFlags === 4 /* Using */ ? Diagnostics.The_left_hand_side_of_a_for_in_statement_cannot_be_a_using_declaration : Diagnostics.The_left_hand_side_of_a_for_in_statement_cannot_be_an_await_using_declaration);
                }
                if (blockScopeFlags === 6 /* AwaitUsing */) {
                    return checkAwaitGrammar(declarationList);
                }
                return false;
            }
            function allowLetAndConstDeclarations(parent2) {
                switch (parent2.kind) {
                    case 245 /* IfStatement */:
                    case 246 /* DoStatement */:
                    case 247 /* WhileStatement */:
                    case 254 /* WithStatement */:
                    case 248 /* ForStatement */:
                    case 249 /* ForInStatement */:
                    case 250 /* ForOfStatement */:
                        return false;
                    case 256 /* LabeledStatement */:
                        return allowLetAndConstDeclarations(parent2.parent);
                }
                return true;
            }
            function checkGrammarForDisallowedBlockScopedVariableStatement(node) {
                if (!allowLetAndConstDeclarations(node.parent)) {
                    const blockScopeKind = getCombinedNodeFlagsCached(node.declarationList) & 7 /* BlockScoped */;
                    if (blockScopeKind) {
                        const keyword = blockScopeKind === 1 /* Let */ ? "let" : blockScopeKind === 2 /* Const */ ? "const" : blockScopeKind === 4 /* Using */ ? "using" : blockScopeKind === 6 /* AwaitUsing */ ? "await using" : Debug.fail("Unknown BlockScope flag");
                        return grammarErrorOnNode(node, Diagnostics._0_declarations_can_only_be_declared_inside_a_block, keyword);
                    }
                }
            }
            function checkGrammarMetaProperty(node) {
                const escapedText = node.name.escapedText;
                switch (node.keywordToken) {
                    case 105 /* NewKeyword */:
                        if (escapedText !== "target") {
                            return grammarErrorOnNode(node.name, Diagnostics._0_is_not_a_valid_meta_property_for_keyword_1_Did_you_mean_2, unescapeLeadingUnderscores(node.name.escapedText), tokenToString(node.keywordToken), "target");
                        }
                        break;
                    case 102 /* ImportKeyword */:
                        if (escapedText !== "meta") {
                            return grammarErrorOnNode(node.name, Diagnostics._0_is_not_a_valid_meta_property_for_keyword_1_Did_you_mean_2, unescapeLeadingUnderscores(node.name.escapedText), tokenToString(node.keywordToken), "meta");
                        }
                        break;
                }
            }
            function hasParseDiagnostics(sourceFile) {
                return sourceFile.parseDiagnostics.length > 0;
            }
            function grammarErrorOnFirstToken(node, message, ...args) {
                const sourceFile = getSourceFileOfNode(node);
                if (!hasParseDiagnostics(sourceFile)) {
                    const span = getSpanOfTokenAtPosition(sourceFile, node.pos);
                    diagnostics.add(createFileDiagnostic(sourceFile, span.start, span.length, message, ...args));
                    return true;
                }
                return false;
            }
            function grammarErrorAtPos(nodeForSourceFile, start, length2, message, ...args) {
                const sourceFile = getSourceFileOfNode(nodeForSourceFile);
                if (!hasParseDiagnostics(sourceFile)) {
                    diagnostics.add(createFileDiagnostic(sourceFile, start, length2, message, ...args));
                    return true;
                }
                return false;
            }
            function grammarErrorOnNodeSkippedOn(key, node, message, ...args) {
                const sourceFile = getSourceFileOfNode(node);
                if (!hasParseDiagnostics(sourceFile)) {
                    errorSkippedOn(key, node, message, ...args);
                    return true;
                }
                return false;
            }
            function grammarErrorOnNode(node, message, ...args) {
                const sourceFile = getSourceFileOfNode(node);
                if (!hasParseDiagnostics(sourceFile)) {
                    diagnostics.add(createDiagnosticForNode(node, message, ...args));
                    return true;
                }
                return false;
            }
            function checkGrammarConstructorTypeParameters(node) {
                const jsdocTypeParameters = isInJSFile(node) ? getJSDocTypeParameterDeclarations(node) : void 0;
                const range = node.typeParameters || jsdocTypeParameters && firstOrUndefined(jsdocTypeParameters);
                if (range) {
                    const pos = range.pos === range.end ? range.pos : skipTrivia(getSourceFileOfNode(node).text, range.pos);
                    return grammarErrorAtPos(node, pos, range.end - pos, Diagnostics.Type_parameters_cannot_appear_on_a_constructor_declaration);
                }
            }
            function checkGrammarConstructorTypeAnnotation(node) {
                const type = node.type || getEffectiveReturnTypeNode(node);
                if (type) {
                    return grammarErrorOnNode(type, Diagnostics.Type_annotation_cannot_appear_on_a_constructor_declaration);
                }
            }
            function checkGrammarProperty(node) {
                if (isComputedPropertyName(node.name) && isBinaryExpression(node.name.expression) && node.name.expression.operatorToken.kind === 103 /* InKeyword */) {
                    return grammarErrorOnNode(node.parent.members[0], Diagnostics.A_mapped_type_may_not_declare_properties_or_methods);
                }
                if (isClassLike(node.parent)) {
                    if (isStringLiteral(node.name) && node.name.text === "constructor") {
                        return grammarErrorOnNode(node.name, Diagnostics.Classes_may_not_have_a_field_named_constructor);
                    }
                    if (checkGrammarForInvalidDynamicName(node.name, Diagnostics.A_computed_property_name_in_a_class_property_declaration_must_have_a_simple_literal_type_or_a_unique_symbol_type)) {
                        return true;
                    }
                    if (languageVersion < 2 /* ES2015 */ && isPrivateIdentifier(node.name)) {
                        return grammarErrorOnNode(node.name, Diagnostics.Private_identifiers_are_only_available_when_targeting_ECMAScript_2015_and_higher);
                    }
                    if (languageVersion < 2 /* ES2015 */ && isAutoAccessorPropertyDeclaration(node)) {
                        return grammarErrorOnNode(node.name, Diagnostics.Properties_with_the_accessor_modifier_are_only_available_when_targeting_ECMAScript_2015_and_higher);
                    }
                    if (isAutoAccessorPropertyDeclaration(node) && checkGrammarForInvalidQuestionMark(node.questionToken, Diagnostics.An_accessor_property_cannot_be_declared_optional)) {
                        return true;
                    }
                }
                else if (node.parent.kind === 264 /* InterfaceDeclaration */) {
                    if (checkGrammarForInvalidDynamicName(node.name, Diagnostics.A_computed_property_name_in_an_interface_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type)) {
                        return true;
                    }
                    Debug.assertNode(node, isPropertySignature);
                    if (node.initializer) {
                        return grammarErrorOnNode(node.initializer, Diagnostics.An_interface_property_cannot_have_an_initializer);
                    }
                }
                else if (isTypeLiteralNode(node.parent)) {
                    if (checkGrammarForInvalidDynamicName(node.name, Diagnostics.A_computed_property_name_in_a_type_literal_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type)) {
                        return true;
                    }
                    Debug.assertNode(node, isPropertySignature);
                    if (node.initializer) {
                        return grammarErrorOnNode(node.initializer, Diagnostics.A_type_literal_property_cannot_have_an_initializer);
                    }
                }
                if (node.flags & 33554432 /* Ambient */) {
                    checkAmbientInitializer(node);
                }
                if (isPropertyDeclaration(node) && node.exclamationToken && (!isClassLike(node.parent) || !node.type || node.initializer || node.flags & 33554432 /* Ambient */ || isStatic(node) || hasAbstractModifier(node))) {
                    const message = node.initializer ? Diagnostics.Declarations_with_initializers_cannot_also_have_definite_assignment_assertions : !node.type ? Diagnostics.Declarations_with_definite_assignment_assertions_must_also_have_type_annotations : Diagnostics.A_definite_assignment_assertion_is_not_permitted_in_this_context;
                    return grammarErrorOnNode(node.exclamationToken, message);
                }
            }
            function checkGrammarTopLevelElementForRequiredDeclareModifier(node) {
                if (node.kind === 264 /* InterfaceDeclaration */ || node.kind === 265 /* TypeAliasDeclaration */ || node.kind === 272 /* ImportDeclaration */ || node.kind === 271 /* ImportEqualsDeclaration */ || node.kind === 278 /* ExportDeclaration */ || node.kind === 277 /* ExportAssignment */ || node.kind === 270 /* NamespaceExportDeclaration */ || hasSyntacticModifier(node, 128 /* Ambient */ | 32 /* Export */ | 2048 /* Default */)) {
                    return false;
                }
                return grammarErrorOnFirstToken(node, Diagnostics.Top_level_declarations_in_d_ts_files_must_start_with_either_a_declare_or_export_modifier);
            }
            function checkGrammarTopLevelElementsForRequiredDeclareModifier(file) {
                for (const decl of file.statements) {
                    if (isDeclaration(decl) || decl.kind === 243 /* VariableStatement */) {
                        if (checkGrammarTopLevelElementForRequiredDeclareModifier(decl)) {
                            return true;
                        }
                    }
                }
                return false;
            }
            function checkGrammarSourceFile(node) {
                return !!(node.flags & 33554432 /* Ambient */) && checkGrammarTopLevelElementsForRequiredDeclareModifier(node);
            }
            function checkGrammarStatementInAmbientContext(node) {
                if (node.flags & 33554432 /* Ambient */) {
                    const links = getNodeLinks(node);
                    if (!links.hasReportedStatementInAmbientContext && (isFunctionLike(node.parent) || isAccessor(node.parent))) {
                        return getNodeLinks(node).hasReportedStatementInAmbientContext = grammarErrorOnFirstToken(node, Diagnostics.An_implementation_cannot_be_declared_in_ambient_contexts);
                    }
                    if (node.parent.kind === 241 /* Block */ || node.parent.kind === 268 /* ModuleBlock */ || node.parent.kind === 312 /* SourceFile */) {
                        const links2 = getNodeLinks(node.parent);
                        if (!links2.hasReportedStatementInAmbientContext) {
                            return links2.hasReportedStatementInAmbientContext = grammarErrorOnFirstToken(node, Diagnostics.Statements_are_not_allowed_in_ambient_contexts);
                        }
                    }
                    else {
                    }
                }
                return false;
            }
            function checkGrammarNumericLiteral(node) {
                const isFractional = getTextOfNode(node).includes(".");
                const isScientific = node.numericLiteralFlags & 16 /* Scientific */;
                if (isFractional || isScientific) {
                    return;
                }
                const value = +node.text;
                if (value <= 2 ** 53 - 1) {
                    return;
                }
                addErrorOrSuggestion(
                /*isError*/
                false, createDiagnosticForNode(node, Diagnostics.Numeric_literals_with_absolute_values_equal_to_2_53_or_greater_are_too_large_to_be_represented_accurately_as_integers));
            }
            function checkGrammarBigIntLiteral(node) {
                const literalType = isLiteralTypeNode(node.parent) || isPrefixUnaryExpression(node.parent) && isLiteralTypeNode(node.parent.parent);
                if (!literalType) {
                    if (languageVersion < 7 /* ES2020 */) {
                        if (grammarErrorOnNode(node, Diagnostics.BigInt_literals_are_not_available_when_targeting_lower_than_ES2020)) {
                            return true;
                        }
                    }
                }
                return false;
            }
            function grammarErrorAfterFirstToken(node, message, ...args) {
                const sourceFile = getSourceFileOfNode(node);
                if (!hasParseDiagnostics(sourceFile)) {
                    const span = getSpanOfTokenAtPosition(sourceFile, node.pos);
                    diagnostics.add(createFileDiagnostic(sourceFile, textSpanEnd(span), 
                    /*length*/
                    0, message, ...args));
                    return true;
                }
                return false;
            }
            function getAmbientModules() {
                if (!ambientModulesCache) {
                    ambientModulesCache = [];
                    globals.forEach((global2, sym) => {
                        if (ambientModuleSymbolRegex.test(sym)) {
                            ambientModulesCache.push(global2);
                        }
                    });
                }
                return ambientModulesCache;
            }
            function checkGrammarImportClause(node) {
                var _a;
                if (node.isTypeOnly && node.name && node.namedBindings) {
                    return grammarErrorOnNode(node, Diagnostics.A_type_only_import_can_specify_a_default_import_or_named_bindings_but_not_both);
                }
                if (node.isTypeOnly && ((_a = node.namedBindings) == null ? void 0 : _a.kind) === 275 /* NamedImports */) {
                    return checkGrammarNamedImportsOrExports(node.namedBindings);
                }
                return false;
            }
            function checkGrammarNamedImportsOrExports(namedBindings) {
                return !!forEach(namedBindings.elements, (specifier) => {
                    if (specifier.isTypeOnly) {
                        return grammarErrorOnFirstToken(specifier, specifier.kind === 276 /* ImportSpecifier */ ? Diagnostics.The_type_modifier_cannot_be_used_on_a_named_import_when_import_type_is_used_on_its_import_statement : Diagnostics.The_type_modifier_cannot_be_used_on_a_named_export_when_export_type_is_used_on_its_export_statement);
                    }
                });
            }
            function checkGrammarImportCallExpression(node) {
                if (compilerOptions.verbatimModuleSyntax && moduleKind === 1 /* CommonJS */) {
                    return grammarErrorOnNode(node, Diagnostics.ESM_syntax_is_not_allowed_in_a_CommonJS_module_when_verbatimModuleSyntax_is_enabled);
                }
                if (moduleKind === 5 /* ES2015 */) {
                    return grammarErrorOnNode(node, Diagnostics.Dynamic_imports_are_only_supported_when_the_module_flag_is_set_to_es2020_es2022_esnext_commonjs_amd_system_umd_node16_or_nodenext);
                }
                if (node.typeArguments) {
                    return grammarErrorOnNode(node, Diagnostics.This_use_of_import_is_invalid_import_calls_can_be_written_but_they_must_have_parentheses_and_cannot_have_type_arguments);
                }
                const nodeArguments = node.arguments;
                if (moduleKind !== 99 /* ESNext */ && moduleKind !== 199 /* NodeNext */ && moduleKind !== 100 /* Node16 */) {
                    checkGrammarForDisallowedTrailingComma(nodeArguments);
                    if (nodeArguments.length > 1) {
                        const importAttributesArgument = nodeArguments[1];
                        return grammarErrorOnNode(importAttributesArgument, Diagnostics.Dynamic_imports_only_support_a_second_argument_when_the_module_option_is_set_to_esnext_node16_or_nodenext);
                    }
                }
                if (nodeArguments.length === 0 || nodeArguments.length > 2) {
                    return grammarErrorOnNode(node, Diagnostics.Dynamic_imports_can_only_accept_a_module_specifier_and_an_optional_set_of_attributes_as_arguments);
                }
                const spreadElement = find(nodeArguments, isSpreadElement);
                if (spreadElement) {
                    return grammarErrorOnNode(spreadElement, Diagnostics.Argument_of_dynamic_import_cannot_be_spread_element);
                }
                return false;
            }
            function findMatchingTypeReferenceOrTypeAliasReference(source, unionTarget) {
                const sourceObjectFlags = getObjectFlags(source);
                if (sourceObjectFlags & (4 /* Reference */ | 16 /* Anonymous */) && unionTarget.flags & 1048576 /* Union */) {
                    return find(unionTarget.types, (target) => {
                        if (target.flags & 524288 /* Object */) {
                            const overlapObjFlags = sourceObjectFlags & getObjectFlags(target);
                            if (overlapObjFlags & 4 /* Reference */) {
                                return source.target === target.target;
                            }
                            if (overlapObjFlags & 16 /* Anonymous */) {
                                return !!source.aliasSymbol && source.aliasSymbol === target.aliasSymbol;
                            }
                        }
                        return false;
                    });
                }
            }
            function findBestTypeForObjectLiteral(source, unionTarget) {
                if (getObjectFlags(source) & 128 /* ObjectLiteral */ && someType(unionTarget, isArrayLikeType)) {
                    return find(unionTarget.types, (t) => !isArrayLikeType(t));
                }
            }
            function findBestTypeForInvokable(source, unionTarget) {
                let signatureKind = 0 /* Call */;
                const hasSignatures = getSignaturesOfType(source, signatureKind).length > 0 || (signatureKind = 1 /* Construct */, getSignaturesOfType(source, signatureKind).length > 0);
                if (hasSignatures) {
                    return find(unionTarget.types, (t) => getSignaturesOfType(t, signatureKind).length > 0);
                }
            }
            function findMostOverlappyType(source, unionTarget) {
                let bestMatch;
                if (!(source.flags & (402784252 /* Primitive */ | 406847488 /* InstantiablePrimitive */))) {
                    let matchingCount = 0;
                    for (const target of unionTarget.types) {
                        if (!(target.flags & (402784252 /* Primitive */ | 406847488 /* InstantiablePrimitive */))) {
                            const overlap = getIntersectionType([getIndexType(source), getIndexType(target)]);
                            if (overlap.flags & 4194304 /* Index */) {
                                return target;
                            }
                            else if (isUnitType(overlap) || overlap.flags & 1048576 /* Union */) {
                                const len = overlap.flags & 1048576 /* Union */ ? countWhere(overlap.types, isUnitType) : 1;
                                if (len >= matchingCount) {
                                    bestMatch = target;
                                    matchingCount = len;
                                }
                            }
                        }
                    }
                }
                return bestMatch;
            }
            function filterPrimitivesIfContainsNonPrimitive(type) {
                if (maybeTypeOfKind(type, 67108864 /* NonPrimitive */)) {
                    const result = filterType(type, (t) => !(t.flags & 402784252 /* Primitive */));
                    if (!(result.flags & 131072 /* Never */)) {
                        return result;
                    }
                }
                return type;
            }
            function findMatchingDiscriminantType(source, target, isRelatedTo) {
                if (target.flags & 1048576 /* Union */ && source.flags & (2097152 /* Intersection */ | 524288 /* Object */)) {
                    const match = getMatchingUnionConstituentForType(target, source);
                    if (match) {
                        return match;
                    }
                    const sourceProperties = getPropertiesOfType(source);
                    if (sourceProperties) {
                        const sourcePropertiesFiltered = findDiscriminantProperties(sourceProperties, target);
                        if (sourcePropertiesFiltered) {
                            const discriminated = discriminateTypeByDiscriminableItems(target, map(sourcePropertiesFiltered, (p) => [() => getTypeOfSymbol(p), p.escapedName]), isRelatedTo);
                            if (discriminated !== target) {
                                return discriminated;
                            }
                        }
                    }
                }
                return void 0;
            }
            function getEffectivePropertyNameForPropertyNameNode(node) {
                const name = getPropertyNameForPropertyNameNode(node);
                return name ? name : isComputedPropertyName(node) ? tryGetNameFromType(getTypeOfExpression(node.expression)) : void 0;
            }
            function getCombinedModifierFlagsCached(node) {
                if (lastGetCombinedModifierFlagsNode === node) {
                    return lastGetCombinedModifierFlagsResult;
                }
                lastGetCombinedModifierFlagsNode = node;
                lastGetCombinedModifierFlagsResult = getCombinedModifierFlags(node);
                return lastGetCombinedModifierFlagsResult;
            }
            function getCombinedNodeFlagsCached(node) {
                if (lastGetCombinedNodeFlagsNode === node) {
                    return lastGetCombinedNodeFlagsResult;
                }
                lastGetCombinedNodeFlagsNode = node;
                lastGetCombinedNodeFlagsResult = getCombinedNodeFlags(node);
                return lastGetCombinedNodeFlagsResult;
            }
            function isVarConstLike(node) {
                const blockScopeKind = getCombinedNodeFlagsCached(node) & 7 /* BlockScoped */;
                return blockScopeKind === 2 /* Const */ || blockScopeKind === 4 /* Using */ || blockScopeKind === 6 /* AwaitUsing */;
            }
        }
        function isNotAccessor(declaration) {
            return !isAccessor(declaration);
        }
        function isNotOverload(declaration) {
            return declaration.kind !== 262 /* FunctionDeclaration */ && declaration.kind !== 174 /* MethodDeclaration */ || !!declaration.body;
        }
        function isDeclarationNameOrImportPropertyName(name) {
            switch (name.parent.kind) {
                case 276 /* ImportSpecifier */:
                case 281 /* ExportSpecifier */:
                    return isIdentifier(name);
                default:
                    return isDeclarationName(name);
            }
        }
        function getIterationTypesKeyFromIterationTypeKind(typeKind) {
            switch (typeKind) {
                case 0 /* Yield */:
                    return "yieldType";
                case 1 /* Return */:
                    return "returnType";
                case 2 /* Next */:
                    return "nextType";
            }
        }
        function signatureHasRestParameter(s) {
            return !!(s.flags & 1 /* HasRestParameter */);
        }
        function signatureHasLiteralTypes(s) {
            return !!(s.flags & 2 /* HasLiteralTypes */);
        }
        function createBasicNodeBuilderModuleSpecifierResolutionHost(host) {
            return {
                getCommonSourceDirectory: !!host.getCommonSourceDirectory ? () => host.getCommonSourceDirectory() : () => "",
                getCurrentDirectory: () => host.getCurrentDirectory(),
                getSymlinkCache: maybeBind(host, host.getSymlinkCache),
                getPackageJsonInfoCache: () => {
                    var _a;
                    return (_a = host.getPackageJsonInfoCache) == null ? void 0 : _a.call(host);
                },
                useCaseSensitiveFileNames: maybeBind(host, host.useCaseSensitiveFileNames),
                redirectTargetsMap: host.redirectTargetsMap,
                getProjectReferenceRedirect: (fileName) => host.getProjectReferenceRedirect(fileName),
                isSourceOfProjectReferenceRedirect: (fileName) => host.isSourceOfProjectReferenceRedirect(fileName),
                fileExists: (fileName) => host.fileExists(fileName),
                getFileIncludeReasons: () => host.getFileIncludeReasons(),
                readFile: host.readFile ? (fileName) => host.readFile(fileName) : void 0
            };
        }
        var ambientModuleSymbolRegex, anon, nextSymbolId, nextNodeId, nextMergeId, nextFlowId, TypeFacts, typeofNEFacts, CheckMode, SignatureCheckMode, isNotOverloadAndNotAccessor, intrinsicTypeKinds, SymbolLinks, JsxNames, SymbolTrackerImpl;
        var init_checker = __esm({
            "src/compiler/checker.ts"() {
                "use strict";
                init_ts2();
                init_ts_moduleSpecifiers();
                init_ts_performance();
                ambientModuleSymbolRegex = /^".+"$/;
                anon = "(anonymous)";
                nextSymbolId = 1;
                nextNodeId = 1;
                nextMergeId = 1;
                nextFlowId = 1;
                TypeFacts = /* @__PURE__ */ ((TypeFacts3) => {
                    TypeFacts3[TypeFacts3["None"] = 0] = "None";
                    TypeFacts3[TypeFacts3["TypeofEQString"] = 1] = "TypeofEQString";
                    TypeFacts3[TypeFacts3["TypeofEQNumber"] = 2] = "TypeofEQNumber";
                    TypeFacts3[TypeFacts3["TypeofEQBigInt"] = 4] = "TypeofEQBigInt";
                    TypeFacts3[TypeFacts3["TypeofEQBoolean"] = 8] = "TypeofEQBoolean";
                    TypeFacts3[TypeFacts3["TypeofEQSymbol"] = 16] = "TypeofEQSymbol";
                    TypeFacts3[TypeFacts3["TypeofEQObject"] = 32] = "TypeofEQObject";
                    TypeFacts3[TypeFacts3["TypeofEQFunction"] = 64] = "TypeofEQFunction";
                    TypeFacts3[TypeFacts3["TypeofEQHostObject"] = 128] = "TypeofEQHostObject";
                    TypeFacts3[TypeFacts3["TypeofNEString"] = 256] = "TypeofNEString";
                    TypeFacts3[TypeFacts3["TypeofNENumber"] = 512] = "TypeofNENumber";
                    TypeFacts3[TypeFacts3["TypeofNEBigInt"] = 1024] = "TypeofNEBigInt";
                    TypeFacts3[TypeFacts3["TypeofNEBoolean"] = 2048] = "TypeofNEBoolean";
                    TypeFacts3[TypeFacts3["TypeofNESymbol"] = 4096] = "TypeofNESymbol";
                    TypeFacts3[TypeFacts3["TypeofNEObject"] = 8192] = "TypeofNEObject";
                    TypeFacts3[TypeFacts3["TypeofNEFunction"] = 16384] = "TypeofNEFunction";
                    TypeFacts3[TypeFacts3["TypeofNEHostObject"] = 32768] = "TypeofNEHostObject";
                    TypeFacts3[TypeFacts3["EQUndefined"] = 65536] = "EQUndefined";
                    TypeFacts3[TypeFacts3["EQNull"] = 131072] = "EQNull";
                    TypeFacts3[TypeFacts3["EQUndefinedOrNull"] = 262144] = "EQUndefinedOrNull";
                    TypeFacts3[TypeFacts3["NEUndefined"] = 524288] = "NEUndefined";
                    TypeFacts3[TypeFacts3["NENull"] = 1048576] = "NENull";
                    TypeFacts3[TypeFacts3["NEUndefinedOrNull"] = 2097152] = "NEUndefinedOrNull";
                    TypeFacts3[TypeFacts3["Truthy"] = 4194304] = "Truthy";
                    TypeFacts3[TypeFacts3["Falsy"] = 8388608] = "Falsy";
                    TypeFacts3[TypeFacts3["IsUndefined"] = 16777216] = "IsUndefined";
                    TypeFacts3[TypeFacts3["IsNull"] = 33554432] = "IsNull";
                    TypeFacts3[TypeFacts3["IsUndefinedOrNull"] = 50331648] = "IsUndefinedOrNull";
                    TypeFacts3[TypeFacts3["All"] = 134217727] = "All";
                    TypeFacts3[TypeFacts3["BaseStringStrictFacts"] = 3735041] = "BaseStringStrictFacts";
                    TypeFacts3[TypeFacts3["BaseStringFacts"] = 12582401] = "BaseStringFacts";
                    TypeFacts3[TypeFacts3["StringStrictFacts"] = 16317953] = "StringStrictFacts";
                    TypeFacts3[TypeFacts3["StringFacts"] = 16776705] = "StringFacts";
                    TypeFacts3[TypeFacts3["EmptyStringStrictFacts"] = 12123649] = "EmptyStringStrictFacts";
                    TypeFacts3[TypeFacts3["EmptyStringFacts"] = 12582401 /* BaseStringFacts */] = "EmptyStringFacts";
                    TypeFacts3[TypeFacts3["NonEmptyStringStrictFacts"] = 7929345] = "NonEmptyStringStrictFacts";
                    TypeFacts3[TypeFacts3["NonEmptyStringFacts"] = 16776705] = "NonEmptyStringFacts";
                    TypeFacts3[TypeFacts3["BaseNumberStrictFacts"] = 3734786] = "BaseNumberStrictFacts";
                    TypeFacts3[TypeFacts3["BaseNumberFacts"] = 12582146] = "BaseNumberFacts";
                    TypeFacts3[TypeFacts3["NumberStrictFacts"] = 16317698] = "NumberStrictFacts";
                    TypeFacts3[TypeFacts3["NumberFacts"] = 16776450] = "NumberFacts";
                    TypeFacts3[TypeFacts3["ZeroNumberStrictFacts"] = 12123394] = "ZeroNumberStrictFacts";
                    TypeFacts3[TypeFacts3["ZeroNumberFacts"] = 12582146 /* BaseNumberFacts */] = "ZeroNumberFacts";
                    TypeFacts3[TypeFacts3["NonZeroNumberStrictFacts"] = 7929090] = "NonZeroNumberStrictFacts";
                    TypeFacts3[TypeFacts3["NonZeroNumberFacts"] = 16776450] = "NonZeroNumberFacts";
                    TypeFacts3[TypeFacts3["BaseBigIntStrictFacts"] = 3734276] = "BaseBigIntStrictFacts";
                    TypeFacts3[TypeFacts3["BaseBigIntFacts"] = 12581636] = "BaseBigIntFacts";
                    TypeFacts3[TypeFacts3["BigIntStrictFacts"] = 16317188] = "BigIntStrictFacts";
                    TypeFacts3[TypeFacts3["BigIntFacts"] = 16775940] = "BigIntFacts";
                    TypeFacts3[TypeFacts3["ZeroBigIntStrictFacts"] = 12122884] = "ZeroBigIntStrictFacts";
                    TypeFacts3[TypeFacts3["ZeroBigIntFacts"] = 12581636 /* BaseBigIntFacts */] = "ZeroBigIntFacts";
                    TypeFacts3[TypeFacts3["NonZeroBigIntStrictFacts"] = 7928580] = "NonZeroBigIntStrictFacts";
                    TypeFacts3[TypeFacts3["NonZeroBigIntFacts"] = 16775940] = "NonZeroBigIntFacts";
                    TypeFacts3[TypeFacts3["BaseBooleanStrictFacts"] = 3733256] = "BaseBooleanStrictFacts";
                    TypeFacts3[TypeFacts3["BaseBooleanFacts"] = 12580616] = "BaseBooleanFacts";
                    TypeFacts3[TypeFacts3["BooleanStrictFacts"] = 16316168] = "BooleanStrictFacts";
                    TypeFacts3[TypeFacts3["BooleanFacts"] = 16774920] = "BooleanFacts";
                    TypeFacts3[TypeFacts3["FalseStrictFacts"] = 12121864] = "FalseStrictFacts";
                    TypeFacts3[TypeFacts3["FalseFacts"] = 12580616 /* BaseBooleanFacts */] = "FalseFacts";
                    TypeFacts3[TypeFacts3["TrueStrictFacts"] = 7927560] = "TrueStrictFacts";
                    TypeFacts3[TypeFacts3["TrueFacts"] = 16774920] = "TrueFacts";
                    TypeFacts3[TypeFacts3["SymbolStrictFacts"] = 7925520] = "SymbolStrictFacts";
                    TypeFacts3[TypeFacts3["SymbolFacts"] = 16772880] = "SymbolFacts";
                    TypeFacts3[TypeFacts3["ObjectStrictFacts"] = 7888800] = "ObjectStrictFacts";
                    TypeFacts3[TypeFacts3["ObjectFacts"] = 16736160] = "ObjectFacts";
                    TypeFacts3[TypeFacts3["FunctionStrictFacts"] = 7880640] = "FunctionStrictFacts";
                    TypeFacts3[TypeFacts3["FunctionFacts"] = 16728e3] = "FunctionFacts";
                    TypeFacts3[TypeFacts3["VoidFacts"] = 9830144] = "VoidFacts";
                    TypeFacts3[TypeFacts3["UndefinedFacts"] = 26607360] = "UndefinedFacts";
                    TypeFacts3[TypeFacts3["NullFacts"] = 42917664] = "NullFacts";
                    TypeFacts3[TypeFacts3["EmptyObjectStrictFacts"] = 83427327] = "EmptyObjectStrictFacts";
                    TypeFacts3[TypeFacts3["EmptyObjectFacts"] = 83886079] = "EmptyObjectFacts";
                    TypeFacts3[TypeFacts3["UnknownFacts"] = 83886079] = "UnknownFacts";
                    TypeFacts3[TypeFacts3["AllTypeofNE"] = 556800] = "AllTypeofNE";
                    TypeFacts3[TypeFacts3["OrFactsMask"] = 8256] = "OrFactsMask";
                    TypeFacts3[TypeFacts3["AndFactsMask"] = 134209471] = "AndFactsMask";
                    return TypeFacts3;
                })(TypeFacts || {});
                typeofNEFacts = new Map(Object.entries({
                    string: 256 /* TypeofNEString */,
                    number: 512 /* TypeofNENumber */,
                    bigint: 1024 /* TypeofNEBigInt */,
                    boolean: 2048 /* TypeofNEBoolean */,
                    symbol: 4096 /* TypeofNESymbol */,
                    undefined: 524288 /* NEUndefined */,
                    object: 8192 /* TypeofNEObject */,
                    function: 16384 /* TypeofNEFunction */
                }));
                CheckMode = /* @__PURE__ */ ((CheckMode3) => {
                    CheckMode3[CheckMode3["Normal"] = 0] = "Normal";
                    CheckMode3[CheckMode3["Contextual"] = 1] = "Contextual";
                    CheckMode3[CheckMode3["Inferential"] = 2] = "Inferential";
                    CheckMode3[CheckMode3["SkipContextSensitive"] = 4] = "SkipContextSensitive";
                    CheckMode3[CheckMode3["SkipGenericFunctions"] = 8] = "SkipGenericFunctions";
                    CheckMode3[CheckMode3["IsForSignatureHelp"] = 16] = "IsForSignatureHelp";
                    CheckMode3[CheckMode3["RestBindingElement"] = 32] = "RestBindingElement";
                    CheckMode3[CheckMode3["TypeOnly"] = 64] = "TypeOnly";
                    return CheckMode3;
                })(CheckMode || {});
                SignatureCheckMode = /* @__PURE__ */ ((SignatureCheckMode3) => {
                    SignatureCheckMode3[SignatureCheckMode3["None"] = 0] = "None";
                    SignatureCheckMode3[SignatureCheckMode3["BivariantCallback"] = 1] = "BivariantCallback";
                    SignatureCheckMode3[SignatureCheckMode3["StrictCallback"] = 2] = "StrictCallback";
                    SignatureCheckMode3[SignatureCheckMode3["IgnoreReturnTypes"] = 4] = "IgnoreReturnTypes";
                    SignatureCheckMode3[SignatureCheckMode3["StrictArity"] = 8] = "StrictArity";
                    SignatureCheckMode3[SignatureCheckMode3["StrictTopSignature"] = 16] = "StrictTopSignature";
                    SignatureCheckMode3[SignatureCheckMode3["Callback"] = 3] = "Callback";
                    return SignatureCheckMode3;
                })(SignatureCheckMode || {});
                isNotOverloadAndNotAccessor = and(isNotOverload, isNotAccessor);
                intrinsicTypeKinds = new Map(Object.entries({
                    Uppercase: 0 /* Uppercase */,
                    Lowercase: 1 /* Lowercase */,
                    Capitalize: 2 /* Capitalize */,
                    Uncapitalize: 3 /* Uncapitalize */,
                    NoInfer: 4 /* NoInfer */
                }));
                SymbolLinks = class {
                };
                ((JsxNames2) => {
                    JsxNames2.JSX = "JSX";
                    JsxNames2.IntrinsicElements = "IntrinsicElements";
                    JsxNames2.ElementClass = "ElementClass";
                    JsxNames2.ElementAttributesPropertyNameContainer = "ElementAttributesProperty";
                    JsxNames2.ElementChildrenAttributeNameContainer = "ElementChildrenAttribute";
                    JsxNames2.Element = "Element";
                    JsxNames2.ElementType = "ElementType";
                    JsxNames2.IntrinsicAttributes = "IntrinsicAttributes";
                    JsxNames2.IntrinsicClassAttributes = "IntrinsicClassAttributes";
                    JsxNames2.LibraryManagedAttributes = "LibraryManagedAttributes";
                })(JsxNames || (JsxNames = {}));
                SymbolTrackerImpl = class _SymbolTrackerImpl {
                    constructor(context, tracker, moduleResolverHost) {
                        this.moduleResolverHost = void 0;
                        this.inner = void 0;
                        this.disableTrackSymbol = false;
                        var _a;
                        while (tracker instanceof _SymbolTrackerImpl) {
                            tracker = tracker.inner;
                        }
                        this.inner = tracker;
                        this.moduleResolverHost = moduleResolverHost;
                        this.context = context;
                        this.canTrackSymbol = !!((_a = this.inner) == null ? void 0 : _a.trackSymbol);
                    }
                    trackSymbol(symbol, enclosingDeclaration, meaning) {
                        var _a, _b;
                        if (((_a = this.inner) == null ? void 0 : _a.trackSymbol) && !this.disableTrackSymbol) {
                            if (this.inner.trackSymbol(symbol, enclosingDeclaration, meaning)) {
                                this.onDiagnosticReported();
                                return true;
                            }
                            if (!(symbol.flags & 262144 /* TypeParameter */))
                                ((_b = this.context).trackedSymbols ?? (_b.trackedSymbols = [])).push([symbol, enclosingDeclaration, meaning]);
                        }
                        return false;
                    }
                    reportInaccessibleThisError() {
                        var _a;
                        if ((_a = this.inner) == null ? void 0 : _a.reportInaccessibleThisError) {
                            this.onDiagnosticReported();
                            this.inner.reportInaccessibleThisError();
                        }
                    }
                    reportPrivateInBaseOfClassExpression(propertyName) {
                        var _a;
                        if ((_a = this.inner) == null ? void 0 : _a.reportPrivateInBaseOfClassExpression) {
                            this.onDiagnosticReported();
                            this.inner.reportPrivateInBaseOfClassExpression(propertyName);
                        }
                    }
                    reportInaccessibleUniqueSymbolError() {
                        var _a;
                        if ((_a = this.inner) == null ? void 0 : _a.reportInaccessibleUniqueSymbolError) {
                            this.onDiagnosticReported();
                            this.inner.reportInaccessibleUniqueSymbolError();
                        }
                    }
                    reportCyclicStructureError() {
                        var _a;
                        if ((_a = this.inner) == null ? void 0 : _a.reportCyclicStructureError) {
                            this.onDiagnosticReported();
                            this.inner.reportCyclicStructureError();
                        }
                    }
                    reportLikelyUnsafeImportRequiredError(specifier) {
                        var _a;
                        if ((_a = this.inner) == null ? void 0 : _a.reportLikelyUnsafeImportRequiredError) {
                            this.onDiagnosticReported();
                            this.inner.reportLikelyUnsafeImportRequiredError(specifier);
                        }
                    }
                    reportTruncationError() {
                        var _a;
                        if ((_a = this.inner) == null ? void 0 : _a.reportTruncationError) {
                            this.onDiagnosticReported();
                            this.inner.reportTruncationError();
                        }
                    }
                    trackReferencedAmbientModule(decl, symbol) {
                        var _a;
                        if ((_a = this.inner) == null ? void 0 : _a.trackReferencedAmbientModule) {
                            this.onDiagnosticReported();
                            this.inner.trackReferencedAmbientModule(decl, symbol);
                        }
                    }
                    trackExternalModuleSymbolOfImportTypeNode(symbol) {
                        var _a;
                        if ((_a = this.inner) == null ? void 0 : _a.trackExternalModuleSymbolOfImportTypeNode) {
                            this.onDiagnosticReported();
                            this.inner.trackExternalModuleSymbolOfImportTypeNode(symbol);
                        }
                    }
                    reportNonlocalAugmentation(containingFile, parentSymbol, augmentingSymbol) {
                        var _a;
                        if ((_a = this.inner) == null ? void 0 : _a.reportNonlocalAugmentation) {
                            this.onDiagnosticReported();
                            this.inner.reportNonlocalAugmentation(containingFile, parentSymbol, augmentingSymbol);
                        }
                    }
                    reportNonSerializableProperty(propertyName) {
                        var _a;
                        if ((_a = this.inner) == null ? void 0 : _a.reportNonSerializableProperty) {
                            this.onDiagnosticReported();
                            this.inner.reportNonSerializableProperty(propertyName);
                        }
                    }
                    onDiagnosticReported() {
                        this.context.reportedDiagnostic = true;
                    }
                };
            }
        });
        // src/compiler/visitorPublic.ts
        function visitNode(node, visitor, test, lift) {
            if (node === void 0) {
                return node;
            }
            const visited = visitor(node);
            let visitedNode;
            if (visited === void 0) {
                return void 0;
            }
            else if (isArray(visited)) {
                visitedNode = (lift || extractSingleNode)(visited);
            }
            else {
                visitedNode = visited;
            }
            Debug.assertNode(visitedNode, test);
            return visitedNode;
        }
        function visitNodes2(nodes, visitor, test, start, count) {
            if (nodes === void 0) {
                return nodes;
            }
            const length2 = nodes.length;
            if (start === void 0 || start < 0) {
                start = 0;
            }
            if (count === void 0 || count > length2 - start) {
                count = length2 - start;
            }
            let hasTrailingComma;
            let pos = -1;
            let end = -1;
            if (start > 0 || count < length2) {
                hasTrailingComma = nodes.hasTrailingComma && start + count === length2;
            }
            else {
                pos = nodes.pos;
                end = nodes.end;
                hasTrailingComma = nodes.hasTrailingComma;
            }
            const updated = visitArrayWorker(nodes, visitor, test, start, count);
            if (updated !== nodes) {
                const updatedArray = factory.createNodeArray(updated, hasTrailingComma);
                setTextRangePosEnd(updatedArray, pos, end);
                return updatedArray;
            }
            return nodes;
        }
        function visitArray(nodes, visitor, test, start, count) {
            if (nodes === void 0) {
                return nodes;
            }
            const length2 = nodes.length;
            if (start === void 0 || start < 0) {
                start = 0;
            }
            if (count === void 0 || count > length2 - start) {
                count = length2 - start;
            }
            return visitArrayWorker(nodes, visitor, test, start, count);
        }
        function visitArrayWorker(nodes, visitor, test, start, count) {
            let updated;
            const length2 = nodes.length;
            if (start > 0 || count < length2) {
                updated = [];
            }
            for (let i = 0; i < count; i++) {
                const node = nodes[i + start];
                const visited = node !== void 0 ? visitor ? visitor(node) : node : void 0;
                if (updated !== void 0 || visited === void 0 || visited !== node) {
                    if (updated === void 0) {
                        updated = nodes.slice(0, i);
                        Debug.assertEachNode(updated, test);
                    }
                    if (visited) {
                        if (isArray(visited)) {
                            for (const visitedNode of visited) {
                                Debug.assertNode(visitedNode, test);
                                updated.push(visitedNode);
                            }
                        }
                        else {
                            Debug.assertNode(visited, test);
                            updated.push(visited);
                        }
                    }
                }
            }
            if (updated) {
                return updated;
            }
            Debug.assertEachNode(nodes, test);
            return nodes;
        }
        function visitLexicalEnvironment(statements, visitor, context, start, ensureUseStrict, nodesVisitor = visitNodes2) {
            context.startLexicalEnvironment();
            statements = nodesVisitor(statements, visitor, isStatement, start);
            if (ensureUseStrict)
                statements = context.factory.ensureUseStrict(statements);
            return factory.mergeLexicalEnvironment(statements, context.endLexicalEnvironment());
        }
        function visitParameterList(nodes, visitor, context, nodesVisitor = visitNodes2) {
            let updated;
            context.startLexicalEnvironment();
            if (nodes) {
                context.setLexicalEnvironmentFlags(1 /* InParameters */, true);
                updated = nodesVisitor(nodes, visitor, isParameter);
                if (context.getLexicalEnvironmentFlags() & 2 /* VariablesHoistedInParameters */ && getEmitScriptTarget(context.getCompilerOptions()) >= 2 /* ES2015 */) {
                    updated = addDefaultValueAssignmentsIfNeeded(updated, context);
                }
                context.setLexicalEnvironmentFlags(1 /* InParameters */, false);
            }
            context.suspendLexicalEnvironment();
            return updated;
        }
        function addDefaultValueAssignmentsIfNeeded(parameters, context) {
            let result;
            for (let i = 0; i < parameters.length; i++) {
                const parameter = parameters[i];
                const updated = addDefaultValueAssignmentIfNeeded(parameter, context);
                if (result || updated !== parameter) {
                    if (!result)
                        result = parameters.slice(0, i);
                    result[i] = updated;
                }
            }
            if (result) {
                return setTextRange(context.factory.createNodeArray(result, parameters.hasTrailingComma), parameters);
            }
            return parameters;
        }
        function addDefaultValueAssignmentIfNeeded(parameter, context) {
            return parameter.dotDotDotToken ? parameter : isBindingPattern(parameter.name) ? addDefaultValueAssignmentForBindingPattern(parameter, context) : parameter.initializer ? addDefaultValueAssignmentForInitializer(parameter, parameter.name, parameter.initializer, context) : parameter;
        }
        function addDefaultValueAssignmentForBindingPattern(parameter, context) {
            const { factory: factory2 } = context;
            context.addInitializationStatement(factory2.createVariableStatement(
            /*modifiers*/
            void 0, factory2.createVariableDeclarationList([
                factory2.createVariableDeclaration(parameter.name, 
                /*exclamationToken*/
                void 0, parameter.type, parameter.initializer ? factory2.createConditionalExpression(factory2.createStrictEquality(factory2.getGeneratedNameForNode(parameter), factory2.createVoidZero()), 
                /*questionToken*/
                void 0, parameter.initializer, 
                /*colonToken*/
                void 0, factory2.getGeneratedNameForNode(parameter)) : factory2.getGeneratedNameForNode(parameter))
            ])));
            return factory2.updateParameterDeclaration(parameter, parameter.modifiers, parameter.dotDotDotToken, factory2.getGeneratedNameForNode(parameter), parameter.questionToken, parameter.type, 
            /*initializer*/
            void 0);
        }
        function addDefaultValueAssignmentForInitializer(parameter, name, initializer, context) {
            const factory2 = context.factory;
            context.addInitializationStatement(factory2.createIfStatement(factory2.createTypeCheck(factory2.cloneNode(name), "undefined"), setEmitFlags(setTextRange(factory2.createBlock([
                factory2.createExpressionStatement(setEmitFlags(setTextRange(factory2.createAssignment(setEmitFlags(factory2.cloneNode(name), 96 /* NoSourceMap */), setEmitFlags(initializer, 96 /* NoSourceMap */ | getEmitFlags(initializer) | 3072 /* NoComments */)), parameter), 3072 /* NoComments */))
            ]), parameter), 1 /* SingleLine */ | 64 /* NoTrailingSourceMap */ | 768 /* NoTokenSourceMaps */ | 3072 /* NoComments */)));
            return factory2.updateParameterDeclaration(parameter, parameter.modifiers, parameter.dotDotDotToken, parameter.name, parameter.questionToken, parameter.type, 
            /*initializer*/
            void 0);
        }
        function visitFunctionBody(node, visitor, context, nodeVisitor = visitNode) {
            context.resumeLexicalEnvironment();
            const updated = nodeVisitor(node, visitor, isConciseBody);
            const declarations = context.endLexicalEnvironment();
            if (some(declarations)) {
                if (!updated) {
                    return context.factory.createBlock(declarations);
                }
                const block = context.factory.converters.convertToFunctionBlock(updated);
                const statements = factory.mergeLexicalEnvironment(block.statements, declarations);
                return context.factory.updateBlock(block, statements);
            }
            return updated;
        }
        function visitIterationBody(body, visitor, context, nodeVisitor = visitNode) {
            context.startBlockScope();
            const updated = nodeVisitor(body, visitor, isStatement, context.factory.liftToBlock);
            Debug.assert(updated);
            const declarations = context.endBlockScope();
            if (some(declarations)) {
                if (isBlock(updated)) {
                    declarations.push(...updated.statements);
                    return context.factory.updateBlock(updated, declarations);
                }
                declarations.push(updated);
                return context.factory.createBlock(declarations);
            }
            return updated;
        }
        function visitCommaListElements(elements, visitor, discardVisitor = visitor) {
            if (discardVisitor === visitor || elements.length <= 1) {
                return visitNodes2(elements, visitor, isExpression);
            }
            let i = 0;
            const length2 = elements.length;
            return visitNodes2(elements, (node) => {
                const discarded = i < length2 - 1;
                i++;
                return discarded ? discardVisitor(node) : visitor(node);
            }, isExpression);
        }
        function visitEachChild(node, visitor, context = nullTransformationContext, nodesVisitor = visitNodes2, tokenVisitor, nodeVisitor = visitNode) {
            if (node === void 0) {
                return void 0;
            }
            const fn = visitEachChildTable[node.kind];
            return fn === void 0 ? node : fn(node, visitor, context, nodesVisitor, nodeVisitor, tokenVisitor);
        }
        function extractSingleNode(nodes) {
            Debug.assert(nodes.length <= 1, "Too many nodes written to output.");
            return singleOrUndefined(nodes);
        }
        var visitEachChildTable;
        var init_visitorPublic = __esm({
            "src/compiler/visitorPublic.ts"() {
                "use strict";
                init_ts2();
                visitEachChildTable = {
                    [166 /* QualifiedName */]: function visitEachChildOfQualifiedName(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateQualifiedName(node, Debug.checkDefined(nodeVisitor(node.left, visitor, isEntityName)), Debug.checkDefined(nodeVisitor(node.right, visitor, isIdentifier)));
                    },
                    [167 /* ComputedPropertyName */]: function visitEachChildOfComputedPropertyName(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateComputedPropertyName(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    // Signature elements
                    [168 /* TypeParameter */]: function visitEachChildOfTypeParameterDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTypeParameterDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifier), Debug.checkDefined(nodeVisitor(node.name, visitor, isIdentifier)), nodeVisitor(node.constraint, visitor, isTypeNode), nodeVisitor(node.default, visitor, isTypeNode));
                    },
                    [169 /* Parameter */]: function visitEachChildOfParameterDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updateParameterDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifierLike), tokenVisitor ? nodeVisitor(node.dotDotDotToken, tokenVisitor, isDotDotDotToken) : node.dotDotDotToken, Debug.checkDefined(nodeVisitor(node.name, visitor, isBindingName)), tokenVisitor ? nodeVisitor(node.questionToken, tokenVisitor, isQuestionToken) : node.questionToken, nodeVisitor(node.type, visitor, isTypeNode), nodeVisitor(node.initializer, visitor, isExpression));
                    },
                    [170 /* Decorator */]: function visitEachChildOfDecorator(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateDecorator(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    // Type elements
                    [171 /* PropertySignature */]: function visitEachChildOfPropertySignature(node, visitor, context, nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updatePropertySignature(node, nodesVisitor(node.modifiers, visitor, isModifier), Debug.checkDefined(nodeVisitor(node.name, visitor, isPropertyName)), tokenVisitor ? nodeVisitor(node.questionToken, tokenVisitor, isQuestionToken) : node.questionToken, nodeVisitor(node.type, visitor, isTypeNode));
                    },
                    [172 /* PropertyDeclaration */]: function visitEachChildOfPropertyDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updatePropertyDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifierLike), Debug.checkDefined(nodeVisitor(node.name, visitor, isPropertyName)), 
                        // QuestionToken and ExclamationToken are mutually exclusive in PropertyDeclaration
                        tokenVisitor ? nodeVisitor(node.questionToken ?? node.exclamationToken, tokenVisitor, isQuestionOrExclamationToken) : node.questionToken ?? node.exclamationToken, nodeVisitor(node.type, visitor, isTypeNode), nodeVisitor(node.initializer, visitor, isExpression));
                    },
                    [173 /* MethodSignature */]: function visitEachChildOfMethodSignature(node, visitor, context, nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updateMethodSignature(node, nodesVisitor(node.modifiers, visitor, isModifier), Debug.checkDefined(nodeVisitor(node.name, visitor, isPropertyName)), tokenVisitor ? nodeVisitor(node.questionToken, tokenVisitor, isQuestionToken) : node.questionToken, nodesVisitor(node.typeParameters, visitor, isTypeParameterDeclaration), nodesVisitor(node.parameters, visitor, isParameter), nodeVisitor(node.type, visitor, isTypeNode));
                    },
                    [174 /* MethodDeclaration */]: function visitEachChildOfMethodDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updateMethodDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifierLike), tokenVisitor ? nodeVisitor(node.asteriskToken, tokenVisitor, isAsteriskToken) : node.asteriskToken, Debug.checkDefined(nodeVisitor(node.name, visitor, isPropertyName)), tokenVisitor ? nodeVisitor(node.questionToken, tokenVisitor, isQuestionToken) : node.questionToken, nodesVisitor(node.typeParameters, visitor, isTypeParameterDeclaration), visitParameterList(node.parameters, visitor, context, nodesVisitor), nodeVisitor(node.type, visitor, isTypeNode), visitFunctionBody(node.body, visitor, context, nodeVisitor));
                    },
                    [176 /* Constructor */]: function visitEachChildOfConstructorDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateConstructorDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifierLike), visitParameterList(node.parameters, visitor, context, nodesVisitor), visitFunctionBody(node.body, visitor, context, nodeVisitor));
                    },
                    [177 /* GetAccessor */]: function visitEachChildOfGetAccessorDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateGetAccessorDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifierLike), Debug.checkDefined(nodeVisitor(node.name, visitor, isPropertyName)), visitParameterList(node.parameters, visitor, context, nodesVisitor), nodeVisitor(node.type, visitor, isTypeNode), visitFunctionBody(node.body, visitor, context, nodeVisitor));
                    },
                    [178 /* SetAccessor */]: function visitEachChildOfSetAccessorDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateSetAccessorDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifierLike), Debug.checkDefined(nodeVisitor(node.name, visitor, isPropertyName)), visitParameterList(node.parameters, visitor, context, nodesVisitor), visitFunctionBody(node.body, visitor, context, nodeVisitor));
                    },
                    [175 /* ClassStaticBlockDeclaration */]: function visitEachChildOfClassStaticBlockDeclaration(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        context.startLexicalEnvironment();
                        context.suspendLexicalEnvironment();
                        return context.factory.updateClassStaticBlockDeclaration(node, visitFunctionBody(node.body, visitor, context, nodeVisitor));
                    },
                    [179 /* CallSignature */]: function visitEachChildOfCallSignatureDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateCallSignature(node, nodesVisitor(node.typeParameters, visitor, isTypeParameterDeclaration), nodesVisitor(node.parameters, visitor, isParameter), nodeVisitor(node.type, visitor, isTypeNode));
                    },
                    [180 /* ConstructSignature */]: function visitEachChildOfConstructSignatureDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateConstructSignature(node, nodesVisitor(node.typeParameters, visitor, isTypeParameterDeclaration), nodesVisitor(node.parameters, visitor, isParameter), nodeVisitor(node.type, visitor, isTypeNode));
                    },
                    [181 /* IndexSignature */]: function visitEachChildOfIndexSignatureDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateIndexSignature(node, nodesVisitor(node.modifiers, visitor, isModifierLike), nodesVisitor(node.parameters, visitor, isParameter), Debug.checkDefined(nodeVisitor(node.type, visitor, isTypeNode)));
                    },
                    // Types
                    [182 /* TypePredicate */]: function visitEachChildOfTypePredicateNode(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTypePredicateNode(node, nodeVisitor(node.assertsModifier, visitor, isAssertsKeyword), Debug.checkDefined(nodeVisitor(node.parameterName, visitor, isIdentifierOrThisTypeNode)), nodeVisitor(node.type, visitor, isTypeNode));
                    },
                    [183 /* TypeReference */]: function visitEachChildOfTypeReferenceNode(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTypeReferenceNode(node, Debug.checkDefined(nodeVisitor(node.typeName, visitor, isEntityName)), nodesVisitor(node.typeArguments, visitor, isTypeNode));
                    },
                    [184 /* FunctionType */]: function visitEachChildOfFunctionTypeNode(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateFunctionTypeNode(node, nodesVisitor(node.typeParameters, visitor, isTypeParameterDeclaration), nodesVisitor(node.parameters, visitor, isParameter), Debug.checkDefined(nodeVisitor(node.type, visitor, isTypeNode)));
                    },
                    [185 /* ConstructorType */]: function visitEachChildOfConstructorTypeNode(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateConstructorTypeNode(node, nodesVisitor(node.modifiers, visitor, isModifier), nodesVisitor(node.typeParameters, visitor, isTypeParameterDeclaration), nodesVisitor(node.parameters, visitor, isParameter), Debug.checkDefined(nodeVisitor(node.type, visitor, isTypeNode)));
                    },
                    [186 /* TypeQuery */]: function visitEachChildOfTypeQueryNode(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTypeQueryNode(node, Debug.checkDefined(nodeVisitor(node.exprName, visitor, isEntityName)), nodesVisitor(node.typeArguments, visitor, isTypeNode));
                    },
                    [187 /* TypeLiteral */]: function visitEachChildOfTypeLiteralNode(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTypeLiteralNode(node, nodesVisitor(node.members, visitor, isTypeElement));
                    },
                    [188 /* ArrayType */]: function visitEachChildOfArrayTypeNode(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateArrayTypeNode(node, Debug.checkDefined(nodeVisitor(node.elementType, visitor, isTypeNode)));
                    },
                    [189 /* TupleType */]: function visitEachChildOfTupleTypeNode(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTupleTypeNode(node, nodesVisitor(node.elements, visitor, isTypeNode));
                    },
                    [190 /* OptionalType */]: function visitEachChildOfOptionalTypeNode(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateOptionalTypeNode(node, Debug.checkDefined(nodeVisitor(node.type, visitor, isTypeNode)));
                    },
                    [191 /* RestType */]: function visitEachChildOfRestTypeNode(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateRestTypeNode(node, Debug.checkDefined(nodeVisitor(node.type, visitor, isTypeNode)));
                    },
                    [192 /* UnionType */]: function visitEachChildOfUnionTypeNode(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateUnionTypeNode(node, nodesVisitor(node.types, visitor, isTypeNode));
                    },
                    [193 /* IntersectionType */]: function visitEachChildOfIntersectionTypeNode(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateIntersectionTypeNode(node, nodesVisitor(node.types, visitor, isTypeNode));
                    },
                    [194 /* ConditionalType */]: function visitEachChildOfConditionalTypeNode(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateConditionalTypeNode(node, Debug.checkDefined(nodeVisitor(node.checkType, visitor, isTypeNode)), Debug.checkDefined(nodeVisitor(node.extendsType, visitor, isTypeNode)), Debug.checkDefined(nodeVisitor(node.trueType, visitor, isTypeNode)), Debug.checkDefined(nodeVisitor(node.falseType, visitor, isTypeNode)));
                    },
                    [195 /* InferType */]: function visitEachChildOfInferTypeNode(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateInferTypeNode(node, Debug.checkDefined(nodeVisitor(node.typeParameter, visitor, isTypeParameterDeclaration)));
                    },
                    [205 /* ImportType */]: function visitEachChildOfImportTypeNode(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateImportTypeNode(node, Debug.checkDefined(nodeVisitor(node.argument, visitor, isTypeNode)), nodeVisitor(node.attributes, visitor, isImportAttributes), nodeVisitor(node.qualifier, visitor, isEntityName), nodesVisitor(node.typeArguments, visitor, isTypeNode), node.isTypeOf);
                    },
                    [302 /* ImportTypeAssertionContainer */]: function visitEachChildOfImportTypeAssertionContainer(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateImportTypeAssertionContainer(node, Debug.checkDefined(nodeVisitor(node.assertClause, visitor, isAssertClause)), node.multiLine);
                    },
                    [202 /* NamedTupleMember */]: function visitEachChildOfNamedTupleMember(node, visitor, context, _nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updateNamedTupleMember(node, tokenVisitor ? nodeVisitor(node.dotDotDotToken, tokenVisitor, isDotDotDotToken) : node.dotDotDotToken, Debug.checkDefined(nodeVisitor(node.name, visitor, isIdentifier)), tokenVisitor ? nodeVisitor(node.questionToken, tokenVisitor, isQuestionToken) : node.questionToken, Debug.checkDefined(nodeVisitor(node.type, visitor, isTypeNode)));
                    },
                    [196 /* ParenthesizedType */]: function visitEachChildOfParenthesizedType(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateParenthesizedType(node, Debug.checkDefined(nodeVisitor(node.type, visitor, isTypeNode)));
                    },
                    [198 /* TypeOperator */]: function visitEachChildOfTypeOperatorNode(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTypeOperatorNode(node, Debug.checkDefined(nodeVisitor(node.type, visitor, isTypeNode)));
                    },
                    [199 /* IndexedAccessType */]: function visitEachChildOfIndexedAccessType(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateIndexedAccessTypeNode(node, Debug.checkDefined(nodeVisitor(node.objectType, visitor, isTypeNode)), Debug.checkDefined(nodeVisitor(node.indexType, visitor, isTypeNode)));
                    },
                    [200 /* MappedType */]: function visitEachChildOfMappedType(node, visitor, context, nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updateMappedTypeNode(node, tokenVisitor ? nodeVisitor(node.readonlyToken, tokenVisitor, isReadonlyKeywordOrPlusOrMinusToken) : node.readonlyToken, Debug.checkDefined(nodeVisitor(node.typeParameter, visitor, isTypeParameterDeclaration)), nodeVisitor(node.nameType, visitor, isTypeNode), tokenVisitor ? nodeVisitor(node.questionToken, tokenVisitor, isQuestionOrPlusOrMinusToken) : node.questionToken, nodeVisitor(node.type, visitor, isTypeNode), nodesVisitor(node.members, visitor, isTypeElement));
                    },
                    [201 /* LiteralType */]: function visitEachChildOfLiteralTypeNode(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateLiteralTypeNode(node, Debug.checkDefined(nodeVisitor(node.literal, visitor, isLiteralTypeLiteral)));
                    },
                    [203 /* TemplateLiteralType */]: function visitEachChildOfTemplateLiteralType(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTemplateLiteralType(node, Debug.checkDefined(nodeVisitor(node.head, visitor, isTemplateHead)), nodesVisitor(node.templateSpans, visitor, isTemplateLiteralTypeSpan));
                    },
                    [204 /* TemplateLiteralTypeSpan */]: function visitEachChildOfTemplateLiteralTypeSpan(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTemplateLiteralTypeSpan(node, Debug.checkDefined(nodeVisitor(node.type, visitor, isTypeNode)), Debug.checkDefined(nodeVisitor(node.literal, visitor, isTemplateMiddleOrTemplateTail)));
                    },
                    // Binding patterns
                    [206 /* ObjectBindingPattern */]: function visitEachChildOfObjectBindingPattern(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateObjectBindingPattern(node, nodesVisitor(node.elements, visitor, isBindingElement));
                    },
                    [207 /* ArrayBindingPattern */]: function visitEachChildOfArrayBindingPattern(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateArrayBindingPattern(node, nodesVisitor(node.elements, visitor, isArrayBindingElement));
                    },
                    [208 /* BindingElement */]: function visitEachChildOfBindingElement(node, visitor, context, _nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updateBindingElement(node, tokenVisitor ? nodeVisitor(node.dotDotDotToken, tokenVisitor, isDotDotDotToken) : node.dotDotDotToken, nodeVisitor(node.propertyName, visitor, isPropertyName), Debug.checkDefined(nodeVisitor(node.name, visitor, isBindingName)), nodeVisitor(node.initializer, visitor, isExpression));
                    },
                    // Expression
                    [209 /* ArrayLiteralExpression */]: function visitEachChildOfArrayLiteralExpression(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateArrayLiteralExpression(node, nodesVisitor(node.elements, visitor, isExpression));
                    },
                    [210 /* ObjectLiteralExpression */]: function visitEachChildOfObjectLiteralExpression(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateObjectLiteralExpression(node, nodesVisitor(node.properties, visitor, isObjectLiteralElementLike));
                    },
                    [211 /* PropertyAccessExpression */]: function visitEachChildOfPropertyAccessExpression(node, visitor, context, _nodesVisitor, nodeVisitor, tokenVisitor) {
                        return isPropertyAccessChain(node) ? context.factory.updatePropertyAccessChain(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), tokenVisitor ? nodeVisitor(node.questionDotToken, tokenVisitor, isQuestionDotToken) : node.questionDotToken, Debug.checkDefined(nodeVisitor(node.name, visitor, isMemberName))) : context.factory.updatePropertyAccessExpression(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), Debug.checkDefined(nodeVisitor(node.name, visitor, isMemberName)));
                    },
                    [212 /* ElementAccessExpression */]: function visitEachChildOfElementAccessExpression(node, visitor, context, _nodesVisitor, nodeVisitor, tokenVisitor) {
                        return isElementAccessChain(node) ? context.factory.updateElementAccessChain(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), tokenVisitor ? nodeVisitor(node.questionDotToken, tokenVisitor, isQuestionDotToken) : node.questionDotToken, Debug.checkDefined(nodeVisitor(node.argumentExpression, visitor, isExpression))) : context.factory.updateElementAccessExpression(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), Debug.checkDefined(nodeVisitor(node.argumentExpression, visitor, isExpression)));
                    },
                    [213 /* CallExpression */]: function visitEachChildOfCallExpression(node, visitor, context, nodesVisitor, nodeVisitor, tokenVisitor) {
                        return isCallChain(node) ? context.factory.updateCallChain(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), tokenVisitor ? nodeVisitor(node.questionDotToken, tokenVisitor, isQuestionDotToken) : node.questionDotToken, nodesVisitor(node.typeArguments, visitor, isTypeNode), nodesVisitor(node.arguments, visitor, isExpression)) : context.factory.updateCallExpression(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), nodesVisitor(node.typeArguments, visitor, isTypeNode), nodesVisitor(node.arguments, visitor, isExpression));
                    },
                    [214 /* NewExpression */]: function visitEachChildOfNewExpression(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateNewExpression(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), nodesVisitor(node.typeArguments, visitor, isTypeNode), nodesVisitor(node.arguments, visitor, isExpression));
                    },
                    [215 /* TaggedTemplateExpression */]: function visitEachChildOfTaggedTemplateExpression(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTaggedTemplateExpression(node, Debug.checkDefined(nodeVisitor(node.tag, visitor, isExpression)), nodesVisitor(node.typeArguments, visitor, isTypeNode), Debug.checkDefined(nodeVisitor(node.template, visitor, isTemplateLiteral)));
                    },
                    [216 /* TypeAssertionExpression */]: function visitEachChildOfTypeAssertionExpression(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTypeAssertion(node, Debug.checkDefined(nodeVisitor(node.type, visitor, isTypeNode)), Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    [217 /* ParenthesizedExpression */]: function visitEachChildOfParenthesizedExpression(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateParenthesizedExpression(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    [218 /* FunctionExpression */]: function visitEachChildOfFunctionExpression(node, visitor, context, nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updateFunctionExpression(node, nodesVisitor(node.modifiers, visitor, isModifier), tokenVisitor ? nodeVisitor(node.asteriskToken, tokenVisitor, isAsteriskToken) : node.asteriskToken, nodeVisitor(node.name, visitor, isIdentifier), nodesVisitor(node.typeParameters, visitor, isTypeParameterDeclaration), visitParameterList(node.parameters, visitor, context, nodesVisitor), nodeVisitor(node.type, visitor, isTypeNode), visitFunctionBody(node.body, visitor, context, nodeVisitor));
                    },
                    [219 /* ArrowFunction */]: function visitEachChildOfArrowFunction(node, visitor, context, nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updateArrowFunction(node, nodesVisitor(node.modifiers, visitor, isModifier), nodesVisitor(node.typeParameters, visitor, isTypeParameterDeclaration), visitParameterList(node.parameters, visitor, context, nodesVisitor), nodeVisitor(node.type, visitor, isTypeNode), tokenVisitor ? Debug.checkDefined(nodeVisitor(node.equalsGreaterThanToken, tokenVisitor, isEqualsGreaterThanToken)) : node.equalsGreaterThanToken, visitFunctionBody(node.body, visitor, context, nodeVisitor));
                    },
                    [220 /* DeleteExpression */]: function visitEachChildOfDeleteExpression(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateDeleteExpression(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    [221 /* TypeOfExpression */]: function visitEachChildOfTypeOfExpression(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTypeOfExpression(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    [222 /* VoidExpression */]: function visitEachChildOfVoidExpression(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateVoidExpression(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    [223 /* AwaitExpression */]: function visitEachChildOfAwaitExpression(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateAwaitExpression(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    [224 /* PrefixUnaryExpression */]: function visitEachChildOfPrefixUnaryExpression(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updatePrefixUnaryExpression(node, Debug.checkDefined(nodeVisitor(node.operand, visitor, isExpression)));
                    },
                    [225 /* PostfixUnaryExpression */]: function visitEachChildOfPostfixUnaryExpression(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updatePostfixUnaryExpression(node, Debug.checkDefined(nodeVisitor(node.operand, visitor, isExpression)));
                    },
                    [226 /* BinaryExpression */]: function visitEachChildOfBinaryExpression(node, visitor, context, _nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updateBinaryExpression(node, Debug.checkDefined(nodeVisitor(node.left, visitor, isExpression)), tokenVisitor ? Debug.checkDefined(nodeVisitor(node.operatorToken, tokenVisitor, isBinaryOperatorToken)) : node.operatorToken, Debug.checkDefined(nodeVisitor(node.right, visitor, isExpression)));
                    },
                    [227 /* ConditionalExpression */]: function visitEachChildOfConditionalExpression(node, visitor, context, _nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updateConditionalExpression(node, Debug.checkDefined(nodeVisitor(node.condition, visitor, isExpression)), tokenVisitor ? Debug.checkDefined(nodeVisitor(node.questionToken, tokenVisitor, isQuestionToken)) : node.questionToken, Debug.checkDefined(nodeVisitor(node.whenTrue, visitor, isExpression)), tokenVisitor ? Debug.checkDefined(nodeVisitor(node.colonToken, tokenVisitor, isColonToken)) : node.colonToken, Debug.checkDefined(nodeVisitor(node.whenFalse, visitor, isExpression)));
                    },
                    [228 /* TemplateExpression */]: function visitEachChildOfTemplateExpression(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTemplateExpression(node, Debug.checkDefined(nodeVisitor(node.head, visitor, isTemplateHead)), nodesVisitor(node.templateSpans, visitor, isTemplateSpan));
                    },
                    [229 /* YieldExpression */]: function visitEachChildOfYieldExpression(node, visitor, context, _nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updateYieldExpression(node, tokenVisitor ? nodeVisitor(node.asteriskToken, tokenVisitor, isAsteriskToken) : node.asteriskToken, nodeVisitor(node.expression, visitor, isExpression));
                    },
                    [230 /* SpreadElement */]: function visitEachChildOfSpreadElement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateSpreadElement(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    [231 /* ClassExpression */]: function visitEachChildOfClassExpression(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateClassExpression(node, nodesVisitor(node.modifiers, visitor, isModifierLike), nodeVisitor(node.name, visitor, isIdentifier), nodesVisitor(node.typeParameters, visitor, isTypeParameterDeclaration), nodesVisitor(node.heritageClauses, visitor, isHeritageClause), nodesVisitor(node.members, visitor, isClassElement));
                    },
                    [233 /* ExpressionWithTypeArguments */]: function visitEachChildOfExpressionWithTypeArguments(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateExpressionWithTypeArguments(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), nodesVisitor(node.typeArguments, visitor, isTypeNode));
                    },
                    [234 /* AsExpression */]: function visitEachChildOfAsExpression(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateAsExpression(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), Debug.checkDefined(nodeVisitor(node.type, visitor, isTypeNode)));
                    },
                    [238 /* SatisfiesExpression */]: function visitEachChildOfSatisfiesExpression(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateSatisfiesExpression(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), Debug.checkDefined(nodeVisitor(node.type, visitor, isTypeNode)));
                    },
                    [235 /* NonNullExpression */]: function visitEachChildOfNonNullExpression(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return isOptionalChain(node) ? context.factory.updateNonNullChain(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression))) : context.factory.updateNonNullExpression(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    [236 /* MetaProperty */]: function visitEachChildOfMetaProperty(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateMetaProperty(node, Debug.checkDefined(nodeVisitor(node.name, visitor, isIdentifier)));
                    },
                    // Misc
                    [239 /* TemplateSpan */]: function visitEachChildOfTemplateSpan(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTemplateSpan(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), Debug.checkDefined(nodeVisitor(node.literal, visitor, isTemplateMiddleOrTemplateTail)));
                    },
                    // Element
                    [241 /* Block */]: function visitEachChildOfBlock(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateBlock(node, nodesVisitor(node.statements, visitor, isStatement));
                    },
                    [243 /* VariableStatement */]: function visitEachChildOfVariableStatement(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateVariableStatement(node, nodesVisitor(node.modifiers, visitor, isModifierLike), Debug.checkDefined(nodeVisitor(node.declarationList, visitor, isVariableDeclarationList)));
                    },
                    [244 /* ExpressionStatement */]: function visitEachChildOfExpressionStatement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateExpressionStatement(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    [245 /* IfStatement */]: function visitEachChildOfIfStatement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateIfStatement(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), Debug.checkDefined(nodeVisitor(node.thenStatement, visitor, isStatement, context.factory.liftToBlock)), nodeVisitor(node.elseStatement, visitor, isStatement, context.factory.liftToBlock));
                    },
                    [246 /* DoStatement */]: function visitEachChildOfDoStatement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateDoStatement(node, visitIterationBody(node.statement, visitor, context, nodeVisitor), Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    [247 /* WhileStatement */]: function visitEachChildOfWhileStatement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateWhileStatement(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), visitIterationBody(node.statement, visitor, context, nodeVisitor));
                    },
                    [248 /* ForStatement */]: function visitEachChildOfForStatement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateForStatement(node, nodeVisitor(node.initializer, visitor, isForInitializer), nodeVisitor(node.condition, visitor, isExpression), nodeVisitor(node.incrementor, visitor, isExpression), visitIterationBody(node.statement, visitor, context, nodeVisitor));
                    },
                    [249 /* ForInStatement */]: function visitEachChildOfForInStatement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateForInStatement(node, Debug.checkDefined(nodeVisitor(node.initializer, visitor, isForInitializer)), Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), visitIterationBody(node.statement, visitor, context, nodeVisitor));
                    },
                    [250 /* ForOfStatement */]: function visitEachChildOfForOfStatement(node, visitor, context, _nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updateForOfStatement(node, tokenVisitor ? nodeVisitor(node.awaitModifier, tokenVisitor, isAwaitKeyword) : node.awaitModifier, Debug.checkDefined(nodeVisitor(node.initializer, visitor, isForInitializer)), Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), visitIterationBody(node.statement, visitor, context, nodeVisitor));
                    },
                    [251 /* ContinueStatement */]: function visitEachChildOfContinueStatement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateContinueStatement(node, nodeVisitor(node.label, visitor, isIdentifier));
                    },
                    [252 /* BreakStatement */]: function visitEachChildOfBreakStatement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateBreakStatement(node, nodeVisitor(node.label, visitor, isIdentifier));
                    },
                    [253 /* ReturnStatement */]: function visitEachChildOfReturnStatement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateReturnStatement(node, nodeVisitor(node.expression, visitor, isExpression));
                    },
                    [254 /* WithStatement */]: function visitEachChildOfWithStatement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateWithStatement(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), Debug.checkDefined(nodeVisitor(node.statement, visitor, isStatement, context.factory.liftToBlock)));
                    },
                    [255 /* SwitchStatement */]: function visitEachChildOfSwitchStatement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateSwitchStatement(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), Debug.checkDefined(nodeVisitor(node.caseBlock, visitor, isCaseBlock)));
                    },
                    [256 /* LabeledStatement */]: function visitEachChildOfLabeledStatement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateLabeledStatement(node, Debug.checkDefined(nodeVisitor(node.label, visitor, isIdentifier)), Debug.checkDefined(nodeVisitor(node.statement, visitor, isStatement, context.factory.liftToBlock)));
                    },
                    [257 /* ThrowStatement */]: function visitEachChildOfThrowStatement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateThrowStatement(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    [258 /* TryStatement */]: function visitEachChildOfTryStatement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTryStatement(node, Debug.checkDefined(nodeVisitor(node.tryBlock, visitor, isBlock)), nodeVisitor(node.catchClause, visitor, isCatchClause), nodeVisitor(node.finallyBlock, visitor, isBlock));
                    },
                    [260 /* VariableDeclaration */]: function visitEachChildOfVariableDeclaration(node, visitor, context, _nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updateVariableDeclaration(node, Debug.checkDefined(nodeVisitor(node.name, visitor, isBindingName)), tokenVisitor ? nodeVisitor(node.exclamationToken, tokenVisitor, isExclamationToken) : node.exclamationToken, nodeVisitor(node.type, visitor, isTypeNode), nodeVisitor(node.initializer, visitor, isExpression));
                    },
                    [261 /* VariableDeclarationList */]: function visitEachChildOfVariableDeclarationList(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateVariableDeclarationList(node, nodesVisitor(node.declarations, visitor, isVariableDeclaration));
                    },
                    [262 /* FunctionDeclaration */]: function visitEachChildOfFunctionDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, tokenVisitor) {
                        return context.factory.updateFunctionDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifier), tokenVisitor ? nodeVisitor(node.asteriskToken, tokenVisitor, isAsteriskToken) : node.asteriskToken, nodeVisitor(node.name, visitor, isIdentifier), nodesVisitor(node.typeParameters, visitor, isTypeParameterDeclaration), visitParameterList(node.parameters, visitor, context, nodesVisitor), nodeVisitor(node.type, visitor, isTypeNode), visitFunctionBody(node.body, visitor, context, nodeVisitor));
                    },
                    [263 /* ClassDeclaration */]: function visitEachChildOfClassDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateClassDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifierLike), nodeVisitor(node.name, visitor, isIdentifier), nodesVisitor(node.typeParameters, visitor, isTypeParameterDeclaration), nodesVisitor(node.heritageClauses, visitor, isHeritageClause), nodesVisitor(node.members, visitor, isClassElement));
                    },
                    [264 /* InterfaceDeclaration */]: function visitEachChildOfInterfaceDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateInterfaceDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifierLike), Debug.checkDefined(nodeVisitor(node.name, visitor, isIdentifier)), nodesVisitor(node.typeParameters, visitor, isTypeParameterDeclaration), nodesVisitor(node.heritageClauses, visitor, isHeritageClause), nodesVisitor(node.members, visitor, isTypeElement));
                    },
                    [265 /* TypeAliasDeclaration */]: function visitEachChildOfTypeAliasDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateTypeAliasDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifierLike), Debug.checkDefined(nodeVisitor(node.name, visitor, isIdentifier)), nodesVisitor(node.typeParameters, visitor, isTypeParameterDeclaration), Debug.checkDefined(nodeVisitor(node.type, visitor, isTypeNode)));
                    },
                    [266 /* EnumDeclaration */]: function visitEachChildOfEnumDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateEnumDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifierLike), Debug.checkDefined(nodeVisitor(node.name, visitor, isIdentifier)), nodesVisitor(node.members, visitor, isEnumMember));
                    },
                    [267 /* ModuleDeclaration */]: function visitEachChildOfModuleDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateModuleDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifierLike), Debug.checkDefined(nodeVisitor(node.name, visitor, isModuleName)), nodeVisitor(node.body, visitor, isModuleBody));
                    },
                    [268 /* ModuleBlock */]: function visitEachChildOfModuleBlock(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateModuleBlock(node, nodesVisitor(node.statements, visitor, isStatement));
                    },
                    [269 /* CaseBlock */]: function visitEachChildOfCaseBlock(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateCaseBlock(node, nodesVisitor(node.clauses, visitor, isCaseOrDefaultClause));
                    },
                    [270 /* NamespaceExportDeclaration */]: function visitEachChildOfNamespaceExportDeclaration(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateNamespaceExportDeclaration(node, Debug.checkDefined(nodeVisitor(node.name, visitor, isIdentifier)));
                    },
                    [271 /* ImportEqualsDeclaration */]: function visitEachChildOfImportEqualsDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateImportEqualsDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifierLike), node.isTypeOnly, Debug.checkDefined(nodeVisitor(node.name, visitor, isIdentifier)), Debug.checkDefined(nodeVisitor(node.moduleReference, visitor, isModuleReference)));
                    },
                    [272 /* ImportDeclaration */]: function visitEachChildOfImportDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateImportDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifierLike), nodeVisitor(node.importClause, visitor, isImportClause), Debug.checkDefined(nodeVisitor(node.moduleSpecifier, visitor, isExpression)), nodeVisitor(node.attributes, visitor, isImportAttributes));
                    },
                    [300 /* ImportAttributes */]: function visitEachChildOfImportAttributes(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateImportAttributes(node, nodesVisitor(node.elements, visitor, isImportAttribute), node.multiLine);
                    },
                    [301 /* ImportAttribute */]: function visitEachChildOfImportAttribute(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateImportAttribute(node, Debug.checkDefined(nodeVisitor(node.name, visitor, isImportAttributeName)), Debug.checkDefined(nodeVisitor(node.value, visitor, isExpression)));
                    },
                    [273 /* ImportClause */]: function visitEachChildOfImportClause(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateImportClause(node, node.isTypeOnly, nodeVisitor(node.name, visitor, isIdentifier), nodeVisitor(node.namedBindings, visitor, isNamedImportBindings));
                    },
                    [274 /* NamespaceImport */]: function visitEachChildOfNamespaceImport(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateNamespaceImport(node, Debug.checkDefined(nodeVisitor(node.name, visitor, isIdentifier)));
                    },
                    [280 /* NamespaceExport */]: function visitEachChildOfNamespaceExport(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateNamespaceExport(node, Debug.checkDefined(nodeVisitor(node.name, visitor, isIdentifier)));
                    },
                    [275 /* NamedImports */]: function visitEachChildOfNamedImports(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateNamedImports(node, nodesVisitor(node.elements, visitor, isImportSpecifier));
                    },
                    [276 /* ImportSpecifier */]: function visitEachChildOfImportSpecifier(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateImportSpecifier(node, node.isTypeOnly, nodeVisitor(node.propertyName, visitor, isIdentifier), Debug.checkDefined(nodeVisitor(node.name, visitor, isIdentifier)));
                    },
                    [277 /* ExportAssignment */]: function visitEachChildOfExportAssignment(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateExportAssignment(node, nodesVisitor(node.modifiers, visitor, isModifierLike), Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    [278 /* ExportDeclaration */]: function visitEachChildOfExportDeclaration(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateExportDeclaration(node, nodesVisitor(node.modifiers, visitor, isModifierLike), node.isTypeOnly, nodeVisitor(node.exportClause, visitor, isNamedExportBindings), nodeVisitor(node.moduleSpecifier, visitor, isExpression), nodeVisitor(node.attributes, visitor, isImportAttributes));
                    },
                    [279 /* NamedExports */]: function visitEachChildOfNamedExports(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateNamedExports(node, nodesVisitor(node.elements, visitor, isExportSpecifier));
                    },
                    [281 /* ExportSpecifier */]: function visitEachChildOfExportSpecifier(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateExportSpecifier(node, node.isTypeOnly, nodeVisitor(node.propertyName, visitor, isIdentifier), Debug.checkDefined(nodeVisitor(node.name, visitor, isIdentifier)));
                    },
                    // Module references
                    [283 /* ExternalModuleReference */]: function visitEachChildOfExternalModuleReference(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateExternalModuleReference(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    // JSX
                    [284 /* JsxElement */]: function visitEachChildOfJsxElement(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateJsxElement(node, Debug.checkDefined(nodeVisitor(node.openingElement, visitor, isJsxOpeningElement)), nodesVisitor(node.children, visitor, isJsxChild), Debug.checkDefined(nodeVisitor(node.closingElement, visitor, isJsxClosingElement)));
                    },
                    [285 /* JsxSelfClosingElement */]: function visitEachChildOfJsxSelfClosingElement(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateJsxSelfClosingElement(node, Debug.checkDefined(nodeVisitor(node.tagName, visitor, isJsxTagNameExpression)), nodesVisitor(node.typeArguments, visitor, isTypeNode), Debug.checkDefined(nodeVisitor(node.attributes, visitor, isJsxAttributes)));
                    },
                    [286 /* JsxOpeningElement */]: function visitEachChildOfJsxOpeningElement(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateJsxOpeningElement(node, Debug.checkDefined(nodeVisitor(node.tagName, visitor, isJsxTagNameExpression)), nodesVisitor(node.typeArguments, visitor, isTypeNode), Debug.checkDefined(nodeVisitor(node.attributes, visitor, isJsxAttributes)));
                    },
                    [287 /* JsxClosingElement */]: function visitEachChildOfJsxClosingElement(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateJsxClosingElement(node, Debug.checkDefined(nodeVisitor(node.tagName, visitor, isJsxTagNameExpression)));
                    },
                    [295 /* JsxNamespacedName */]: function forEachChildInJsxNamespacedName2(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateJsxNamespacedName(node, Debug.checkDefined(nodeVisitor(node.namespace, visitor, isIdentifier)), Debug.checkDefined(nodeVisitor(node.name, visitor, isIdentifier)));
                    },
                    [288 /* JsxFragment */]: function visitEachChildOfJsxFragment(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateJsxFragment(node, Debug.checkDefined(nodeVisitor(node.openingFragment, visitor, isJsxOpeningFragment)), nodesVisitor(node.children, visitor, isJsxChild), Debug.checkDefined(nodeVisitor(node.closingFragment, visitor, isJsxClosingFragment)));
                    },
                    [291 /* JsxAttribute */]: function visitEachChildOfJsxAttribute(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateJsxAttribute(node, Debug.checkDefined(nodeVisitor(node.name, visitor, isJsxAttributeName)), nodeVisitor(node.initializer, visitor, isStringLiteralOrJsxExpression));
                    },
                    [292 /* JsxAttributes */]: function visitEachChildOfJsxAttributes(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateJsxAttributes(node, nodesVisitor(node.properties, visitor, isJsxAttributeLike));
                    },
                    [293 /* JsxSpreadAttribute */]: function visitEachChildOfJsxSpreadAttribute(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateJsxSpreadAttribute(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    [294 /* JsxExpression */]: function visitEachChildOfJsxExpression(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateJsxExpression(node, nodeVisitor(node.expression, visitor, isExpression));
                    },
                    // Clauses
                    [296 /* CaseClause */]: function visitEachChildOfCaseClause(node, visitor, context, nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateCaseClause(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)), nodesVisitor(node.statements, visitor, isStatement));
                    },
                    [297 /* DefaultClause */]: function visitEachChildOfDefaultClause(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateDefaultClause(node, nodesVisitor(node.statements, visitor, isStatement));
                    },
                    [298 /* HeritageClause */]: function visitEachChildOfHeritageClause(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateHeritageClause(node, nodesVisitor(node.types, visitor, isExpressionWithTypeArguments));
                    },
                    [299 /* CatchClause */]: function visitEachChildOfCatchClause(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateCatchClause(node, nodeVisitor(node.variableDeclaration, visitor, isVariableDeclaration), Debug.checkDefined(nodeVisitor(node.block, visitor, isBlock)));
                    },
                    // Property assignments
                    [303 /* PropertyAssignment */]: function visitEachChildOfPropertyAssignment(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updatePropertyAssignment(node, Debug.checkDefined(nodeVisitor(node.name, visitor, isPropertyName)), Debug.checkDefined(nodeVisitor(node.initializer, visitor, isExpression)));
                    },
                    [304 /* ShorthandPropertyAssignment */]: function visitEachChildOfShorthandPropertyAssignment(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateShorthandPropertyAssignment(node, Debug.checkDefined(nodeVisitor(node.name, visitor, isIdentifier)), nodeVisitor(node.objectAssignmentInitializer, visitor, isExpression));
                    },
                    [305 /* SpreadAssignment */]: function visitEachChildOfSpreadAssignment(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateSpreadAssignment(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    // Enum
                    [306 /* EnumMember */]: function visitEachChildOfEnumMember(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updateEnumMember(node, Debug.checkDefined(nodeVisitor(node.name, visitor, isPropertyName)), nodeVisitor(node.initializer, visitor, isExpression));
                    },
                    // Top-level nodes
                    [312 /* SourceFile */]: function visitEachChildOfSourceFile(node, visitor, context, _nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateSourceFile(node, visitLexicalEnvironment(node.statements, visitor, context));
                    },
                    // Transformation nodes
                    [360 /* PartiallyEmittedExpression */]: function visitEachChildOfPartiallyEmittedExpression(node, visitor, context, _nodesVisitor, nodeVisitor, _tokenVisitor) {
                        return context.factory.updatePartiallyEmittedExpression(node, Debug.checkDefined(nodeVisitor(node.expression, visitor, isExpression)));
                    },
                    [361 /* CommaListExpression */]: function visitEachChildOfCommaListExpression(node, visitor, context, nodesVisitor, _nodeVisitor, _tokenVisitor) {
                        return context.factory.updateCommaListExpression(node, nodesVisitor(node.elements, visitor, isExpression));
                    }
                };
            }
        });
        // src/compiler/sourcemap.ts
        function createSourceMapGenerator(host, file, sourceRoot, sourcesDirectoryPath, generatorOptions) {
            var { enter, exit } = generatorOptions.extendedDiagnostics ? createTimer("Source Map", "beforeSourcemap", "afterSourcemap") : nullTimer;
            var rawSources = [];
            var sources = [];
            var sourceToSourceIndexMap = /* @__PURE__ */ new Map();
            var sourcesContent;
            var names = [];
            var nameToNameIndexMap;
            var mappingCharCodes = [];
            var mappings = "";
            var lastGeneratedLine = 0;
            var lastGeneratedCharacter = 0;
            var lastSourceIndex = 0;
            var lastSourceLine = 0;
            var lastSourceCharacter = 0;
            var lastNameIndex = 0;
            var hasLast = false;
            var pendingGeneratedLine = 0;
            var pendingGeneratedCharacter = 0;
            var pendingSourceIndex = 0;
            var pendingSourceLine = 0;
            var pendingSourceCharacter = 0;
            var pendingNameIndex = 0;
            var hasPending = false;
            var hasPendingSource = false;
            var hasPendingName = false;
            return {
                getSources: () => rawSources,
                addSource,
                setSourceContent,
                addName,
                addMapping,
                appendSourceMap,
                toJSON,
                toString: () => JSON.stringify(toJSON())
            };
            function addSource(fileName) {
                enter();
                const source = getRelativePathToDirectoryOrUrl(sourcesDirectoryPath, fileName, host.getCurrentDirectory(), host.getCanonicalFileName, 
                /*isAbsolutePathAnUrl*/
                true);
                let sourceIndex = sourceToSourceIndexMap.get(source);
                if (sourceIndex === void 0) {
                    sourceIndex = sources.length;
                    sources.push(source);
                    rawSources.push(fileName);
                    sourceToSourceIndexMap.set(source, sourceIndex);
                }
                exit();
                return sourceIndex;
            }
            function setSourceContent(sourceIndex, content) {
                enter();
                if (content !== null) {
                    if (!sourcesContent)
                        sourcesContent = [];
                    while (sourcesContent.length < sourceIndex) {
                        sourcesContent.push(null);
                    }
                    sourcesContent[sourceIndex] = content;
                }
                exit();
            }
            function addName(name) {
                enter();
                if (!nameToNameIndexMap)
                    nameToNameIndexMap = /* @__PURE__ */ new Map();
                let nameIndex = nameToNameIndexMap.get(name);
                if (nameIndex === void 0) {
                    nameIndex = names.length;
                    names.push(name);
                    nameToNameIndexMap.set(name, nameIndex);
                }
                exit();
                return nameIndex;
            }
            function isNewGeneratedPosition(generatedLine, generatedCharacter) {
                return !hasPending || pendingGeneratedLine !== generatedLine || pendingGeneratedCharacter !== generatedCharacter;
            }
            function isBacktrackingSourcePosition(sourceIndex, sourceLine, sourceCharacter) {
                return sourceIndex !== void 0 && sourceLine !== void 0 && sourceCharacter !== void 0 && pendingSourceIndex === sourceIndex && (pendingSourceLine > sourceLine || pendingSourceLine === sourceLine && pendingSourceCharacter > sourceCharacter);
            }
            function addMapping(generatedLine, generatedCharacter, sourceIndex, sourceLine, sourceCharacter, nameIndex) {
                Debug.assert(generatedLine >= pendingGeneratedLine, "generatedLine cannot backtrack");
                Debug.assert(generatedCharacter >= 0, "generatedCharacter cannot be negative");
                Debug.assert(sourceIndex === void 0 || sourceIndex >= 0, "sourceIndex cannot be negative");
                Debug.assert(sourceLine === void 0 || sourceLine >= 0, "sourceLine cannot be negative");
                Debug.assert(sourceCharacter === void 0 || sourceCharacter >= 0, "sourceCharacter cannot be negative");
                enter();
                if (isNewGeneratedPosition(generatedLine, generatedCharacter) || isBacktrackingSourcePosition(sourceIndex, sourceLine, sourceCharacter)) {
                    commitPendingMapping();
                    pendingGeneratedLine = generatedLine;
                    pendingGeneratedCharacter = generatedCharacter;
                    hasPendingSource = false;
                    hasPendingName = false;
                    hasPending = true;
                }
                if (sourceIndex !== void 0 && sourceLine !== void 0 && sourceCharacter !== void 0) {
                    pendingSourceIndex = sourceIndex;
                    pendingSourceLine = sourceLine;
                    pendingSourceCharacter = sourceCharacter;
                    hasPendingSource = true;
                    if (nameIndex !== void 0) {
                        pendingNameIndex = nameIndex;
                        hasPendingName = true;
                    }
                }
                exit();
            }
            function appendSourceMap(generatedLine, generatedCharacter, map2, sourceMapPath, start, end) {
                Debug.assert(generatedLine >= pendingGeneratedLine, "generatedLine cannot backtrack");
                Debug.assert(generatedCharacter >= 0, "generatedCharacter cannot be negative");
                enter();
                const sourceIndexToNewSourceIndexMap = [];
                let nameIndexToNewNameIndexMap;
                const mappingIterator = decodeMappings(map2.mappings);
                for (const raw of mappingIterator) {
                    if (end && (raw.generatedLine > end.line || raw.generatedLine === end.line && raw.generatedCharacter > end.character)) {
                        break;
                    }
                    if (start && (raw.generatedLine < start.line || start.line === raw.generatedLine && raw.generatedCharacter < start.character)) {
                        continue;
                    }
                    let newSourceIndex;
                    let newSourceLine;
                    let newSourceCharacter;
                    let newNameIndex;
                    if (raw.sourceIndex !== void 0) {
                        newSourceIndex = sourceIndexToNewSourceIndexMap[raw.sourceIndex];
                        if (newSourceIndex === void 0) {
                            const rawPath = map2.sources[raw.sourceIndex];
                            const relativePath = map2.sourceRoot ? combinePaths(map2.sourceRoot, rawPath) : rawPath;
                            const combinedPath = combinePaths(getDirectoryPath(sourceMapPath), relativePath);
                            sourceIndexToNewSourceIndexMap[raw.sourceIndex] = newSourceIndex = addSource(combinedPath);
                            if (map2.sourcesContent && typeof map2.sourcesContent[raw.sourceIndex] === "string") {
                                setSourceContent(newSourceIndex, map2.sourcesContent[raw.sourceIndex]);
                            }
                        }
                        newSourceLine = raw.sourceLine;
                        newSourceCharacter = raw.sourceCharacter;
                        if (map2.names && raw.nameIndex !== void 0) {
                            if (!nameIndexToNewNameIndexMap)
                                nameIndexToNewNameIndexMap = [];
                            newNameIndex = nameIndexToNewNameIndexMap[raw.nameIndex];
                            if (newNameIndex === void 0) {
                                nameIndexToNewNameIndexMap[raw.nameIndex] = newNameIndex = addName(map2.names[raw.nameIndex]);
                            }
                        }
                    }
                    const rawGeneratedLine = raw.generatedLine - (start ? start.line : 0);
                    const newGeneratedLine = rawGeneratedLine + generatedLine;
                    const rawGeneratedCharacter = start && start.line === raw.generatedLine ? raw.generatedCharacter - start.character : raw.generatedCharacter;
                    const newGeneratedCharacter = rawGeneratedLine === 0 ? rawGeneratedCharacter + generatedCharacter : rawGeneratedCharacter;
                    addMapping(newGeneratedLine, newGeneratedCharacter, newSourceIndex, newSourceLine, newSourceCharacter, newNameIndex);
                }
                exit();
            }
            function shouldCommitMapping() {
                return !hasLast || lastGeneratedLine !== pendingGeneratedLine || lastGeneratedCharacter !== pendingGeneratedCharacter || lastSourceIndex !== pendingSourceIndex || lastSourceLine !== pendingSourceLine || lastSourceCharacter !== pendingSourceCharacter || lastNameIndex !== pendingNameIndex;
            }
            function appendMappingCharCode(charCode) {
                mappingCharCodes.push(charCode);
                if (mappingCharCodes.length >= 1024) {
                    flushMappingBuffer();
                }
            }
            function commitPendingMapping() {
                if (!hasPending || !shouldCommitMapping()) {
                    return;
                }
                enter();
                if (lastGeneratedLine < pendingGeneratedLine) {
                    do {
                        appendMappingCharCode(59 /* semicolon */);
                        lastGeneratedLine++;
                    } while (lastGeneratedLine < pendingGeneratedLine);
                    lastGeneratedCharacter = 0;
                }
                else {
                    Debug.assertEqual(lastGeneratedLine, pendingGeneratedLine, "generatedLine cannot backtrack");
                    if (hasLast) {
                        appendMappingCharCode(44 /* comma */);
                    }
                }
                appendBase64VLQ(pendingGeneratedCharacter - lastGeneratedCharacter);
                lastGeneratedCharacter = pendingGeneratedCharacter;
                if (hasPendingSource) {
                    appendBase64VLQ(pendingSourceIndex - lastSourceIndex);
                    lastSourceIndex = pendingSourceIndex;
                    appendBase64VLQ(pendingSourceLine - lastSourceLine);
                    lastSourceLine = pendingSourceLine;
                    appendBase64VLQ(pendingSourceCharacter - lastSourceCharacter);
                    lastSourceCharacter = pendingSourceCharacter;
                    if (hasPendingName) {
                        appendBase64VLQ(pendingNameIndex - lastNameIndex);
                        lastNameIndex = pendingNameIndex;
                    }
                }
                hasLast = true;
                exit();
            }
            function flushMappingBuffer() {
                if (mappingCharCodes.length > 0) {
                    mappings += String.fromCharCode.apply(void 0, mappingCharCodes);
                    mappingCharCodes.length = 0;
                }
            }
            function toJSON() {
                commitPendingMapping();
                flushMappingBuffer();
                return {
                    version: 3,
                    file,
                    sourceRoot,
                    sources,
                    names,
                    mappings,
                    sourcesContent
                };
            }
            function appendBase64VLQ(inValue) {
                if (inValue < 0) {
                    inValue = (-inValue << 1) + 1;
                }
                else {
                    inValue = inValue << 1;
                }
                do {
                    let currentDigit = inValue & 31;
                    inValue = inValue >> 5;
                    if (inValue > 0) {
                        currentDigit = currentDigit | 32;
                    }
                    appendMappingCharCode(base64FormatEncode(currentDigit));
                } while (inValue > 0);
            }
        }
        function getLineInfo(text, lineStarts) {
            return {
                getLineCount: () => lineStarts.length,
                getLineText: (line) => text.substring(lineStarts[line], lineStarts[line + 1])
            };
        }
        function tryGetSourceMappingURL(lineInfo) {
            for (let index = lineInfo.getLineCount() - 1; index >= 0; index--) {
                const line = lineInfo.getLineText(index);
                const comment = sourceMapCommentRegExp.exec(line);
                if (comment) {
                    return comment[1].trimEnd();
                }
                else if (!line.match(whitespaceOrMapCommentRegExp)) {
                    break;
                }
            }
        }
        function isStringOrNull(x) {
            return typeof x === "string" || x === null;
        }
        function isRawSourceMap(x) {
            return x !== null && typeof x === "object" && x.version === 3 && typeof x.file === "string" && typeof x.mappings === "string" && isArray(x.sources) && every(x.sources, isString) && (x.sourceRoot === void 0 || x.sourceRoot === null || typeof x.sourceRoot === "string") && (x.sourcesContent === void 0 || x.sourcesContent === null || isArray(x.sourcesContent) && every(x.sourcesContent, isStringOrNull)) && (x.names === void 0 || x.names === null || isArray(x.names) && every(x.names, isString));
        }
        function tryParseRawSourceMap(text) {
            try {
                const parsed = JSON.parse(text);
                if (isRawSourceMap(parsed)) {
                    return parsed;
                }
            }
            catch {
            }
            return void 0;
        }
        function decodeMappings(mappings) {
            let done = false;
            let pos = 0;
            let generatedLine = 0;
            let generatedCharacter = 0;
            let sourceIndex = 0;
            let sourceLine = 0;
            let sourceCharacter = 0;
            let nameIndex = 0;
            let error2;
            return {
                get pos() {
                    return pos;
                },
                get error() {
                    return error2;
                },
                get state() {
                    return captureMapping(
                    /*hasSource*/
                    true, 
                    /*hasName*/
                    true);
                },
                next() {
                    while (!done && pos < mappings.length) {
                        const ch = mappings.charCodeAt(pos);
                        if (ch === 59 /* semicolon */) {
                            generatedLine++;
                            generatedCharacter = 0;
                            pos++;
                            continue;
                        }
                        if (ch === 44 /* comma */) {
                            pos++;
                            continue;
                        }
                        let hasSource = false;
                        let hasName = false;
                        generatedCharacter += base64VLQFormatDecode();
                        if (hasReportedError())
                            return stopIterating();
                        if (generatedCharacter < 0)
                            return setErrorAndStopIterating("Invalid generatedCharacter found");
                        if (!isSourceMappingSegmentEnd()) {
                            hasSource = true;
                            sourceIndex += base64VLQFormatDecode();
                            if (hasReportedError())
                                return stopIterating();
                            if (sourceIndex < 0)
                                return setErrorAndStopIterating("Invalid sourceIndex found");
                            if (isSourceMappingSegmentEnd())
                                return setErrorAndStopIterating("Unsupported Format: No entries after sourceIndex");
                            sourceLine += base64VLQFormatDecode();
                            if (hasReportedError())
                                return stopIterating();
                            if (sourceLine < 0)
                                return setErrorAndStopIterating("Invalid sourceLine found");
                            if (isSourceMappingSegmentEnd())
                                return setErrorAndStopIterating("Unsupported Format: No entries after sourceLine");
                            sourceCharacter += base64VLQFormatDecode();
                            if (hasReportedError())
                                return stopIterating();
                            if (sourceCharacter < 0)
                                return setErrorAndStopIterating("Invalid sourceCharacter found");
                            if (!isSourceMappingSegmentEnd()) {
                                hasName = true;
                                nameIndex += base64VLQFormatDecode();
                                if (hasReportedError())
                                    return stopIterating();
                                if (nameIndex < 0)
                                    return setErrorAndStopIterating("Invalid nameIndex found");
                                if (!isSourceMappingSegmentEnd())
                                    return setErrorAndStopIterating("Unsupported Error Format: Entries after nameIndex");
                            }
                        }
                        return { value: captureMapping(hasSource, hasName), done };
                    }
                    return stopIterating();
                },
                [Symbol.iterator]() {
                    return this;
                }
            };
            function captureMapping(hasSource, hasName) {
                return {
                    generatedLine,
                    generatedCharacter,
                    sourceIndex: hasSource ? sourceIndex : void 0,
                    sourceLine: hasSource ? sourceLine : void 0,
                    sourceCharacter: hasSource ? sourceCharacter : void 0,
                    nameIndex: hasName ? nameIndex : void 0
                };
            }
            function stopIterating() {
                done = true;
                return { value: void 0, done: true };
            }
            function setError(message) {
                if (error2 === void 0) {
                    error2 = message;
                }
            }
            function setErrorAndStopIterating(message) {
                setError(message);
                return stopIterating();
            }
            function hasReportedError() {
                return error2 !== void 0;
            }
            function isSourceMappingSegmentEnd() {
                return pos === mappings.length || mappings.charCodeAt(pos) === 44 /* comma */ || mappings.charCodeAt(pos) === 59 /* semicolon */;
            }
            function base64VLQFormatDecode() {
                let moreDigits = true;
                let shiftCount = 0;
                let value = 0;
                for (; moreDigits; pos++) {
                    if (pos >= mappings.length)
                        return setError("Error in decoding base64VLQFormatDecode, past the mapping string"), -1;
                    const currentByte = base64FormatDecode(mappings.charCodeAt(pos));
                    if (currentByte === -1)
                        return setError("Invalid character in VLQ"), -1;
                    moreDigits = (currentByte & 32) !== 0;
                    value = value | (currentByte & 31) << shiftCount;
                    shiftCount += 5;
                }
                if ((value & 1) === 0) {
                    value = value >> 1;
                }
                else {
                    value = value >> 1;
                    value = -value;
                }
                return value;
            }
        }
        function sameMapping(left, right) {
            return left === right || left.generatedLine === right.generatedLine && left.generatedCharacter === right.generatedCharacter && left.sourceIndex === right.sourceIndex && left.sourceLine === right.sourceLine && left.sourceCharacter === right.sourceCharacter && left.nameIndex === right.nameIndex;
        }
        function isSourceMapping(mapping) {
            return mapping.sourceIndex !== void 0 && mapping.sourceLine !== void 0 && mapping.sourceCharacter !== void 0;
        }
        function base64FormatEncode(value) {
            return value >= 0 && value < 26 ? 65 /* A */ + value : value >= 26 && value < 52 ? 97 /* a */ + value - 26 : value >= 52 && value < 62 ? 48 /* _0 */ + value - 52 : value === 62 ? 43 /* plus */ : value === 63 ? 47 /* slash */ : Debug.fail(`${value}: not a base64 value`);
        }
        function base64FormatDecode(ch) {
            return ch >= 65 /* A */ && ch <= 90 /* Z */ ? ch - 65 /* A */ : ch >= 97 /* a */ && ch <= 122 /* z */ ? ch - 97 /* a */ + 26 : ch >= 48 /* _0 */ && ch <= 57 /* _9 */ ? ch - 48 /* _0 */ + 52 : ch === 43 /* plus */ ? 62 : ch === 47 /* slash */ ? 63 : -1;
        }
        function isSourceMappedPosition(value) {
            return value.sourceIndex !== void 0 && value.sourcePosition !== void 0;
        }
        function sameMappedPosition(left, right) {
            return left.generatedPosition === right.generatedPosition && left.sourceIndex === right.sourceIndex && left.sourcePosition === right.sourcePosition;
        }
        function compareSourcePositions(left, right) {
            Debug.assert(left.sourceIndex === right.sourceIndex);
            return compareValues(left.sourcePosition, right.sourcePosition);
        }
        function compareGeneratedPositions(left, right) {
            return compareValues(left.generatedPosition, right.generatedPosition);
        }
        function getSourcePositionOfMapping(value) {
            return value.sourcePosition;
        }
        function getGeneratedPositionOfMapping(value) {
            return value.generatedPosition;
        }
        function createDocumentPositionMapper(host, map2, mapPath) {
            const mapDirectory = getDirectoryPath(mapPath);
            const sourceRoot = map2.sourceRoot ? getNormalizedAbsolutePath(map2.sourceRoot, mapDirectory) : mapDirectory;
            const generatedAbsoluteFilePath = getNormalizedAbsolutePath(map2.file, mapDirectory);
            const generatedFile = host.getSourceFileLike(generatedAbsoluteFilePath);
            const sourceFileAbsolutePaths = map2.sources.map((source) => getNormalizedAbsolutePath(source, sourceRoot));
            const sourceToSourceIndexMap = new Map(sourceFileAbsolutePaths.map((source, i) => [host.getCanonicalFileName(source), i]));
            let decodedMappings;
            let generatedMappings;
            let sourceMappings;
            return {
                getSourcePosition,
                getGeneratedPosition
            };
            function processMapping(mapping) {
                const generatedPosition = generatedFile !== void 0 ? getPositionOfLineAndCharacter(generatedFile, mapping.generatedLine, mapping.generatedCharacter, 
                /*allowEdits*/
                true) : -1;
                let source;
                let sourcePosition;
                if (isSourceMapping(mapping)) {
                    const sourceFile = host.getSourceFileLike(sourceFileAbsolutePaths[mapping.sourceIndex]);
                    source = map2.sources[mapping.sourceIndex];
                    sourcePosition = sourceFile !== void 0 ? getPositionOfLineAndCharacter(sourceFile, mapping.sourceLine, mapping.sourceCharacter, 
                    /*allowEdits*/
                    true) : -1;
                }
                return {
                    generatedPosition,
                    source,
                    sourceIndex: mapping.sourceIndex,
                    sourcePosition,
                    nameIndex: mapping.nameIndex
                };
            }
            function getDecodedMappings() {
                if (decodedMappings === void 0) {
                    const decoder = decodeMappings(map2.mappings);
                    const mappings = arrayFrom(decoder, processMapping);
                    if (decoder.error !== void 0) {
                        if (host.log) {
                            host.log(`Encountered error while decoding sourcemap: ${decoder.error}`);
                        }
                        decodedMappings = emptyArray;
                    }
                    else {
                        decodedMappings = mappings;
                    }
                }
                return decodedMappings;
            }
            function getSourceMappings(sourceIndex) {
                if (sourceMappings === void 0) {
                    const lists = [];
                    for (const mapping of getDecodedMappings()) {
                        if (!isSourceMappedPosition(mapping))
                            continue;
                        let list = lists[mapping.sourceIndex];
                        if (!list)
                            lists[mapping.sourceIndex] = list = [];
                        list.push(mapping);
                    }
                    sourceMappings = lists.map((list) => sortAndDeduplicate(list, compareSourcePositions, sameMappedPosition));
                }
                return sourceMappings[sourceIndex];
            }
            function getGeneratedMappings() {
                if (generatedMappings === void 0) {
                    const list = [];
                    for (const mapping of getDecodedMappings()) {
                        list.push(mapping);
                    }
                    generatedMappings = sortAndDeduplicate(list, compareGeneratedPositions, sameMappedPosition);
                }
                return generatedMappings;
            }
            function getGeneratedPosition(loc) {
                const sourceIndex = sourceToSourceIndexMap.get(host.getCanonicalFileName(loc.fileName));
                if (sourceIndex === void 0)
                    return loc;
                const sourceMappings2 = getSourceMappings(sourceIndex);
                if (!some(sourceMappings2))
                    return loc;
                let targetIndex = binarySearchKey(sourceMappings2, loc.pos, getSourcePositionOfMapping, compareValues);
                if (targetIndex < 0) {
                    targetIndex = ~targetIndex;
                }
                const mapping = sourceMappings2[targetIndex];
                if (mapping === void 0 || mapping.sourceIndex !== sourceIndex) {
                    return loc;
                }
                return { fileName: generatedAbsoluteFilePath, pos: mapping.generatedPosition };
            }
            function getSourcePosition(loc) {
                const generatedMappings2 = getGeneratedMappings();
                if (!some(generatedMappings2))
                    return loc;
                let targetIndex = binarySearchKey(generatedMappings2, loc.pos, getGeneratedPositionOfMapping, compareValues);
                if (targetIndex < 0) {
                    targetIndex = ~targetIndex;
                }
                const mapping = generatedMappings2[targetIndex];
                if (mapping === void 0 || !isSourceMappedPosition(mapping)) {
                    return loc;
                }
                return { fileName: sourceFileAbsolutePaths[mapping.sourceIndex], pos: mapping.sourcePosition };
            }
        }
        var sourceMapCommentRegExpDontCareLineStart, sourceMapCommentRegExp, whitespaceOrMapCommentRegExp, identitySourceMapConsumer;
        var init_sourcemap = __esm({
            "src/compiler/sourcemap.ts"() {
                "use strict";
                init_ts2();
                init_ts_performance();
                sourceMapCommentRegExpDontCareLineStart = /\/\/[@#] source[M]appingURL=(.+)\r?\n?$/;
                sourceMapCommentRegExp = /^\/\/[@#] source[M]appingURL=(.+)\r?\n?$/;
                whitespaceOrMapCommentRegExp = /^\s*(\/\/[@#] .*)?$/;
                identitySourceMapConsumer = {
                    getSourcePosition: identity,
                    getGeneratedPosition: identity
                };
            }
        });
        // src/compiler/transformers/utilities.ts
        function getOriginalNodeId(node) {
            node = getOriginalNode(node);
            return node ? getNodeId(node) : 0;
        }
        function containsDefaultReference(node) {
            if (!node)
                return false;
            if (!isNamedImports(node))
                return false;
            return some(node.elements, isNamedDefaultReference);
        }
        function isNamedDefaultReference(e) {
            return e.propertyName !== void 0 && e.propertyName.escapedText === "default" /* Default */;
        }
        function chainBundle(context, transformSourceFile) {
            return transformSourceFileOrBundle;
            function transformSourceFileOrBundle(node) {
                return node.kind === 312 /* SourceFile */ ? transformSourceFile(node) : transformBundle(node);
            }
            function transformBundle(node) {
                return context.factory.createBundle(map(node.sourceFiles, transformSourceFile), node.prepends);
            }
        }
        function getExportNeedsImportStarHelper(node) {
            return !!getNamespaceDeclarationNode(node);
        }
        function getImportNeedsImportStarHelper(node) {
            if (!!getNamespaceDeclarationNode(node)) {
                return true;
            }
            const bindings = node.importClause && node.importClause.namedBindings;
            if (!bindings) {
                return false;
            }
            if (!isNamedImports(bindings))
                return false;
            let defaultRefCount = 0;
            for (const binding of bindings.elements) {
                if (isNamedDefaultReference(binding)) {
                    defaultRefCount++;
                }
            }
            return defaultRefCount > 0 && defaultRefCount !== bindings.elements.length || !!(bindings.elements.length - defaultRefCount) && isDefaultImport(node);
        }
        function getImportNeedsImportDefaultHelper(node) {
            return !getImportNeedsImportStarHelper(node) && (isDefaultImport(node) || !!node.importClause && isNamedImports(node.importClause.namedBindings) && containsDefaultReference(node.importClause.namedBindings));
        }
        function collectExternalModuleInfo(context, sourceFile) {
            const resolver = context.getEmitResolver();
            const compilerOptions = context.getCompilerOptions();
            const externalImports = [];
            const exportSpecifiers = new IdentifierNameMultiMap();
            const exportedBindings = [];
            const uniqueExports = /* @__PURE__ */ new Map();
            let exportedNames;
            let hasExportDefault = false;
            let exportEquals;
            let hasExportStarsToExportValues = false;
            let hasImportStar = false;
            let hasImportDefault = false;
            for (const node of sourceFile.statements) {
                switch (node.kind) {
                    case 272 /* ImportDeclaration */:
                        externalImports.push(node);
                        if (!hasImportStar && getImportNeedsImportStarHelper(node)) {
                            hasImportStar = true;
                        }
                        if (!hasImportDefault && getImportNeedsImportDefaultHelper(node)) {
                            hasImportDefault = true;
                        }
                        break;
                    case 271 /* ImportEqualsDeclaration */:
                        if (node.moduleReference.kind === 283 /* ExternalModuleReference */) {
                            externalImports.push(node);
                        }
                        break;
                    case 278 /* ExportDeclaration */:
                        if (node.moduleSpecifier) {
                            if (!node.exportClause) {
                                externalImports.push(node);
                                hasExportStarsToExportValues = true;
                            }
                            else {
                                externalImports.push(node);
                                if (isNamedExports(node.exportClause)) {
                                    addExportedNamesForExportDeclaration(node);
                                }
                                else {
                                    const name = node.exportClause.name;
                                    if (!uniqueExports.get(idText(name))) {
                                        multiMapSparseArrayAdd(exportedBindings, getOriginalNodeId(node), name);
                                        uniqueExports.set(idText(name), true);
                                        exportedNames = append(exportedNames, name);
                                    }
                                    hasImportStar = true;
                                }
                            }
                        }
                        else {
                            addExportedNamesForExportDeclaration(node);
                        }
                        break;
                    case 277 /* ExportAssignment */:
                        if (node.isExportEquals && !exportEquals) {
                            exportEquals = node;
                        }
                        break;
                    case 243 /* VariableStatement */:
                        if (hasSyntacticModifier(node, 32 /* Export */)) {
                            for (const decl of node.declarationList.declarations) {
                                exportedNames = collectExportedVariableInfo(decl, uniqueExports, exportedNames, exportedBindings);
                            }
                        }
                        break;
                    case 262 /* FunctionDeclaration */:
                        if (hasSyntacticModifier(node, 32 /* Export */)) {
                            if (hasSyntacticModifier(node, 2048 /* Default */)) {
                                if (!hasExportDefault) {
                                    multiMapSparseArrayAdd(exportedBindings, getOriginalNodeId(node), context.factory.getDeclarationName(node));
                                    hasExportDefault = true;
                                }
                            }
                            else {
                                const name = node.name;
                                if (!uniqueExports.get(idText(name))) {
                                    multiMapSparseArrayAdd(exportedBindings, getOriginalNodeId(node), name);
                                    uniqueExports.set(idText(name), true);
                                    exportedNames = append(exportedNames, name);
                                }
                            }
                        }
                        break;
                    case 263 /* ClassDeclaration */:
                        if (hasSyntacticModifier(node, 32 /* Export */)) {
                            if (hasSyntacticModifier(node, 2048 /* Default */)) {
                                if (!hasExportDefault) {
                                    multiMapSparseArrayAdd(exportedBindings, getOriginalNodeId(node), context.factory.getDeclarationName(node));
                                    hasExportDefault = true;
                                }
                            }
                            else {
                                const name = node.name;
                                if (name && !uniqueExports.get(idText(name))) {
                                    multiMapSparseArrayAdd(exportedBindings, getOriginalNodeId(node), name);
                                    uniqueExports.set(idText(name), true);
                                    exportedNames = append(exportedNames, name);
                                }
                            }
                        }
                        break;
                }
            }
            const externalHelpersImportDeclaration = createExternalHelpersImportDeclarationIfNeeded(context.factory, context.getEmitHelperFactory(), sourceFile, compilerOptions, hasExportStarsToExportValues, hasImportStar, hasImportDefault);
            if (externalHelpersImportDeclaration) {
                externalImports.unshift(externalHelpersImportDeclaration);
            }
            return { externalImports, exportSpecifiers, exportEquals, hasExportStarsToExportValues, exportedBindings, exportedNames, externalHelpersImportDeclaration };
            function addExportedNamesForExportDeclaration(node) {
                for (const specifier of cast(node.exportClause, isNamedExports).elements) {
                    if (!uniqueExports.get(idText(specifier.name))) {
                        const name = specifier.propertyName || specifier.name;
                        if (!node.moduleSpecifier) {
                            exportSpecifiers.add(name, specifier);
                        }
                        const decl = resolver.getReferencedImportDeclaration(name) || resolver.getReferencedValueDeclaration(name);
                        if (decl) {
                            multiMapSparseArrayAdd(exportedBindings, getOriginalNodeId(decl), specifier.name);
                        }
                        uniqueExports.set(idText(specifier.name), true);
                        exportedNames = append(exportedNames, specifier.name);
                    }
                }
            }
        }
        function collectExportedVariableInfo(decl, uniqueExports, exportedNames, exportedBindings) {
            if (isBindingPattern(decl.name)) {
                for (const element of decl.name.elements) {
                    if (!isOmittedExpression(element)) {
                        exportedNames = collectExportedVariableInfo(element, uniqueExports, exportedNames, exportedBindings);
                    }
                }
            }
            else if (!isGeneratedIdentifier(decl.name)) {
                const text = idText(decl.name);
                if (!uniqueExports.get(text)) {
                    uniqueExports.set(text, true);
                    exportedNames = append(exportedNames, decl.name);
                    if (isLocalName(decl.name)) {
                        multiMapSparseArrayAdd(exportedBindings, getOriginalNodeId(decl), decl.name);
                    }
                }
            }
            return exportedNames;
        }
        function multiMapSparseArrayAdd(map2, key, value) {
            let values = map2[key];
            if (values) {
                values.push(value);
            }
            else {
                map2[key] = values = [value];
            }
            return values;
        }
        function isSimpleCopiableExpression(expression) {
            return isStringLiteralLike(expression) || expression.kind === 9 /* NumericLiteral */ || isKeyword(expression.kind) || isIdentifier(expression);
        }
        function isSimpleInlineableExpression(expression) {
            return !isIdentifier(expression) && isSimpleCopiableExpression(expression);
        }
        function isCompoundAssignment(kind) {
            return kind >= 65 /* FirstCompoundAssignment */ && kind <= 79 /* LastCompoundAssignment */;
        }
        function getNonAssignmentOperatorForCompoundAssignment(kind) {
            switch (kind) {
                case 65 /* PlusEqualsToken */:
                    return 40 /* PlusToken */;
                case 66 /* MinusEqualsToken */:
                    return 41 /* MinusToken */;
                case 67 /* AsteriskEqualsToken */:
                    return 42 /* AsteriskToken */;
                case 68 /* AsteriskAsteriskEqualsToken */:
                    return 43 /* AsteriskAsteriskToken */;
                case 69 /* SlashEqualsToken */:
                    return 44 /* SlashToken */;
                case 70 /* PercentEqualsToken */:
                    return 45 /* PercentToken */;
                case 71 /* LessThanLessThanEqualsToken */:
                    return 48 /* LessThanLessThanToken */;
                case 72 /* GreaterThanGreaterThanEqualsToken */:
                    return 49 /* GreaterThanGreaterThanToken */;
                case 73 /* GreaterThanGreaterThanGreaterThanEqualsToken */:
                    return 50 /* GreaterThanGreaterThanGreaterThanToken */;
                case 74 /* AmpersandEqualsToken */:
                    return 51 /* AmpersandToken */;
                case 75 /* BarEqualsToken */:
                    return 52 /* BarToken */;
                case 79 /* CaretEqualsToken */:
                    return 53 /* CaretToken */;
                case 76 /* BarBarEqualsToken */:
                    return 57 /* BarBarToken */;
                case 77 /* AmpersandAmpersandEqualsToken */:
                    return 56 /* AmpersandAmpersandToken */;
                case 78 /* QuestionQuestionEqualsToken */:
                    return 61 /* QuestionQuestionToken */;
            }
        }
        function getSuperCallFromStatement(statement) {
            if (!isExpressionStatement(statement)) {
                return void 0;
            }
            const expression = skipParentheses(statement.expression);
            return isSuperCall(expression) ? expression : void 0;
        }
        function findSuperStatementIndexPathWorker(statements, start, indices) {
            for (let i = start; i < statements.length; i += 1) {
                const statement = statements[i];
                if (getSuperCallFromStatement(statement)) {
                    indices.unshift(i);
                    return true;
                }
                else if (isTryStatement(statement) && findSuperStatementIndexPathWorker(statement.tryBlock.statements, 0, indices)) {
                    indices.unshift(i);
                    return true;
                }
            }
            return false;
        }
        function findSuperStatementIndexPath(statements, start) {
            const indices = [];
            findSuperStatementIndexPathWorker(statements, start, indices);
            return indices;
        }
        function getProperties(node, requireInitializer, isStatic2) {
            return filter(node.members, (m) => isInitializedOrStaticProperty(m, requireInitializer, isStatic2));
        }
        function isStaticPropertyDeclarationOrClassStaticBlockDeclaration(element) {
            return isStaticPropertyDeclaration(element) || isClassStaticBlockDeclaration(element);
        }
        function getStaticPropertiesAndClassStaticBlock(node) {
            return filter(node.members, isStaticPropertyDeclarationOrClassStaticBlockDeclaration);
        }
        function isInitializedOrStaticProperty(member, requireInitializer, isStatic2) {
            return isPropertyDeclaration(member) && (!!member.initializer || !requireInitializer) && hasStaticModifier(member) === isStatic2;
        }
        function isStaticPropertyDeclaration(member) {
            return isPropertyDeclaration(member) && hasStaticModifier(member);
        }
        function isInitializedProperty(member) {
            return member.kind === 172 /* PropertyDeclaration */ && member.initializer !== void 0;
        }
        function isNonStaticMethodOrAccessorWithPrivateName(member) {
            return !isStatic(member) && (isMethodOrAccessor(member) || isAutoAccessorPropertyDeclaration(member)) && isPrivateIdentifier(member.name);
        }
        function getDecoratorsOfParameters(node) {
            let decorators;
            if (node) {
                const parameters = node.parameters;
                const firstParameterIsThis = parameters.length > 0 && parameterIsThisKeyword(parameters[0]);
                const firstParameterOffset = firstParameterIsThis ? 1 : 0;
                const numParameters = firstParameterIsThis ? parameters.length - 1 : parameters.length;
                for (let i = 0; i < numParameters; i++) {
                    const parameter = parameters[i + firstParameterOffset];
                    if (decorators || hasDecorators(parameter)) {
                        if (!decorators) {
                            decorators = new Array(numParameters);
                        }
                        decorators[i] = getDecorators(parameter);
                    }
                }
            }
            return decorators;
        }
        function getAllDecoratorsOfClass(node) {
            const decorators = getDecorators(node);
            const parameters = getDecoratorsOfParameters(getFirstConstructorWithBody(node));
            if (!some(decorators) && !some(parameters)) {
                return void 0;
            }
            return {
                decorators,
                parameters
            };
        }
        function getAllDecoratorsOfClassElement(member, parent2, useLegacyDecorators) {
            switch (member.kind) {
                case 177 /* GetAccessor */:
                case 178 /* SetAccessor */:
                    if (!useLegacyDecorators) {
                        return getAllDecoratorsOfMethod(member);
                    }
                    return getAllDecoratorsOfAccessors(member, parent2);
                case 174 /* MethodDeclaration */:
                    return getAllDecoratorsOfMethod(member);
                case 172 /* PropertyDeclaration */:
                    return getAllDecoratorsOfProperty(member);
                default:
                    return void 0;
            }
        }
        function getAllDecoratorsOfAccessors(accessor, parent2) {
            if (!accessor.body) {
                return void 0;
            }
            const { firstAccessor, secondAccessor, getAccessor, setAccessor } = getAllAccessorDeclarations(parent2.members, accessor);
            const firstAccessorWithDecorators = hasDecorators(firstAccessor) ? firstAccessor : secondAccessor && hasDecorators(secondAccessor) ? secondAccessor : void 0;
            if (!firstAccessorWithDecorators || accessor !== firstAccessorWithDecorators) {
                return void 0;
            }
            const decorators = getDecorators(firstAccessorWithDecorators);
            const parameters = getDecoratorsOfParameters(setAccessor);
            if (!some(decorators) && !some(parameters)) {
                return void 0;
            }
            return {
                decorators,
                parameters,
                getDecorators: getAccessor && getDecorators(getAccessor),
                setDecorators: setAccessor && getDecorators(setAccessor)
            };
        }
        function getAllDecoratorsOfMethod(method) {
            if (!method.body) {
                return void 0;
            }
            const decorators = getDecorators(method);
            const parameters = getDecoratorsOfParameters(method);
            if (!some(decorators) && !some(parameters)) {
                return void 0;
            }
            return { decorators, parameters };
        }
        function getAllDecoratorsOfProperty(property) {
            const decorators = getDecorators(property);
            if (!some(decorators)) {
                return void 0;
            }
            return { decorators };
        }
        function walkUpLexicalEnvironments(env, cb) {
            while (env) {
                const result = cb(env);
                if (result !== void 0)
                    return result;
                env = env.previous;
            }
        }
        function newPrivateEnvironment(data) {
            return { data };
        }
        function getPrivateIdentifier(privateEnv, name) {
            var _a, _b;
            return isGeneratedPrivateIdentifier(name) ? (_a = privateEnv == null ? void 0 : privateEnv.generatedIdentifiers) == null ? void 0 : _a.get(getNodeForGeneratedName(name)) : (_b = privateEnv == null ? void 0 : privateEnv.identifiers) == null ? void 0 : _b.get(name.escapedText);
        }
        function setPrivateIdentifier(privateEnv, name, entry) {
            if (isGeneratedPrivateIdentifier(name)) {
                privateEnv.generatedIdentifiers ?? (privateEnv.generatedIdentifiers = /* @__PURE__ */ new Map());
                privateEnv.generatedIdentifiers.set(getNodeForGeneratedName(name), entry);
            }
            else {
                privateEnv.identifiers ?? (privateEnv.identifiers = /* @__PURE__ */ new Map());
                privateEnv.identifiers.set(name.escapedText, entry);
            }
        }
        function accessPrivateIdentifier(env, name) {
            return walkUpLexicalEnvironments(env, (env2) => getPrivateIdentifier(env2.privateEnv, name));
        }
        function isSimpleParameter(node) {
            return !node.initializer && isIdentifier(node.name);
        }
        function isSimpleParameterList(nodes) {
            return every(nodes, isSimpleParameter);
        }
        var IdentifierNameMap, IdentifierNameMultiMap;
        var init_utilities3 = __esm({
            "src/compiler/transformers/utilities.ts"() {
                "use strict";
                init_ts2();
                IdentifierNameMap = class _IdentifierNameMap {
                    constructor() {
                        this._map = /* @__PURE__ */ new Map();
                    }
                    get size() {
                        return this._map.size;
                    }
                    has(key) {
                        return this._map.has(_IdentifierNameMap.toKey(key));
                    }
                    get(key) {
                        return this._map.get(_IdentifierNameMap.toKey(key));
                    }
                    set(key, value) {
                        this._map.set(_IdentifierNameMap.toKey(key), value);
                        return this;
                    }
                    delete(key) {
                        var _a;
                        return ((_a = this._map) == null ? void 0 : _a.delete(_IdentifierNameMap.toKey(key))) ?? false;
                    }
                    clear() {
                        this._map.clear();
                    }
                    values() {
                        return this._map.values();
                    }
                    static toKey(name) {
                        if (isGeneratedPrivateIdentifier(name) || isGeneratedIdentifier(name)) {
                            const autoGenerate = name.emitNode.autoGenerate;
                            if ((autoGenerate.flags & 7 /* KindMask */) === 4 /* Node */) {
                                const node = getNodeForGeneratedName(name);
                                const baseName = isMemberName(node) && node !== name ? _IdentifierNameMap.toKey(node) : `(generated@${getNodeId(node)})`;
                                return formatGeneratedName(
                                /*privateName*/
                                false, autoGenerate.prefix, baseName, autoGenerate.suffix, _IdentifierNameMap.toKey);
                            }
                            else {
                                const baseName = `(auto@${autoGenerate.id})`;
                                return formatGeneratedName(
                                /*privateName*/
                                false, autoGenerate.prefix, baseName, autoGenerate.suffix, _IdentifierNameMap.toKey);
                            }
                        }
                        if (isPrivateIdentifier(name)) {
                            return idText(name).slice(1);
                        }
                        return idText(name);
                    }
                };
                IdentifierNameMultiMap = class extends IdentifierNameMap {
                    add(key, value) {
                        let values = this.get(key);
                        if (values) {
                            values.push(value);
                        }
                        else {
                            this.set(key, values = [value]);
                        }
                        return values;
                    }
                    remove(key, value) {
                        const values = this.get(key);
                        if (values) {
                            unorderedRemoveItem(values, value);
                            if (!values.length) {
                                this.delete(key);
                            }
                        }
                    }
                };
            }
        });
        // src/compiler/transformers/destructuring.ts
        function flattenDestructuringAssignment(node, visitor, context, level, needsValue, createAssignmentCallback) {
            let location = node;
            let value;
            if (isDestructuringAssignment(node)) {
                value = node.right;
                while (isEmptyArrayLiteral(node.left) || isEmptyObjectLiteral(node.left)) {
                    if (isDestructuringAssignment(value)) {
                        location = node = value;
                        value = node.right;
                    }
                    else {
                        return Debug.checkDefined(visitNode(value, visitor, isExpression));
                    }
                }
            }
            let expressions;
            const flattenContext = {
                context,
                level,
                downlevelIteration: !!context.getCompilerOptions().downlevelIteration,
                hoistTempVariables: true,
                emitExpression,
                emitBindingOrAssignment,
                createArrayBindingOrAssignmentPattern: (elements) => makeArrayAssignmentPattern(context.factory, elements),
                createObjectBindingOrAssignmentPattern: (elements) => makeObjectAssignmentPattern(context.factory, elements),
                createArrayBindingOrAssignmentElement: makeAssignmentElement,
                visitor
            };
            if (value) {
                value = visitNode(value, visitor, isExpression);
                Debug.assert(value);
                if (isIdentifier(value) && bindingOrAssignmentElementAssignsToName(node, value.escapedText) || bindingOrAssignmentElementContainsNonLiteralComputedName(node)) {
                    value = ensureIdentifier(flattenContext, value, 
                    /*reuseIdentifierExpressions*/
                    false, location);
                }
                else if (needsValue) {
                    value = ensureIdentifier(flattenContext, value, 
                    /*reuseIdentifierExpressions*/
                    true, location);
                }
                else if (nodeIsSynthesized(node)) {
                    location = value;
                }
            }
            flattenBindingOrAssignmentElement(flattenContext, node, value, location, 
            /*skipInitializer*/
            isDestructuringAssignment(node));
            if (value && needsValue) {
                if (!some(expressions)) {
                    return value;
                }
                expressions.push(value);
            }
            return context.factory.inlineExpressions(expressions) || context.factory.createOmittedExpression();
            function emitExpression(expression) {
                expressions = append(expressions, expression);
            }
            function emitBindingOrAssignment(target, value2, location2, original) {
                Debug.assertNode(target, createAssignmentCallback ? isIdentifier : isExpression);
                const expression = createAssignmentCallback ? createAssignmentCallback(target, value2, location2) : setTextRange(context.factory.createAssignment(Debug.checkDefined(visitNode(target, visitor, isExpression)), value2), location2);
                expression.original = original;
                emitExpression(expression);
            }
        }
        function bindingOrAssignmentElementAssignsToName(element, escapedName) {
            const target = getTargetOfBindingOrAssignmentElement(element);
            if (isBindingOrAssignmentPattern(target)) {
                return bindingOrAssignmentPatternAssignsToName(target, escapedName);
            }
            else if (isIdentifier(target)) {
                return target.escapedText === escapedName;
            }
            return false;
        }
        function bindingOrAssignmentPatternAssignsToName(pattern, escapedName) {
            const elements = getElementsOfBindingOrAssignmentPattern(pattern);
            for (const element of elements) {
                if (bindingOrAssignmentElementAssignsToName(element, escapedName)) {
                    return true;
                }
            }
            return false;
        }
        function bindingOrAssignmentElementContainsNonLiteralComputedName(element) {
            const propertyName = tryGetPropertyNameOfBindingOrAssignmentElement(element);
            if (propertyName && isComputedPropertyName(propertyName) && !isLiteralExpression(propertyName.expression)) {
                return true;
            }
            const target = getTargetOfBindingOrAssignmentElement(element);
            return !!target && isBindingOrAssignmentPattern(target) && bindingOrAssignmentPatternContainsNonLiteralComputedName(target);
        }
        function bindingOrAssignmentPatternContainsNonLiteralComputedName(pattern) {
            return !!forEach(getElementsOfBindingOrAssignmentPattern(pattern), bindingOrAssignmentElementContainsNonLiteralComputedName);
        }
        function flattenDestructuringBinding(node, visitor, context, level, rval, hoistTempVariables = false, skipInitializer) {
            let pendingExpressions;
            const pendingDeclarations = [];
            const declarations = [];
            const flattenContext = {
                context,
                level,
                downlevelIteration: !!context.getCompilerOptions().downlevelIteration,
                hoistTempVariables,
                emitExpression,
                emitBindingOrAssignment,
                createArrayBindingOrAssignmentPattern: (elements) => makeArrayBindingPattern(context.factory, elements),
                createObjectBindingOrAssignmentPattern: (elements) => makeObjectBindingPattern(context.factory, elements),
                createArrayBindingOrAssignmentElement: (name) => makeBindingElement(context.factory, name),
                visitor
            };
            if (isVariableDeclaration(node)) {
                let initializer = getInitializerOfBindingOrAssignmentElement(node);
                if (initializer && (isIdentifier(initializer) && bindingOrAssignmentElementAssignsToName(node, initializer.escapedText) || bindingOrAssignmentElementContainsNonLiteralComputedName(node))) {
                    initializer = ensureIdentifier(flattenContext, Debug.checkDefined(visitNode(initializer, flattenContext.visitor, isExpression)), 
                    /*reuseIdentifierExpressions*/
                    false, initializer);
                    node = context.factory.updateVariableDeclaration(node, node.name, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, initializer);
                }
            }
            flattenBindingOrAssignmentElement(flattenContext, node, rval, node, skipInitializer);
            if (pendingExpressions) {
                const temp = context.factory.createTempVariable(
                /*recordTempVariable*/
                void 0);
                if (hoistTempVariables) {
                    const value = context.factory.inlineExpressions(pendingExpressions);
                    pendingExpressions = void 0;
                    emitBindingOrAssignment(temp, value, 
                    /*location*/
                    void 0, 
                    /*original*/
                    void 0);
                }
                else {
                    context.hoistVariableDeclaration(temp);
                    const pendingDeclaration = last(pendingDeclarations);
                    pendingDeclaration.pendingExpressions = append(pendingDeclaration.pendingExpressions, context.factory.createAssignment(temp, pendingDeclaration.value));
                    addRange(pendingDeclaration.pendingExpressions, pendingExpressions);
                    pendingDeclaration.value = temp;
                }
            }
            for (const { pendingExpressions: pendingExpressions2, name, value, location, original } of pendingDeclarations) {
                const variable = context.factory.createVariableDeclaration(name, 
                /*exclamationToken*/
                void 0, 
                /*type*/
                void 0, pendingExpressions2 ? context.factory.inlineExpressions(append(pendingExpressions2, value)) : value);
                variable.original = original;
                setTextRange(variable, location);
                declarations.push(variable);
            }
            return declarations;
            function emitExpression(value) {
                pendingExpressions = append(pendingExpressions, value);
            }
            function emitBindingOrAssignment(target, value, location, original) {
                Debug.assertNode(target, isBindingName);
                if (pendingExpressions) {
                    value = context.factory.inlineExpressions(append(pendingExpressions, value));
                    pendingExpressions = void 0;
                }
                pendingDeclarations.push({ pendingExpressions, name: target, value, location, original });
            }
        }
        function flattenBindingOrAssignmentElement(flattenContext, element, value, location, skipInitializer) {
            const bindingTarget = getTargetOfBindingOrAssignmentElement(element);
            if (!skipInitializer) {
                const initializer = visitNode(getInitializerOfBindingOrAssignmentElement(element), flattenContext.visitor, isExpression);
                if (initializer) {
                    if (value) {
                        value = createDefaultValueCheck(flattenContext, value, initializer, location);
                        if (!isSimpleInlineableExpression(initializer) && isBindingOrAssignmentPattern(bindingTarget)) {
                            value = ensureIdentifier(flattenContext, value, 
                            /*reuseIdentifierExpressions*/
                            true, location);
                        }
                    }
                    else {
                        value = initializer;
                    }
                }
                else if (!value) {
                    value = flattenContext.context.factory.createVoidZero();
                }
            }
            if (isObjectBindingOrAssignmentPattern(bindingTarget)) {
                flattenObjectBindingOrAssignmentPattern(flattenContext, element, bindingTarget, value, location);
            }
            else if (isArrayBindingOrAssignmentPattern(bindingTarget)) {
                flattenArrayBindingOrAssignmentPattern(flattenContext, element, bindingTarget, value, location);
            }
            else {
                flattenContext.emitBindingOrAssignment(bindingTarget, value, location, 
                /*original*/
                element);
            }
        }
        function flattenObjectBindingOrAssignmentPattern(flattenContext, parent2, pattern, value, location) {
            const elements = getElementsOfBindingOrAssignmentPattern(pattern);
            const numElements = elements.length;
            if (numElements !== 1) {
                const reuseIdentifierExpressions = !isDeclarationBindingElement(parent2) || numElements !== 0;
                value = ensureIdentifier(flattenContext, value, reuseIdentifierExpressions, location);
            }
            let bindingElements;
            let computedTempVariables;
            for (let i = 0; i < numElements; i++) {
                const element = elements[i];
                if (!getRestIndicatorOfBindingOrAssignmentElement(element)) {
                    const propertyName = getPropertyNameOfBindingOrAssignmentElement(element);
                    if (flattenContext.level >= 1 /* ObjectRest */ && !(element.transformFlags & (32768 /* ContainsRestOrSpread */ | 65536 /* ContainsObjectRestOrSpread */)) && !(getTargetOfBindingOrAssignmentElement(element).transformFlags & (32768 /* ContainsRestOrSpread */ | 65536 /* ContainsObjectRestOrSpread */)) && !isComputedPropertyName(propertyName)) {
                        bindingElements = append(bindingElements, visitNode(element, flattenContext.visitor, isBindingOrAssignmentElement));
                    }
                    else {
                        if (bindingElements) {
                            flattenContext.emitBindingOrAssignment(flattenContext.createObjectBindingOrAssignmentPattern(bindingElements), value, location, pattern);
                            bindingElements = void 0;
                        }
                        const rhsValue = createDestructuringPropertyAccess(flattenContext, value, propertyName);
                        if (isComputedPropertyName(propertyName)) {
                            computedTempVariables = append(computedTempVariables, rhsValue.argumentExpression);
                        }
                        flattenBindingOrAssignmentElement(flattenContext, element, rhsValue, 
                        /*location*/
                        element);
                    }
                }
                else if (i === numElements - 1) {
                    if (bindingElements) {
                        flattenContext.emitBindingOrAssignment(flattenContext.createObjectBindingOrAssignmentPattern(bindingElements), value, location, pattern);
                        bindingElements = void 0;
                    }
                    const rhsValue = flattenContext.context.getEmitHelperFactory().createRestHelper(value, elements, computedTempVariables, pattern);
                    flattenBindingOrAssignmentElement(flattenContext, element, rhsValue, element);
                }
            }
            if (bindingElements) {
                flattenContext.emitBindingOrAssignment(flattenContext.createObjectBindingOrAssignmentPattern(bindingElements), value, location, pattern);
            }
        }
        function flattenArrayBindingOrAssignmentPattern(flattenContext, parent2, pattern, value, location) {
            const elements = getElementsOfBindingOrAssignmentPattern(pattern);
            const numElements = elements.length;
            if (flattenContext.level < 1 /* ObjectRest */ && flattenContext.downlevelIteration) {
                value = ensureIdentifier(flattenContext, setTextRange(flattenContext.context.getEmitHelperFactory().createReadHelper(value, numElements > 0 && getRestIndicatorOfBindingOrAssignmentElement(elements[numElements - 1]) ? void 0 : numElements), location), 
                /*reuseIdentifierExpressions*/
                false, location);
            }
            else if (numElements !== 1 && (flattenContext.level < 1 /* ObjectRest */ || numElements === 0) || every(elements, isOmittedExpression)) {
                const reuseIdentifierExpressions = !isDeclarationBindingElement(parent2) || numElements !== 0;
                value = ensureIdentifier(flattenContext, value, reuseIdentifierExpressions, location);
            }
            let bindingElements;
            let restContainingElements;
            for (let i = 0; i < numElements; i++) {
                const element = elements[i];
                if (flattenContext.level >= 1 /* ObjectRest */) {
                    if (element.transformFlags & 65536 /* ContainsObjectRestOrSpread */ || flattenContext.hasTransformedPriorElement && !isSimpleBindingOrAssignmentElement(element)) {
                        flattenContext.hasTransformedPriorElement = true;
                        const temp = flattenContext.context.factory.createTempVariable(
                        /*recordTempVariable*/
                        void 0);
                        if (flattenContext.hoistTempVariables) {
                            flattenContext.context.hoistVariableDeclaration(temp);
                        }
                        restContainingElements = append(restContainingElements, [temp, element]);
                        bindingElements = append(bindingElements, flattenContext.createArrayBindingOrAssignmentElement(temp));
                    }
                    else {
                        bindingElements = append(bindingElements, element);
                    }
                }
                else if (isOmittedExpression(element)) {
                    continue;
                }
                else if (!getRestIndicatorOfBindingOrAssignmentElement(element)) {
                    const rhsValue = flattenContext.context.factory.createElementAccessExpression(value, i);
                    flattenBindingOrAssignmentElement(flattenContext, element, rhsValue, 
                    /*location*/
                    element);
                }
                else if (i === numElements - 1) {
                    const rhsValue = flattenContext.context.factory.createArraySliceCall(value, i);
                    flattenBindingOrAssignmentElement(flattenContext, element, rhsValue, 
                    /*location*/
                    element);
                }
            }
            if (bindingElements) {
                flattenContext.emitBindingOrAssignment(flattenContext.createArrayBindingOrAssignmentPattern(bindingElements), value, location, pattern);
            }
            if (restContainingElements) {
                for (const [id, element] of restContainingElements) {
                    flattenBindingOrAssignmentElement(flattenContext, element, id, element);
                }
            }
        }
        function isSimpleBindingOrAssignmentElement(element) {
            const target = getTargetOfBindingOrAssignmentElement(element);
            if (!target || isOmittedExpression(target))
                return true;
            const propertyName = tryGetPropertyNameOfBindingOrAssignmentElement(element);
            if (propertyName && !isPropertyNameLiteral(propertyName))
                return false;
            const initializer = getInitializerOfBindingOrAssignmentElement(element);
            if (initializer && !isSimpleInlineableExpression(initializer))
                return false;
            if (isBindingOrAssignmentPattern(target))
                return every(getElementsOfBindingOrAssignmentPattern(target), isSimpleBindingOrAssignmentElement);
            return isIdentifier(target);
        }
        function createDefaultValueCheck(flattenContext, value, defaultValue, location) {
            value = ensureIdentifier(flattenContext, value, 
            /*reuseIdentifierExpressions*/
            true, location);
            return flattenContext.context.factory.createConditionalExpression(flattenContext.context.factory.createTypeCheck(value, "undefined"), 
            /*questionToken*/
            void 0, defaultValue, 
            /*colonToken*/
            void 0, value);
        }
        function createDestructuringPropertyAccess(flattenContext, value, propertyName) {
            const { factory: factory2 } = flattenContext.context;
            if (isComputedPropertyName(propertyName)) {
                const argumentExpression = ensureIdentifier(flattenContext, Debug.checkDefined(visitNode(propertyName.expression, flattenContext.visitor, isExpression)), 
                /*reuseIdentifierExpressions*/
                false, 
                /*location*/
                propertyName);
                return flattenContext.context.factory.createElementAccessExpression(value, argumentExpression);
            }
            else if (isStringOrNumericLiteralLike(propertyName)) {
                const argumentExpression = factory2.cloneNode(propertyName);
                return flattenContext.context.factory.createElementAccessExpression(value, argumentExpression);
            }
            else {
                const name = flattenContext.context.factory.createIdentifier(idText(propertyName));
                return flattenContext.context.factory.createPropertyAccessExpression(value, name);
            }
        }
        function ensureIdentifier(flattenContext, value, reuseIdentifierExpressions, location) {
            if (isIdentifier(value) && reuseIdentifierExpressions) {
                return value;
            }
            else {
                const temp = flattenContext.context.factory.createTempVariable(
                /*recordTempVariable*/
                void 0);
                if (flattenContext.hoistTempVariables) {
                    flattenContext.context.hoistVariableDeclaration(temp);
                    flattenContext.emitExpression(setTextRange(flattenContext.context.factory.createAssignment(temp, value), location));
                }
                else {
                    flattenContext.emitBindingOrAssignment(temp, value, location, 
                    /*original*/
                    void 0);
                }
                return temp;
            }
        }
        function makeArrayBindingPattern(factory2, elements) {
            Debug.assertEachNode(elements, isArrayBindingElement);
            return factory2.createArrayBindingPattern(elements);
        }
        function makeArrayAssignmentPattern(factory2, elements) {
            Debug.assertEachNode(elements, isArrayBindingOrAssignmentElement);
            return factory2.createArrayLiteralExpression(map(elements, factory2.converters.convertToArrayAssignmentElement));
        }
        function makeObjectBindingPattern(factory2, elements) {
            Debug.assertEachNode(elements, isBindingElement);
            return factory2.createObjectBindingPattern(elements);
        }
        function makeObjectAssignmentPattern(factory2, elements) {
            Debug.assertEachNode(elements, isObjectBindingOrAssignmentElement);
            return factory2.createObjectLiteralExpression(map(elements, factory2.converters.convertToObjectAssignmentElement));
        }
        function makeBindingElement(factory2, name) {
            return factory2.createBindingElement(
            /*dotDotDotToken*/
            void 0, 
            /*propertyName*/
            void 0, name);
        }
        function makeAssignmentElement(name) {
            return name;
        }
        var FlattenLevel;
        var init_destructuring = __esm({
            "src/compiler/transformers/destructuring.ts"() {
                "use strict";
                init_ts2();
                FlattenLevel = /* @__PURE__ */ ((FlattenLevel2) => {
                    FlattenLevel2[FlattenLevel2["All"] = 0] = "All";
                    FlattenLevel2[FlattenLevel2["ObjectRest"] = 1] = "ObjectRest";
                    return FlattenLevel2;
                })(FlattenLevel || {});
            }
        });
        // src/compiler/transformers/classThis.ts
        function createClassThisAssignmentBlock(factory2, classThis, thisExpression = factory2.createThis()) {
            const expression = factory2.createAssignment(classThis, thisExpression);
            const statement = factory2.createExpressionStatement(expression);
            const body = factory2.createBlock([statement], 
            /*multiLine*/
            false);
            const block = factory2.createClassStaticBlockDeclaration(body);
            getOrCreateEmitNode(block).classThis = classThis;
            return block;
        }
        function isClassThisAssignmentBlock(node) {
            var _a;
            if (!isClassStaticBlockDeclaration(node) || node.body.statements.length !== 1) {
                return false;
            }
            const statement = node.body.statements[0];
            return isExpressionStatement(statement) && isAssignmentExpression(statement.expression, 
            /*excludeCompoundAssignment*/
            true) && isIdentifier(statement.expression.left) && ((_a = node.emitNode) == null ? void 0 : _a.classThis) === statement.expression.left && statement.expression.right.kind === 110 /* ThisKeyword */;
        }
        function classHasClassThisAssignment(node) {
            var _a;
            return !!((_a = node.emitNode) == null ? void 0 : _a.classThis) && some(node.members, isClassThisAssignmentBlock);
        }
        function injectClassThisAssignmentIfMissing(factory2, node, classThis, thisExpression) {
            if (classHasClassThisAssignment(node)) {
                return node;
            }
            const staticBlock = createClassThisAssignmentBlock(factory2, classThis, thisExpression);
            if (node.name) {
                setSourceMapRange(staticBlock.body.statements[0], node.name);
            }
            const members = factory2.createNodeArray([staticBlock, ...node.members]);
            setTextRange(members, node.members);
            const updatedNode = isClassDeclaration(node) ? factory2.updateClassDeclaration(node, node.modifiers, node.name, node.typeParameters, node.heritageClauses, members) : factory2.updateClassExpression(node, node.modifiers, node.name, node.typeParameters, node.heritageClauses, members);
            getOrCreateEmitNode(updatedNode).classThis = classThis;
            return updatedNode;
        }
        var init_classThis = __esm({
            "src/compiler/transformers/classThis.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/namedEvaluation.ts
        function getAssignedNameOfIdentifier(factory2, name, expression) {
            const original = getOriginalNode(skipOuterExpressions(expression));
            if ((isClassDeclaration(original) || isFunctionDeclaration(original)) && !original.name && hasSyntacticModifier(original, 2048 /* Default */)) {
                return factory2.createStringLiteral("default");
            }
            return factory2.createStringLiteralFromNode(name);
        }
        function getAssignedNameOfPropertyName(context, name, assignedNameText) {
            const { factory: factory2 } = context;
            if (assignedNameText !== void 0) {
                const assignedName2 = factory2.createStringLiteral(assignedNameText);
                return { assignedName: assignedName2, name };
            }
            if (isPropertyNameLiteral(name) || isPrivateIdentifier(name)) {
                const assignedName2 = factory2.createStringLiteralFromNode(name);
                return { assignedName: assignedName2, name };
            }
            if (isPropertyNameLiteral(name.expression) && !isIdentifier(name.expression)) {
                const assignedName2 = factory2.createStringLiteralFromNode(name.expression);
                return { assignedName: assignedName2, name };
            }
            const assignedName = factory2.getGeneratedNameForNode(name);
            context.hoistVariableDeclaration(assignedName);
            const key = context.getEmitHelperFactory().createPropKeyHelper(name.expression);
            const assignment = factory2.createAssignment(assignedName, key);
            const updatedName = factory2.updateComputedPropertyName(name, assignment);
            return { assignedName, name: updatedName };
        }
        function createClassNamedEvaluationHelperBlock(context, assignedName, thisExpression = context.factory.createThis()) {
            const { factory: factory2 } = context;
            const expression = context.getEmitHelperFactory().createSetFunctionNameHelper(thisExpression, assignedName);
            const statement = factory2.createExpressionStatement(expression);
            const body = factory2.createBlock([statement], 
            /*multiLine*/
            false);
            const block = factory2.createClassStaticBlockDeclaration(body);
            getOrCreateEmitNode(block).assignedName = assignedName;
            return block;
        }
        function isClassNamedEvaluationHelperBlock(node) {
            var _a;
            if (!isClassStaticBlockDeclaration(node) || node.body.statements.length !== 1) {
                return false;
            }
            const statement = node.body.statements[0];
            return isExpressionStatement(statement) && isCallToHelper(statement.expression, "___setFunctionName") && statement.expression.arguments.length >= 2 && statement.expression.arguments[1] === ((_a = node.emitNode) == null ? void 0 : _a.assignedName);
        }
        function classHasExplicitlyAssignedName(node) {
            var _a;
            return !!((_a = node.emitNode) == null ? void 0 : _a.assignedName) && some(node.members, isClassNamedEvaluationHelperBlock);
        }
        function classHasDeclaredOrExplicitlyAssignedName(node) {
            return !!node.name || classHasExplicitlyAssignedName(node);
        }
        function injectClassNamedEvaluationHelperBlockIfMissing(context, node, assignedName, thisExpression) {
            if (classHasExplicitlyAssignedName(node)) {
                return node;
            }
            const { factory: factory2 } = context;
            const namedEvaluationBlock = createClassNamedEvaluationHelperBlock(context, assignedName, thisExpression);
            if (node.name) {
                setSourceMapRange(namedEvaluationBlock.body.statements[0], node.name);
            }
            const insertionIndex = findIndex(node.members, isClassThisAssignmentBlock) + 1;
            const leading = node.members.slice(0, insertionIndex);
            const trailing = node.members.slice(insertionIndex);
            const members = factory2.createNodeArray([...leading, namedEvaluationBlock, ...trailing]);
            setTextRange(members, node.members);
            node = isClassDeclaration(node) ? factory2.updateClassDeclaration(node, node.modifiers, node.name, node.typeParameters, node.heritageClauses, members) : factory2.updateClassExpression(node, node.modifiers, node.name, node.typeParameters, node.heritageClauses, members);
            getOrCreateEmitNode(node).assignedName = assignedName;
            return node;
        }
        function finishTransformNamedEvaluation(context, expression, assignedName, ignoreEmptyStringLiteral) {
            if (ignoreEmptyStringLiteral && isStringLiteral(assignedName) && isEmptyStringLiteral(assignedName)) {
                return expression;
            }
            const { factory: factory2 } = context;
            const innerExpression = skipOuterExpressions(expression);
            const updatedExpression = isClassExpression(innerExpression) ? cast(injectClassNamedEvaluationHelperBlockIfMissing(context, innerExpression, assignedName), isClassExpression) : context.getEmitHelperFactory().createSetFunctionNameHelper(innerExpression, assignedName);
            return factory2.restoreOuterExpressions(expression, updatedExpression);
        }
        function transformNamedEvaluationOfPropertyAssignment(context, node, ignoreEmptyStringLiteral, assignedNameText) {
            const { factory: factory2 } = context;
            const { assignedName, name } = getAssignedNameOfPropertyName(context, node.name, assignedNameText);
            const initializer = finishTransformNamedEvaluation(context, node.initializer, assignedName, ignoreEmptyStringLiteral);
            return factory2.updatePropertyAssignment(node, name, initializer);
        }
        function transformNamedEvaluationOfShorthandAssignmentProperty(context, node, ignoreEmptyStringLiteral, assignedNameText) {
            const { factory: factory2 } = context;
            const assignedName = assignedNameText !== void 0 ? factory2.createStringLiteral(assignedNameText) : getAssignedNameOfIdentifier(factory2, node.name, node.objectAssignmentInitializer);
            const objectAssignmentInitializer = finishTransformNamedEvaluation(context, node.objectAssignmentInitializer, assignedName, ignoreEmptyStringLiteral);
            return factory2.updateShorthandPropertyAssignment(node, node.name, objectAssignmentInitializer);
        }
        function transformNamedEvaluationOfVariableDeclaration(context, node, ignoreEmptyStringLiteral, assignedNameText) {
            const { factory: factory2 } = context;
            const assignedName = assignedNameText !== void 0 ? factory2.createStringLiteral(assignedNameText) : getAssignedNameOfIdentifier(factory2, node.name, node.initializer);
            const initializer = finishTransformNamedEvaluation(context, node.initializer, assignedName, ignoreEmptyStringLiteral);
            return factory2.updateVariableDeclaration(node, node.name, node.exclamationToken, node.type, initializer);
        }
        function transformNamedEvaluationOfParameterDeclaration(context, node, ignoreEmptyStringLiteral, assignedNameText) {
            const { factory: factory2 } = context;
            const assignedName = assignedNameText !== void 0 ? factory2.createStringLiteral(assignedNameText) : getAssignedNameOfIdentifier(factory2, node.name, node.initializer);
            const initializer = finishTransformNamedEvaluation(context, node.initializer, assignedName, ignoreEmptyStringLiteral);
            return factory2.updateParameterDeclaration(node, node.modifiers, node.dotDotDotToken, node.name, node.questionToken, node.type, initializer);
        }
        function transformNamedEvaluationOfBindingElement(context, node, ignoreEmptyStringLiteral, assignedNameText) {
            const { factory: factory2 } = context;
            const assignedName = assignedNameText !== void 0 ? factory2.createStringLiteral(assignedNameText) : getAssignedNameOfIdentifier(factory2, node.name, node.initializer);
            const initializer = finishTransformNamedEvaluation(context, node.initializer, assignedName, ignoreEmptyStringLiteral);
            return factory2.updateBindingElement(node, node.dotDotDotToken, node.propertyName, node.name, initializer);
        }
        function transformNamedEvaluationOfPropertyDeclaration(context, node, ignoreEmptyStringLiteral, assignedNameText) {
            const { factory: factory2 } = context;
            const { assignedName, name } = getAssignedNameOfPropertyName(context, node.name, assignedNameText);
            const initializer = finishTransformNamedEvaluation(context, node.initializer, assignedName, ignoreEmptyStringLiteral);
            return factory2.updatePropertyDeclaration(node, node.modifiers, name, node.questionToken ?? node.exclamationToken, node.type, initializer);
        }
        function transformNamedEvaluationOfAssignmentExpression(context, node, ignoreEmptyStringLiteral, assignedNameText) {
            const { factory: factory2 } = context;
            const assignedName = assignedNameText !== void 0 ? factory2.createStringLiteral(assignedNameText) : getAssignedNameOfIdentifier(factory2, node.left, node.right);
            const right = finishTransformNamedEvaluation(context, node.right, assignedName, ignoreEmptyStringLiteral);
            return factory2.updateBinaryExpression(node, node.left, node.operatorToken, right);
        }
        function transformNamedEvaluationOfExportAssignment(context, node, ignoreEmptyStringLiteral, assignedNameText) {
            const { factory: factory2 } = context;
            const assignedName = assignedNameText !== void 0 ? factory2.createStringLiteral(assignedNameText) : factory2.createStringLiteral(node.isExportEquals ? "" : "default");
            const expression = finishTransformNamedEvaluation(context, node.expression, assignedName, ignoreEmptyStringLiteral);
            return factory2.updateExportAssignment(node, node.modifiers, expression);
        }
        function transformNamedEvaluation(context, node, ignoreEmptyStringLiteral, assignedName) {
            switch (node.kind) {
                case 303 /* PropertyAssignment */:
                    return transformNamedEvaluationOfPropertyAssignment(context, node, ignoreEmptyStringLiteral, assignedName);
                case 304 /* ShorthandPropertyAssignment */:
                    return transformNamedEvaluationOfShorthandAssignmentProperty(context, node, ignoreEmptyStringLiteral, assignedName);
                case 260 /* VariableDeclaration */:
                    return transformNamedEvaluationOfVariableDeclaration(context, node, ignoreEmptyStringLiteral, assignedName);
                case 169 /* Parameter */:
                    return transformNamedEvaluationOfParameterDeclaration(context, node, ignoreEmptyStringLiteral, assignedName);
                case 208 /* BindingElement */:
                    return transformNamedEvaluationOfBindingElement(context, node, ignoreEmptyStringLiteral, assignedName);
                case 172 /* PropertyDeclaration */:
                    return transformNamedEvaluationOfPropertyDeclaration(context, node, ignoreEmptyStringLiteral, assignedName);
                case 226 /* BinaryExpression */:
                    return transformNamedEvaluationOfAssignmentExpression(context, node, ignoreEmptyStringLiteral, assignedName);
                case 277 /* ExportAssignment */:
                    return transformNamedEvaluationOfExportAssignment(context, node, ignoreEmptyStringLiteral, assignedName);
            }
        }
        var init_namedEvaluation = __esm({
            "src/compiler/transformers/namedEvaluation.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/taggedTemplate.ts
        function processTaggedTemplateExpression(context, node, visitor, currentSourceFile, recordTaggedTemplateString, level) {
            const tag = visitNode(node.tag, visitor, isExpression);
            Debug.assert(tag);
            const templateArguments = [void 0];
            const cookedStrings = [];
            const rawStrings = [];
            const template = node.template;
            if (level === 0 /* LiftRestriction */ && !hasInvalidEscape(template)) {
                return visitEachChild(node, visitor, context);
            }
            const { factory: factory2 } = context;
            if (isNoSubstitutionTemplateLiteral(template)) {
                cookedStrings.push(createTemplateCooked(factory2, template));
                rawStrings.push(getRawLiteral(factory2, template, currentSourceFile));
            }
            else {
                cookedStrings.push(createTemplateCooked(factory2, template.head));
                rawStrings.push(getRawLiteral(factory2, template.head, currentSourceFile));
                for (const templateSpan of template.templateSpans) {
                    cookedStrings.push(createTemplateCooked(factory2, templateSpan.literal));
                    rawStrings.push(getRawLiteral(factory2, templateSpan.literal, currentSourceFile));
                    templateArguments.push(Debug.checkDefined(visitNode(templateSpan.expression, visitor, isExpression)));
                }
            }
            const helperCall = context.getEmitHelperFactory().createTemplateObjectHelper(factory2.createArrayLiteralExpression(cookedStrings), factory2.createArrayLiteralExpression(rawStrings));
            if (isExternalModule(currentSourceFile)) {
                const tempVar = factory2.createUniqueName("templateObject");
                recordTaggedTemplateString(tempVar);
                templateArguments[0] = factory2.createLogicalOr(tempVar, factory2.createAssignment(tempVar, helperCall));
            }
            else {
                templateArguments[0] = helperCall;
            }
            return factory2.createCallExpression(tag, 
            /*typeArguments*/
            void 0, templateArguments);
        }
        function createTemplateCooked(factory2, template) {
            return template.templateFlags & 26656 /* IsInvalid */ ? factory2.createVoidZero() : factory2.createStringLiteral(template.text);
        }
        function getRawLiteral(factory2, node, currentSourceFile) {
            let text = node.rawText;
            if (text === void 0) {
                Debug.assertIsDefined(currentSourceFile, "Template literal node is missing 'rawText' and does not have a source file. Possibly bad transform.");
                text = getSourceTextOfNodeFromSourceFile(currentSourceFile, node);
                const isLast = node.kind === 15 /* NoSubstitutionTemplateLiteral */ || node.kind === 18 /* TemplateTail */;
                text = text.substring(1, text.length - (isLast ? 1 : 2));
            }
            text = text.replace(/\r\n?/g, "\n");
            return setTextRange(factory2.createStringLiteral(text), node);
        }
        var ProcessLevel;
        var init_taggedTemplate = __esm({
            "src/compiler/transformers/taggedTemplate.ts"() {
                "use strict";
                init_ts2();
                ProcessLevel = /* @__PURE__ */ ((ProcessLevel2) => {
                    ProcessLevel2[ProcessLevel2["LiftRestriction"] = 0] = "LiftRestriction";
                    ProcessLevel2[ProcessLevel2["All"] = 1] = "All";
                    return ProcessLevel2;
                })(ProcessLevel || {});
            }
        });
        // src/compiler/transformers/ts.ts
        function transformTypeScript(context) {
            const { factory: factory2, getEmitHelperFactory: emitHelpers, startLexicalEnvironment, resumeLexicalEnvironment, endLexicalEnvironment, hoistVariableDeclaration } = context;
            const resolver = context.getEmitResolver();
            const compilerOptions = context.getCompilerOptions();
            const languageVersion = getEmitScriptTarget(compilerOptions);
            const moduleKind = getEmitModuleKind(compilerOptions);
            const legacyDecorators = !!compilerOptions.experimentalDecorators;
            const typeSerializer = compilerOptions.emitDecoratorMetadata ? createRuntimeTypeSerializer(context) : void 0;
            const previousOnEmitNode = context.onEmitNode;
            const previousOnSubstituteNode = context.onSubstituteNode;
            context.onEmitNode = onEmitNode;
            context.onSubstituteNode = onSubstituteNode;
            context.enableSubstitution(211 /* PropertyAccessExpression */);
            context.enableSubstitution(212 /* ElementAccessExpression */);
            let currentSourceFile;
            let currentNamespace;
            let currentNamespaceContainerName;
            let currentLexicalScope;
            let currentScopeFirstDeclarationsOfName;
            let currentClassHasParameterProperties;
            let enabledSubstitutions;
            let applicableSubstitutions;
            return transformSourceFileOrBundle;
            function transformSourceFileOrBundle(node) {
                if (node.kind === 313 /* Bundle */) {
                    return transformBundle(node);
                }
                return transformSourceFile(node);
            }
            function transformBundle(node) {
                return factory2.createBundle(node.sourceFiles.map(transformSourceFile), mapDefined(node.prepends, (prepend) => {
                    if (prepend.kind === 315 /* InputFiles */) {
                        return createUnparsedSourceFile(prepend, "js");
                    }
                    return prepend;
                }));
            }
            function transformSourceFile(node) {
                if (node.isDeclarationFile) {
                    return node;
                }
                currentSourceFile = node;
                const visited = saveStateAndInvoke(node, visitSourceFile);
                addEmitHelpers(visited, context.readEmitHelpers());
                currentSourceFile = void 0;
                return visited;
            }
            function saveStateAndInvoke(node, f) {
                const savedCurrentScope = currentLexicalScope;
                const savedCurrentScopeFirstDeclarationsOfName = currentScopeFirstDeclarationsOfName;
                const savedCurrentClassHasParameterProperties = currentClassHasParameterProperties;
                onBeforeVisitNode(node);
                const visited = f(node);
                if (currentLexicalScope !== savedCurrentScope) {
                    currentScopeFirstDeclarationsOfName = savedCurrentScopeFirstDeclarationsOfName;
                }
                currentLexicalScope = savedCurrentScope;
                currentClassHasParameterProperties = savedCurrentClassHasParameterProperties;
                return visited;
            }
            function onBeforeVisitNode(node) {
                switch (node.kind) {
                    case 312 /* SourceFile */:
                    case 269 /* CaseBlock */:
                    case 268 /* ModuleBlock */:
                    case 241 /* Block */:
                        currentLexicalScope = node;
                        currentScopeFirstDeclarationsOfName = void 0;
                        break;
                    case 263 /* ClassDeclaration */:
                    case 262 /* FunctionDeclaration */:
                        if (hasSyntacticModifier(node, 128 /* Ambient */)) {
                            break;
                        }
                        if (node.name) {
                            recordEmittedDeclarationInScope(node);
                        }
                        else {
                            Debug.assert(node.kind === 263 /* ClassDeclaration */ || hasSyntacticModifier(node, 2048 /* Default */));
                        }
                        break;
                }
            }
            function visitor(node) {
                return saveStateAndInvoke(node, visitorWorker);
            }
            function visitorWorker(node) {
                if (node.transformFlags & 1 /* ContainsTypeScript */) {
                    return visitTypeScript(node);
                }
                return node;
            }
            function sourceElementVisitor(node) {
                return saveStateAndInvoke(node, sourceElementVisitorWorker);
            }
            function sourceElementVisitorWorker(node) {
                switch (node.kind) {
                    case 272 /* ImportDeclaration */:
                    case 271 /* ImportEqualsDeclaration */:
                    case 277 /* ExportAssignment */:
                    case 278 /* ExportDeclaration */:
                        return visitElidableStatement(node);
                    default:
                        return visitorWorker(node);
                }
            }
            function isElisionBlocked(node) {
                const parsed = getParseTreeNode(node);
                if (parsed === node || isExportAssignment(node)) {
                    return false;
                }
                if (!parsed || parsed.kind !== node.kind) {
                    return true;
                }
                switch (node.kind) {
                    case 272 /* ImportDeclaration */:
                        Debug.assertNode(parsed, isImportDeclaration);
                        if (node.importClause !== parsed.importClause) {
                            return true;
                        }
                        if (node.attributes !== parsed.attributes) {
                            return true;
                        }
                        break;
                    case 271 /* ImportEqualsDeclaration */:
                        Debug.assertNode(parsed, isImportEqualsDeclaration);
                        if (node.name !== parsed.name) {
                            return true;
                        }
                        if (node.isTypeOnly !== parsed.isTypeOnly) {
                            return true;
                        }
                        if (node.moduleReference !== parsed.moduleReference && (isEntityName(node.moduleReference) || isEntityName(parsed.moduleReference))) {
                            return true;
                        }
                        break;
                    case 278 /* ExportDeclaration */:
                        Debug.assertNode(parsed, isExportDeclaration);
                        if (node.exportClause !== parsed.exportClause) {
                            return true;
                        }
                        if (node.attributes !== parsed.attributes) {
                            return true;
                        }
                        break;
                }
                return false;
            }
            function visitElidableStatement(node) {
                if (isElisionBlocked(node)) {
                    if (node.transformFlags & 1 /* ContainsTypeScript */) {
                        return visitEachChild(node, visitor, context);
                    }
                    return node;
                }
                switch (node.kind) {
                    case 272 /* ImportDeclaration */:
                        return visitImportDeclaration(node);
                    case 271 /* ImportEqualsDeclaration */:
                        return visitImportEqualsDeclaration(node);
                    case 277 /* ExportAssignment */:
                        return visitExportAssignment(node);
                    case 278 /* ExportDeclaration */:
                        return visitExportDeclaration(node);
                    default:
                        Debug.fail("Unhandled ellided statement");
                }
            }
            function namespaceElementVisitor(node) {
                return saveStateAndInvoke(node, namespaceElementVisitorWorker);
            }
            function namespaceElementVisitorWorker(node) {
                if (node.kind === 278 /* ExportDeclaration */ || node.kind === 272 /* ImportDeclaration */ || node.kind === 273 /* ImportClause */ || node.kind === 271 /* ImportEqualsDeclaration */ && node.moduleReference.kind === 283 /* ExternalModuleReference */) {
                    return void 0;
                }
                else if (node.transformFlags & 1 /* ContainsTypeScript */ || hasSyntacticModifier(node, 32 /* Export */)) {
                    return visitTypeScript(node);
                }
                return node;
            }
            function getClassElementVisitor(parent2) {
                return (node) => saveStateAndInvoke(node, (n) => classElementVisitorWorker(n, parent2));
            }
            function classElementVisitorWorker(node, parent2) {
                switch (node.kind) {
                    case 176 /* Constructor */:
                        return visitConstructor(node);
                    case 172 /* PropertyDeclaration */:
                        return visitPropertyDeclaration(node, parent2);
                    case 177 /* GetAccessor */:
                        return visitGetAccessor(node, parent2);
                    case 178 /* SetAccessor */:
                        return visitSetAccessor(node, parent2);
                    case 174 /* MethodDeclaration */:
                        return visitMethodDeclaration(node, parent2);
                    case 175 /* ClassStaticBlockDeclaration */:
                        return visitEachChild(node, visitor, context);
                    case 240 /* SemicolonClassElement */:
                        return node;
                    case 181 /* IndexSignature */:
                        return;
                    default:
                        return Debug.failBadSyntaxKind(node);
                }
            }
            function getObjectLiteralElementVisitor(parent2) {
                return (node) => saveStateAndInvoke(node, (n) => objectLiteralElementVisitorWorker(n, parent2));
            }
            function objectLiteralElementVisitorWorker(node, parent2) {
                switch (node.kind) {
                    case 303 /* PropertyAssignment */:
                    case 304 /* ShorthandPropertyAssignment */:
                    case 305 /* SpreadAssignment */:
                        return visitor(node);
                    case 177 /* GetAccessor */:
                        return visitGetAccessor(node, parent2);
                    case 178 /* SetAccessor */:
                        return visitSetAccessor(node, parent2);
                    case 174 /* MethodDeclaration */:
                        return visitMethodDeclaration(node, parent2);
                    default:
                        return Debug.failBadSyntaxKind(node);
                }
            }
            function decoratorElidingVisitor(node) {
                return isDecorator(node) ? void 0 : visitor(node);
            }
            function modifierElidingVisitor(node) {
                return isModifier(node) ? void 0 : visitor(node);
            }
            function modifierVisitor(node) {
                if (isDecorator(node))
                    return void 0;
                if (modifierToFlag(node.kind) & 28895 /* TypeScriptModifier */) {
                    return void 0;
                }
                else if (currentNamespace && node.kind === 95 /* ExportKeyword */) {
                    return void 0;
                }
                return node;
            }
            function visitTypeScript(node) {
                if (isStatement(node) && hasSyntacticModifier(node, 128 /* Ambient */)) {
                    return factory2.createNotEmittedStatement(node);
                }
                switch (node.kind) {
                    case 95 /* ExportKeyword */:
                    case 90 /* DefaultKeyword */:
                        return currentNamespace ? void 0 : node;
                    case 125 /* PublicKeyword */:
                    case 123 /* PrivateKeyword */:
                    case 124 /* ProtectedKeyword */:
                    case 128 /* AbstractKeyword */:
                    case 164 /* OverrideKeyword */:
                    case 87 /* ConstKeyword */:
                    case 138 /* DeclareKeyword */:
                    case 148 /* ReadonlyKeyword */:
                    case 103 /* InKeyword */:
                    case 147 /* OutKeyword */:
                    case 188 /* ArrayType */:
                    case 189 /* TupleType */:
                    case 190 /* OptionalType */:
                    case 191 /* RestType */:
                    case 187 /* TypeLiteral */:
                    case 182 /* TypePredicate */:
                    case 168 /* TypeParameter */:
                    case 133 /* AnyKeyword */:
                    case 159 /* UnknownKeyword */:
                    case 136 /* BooleanKeyword */:
                    case 154 /* StringKeyword */:
                    case 150 /* NumberKeyword */:
                    case 146 /* NeverKeyword */:
                    case 116 /* VoidKeyword */:
                    case 155 /* SymbolKeyword */:
                    case 185 /* ConstructorType */:
                    case 184 /* FunctionType */:
                    case 186 /* TypeQuery */:
                    case 183 /* TypeReference */:
                    case 192 /* UnionType */:
                    case 193 /* IntersectionType */:
                    case 194 /* ConditionalType */:
                    case 196 /* ParenthesizedType */:
                    case 197 /* ThisType */:
                    case 198 /* TypeOperator */:
                    case 199 /* IndexedAccessType */:
                    case 200 /* MappedType */:
                    case 201 /* LiteralType */:
                    case 181 /* IndexSignature */:
                        return void 0;
                    case 265 /* TypeAliasDeclaration */:
                        return factory2.createNotEmittedStatement(node);
                    case 270 /* NamespaceExportDeclaration */:
                        return void 0;
                    case 264 /* InterfaceDeclaration */:
                        return factory2.createNotEmittedStatement(node);
                    case 263 /* ClassDeclaration */:
                        return visitClassDeclaration(node);
                    case 231 /* ClassExpression */:
                        return visitClassExpression(node);
                    case 298 /* HeritageClause */:
                        return visitHeritageClause(node);
                    case 233 /* ExpressionWithTypeArguments */:
                        return visitExpressionWithTypeArguments(node);
                    case 210 /* ObjectLiteralExpression */:
                        return visitObjectLiteralExpression(node);
                    case 176 /* Constructor */:
                    case 172 /* PropertyDeclaration */:
                    case 174 /* MethodDeclaration */:
                    case 177 /* GetAccessor */:
                    case 178 /* SetAccessor */:
                    case 175 /* ClassStaticBlockDeclaration */:
                        return Debug.fail("Class and object literal elements must be visited with their respective visitors");
                    case 262 /* FunctionDeclaration */:
                        return visitFunctionDeclaration(node);
                    case 218 /* FunctionExpression */:
                        return visitFunctionExpression(node);
                    case 219 /* ArrowFunction */:
                        return visitArrowFunction(node);
                    case 169 /* Parameter */:
                        return visitParameter(node);
                    case 217 /* ParenthesizedExpression */:
                        return visitParenthesizedExpression(node);
                    case 216 /* TypeAssertionExpression */:
                    case 234 /* AsExpression */:
                        return visitAssertionExpression(node);
                    case 238 /* SatisfiesExpression */:
                        return visitSatisfiesExpression(node);
                    case 213 /* CallExpression */:
                        return visitCallExpression(node);
                    case 214 /* NewExpression */:
                        return visitNewExpression(node);
                    case 215 /* TaggedTemplateExpression */:
                        return visitTaggedTemplateExpression(node);
                    case 235 /* NonNullExpression */:
                        return visitNonNullExpression(node);
                    case 266 /* EnumDeclaration */:
                        return visitEnumDeclaration(node);
                    case 243 /* VariableStatement */:
                        return visitVariableStatement(node);
                    case 260 /* VariableDeclaration */:
                        return visitVariableDeclaration(node);
                    case 267 /* ModuleDeclaration */:
                        return visitModuleDeclaration(node);
                    case 271 /* ImportEqualsDeclaration */:
                        return visitImportEqualsDeclaration(node);
                    case 285 /* JsxSelfClosingElement */:
                        return visitJsxSelfClosingElement(node);
                    case 286 /* JsxOpeningElement */:
                        return visitJsxJsxOpeningElement(node);
                    default:
                        return visitEachChild(node, visitor, context);
                }
            }
            function visitSourceFile(node) {
                const alwaysStrict = getStrictOptionValue(compilerOptions, "alwaysStrict") && !(isExternalModule(node) && moduleKind >= 5 /* ES2015 */) && !isJsonSourceFile(node);
                return factory2.updateSourceFile(node, visitLexicalEnvironment(node.statements, sourceElementVisitor, context, 
                /*start*/
                0, alwaysStrict));
            }
            function visitObjectLiteralExpression(node) {
                return factory2.updateObjectLiteralExpression(node, visitNodes2(node.properties, getObjectLiteralElementVisitor(node), isObjectLiteralElementLike));
            }
            function getClassFacts(node) {
                let facts = 0 /* None */;
                if (some(getProperties(node, 
                /*requireInitializer*/
                true, 
                /*isStatic*/
                true)))
                    facts |= 1 /* HasStaticInitializedProperties */;
                const extendsClauseElement = getEffectiveBaseTypeNode(node);
                if (extendsClauseElement && skipOuterExpressions(extendsClauseElement.expression).kind !== 106 /* NullKeyword */)
                    facts |= 64 /* IsDerivedClass */;
                if (classOrConstructorParameterIsDecorated(legacyDecorators, node))
                    facts |= 2 /* HasClassOrConstructorParameterDecorators */;
                if (childIsDecorated(legacyDecorators, node))
                    facts |= 4 /* HasMemberDecorators */;
                if (isExportOfNamespace(node))
                    facts |= 8 /* IsExportOfNamespace */;
                else if (isDefaultExternalModuleExport(node))
                    facts |= 32 /* IsDefaultExternalExport */;
                else if (isNamedExternalModuleExport(node))
                    facts |= 16 /* IsNamedExternalExport */;
                return facts;
            }
            function hasTypeScriptClassSyntax(node) {
                return !!(node.transformFlags & 8192 /* ContainsTypeScriptClassSyntax */);
            }
            function isClassLikeDeclarationWithTypeScriptSyntax(node) {
                return hasDecorators(node) || some(node.typeParameters) || some(node.heritageClauses, hasTypeScriptClassSyntax) || some(node.members, hasTypeScriptClassSyntax);
            }
            function visitClassDeclaration(node) {
                const facts = getClassFacts(node);
                const promoteToIIFE = languageVersion <= 1 /* ES5 */ && !!(facts & 7 /* MayNeedImmediatelyInvokedFunctionExpression */);
                if (!isClassLikeDeclarationWithTypeScriptSyntax(node) && !classOrConstructorParameterIsDecorated(legacyDecorators, node) && !isExportOfNamespace(node)) {
                    return factory2.updateClassDeclaration(node, visitNodes2(node.modifiers, modifierVisitor, isModifier), node.name, 
                    /*typeParameters*/
                    void 0, visitNodes2(node.heritageClauses, visitor, isHeritageClause), visitNodes2(node.members, getClassElementVisitor(node), isClassElement));
                }
                if (promoteToIIFE) {
                    context.startLexicalEnvironment();
                }
                const moveModifiers = promoteToIIFE || facts & 8 /* IsExportOfNamespace */;
                let modifiers = moveModifiers ? visitNodes2(node.modifiers, modifierElidingVisitor, isModifierLike) : visitNodes2(node.modifiers, visitor, isModifierLike);
                if (facts & 2 /* HasClassOrConstructorParameterDecorators */) {
                    modifiers = injectClassTypeMetadata(modifiers, node);
                }
                const needsName = moveModifiers && !node.name || facts & 4 /* HasMemberDecorators */ || facts & 1 /* HasStaticInitializedProperties */;
                const name = needsName ? node.name ?? factory2.getGeneratedNameForNode(node) : node.name;
                const classDeclaration = factory2.updateClassDeclaration(node, modifiers, name, 
                /*typeParameters*/
                void 0, visitNodes2(node.heritageClauses, visitor, isHeritageClause), transformClassMembers(node));
                let emitFlags = getEmitFlags(node);
                if (facts & 1 /* HasStaticInitializedProperties */) {
                    emitFlags |= 64 /* NoTrailingSourceMap */;
                }
                setEmitFlags(classDeclaration, emitFlags);
                let statement;
                if (promoteToIIFE) {
                    const statements = [classDeclaration];
                    const closingBraceLocation = createTokenRange(skipTrivia(currentSourceFile.text, node.members.end), 20 /* CloseBraceToken */);
                    const localName = factory2.getInternalName(node);
                    const outer = factory2.createPartiallyEmittedExpression(localName);
                    setTextRangeEnd(outer, closingBraceLocation.end);
                    setEmitFlags(outer, 3072 /* NoComments */);
                    const returnStatement = factory2.createReturnStatement(outer);
                    setTextRangePos(returnStatement, closingBraceLocation.pos);
                    setEmitFlags(returnStatement, 3072 /* NoComments */ | 768 /* NoTokenSourceMaps */);
                    statements.push(returnStatement);
                    insertStatementsAfterStandardPrologue(statements, context.endLexicalEnvironment());
                    const iife = factory2.createImmediatelyInvokedArrowFunction(statements);
                    setInternalEmitFlags(iife, 1 /* TypeScriptClassWrapper */);
                    const varDecl = factory2.createVariableDeclaration(factory2.getLocalName(node, 
                    /*allowComments*/
                    false, 
                    /*allowSourceMaps*/
                    false), 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, iife);
                    setOriginalNode(varDecl, node);
                    const varStatement = factory2.createVariableStatement(
                    /*modifiers*/
                    void 0, factory2.createVariableDeclarationList([varDecl], 1 /* Let */));
                    setOriginalNode(varStatement, node);
                    setCommentRange(varStatement, node);
                    setSourceMapRange(varStatement, moveRangePastDecorators(node));
                    startOnNewLine(varStatement);
                    statement = varStatement;
                }
                else {
                    statement = classDeclaration;
                }
                if (moveModifiers) {
                    if (facts & 8 /* IsExportOfNamespace */) {
                        return [
                            statement,
                            createExportMemberAssignmentStatement(node)
                        ];
                    }
                    if (facts & 32 /* IsDefaultExternalExport */) {
                        return [
                            statement,
                            factory2.createExportDefault(factory2.getLocalName(node, 
                            /*allowComments*/
                            false, 
                            /*allowSourceMaps*/
                            true))
                        ];
                    }
                    if (facts & 16 /* IsNamedExternalExport */) {
                        return [
                            statement,
                            factory2.createExternalModuleExport(factory2.getDeclarationName(node, 
                            /*allowComments*/
                            false, 
                            /*allowSourceMaps*/
                            true))
                        ];
                    }
                }
                return statement;
            }
            function visitClassExpression(node) {
                let modifiers = visitNodes2(node.modifiers, modifierElidingVisitor, isModifierLike);
                if (classOrConstructorParameterIsDecorated(legacyDecorators, node)) {
                    modifiers = injectClassTypeMetadata(modifiers, node);
                }
                return factory2.updateClassExpression(node, modifiers, node.name, 
                /*typeParameters*/
                void 0, visitNodes2(node.heritageClauses, visitor, isHeritageClause), transformClassMembers(node));
            }
            function transformClassMembers(node) {
                const members = visitNodes2(node.members, getClassElementVisitor(node), isClassElement);
                let newMembers;
                const constructor = getFirstConstructorWithBody(node);
                const parametersWithPropertyAssignments = constructor && filter(constructor.parameters, (p) => isParameterPropertyDeclaration(p, constructor));
                if (parametersWithPropertyAssignments) {
                    for (const parameter of parametersWithPropertyAssignments) {
                        const parameterProperty = factory2.createPropertyDeclaration(
                        /*modifiers*/
                        void 0, parameter.name, 
                        /*questionOrExclamationToken*/
                        void 0, 
                        /*type*/
                        void 0, 
                        /*initializer*/
                        void 0);
                        setOriginalNode(parameterProperty, parameter);
                        newMembers = append(newMembers, parameterProperty);
                    }
                }
                if (newMembers) {
                    newMembers = addRange(newMembers, members);
                    return setTextRange(factory2.createNodeArray(newMembers), 
                    /*location*/
                    node.members);
                }
                return members;
            }
            function injectClassTypeMetadata(modifiers, node) {
                const metadata = getTypeMetadata(node, node);
                if (some(metadata)) {
                    const modifiersArray = [];
                    addRange(modifiersArray, takeWhile(modifiers, isExportOrDefaultModifier));
                    addRange(modifiersArray, filter(modifiers, isDecorator));
                    addRange(modifiersArray, metadata);
                    addRange(modifiersArray, filter(skipWhile(modifiers, isExportOrDefaultModifier), isModifier));
                    modifiers = setTextRange(factory2.createNodeArray(modifiersArray), modifiers);
                }
                return modifiers;
            }
            function injectClassElementTypeMetadata(modifiers, node, container) {
                if (isClassLike(container) && classElementOrClassElementParameterIsDecorated(legacyDecorators, node, container)) {
                    const metadata = getTypeMetadata(node, container);
                    if (some(metadata)) {
                        const modifiersArray = [];
                        addRange(modifiersArray, filter(modifiers, isDecorator));
                        addRange(modifiersArray, metadata);
                        addRange(modifiersArray, filter(modifiers, isModifier));
                        modifiers = setTextRange(factory2.createNodeArray(modifiersArray), modifiers);
                    }
                }
                return modifiers;
            }
            function getTypeMetadata(node, container) {
                if (!legacyDecorators)
                    return void 0;
                return USE_NEW_TYPE_METADATA_FORMAT ? getNewTypeMetadata(node, container) : getOldTypeMetadata(node, container);
            }
            function getOldTypeMetadata(node, container) {
                if (typeSerializer) {
                    let decorators;
                    if (shouldAddTypeMetadata(node)) {
                        const typeMetadata = emitHelpers().createMetadataHelper("design:type", typeSerializer.serializeTypeOfNode({ currentLexicalScope, currentNameScope: container }, node));
                        decorators = append(decorators, factory2.createDecorator(typeMetadata));
                    }
                    if (shouldAddParamTypesMetadata(node)) {
                        const paramTypesMetadata = emitHelpers().createMetadataHelper("design:paramtypes", typeSerializer.serializeParameterTypesOfNode({ currentLexicalScope, currentNameScope: container }, node, container));
                        decorators = append(decorators, factory2.createDecorator(paramTypesMetadata));
                    }
                    if (shouldAddReturnTypeMetadata(node)) {
                        const returnTypeMetadata = emitHelpers().createMetadataHelper("design:returntype", typeSerializer.serializeReturnTypeOfNode({ currentLexicalScope, currentNameScope: container }, node));
                        decorators = append(decorators, factory2.createDecorator(returnTypeMetadata));
                    }
                    return decorators;
                }
            }
            function getNewTypeMetadata(node, container) {
                if (typeSerializer) {
                    let properties;
                    if (shouldAddTypeMetadata(node)) {
                        const typeProperty = factory2.createPropertyAssignment("type", factory2.createArrowFunction(
                        /*modifiers*/
                        void 0, 
                        /*typeParameters*/
                        void 0, [], 
                        /*type*/
                        void 0, factory2.createToken(39 /* EqualsGreaterThanToken */), typeSerializer.serializeTypeOfNode({ currentLexicalScope, currentNameScope: container }, node)));
                        properties = append(properties, typeProperty);
                    }
                    if (shouldAddParamTypesMetadata(node)) {
                        const paramTypeProperty = factory2.createPropertyAssignment("paramTypes", factory2.createArrowFunction(
                        /*modifiers*/
                        void 0, 
                        /*typeParameters*/
                        void 0, [], 
                        /*type*/
                        void 0, factory2.createToken(39 /* EqualsGreaterThanToken */), typeSerializer.serializeParameterTypesOfNode({ currentLexicalScope, currentNameScope: container }, node, container)));
                        properties = append(properties, paramTypeProperty);
                    }
                    if (shouldAddReturnTypeMetadata(node)) {
                        const returnTypeProperty = factory2.createPropertyAssignment("returnType", factory2.createArrowFunction(
                        /*modifiers*/
                        void 0, 
                        /*typeParameters*/
                        void 0, [], 
                        /*type*/
                        void 0, factory2.createToken(39 /* EqualsGreaterThanToken */), typeSerializer.serializeReturnTypeOfNode({ currentLexicalScope, currentNameScope: container }, node)));
                        properties = append(properties, returnTypeProperty);
                    }
                    if (properties) {
                        const typeInfoMetadata = emitHelpers().createMetadataHelper("design:typeinfo", factory2.createObjectLiteralExpression(properties, 
                        /*multiLine*/
                        true));
                        return [factory2.createDecorator(typeInfoMetadata)];
                    }
                }
            }
            function shouldAddTypeMetadata(node) {
                const kind = node.kind;
                return kind === 174 /* MethodDeclaration */ || kind === 177 /* GetAccessor */ || kind === 178 /* SetAccessor */ || kind === 172 /* PropertyDeclaration */;
            }
            function shouldAddReturnTypeMetadata(node) {
                return node.kind === 174 /* MethodDeclaration */;
            }
            function shouldAddParamTypesMetadata(node) {
                switch (node.kind) {
                    case 263 /* ClassDeclaration */:
                    case 231 /* ClassExpression */:
                        return getFirstConstructorWithBody(node) !== void 0;
                    case 174 /* MethodDeclaration */:
                    case 177 /* GetAccessor */:
                    case 178 /* SetAccessor */:
                        return true;
                }
                return false;
            }
            function getExpressionForPropertyName(member, generateNameForComputedPropertyName) {
                const name = member.name;
                if (isPrivateIdentifier(name)) {
                    return factory2.createIdentifier("");
                }
                else if (isComputedPropertyName(name)) {
                    return generateNameForComputedPropertyName && !isSimpleInlineableExpression(name.expression) ? factory2.getGeneratedNameForNode(name) : name.expression;
                }
                else if (isIdentifier(name)) {
                    return factory2.createStringLiteral(idText(name));
                }
                else {
                    return factory2.cloneNode(name);
                }
            }
            function visitPropertyNameOfClassElement(member) {
                const name = member.name;
                if (isComputedPropertyName(name) && (!hasStaticModifier(member) && currentClassHasParameterProperties || hasDecorators(member) && legacyDecorators)) {
                    const expression = visitNode(name.expression, visitor, isExpression);
                    Debug.assert(expression);
                    const innerExpression = skipPartiallyEmittedExpressions(expression);
                    if (!isSimpleInlineableExpression(innerExpression)) {
                        const generatedName = factory2.getGeneratedNameForNode(name);
                        hoistVariableDeclaration(generatedName);
                        return factory2.updateComputedPropertyName(name, factory2.createAssignment(generatedName, expression));
                    }
                }
                return Debug.checkDefined(visitNode(name, visitor, isPropertyName));
            }
            function visitHeritageClause(node) {
                if (node.token === 119 /* ImplementsKeyword */) {
                    return void 0;
                }
                return visitEachChild(node, visitor, context);
            }
            function visitExpressionWithTypeArguments(node) {
                return factory2.updateExpressionWithTypeArguments(node, Debug.checkDefined(visitNode(node.expression, visitor, isLeftHandSideExpression)), 
                /*typeArguments*/
                void 0);
            }
            function shouldEmitFunctionLikeDeclaration(node) {
                return !nodeIsMissing(node.body);
            }
            function visitPropertyDeclaration(node, parent2) {
                const isAmbient = node.flags & 33554432 /* Ambient */ || hasSyntacticModifier(node, 64 /* Abstract */);
                if (isAmbient && !(legacyDecorators && hasDecorators(node))) {
                    return void 0;
                }
                let modifiers = isClassLike(parent2) ? !isAmbient ? visitNodes2(node.modifiers, visitor, isModifierLike) : visitNodes2(node.modifiers, modifierElidingVisitor, isModifierLike) : visitNodes2(node.modifiers, decoratorElidingVisitor, isModifierLike);
                modifiers = injectClassElementTypeMetadata(modifiers, node, parent2);
                if (isAmbient) {
                    return factory2.updatePropertyDeclaration(node, concatenate(modifiers, factory2.createModifiersFromModifierFlags(128 /* Ambient */)), Debug.checkDefined(visitNode(node.name, visitor, isPropertyName)), 
                    /*questionOrExclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, 
                    /*initializer*/
                    void 0);
                }
                return factory2.updatePropertyDeclaration(node, modifiers, visitPropertyNameOfClassElement(node), 
                /*questionOrExclamationToken*/
                void 0, 
                /*type*/
                void 0, visitNode(node.initializer, visitor, isExpression));
            }
            function visitConstructor(node) {
                if (!shouldEmitFunctionLikeDeclaration(node)) {
                    return void 0;
                }
                return factory2.updateConstructorDeclaration(node, 
                /*modifiers*/
                void 0, visitParameterList(node.parameters, visitor, context), transformConstructorBody(node.body, node));
            }
            function transformConstructorBodyWorker(statementsOut, statementsIn, statementOffset, superPath, superPathDepth, initializerStatements) {
                const superStatementIndex = superPath[superPathDepth];
                const superStatement = statementsIn[superStatementIndex];
                addRange(statementsOut, visitNodes2(statementsIn, visitor, isStatement, statementOffset, superStatementIndex - statementOffset));
                if (isTryStatement(superStatement)) {
                    const tryBlockStatements = [];
                    transformConstructorBodyWorker(tryBlockStatements, superStatement.tryBlock.statements, 
                    /*statementOffset*/
                    0, superPath, superPathDepth + 1, initializerStatements);
                    const tryBlockStatementsArray = factory2.createNodeArray(tryBlockStatements);
                    setTextRange(tryBlockStatementsArray, superStatement.tryBlock.statements);
                    statementsOut.push(factory2.updateTryStatement(superStatement, factory2.updateBlock(superStatement.tryBlock, tryBlockStatements), visitNode(superStatement.catchClause, visitor, isCatchClause), visitNode(superStatement.finallyBlock, visitor, isBlock)));
                }
                else {
                    addRange(statementsOut, visitNodes2(statementsIn, visitor, isStatement, superStatementIndex, 1));
                    addRange(statementsOut, initializerStatements);
                }
                addRange(statementsOut, visitNodes2(statementsIn, visitor, isStatement, superStatementIndex + 1));
            }
            function transformConstructorBody(body, constructor) {
                const parametersWithPropertyAssignments = constructor && filter(constructor.parameters, (p) => isParameterPropertyDeclaration(p, constructor));
                if (!some(parametersWithPropertyAssignments)) {
                    return visitFunctionBody(body, visitor, context);
                }
                let statements = [];
                resumeLexicalEnvironment();
                const prologueStatementCount = factory2.copyPrologue(body.statements, statements, 
                /*ensureUseStrict*/
                false, visitor);
                const superPath = findSuperStatementIndexPath(body.statements, prologueStatementCount);
                const parameterPropertyAssignments = mapDefined(parametersWithPropertyAssignments, transformParameterWithPropertyAssignment);
                if (superPath.length) {
                    transformConstructorBodyWorker(statements, body.statements, prologueStatementCount, superPath, 
                    /*superPathDepth*/
                    0, parameterPropertyAssignments);
                }
                else {
                    addRange(statements, parameterPropertyAssignments);
                    addRange(statements, visitNodes2(body.statements, visitor, isStatement, prologueStatementCount));
                }
                statements = factory2.mergeLexicalEnvironment(statements, endLexicalEnvironment());
                const block = factory2.createBlock(setTextRange(factory2.createNodeArray(statements), body.statements), 
                /*multiLine*/
                true);
                setTextRange(block, 
                /*location*/
                body);
                setOriginalNode(block, body);
                return block;
            }
            function transformParameterWithPropertyAssignment(node) {
                const name = node.name;
                if (!isIdentifier(name)) {
                    return void 0;
                }
                const propertyName = setParent(setTextRange(factory2.cloneNode(name), name), name.parent);
                setEmitFlags(propertyName, 3072 /* NoComments */ | 96 /* NoSourceMap */);
                const localName = setParent(setTextRange(factory2.cloneNode(name), name), name.parent);
                setEmitFlags(localName, 3072 /* NoComments */);
                return startOnNewLine(removeAllComments(setTextRange(setOriginalNode(factory2.createExpressionStatement(factory2.createAssignment(setTextRange(factory2.createPropertyAccessExpression(factory2.createThis(), propertyName), node.name), localName)), node), moveRangePos(node, -1))));
            }
            function visitMethodDeclaration(node, parent2) {
                if (!(node.transformFlags & 1 /* ContainsTypeScript */)) {
                    return node;
                }
                if (!shouldEmitFunctionLikeDeclaration(node)) {
                    return void 0;
                }
                let modifiers = isClassLike(parent2) ? visitNodes2(node.modifiers, visitor, isModifierLike) : visitNodes2(node.modifiers, decoratorElidingVisitor, isModifierLike);
                modifiers = injectClassElementTypeMetadata(modifiers, node, parent2);
                return factory2.updateMethodDeclaration(node, modifiers, node.asteriskToken, visitPropertyNameOfClassElement(node), 
                /*questionToken*/
                void 0, 
                /*typeParameters*/
                void 0, visitParameterList(node.parameters, visitor, context), 
                /*type*/
                void 0, visitFunctionBody(node.body, visitor, context));
            }
            function shouldEmitAccessorDeclaration(node) {
                return !(nodeIsMissing(node.body) && hasSyntacticModifier(node, 64 /* Abstract */));
            }
            function visitGetAccessor(node, parent2) {
                if (!(node.transformFlags & 1 /* ContainsTypeScript */)) {
                    return node;
                }
                if (!shouldEmitAccessorDeclaration(node)) {
                    return void 0;
                }
                let modifiers = isClassLike(parent2) ? visitNodes2(node.modifiers, visitor, isModifierLike) : visitNodes2(node.modifiers, decoratorElidingVisitor, isModifierLike);
                modifiers = injectClassElementTypeMetadata(modifiers, node, parent2);
                return factory2.updateGetAccessorDeclaration(node, modifiers, visitPropertyNameOfClassElement(node), visitParameterList(node.parameters, visitor, context), 
                /*type*/
                void 0, visitFunctionBody(node.body, visitor, context) || factory2.createBlock([]));
            }
            function visitSetAccessor(node, parent2) {
                if (!(node.transformFlags & 1 /* ContainsTypeScript */)) {
                    return node;
                }
                if (!shouldEmitAccessorDeclaration(node)) {
                    return void 0;
                }
                let modifiers = isClassLike(parent2) ? visitNodes2(node.modifiers, visitor, isModifierLike) : visitNodes2(node.modifiers, decoratorElidingVisitor, isModifierLike);
                modifiers = injectClassElementTypeMetadata(modifiers, node, parent2);
                return factory2.updateSetAccessorDeclaration(node, modifiers, visitPropertyNameOfClassElement(node), visitParameterList(node.parameters, visitor, context), visitFunctionBody(node.body, visitor, context) || factory2.createBlock([]));
            }
            function visitFunctionDeclaration(node) {
                if (!shouldEmitFunctionLikeDeclaration(node)) {
                    return factory2.createNotEmittedStatement(node);
                }
                const updated = factory2.updateFunctionDeclaration(node, visitNodes2(node.modifiers, modifierVisitor, isModifier), node.asteriskToken, node.name, 
                /*typeParameters*/
                void 0, visitParameterList(node.parameters, visitor, context), 
                /*type*/
                void 0, visitFunctionBody(node.body, visitor, context) || factory2.createBlock([]));
                if (isExportOfNamespace(node)) {
                    const statements = [updated];
                    addExportMemberAssignment(statements, node);
                    return statements;
                }
                return updated;
            }
            function visitFunctionExpression(node) {
                if (!shouldEmitFunctionLikeDeclaration(node)) {
                    return factory2.createOmittedExpression();
                }
                const updated = factory2.updateFunctionExpression(node, visitNodes2(node.modifiers, modifierVisitor, isModifier), node.asteriskToken, node.name, 
                /*typeParameters*/
                void 0, visitParameterList(node.parameters, visitor, context), 
                /*type*/
                void 0, visitFunctionBody(node.body, visitor, context) || factory2.createBlock([]));
                return updated;
            }
            function visitArrowFunction(node) {
                const updated = factory2.updateArrowFunction(node, visitNodes2(node.modifiers, modifierVisitor, isModifier), 
                /*typeParameters*/
                void 0, visitParameterList(node.parameters, visitor, context), 
                /*type*/
                void 0, node.equalsGreaterThanToken, visitFunctionBody(node.body, visitor, context));
                return updated;
            }
            function visitParameter(node) {
                if (parameterIsThisKeyword(node)) {
                    return void 0;
                }
                const updated = factory2.updateParameterDeclaration(node, visitNodes2(node.modifiers, (node2) => isDecorator(node2) ? visitor(node2) : void 0, isModifierLike), node.dotDotDotToken, Debug.checkDefined(visitNode(node.name, visitor, isBindingName)), 
                /*questionToken*/
                void 0, 
                /*type*/
                void 0, visitNode(node.initializer, visitor, isExpression));
                if (updated !== node) {
                    setCommentRange(updated, node);
                    setTextRange(updated, moveRangePastModifiers(node));
                    setSourceMapRange(updated, moveRangePastModifiers(node));
                    setEmitFlags(updated.name, 64 /* NoTrailingSourceMap */);
                }
                return updated;
            }
            function visitVariableStatement(node) {
                if (isExportOfNamespace(node)) {
                    const variables = getInitializedVariables(node.declarationList);
                    if (variables.length === 0) {
                        return void 0;
                    }
                    return setTextRange(factory2.createExpressionStatement(factory2.inlineExpressions(map(variables, transformInitializedVariable))), node);
                }
                else {
                    return visitEachChild(node, visitor, context);
                }
            }
            function transformInitializedVariable(node) {
                const name = node.name;
                if (isBindingPattern(name)) {
                    return flattenDestructuringAssignment(node, visitor, context, 0 /* All */, 
                    /*needsValue*/
                    false, createNamespaceExportExpression);
                }
                else {
                    return setTextRange(factory2.createAssignment(getNamespaceMemberNameWithSourceMapsAndWithoutComments(name), Debug.checkDefined(visitNode(node.initializer, visitor, isExpression))), 
                    /*location*/
                    node);
                }
            }
            function visitVariableDeclaration(node) {
                const updated = factory2.updateVariableDeclaration(node, Debug.checkDefined(visitNode(node.name, visitor, isBindingName)), 
                /*exclamationToken*/
                void 0, 
                /*type*/
                void 0, visitNode(node.initializer, visitor, isExpression));
                if (node.type) {
                    setTypeNode(updated.name, node.type);
                }
                return updated;
            }
            function visitParenthesizedExpression(node) {
                const innerExpression = skipOuterExpressions(node.expression, ~6 /* Assertions */);
                if (isAssertionExpression(innerExpression)) {
                    const expression = visitNode(node.expression, visitor, isExpression);
                    Debug.assert(expression);
                    return factory2.createPartiallyEmittedExpression(expression, node);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitAssertionExpression(node) {
                const expression = visitNode(node.expression, visitor, isExpression);
                Debug.assert(expression);
                return factory2.createPartiallyEmittedExpression(expression, node);
            }
            function visitNonNullExpression(node) {
                const expression = visitNode(node.expression, visitor, isLeftHandSideExpression);
                Debug.assert(expression);
                return factory2.createPartiallyEmittedExpression(expression, node);
            }
            function visitSatisfiesExpression(node) {
                const expression = visitNode(node.expression, visitor, isExpression);
                Debug.assert(expression);
                return factory2.createPartiallyEmittedExpression(expression, node);
            }
            function visitCallExpression(node) {
                return factory2.updateCallExpression(node, Debug.checkDefined(visitNode(node.expression, visitor, isExpression)), 
                /*typeArguments*/
                void 0, visitNodes2(node.arguments, visitor, isExpression));
            }
            function visitNewExpression(node) {
                return factory2.updateNewExpression(node, Debug.checkDefined(visitNode(node.expression, visitor, isExpression)), 
                /*typeArguments*/
                void 0, visitNodes2(node.arguments, visitor, isExpression));
            }
            function visitTaggedTemplateExpression(node) {
                return factory2.updateTaggedTemplateExpression(node, Debug.checkDefined(visitNode(node.tag, visitor, isExpression)), 
                /*typeArguments*/
                void 0, Debug.checkDefined(visitNode(node.template, visitor, isTemplateLiteral)));
            }
            function visitJsxSelfClosingElement(node) {
                return factory2.updateJsxSelfClosingElement(node, Debug.checkDefined(visitNode(node.tagName, visitor, isJsxTagNameExpression)), 
                /*typeArguments*/
                void 0, Debug.checkDefined(visitNode(node.attributes, visitor, isJsxAttributes)));
            }
            function visitJsxJsxOpeningElement(node) {
                return factory2.updateJsxOpeningElement(node, Debug.checkDefined(visitNode(node.tagName, visitor, isJsxTagNameExpression)), 
                /*typeArguments*/
                void 0, Debug.checkDefined(visitNode(node.attributes, visitor, isJsxAttributes)));
            }
            function shouldEmitEnumDeclaration(node) {
                return !isEnumConst(node) || shouldPreserveConstEnums(compilerOptions);
            }
            function visitEnumDeclaration(node) {
                if (!shouldEmitEnumDeclaration(node)) {
                    return factory2.createNotEmittedStatement(node);
                }
                const statements = [];
                let emitFlags = 4 /* AdviseOnEmitNode */;
                const varAdded = addVarForEnumOrModuleDeclaration(statements, node);
                if (varAdded) {
                    if (moduleKind !== 4 /* System */ || currentLexicalScope !== currentSourceFile) {
                        emitFlags |= 1024 /* NoLeadingComments */;
                    }
                }
                const parameterName = getNamespaceParameterName(node);
                const containerName = getNamespaceContainerName(node);
                const exportName = isExportOfNamespace(node) ? factory2.getExternalModuleOrNamespaceExportName(currentNamespaceContainerName, node, 
                /*allowComments*/
                false, 
                /*allowSourceMaps*/
                true) : factory2.getDeclarationName(node, 
                /*allowComments*/
                false, 
                /*allowSourceMaps*/
                true);
                let moduleArg = factory2.createLogicalOr(exportName, factory2.createAssignment(exportName, factory2.createObjectLiteralExpression()));
                if (isExportOfNamespace(node)) {
                    const localName = factory2.getLocalName(node, 
                    /*allowComments*/
                    false, 
                    /*allowSourceMaps*/
                    true);
                    moduleArg = factory2.createAssignment(localName, moduleArg);
                }
                const enumStatement = factory2.createExpressionStatement(factory2.createCallExpression(factory2.createFunctionExpression(
                /*modifiers*/
                void 0, 
                /*asteriskToken*/
                void 0, 
                /*name*/
                void 0, 
                /*typeParameters*/
                void 0, [factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, parameterName)], 
                /*type*/
                void 0, transformEnumBody(node, containerName)), 
                /*typeArguments*/
                void 0, [moduleArg]));
                setOriginalNode(enumStatement, node);
                if (varAdded) {
                    setSyntheticLeadingComments(enumStatement, void 0);
                    setSyntheticTrailingComments(enumStatement, void 0);
                }
                setTextRange(enumStatement, node);
                addEmitFlags(enumStatement, emitFlags);
                statements.push(enumStatement);
                return statements;
            }
            function transformEnumBody(node, localName) {
                const savedCurrentNamespaceLocalName = currentNamespaceContainerName;
                currentNamespaceContainerName = localName;
                const statements = [];
                startLexicalEnvironment();
                const members = map(node.members, transformEnumMember);
                insertStatementsAfterStandardPrologue(statements, endLexicalEnvironment());
                addRange(statements, members);
                currentNamespaceContainerName = savedCurrentNamespaceLocalName;
                return factory2.createBlock(setTextRange(factory2.createNodeArray(statements), 
                /*location*/
                node.members), 
                /*multiLine*/
                true);
            }
            function transformEnumMember(member) {
                const name = getExpressionForPropertyName(member, 
                /*generateNameForComputedPropertyName*/
                false);
                const valueExpression = transformEnumMemberDeclarationValue(member);
                const innerAssignment = factory2.createAssignment(factory2.createElementAccessExpression(currentNamespaceContainerName, name), valueExpression);
                const outerAssignment = valueExpression.kind === 11 /* StringLiteral */ ? innerAssignment : factory2.createAssignment(factory2.createElementAccessExpression(currentNamespaceContainerName, innerAssignment), name);
                return setTextRange(factory2.createExpressionStatement(setTextRange(outerAssignment, member)), member);
            }
            function transformEnumMemberDeclarationValue(member) {
                const value = resolver.getConstantValue(member);
                if (value !== void 0) {
                    return typeof value === "string" ? factory2.createStringLiteral(value) : value < 0 ? factory2.createPrefixUnaryExpression(41 /* MinusToken */, factory2.createNumericLiteral(-value)) : factory2.createNumericLiteral(value);
                }
                else {
                    enableSubstitutionForNonQualifiedEnumMembers();
                    if (member.initializer) {
                        return Debug.checkDefined(visitNode(member.initializer, visitor, isExpression));
                    }
                    else {
                        return factory2.createVoidZero();
                    }
                }
            }
            function shouldEmitModuleDeclaration(nodeIn) {
                const node = getParseTreeNode(nodeIn, isModuleDeclaration);
                if (!node) {
                    return true;
                }
                return isInstantiatedModule(node, shouldPreserveConstEnums(compilerOptions));
            }
            function recordEmittedDeclarationInScope(node) {
                if (!currentScopeFirstDeclarationsOfName) {
                    currentScopeFirstDeclarationsOfName = /* @__PURE__ */ new Map();
                }
                const name = declaredNameInScope(node);
                if (!currentScopeFirstDeclarationsOfName.has(name)) {
                    currentScopeFirstDeclarationsOfName.set(name, node);
                }
            }
            function isFirstEmittedDeclarationInScope(node) {
                if (currentScopeFirstDeclarationsOfName) {
                    const name = declaredNameInScope(node);
                    return currentScopeFirstDeclarationsOfName.get(name) === node;
                }
                return true;
            }
            function declaredNameInScope(node) {
                Debug.assertNode(node.name, isIdentifier);
                return node.name.escapedText;
            }
            function addVarForEnumOrModuleDeclaration(statements, node) {
                const varDecl = factory2.createVariableDeclaration(factory2.getLocalName(node, 
                /*allowComments*/
                false, 
                /*allowSourceMaps*/
                true));
                const varFlags = currentLexicalScope.kind === 312 /* SourceFile */ ? 0 /* None */ : 1 /* Let */;
                const statement = factory2.createVariableStatement(visitNodes2(node.modifiers, modifierVisitor, isModifier), factory2.createVariableDeclarationList([varDecl], varFlags));
                setOriginalNode(varDecl, node);
                setSyntheticLeadingComments(varDecl, void 0);
                setSyntheticTrailingComments(varDecl, void 0);
                setOriginalNode(statement, node);
                recordEmittedDeclarationInScope(node);
                if (isFirstEmittedDeclarationInScope(node)) {
                    if (node.kind === 266 /* EnumDeclaration */) {
                        setSourceMapRange(statement.declarationList, node);
                    }
                    else {
                        setSourceMapRange(statement, node);
                    }
                    setCommentRange(statement, node);
                    addEmitFlags(statement, 2048 /* NoTrailingComments */);
                    statements.push(statement);
                    return true;
                }
                return false;
            }
            function visitModuleDeclaration(node) {
                if (!shouldEmitModuleDeclaration(node)) {
                    return factory2.createNotEmittedStatement(node);
                }
                Debug.assertNode(node.name, isIdentifier, "A TypeScript namespace should have an Identifier name.");
                enableSubstitutionForNamespaceExports();
                const statements = [];
                let emitFlags = 4 /* AdviseOnEmitNode */;
                const varAdded = addVarForEnumOrModuleDeclaration(statements, node);
                if (varAdded) {
                    if (moduleKind !== 4 /* System */ || currentLexicalScope !== currentSourceFile) {
                        emitFlags |= 1024 /* NoLeadingComments */;
                    }
                }
                const parameterName = getNamespaceParameterName(node);
                const containerName = getNamespaceContainerName(node);
                const exportName = isExportOfNamespace(node) ? factory2.getExternalModuleOrNamespaceExportName(currentNamespaceContainerName, node, 
                /*allowComments*/
                false, 
                /*allowSourceMaps*/
                true) : factory2.getDeclarationName(node, 
                /*allowComments*/
                false, 
                /*allowSourceMaps*/
                true);
                let moduleArg = factory2.createLogicalOr(exportName, factory2.createAssignment(exportName, factory2.createObjectLiteralExpression()));
                if (isExportOfNamespace(node)) {
                    const localName = factory2.getLocalName(node, 
                    /*allowComments*/
                    false, 
                    /*allowSourceMaps*/
                    true);
                    moduleArg = factory2.createAssignment(localName, moduleArg);
                }
                const moduleStatement = factory2.createExpressionStatement(factory2.createCallExpression(factory2.createFunctionExpression(
                /*modifiers*/
                void 0, 
                /*asteriskToken*/
                void 0, 
                /*name*/
                void 0, 
                /*typeParameters*/
                void 0, [factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, parameterName)], 
                /*type*/
                void 0, transformModuleBody(node, containerName)), 
                /*typeArguments*/
                void 0, [moduleArg]));
                setOriginalNode(moduleStatement, node);
                if (varAdded) {
                    setSyntheticLeadingComments(moduleStatement, void 0);
                    setSyntheticTrailingComments(moduleStatement, void 0);
                }
                setTextRange(moduleStatement, node);
                addEmitFlags(moduleStatement, emitFlags);
                statements.push(moduleStatement);
                return statements;
            }
            function transformModuleBody(node, namespaceLocalName) {
                const savedCurrentNamespaceContainerName = currentNamespaceContainerName;
                const savedCurrentNamespace = currentNamespace;
                const savedCurrentScopeFirstDeclarationsOfName = currentScopeFirstDeclarationsOfName;
                currentNamespaceContainerName = namespaceLocalName;
                currentNamespace = node;
                currentScopeFirstDeclarationsOfName = void 0;
                const statements = [];
                startLexicalEnvironment();
                let statementsLocation;
                let blockLocation;
                if (node.body) {
                    if (node.body.kind === 268 /* ModuleBlock */) {
                        saveStateAndInvoke(node.body, (body) => addRange(statements, visitNodes2(body.statements, namespaceElementVisitor, isStatement)));
                        statementsLocation = node.body.statements;
                        blockLocation = node.body;
                    }
                    else {
                        const result = visitModuleDeclaration(node.body);
                        if (result) {
                            if (isArray(result)) {
                                addRange(statements, result);
                            }
                            else {
                                statements.push(result);
                            }
                        }
                        const moduleBlock = getInnerMostModuleDeclarationFromDottedModule(node).body;
                        statementsLocation = moveRangePos(moduleBlock.statements, -1);
                    }
                }
                insertStatementsAfterStandardPrologue(statements, endLexicalEnvironment());
                currentNamespaceContainerName = savedCurrentNamespaceContainerName;
                currentNamespace = savedCurrentNamespace;
                currentScopeFirstDeclarationsOfName = savedCurrentScopeFirstDeclarationsOfName;
                const block = factory2.createBlock(setTextRange(factory2.createNodeArray(statements), 
                /*location*/
                statementsLocation), 
                /*multiLine*/
                true);
                setTextRange(block, blockLocation);
                if (!node.body || node.body.kind !== 268 /* ModuleBlock */) {
                    setEmitFlags(block, getEmitFlags(block) | 3072 /* NoComments */);
                }
                return block;
            }
            function getInnerMostModuleDeclarationFromDottedModule(moduleDeclaration) {
                if (moduleDeclaration.body.kind === 267 /* ModuleDeclaration */) {
                    const recursiveInnerModule = getInnerMostModuleDeclarationFromDottedModule(moduleDeclaration.body);
                    return recursiveInnerModule || moduleDeclaration.body;
                }
            }
            function visitImportDeclaration(node) {
                if (!node.importClause) {
                    return node;
                }
                if (node.importClause.isTypeOnly) {
                    return void 0;
                }
                const importClause = visitNode(node.importClause, visitImportClause, isImportClause);
                return importClause || compilerOptions.importsNotUsedAsValues === 1 /* Preserve */ || compilerOptions.importsNotUsedAsValues === 2 /* Error */ ? factory2.updateImportDeclaration(node, 
                /*modifiers*/
                void 0, importClause, node.moduleSpecifier, node.attributes) : void 0;
            }
            function visitImportClause(node) {
                Debug.assert(!node.isTypeOnly);
                const name = shouldEmitAliasDeclaration(node) ? node.name : void 0;
                const namedBindings = visitNode(node.namedBindings, visitNamedImportBindings, isNamedImportBindings);
                return name || namedBindings ? factory2.updateImportClause(node, 
                /*isTypeOnly*/
                false, name, namedBindings) : void 0;
            }
            function visitNamedImportBindings(node) {
                if (node.kind === 274 /* NamespaceImport */) {
                    return shouldEmitAliasDeclaration(node) ? node : void 0;
                }
                else {
                    const allowEmpty = compilerOptions.verbatimModuleSyntax || compilerOptions.preserveValueImports && (compilerOptions.importsNotUsedAsValues === 1 /* Preserve */ || compilerOptions.importsNotUsedAsValues === 2 /* Error */);
                    const elements = visitNodes2(node.elements, visitImportSpecifier, isImportSpecifier);
                    return allowEmpty || some(elements) ? factory2.updateNamedImports(node, elements) : void 0;
                }
            }
            function visitImportSpecifier(node) {
                return !node.isTypeOnly && shouldEmitAliasDeclaration(node) ? node : void 0;
            }
            function visitExportAssignment(node) {
                return compilerOptions.verbatimModuleSyntax || resolver.isValueAliasDeclaration(node) ? visitEachChild(node, visitor, context) : void 0;
            }
            function visitExportDeclaration(node) {
                if (node.isTypeOnly) {
                    return void 0;
                }
                if (!node.exportClause || isNamespaceExport(node.exportClause)) {
                    return node;
                }
                const allowEmpty = compilerOptions.verbatimModuleSyntax || !!node.moduleSpecifier && (compilerOptions.importsNotUsedAsValues === 1 /* Preserve */ || compilerOptions.importsNotUsedAsValues === 2 /* Error */);
                const exportClause = visitNode(node.exportClause, (bindings) => visitNamedExportBindings(bindings, allowEmpty), isNamedExportBindings);
                return exportClause ? factory2.updateExportDeclaration(node, 
                /*modifiers*/
                void 0, node.isTypeOnly, exportClause, node.moduleSpecifier, node.attributes) : void 0;
            }
            function visitNamedExports(node, allowEmpty) {
                const elements = visitNodes2(node.elements, visitExportSpecifier, isExportSpecifier);
                return allowEmpty || some(elements) ? factory2.updateNamedExports(node, elements) : void 0;
            }
            function visitNamespaceExports(node) {
                return factory2.updateNamespaceExport(node, Debug.checkDefined(visitNode(node.name, visitor, isIdentifier)));
            }
            function visitNamedExportBindings(node, allowEmpty) {
                return isNamespaceExport(node) ? visitNamespaceExports(node) : visitNamedExports(node, allowEmpty);
            }
            function visitExportSpecifier(node) {
                return !node.isTypeOnly && (compilerOptions.verbatimModuleSyntax || resolver.isValueAliasDeclaration(node)) ? node : void 0;
            }
            function shouldEmitImportEqualsDeclaration(node) {
                return shouldEmitAliasDeclaration(node) || !isExternalModule(currentSourceFile) && resolver.isTopLevelValueImportEqualsWithEntityName(node);
            }
            function visitImportEqualsDeclaration(node) {
                if (node.isTypeOnly) {
                    return void 0;
                }
                if (isExternalModuleImportEqualsDeclaration(node)) {
                    const isReferenced = shouldEmitAliasDeclaration(node);
                    if (!isReferenced && compilerOptions.importsNotUsedAsValues === 1 /* Preserve */) {
                        return setOriginalNode(setTextRange(factory2.createImportDeclaration(
                        /*modifiers*/
                        void 0, 
                        /*importClause*/
                        void 0, node.moduleReference.expression, 
                        /*attributes*/
                        void 0), node), node);
                    }
                    return isReferenced ? visitEachChild(node, visitor, context) : void 0;
                }
                if (!shouldEmitImportEqualsDeclaration(node)) {
                    return void 0;
                }
                const moduleReference = createExpressionFromEntityName(factory2, node.moduleReference);
                setEmitFlags(moduleReference, 3072 /* NoComments */ | 4096 /* NoNestedComments */);
                if (isNamedExternalModuleExport(node) || !isExportOfNamespace(node)) {
                    return setOriginalNode(setTextRange(factory2.createVariableStatement(visitNodes2(node.modifiers, modifierVisitor, isModifier), factory2.createVariableDeclarationList([
                        setOriginalNode(factory2.createVariableDeclaration(node.name, 
                        /*exclamationToken*/
                        void 0, 
                        /*type*/
                        void 0, moduleReference), node)
                    ])), node), node);
                }
                else {
                    return setOriginalNode(createNamespaceExport(node.name, moduleReference, node), node);
                }
            }
            function isExportOfNamespace(node) {
                return currentNamespace !== void 0 && hasSyntacticModifier(node, 32 /* Export */);
            }
            function isExternalModuleExport(node) {
                return currentNamespace === void 0 && hasSyntacticModifier(node, 32 /* Export */);
            }
            function isNamedExternalModuleExport(node) {
                return isExternalModuleExport(node) && !hasSyntacticModifier(node, 2048 /* Default */);
            }
            function isDefaultExternalModuleExport(node) {
                return isExternalModuleExport(node) && hasSyntacticModifier(node, 2048 /* Default */);
            }
            function createExportMemberAssignmentStatement(node) {
                const expression = factory2.createAssignment(factory2.getExternalModuleOrNamespaceExportName(currentNamespaceContainerName, node, 
                /*allowComments*/
                false, 
                /*allowSourceMaps*/
                true), factory2.getLocalName(node));
                setSourceMapRange(expression, createRange(node.name ? node.name.pos : node.pos, node.end));
                const statement = factory2.createExpressionStatement(expression);
                setSourceMapRange(statement, createRange(-1, node.end));
                return statement;
            }
            function addExportMemberAssignment(statements, node) {
                statements.push(createExportMemberAssignmentStatement(node));
            }
            function createNamespaceExport(exportName, exportValue, location) {
                return setTextRange(factory2.createExpressionStatement(factory2.createAssignment(factory2.getNamespaceMemberName(currentNamespaceContainerName, exportName, 
                /*allowComments*/
                false, 
                /*allowSourceMaps*/
                true), exportValue)), location);
            }
            function createNamespaceExportExpression(exportName, exportValue, location) {
                return setTextRange(factory2.createAssignment(getNamespaceMemberNameWithSourceMapsAndWithoutComments(exportName), exportValue), location);
            }
            function getNamespaceMemberNameWithSourceMapsAndWithoutComments(name) {
                return factory2.getNamespaceMemberName(currentNamespaceContainerName, name, 
                /*allowComments*/
                false, 
                /*allowSourceMaps*/
                true);
            }
            function getNamespaceParameterName(node) {
                const name = factory2.getGeneratedNameForNode(node);
                setSourceMapRange(name, node.name);
                return name;
            }
            function getNamespaceContainerName(node) {
                return factory2.getGeneratedNameForNode(node);
            }
            function enableSubstitutionForNonQualifiedEnumMembers() {
                if ((enabledSubstitutions & 8 /* NonQualifiedEnumMembers */) === 0) {
                    enabledSubstitutions |= 8 /* NonQualifiedEnumMembers */;
                    context.enableSubstitution(80 /* Identifier */);
                }
            }
            function enableSubstitutionForNamespaceExports() {
                if ((enabledSubstitutions & 2 /* NamespaceExports */) === 0) {
                    enabledSubstitutions |= 2 /* NamespaceExports */;
                    context.enableSubstitution(80 /* Identifier */);
                    context.enableSubstitution(304 /* ShorthandPropertyAssignment */);
                    context.enableEmitNotification(267 /* ModuleDeclaration */);
                }
            }
            function isTransformedModuleDeclaration(node) {
                return getOriginalNode(node).kind === 267 /* ModuleDeclaration */;
            }
            function isTransformedEnumDeclaration(node) {
                return getOriginalNode(node).kind === 266 /* EnumDeclaration */;
            }
            function onEmitNode(hint, node, emitCallback) {
                const savedApplicableSubstitutions = applicableSubstitutions;
                const savedCurrentSourceFile = currentSourceFile;
                if (isSourceFile(node)) {
                    currentSourceFile = node;
                }
                if (enabledSubstitutions & 2 /* NamespaceExports */ && isTransformedModuleDeclaration(node)) {
                    applicableSubstitutions |= 2 /* NamespaceExports */;
                }
                if (enabledSubstitutions & 8 /* NonQualifiedEnumMembers */ && isTransformedEnumDeclaration(node)) {
                    applicableSubstitutions |= 8 /* NonQualifiedEnumMembers */;
                }
                previousOnEmitNode(hint, node, emitCallback);
                applicableSubstitutions = savedApplicableSubstitutions;
                currentSourceFile = savedCurrentSourceFile;
            }
            function onSubstituteNode(hint, node) {
                node = previousOnSubstituteNode(hint, node);
                if (hint === 1 /* Expression */) {
                    return substituteExpression(node);
                }
                else if (isShorthandPropertyAssignment(node)) {
                    return substituteShorthandPropertyAssignment(node);
                }
                return node;
            }
            function substituteShorthandPropertyAssignment(node) {
                if (enabledSubstitutions & 2 /* NamespaceExports */) {
                    const name = node.name;
                    const exportedName = trySubstituteNamespaceExportedName(name);
                    if (exportedName) {
                        if (node.objectAssignmentInitializer) {
                            const initializer = factory2.createAssignment(exportedName, node.objectAssignmentInitializer);
                            return setTextRange(factory2.createPropertyAssignment(name, initializer), node);
                        }
                        return setTextRange(factory2.createPropertyAssignment(name, exportedName), node);
                    }
                }
                return node;
            }
            function substituteExpression(node) {
                switch (node.kind) {
                    case 80 /* Identifier */:
                        return substituteExpressionIdentifier(node);
                    case 211 /* PropertyAccessExpression */:
                        return substitutePropertyAccessExpression(node);
                    case 212 /* ElementAccessExpression */:
                        return substituteElementAccessExpression(node);
                }
                return node;
            }
            function substituteExpressionIdentifier(node) {
                return trySubstituteNamespaceExportedName(node) || node;
            }
            function trySubstituteNamespaceExportedName(node) {
                if (enabledSubstitutions & applicableSubstitutions && !isGeneratedIdentifier(node) && !isLocalName(node)) {
                    const container = resolver.getReferencedExportContainer(node, 
                    /*prefixLocals*/
                    false);
                    if (container && container.kind !== 312 /* SourceFile */) {
                        const substitute = applicableSubstitutions & 2 /* NamespaceExports */ && container.kind === 267 /* ModuleDeclaration */ || applicableSubstitutions & 8 /* NonQualifiedEnumMembers */ && container.kind === 266 /* EnumDeclaration */;
                        if (substitute) {
                            return setTextRange(factory2.createPropertyAccessExpression(factory2.getGeneratedNameForNode(container), node), 
                            /*location*/
                            node);
                        }
                    }
                }
                return void 0;
            }
            function substitutePropertyAccessExpression(node) {
                return substituteConstantValue(node);
            }
            function substituteElementAccessExpression(node) {
                return substituteConstantValue(node);
            }
            function safeMultiLineComment(value) {
                return value.replace(/\*\//g, "*_/");
            }
            function substituteConstantValue(node) {
                const constantValue = tryGetConstEnumValue(node);
                if (constantValue !== void 0) {
                    setConstantValue(node, constantValue);
                    const substitute = typeof constantValue === "string" ? factory2.createStringLiteral(constantValue) : constantValue < 0 ? factory2.createPrefixUnaryExpression(41 /* MinusToken */, factory2.createNumericLiteral(-constantValue)) : factory2.createNumericLiteral(constantValue);
                    if (!compilerOptions.removeComments) {
                        const originalNode = getOriginalNode(node, isAccessExpression);
                        addSyntheticTrailingComment(substitute, 3 /* MultiLineCommentTrivia */, ` ${safeMultiLineComment(getTextOfNode(originalNode))} `);
                    }
                    return substitute;
                }
                return node;
            }
            function tryGetConstEnumValue(node) {
                if (getIsolatedModules(compilerOptions)) {
                    return void 0;
                }
                return isPropertyAccessExpression(node) || isElementAccessExpression(node) ? resolver.getConstantValue(node) : void 0;
            }
            function shouldEmitAliasDeclaration(node) {
                return compilerOptions.verbatimModuleSyntax || isInJSFile(node) || (compilerOptions.preserveValueImports ? resolver.isValueAliasDeclaration(node) : resolver.isReferencedAliasDeclaration(node));
            }
        }
        var USE_NEW_TYPE_METADATA_FORMAT;
        var init_ts = __esm({
            "src/compiler/transformers/ts.ts"() {
                "use strict";
                init_ts2();
                USE_NEW_TYPE_METADATA_FORMAT = false;
            }
        });
        // src/compiler/transformers/classFields.ts
        function transformClassFields(context) {
            const { factory: factory2, getEmitHelperFactory: emitHelpers, hoistVariableDeclaration, endLexicalEnvironment, startLexicalEnvironment, resumeLexicalEnvironment, addBlockScopedVariable } = context;
            const resolver = context.getEmitResolver();
            const compilerOptions = context.getCompilerOptions();
            const languageVersion = getEmitScriptTarget(compilerOptions);
            const useDefineForClassFields = getUseDefineForClassFields(compilerOptions);
            const legacyDecorators = !!compilerOptions.experimentalDecorators;
            const shouldTransformInitializersUsingSet = !useDefineForClassFields;
            const shouldTransformInitializersUsingDefine = useDefineForClassFields && languageVersion < 9 /* ES2022 */;
            const shouldTransformInitializers = shouldTransformInitializersUsingSet || shouldTransformInitializersUsingDefine;
            const shouldTransformPrivateElementsOrClassStaticBlocks = languageVersion < 9 /* ES2022 */;
            const shouldTransformAutoAccessors = languageVersion < 99 /* ESNext */ ? -1 /* True */ : !useDefineForClassFields ? 3 /* Maybe */ : 0 /* False */;
            const shouldTransformThisInStaticInitializers = languageVersion < 9 /* ES2022 */;
            const shouldTransformSuperInStaticInitializers = shouldTransformThisInStaticInitializers && languageVersion >= 2 /* ES2015 */;
            const shouldTransformAnything = shouldTransformInitializers || shouldTransformPrivateElementsOrClassStaticBlocks || shouldTransformAutoAccessors === -1 /* True */;
            const previousOnSubstituteNode = context.onSubstituteNode;
            context.onSubstituteNode = onSubstituteNode;
            const previousOnEmitNode = context.onEmitNode;
            context.onEmitNode = onEmitNode;
            let shouldTransformPrivateStaticElementsInFile = false;
            let enabledSubstitutions;
            let classAliases;
            let pendingExpressions;
            let pendingStatements;
            let lexicalEnvironment;
            const lexicalEnvironmentMap = /* @__PURE__ */ new Map();
            const noSubstitution = /* @__PURE__ */ new Set();
            let currentClassContainer;
            let currentClassElement;
            let shouldSubstituteThisWithClassThis = false;
            let previousShouldSubstituteThisWithClassThis = false;
            return chainBundle(context, transformSourceFile);
            function transformSourceFile(node) {
                if (node.isDeclarationFile) {
                    return node;
                }
                lexicalEnvironment = void 0;
                shouldTransformPrivateStaticElementsInFile = !!(getInternalEmitFlags(node) & 32 /* TransformPrivateStaticElements */);
                if (!shouldTransformAnything && !shouldTransformPrivateStaticElementsInFile) {
                    return node;
                }
                const visited = visitEachChild(node, visitor, context);
                addEmitHelpers(visited, context.readEmitHelpers());
                return visited;
            }
            function modifierVisitor(node) {
                switch (node.kind) {
                    case 129 /* AccessorKeyword */:
                        return shouldTransformAutoAccessorsInCurrentClass() ? void 0 : node;
                    default:
                        return tryCast(node, isModifier);
                }
            }
            function visitor(node) {
                if (!(node.transformFlags & 16777216 /* ContainsClassFields */) && !(node.transformFlags & 134234112 /* ContainsLexicalThisOrSuper */)) {
                    return node;
                }
                switch (node.kind) {
                    case 129 /* AccessorKeyword */:
                        return Debug.fail("Use `modifierVisitor` instead.");
                    case 263 /* ClassDeclaration */:
                        return visitClassDeclaration(node);
                    case 231 /* ClassExpression */:
                        return visitClassExpression(node);
                    case 175 /* ClassStaticBlockDeclaration */:
                    case 172 /* PropertyDeclaration */:
                        return Debug.fail("Use `classElementVisitor` instead.");
                    case 303 /* PropertyAssignment */:
                        return visitPropertyAssignment(node);
                    case 243 /* VariableStatement */:
                        return visitVariableStatement(node);
                    case 260 /* VariableDeclaration */:
                        return visitVariableDeclaration(node);
                    case 169 /* Parameter */:
                        return visitParameterDeclaration(node);
                    case 208 /* BindingElement */:
                        return visitBindingElement(node);
                    case 277 /* ExportAssignment */:
                        return visitExportAssignment(node);
                    case 81 /* PrivateIdentifier */:
                        return visitPrivateIdentifier(node);
                    case 211 /* PropertyAccessExpression */:
                        return visitPropertyAccessExpression(node);
                    case 212 /* ElementAccessExpression */:
                        return visitElementAccessExpression(node);
                    case 224 /* PrefixUnaryExpression */:
                    case 225 /* PostfixUnaryExpression */:
                        return visitPreOrPostfixUnaryExpression(node, 
                        /*discarded*/
                        false);
                    case 226 /* BinaryExpression */:
                        return visitBinaryExpression(node, 
                        /*discarded*/
                        false);
                    case 217 /* ParenthesizedExpression */:
                        return visitParenthesizedExpression(node, 
                        /*discarded*/
                        false);
                    case 213 /* CallExpression */:
                        return visitCallExpression(node);
                    case 244 /* ExpressionStatement */:
                        return visitExpressionStatement(node);
                    case 215 /* TaggedTemplateExpression */:
                        return visitTaggedTemplateExpression(node);
                    case 248 /* ForStatement */:
                        return visitForStatement(node);
                    case 110 /* ThisKeyword */:
                        return visitThisExpression(node);
                    case 262 /* FunctionDeclaration */:
                    case 218 /* FunctionExpression */:
                        return setCurrentClassElementAnd(
                        /*classElement*/
                        void 0, fallbackVisitor, node);
                    case 176 /* Constructor */:
                    case 174 /* MethodDeclaration */:
                    case 177 /* GetAccessor */:
                    case 178 /* SetAccessor */: {
                        return setCurrentClassElementAnd(node, fallbackVisitor, node);
                    }
                    default:
                        return fallbackVisitor(node);
                }
            }
            function fallbackVisitor(node) {
                return visitEachChild(node, visitor, context);
            }
            function discardedValueVisitor(node) {
                switch (node.kind) {
                    case 224 /* PrefixUnaryExpression */:
                    case 225 /* PostfixUnaryExpression */:
                        return visitPreOrPostfixUnaryExpression(node, 
                        /*discarded*/
                        true);
                    case 226 /* BinaryExpression */:
                        return visitBinaryExpression(node, 
                        /*discarded*/
                        true);
                    case 361 /* CommaListExpression */:
                        return visitCommaListExpression(node, 
                        /*discarded*/
                        true);
                    case 217 /* ParenthesizedExpression */:
                        return visitParenthesizedExpression(node, 
                        /*discarded*/
                        true);
                    default:
                        return visitor(node);
                }
            }
            function heritageClauseVisitor(node) {
                switch (node.kind) {
                    case 298 /* HeritageClause */:
                        return visitEachChild(node, heritageClauseVisitor, context);
                    case 233 /* ExpressionWithTypeArguments */:
                        return visitExpressionWithTypeArgumentsInHeritageClause(node);
                    default:
                        return visitor(node);
                }
            }
            function assignmentTargetVisitor(node) {
                switch (node.kind) {
                    case 210 /* ObjectLiteralExpression */:
                    case 209 /* ArrayLiteralExpression */:
                        return visitAssignmentPattern(node);
                    default:
                        return visitor(node);
                }
            }
            function classElementVisitor(node) {
                switch (node.kind) {
                    case 176 /* Constructor */:
                        return setCurrentClassElementAnd(node, visitConstructorDeclaration, node);
                    case 177 /* GetAccessor */:
                    case 178 /* SetAccessor */:
                    case 174 /* MethodDeclaration */:
                        return setCurrentClassElementAnd(node, visitMethodOrAccessorDeclaration, node);
                    case 172 /* PropertyDeclaration */:
                        return setCurrentClassElementAnd(node, visitPropertyDeclaration, node);
                    case 175 /* ClassStaticBlockDeclaration */:
                        return setCurrentClassElementAnd(node, visitClassStaticBlockDeclaration, node);
                    case 167 /* ComputedPropertyName */:
                        return visitComputedPropertyName(node);
                    case 240 /* SemicolonClassElement */:
                        return node;
                    default:
                        return isModifierLike(node) ? modifierVisitor(node) : visitor(node);
                }
            }
            function propertyNameVisitor(node) {
                switch (node.kind) {
                    case 167 /* ComputedPropertyName */:
                        return visitComputedPropertyName(node);
                    default:
                        return visitor(node);
                }
            }
            function accessorFieldResultVisitor(node) {
                switch (node.kind) {
                    case 172 /* PropertyDeclaration */:
                        return transformFieldInitializer(node);
                    case 177 /* GetAccessor */:
                    case 178 /* SetAccessor */:
                        return classElementVisitor(node);
                    default:
                        Debug.assertMissingNode(node, "Expected node to either be a PropertyDeclaration, GetAccessorDeclaration, or SetAccessorDeclaration");
                        break;
                }
            }
            function visitPrivateIdentifier(node) {
                if (!shouldTransformPrivateElementsOrClassStaticBlocks) {
                    return node;
                }
                if (isStatement(node.parent)) {
                    return node;
                }
                return setOriginalNode(factory2.createIdentifier(""), node);
            }
            function transformPrivateIdentifierInInExpression(node) {
                const info = accessPrivateIdentifier2(node.left);
                if (info) {
                    const receiver = visitNode(node.right, visitor, isExpression);
                    return setOriginalNode(emitHelpers().createClassPrivateFieldInHelper(info.brandCheckIdentifier, receiver), node);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitPropertyAssignment(node) {
                if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                    node = transformNamedEvaluation(context, node);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitVariableStatement(node) {
                const savedPendingStatements = pendingStatements;
                pendingStatements = [];
                const visitedNode = visitEachChild(node, visitor, context);
                const statement = some(pendingStatements) ? [visitedNode, ...pendingStatements] : visitedNode;
                pendingStatements = savedPendingStatements;
                return statement;
            }
            function visitVariableDeclaration(node) {
                if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                    node = transformNamedEvaluation(context, node);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitParameterDeclaration(node) {
                if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                    node = transformNamedEvaluation(context, node);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitBindingElement(node) {
                if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                    node = transformNamedEvaluation(context, node);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitExportAssignment(node) {
                if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                    node = transformNamedEvaluation(context, node, 
                    /*ignoreEmptyStringLiteral*/
                    true, node.isExportEquals ? "" : "default");
                }
                return visitEachChild(node, visitor, context);
            }
            function injectPendingExpressions(expression) {
                if (some(pendingExpressions)) {
                    if (isParenthesizedExpression(expression)) {
                        pendingExpressions.push(expression.expression);
                        expression = factory2.updateParenthesizedExpression(expression, factory2.inlineExpressions(pendingExpressions));
                    }
                    else {
                        pendingExpressions.push(expression);
                        expression = factory2.inlineExpressions(pendingExpressions);
                    }
                    pendingExpressions = void 0;
                }
                return expression;
            }
            function visitComputedPropertyName(node) {
                const expression = visitNode(node.expression, visitor, isExpression);
                return factory2.updateComputedPropertyName(node, injectPendingExpressions(expression));
            }
            function visitConstructorDeclaration(node) {
                if (currentClassContainer) {
                    return transformConstructor(node, currentClassContainer);
                }
                return fallbackVisitor(node);
            }
            function shouldTransformClassElementToWeakMap(node) {
                if (shouldTransformPrivateElementsOrClassStaticBlocks)
                    return true;
                if (hasStaticModifier(node) && getInternalEmitFlags(node) & 32 /* TransformPrivateStaticElements */)
                    return true;
                return false;
            }
            function visitMethodOrAccessorDeclaration(node) {
                Debug.assert(!hasDecorators(node));
                if (!isPrivateIdentifierClassElementDeclaration(node) || !shouldTransformClassElementToWeakMap(node)) {
                    return visitEachChild(node, classElementVisitor, context);
                }
                const info = accessPrivateIdentifier2(node.name);
                Debug.assert(info, "Undeclared private name for property declaration.");
                if (!info.isValid) {
                    return node;
                }
                const functionName = getHoistedFunctionName(node);
                if (functionName) {
                    getPendingExpressions().push(factory2.createAssignment(functionName, factory2.createFunctionExpression(filter(node.modifiers, (m) => isModifier(m) && !isStaticModifier(m) && !isAccessorModifier(m)), node.asteriskToken, functionName, 
                    /*typeParameters*/
                    void 0, visitParameterList(node.parameters, visitor, context), 
                    /*type*/
                    void 0, visitFunctionBody(node.body, visitor, context))));
                }
                return void 0;
            }
            function setCurrentClassElementAnd(classElement, visitor2, arg) {
                if (classElement !== currentClassElement) {
                    const savedCurrentClassElement = currentClassElement;
                    currentClassElement = classElement;
                    const result = visitor2(arg);
                    currentClassElement = savedCurrentClassElement;
                    return result;
                }
                return visitor2(arg);
            }
            function getHoistedFunctionName(node) {
                Debug.assert(isPrivateIdentifier(node.name));
                const info = accessPrivateIdentifier2(node.name);
                Debug.assert(info, "Undeclared private name for property declaration.");
                if (info.kind === "m" /* Method */) {
                    return info.methodName;
                }
                if (info.kind === "a" /* Accessor */) {
                    if (isGetAccessor(node)) {
                        return info.getterName;
                    }
                    if (isSetAccessor(node)) {
                        return info.setterName;
                    }
                }
            }
            function getClassThis() {
                const lex = getClassLexicalEnvironment();
                const classThis = lex.classThis ?? lex.classConstructor ?? (currentClassContainer == null ? void 0 : currentClassContainer.name);
                return Debug.checkDefined(classThis);
            }
            function transformAutoAccessor(node) {
                const commentRange = getCommentRange(node);
                const sourceMapRange = getSourceMapRange(node);
                const name = node.name;
                let getterName = name;
                let setterName = name;
                if (isComputedPropertyName(name) && !isSimpleInlineableExpression(name.expression)) {
                    const cacheAssignment = findComputedPropertyNameCacheAssignment(name);
                    if (cacheAssignment) {
                        getterName = factory2.updateComputedPropertyName(name, visitNode(name.expression, visitor, isExpression));
                        setterName = factory2.updateComputedPropertyName(name, cacheAssignment.left);
                    }
                    else {
                        const temp = factory2.createTempVariable(hoistVariableDeclaration);
                        setSourceMapRange(temp, name.expression);
                        const expression = visitNode(name.expression, visitor, isExpression);
                        const assignment = factory2.createAssignment(temp, expression);
                        setSourceMapRange(assignment, name.expression);
                        getterName = factory2.updateComputedPropertyName(name, assignment);
                        setterName = factory2.updateComputedPropertyName(name, temp);
                    }
                }
                const modifiers = visitNodes2(node.modifiers, modifierVisitor, isModifier);
                const backingField = createAccessorPropertyBackingField(factory2, node, modifiers, node.initializer);
                setOriginalNode(backingField, node);
                setEmitFlags(backingField, 3072 /* NoComments */);
                setSourceMapRange(backingField, sourceMapRange);
                const receiver = isStatic(node) ? getClassThis() : factory2.createThis();
                const getter = createAccessorPropertyGetRedirector(factory2, node, modifiers, getterName, receiver);
                setOriginalNode(getter, node);
                setCommentRange(getter, commentRange);
                setSourceMapRange(getter, sourceMapRange);
                const setterModifiers = factory2.createModifiersFromModifierFlags(modifiersToFlags(modifiers));
                const setter = createAccessorPropertySetRedirector(factory2, node, setterModifiers, setterName, receiver);
                setOriginalNode(setter, node);
                setEmitFlags(setter, 3072 /* NoComments */);
                setSourceMapRange(setter, sourceMapRange);
                return visitArray([backingField, getter, setter], accessorFieldResultVisitor, isClassElement);
            }
            function transformPrivateFieldInitializer(node) {
                if (shouldTransformClassElementToWeakMap(node)) {
                    const info = accessPrivateIdentifier2(node.name);
                    Debug.assert(info, "Undeclared private name for property declaration.");
                    if (!info.isValid) {
                        return node;
                    }
                    if (info.isStatic && !shouldTransformPrivateElementsOrClassStaticBlocks) {
                        const statement = transformPropertyOrClassStaticBlock(node, factory2.createThis());
                        if (statement) {
                            return factory2.createClassStaticBlockDeclaration(factory2.createBlock([statement], 
                            /*multiLine*/
                            true));
                        }
                    }
                    return void 0;
                }
                if (shouldTransformInitializersUsingSet && !isStatic(node) && (lexicalEnvironment == null ? void 0 : lexicalEnvironment.data) && lexicalEnvironment.data.facts & 16 /* WillHoistInitializersToConstructor */) {
                    return factory2.updatePropertyDeclaration(node, visitNodes2(node.modifiers, visitor, isModifierLike), node.name, 
                    /*questionOrExclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, 
                    /*initializer*/
                    void 0);
                }
                if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                    node = transformNamedEvaluation(context, node);
                }
                return factory2.updatePropertyDeclaration(node, visitNodes2(node.modifiers, modifierVisitor, isModifier), visitNode(node.name, propertyNameVisitor, isPropertyName), 
                /*questionOrExclamationToken*/
                void 0, 
                /*type*/
                void 0, visitNode(node.initializer, visitor, isExpression));
            }
            function transformPublicFieldInitializer(node) {
                if (shouldTransformInitializers && !isAutoAccessorPropertyDeclaration(node)) {
                    const expr = getPropertyNameExpressionIfNeeded(node.name, 
                    /*shouldHoist*/
                    !!node.initializer || useDefineForClassFields);
                    if (expr) {
                        getPendingExpressions().push(...flattenCommaList(expr));
                    }
                    if (isStatic(node) && !shouldTransformPrivateElementsOrClassStaticBlocks) {
                        const initializerStatement = transformPropertyOrClassStaticBlock(node, factory2.createThis());
                        if (initializerStatement) {
                            const staticBlock = factory2.createClassStaticBlockDeclaration(factory2.createBlock([initializerStatement]));
                            setOriginalNode(staticBlock, node);
                            setCommentRange(staticBlock, node);
                            setCommentRange(initializerStatement, { pos: -1, end: -1 });
                            setSyntheticLeadingComments(initializerStatement, void 0);
                            setSyntheticTrailingComments(initializerStatement, void 0);
                            return staticBlock;
                        }
                    }
                    return void 0;
                }
                return factory2.updatePropertyDeclaration(node, visitNodes2(node.modifiers, modifierVisitor, isModifier), visitNode(node.name, propertyNameVisitor, isPropertyName), 
                /*questionOrExclamationToken*/
                void 0, 
                /*type*/
                void 0, visitNode(node.initializer, visitor, isExpression));
            }
            function transformFieldInitializer(node) {
                Debug.assert(!hasDecorators(node), "Decorators should already have been transformed and elided.");
                return isPrivateIdentifierClassElementDeclaration(node) ? transformPrivateFieldInitializer(node) : transformPublicFieldInitializer(node);
            }
            function shouldTransformAutoAccessorsInCurrentClass() {
                return shouldTransformAutoAccessors === -1 /* True */ || shouldTransformAutoAccessors === 3 /* Maybe */ && !!(lexicalEnvironment == null ? void 0 : lexicalEnvironment.data) && !!(lexicalEnvironment.data.facts & 16 /* WillHoistInitializersToConstructor */);
            }
            function visitPropertyDeclaration(node) {
                if (isAutoAccessorPropertyDeclaration(node) && (shouldTransformAutoAccessorsInCurrentClass() || hasStaticModifier(node) && getInternalEmitFlags(node) & 32 /* TransformPrivateStaticElements */)) {
                    return transformAutoAccessor(node);
                }
                return transformFieldInitializer(node);
            }
            function shouldForceDynamicThis() {
                return !!currentClassElement && hasStaticModifier(currentClassElement) && isAccessor(currentClassElement) && isAutoAccessorPropertyDeclaration(getOriginalNode(currentClassElement));
            }
            function ensureDynamicThisIfNeeded(node) {
                if (shouldForceDynamicThis()) {
                    const innerExpression = skipOuterExpressions(node);
                    if (innerExpression.kind === 110 /* ThisKeyword */) {
                        noSubstitution.add(innerExpression);
                    }
                }
            }
            function createPrivateIdentifierAccess(info, receiver) {
                receiver = visitNode(receiver, visitor, isExpression);
                ensureDynamicThisIfNeeded(receiver);
                return createPrivateIdentifierAccessHelper(info, receiver);
            }
            function createPrivateIdentifierAccessHelper(info, receiver) {
                setCommentRange(receiver, moveRangePos(receiver, -1));
                switch (info.kind) {
                    case "a" /* Accessor */:
                        return emitHelpers().createClassPrivateFieldGetHelper(receiver, info.brandCheckIdentifier, info.kind, info.getterName);
                    case "m" /* Method */:
                        return emitHelpers().createClassPrivateFieldGetHelper(receiver, info.brandCheckIdentifier, info.kind, info.methodName);
                    case "f" /* Field */:
                        return emitHelpers().createClassPrivateFieldGetHelper(receiver, info.brandCheckIdentifier, info.kind, info.isStatic ? info.variableName : void 0);
                    case "untransformed":
                        return Debug.fail("Access helpers should not be created for untransformed private elements");
                    default:
                        Debug.assertNever(info, "Unknown private element type");
                }
            }
            function visitPropertyAccessExpression(node) {
                if (isPrivateIdentifier(node.name)) {
                    const privateIdentifierInfo = accessPrivateIdentifier2(node.name);
                    if (privateIdentifierInfo) {
                        return setTextRange(setOriginalNode(createPrivateIdentifierAccess(privateIdentifierInfo, node.expression), node), node);
                    }
                }
                if (shouldTransformSuperInStaticInitializers && currentClassElement && isSuperProperty(node) && isIdentifier(node.name) && isStaticPropertyDeclarationOrClassStaticBlock(currentClassElement) && (lexicalEnvironment == null ? void 0 : lexicalEnvironment.data)) {
                    const { classConstructor, superClassReference, facts } = lexicalEnvironment.data;
                    if (facts & 1 /* ClassWasDecorated */) {
                        return visitInvalidSuperProperty(node);
                    }
                    if (classConstructor && superClassReference) {
                        const superProperty = factory2.createReflectGetCall(superClassReference, factory2.createStringLiteralFromNode(node.name), classConstructor);
                        setOriginalNode(superProperty, node.expression);
                        setTextRange(superProperty, node.expression);
                        return superProperty;
                    }
                }
                return visitEachChild(node, visitor, context);
            }
            function visitElementAccessExpression(node) {
                if (shouldTransformSuperInStaticInitializers && currentClassElement && isSuperProperty(node) && isStaticPropertyDeclarationOrClassStaticBlock(currentClassElement) && (lexicalEnvironment == null ? void 0 : lexicalEnvironment.data)) {
                    const { classConstructor, superClassReference, facts } = lexicalEnvironment.data;
                    if (facts & 1 /* ClassWasDecorated */) {
                        return visitInvalidSuperProperty(node);
                    }
                    if (classConstructor && superClassReference) {
                        const superProperty = factory2.createReflectGetCall(superClassReference, visitNode(node.argumentExpression, visitor, isExpression), classConstructor);
                        setOriginalNode(superProperty, node.expression);
                        setTextRange(superProperty, node.expression);
                        return superProperty;
                    }
                }
                return visitEachChild(node, visitor, context);
            }
            function visitPreOrPostfixUnaryExpression(node, discarded) {
                if (node.operator === 46 /* PlusPlusToken */ || node.operator === 47 /* MinusMinusToken */) {
                    const operand = skipParentheses(node.operand);
                    if (isPrivateIdentifierPropertyAccessExpression(operand)) {
                        let info;
                        if (info = accessPrivateIdentifier2(operand.name)) {
                            const receiver = visitNode(operand.expression, visitor, isExpression);
                            ensureDynamicThisIfNeeded(receiver);
                            const { readExpression, initializeExpression } = createCopiableReceiverExpr(receiver);
                            let expression = createPrivateIdentifierAccess(info, readExpression);
                            const temp = isPrefixUnaryExpression(node) || discarded ? void 0 : factory2.createTempVariable(hoistVariableDeclaration);
                            expression = expandPreOrPostfixIncrementOrDecrementExpression(factory2, node, expression, hoistVariableDeclaration, temp);
                            expression = createPrivateIdentifierAssignment(info, initializeExpression || readExpression, expression, 64 /* EqualsToken */);
                            setOriginalNode(expression, node);
                            setTextRange(expression, node);
                            if (temp) {
                                expression = factory2.createComma(expression, temp);
                                setTextRange(expression, node);
                            }
                            return expression;
                        }
                    }
                    else if (shouldTransformSuperInStaticInitializers && currentClassElement && isSuperProperty(operand) && isStaticPropertyDeclarationOrClassStaticBlock(currentClassElement) && (lexicalEnvironment == null ? void 0 : lexicalEnvironment.data)) {
                        const { classConstructor, superClassReference, facts } = lexicalEnvironment.data;
                        if (facts & 1 /* ClassWasDecorated */) {
                            const expression = visitInvalidSuperProperty(operand);
                            return isPrefixUnaryExpression(node) ? factory2.updatePrefixUnaryExpression(node, expression) : factory2.updatePostfixUnaryExpression(node, expression);
                        }
                        if (classConstructor && superClassReference) {
                            let setterName;
                            let getterName;
                            if (isPropertyAccessExpression(operand)) {
                                if (isIdentifier(operand.name)) {
                                    getterName = setterName = factory2.createStringLiteralFromNode(operand.name);
                                }
                            }
                            else {
                                if (isSimpleInlineableExpression(operand.argumentExpression)) {
                                    getterName = setterName = operand.argumentExpression;
                                }
                                else {
                                    getterName = factory2.createTempVariable(hoistVariableDeclaration);
                                    setterName = factory2.createAssignment(getterName, visitNode(operand.argumentExpression, visitor, isExpression));
                                }
                            }
                            if (setterName && getterName) {
                                let expression = factory2.createReflectGetCall(superClassReference, getterName, classConstructor);
                                setTextRange(expression, operand);
                                const temp = discarded ? void 0 : factory2.createTempVariable(hoistVariableDeclaration);
                                expression = expandPreOrPostfixIncrementOrDecrementExpression(factory2, node, expression, hoistVariableDeclaration, temp);
                                expression = factory2.createReflectSetCall(superClassReference, setterName, expression, classConstructor);
                                setOriginalNode(expression, node);
                                setTextRange(expression, node);
                                if (temp) {
                                    expression = factory2.createComma(expression, temp);
                                    setTextRange(expression, node);
                                }
                                return expression;
                            }
                        }
                    }
                }
                return visitEachChild(node, visitor, context);
            }
            function visitForStatement(node) {
                return factory2.updateForStatement(node, visitNode(node.initializer, discardedValueVisitor, isForInitializer), visitNode(node.condition, visitor, isExpression), visitNode(node.incrementor, discardedValueVisitor, isExpression), visitIterationBody(node.statement, visitor, context));
            }
            function visitExpressionStatement(node) {
                return factory2.updateExpressionStatement(node, visitNode(node.expression, discardedValueVisitor, isExpression));
            }
            function createCopiableReceiverExpr(receiver) {
                const clone2 = nodeIsSynthesized(receiver) ? receiver : factory2.cloneNode(receiver);
                if (receiver.kind === 110 /* ThisKeyword */ && noSubstitution.has(receiver)) {
                    noSubstitution.add(clone2);
                }
                if (isSimpleInlineableExpression(receiver)) {
                    return { readExpression: clone2, initializeExpression: void 0 };
                }
                const readExpression = factory2.createTempVariable(hoistVariableDeclaration);
                const initializeExpression = factory2.createAssignment(readExpression, clone2);
                return { readExpression, initializeExpression };
            }
            function visitCallExpression(node) {
                var _a;
                if (isPrivateIdentifierPropertyAccessExpression(node.expression) && accessPrivateIdentifier2(node.expression.name)) {
                    const { thisArg, target } = factory2.createCallBinding(node.expression, hoistVariableDeclaration, languageVersion);
                    if (isCallChain(node)) {
                        return factory2.updateCallChain(node, factory2.createPropertyAccessChain(visitNode(target, visitor, isExpression), node.questionDotToken, "call"), 
                        /*questionDotToken*/
                        void 0, 
                        /*typeArguments*/
                        void 0, [visitNode(thisArg, visitor, isExpression), ...visitNodes2(node.arguments, visitor, isExpression)]);
                    }
                    return factory2.updateCallExpression(node, factory2.createPropertyAccessExpression(visitNode(target, visitor, isExpression), "call"), 
                    /*typeArguments*/
                    void 0, [visitNode(thisArg, visitor, isExpression), ...visitNodes2(node.arguments, visitor, isExpression)]);
                }
                if (shouldTransformSuperInStaticInitializers && currentClassElement && isSuperProperty(node.expression) && isStaticPropertyDeclarationOrClassStaticBlock(currentClassElement) && ((_a = lexicalEnvironment == null ? void 0 : lexicalEnvironment.data) == null ? void 0 : _a.classConstructor)) {
                    const invocation = factory2.createFunctionCallCall(visitNode(node.expression, visitor, isExpression), lexicalEnvironment.data.classConstructor, visitNodes2(node.arguments, visitor, isExpression));
                    setOriginalNode(invocation, node);
                    setTextRange(invocation, node);
                    return invocation;
                }
                return visitEachChild(node, visitor, context);
            }
            function visitTaggedTemplateExpression(node) {
                var _a;
                if (isPrivateIdentifierPropertyAccessExpression(node.tag) && accessPrivateIdentifier2(node.tag.name)) {
                    const { thisArg, target } = factory2.createCallBinding(node.tag, hoistVariableDeclaration, languageVersion);
                    return factory2.updateTaggedTemplateExpression(node, factory2.createCallExpression(factory2.createPropertyAccessExpression(visitNode(target, visitor, isExpression), "bind"), 
                    /*typeArguments*/
                    void 0, [visitNode(thisArg, visitor, isExpression)]), 
                    /*typeArguments*/
                    void 0, visitNode(node.template, visitor, isTemplateLiteral));
                }
                if (shouldTransformSuperInStaticInitializers && currentClassElement && isSuperProperty(node.tag) && isStaticPropertyDeclarationOrClassStaticBlock(currentClassElement) && ((_a = lexicalEnvironment == null ? void 0 : lexicalEnvironment.data) == null ? void 0 : _a.classConstructor)) {
                    const invocation = factory2.createFunctionBindCall(visitNode(node.tag, visitor, isExpression), lexicalEnvironment.data.classConstructor, []);
                    setOriginalNode(invocation, node);
                    setTextRange(invocation, node);
                    return factory2.updateTaggedTemplateExpression(node, invocation, 
                    /*typeArguments*/
                    void 0, visitNode(node.template, visitor, isTemplateLiteral));
                }
                return visitEachChild(node, visitor, context);
            }
            function transformClassStaticBlockDeclaration(node) {
                if (lexicalEnvironment) {
                    lexicalEnvironmentMap.set(getOriginalNode(node), lexicalEnvironment);
                }
                if (shouldTransformPrivateElementsOrClassStaticBlocks) {
                    if (isClassThisAssignmentBlock(node)) {
                        const result = visitNode(node.body.statements[0].expression, visitor, isExpression);
                        if (isAssignmentExpression(result, 
                        /*excludeCompoundAssignment*/
                        true) && result.left === result.right) {
                            return void 0;
                        }
                        return result;
                    }
                    if (isClassNamedEvaluationHelperBlock(node)) {
                        return visitNode(node.body.statements[0].expression, visitor, isExpression);
                    }
                    startLexicalEnvironment();
                    let statements = setCurrentClassElementAnd(node, (statements2) => visitNodes2(statements2, visitor, isStatement), node.body.statements);
                    statements = factory2.mergeLexicalEnvironment(statements, endLexicalEnvironment());
                    const iife = factory2.createImmediatelyInvokedArrowFunction(statements);
                    setOriginalNode(skipParentheses(iife.expression), node);
                    addEmitFlags(skipParentheses(iife.expression), 4 /* AdviseOnEmitNode */);
                    setOriginalNode(iife, node);
                    setTextRange(iife, node);
                    return iife;
                }
            }
            function isAnonymousClassNeedingAssignedName(node) {
                if (isClassExpression(node) && !node.name) {
                    const staticPropertiesOrClassStaticBlocks = getStaticPropertiesAndClassStaticBlock(node);
                    if (some(staticPropertiesOrClassStaticBlocks, isClassNamedEvaluationHelperBlock)) {
                        return false;
                    }
                    const hasTransformableStatics = (shouldTransformPrivateElementsOrClassStaticBlocks || !!(getInternalEmitFlags(node) && 32 /* TransformPrivateStaticElements */)) && some(staticPropertiesOrClassStaticBlocks, (node2) => isClassStaticBlockDeclaration(node2) || isPrivateIdentifierClassElementDeclaration(node2) || shouldTransformInitializers && isInitializedProperty(node2));
                    return hasTransformableStatics;
                }
                return false;
            }
            function visitBinaryExpression(node, discarded) {
                if (isDestructuringAssignment(node)) {
                    const savedPendingExpressions = pendingExpressions;
                    pendingExpressions = void 0;
                    node = factory2.updateBinaryExpression(node, visitNode(node.left, assignmentTargetVisitor, isExpression), node.operatorToken, visitNode(node.right, visitor, isExpression));
                    const expr = some(pendingExpressions) ? factory2.inlineExpressions(compact([...pendingExpressions, node])) : node;
                    pendingExpressions = savedPendingExpressions;
                    return expr;
                }
                if (isAssignmentExpression(node)) {
                    if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                        node = transformNamedEvaluation(context, node);
                        Debug.assertNode(node, isAssignmentExpression);
                    }
                    const left = skipOuterExpressions(node.left, 8 /* PartiallyEmittedExpressions */ | 1 /* Parentheses */);
                    if (isPrivateIdentifierPropertyAccessExpression(left)) {
                        const info = accessPrivateIdentifier2(left.name);
                        if (info) {
                            return setTextRange(setOriginalNode(createPrivateIdentifierAssignment(info, left.expression, node.right, node.operatorToken.kind), node), node);
                        }
                    }
                    else if (shouldTransformSuperInStaticInitializers && currentClassElement && isSuperProperty(node.left) && isStaticPropertyDeclarationOrClassStaticBlock(currentClassElement) && (lexicalEnvironment == null ? void 0 : lexicalEnvironment.data)) {
                        const { classConstructor, superClassReference, facts } = lexicalEnvironment.data;
                        if (facts & 1 /* ClassWasDecorated */) {
                            return factory2.updateBinaryExpression(node, visitInvalidSuperProperty(node.left), node.operatorToken, visitNode(node.right, visitor, isExpression));
                        }
                        if (classConstructor && superClassReference) {
                            let setterName = isElementAccessExpression(node.left) ? visitNode(node.left.argumentExpression, visitor, isExpression) : isIdentifier(node.left.name) ? factory2.createStringLiteralFromNode(node.left.name) : void 0;
                            if (setterName) {
                                let expression = visitNode(node.right, visitor, isExpression);
                                if (isCompoundAssignment(node.operatorToken.kind)) {
                                    let getterName = setterName;
                                    if (!isSimpleInlineableExpression(setterName)) {
                                        getterName = factory2.createTempVariable(hoistVariableDeclaration);
                                        setterName = factory2.createAssignment(getterName, setterName);
                                    }
                                    const superPropertyGet = factory2.createReflectGetCall(superClassReference, getterName, classConstructor);
                                    setOriginalNode(superPropertyGet, node.left);
                                    setTextRange(superPropertyGet, node.left);
                                    expression = factory2.createBinaryExpression(superPropertyGet, getNonAssignmentOperatorForCompoundAssignment(node.operatorToken.kind), expression);
                                    setTextRange(expression, node);
                                }
                                const temp = discarded ? void 0 : factory2.createTempVariable(hoistVariableDeclaration);
                                if (temp) {
                                    expression = factory2.createAssignment(temp, expression);
                                    setTextRange(temp, node);
                                }
                                expression = factory2.createReflectSetCall(superClassReference, setterName, expression, classConstructor);
                                setOriginalNode(expression, node);
                                setTextRange(expression, node);
                                if (temp) {
                                    expression = factory2.createComma(expression, temp);
                                    setTextRange(expression, node);
                                }
                                return expression;
                            }
                        }
                    }
                }
                if (isPrivateIdentifierInExpression(node)) {
                    return transformPrivateIdentifierInInExpression(node);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitCommaListExpression(node, discarded) {
                const elements = discarded ? visitCommaListElements(node.elements, discardedValueVisitor) : visitCommaListElements(node.elements, visitor, discardedValueVisitor);
                return factory2.updateCommaListExpression(node, elements);
            }
            function visitParenthesizedExpression(node, discarded) {
                const visitorFunc = discarded ? discardedValueVisitor : visitor;
                const expression = visitNode(node.expression, visitorFunc, isExpression);
                return factory2.updateParenthesizedExpression(node, expression);
            }
            function createPrivateIdentifierAssignment(info, receiver, right, operator) {
                receiver = visitNode(receiver, visitor, isExpression);
                right = visitNode(right, visitor, isExpression);
                ensureDynamicThisIfNeeded(receiver);
                if (isCompoundAssignment(operator)) {
                    const { readExpression, initializeExpression } = createCopiableReceiverExpr(receiver);
                    receiver = initializeExpression || readExpression;
                    right = factory2.createBinaryExpression(createPrivateIdentifierAccessHelper(info, readExpression), getNonAssignmentOperatorForCompoundAssignment(operator), right);
                }
                setCommentRange(receiver, moveRangePos(receiver, -1));
                switch (info.kind) {
                    case "a" /* Accessor */:
                        return emitHelpers().createClassPrivateFieldSetHelper(receiver, info.brandCheckIdentifier, right, info.kind, info.setterName);
                    case "m" /* Method */:
                        return emitHelpers().createClassPrivateFieldSetHelper(receiver, info.brandCheckIdentifier, right, info.kind, 
                        /*f*/
                        void 0);
                    case "f" /* Field */:
                        return emitHelpers().createClassPrivateFieldSetHelper(receiver, info.brandCheckIdentifier, right, info.kind, info.isStatic ? info.variableName : void 0);
                    case "untransformed":
                        return Debug.fail("Access helpers should not be created for untransformed private elements");
                    default:
                        Debug.assertNever(info, "Unknown private element type");
                }
            }
            function getPrivateInstanceMethodsAndAccessors(node) {
                return filter(node.members, isNonStaticMethodOrAccessorWithPrivateName);
            }
            function getClassFacts(node) {
                var _a;
                let facts = 0 /* None */;
                const original = getOriginalNode(node);
                if (isClassDeclaration(original) && classOrConstructorParameterIsDecorated(legacyDecorators, original)) {
                    facts |= 1 /* ClassWasDecorated */;
                }
                if (shouldTransformPrivateElementsOrClassStaticBlocks && (classHasClassThisAssignment(node) || classHasExplicitlyAssignedName(node))) {
                    facts |= 2 /* NeedsClassConstructorReference */;
                }
                let containsPublicInstanceFields = false;
                let containsInitializedPublicInstanceFields = false;
                let containsInstancePrivateElements = false;
                let containsInstanceAutoAccessors = false;
                for (const member of node.members) {
                    if (isStatic(member)) {
                        if (member.name && (isPrivateIdentifier(member.name) || isAutoAccessorPropertyDeclaration(member)) && shouldTransformPrivateElementsOrClassStaticBlocks) {
                            facts |= 2 /* NeedsClassConstructorReference */;
                        }
                        else if (isAutoAccessorPropertyDeclaration(member) && shouldTransformAutoAccessors === -1 /* True */ && !node.name && !((_a = node.emitNode) == null ? void 0 : _a.classThis)) {
                            facts |= 2 /* NeedsClassConstructorReference */;
                        }
                        if (isPropertyDeclaration(member) || isClassStaticBlockDeclaration(member)) {
                            if (shouldTransformThisInStaticInitializers && member.transformFlags & 16384 /* ContainsLexicalThis */) {
                                facts |= 8 /* NeedsSubstitutionForThisInClassStaticField */;
                                if (!(facts & 1 /* ClassWasDecorated */)) {
                                    facts |= 2 /* NeedsClassConstructorReference */;
                                }
                            }
                            if (shouldTransformSuperInStaticInitializers && member.transformFlags & 134217728 /* ContainsLexicalSuper */) {
                                if (!(facts & 1 /* ClassWasDecorated */)) {
                                    facts |= 2 /* NeedsClassConstructorReference */ | 4 /* NeedsClassSuperReference */;
                                }
                            }
                        }
                    }
                    else if (!hasAbstractModifier(getOriginalNode(member))) {
                        if (isAutoAccessorPropertyDeclaration(member)) {
                            containsInstanceAutoAccessors = true;
                            containsInstancePrivateElements || (containsInstancePrivateElements = isPrivateIdentifierClassElementDeclaration(member));
                        }
                        else if (isPrivateIdentifierClassElementDeclaration(member)) {
                            containsInstancePrivateElements = true;
                            if (resolver.getNodeCheckFlags(member) & 262144 /* ContainsConstructorReference */) {
                                facts |= 2 /* NeedsClassConstructorReference */;
                            }
                        }
                        else if (isPropertyDeclaration(member)) {
                            containsPublicInstanceFields = true;
                            containsInitializedPublicInstanceFields || (containsInitializedPublicInstanceFields = !!member.initializer);
                        }
                    }
                }
                const willHoistInitializersToConstructor = shouldTransformInitializersUsingDefine && containsPublicInstanceFields || shouldTransformInitializersUsingSet && containsInitializedPublicInstanceFields || shouldTransformPrivateElementsOrClassStaticBlocks && containsInstancePrivateElements || shouldTransformPrivateElementsOrClassStaticBlocks && containsInstanceAutoAccessors && shouldTransformAutoAccessors === -1 /* True */;
                if (willHoistInitializersToConstructor) {
                    facts |= 16 /* WillHoistInitializersToConstructor */;
                }
                return facts;
            }
            function visitExpressionWithTypeArgumentsInHeritageClause(node) {
                var _a;
                const facts = ((_a = lexicalEnvironment == null ? void 0 : lexicalEnvironment.data) == null ? void 0 : _a.facts) || 0 /* None */;
                if (facts & 4 /* NeedsClassSuperReference */) {
                    const temp = factory2.createTempVariable(hoistVariableDeclaration, 
                    /*reservedInNestedScopes*/
                    true);
                    getClassLexicalEnvironment().superClassReference = temp;
                    return factory2.updateExpressionWithTypeArguments(node, factory2.createAssignment(temp, visitNode(node.expression, visitor, isExpression)), 
                    /*typeArguments*/
                    void 0);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitInNewClassLexicalEnvironment(node, visitor2) {
                var _a;
                const savedCurrentClassContainer = currentClassContainer;
                const savedPendingExpressions = pendingExpressions;
                const savedLexicalEnvironment = lexicalEnvironment;
                currentClassContainer = node;
                pendingExpressions = void 0;
                startClassLexicalEnvironment();
                const shouldAlwaysTransformPrivateStaticElements = getInternalEmitFlags(node) & 32 /* TransformPrivateStaticElements */;
                if (shouldTransformPrivateElementsOrClassStaticBlocks || shouldAlwaysTransformPrivateStaticElements) {
                    const name = getNameOfDeclaration(node);
                    if (name && isIdentifier(name)) {
                        getPrivateIdentifierEnvironment().data.className = name;
                    }
                    else if ((_a = node.emitNode) == null ? void 0 : _a.assignedName) {
                        if (isStringLiteral(node.emitNode.assignedName)) {
                            if (node.emitNode.assignedName.textSourceNode && isIdentifier(node.emitNode.assignedName.textSourceNode)) {
                                getPrivateIdentifierEnvironment().data.className = node.emitNode.assignedName.textSourceNode;
                            }
                            else if (isIdentifierText(node.emitNode.assignedName.text, languageVersion)) {
                                const prefixName = factory2.createIdentifier(node.emitNode.assignedName.text);
                                getPrivateIdentifierEnvironment().data.className = prefixName;
                            }
                        }
                    }
                }
                if (shouldTransformPrivateElementsOrClassStaticBlocks) {
                    const privateInstanceMethodsAndAccessors = getPrivateInstanceMethodsAndAccessors(node);
                    if (some(privateInstanceMethodsAndAccessors)) {
                        getPrivateIdentifierEnvironment().data.weakSetName = createHoistedVariableForClass("instances", privateInstanceMethodsAndAccessors[0].name);
                    }
                }
                const facts = getClassFacts(node);
                if (facts) {
                    getClassLexicalEnvironment().facts = facts;
                }
                if (facts & 8 /* NeedsSubstitutionForThisInClassStaticField */) {
                    enableSubstitutionForClassStaticThisOrSuperReference();
                }
                const result = visitor2(node, facts);
                endClassLexicalEnvironment();
                Debug.assert(lexicalEnvironment === savedLexicalEnvironment);
                currentClassContainer = savedCurrentClassContainer;
                pendingExpressions = savedPendingExpressions;
                return result;
            }
            function visitClassDeclaration(node) {
                return visitInNewClassLexicalEnvironment(node, visitClassDeclarationInNewClassLexicalEnvironment);
            }
            function visitClassDeclarationInNewClassLexicalEnvironment(node, facts) {
                var _a, _b;
                let pendingClassReferenceAssignment;
                if (facts & 2 /* NeedsClassConstructorReference */) {
                    if (shouldTransformPrivateElementsOrClassStaticBlocks && ((_a = node.emitNode) == null ? void 0 : _a.classThis)) {
                        getClassLexicalEnvironment().classConstructor = node.emitNode.classThis;
                        pendingClassReferenceAssignment = factory2.createAssignment(node.emitNode.classThis, factory2.getInternalName(node));
                    }
                    else {
                        const temp = factory2.createTempVariable(hoistVariableDeclaration, 
                        /*reservedInNestedScopes*/
                        true);
                        getClassLexicalEnvironment().classConstructor = factory2.cloneNode(temp);
                        pendingClassReferenceAssignment = factory2.createAssignment(temp, factory2.getInternalName(node));
                    }
                }
                if ((_b = node.emitNode) == null ? void 0 : _b.classThis) {
                    getClassLexicalEnvironment().classThis = node.emitNode.classThis;
                }
                const isClassWithConstructorReference = resolver.getNodeCheckFlags(node) & 262144 /* ContainsConstructorReference */;
                const isExport = hasSyntacticModifier(node, 32 /* Export */);
                const isDefault = hasSyntacticModifier(node, 2048 /* Default */);
                let modifiers = visitNodes2(node.modifiers, modifierVisitor, isModifier);
                const heritageClauses = visitNodes2(node.heritageClauses, heritageClauseVisitor, isHeritageClause);
                const { members, prologue } = transformClassMembers(node);
                const statements = [];
                if (pendingClassReferenceAssignment) {
                    getPendingExpressions().unshift(pendingClassReferenceAssignment);
                }
                if (some(pendingExpressions)) {
                    statements.push(factory2.createExpressionStatement(factory2.inlineExpressions(pendingExpressions)));
                }
                if (shouldTransformInitializersUsingSet || shouldTransformPrivateElementsOrClassStaticBlocks || getInternalEmitFlags(node) & 32 /* TransformPrivateStaticElements */) {
                    const staticProperties = getStaticPropertiesAndClassStaticBlock(node);
                    if (some(staticProperties)) {
                        addPropertyOrClassStaticBlockStatements(statements, staticProperties, factory2.getInternalName(node));
                    }
                }
                if (statements.length > 0 && isExport && isDefault) {
                    modifiers = visitNodes2(modifiers, (node2) => isExportOrDefaultModifier(node2) ? void 0 : node2, isModifier);
                    statements.push(factory2.createExportAssignment(
                    /*modifiers*/
                    void 0, 
                    /*isExportEquals*/
                    false, factory2.getLocalName(node, 
                    /*allowComments*/
                    false, 
                    /*allowSourceMaps*/
                    true)));
                }
                const alias = getClassLexicalEnvironment().classConstructor;
                if (isClassWithConstructorReference && alias) {
                    enableSubstitutionForClassAliases();
                    classAliases[getOriginalNodeId(node)] = alias;
                }
                const classDecl = factory2.updateClassDeclaration(node, modifiers, node.name, 
                /*typeParameters*/
                void 0, heritageClauses, members);
                statements.unshift(classDecl);
                if (prologue) {
                    statements.unshift(factory2.createExpressionStatement(prologue));
                }
                return statements;
            }
            function visitClassExpression(node) {
                return visitInNewClassLexicalEnvironment(node, visitClassExpressionInNewClassLexicalEnvironment);
            }
            function visitClassExpressionInNewClassLexicalEnvironment(node, facts) {
                var _a, _b, _c;
                const isDecoratedClassDeclaration = !!(facts & 1 /* ClassWasDecorated */);
                const staticPropertiesOrClassStaticBlocks = getStaticPropertiesAndClassStaticBlock(node);
                const classCheckFlags = resolver.getNodeCheckFlags(node);
                const isClassWithConstructorReference = classCheckFlags & 262144 /* ContainsConstructorReference */;
                let temp;
                function createClassTempVar() {
                    var _a2;
                    if (shouldTransformPrivateElementsOrClassStaticBlocks && ((_a2 = node.emitNode) == null ? void 0 : _a2.classThis)) {
                        return getClassLexicalEnvironment().classConstructor = node.emitNode.classThis;
                    }
                    const requiresBlockScopedVar = classCheckFlags & 32768 /* BlockScopedBindingInLoop */;
                    const temp2 = factory2.createTempVariable(requiresBlockScopedVar ? addBlockScopedVariable : hoistVariableDeclaration, 
                    /*reservedInNestedScopes*/
                    true);
                    getClassLexicalEnvironment().classConstructor = factory2.cloneNode(temp2);
                    return temp2;
                }
                if ((_a = node.emitNode) == null ? void 0 : _a.classThis) {
                    getClassLexicalEnvironment().classThis = node.emitNode.classThis;
                }
                if (facts & 2 /* NeedsClassConstructorReference */) {
                    temp ?? (temp = createClassTempVar());
                }
                const modifiers = visitNodes2(node.modifiers, modifierVisitor, isModifier);
                const heritageClauses = visitNodes2(node.heritageClauses, heritageClauseVisitor, isHeritageClause);
                const { members, prologue } = transformClassMembers(node);
                const classExpression = factory2.updateClassExpression(node, modifiers, node.name, 
                /*typeParameters*/
                void 0, heritageClauses, members);
                const expressions = [];
                if (prologue) {
                    expressions.push(prologue);
                }
                const hasTransformableStatics = (shouldTransformPrivateElementsOrClassStaticBlocks || getInternalEmitFlags(node) & 32 /* TransformPrivateStaticElements */) && some(staticPropertiesOrClassStaticBlocks, (node2) => isClassStaticBlockDeclaration(node2) || isPrivateIdentifierClassElementDeclaration(node2) || shouldTransformInitializers && isInitializedProperty(node2));
                if (hasTransformableStatics || some(pendingExpressions)) {
                    if (isDecoratedClassDeclaration) {
                        Debug.assertIsDefined(pendingStatements, "Decorated classes transformed by TypeScript are expected to be within a variable declaration.");
                        if (some(pendingExpressions)) {
                            addRange(pendingStatements, map(pendingExpressions, factory2.createExpressionStatement));
                        }
                        if (some(staticPropertiesOrClassStaticBlocks)) {
                            addPropertyOrClassStaticBlockStatements(pendingStatements, staticPropertiesOrClassStaticBlocks, ((_b = node.emitNode) == null ? void 0 : _b.classThis) ?? factory2.getInternalName(node));
                        }
                        if (temp) {
                            expressions.push(factory2.createAssignment(temp, classExpression));
                        }
                        else if (shouldTransformPrivateElementsOrClassStaticBlocks && ((_c = node.emitNode) == null ? void 0 : _c.classThis)) {
                            expressions.push(factory2.createAssignment(node.emitNode.classThis, classExpression));
                        }
                        else {
                            expressions.push(classExpression);
                        }
                    }
                    else {
                        temp ?? (temp = createClassTempVar());
                        if (isClassWithConstructorReference) {
                            enableSubstitutionForClassAliases();
                            const alias = factory2.cloneNode(temp);
                            alias.emitNode.autoGenerate.flags &= ~8 /* ReservedInNestedScopes */;
                            classAliases[getOriginalNodeId(node)] = alias;
                        }
                        expressions.push(factory2.createAssignment(temp, classExpression));
                        addRange(expressions, pendingExpressions);
                        addRange(expressions, generateInitializedPropertyExpressionsOrClassStaticBlock(staticPropertiesOrClassStaticBlocks, temp));
                        expressions.push(factory2.cloneNode(temp));
                    }
                }
                else {
                    expressions.push(classExpression);
                }
                if (expressions.length > 1) {
                    addEmitFlags(classExpression, 131072 /* Indented */);
                    expressions.forEach(startOnNewLine);
                }
                return factory2.inlineExpressions(expressions);
            }
            function visitClassStaticBlockDeclaration(node) {
                if (!shouldTransformPrivateElementsOrClassStaticBlocks) {
                    return visitEachChild(node, visitor, context);
                }
                return void 0;
            }
            function visitThisExpression(node) {
                if (shouldTransformThisInStaticInitializers && currentClassElement && isClassStaticBlockDeclaration(currentClassElement) && (lexicalEnvironment == null ? void 0 : lexicalEnvironment.data)) {
                    const { classThis, classConstructor } = lexicalEnvironment.data;
                    return classThis ?? classConstructor ?? node;
                }
                return node;
            }
            function transformClassMembers(node) {
                const shouldTransformPrivateStaticElementsInClass = !!(getInternalEmitFlags(node) & 32 /* TransformPrivateStaticElements */);
                if (shouldTransformPrivateElementsOrClassStaticBlocks || shouldTransformPrivateStaticElementsInFile) {
                    for (const member of node.members) {
                        if (isPrivateIdentifierClassElementDeclaration(member)) {
                            if (shouldTransformClassElementToWeakMap(member)) {
                                addPrivateIdentifierToEnvironment(member, member.name, addPrivateIdentifierClassElementToEnvironment);
                            }
                            else {
                                const privateEnv = getPrivateIdentifierEnvironment();
                                setPrivateIdentifier(privateEnv, member.name, { kind: "untransformed" });
                            }
                        }
                    }
                    if (shouldTransformPrivateElementsOrClassStaticBlocks) {
                        if (some(getPrivateInstanceMethodsAndAccessors(node))) {
                            createBrandCheckWeakSetForPrivateMethods();
                        }
                    }
                    if (shouldTransformAutoAccessorsInCurrentClass()) {
                        for (const member of node.members) {
                            if (isAutoAccessorPropertyDeclaration(member)) {
                                const storageName = factory2.getGeneratedPrivateNameForNode(member.name, 
                                /*prefix*/
                                void 0, "_accessor_storage");
                                if (shouldTransformPrivateElementsOrClassStaticBlocks || shouldTransformPrivateStaticElementsInClass && hasStaticModifier(member)) {
                                    addPrivateIdentifierToEnvironment(member, storageName, addPrivateIdentifierPropertyDeclarationToEnvironment);
                                }
                                else {
                                    const privateEnv = getPrivateIdentifierEnvironment();
                                    setPrivateIdentifier(privateEnv, storageName, { kind: "untransformed" });
                                }
                            }
                        }
                    }
                }
                let members = visitNodes2(node.members, classElementVisitor, isClassElement);
                let syntheticConstructor;
                if (!some(members, isConstructorDeclaration)) {
                    syntheticConstructor = transformConstructor(
                    /*constructor*/
                    void 0, node);
                }
                let prologue;
                let syntheticStaticBlock;
                if (!shouldTransformPrivateElementsOrClassStaticBlocks && some(pendingExpressions)) {
                    let statement = factory2.createExpressionStatement(factory2.inlineExpressions(pendingExpressions));
                    if (statement.transformFlags & 134234112 /* ContainsLexicalThisOrSuper */) {
                        const temp = factory2.createTempVariable(hoistVariableDeclaration);
                        const arrow = factory2.createArrowFunction(
                        /*modifiers*/
                        void 0, 
                        /*typeParameters*/
                        void 0, 
                        /*parameters*/
                        [], 
                        /*type*/
                        void 0, 
                        /*equalsGreaterThanToken*/
                        void 0, factory2.createBlock([statement]));
                        prologue = factory2.createAssignment(temp, arrow);
                        statement = factory2.createExpressionStatement(factory2.createCallExpression(temp, 
                        /*typeArguments*/
                        void 0, []));
                    }
                    const block = factory2.createBlock([statement]);
                    syntheticStaticBlock = factory2.createClassStaticBlockDeclaration(block);
                    pendingExpressions = void 0;
                }
                if (syntheticConstructor || syntheticStaticBlock) {
                    let membersArray;
                    const classThisAssignmentBlock = find(members, isClassThisAssignmentBlock);
                    const classNamedEvaluationHelperBlock = find(members, isClassNamedEvaluationHelperBlock);
                    membersArray = append(membersArray, classThisAssignmentBlock);
                    membersArray = append(membersArray, classNamedEvaluationHelperBlock);
                    membersArray = append(membersArray, syntheticConstructor);
                    membersArray = append(membersArray, syntheticStaticBlock);
                    const remainingMembers = classThisAssignmentBlock || classNamedEvaluationHelperBlock ? filter(members, (member) => member !== classThisAssignmentBlock && member !== classNamedEvaluationHelperBlock) : members;
                    membersArray = addRange(membersArray, remainingMembers);
                    members = setTextRange(factory2.createNodeArray(membersArray), 
                    /*location*/
                    node.members);
                }
                return { members, prologue };
            }
            function createBrandCheckWeakSetForPrivateMethods() {
                const { weakSetName } = getPrivateIdentifierEnvironment().data;
                Debug.assert(weakSetName, "weakSetName should be set in private identifier environment");
                getPendingExpressions().push(factory2.createAssignment(weakSetName, factory2.createNewExpression(factory2.createIdentifier("WeakSet"), 
                /*typeArguments*/
                void 0, [])));
            }
            function transformConstructor(constructor, container) {
                constructor = visitNode(constructor, visitor, isConstructorDeclaration);
                if (!(lexicalEnvironment == null ? void 0 : lexicalEnvironment.data) || !(lexicalEnvironment.data.facts & 16 /* WillHoistInitializersToConstructor */)) {
                    return constructor;
                }
                const extendsClauseElement = getEffectiveBaseTypeNode(container);
                const isDerivedClass = !!(extendsClauseElement && skipOuterExpressions(extendsClauseElement.expression).kind !== 106 /* NullKeyword */);
                const parameters = visitParameterList(constructor ? constructor.parameters : void 0, visitor, context);
                const body = transformConstructorBody(container, constructor, isDerivedClass);
                if (!body) {
                    return constructor;
                }
                if (constructor) {
                    Debug.assert(parameters);
                    return factory2.updateConstructorDeclaration(constructor, 
                    /*modifiers*/
                    void 0, parameters, body);
                }
                return startOnNewLine(setOriginalNode(setTextRange(factory2.createConstructorDeclaration(
                /*modifiers*/
                void 0, parameters ?? [], body), constructor || container), constructor));
            }
            function transformConstructorBodyWorker(statementsOut, statementsIn, statementOffset, superPath, superPathDepth, initializerStatements, constructor) {
                const superStatementIndex = superPath[superPathDepth];
                const superStatement = statementsIn[superStatementIndex];
                addRange(statementsOut, visitNodes2(statementsIn, visitor, isStatement, statementOffset, superStatementIndex - statementOffset));
                statementOffset = superStatementIndex + 1;
                if (isTryStatement(superStatement)) {
                    const tryBlockStatements = [];
                    transformConstructorBodyWorker(tryBlockStatements, superStatement.tryBlock.statements, 
                    /*statementOffset*/
                    0, superPath, superPathDepth + 1, initializerStatements, constructor);
                    const tryBlockStatementsArray = factory2.createNodeArray(tryBlockStatements);
                    setTextRange(tryBlockStatementsArray, superStatement.tryBlock.statements);
                    statementsOut.push(factory2.updateTryStatement(superStatement, factory2.updateBlock(superStatement.tryBlock, tryBlockStatements), visitNode(superStatement.catchClause, visitor, isCatchClause), visitNode(superStatement.finallyBlock, visitor, isBlock)));
                }
                else {
                    addRange(statementsOut, visitNodes2(statementsIn, visitor, isStatement, superStatementIndex, 1));
                    while (statementOffset < statementsIn.length) {
                        const statement = statementsIn[statementOffset];
                        if (isParameterPropertyDeclaration(getOriginalNode(statement), constructor)) {
                            statementOffset++;
                        }
                        else {
                            break;
                        }
                    }
                    addRange(statementsOut, initializerStatements);
                }
                addRange(statementsOut, visitNodes2(statementsIn, visitor, isStatement, statementOffset));
            }
            function transformConstructorBody(node, constructor, isDerivedClass) {
                const instanceProperties = getProperties(node, 
                /*requireInitializer*/
                false, 
                /*isStatic*/
                false);
                let properties = instanceProperties;
                if (!useDefineForClassFields) {
                    properties = filter(properties, (property) => !!property.initializer || isPrivateIdentifier(property.name) || hasAccessorModifier(property));
                }
                const privateMethodsAndAccessors = getPrivateInstanceMethodsAndAccessors(node);
                const needsConstructorBody = some(properties) || some(privateMethodsAndAccessors);
                if (!constructor && !needsConstructorBody) {
                    return visitFunctionBody(
                    /*node*/
                    void 0, visitor, context);
                }
                resumeLexicalEnvironment();
                const needsSyntheticConstructor = !constructor && isDerivedClass;
                let statementOffset = 0;
                let statements = [];
                const initializerStatements = [];
                const receiver = factory2.createThis();
                addInstanceMethodStatements(initializerStatements, privateMethodsAndAccessors, receiver);
                if (constructor) {
                    const parameterProperties = filter(instanceProperties, (prop) => isParameterPropertyDeclaration(getOriginalNode(prop), constructor));
                    const nonParameterProperties = filter(properties, (prop) => !isParameterPropertyDeclaration(getOriginalNode(prop), constructor));
                    addPropertyOrClassStaticBlockStatements(initializerStatements, parameterProperties, receiver);
                    addPropertyOrClassStaticBlockStatements(initializerStatements, nonParameterProperties, receiver);
                }
                else {
                    addPropertyOrClassStaticBlockStatements(initializerStatements, properties, receiver);
                }
                if (constructor == null ? void 0 : constructor.body) {
                    statementOffset = factory2.copyPrologue(constructor.body.statements, statements, 
                    /*ensureUseStrict*/
                    false, visitor);
                    const superStatementIndices = findSuperStatementIndexPath(constructor.body.statements, statementOffset);
                    if (superStatementIndices.length) {
                        transformConstructorBodyWorker(statements, constructor.body.statements, statementOffset, superStatementIndices, 
                        /*superPathDepth*/
                        0, initializerStatements, constructor);
                    }
                    else {
                        while (statementOffset < constructor.body.statements.length) {
                            const statement = constructor.body.statements[statementOffset];
                            if (isParameterPropertyDeclaration(getOriginalNode(statement), constructor)) {
                                statementOffset++;
                            }
                            else {
                                break;
                            }
                        }
                        addRange(statements, initializerStatements);
                        addRange(statements, visitNodes2(constructor.body.statements, visitor, isStatement, statementOffset));
                    }
                }
                else {
                    if (needsSyntheticConstructor) {
                        statements.push(factory2.createExpressionStatement(factory2.createCallExpression(factory2.createSuper(), 
                        /*typeArguments*/
                        void 0, [factory2.createSpreadElement(factory2.createIdentifier("arguments"))])));
                    }
                    addRange(statements, initializerStatements);
                }
                statements = factory2.mergeLexicalEnvironment(statements, endLexicalEnvironment());
                if (statements.length === 0 && !constructor) {
                    return void 0;
                }
                const multiLine = (constructor == null ? void 0 : constructor.body) && constructor.body.statements.length >= statements.length ? constructor.body.multiLine ?? statements.length > 0 : statements.length > 0;
                return setTextRange(factory2.createBlock(setTextRange(factory2.createNodeArray(statements), 
                /*location*/
                constructor ? constructor.body.statements : node.members), multiLine), 
                /*location*/
                constructor ? constructor.body : void 0);
            }
            function addPropertyOrClassStaticBlockStatements(statements, properties, receiver) {
                for (const property of properties) {
                    if (isStatic(property) && !shouldTransformPrivateElementsOrClassStaticBlocks) {
                        continue;
                    }
                    const statement = transformPropertyOrClassStaticBlock(property, receiver);
                    if (!statement) {
                        continue;
                    }
                    statements.push(statement);
                }
            }
            function transformPropertyOrClassStaticBlock(property, receiver) {
                const expression = isClassStaticBlockDeclaration(property) ? setCurrentClassElementAnd(property, transformClassStaticBlockDeclaration, property) : transformProperty(property, receiver);
                if (!expression) {
                    return void 0;
                }
                const statement = factory2.createExpressionStatement(expression);
                setOriginalNode(statement, property);
                addEmitFlags(statement, getEmitFlags(property) & 3072 /* NoComments */);
                setCommentRange(statement, property);
                const propertyOriginalNode = getOriginalNode(property);
                if (isParameter(propertyOriginalNode)) {
                    setSourceMapRange(statement, propertyOriginalNode);
                    removeAllComments(statement);
                }
                else {
                    setSourceMapRange(statement, moveRangePastModifiers(property));
                }
                setSyntheticLeadingComments(expression, void 0);
                setSyntheticTrailingComments(expression, void 0);
                if (hasAccessorModifier(propertyOriginalNode)) {
                    addEmitFlags(statement, 3072 /* NoComments */);
                }
                return statement;
            }
            function generateInitializedPropertyExpressionsOrClassStaticBlock(propertiesOrClassStaticBlocks, receiver) {
                const expressions = [];
                for (const property of propertiesOrClassStaticBlocks) {
                    const expression = isClassStaticBlockDeclaration(property) ? setCurrentClassElementAnd(property, transformClassStaticBlockDeclaration, property) : setCurrentClassElementAnd(property, () => transformProperty(property, receiver), 
                    /*arg*/
                    void 0);
                    if (!expression) {
                        continue;
                    }
                    startOnNewLine(expression);
                    setOriginalNode(expression, property);
                    addEmitFlags(expression, getEmitFlags(property) & 3072 /* NoComments */);
                    setSourceMapRange(expression, moveRangePastModifiers(property));
                    setCommentRange(expression, property);
                    expressions.push(expression);
                }
                return expressions;
            }
            function transformProperty(property, receiver) {
                var _a;
                const savedCurrentClassElement = currentClassElement;
                const transformed = transformPropertyWorker(property, receiver);
                if (transformed && hasStaticModifier(property) && ((_a = lexicalEnvironment == null ? void 0 : lexicalEnvironment.data) == null ? void 0 : _a.facts)) {
                    setOriginalNode(transformed, property);
                    addEmitFlags(transformed, 4 /* AdviseOnEmitNode */);
                    setSourceMapRange(transformed, getSourceMapRange(property.name));
                    lexicalEnvironmentMap.set(getOriginalNode(property), lexicalEnvironment);
                }
                currentClassElement = savedCurrentClassElement;
                return transformed;
            }
            function transformPropertyWorker(property, receiver) {
                const emitAssignment = !useDefineForClassFields;
                if (isNamedEvaluation(property, isAnonymousClassNeedingAssignedName)) {
                    property = transformNamedEvaluation(context, property);
                }
                const propertyName = hasAccessorModifier(property) ? factory2.getGeneratedPrivateNameForNode(property.name) : isComputedPropertyName(property.name) && !isSimpleInlineableExpression(property.name.expression) ? factory2.updateComputedPropertyName(property.name, factory2.getGeneratedNameForNode(property.name)) : property.name;
                if (hasStaticModifier(property)) {
                    currentClassElement = property;
                }
                if (isPrivateIdentifier(propertyName) && shouldTransformClassElementToWeakMap(property)) {
                    const privateIdentifierInfo = accessPrivateIdentifier2(propertyName);
                    if (privateIdentifierInfo) {
                        if (privateIdentifierInfo.kind === "f" /* Field */) {
                            if (!privateIdentifierInfo.isStatic) {
                                return createPrivateInstanceFieldInitializer(factory2, receiver, visitNode(property.initializer, visitor, isExpression), privateIdentifierInfo.brandCheckIdentifier);
                            }
                            else {
                                return createPrivateStaticFieldInitializer(factory2, privateIdentifierInfo.variableName, visitNode(property.initializer, visitor, isExpression));
                            }
                        }
                        else {
                            return void 0;
                        }
                    }
                    else {
                        Debug.fail("Undeclared private name for property declaration.");
                    }
                }
                if ((isPrivateIdentifier(propertyName) || hasStaticModifier(property)) && !property.initializer) {
                    return void 0;
                }
                const propertyOriginalNode = getOriginalNode(property);
                if (hasSyntacticModifier(propertyOriginalNode, 64 /* Abstract */)) {
                    return void 0;
                }
                let initializer = visitNode(property.initializer, visitor, isExpression);
                if (isParameterPropertyDeclaration(propertyOriginalNode, propertyOriginalNode.parent) && isIdentifier(propertyName)) {
                    const localName = factory2.cloneNode(propertyName);
                    if (initializer) {
                        if (isParenthesizedExpression(initializer) && isCommaExpression(initializer.expression) && isCallToHelper(initializer.expression.left, "___runInitializers") && isVoidExpression(initializer.expression.right) && isNumericLiteral(initializer.expression.right.expression)) {
                            initializer = initializer.expression.left;
                        }
                        initializer = factory2.inlineExpressions([initializer, localName]);
                    }
                    else {
                        initializer = localName;
                    }
                    setEmitFlags(propertyName, 3072 /* NoComments */ | 96 /* NoSourceMap */);
                    setSourceMapRange(localName, propertyOriginalNode.name);
                    setEmitFlags(localName, 3072 /* NoComments */);
                }
                else {
                    initializer ?? (initializer = factory2.createVoidZero());
                }
                if (emitAssignment || isPrivateIdentifier(propertyName)) {
                    const memberAccess = createMemberAccessForPropertyName(factory2, receiver, propertyName, 
                    /*location*/
                    propertyName);
                    addEmitFlags(memberAccess, 1024 /* NoLeadingComments */);
                    const expression = factory2.createAssignment(memberAccess, initializer);
                    return expression;
                }
                else {
                    const name = isComputedPropertyName(propertyName) ? propertyName.expression : isIdentifier(propertyName) ? factory2.createStringLiteral(unescapeLeadingUnderscores(propertyName.escapedText)) : propertyName;
                    const descriptor = factory2.createPropertyDescriptor({ value: initializer, configurable: true, writable: true, enumerable: true });
                    return factory2.createObjectDefinePropertyCall(receiver, name, descriptor);
                }
            }
            function enableSubstitutionForClassAliases() {
                if ((enabledSubstitutions & 1 /* ClassAliases */) === 0) {
                    enabledSubstitutions |= 1 /* ClassAliases */;
                    context.enableSubstitution(80 /* Identifier */);
                    classAliases = [];
                }
            }
            function enableSubstitutionForClassStaticThisOrSuperReference() {
                if ((enabledSubstitutions & 2 /* ClassStaticThisOrSuperReference */) === 0) {
                    enabledSubstitutions |= 2 /* ClassStaticThisOrSuperReference */;
                    context.enableSubstitution(110 /* ThisKeyword */);
                    context.enableEmitNotification(262 /* FunctionDeclaration */);
                    context.enableEmitNotification(218 /* FunctionExpression */);
                    context.enableEmitNotification(176 /* Constructor */);
                    context.enableEmitNotification(177 /* GetAccessor */);
                    context.enableEmitNotification(178 /* SetAccessor */);
                    context.enableEmitNotification(174 /* MethodDeclaration */);
                    context.enableEmitNotification(172 /* PropertyDeclaration */);
                    context.enableEmitNotification(167 /* ComputedPropertyName */);
                }
            }
            function addInstanceMethodStatements(statements, methods, receiver) {
                if (!shouldTransformPrivateElementsOrClassStaticBlocks || !some(methods)) {
                    return;
                }
                const { weakSetName } = getPrivateIdentifierEnvironment().data;
                Debug.assert(weakSetName, "weakSetName should be set in private identifier environment");
                statements.push(factory2.createExpressionStatement(createPrivateInstanceMethodInitializer(factory2, receiver, weakSetName)));
            }
            function visitInvalidSuperProperty(node) {
                return isPropertyAccessExpression(node) ? factory2.updatePropertyAccessExpression(node, factory2.createVoidZero(), node.name) : factory2.updateElementAccessExpression(node, factory2.createVoidZero(), visitNode(node.argumentExpression, visitor, isExpression));
            }
            function getPropertyNameExpressionIfNeeded(name, shouldHoist) {
                if (isComputedPropertyName(name)) {
                    const cacheAssignment = findComputedPropertyNameCacheAssignment(name);
                    const expression = visitNode(name.expression, visitor, isExpression);
                    const innerExpression = skipPartiallyEmittedExpressions(expression);
                    const inlinable = isSimpleInlineableExpression(innerExpression);
                    const alreadyTransformed = !!cacheAssignment || isAssignmentExpression(innerExpression) && isGeneratedIdentifier(innerExpression.left);
                    if (!alreadyTransformed && !inlinable && shouldHoist) {
                        const generatedName = factory2.getGeneratedNameForNode(name);
                        if (resolver.getNodeCheckFlags(name) & 32768 /* BlockScopedBindingInLoop */) {
                            addBlockScopedVariable(generatedName);
                        }
                        else {
                            hoistVariableDeclaration(generatedName);
                        }
                        return factory2.createAssignment(generatedName, expression);
                    }
                    return inlinable || isIdentifier(innerExpression) ? void 0 : expression;
                }
            }
            function startClassLexicalEnvironment() {
                lexicalEnvironment = { previous: lexicalEnvironment, data: void 0 };
            }
            function endClassLexicalEnvironment() {
                lexicalEnvironment = lexicalEnvironment == null ? void 0 : lexicalEnvironment.previous;
            }
            function getClassLexicalEnvironment() {
                Debug.assert(lexicalEnvironment);
                return lexicalEnvironment.data ?? (lexicalEnvironment.data = {
                    facts: 0 /* None */,
                    classConstructor: void 0,
                    classThis: void 0,
                    superClassReference: void 0
                    // privateIdentifierEnvironment: undefined,
                });
            }
            function getPrivateIdentifierEnvironment() {
                Debug.assert(lexicalEnvironment);
                return lexicalEnvironment.privateEnv ?? (lexicalEnvironment.privateEnv = newPrivateEnvironment({
                    className: void 0,
                    weakSetName: void 0
                }));
            }
            function getPendingExpressions() {
                return pendingExpressions ?? (pendingExpressions = []);
            }
            function addPrivateIdentifierClassElementToEnvironment(node, name, lex, privateEnv, isStatic2, isValid, previousInfo) {
                if (isAutoAccessorPropertyDeclaration(node)) {
                    addPrivateIdentifierAutoAccessorPropertyDeclarationToEnvironment(node, name, lex, privateEnv, isStatic2, isValid, previousInfo);
                }
                else if (isPropertyDeclaration(node)) {
                    addPrivateIdentifierPropertyDeclarationToEnvironment(node, name, lex, privateEnv, isStatic2, isValid, previousInfo);
                }
                else if (isMethodDeclaration(node)) {
                    addPrivateIdentifierMethodDeclarationToEnvironment(node, name, lex, privateEnv, isStatic2, isValid, previousInfo);
                }
                else if (isGetAccessorDeclaration(node)) {
                    addPrivateIdentifierGetAccessorDeclarationToEnvironment(node, name, lex, privateEnv, isStatic2, isValid, previousInfo);
                }
                else if (isSetAccessorDeclaration(node)) {
                    addPrivateIdentifierSetAccessorDeclarationToEnvironment(node, name, lex, privateEnv, isStatic2, isValid, previousInfo);
                }
            }
            function addPrivateIdentifierPropertyDeclarationToEnvironment(_node, name, lex, privateEnv, isStatic2, isValid, _previousInfo) {
                if (isStatic2) {
                    const brandCheckIdentifier = Debug.checkDefined(lex.classThis ?? lex.classConstructor, "classConstructor should be set in private identifier environment");
                    const variableName = createHoistedVariableForPrivateName(name);
                    setPrivateIdentifier(privateEnv, name, {
                        kind: "f" /* Field */,
                        isStatic: true,
                        brandCheckIdentifier,
                        variableName,
                        isValid
                    });
                }
                else {
                    const weakMapName = createHoistedVariableForPrivateName(name);
                    setPrivateIdentifier(privateEnv, name, {
                        kind: "f" /* Field */,
                        isStatic: false,
                        brandCheckIdentifier: weakMapName,
                        isValid
                    });
                    getPendingExpressions().push(factory2.createAssignment(weakMapName, factory2.createNewExpression(factory2.createIdentifier("WeakMap"), 
                    /*typeArguments*/
                    void 0, [])));
                }
            }
            function addPrivateIdentifierMethodDeclarationToEnvironment(_node, name, lex, privateEnv, isStatic2, isValid, _previousInfo) {
                const methodName = createHoistedVariableForPrivateName(name);
                const brandCheckIdentifier = isStatic2 ? Debug.checkDefined(lex.classThis ?? lex.classConstructor, "classConstructor should be set in private identifier environment") : Debug.checkDefined(privateEnv.data.weakSetName, "weakSetName should be set in private identifier environment");
                setPrivateIdentifier(privateEnv, name, {
                    kind: "m" /* Method */,
                    methodName,
                    brandCheckIdentifier,
                    isStatic: isStatic2,
                    isValid
                });
            }
            function addPrivateIdentifierGetAccessorDeclarationToEnvironment(_node, name, lex, privateEnv, isStatic2, isValid, previousInfo) {
                const getterName = createHoistedVariableForPrivateName(name, "_get");
                const brandCheckIdentifier = isStatic2 ? Debug.checkDefined(lex.classThis ?? lex.classConstructor, "classConstructor should be set in private identifier environment") : Debug.checkDefined(privateEnv.data.weakSetName, "weakSetName should be set in private identifier environment");
                if ((previousInfo == null ? void 0 : previousInfo.kind) === "a" /* Accessor */ && previousInfo.isStatic === isStatic2 && !previousInfo.getterName) {
                    previousInfo.getterName = getterName;
                }
                else {
                    setPrivateIdentifier(privateEnv, name, {
                        kind: "a" /* Accessor */,
                        getterName,
                        setterName: void 0,
                        brandCheckIdentifier,
                        isStatic: isStatic2,
                        isValid
                    });
                }
            }
            function addPrivateIdentifierSetAccessorDeclarationToEnvironment(_node, name, lex, privateEnv, isStatic2, isValid, previousInfo) {
                const setterName = createHoistedVariableForPrivateName(name, "_set");
                const brandCheckIdentifier = isStatic2 ? Debug.checkDefined(lex.classThis ?? lex.classConstructor, "classConstructor should be set in private identifier environment") : Debug.checkDefined(privateEnv.data.weakSetName, "weakSetName should be set in private identifier environment");
                if ((previousInfo == null ? void 0 : previousInfo.kind) === "a" /* Accessor */ && previousInfo.isStatic === isStatic2 && !previousInfo.setterName) {
                    previousInfo.setterName = setterName;
                }
                else {
                    setPrivateIdentifier(privateEnv, name, {
                        kind: "a" /* Accessor */,
                        getterName: void 0,
                        setterName,
                        brandCheckIdentifier,
                        isStatic: isStatic2,
                        isValid
                    });
                }
            }
            function addPrivateIdentifierAutoAccessorPropertyDeclarationToEnvironment(_node, name, lex, privateEnv, isStatic2, isValid, _previousInfo) {
                const getterName = createHoistedVariableForPrivateName(name, "_get");
                const setterName = createHoistedVariableForPrivateName(name, "_set");
                const brandCheckIdentifier = isStatic2 ? Debug.checkDefined(lex.classThis ?? lex.classConstructor, "classConstructor should be set in private identifier environment") : Debug.checkDefined(privateEnv.data.weakSetName, "weakSetName should be set in private identifier environment");
                setPrivateIdentifier(privateEnv, name, {
                    kind: "a" /* Accessor */,
                    getterName,
                    setterName,
                    brandCheckIdentifier,
                    isStatic: isStatic2,
                    isValid
                });
            }
            function addPrivateIdentifierToEnvironment(node, name, addDeclaration) {
                const lex = getClassLexicalEnvironment();
                const privateEnv = getPrivateIdentifierEnvironment();
                const previousInfo = getPrivateIdentifier(privateEnv, name);
                const isStatic2 = hasStaticModifier(node);
                const isValid = !isReservedPrivateName(name) && previousInfo === void 0;
                addDeclaration(node, name, lex, privateEnv, isStatic2, isValid, previousInfo);
            }
            function createHoistedVariableForClass(name, node, suffix) {
                const { className } = getPrivateIdentifierEnvironment().data;
                const prefix = className ? { prefix: "_", node: className, suffix: "_" } : "_";
                const identifier = typeof name === "object" ? factory2.getGeneratedNameForNode(name, 16 /* Optimistic */ | 8 /* ReservedInNestedScopes */, prefix, suffix) : typeof name === "string" ? factory2.createUniqueName(name, 16 /* Optimistic */, prefix, suffix) : factory2.createTempVariable(
                /*recordTempVariable*/
                void 0, 
                /*reservedInNestedScopes*/
                true, prefix, suffix);
                if (resolver.getNodeCheckFlags(node) & 32768 /* BlockScopedBindingInLoop */) {
                    addBlockScopedVariable(identifier);
                }
                else {
                    hoistVariableDeclaration(identifier);
                }
                return identifier;
            }
            function createHoistedVariableForPrivateName(name, suffix) {
                const text = tryGetTextOfPropertyName(name);
                return createHoistedVariableForClass((text == null ? void 0 : text.substring(1)) ?? name, name, suffix);
            }
            function accessPrivateIdentifier2(name) {
                const info = accessPrivateIdentifier(lexicalEnvironment, name);
                return (info == null ? void 0 : info.kind) === "untransformed" ? void 0 : info;
            }
            function wrapPrivateIdentifierForDestructuringTarget(node) {
                const parameter = factory2.getGeneratedNameForNode(node);
                const info = accessPrivateIdentifier2(node.name);
                if (!info) {
                    return visitEachChild(node, visitor, context);
                }
                let receiver = node.expression;
                if (isThisProperty(node) || isSuperProperty(node) || !isSimpleCopiableExpression(node.expression)) {
                    receiver = factory2.createTempVariable(hoistVariableDeclaration, 
                    /*reservedInNestedScopes*/
                    true);
                    getPendingExpressions().push(factory2.createBinaryExpression(receiver, 64 /* EqualsToken */, visitNode(node.expression, visitor, isExpression)));
                }
                return factory2.createAssignmentTargetWrapper(parameter, createPrivateIdentifierAssignment(info, receiver, parameter, 64 /* EqualsToken */));
            }
            function visitDestructuringAssignmentTarget(node) {
                if (isObjectLiteralExpression(node) || isArrayLiteralExpression(node)) {
                    return visitAssignmentPattern(node);
                }
                if (isPrivateIdentifierPropertyAccessExpression(node)) {
                    return wrapPrivateIdentifierForDestructuringTarget(node);
                }
                else if (shouldTransformSuperInStaticInitializers && currentClassElement && isSuperProperty(node) && isStaticPropertyDeclarationOrClassStaticBlock(currentClassElement) && (lexicalEnvironment == null ? void 0 : lexicalEnvironment.data)) {
                    const { classConstructor, superClassReference, facts } = lexicalEnvironment.data;
                    if (facts & 1 /* ClassWasDecorated */) {
                        return visitInvalidSuperProperty(node);
                    }
                    else if (classConstructor && superClassReference) {
                        const name = isElementAccessExpression(node) ? visitNode(node.argumentExpression, visitor, isExpression) : isIdentifier(node.name) ? factory2.createStringLiteralFromNode(node.name) : void 0;
                        if (name) {
                            const temp = factory2.createTempVariable(
                            /*recordTempVariable*/
                            void 0);
                            return factory2.createAssignmentTargetWrapper(temp, factory2.createReflectSetCall(superClassReference, name, temp, classConstructor));
                        }
                    }
                }
                return visitEachChild(node, visitor, context);
            }
            function visitAssignmentElement(node) {
                if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                    node = transformNamedEvaluation(context, node);
                }
                if (isAssignmentExpression(node, 
                /*excludeCompoundAssignment*/
                true)) {
                    const left = visitDestructuringAssignmentTarget(node.left);
                    const right = visitNode(node.right, visitor, isExpression);
                    return factory2.updateBinaryExpression(node, left, node.operatorToken, right);
                }
                return visitDestructuringAssignmentTarget(node);
            }
            function visitAssignmentRestElement(node) {
                if (isLeftHandSideExpression(node.expression)) {
                    const expression = visitDestructuringAssignmentTarget(node.expression);
                    return factory2.updateSpreadElement(node, expression);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitArrayAssignmentElement(node) {
                if (isArrayBindingOrAssignmentElement(node)) {
                    if (isSpreadElement(node))
                        return visitAssignmentRestElement(node);
                    if (!isOmittedExpression(node))
                        return visitAssignmentElement(node);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitAssignmentProperty(node) {
                const name = visitNode(node.name, visitor, isPropertyName);
                if (isAssignmentExpression(node.initializer, 
                /*excludeCompoundAssignment*/
                true)) {
                    const assignmentElement = visitAssignmentElement(node.initializer);
                    return factory2.updatePropertyAssignment(node, name, assignmentElement);
                }
                if (isLeftHandSideExpression(node.initializer)) {
                    const assignmentElement = visitDestructuringAssignmentTarget(node.initializer);
                    return factory2.updatePropertyAssignment(node, name, assignmentElement);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitShorthandAssignmentProperty(node) {
                if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                    node = transformNamedEvaluation(context, node);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitAssignmentRestProperty(node) {
                if (isLeftHandSideExpression(node.expression)) {
                    const expression = visitDestructuringAssignmentTarget(node.expression);
                    return factory2.updateSpreadAssignment(node, expression);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitObjectAssignmentElement(node) {
                Debug.assertNode(node, isObjectBindingOrAssignmentElement);
                if (isSpreadAssignment(node))
                    return visitAssignmentRestProperty(node);
                if (isShorthandPropertyAssignment(node))
                    return visitShorthandAssignmentProperty(node);
                if (isPropertyAssignment(node))
                    return visitAssignmentProperty(node);
                return visitEachChild(node, visitor, context);
            }
            function visitAssignmentPattern(node) {
                if (isArrayLiteralExpression(node)) {
                    return factory2.updateArrayLiteralExpression(node, visitNodes2(node.elements, visitArrayAssignmentElement, isExpression));
                }
                else {
                    return factory2.updateObjectLiteralExpression(node, visitNodes2(node.properties, visitObjectAssignmentElement, isObjectLiteralElementLike));
                }
            }
            function onEmitNode(hint, node, emitCallback) {
                const original = getOriginalNode(node);
                const lex = lexicalEnvironmentMap.get(original);
                if (lex) {
                    const savedLexicalEnvironment = lexicalEnvironment;
                    const savedPreviousShouldSubstituteThisWithClassThis = previousShouldSubstituteThisWithClassThis;
                    lexicalEnvironment = lex;
                    previousShouldSubstituteThisWithClassThis = shouldSubstituteThisWithClassThis;
                    shouldSubstituteThisWithClassThis = !isClassStaticBlockDeclaration(original) || !(getInternalEmitFlags(original) & 32 /* TransformPrivateStaticElements */);
                    previousOnEmitNode(hint, node, emitCallback);
                    shouldSubstituteThisWithClassThis = previousShouldSubstituteThisWithClassThis;
                    previousShouldSubstituteThisWithClassThis = savedPreviousShouldSubstituteThisWithClassThis;
                    lexicalEnvironment = savedLexicalEnvironment;
                    return;
                }
                switch (node.kind) {
                    case 218 /* FunctionExpression */:
                        if (isArrowFunction(original) || getEmitFlags(node) & 524288 /* AsyncFunctionBody */) {
                            break;
                        }
                    case 262 /* FunctionDeclaration */:
                    case 176 /* Constructor */:
                    case 177 /* GetAccessor */:
                    case 178 /* SetAccessor */:
                    case 174 /* MethodDeclaration */:
                    case 172 /* PropertyDeclaration */: {
                        const savedLexicalEnvironment = lexicalEnvironment;
                        const savedPreviousShouldSubstituteThisWithClassThis = previousShouldSubstituteThisWithClassThis;
                        lexicalEnvironment = void 0;
                        previousShouldSubstituteThisWithClassThis = shouldSubstituteThisWithClassThis;
                        shouldSubstituteThisWithClassThis = false;
                        previousOnEmitNode(hint, node, emitCallback);
                        shouldSubstituteThisWithClassThis = previousShouldSubstituteThisWithClassThis;
                        previousShouldSubstituteThisWithClassThis = savedPreviousShouldSubstituteThisWithClassThis;
                        lexicalEnvironment = savedLexicalEnvironment;
                        return;
                    }
                    case 167 /* ComputedPropertyName */: {
                        const savedLexicalEnvironment = lexicalEnvironment;
                        const savedShouldSubstituteThisWithClassThis = shouldSubstituteThisWithClassThis;
                        lexicalEnvironment = lexicalEnvironment == null ? void 0 : lexicalEnvironment.previous;
                        shouldSubstituteThisWithClassThis = previousShouldSubstituteThisWithClassThis;
                        previousOnEmitNode(hint, node, emitCallback);
                        shouldSubstituteThisWithClassThis = savedShouldSubstituteThisWithClassThis;
                        lexicalEnvironment = savedLexicalEnvironment;
                        return;
                    }
                }
                previousOnEmitNode(hint, node, emitCallback);
            }
            function onSubstituteNode(hint, node) {
                node = previousOnSubstituteNode(hint, node);
                if (hint === 1 /* Expression */) {
                    return substituteExpression(node);
                }
                return node;
            }
            function substituteExpression(node) {
                switch (node.kind) {
                    case 80 /* Identifier */:
                        return substituteExpressionIdentifier(node);
                    case 110 /* ThisKeyword */:
                        return substituteThisExpression(node);
                }
                return node;
            }
            function substituteThisExpression(node) {
                if (enabledSubstitutions & 2 /* ClassStaticThisOrSuperReference */ && (lexicalEnvironment == null ? void 0 : lexicalEnvironment.data) && !noSubstitution.has(node)) {
                    const { facts, classConstructor, classThis } = lexicalEnvironment.data;
                    const substituteThis = shouldSubstituteThisWithClassThis ? classThis ?? classConstructor : classConstructor;
                    if (substituteThis) {
                        return setTextRange(setOriginalNode(factory2.cloneNode(substituteThis), node), node);
                    }
                    if (facts & 1 /* ClassWasDecorated */ && legacyDecorators) {
                        return factory2.createParenthesizedExpression(factory2.createVoidZero());
                    }
                }
                return node;
            }
            function substituteExpressionIdentifier(node) {
                return trySubstituteClassAlias(node) || node;
            }
            function trySubstituteClassAlias(node) {
                if (enabledSubstitutions & 1 /* ClassAliases */) {
                    if (resolver.getNodeCheckFlags(node) & 536870912 /* ConstructorReference */) {
                        const declaration = resolver.getReferencedValueDeclaration(node);
                        if (declaration) {
                            const classAlias = classAliases[declaration.id];
                            if (classAlias) {
                                const clone2 = factory2.cloneNode(classAlias);
                                setSourceMapRange(clone2, node);
                                setCommentRange(clone2, node);
                                return clone2;
                            }
                        }
                    }
                }
                return void 0;
            }
        }
        function createPrivateStaticFieldInitializer(factory2, variableName, initializer) {
            return factory2.createAssignment(variableName, factory2.createObjectLiteralExpression([
                factory2.createPropertyAssignment("value", initializer || factory2.createVoidZero())
            ]));
        }
        function createPrivateInstanceFieldInitializer(factory2, receiver, initializer, weakMapName) {
            return factory2.createCallExpression(factory2.createPropertyAccessExpression(weakMapName, "set"), 
            /*typeArguments*/
            void 0, [receiver, initializer || factory2.createVoidZero()]);
        }
        function createPrivateInstanceMethodInitializer(factory2, receiver, weakSetName) {
            return factory2.createCallExpression(factory2.createPropertyAccessExpression(weakSetName, "add"), 
            /*typeArguments*/
            void 0, [receiver]);
        }
        function isReservedPrivateName(node) {
            return !isGeneratedPrivateIdentifier(node) && node.escapedText === "#constructor";
        }
        function isPrivateIdentifierInExpression(node) {
            return isPrivateIdentifier(node.left) && node.operatorToken.kind === 103 /* InKeyword */;
        }
        function isStaticPropertyDeclaration2(node) {
            return isPropertyDeclaration(node) && hasStaticModifier(node);
        }
        function isStaticPropertyDeclarationOrClassStaticBlock(node) {
            return isClassStaticBlockDeclaration(node) || isStaticPropertyDeclaration2(node);
        }
        var init_classFields = __esm({
            "src/compiler/transformers/classFields.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/typeSerializer.ts
        function createRuntimeTypeSerializer(context) {
            const { factory: factory2, hoistVariableDeclaration } = context;
            const resolver = context.getEmitResolver();
            const compilerOptions = context.getCompilerOptions();
            const languageVersion = getEmitScriptTarget(compilerOptions);
            const strictNullChecks = getStrictOptionValue(compilerOptions, "strictNullChecks");
            let currentLexicalScope;
            let currentNameScope;
            return {
                serializeTypeNode: (serializerContext, node) => setSerializerContextAnd(serializerContext, serializeTypeNode, node),
                serializeTypeOfNode: (serializerContext, node) => setSerializerContextAnd(serializerContext, serializeTypeOfNode, node),
                serializeParameterTypesOfNode: (serializerContext, node, container) => setSerializerContextAnd(serializerContext, serializeParameterTypesOfNode, node, container),
                serializeReturnTypeOfNode: (serializerContext, node) => setSerializerContextAnd(serializerContext, serializeReturnTypeOfNode, node)
            };
            function setSerializerContextAnd(serializerContext, cb, node, arg) {
                const savedCurrentLexicalScope = currentLexicalScope;
                const savedCurrentNameScope = currentNameScope;
                currentLexicalScope = serializerContext.currentLexicalScope;
                currentNameScope = serializerContext.currentNameScope;
                const result = arg === void 0 ? cb(node) : cb(node, arg);
                currentLexicalScope = savedCurrentLexicalScope;
                currentNameScope = savedCurrentNameScope;
                return result;
            }
            function getAccessorTypeNode(node) {
                const accessors = resolver.getAllAccessorDeclarations(node);
                return accessors.setAccessor && getSetAccessorTypeAnnotationNode(accessors.setAccessor) || accessors.getAccessor && getEffectiveReturnTypeNode(accessors.getAccessor);
            }
            function serializeTypeOfNode(node) {
                switch (node.kind) {
                    case 172 /* PropertyDeclaration */:
                    case 169 /* Parameter */:
                        return serializeTypeNode(node.type);
                    case 178 /* SetAccessor */:
                    case 177 /* GetAccessor */:
                        return serializeTypeNode(getAccessorTypeNode(node));
                    case 263 /* ClassDeclaration */:
                    case 231 /* ClassExpression */:
                    case 174 /* MethodDeclaration */:
                        return factory2.createIdentifier("Function");
                    default:
                        return factory2.createVoidZero();
                }
            }
            function serializeParameterTypesOfNode(node, container) {
                const valueDeclaration = isClassLike(node) ? getFirstConstructorWithBody(node) : isFunctionLike(node) && nodeIsPresent(node.body) ? node : void 0;
                const expressions = [];
                if (valueDeclaration) {
                    const parameters = getParametersOfDecoratedDeclaration(valueDeclaration, container);
                    const numParameters = parameters.length;
                    for (let i = 0; i < numParameters; i++) {
                        const parameter = parameters[i];
                        if (i === 0 && isIdentifier(parameter.name) && parameter.name.escapedText === "this") {
                            continue;
                        }
                        if (parameter.dotDotDotToken) {
                            expressions.push(serializeTypeNode(getRestParameterElementType(parameter.type)));
                        }
                        else {
                            expressions.push(serializeTypeOfNode(parameter));
                        }
                    }
                }
                return factory2.createArrayLiteralExpression(expressions);
            }
            function getParametersOfDecoratedDeclaration(node, container) {
                if (container && node.kind === 177 /* GetAccessor */) {
                    const { setAccessor } = getAllAccessorDeclarations(container.members, node);
                    if (setAccessor) {
                        return setAccessor.parameters;
                    }
                }
                return node.parameters;
            }
            function serializeReturnTypeOfNode(node) {
                if (isFunctionLike(node) && node.type) {
                    return serializeTypeNode(node.type);
                }
                else if (isAsyncFunction(node)) {
                    return factory2.createIdentifier("Promise");
                }
                return factory2.createVoidZero();
            }
            function serializeTypeNode(node) {
                if (node === void 0) {
                    return factory2.createIdentifier("Object");
                }
                node = skipTypeParentheses(node);
                switch (node.kind) {
                    case 116 /* VoidKeyword */:
                    case 157 /* UndefinedKeyword */:
                    case 146 /* NeverKeyword */:
                        return factory2.createVoidZero();
                    case 184 /* FunctionType */:
                    case 185 /* ConstructorType */:
                        return factory2.createIdentifier("Function");
                    case 188 /* ArrayType */:
                    case 189 /* TupleType */:
                        return factory2.createIdentifier("Array");
                    case 182 /* TypePredicate */:
                        return node.assertsModifier ? factory2.createVoidZero() : factory2.createIdentifier("Boolean");
                    case 136 /* BooleanKeyword */:
                        return factory2.createIdentifier("Boolean");
                    case 203 /* TemplateLiteralType */:
                    case 154 /* StringKeyword */:
                        return factory2.createIdentifier("String");
                    case 151 /* ObjectKeyword */:
                        return factory2.createIdentifier("Object");
                    case 201 /* LiteralType */:
                        return serializeLiteralOfLiteralTypeNode(node.literal);
                    case 150 /* NumberKeyword */:
                        return factory2.createIdentifier("Number");
                    case 163 /* BigIntKeyword */:
                        return getGlobalConstructor("BigInt", 7 /* ES2020 */);
                    case 155 /* SymbolKeyword */:
                        return getGlobalConstructor("Symbol", 2 /* ES2015 */);
                    case 183 /* TypeReference */:
                        return serializeTypeReferenceNode(node);
                    case 193 /* IntersectionType */:
                        return serializeUnionOrIntersectionConstituents(node.types, 
                        /*isIntersection*/
                        true);
                    case 192 /* UnionType */:
                        return serializeUnionOrIntersectionConstituents(node.types, 
                        /*isIntersection*/
                        false);
                    case 194 /* ConditionalType */:
                        return serializeUnionOrIntersectionConstituents([node.trueType, node.falseType], 
                        /*isIntersection*/
                        false);
                    case 198 /* TypeOperator */:
                        if (node.operator === 148 /* ReadonlyKeyword */) {
                            return serializeTypeNode(node.type);
                        }
                        break;
                    case 186 /* TypeQuery */:
                    case 199 /* IndexedAccessType */:
                    case 200 /* MappedType */:
                    case 187 /* TypeLiteral */:
                    case 133 /* AnyKeyword */:
                    case 159 /* UnknownKeyword */:
                    case 197 /* ThisType */:
                    case 205 /* ImportType */:
                        break;
                    case 319 /* JSDocAllType */:
                    case 320 /* JSDocUnknownType */:
                    case 324 /* JSDocFunctionType */:
                    case 325 /* JSDocVariadicType */:
                    case 326 /* JSDocNamepathType */:
                        break;
                    case 321 /* JSDocNullableType */:
                    case 322 /* JSDocNonNullableType */:
                    case 323 /* JSDocOptionalType */:
                        return serializeTypeNode(node.type);
                    default:
                        return Debug.failBadSyntaxKind(node);
                }
                return factory2.createIdentifier("Object");
            }
            function serializeLiteralOfLiteralTypeNode(node) {
                switch (node.kind) {
                    case 11 /* StringLiteral */:
                    case 15 /* NoSubstitutionTemplateLiteral */:
                        return factory2.createIdentifier("String");
                    case 224 /* PrefixUnaryExpression */: {
                        const operand = node.operand;
                        switch (operand.kind) {
                            case 9 /* NumericLiteral */:
                            case 10 /* BigIntLiteral */:
                                return serializeLiteralOfLiteralTypeNode(operand);
                            default:
                                return Debug.failBadSyntaxKind(operand);
                        }
                    }
                    case 9 /* NumericLiteral */:
                        return factory2.createIdentifier("Number");
                    case 10 /* BigIntLiteral */:
                        return getGlobalConstructor("BigInt", 7 /* ES2020 */);
                    case 112 /* TrueKeyword */:
                    case 97 /* FalseKeyword */:
                        return factory2.createIdentifier("Boolean");
                    case 106 /* NullKeyword */:
                        return factory2.createVoidZero();
                    default:
                        return Debug.failBadSyntaxKind(node);
                }
            }
            function serializeUnionOrIntersectionConstituents(types, isIntersection) {
                let serializedType;
                for (let typeNode of types) {
                    typeNode = skipTypeParentheses(typeNode);
                    if (typeNode.kind === 146 /* NeverKeyword */) {
                        if (isIntersection)
                            return factory2.createVoidZero();
                        continue;
                    }
                    if (typeNode.kind === 159 /* UnknownKeyword */) {
                        if (!isIntersection)
                            return factory2.createIdentifier("Object");
                        continue;
                    }
                    if (typeNode.kind === 133 /* AnyKeyword */) {
                        return factory2.createIdentifier("Object");
                    }
                    if (!strictNullChecks && (isLiteralTypeNode(typeNode) && typeNode.literal.kind === 106 /* NullKeyword */ || typeNode.kind === 157 /* UndefinedKeyword */)) {
                        continue;
                    }
                    const serializedConstituent = serializeTypeNode(typeNode);
                    if (isIdentifier(serializedConstituent) && serializedConstituent.escapedText === "Object") {
                        return serializedConstituent;
                    }
                    if (serializedType) {
                        if (!equateSerializedTypeNodes(serializedType, serializedConstituent)) {
                            return factory2.createIdentifier("Object");
                        }
                    }
                    else {
                        serializedType = serializedConstituent;
                    }
                }
                return serializedType ?? factory2.createVoidZero();
            }
            function equateSerializedTypeNodes(left, right) {
                return (
                // temp vars used in fallback
                isGeneratedIdentifier(left) ? isGeneratedIdentifier(right) : (
                // entity names
                isIdentifier(left) ? isIdentifier(right) && left.escapedText === right.escapedText : isPropertyAccessExpression(left) ? isPropertyAccessExpression(right) && equateSerializedTypeNodes(left.expression, right.expression) && equateSerializedTypeNodes(left.name, right.name) : (
                // `void 0`
                isVoidExpression(left) ? isVoidExpression(right) && isNumericLiteral(left.expression) && left.expression.text === "0" && isNumericLiteral(right.expression) && right.expression.text === "0" : (
                // `"undefined"` or `"function"` in `typeof` checks
                isStringLiteral(left) ? isStringLiteral(right) && left.text === right.text : (
                // used in `typeof` checks for fallback
                isTypeOfExpression(left) ? isTypeOfExpression(right) && equateSerializedTypeNodes(left.expression, right.expression) : (
                // parens in `typeof` checks with temps
                isParenthesizedExpression(left) ? isParenthesizedExpression(right) && equateSerializedTypeNodes(left.expression, right.expression) : (
                // conditionals used in fallback
                isConditionalExpression(left) ? isConditionalExpression(right) && equateSerializedTypeNodes(left.condition, right.condition) && equateSerializedTypeNodes(left.whenTrue, right.whenTrue) && equateSerializedTypeNodes(left.whenFalse, right.whenFalse) : (
                // logical binary and assignments used in fallback
                isBinaryExpression(left) ? isBinaryExpression(right) && left.operatorToken.kind === right.operatorToken.kind && equateSerializedTypeNodes(left.left, right.left) && equateSerializedTypeNodes(left.right, right.right) : false))))))));
            }
            function serializeTypeReferenceNode(node) {
                const kind = resolver.getTypeReferenceSerializationKind(node.typeName, currentNameScope ?? currentLexicalScope);
                switch (kind) {
                    case 0 /* Unknown */:
                        if (findAncestor(node, (n) => n.parent && isConditionalTypeNode(n.parent) && (n.parent.trueType === n || n.parent.falseType === n))) {
                            return factory2.createIdentifier("Object");
                        }
                        const serialized = serializeEntityNameAsExpressionFallback(node.typeName);
                        const temp = factory2.createTempVariable(hoistVariableDeclaration);
                        return factory2.createConditionalExpression(factory2.createTypeCheck(factory2.createAssignment(temp, serialized), "function"), 
                        /*questionToken*/
                        void 0, temp, 
                        /*colonToken*/
                        void 0, factory2.createIdentifier("Object"));
                    case 1 /* TypeWithConstructSignatureAndValue */:
                        return serializeEntityNameAsExpression(node.typeName);
                    case 2 /* VoidNullableOrNeverType */:
                        return factory2.createVoidZero();
                    case 4 /* BigIntLikeType */:
                        return getGlobalConstructor("BigInt", 7 /* ES2020 */);
                    case 6 /* BooleanType */:
                        return factory2.createIdentifier("Boolean");
                    case 3 /* NumberLikeType */:
                        return factory2.createIdentifier("Number");
                    case 5 /* StringLikeType */:
                        return factory2.createIdentifier("String");
                    case 7 /* ArrayLikeType */:
                        return factory2.createIdentifier("Array");
                    case 8 /* ESSymbolType */:
                        return getGlobalConstructor("Symbol", 2 /* ES2015 */);
                    case 10 /* TypeWithCallSignature */:
                        return factory2.createIdentifier("Function");
                    case 9 /* Promise */:
                        return factory2.createIdentifier("Promise");
                    case 11 /* ObjectType */:
                        return factory2.createIdentifier("Object");
                    default:
                        return Debug.assertNever(kind);
                }
            }
            function createCheckedValue(left, right) {
                return factory2.createLogicalAnd(factory2.createStrictInequality(factory2.createTypeOfExpression(left), factory2.createStringLiteral("undefined")), right);
            }
            function serializeEntityNameAsExpressionFallback(node) {
                if (node.kind === 80 /* Identifier */) {
                    const copied = serializeEntityNameAsExpression(node);
                    return createCheckedValue(copied, copied);
                }
                if (node.left.kind === 80 /* Identifier */) {
                    return createCheckedValue(serializeEntityNameAsExpression(node.left), serializeEntityNameAsExpression(node));
                }
                const left = serializeEntityNameAsExpressionFallback(node.left);
                const temp = factory2.createTempVariable(hoistVariableDeclaration);
                return factory2.createLogicalAnd(factory2.createLogicalAnd(left.left, factory2.createStrictInequality(factory2.createAssignment(temp, left.right), factory2.createVoidZero())), factory2.createPropertyAccessExpression(temp, node.right));
            }
            function serializeEntityNameAsExpression(node) {
                switch (node.kind) {
                    case 80 /* Identifier */:
                        const name = setParent(setTextRange(parseNodeFactory.cloneNode(node), node), node.parent);
                        name.original = void 0;
                        setParent(name, getParseTreeNode(currentLexicalScope));
                        return name;
                    case 166 /* QualifiedName */:
                        return serializeQualifiedNameAsExpression(node);
                }
            }
            function serializeQualifiedNameAsExpression(node) {
                return factory2.createPropertyAccessExpression(serializeEntityNameAsExpression(node.left), node.right);
            }
            function getGlobalConstructorWithFallback(name) {
                return factory2.createConditionalExpression(factory2.createTypeCheck(factory2.createIdentifier(name), "function"), 
                /*questionToken*/
                void 0, factory2.createIdentifier(name), 
                /*colonToken*/
                void 0, factory2.createIdentifier("Object"));
            }
            function getGlobalConstructor(name, minLanguageVersion) {
                return languageVersion < minLanguageVersion ? getGlobalConstructorWithFallback(name) : factory2.createIdentifier(name);
            }
        }
        var init_typeSerializer = __esm({
            "src/compiler/transformers/typeSerializer.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/legacyDecorators.ts
        function transformLegacyDecorators(context) {
            const { factory: factory2, getEmitHelperFactory: emitHelpers, hoistVariableDeclaration } = context;
            const resolver = context.getEmitResolver();
            const compilerOptions = context.getCompilerOptions();
            const languageVersion = getEmitScriptTarget(compilerOptions);
            const previousOnSubstituteNode = context.onSubstituteNode;
            context.onSubstituteNode = onSubstituteNode;
            let classAliases;
            return chainBundle(context, transformSourceFile);
            function transformSourceFile(node) {
                const visited = visitEachChild(node, visitor, context);
                addEmitHelpers(visited, context.readEmitHelpers());
                return visited;
            }
            function modifierVisitor(node) {
                return isDecorator(node) ? void 0 : node;
            }
            function visitor(node) {
                if (!(node.transformFlags & 33554432 /* ContainsDecorators */)) {
                    return node;
                }
                switch (node.kind) {
                    case 170 /* Decorator */:
                        return void 0;
                    case 263 /* ClassDeclaration */:
                        return visitClassDeclaration(node);
                    case 231 /* ClassExpression */:
                        return visitClassExpression(node);
                    case 176 /* Constructor */:
                        return visitConstructorDeclaration(node);
                    case 174 /* MethodDeclaration */:
                        return visitMethodDeclaration(node);
                    case 178 /* SetAccessor */:
                        return visitSetAccessorDeclaration(node);
                    case 177 /* GetAccessor */:
                        return visitGetAccessorDeclaration(node);
                    case 172 /* PropertyDeclaration */:
                        return visitPropertyDeclaration(node);
                    case 169 /* Parameter */:
                        return visitParameterDeclaration(node);
                    default:
                        return visitEachChild(node, visitor, context);
                }
            }
            function visitClassDeclaration(node) {
                if (!(classOrConstructorParameterIsDecorated(
                /*useLegacyDecorators*/
                true, node) || childIsDecorated(
                /*useLegacyDecorators*/
                true, node))) {
                    return visitEachChild(node, visitor, context);
                }
                const statements = classOrConstructorParameterIsDecorated(
                /*useLegacyDecorators*/
                true, node) ? transformClassDeclarationWithClassDecorators(node, node.name) : transformClassDeclarationWithoutClassDecorators(node, node.name);
                return singleOrMany(statements);
            }
            function decoratorContainsPrivateIdentifierInExpression(decorator) {
                return !!(decorator.transformFlags & 536870912 /* ContainsPrivateIdentifierInExpression */);
            }
            function parameterDecoratorsContainPrivateIdentifierInExpression(parameterDecorators) {
                return some(parameterDecorators, decoratorContainsPrivateIdentifierInExpression);
            }
            function hasClassElementWithDecoratorContainingPrivateIdentifierInExpression(node) {
                for (const member of node.members) {
                    if (!canHaveDecorators(member))
                        continue;
                    const allDecorators = getAllDecoratorsOfClassElement(member, node, 
                    /*useLegacyDecorators*/
                    true);
                    if (some(allDecorators == null ? void 0 : allDecorators.decorators, decoratorContainsPrivateIdentifierInExpression))
                        return true;
                    if (some(allDecorators == null ? void 0 : allDecorators.parameters, parameterDecoratorsContainPrivateIdentifierInExpression))
                        return true;
                }
                return false;
            }
            function transformDecoratorsOfClassElements(node, members) {
                let decorationStatements = [];
                addClassElementDecorationStatements(decorationStatements, node, 
                /*isStatic*/
                false);
                addClassElementDecorationStatements(decorationStatements, node, 
                /*isStatic*/
                true);
                if (hasClassElementWithDecoratorContainingPrivateIdentifierInExpression(node)) {
                    members = setTextRange(factory2.createNodeArray([
                        ...members,
                        factory2.createClassStaticBlockDeclaration(factory2.createBlock(decorationStatements, 
                        /*multiLine*/
                        true))
                    ]), members);
                    decorationStatements = void 0;
                }
                return { decorationStatements, members };
            }
            function transformClassDeclarationWithoutClassDecorators(node, name) {
                const modifiers = visitNodes2(node.modifiers, modifierVisitor, isModifier);
                const heritageClauses = visitNodes2(node.heritageClauses, visitor, isHeritageClause);
                let members = visitNodes2(node.members, visitor, isClassElement);
                let decorationStatements = [];
                ({ members, decorationStatements } = transformDecoratorsOfClassElements(node, members));
                const updated = factory2.updateClassDeclaration(node, modifiers, name, 
                /*typeParameters*/
                void 0, heritageClauses, members);
                return addRange([updated], decorationStatements);
            }
            function transformClassDeclarationWithClassDecorators(node, name) {
                const isExport = hasSyntacticModifier(node, 32 /* Export */);
                const isDefault = hasSyntacticModifier(node, 2048 /* Default */);
                const modifiers = visitNodes2(node.modifiers, (node2) => isExportOrDefaultModifier(node2) || isDecorator(node2) ? void 0 : node2, isModifierLike);
                const location = moveRangePastModifiers(node);
                const classAlias = getClassAliasIfNeeded(node);
                const declName = languageVersion < 2 /* ES2015 */ ? factory2.getInternalName(node, 
                /*allowComments*/
                false, 
                /*allowSourceMaps*/
                true) : factory2.getLocalName(node, 
                /*allowComments*/
                false, 
                /*allowSourceMaps*/
                true);
                const heritageClauses = visitNodes2(node.heritageClauses, visitor, isHeritageClause);
                let members = visitNodes2(node.members, visitor, isClassElement);
                let decorationStatements = [];
                ({ members, decorationStatements } = transformDecoratorsOfClassElements(node, members));
                const assignClassAliasInStaticBlock = languageVersion >= 9 /* ES2022 */ && !!classAlias && some(members, (member) => isPropertyDeclaration(member) && hasSyntacticModifier(member, 256 /* Static */) || isClassStaticBlockDeclaration(member));
                if (assignClassAliasInStaticBlock) {
                    members = setTextRange(factory2.createNodeArray([
                        factory2.createClassStaticBlockDeclaration(factory2.createBlock([
                            factory2.createExpressionStatement(factory2.createAssignment(classAlias, factory2.createThis()))
                        ])),
                        ...members
                    ]), members);
                }
                const classExpression = factory2.createClassExpression(modifiers, name && isGeneratedIdentifier(name) ? void 0 : name, 
                /*typeParameters*/
                void 0, heritageClauses, members);
                setOriginalNode(classExpression, node);
                setTextRange(classExpression, location);
                const varInitializer = classAlias && !assignClassAliasInStaticBlock ? factory2.createAssignment(classAlias, classExpression) : classExpression;
                const varDecl = factory2.createVariableDeclaration(declName, 
                /*exclamationToken*/
                void 0, 
                /*type*/
                void 0, varInitializer);
                setOriginalNode(varDecl, node);
                const varDeclList = factory2.createVariableDeclarationList([varDecl], 1 /* Let */);
                const varStatement = factory2.createVariableStatement(
                /*modifiers*/
                void 0, varDeclList);
                setOriginalNode(varStatement, node);
                setTextRange(varStatement, location);
                setCommentRange(varStatement, node);
                const statements = [varStatement];
                addRange(statements, decorationStatements);
                addConstructorDecorationStatement(statements, node);
                if (isExport) {
                    if (isDefault) {
                        const exportStatement = factory2.createExportDefault(declName);
                        statements.push(exportStatement);
                    }
                    else {
                        const exportStatement = factory2.createExternalModuleExport(factory2.getDeclarationName(node));
                        statements.push(exportStatement);
                    }
                }
                return statements;
            }
            function visitClassExpression(node) {
                return factory2.updateClassExpression(node, visitNodes2(node.modifiers, modifierVisitor, isModifier), node.name, 
                /*typeParameters*/
                void 0, visitNodes2(node.heritageClauses, visitor, isHeritageClause), visitNodes2(node.members, visitor, isClassElement));
            }
            function visitConstructorDeclaration(node) {
                return factory2.updateConstructorDeclaration(node, visitNodes2(node.modifiers, modifierVisitor, isModifier), visitNodes2(node.parameters, visitor, isParameter), visitNode(node.body, visitor, isBlock));
            }
            function finishClassElement(updated, original) {
                if (updated !== original) {
                    setCommentRange(updated, original);
                    setSourceMapRange(updated, moveRangePastModifiers(original));
                }
                return updated;
            }
            function visitMethodDeclaration(node) {
                return finishClassElement(factory2.updateMethodDeclaration(node, visitNodes2(node.modifiers, modifierVisitor, isModifier), node.asteriskToken, Debug.checkDefined(visitNode(node.name, visitor, isPropertyName)), 
                /*questionToken*/
                void 0, 
                /*typeParameters*/
                void 0, visitNodes2(node.parameters, visitor, isParameter), 
                /*type*/
                void 0, visitNode(node.body, visitor, isBlock)), node);
            }
            function visitGetAccessorDeclaration(node) {
                return finishClassElement(factory2.updateGetAccessorDeclaration(node, visitNodes2(node.modifiers, modifierVisitor, isModifier), Debug.checkDefined(visitNode(node.name, visitor, isPropertyName)), visitNodes2(node.parameters, visitor, isParameter), 
                /*type*/
                void 0, visitNode(node.body, visitor, isBlock)), node);
            }
            function visitSetAccessorDeclaration(node) {
                return finishClassElement(factory2.updateSetAccessorDeclaration(node, visitNodes2(node.modifiers, modifierVisitor, isModifier), Debug.checkDefined(visitNode(node.name, visitor, isPropertyName)), visitNodes2(node.parameters, visitor, isParameter), visitNode(node.body, visitor, isBlock)), node);
            }
            function visitPropertyDeclaration(node) {
                if (node.flags & 33554432 /* Ambient */ || hasSyntacticModifier(node, 128 /* Ambient */)) {
                    return void 0;
                }
                return finishClassElement(factory2.updatePropertyDeclaration(node, visitNodes2(node.modifiers, modifierVisitor, isModifier), Debug.checkDefined(visitNode(node.name, visitor, isPropertyName)), 
                /*questionOrExclamationToken*/
                void 0, 
                /*type*/
                void 0, visitNode(node.initializer, visitor, isExpression)), node);
            }
            function visitParameterDeclaration(node) {
                const updated = factory2.updateParameterDeclaration(node, elideNodes(factory2, node.modifiers), node.dotDotDotToken, Debug.checkDefined(visitNode(node.name, visitor, isBindingName)), 
                /*questionToken*/
                void 0, 
                /*type*/
                void 0, visitNode(node.initializer, visitor, isExpression));
                if (updated !== node) {
                    setCommentRange(updated, node);
                    setTextRange(updated, moveRangePastModifiers(node));
                    setSourceMapRange(updated, moveRangePastModifiers(node));
                    setEmitFlags(updated.name, 64 /* NoTrailingSourceMap */);
                }
                return updated;
            }
            function isSyntheticMetadataDecorator(node) {
                return isCallToHelper(node.expression, "___metadata");
            }
            function transformAllDecoratorsOfDeclaration(allDecorators) {
                if (!allDecorators) {
                    return void 0;
                }
                const { false: decorators, true: metadata } = groupBy(allDecorators.decorators, isSyntheticMetadataDecorator);
                const decoratorExpressions = [];
                addRange(decoratorExpressions, map(decorators, transformDecorator));
                addRange(decoratorExpressions, flatMap(allDecorators.parameters, transformDecoratorsOfParameter));
                addRange(decoratorExpressions, map(metadata, transformDecorator));
                return decoratorExpressions;
            }
            function addClassElementDecorationStatements(statements, node, isStatic2) {
                addRange(statements, map(generateClassElementDecorationExpressions(node, isStatic2), (expr) => factory2.createExpressionStatement(expr)));
            }
            function isDecoratedClassElement(member, isStaticElement, parent2) {
                return nodeOrChildIsDecorated(
                /*useLegacyDecorators*/
                true, member, parent2) && isStaticElement === isStatic(member);
            }
            function getDecoratedClassElements(node, isStatic2) {
                return filter(node.members, (m) => isDecoratedClassElement(m, isStatic2, node));
            }
            function generateClassElementDecorationExpressions(node, isStatic2) {
                const members = getDecoratedClassElements(node, isStatic2);
                let expressions;
                for (const member of members) {
                    expressions = append(expressions, generateClassElementDecorationExpression(node, member));
                }
                return expressions;
            }
            function generateClassElementDecorationExpression(node, member) {
                const allDecorators = getAllDecoratorsOfClassElement(member, node, 
                /*useLegacyDecorators*/
                true);
                const decoratorExpressions = transformAllDecoratorsOfDeclaration(allDecorators);
                if (!decoratorExpressions) {
                    return void 0;
                }
                const prefix = getClassMemberPrefix(node, member);
                const memberName = getExpressionForPropertyName(member, 
                /*generateNameForComputedPropertyName*/
                !hasSyntacticModifier(member, 128 /* Ambient */));
                const descriptor = languageVersion > 0 /* ES3 */ ? isPropertyDeclaration(member) && !hasAccessorModifier(member) ? factory2.createVoidZero() : factory2.createNull() : void 0;
                const helper = emitHelpers().createDecorateHelper(decoratorExpressions, prefix, memberName, descriptor);
                setEmitFlags(helper, 3072 /* NoComments */);
                setSourceMapRange(helper, moveRangePastModifiers(member));
                return helper;
            }
            function addConstructorDecorationStatement(statements, node) {
                const expression = generateConstructorDecorationExpression(node);
                if (expression) {
                    statements.push(setOriginalNode(factory2.createExpressionStatement(expression), node));
                }
            }
            function generateConstructorDecorationExpression(node) {
                const allDecorators = getAllDecoratorsOfClass(node);
                const decoratorExpressions = transformAllDecoratorsOfDeclaration(allDecorators);
                if (!decoratorExpressions) {
                    return void 0;
                }
                const classAlias = classAliases && classAliases[getOriginalNodeId(node)];
                const localName = languageVersion < 2 /* ES2015 */ ? factory2.getInternalName(node, 
                /*allowComments*/
                false, 
                /*allowSourceMaps*/
                true) : factory2.getDeclarationName(node, 
                /*allowComments*/
                false, 
                /*allowSourceMaps*/
                true);
                const decorate = emitHelpers().createDecorateHelper(decoratorExpressions, localName);
                const expression = factory2.createAssignment(localName, classAlias ? factory2.createAssignment(classAlias, decorate) : decorate);
                setEmitFlags(expression, 3072 /* NoComments */);
                setSourceMapRange(expression, moveRangePastModifiers(node));
                return expression;
            }
            function transformDecorator(decorator) {
                return Debug.checkDefined(visitNode(decorator.expression, visitor, isExpression));
            }
            function transformDecoratorsOfParameter(decorators, parameterOffset) {
                let expressions;
                if (decorators) {
                    expressions = [];
                    for (const decorator of decorators) {
                        const helper = emitHelpers().createParamHelper(transformDecorator(decorator), parameterOffset);
                        setTextRange(helper, decorator.expression);
                        setEmitFlags(helper, 3072 /* NoComments */);
                        expressions.push(helper);
                    }
                }
                return expressions;
            }
            function getExpressionForPropertyName(member, generateNameForComputedPropertyName) {
                const name = member.name;
                if (isPrivateIdentifier(name)) {
                    return factory2.createIdentifier("");
                }
                else if (isComputedPropertyName(name)) {
                    return generateNameForComputedPropertyName && !isSimpleInlineableExpression(name.expression) ? factory2.getGeneratedNameForNode(name) : name.expression;
                }
                else if (isIdentifier(name)) {
                    return factory2.createStringLiteral(idText(name));
                }
                else {
                    return factory2.cloneNode(name);
                }
            }
            function enableSubstitutionForClassAliases() {
                if (!classAliases) {
                    context.enableSubstitution(80 /* Identifier */);
                    classAliases = [];
                }
            }
            function getClassAliasIfNeeded(node) {
                if (resolver.getNodeCheckFlags(node) & 262144 /* ContainsConstructorReference */) {
                    enableSubstitutionForClassAliases();
                    const classAlias = factory2.createUniqueName(node.name && !isGeneratedIdentifier(node.name) ? idText(node.name) : "default");
                    classAliases[getOriginalNodeId(node)] = classAlias;
                    hoistVariableDeclaration(classAlias);
                    return classAlias;
                }
            }
            function getClassPrototype(node) {
                return factory2.createPropertyAccessExpression(factory2.getDeclarationName(node), "prototype");
            }
            function getClassMemberPrefix(node, member) {
                return isStatic(member) ? factory2.getDeclarationName(node) : getClassPrototype(node);
            }
            function onSubstituteNode(hint, node) {
                node = previousOnSubstituteNode(hint, node);
                if (hint === 1 /* Expression */) {
                    return substituteExpression(node);
                }
                return node;
            }
            function substituteExpression(node) {
                switch (node.kind) {
                    case 80 /* Identifier */:
                        return substituteExpressionIdentifier(node);
                }
                return node;
            }
            function substituteExpressionIdentifier(node) {
                return trySubstituteClassAlias(node) ?? node;
            }
            function trySubstituteClassAlias(node) {
                if (classAliases) {
                    if (resolver.getNodeCheckFlags(node) & 536870912 /* ConstructorReference */) {
                        const declaration = resolver.getReferencedValueDeclaration(node);
                        if (declaration) {
                            const classAlias = classAliases[declaration.id];
                            if (classAlias) {
                                const clone2 = factory2.cloneNode(classAlias);
                                setSourceMapRange(clone2, node);
                                setCommentRange(clone2, node);
                                return clone2;
                            }
                        }
                    }
                }
                return void 0;
            }
        }
        var init_legacyDecorators = __esm({
            "src/compiler/transformers/legacyDecorators.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/esDecorators.ts
        function transformESDecorators(context) {
            const { factory: factory2, getEmitHelperFactory: emitHelpers, startLexicalEnvironment, endLexicalEnvironment, hoistVariableDeclaration } = context;
            const languageVersion = getEmitScriptTarget(context.getCompilerOptions());
            let top;
            let classInfo;
            let classThis;
            let classSuper;
            let pendingExpressions;
            let shouldTransformPrivateStaticElementsInFile;
            return chainBundle(context, transformSourceFile);
            function transformSourceFile(node) {
                top = void 0;
                shouldTransformPrivateStaticElementsInFile = false;
                const visited = visitEachChild(node, visitor, context);
                addEmitHelpers(visited, context.readEmitHelpers());
                if (shouldTransformPrivateStaticElementsInFile) {
                    addInternalEmitFlags(visited, 32 /* TransformPrivateStaticElements */);
                    shouldTransformPrivateStaticElementsInFile = false;
                }
                return visited;
            }
            function updateState() {
                classInfo = void 0;
                classThis = void 0;
                classSuper = void 0;
                switch (top == null ? void 0 : top.kind) {
                    case "class":
                        classInfo = top.classInfo;
                        break;
                    case "class-element":
                        classInfo = top.next.classInfo;
                        classThis = top.classThis;
                        classSuper = top.classSuper;
                        break;
                    case "name":
                        const grandparent = top.next.next.next;
                        if ((grandparent == null ? void 0 : grandparent.kind) === "class-element") {
                            classInfo = grandparent.next.classInfo;
                            classThis = grandparent.classThis;
                            classSuper = grandparent.classSuper;
                        }
                        break;
                }
            }
            function enterClass(classInfo2) {
                top = { kind: "class", next: top, classInfo: classInfo2, savedPendingExpressions: pendingExpressions };
                pendingExpressions = void 0;
                updateState();
            }
            function exitClass() {
                Debug.assert((top == null ? void 0 : top.kind) === "class", "Incorrect value for top.kind.", () => `Expected top.kind to be 'class' but got '${top == null ? void 0 : top.kind}' instead.`);
                pendingExpressions = top.savedPendingExpressions;
                top = top.next;
                updateState();
            }
            function enterClassElement(node) {
                var _a, _b;
                Debug.assert((top == null ? void 0 : top.kind) === "class", "Incorrect value for top.kind.", () => `Expected top.kind to be 'class' but got '${top == null ? void 0 : top.kind}' instead.`);
                top = { kind: "class-element", next: top };
                if (isClassStaticBlockDeclaration(node) || isPropertyDeclaration(node) && hasStaticModifier(node)) {
                    top.classThis = (_a = top.next.classInfo) == null ? void 0 : _a.classThis;
                    top.classSuper = (_b = top.next.classInfo) == null ? void 0 : _b.classSuper;
                }
                updateState();
            }
            function exitClassElement() {
                var _a;
                Debug.assert((top == null ? void 0 : top.kind) === "class-element", "Incorrect value for top.kind.", () => `Expected top.kind to be 'class-element' but got '${top == null ? void 0 : top.kind}' instead.`);
                Debug.assert(((_a = top.next) == null ? void 0 : _a.kind) === "class", "Incorrect value for top.next.kind.", () => {
                    var _a2;
                    return `Expected top.next.kind to be 'class' but got '${(_a2 = top.next) == null ? void 0 : _a2.kind}' instead.`;
                });
                top = top.next;
                updateState();
            }
            function enterName() {
                Debug.assert((top == null ? void 0 : top.kind) === "class-element", "Incorrect value for top.kind.", () => `Expected top.kind to be 'class-element' but got '${top == null ? void 0 : top.kind}' instead.`);
                top = { kind: "name", next: top };
                updateState();
            }
            function exitName() {
                Debug.assert((top == null ? void 0 : top.kind) === "name", "Incorrect value for top.kind.", () => `Expected top.kind to be 'name' but got '${top == null ? void 0 : top.kind}' instead.`);
                top = top.next;
                updateState();
            }
            function enterOther() {
                if ((top == null ? void 0 : top.kind) === "other") {
                    Debug.assert(!pendingExpressions);
                    top.depth++;
                }
                else {
                    top = { kind: "other", next: top, depth: 0, savedPendingExpressions: pendingExpressions };
                    pendingExpressions = void 0;
                    updateState();
                }
            }
            function exitOther() {
                Debug.assert((top == null ? void 0 : top.kind) === "other", "Incorrect value for top.kind.", () => `Expected top.kind to be 'other' but got '${top == null ? void 0 : top.kind}' instead.`);
                if (top.depth > 0) {
                    Debug.assert(!pendingExpressions);
                    top.depth--;
                }
                else {
                    pendingExpressions = top.savedPendingExpressions;
                    top = top.next;
                    updateState();
                }
            }
            function shouldVisitNode(node) {
                return !!(node.transformFlags & 33554432 /* ContainsDecorators */) || !!classThis && !!(node.transformFlags & 16384 /* ContainsLexicalThis */) || !!classThis && !!classSuper && !!(node.transformFlags & 134217728 /* ContainsLexicalSuper */);
            }
            function visitor(node) {
                if (!shouldVisitNode(node)) {
                    return node;
                }
                switch (node.kind) {
                    case 170 /* Decorator */:
                        return Debug.fail("Use `modifierVisitor` instead.");
                    case 263 /* ClassDeclaration */:
                        return visitClassDeclaration(node);
                    case 231 /* ClassExpression */:
                        return visitClassExpression(node);
                    case 176 /* Constructor */:
                    case 172 /* PropertyDeclaration */:
                    case 175 /* ClassStaticBlockDeclaration */:
                        return Debug.fail("Not supported outside of a class. Use 'classElementVisitor' instead.");
                    case 169 /* Parameter */:
                        return visitParameterDeclaration(node);
                    case 226 /* BinaryExpression */:
                        return visitBinaryExpression(node, 
                        /*discarded*/
                        false);
                    case 303 /* PropertyAssignment */:
                        return visitPropertyAssignment(node);
                    case 260 /* VariableDeclaration */:
                        return visitVariableDeclaration(node);
                    case 208 /* BindingElement */:
                        return visitBindingElement(node);
                    case 277 /* ExportAssignment */:
                        return visitExportAssignment(node);
                    case 110 /* ThisKeyword */:
                        return visitThisExpression(node);
                    case 248 /* ForStatement */:
                        return visitForStatement(node);
                    case 244 /* ExpressionStatement */:
                        return visitExpressionStatement(node);
                    case 361 /* CommaListExpression */:
                        return visitCommaListExpression(node, 
                        /*discarded*/
                        false);
                    case 217 /* ParenthesizedExpression */:
                        return visitParenthesizedExpression(node, 
                        /*discarded*/
                        false);
                    case 360 /* PartiallyEmittedExpression */:
                        return visitPartiallyEmittedExpression(node, 
                        /*discarded*/
                        false);
                    case 213 /* CallExpression */:
                        return visitCallExpression(node);
                    case 215 /* TaggedTemplateExpression */:
                        return visitTaggedTemplateExpression(node);
                    case 224 /* PrefixUnaryExpression */:
                    case 225 /* PostfixUnaryExpression */:
                        return visitPreOrPostfixUnaryExpression(node, 
                        /*discarded*/
                        false);
                    case 211 /* PropertyAccessExpression */:
                        return visitPropertyAccessExpression(node);
                    case 212 /* ElementAccessExpression */:
                        return visitElementAccessExpression(node);
                    case 167 /* ComputedPropertyName */:
                        return visitComputedPropertyName(node);
                    case 174 /* MethodDeclaration */:
                    case 178 /* SetAccessor */:
                    case 177 /* GetAccessor */:
                    case 218 /* FunctionExpression */:
                    case 262 /* FunctionDeclaration */: {
                        enterOther();
                        const result = visitEachChild(node, fallbackVisitor, context);
                        exitOther();
                        return result;
                    }
                    default:
                        return visitEachChild(node, fallbackVisitor, context);
                }
            }
            function fallbackVisitor(node) {
                switch (node.kind) {
                    case 170 /* Decorator */:
                        return void 0;
                    default:
                        return visitor(node);
                }
            }
            function modifierVisitor(node) {
                switch (node.kind) {
                    case 170 /* Decorator */:
                        return void 0;
                    default:
                        return node;
                }
            }
            function classElementVisitor(node) {
                switch (node.kind) {
                    case 176 /* Constructor */:
                        return visitConstructorDeclaration(node);
                    case 174 /* MethodDeclaration */:
                        return visitMethodDeclaration(node);
                    case 177 /* GetAccessor */:
                        return visitGetAccessorDeclaration(node);
                    case 178 /* SetAccessor */:
                        return visitSetAccessorDeclaration(node);
                    case 172 /* PropertyDeclaration */:
                        return visitPropertyDeclaration(node);
                    case 175 /* ClassStaticBlockDeclaration */:
                        return visitClassStaticBlockDeclaration(node);
                    default:
                        return visitor(node);
                }
            }
            function discardedValueVisitor(node) {
                switch (node.kind) {
                    case 224 /* PrefixUnaryExpression */:
                    case 225 /* PostfixUnaryExpression */:
                        return visitPreOrPostfixUnaryExpression(node, 
                        /*discarded*/
                        true);
                    case 226 /* BinaryExpression */:
                        return visitBinaryExpression(node, 
                        /*discarded*/
                        true);
                    case 361 /* CommaListExpression */:
                        return visitCommaListExpression(node, 
                        /*discarded*/
                        true);
                    case 217 /* ParenthesizedExpression */:
                        return visitParenthesizedExpression(node, 
                        /*discarded*/
                        true);
                    default:
                        return visitor(node);
                }
            }
            function getHelperVariableName(node) {
                let declarationName = node.name && isIdentifier(node.name) && !isGeneratedIdentifier(node.name) ? idText(node.name) : node.name && isPrivateIdentifier(node.name) && !isGeneratedIdentifier(node.name) ? idText(node.name).slice(1) : node.name && isStringLiteral(node.name) && isIdentifierText(node.name.text, 99 /* ESNext */) ? node.name.text : isClassLike(node) ? "class" : "member";
                if (isGetAccessor(node))
                    declarationName = `get_${declarationName}`;
                if (isSetAccessor(node))
                    declarationName = `set_${declarationName}`;
                if (node.name && isPrivateIdentifier(node.name))
                    declarationName = `private_${declarationName}`;
                if (isStatic(node))
                    declarationName = `static_${declarationName}`;
                return "_" + declarationName;
            }
            function createHelperVariable(node, suffix) {
                return factory2.createUniqueName(`${getHelperVariableName(node)}_${suffix}`, 16 /* Optimistic */ | 8 /* ReservedInNestedScopes */);
            }
            function createLet(name, initializer) {
                return factory2.createVariableStatement(
                /*modifiers*/
                void 0, factory2.createVariableDeclarationList([
                    factory2.createVariableDeclaration(name, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, initializer)
                ], 1 /* Let */));
            }
            function createClassInfo(node) {
                const metadataReference = factory2.createUniqueName("_metadata", 16 /* Optimistic */ | 32 /* FileLevel */);
                let instanceMethodExtraInitializersName;
                let staticMethodExtraInitializersName;
                let hasStaticInitializers = false;
                let hasNonAmbientInstanceFields = false;
                let hasStaticPrivateClassElements = false;
                let classThis2;
                let pendingStaticInitializers;
                let pendingInstanceInitializers;
                if (nodeIsDecorated(
                /*useLegacyDecorators*/
                false, node)) {
                    const needsUniqueClassThis = some(node.members, (member) => (isPrivateIdentifierClassElementDeclaration(member) || isAutoAccessorPropertyDeclaration(member)) && hasStaticModifier(member));
                    classThis2 = factory2.createUniqueName("_classThis", needsUniqueClassThis ? 16 /* Optimistic */ | 8 /* ReservedInNestedScopes */ : 16 /* Optimistic */ | 32 /* FileLevel */);
                }
                for (const member of node.members) {
                    if (isMethodOrAccessor(member) && nodeOrChildIsDecorated(
                    /*useLegacyDecorators*/
                    false, member, node)) {
                        if (hasStaticModifier(member)) {
                            if (!staticMethodExtraInitializersName) {
                                staticMethodExtraInitializersName = factory2.createUniqueName("_staticExtraInitializers", 16 /* Optimistic */ | 32 /* FileLevel */);
                                const initializer = emitHelpers().createRunInitializersHelper(classThis2 ?? factory2.createThis(), staticMethodExtraInitializersName);
                                setSourceMapRange(initializer, node.name ?? moveRangePastDecorators(node));
                                pendingStaticInitializers ?? (pendingStaticInitializers = []);
                                pendingStaticInitializers.push(initializer);
                            }
                        }
                        else {
                            if (!instanceMethodExtraInitializersName) {
                                instanceMethodExtraInitializersName = factory2.createUniqueName("_instanceExtraInitializers", 16 /* Optimistic */ | 32 /* FileLevel */);
                                const initializer = emitHelpers().createRunInitializersHelper(factory2.createThis(), instanceMethodExtraInitializersName);
                                setSourceMapRange(initializer, node.name ?? moveRangePastDecorators(node));
                                pendingInstanceInitializers ?? (pendingInstanceInitializers = []);
                                pendingInstanceInitializers.push(initializer);
                            }
                            instanceMethodExtraInitializersName ?? (instanceMethodExtraInitializersName = factory2.createUniqueName("_instanceExtraInitializers", 16 /* Optimistic */ | 32 /* FileLevel */));
                        }
                    }
                    if (isClassStaticBlockDeclaration(member)) {
                        if (!isClassNamedEvaluationHelperBlock(member)) {
                            hasStaticInitializers = true;
                        }
                    }
                    else if (isPropertyDeclaration(member)) {
                        if (hasStaticModifier(member)) {
                            hasStaticInitializers || (hasStaticInitializers = !!member.initializer || hasDecorators(member));
                        }
                        else {
                            hasNonAmbientInstanceFields || (hasNonAmbientInstanceFields = !isAmbientPropertyDeclaration(member));
                        }
                    }
                    if ((isPrivateIdentifierClassElementDeclaration(member) || isAutoAccessorPropertyDeclaration(member)) && hasStaticModifier(member)) {
                        hasStaticPrivateClassElements = true;
                    }
                    if (staticMethodExtraInitializersName && instanceMethodExtraInitializersName && hasStaticInitializers && hasNonAmbientInstanceFields && hasStaticPrivateClassElements) {
                        break;
                    }
                }
                return {
                    class: node,
                    classThis: classThis2,
                    metadataReference,
                    instanceMethodExtraInitializersName,
                    staticMethodExtraInitializersName,
                    hasStaticInitializers,
                    hasNonAmbientInstanceFields,
                    hasStaticPrivateClassElements,
                    pendingStaticInitializers,
                    pendingInstanceInitializers
                };
            }
            function transformClassLike(node) {
                startLexicalEnvironment();
                if (!classHasDeclaredOrExplicitlyAssignedName(node) && classOrConstructorParameterIsDecorated(
                /*useLegacyDecorators*/
                false, node)) {
                    node = injectClassNamedEvaluationHelperBlockIfMissing(context, node, factory2.createStringLiteral(""));
                }
                const classReference = factory2.getLocalName(node, 
                /*allowComments*/
                false, 
                /*allowSourceMaps*/
                false, 
                /*ignoreAssignedName*/
                true);
                const classInfo2 = createClassInfo(node);
                const classDefinitionStatements = [];
                let leadingBlockStatements;
                let trailingBlockStatements;
                let syntheticConstructor;
                let heritageClauses;
                let shouldTransformPrivateStaticElementsInClass = false;
                const classDecorators = transformAllDecoratorsOfDeclaration(getAllDecoratorsOfClass(node));
                if (classDecorators) {
                    classInfo2.classDecoratorsName = factory2.createUniqueName("_classDecorators", 16 /* Optimistic */ | 32 /* FileLevel */);
                    classInfo2.classDescriptorName = factory2.createUniqueName("_classDescriptor", 16 /* Optimistic */ | 32 /* FileLevel */);
                    classInfo2.classExtraInitializersName = factory2.createUniqueName("_classExtraInitializers", 16 /* Optimistic */ | 32 /* FileLevel */);
                    Debug.assertIsDefined(classInfo2.classThis);
                    classDefinitionStatements.push(createLet(classInfo2.classDecoratorsName, factory2.createArrayLiteralExpression(classDecorators)), createLet(classInfo2.classDescriptorName), createLet(classInfo2.classExtraInitializersName, factory2.createArrayLiteralExpression()), createLet(classInfo2.classThis));
                    if (classInfo2.hasStaticPrivateClassElements) {
                        shouldTransformPrivateStaticElementsInClass = true;
                        shouldTransformPrivateStaticElementsInFile = true;
                    }
                }
                const extendsClause = getHeritageClause(node.heritageClauses, 96 /* ExtendsKeyword */);
                const extendsElement = extendsClause && firstOrUndefined(extendsClause.types);
                const extendsExpression = extendsElement && visitNode(extendsElement.expression, visitor, isExpression);
                if (extendsExpression) {
                    classInfo2.classSuper = factory2.createUniqueName("_classSuper", 16 /* Optimistic */ | 32 /* FileLevel */);
                    const unwrapped = skipOuterExpressions(extendsExpression);
                    const safeExtendsExpression = isClassExpression(unwrapped) && !unwrapped.name || isFunctionExpression(unwrapped) && !unwrapped.name || isArrowFunction(unwrapped) ? factory2.createComma(factory2.createNumericLiteral(0), extendsExpression) : extendsExpression;
                    classDefinitionStatements.push(createLet(classInfo2.classSuper, safeExtendsExpression));
                    const updatedExtendsElement = factory2.updateExpressionWithTypeArguments(extendsElement, classInfo2.classSuper, 
                    /*typeArguments*/
                    void 0);
                    const updatedExtendsClause = factory2.updateHeritageClause(extendsClause, [updatedExtendsElement]);
                    heritageClauses = factory2.createNodeArray([updatedExtendsClause]);
                }
                const renamedClassThis = classInfo2.classThis ?? factory2.createThis();
                enterClass(classInfo2);
                leadingBlockStatements = append(leadingBlockStatements, createMetadata(classInfo2.metadataReference, classInfo2.classSuper));
                let members = node.members;
                members = visitNodes2(members, (node2) => isConstructorDeclaration(node2) ? node2 : classElementVisitor(node2), isClassElement);
                members = visitNodes2(members, (node2) => isConstructorDeclaration(node2) ? classElementVisitor(node2) : node2, isClassElement);
                if (pendingExpressions) {
                    let outerThis;
                    for (let expression of pendingExpressions) {
                        expression = visitNode(expression, function thisVisitor(node2) {
                            if (!(node2.transformFlags & 16384 /* ContainsLexicalThis */)) {
                                return node2;
                            }
                            switch (node2.kind) {
                                case 110 /* ThisKeyword */:
                                    if (!outerThis) {
                                        outerThis = factory2.createUniqueName("_outerThis", 16 /* Optimistic */);
                                        classDefinitionStatements.unshift(createLet(outerThis, factory2.createThis()));
                                    }
                                    return outerThis;
                                default:
                                    return visitEachChild(node2, thisVisitor, context);
                            }
                        }, isExpression);
                        const statement = factory2.createExpressionStatement(expression);
                        leadingBlockStatements = append(leadingBlockStatements, statement);
                    }
                    pendingExpressions = void 0;
                }
                exitClass();
                if (some(classInfo2.pendingInstanceInitializers) && !getFirstConstructorWithBody(node)) {
                    const initializerStatements = prepareConstructor(node, classInfo2);
                    if (initializerStatements) {
                        const extendsClauseElement = getEffectiveBaseTypeNode(node);
                        const isDerivedClass = !!(extendsClauseElement && skipOuterExpressions(extendsClauseElement.expression).kind !== 106 /* NullKeyword */);
                        const constructorStatements = [];
                        if (isDerivedClass) {
                            const spreadArguments = factory2.createSpreadElement(factory2.createIdentifier("arguments"));
                            const superCall = factory2.createCallExpression(factory2.createSuper(), 
                            /*typeArguments*/
                            void 0, [spreadArguments]);
                            constructorStatements.push(factory2.createExpressionStatement(superCall));
                        }
                        addRange(constructorStatements, initializerStatements);
                        const constructorBody = factory2.createBlock(constructorStatements, 
                        /*multiLine*/
                        true);
                        syntheticConstructor = factory2.createConstructorDeclaration(
                        /*modifiers*/
                        void 0, [], constructorBody);
                    }
                }
                if (classInfo2.staticMethodExtraInitializersName) {
                    classDefinitionStatements.push(createLet(classInfo2.staticMethodExtraInitializersName, factory2.createArrayLiteralExpression()));
                }
                if (classInfo2.instanceMethodExtraInitializersName) {
                    classDefinitionStatements.push(createLet(classInfo2.instanceMethodExtraInitializersName, factory2.createArrayLiteralExpression()));
                }
                if (classInfo2.memberInfos) {
                    forEachEntry(classInfo2.memberInfos, (memberInfo, member) => {
                        if (isStatic(member)) {
                            classDefinitionStatements.push(createLet(memberInfo.memberDecoratorsName));
                            if (memberInfo.memberInitializersName) {
                                classDefinitionStatements.push(createLet(memberInfo.memberInitializersName, factory2.createArrayLiteralExpression()));
                            }
                            if (memberInfo.memberExtraInitializersName) {
                                classDefinitionStatements.push(createLet(memberInfo.memberExtraInitializersName, factory2.createArrayLiteralExpression()));
                            }
                            if (memberInfo.memberDescriptorName) {
                                classDefinitionStatements.push(createLet(memberInfo.memberDescriptorName));
                            }
                        }
                    });
                }
                if (classInfo2.memberInfos) {
                    forEachEntry(classInfo2.memberInfos, (memberInfo, member) => {
                        if (!isStatic(member)) {
                            classDefinitionStatements.push(createLet(memberInfo.memberDecoratorsName));
                            if (memberInfo.memberInitializersName) {
                                classDefinitionStatements.push(createLet(memberInfo.memberInitializersName, factory2.createArrayLiteralExpression()));
                            }
                            if (memberInfo.memberExtraInitializersName) {
                                classDefinitionStatements.push(createLet(memberInfo.memberExtraInitializersName, factory2.createArrayLiteralExpression()));
                            }
                            if (memberInfo.memberDescriptorName) {
                                classDefinitionStatements.push(createLet(memberInfo.memberDescriptorName));
                            }
                        }
                    });
                }
                leadingBlockStatements = addRange(leadingBlockStatements, classInfo2.staticNonFieldDecorationStatements);
                leadingBlockStatements = addRange(leadingBlockStatements, classInfo2.nonStaticNonFieldDecorationStatements);
                leadingBlockStatements = addRange(leadingBlockStatements, classInfo2.staticFieldDecorationStatements);
                leadingBlockStatements = addRange(leadingBlockStatements, classInfo2.nonStaticFieldDecorationStatements);
                if (classInfo2.classDescriptorName && classInfo2.classDecoratorsName && classInfo2.classExtraInitializersName && classInfo2.classThis) {
                    leadingBlockStatements ?? (leadingBlockStatements = []);
                    const valueProperty = factory2.createPropertyAssignment("value", renamedClassThis);
                    const classDescriptor = factory2.createObjectLiteralExpression([valueProperty]);
                    const classDescriptorAssignment = factory2.createAssignment(classInfo2.classDescriptorName, classDescriptor);
                    const classNameReference = factory2.createPropertyAccessExpression(renamedClassThis, "name");
                    const esDecorateHelper2 = emitHelpers().createESDecorateHelper(factory2.createNull(), classDescriptorAssignment, classInfo2.classDecoratorsName, { kind: "class", name: classNameReference, metadata: classInfo2.metadataReference }, factory2.createNull(), classInfo2.classExtraInitializersName);
                    const esDecorateStatement = factory2.createExpressionStatement(esDecorateHelper2);
                    setSourceMapRange(esDecorateStatement, moveRangePastDecorators(node));
                    leadingBlockStatements.push(esDecorateStatement);
                    const classDescriptorValueReference = factory2.createPropertyAccessExpression(classInfo2.classDescriptorName, "value");
                    const classThisAssignment = factory2.createAssignment(classInfo2.classThis, classDescriptorValueReference);
                    const classReferenceAssignment = factory2.createAssignment(classReference, classThisAssignment);
                    leadingBlockStatements.push(factory2.createExpressionStatement(classReferenceAssignment));
                }
                leadingBlockStatements.push(createSymbolMetadata(renamedClassThis, classInfo2.metadataReference));
                if (some(classInfo2.pendingStaticInitializers)) {
                    for (const initializer of classInfo2.pendingStaticInitializers) {
                        const initializerStatement = factory2.createExpressionStatement(initializer);
                        setSourceMapRange(initializerStatement, getSourceMapRange(initializer));
                        trailingBlockStatements = append(trailingBlockStatements, initializerStatement);
                    }
                    classInfo2.pendingStaticInitializers = void 0;
                }
                if (classInfo2.classExtraInitializersName) {
                    const runClassInitializersHelper = emitHelpers().createRunInitializersHelper(renamedClassThis, classInfo2.classExtraInitializersName);
                    const runClassInitializersStatement = factory2.createExpressionStatement(runClassInitializersHelper);
                    setSourceMapRange(runClassInitializersStatement, node.name ?? moveRangePastDecorators(node));
                    trailingBlockStatements = append(trailingBlockStatements, runClassInitializersStatement);
                }
                if (leadingBlockStatements && trailingBlockStatements && !classInfo2.hasStaticInitializers) {
                    addRange(leadingBlockStatements, trailingBlockStatements);
                    trailingBlockStatements = void 0;
                }
                const leadingStaticBlock = leadingBlockStatements && factory2.createClassStaticBlockDeclaration(factory2.createBlock(leadingBlockStatements, 
                /*multiLine*/
                true));
                if (leadingStaticBlock && shouldTransformPrivateStaticElementsInClass) {
                    setInternalEmitFlags(leadingStaticBlock, 32 /* TransformPrivateStaticElements */);
                }
                const trailingStaticBlock = trailingBlockStatements && factory2.createClassStaticBlockDeclaration(factory2.createBlock(trailingBlockStatements, 
                /*multiLine*/
                true));
                if (leadingStaticBlock || syntheticConstructor || trailingStaticBlock) {
                    const newMembers = [];
                    const existingNamedEvaluationHelperBlockIndex = members.findIndex(isClassNamedEvaluationHelperBlock);
                    if (leadingStaticBlock) {
                        addRange(newMembers, members, 0, existingNamedEvaluationHelperBlockIndex + 1);
                        newMembers.push(leadingStaticBlock);
                        addRange(newMembers, members, existingNamedEvaluationHelperBlockIndex + 1);
                    }
                    else {
                        addRange(newMembers, members);
                    }
                    if (syntheticConstructor) {
                        newMembers.push(syntheticConstructor);
                    }
                    if (trailingStaticBlock) {
                        newMembers.push(trailingStaticBlock);
                    }
                    members = setTextRange(factory2.createNodeArray(newMembers), members);
                }
                const lexicalEnvironment = endLexicalEnvironment();
                let classExpression;
                if (classDecorators) {
                    classExpression = factory2.createClassExpression(
                    /*modifiers*/
                    void 0, 
                    /*name*/
                    void 0, 
                    /*typeParameters*/
                    void 0, heritageClauses, members);
                    if (classInfo2.classThis) {
                        classExpression = injectClassThisAssignmentIfMissing(factory2, classExpression, classInfo2.classThis);
                    }
                    const classReferenceDeclaration = factory2.createVariableDeclaration(classReference, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, classExpression);
                    const classReferenceVarDeclList = factory2.createVariableDeclarationList([classReferenceDeclaration]);
                    const returnExpr = classInfo2.classThis ? factory2.createAssignment(classReference, classInfo2.classThis) : classReference;
                    classDefinitionStatements.push(factory2.createVariableStatement(
                    /*modifiers*/
                    void 0, classReferenceVarDeclList), factory2.createReturnStatement(returnExpr));
                }
                else {
                    classExpression = factory2.createClassExpression(
                    /*modifiers*/
                    void 0, node.name, 
                    /*typeParameters*/
                    void 0, heritageClauses, members);
                    classDefinitionStatements.push(factory2.createReturnStatement(classExpression));
                }
                if (shouldTransformPrivateStaticElementsInClass) {
                    addInternalEmitFlags(classExpression, 32 /* TransformPrivateStaticElements */);
                    for (const member of classExpression.members) {
                        if ((isPrivateIdentifierClassElementDeclaration(member) || isAutoAccessorPropertyDeclaration(member)) && hasStaticModifier(member)) {
                            addInternalEmitFlags(member, 32 /* TransformPrivateStaticElements */);
                        }
                    }
                }
                setOriginalNode(classExpression, node);
                return factory2.createImmediatelyInvokedArrowFunction(factory2.mergeLexicalEnvironment(classDefinitionStatements, lexicalEnvironment));
            }
            function isDecoratedClassLike(node) {
                return classOrConstructorParameterIsDecorated(
                /*useLegacyDecorators*/
                false, node) || childIsDecorated(
                /*useLegacyDecorators*/
                false, node);
            }
            function visitClassDeclaration(node) {
                if (isDecoratedClassLike(node)) {
                    const statements = [];
                    const originalClass = getOriginalNode(node, isClassLike) ?? node;
                    const className = originalClass.name ? factory2.createStringLiteralFromNode(originalClass.name) : factory2.createStringLiteral("default");
                    const isExport = hasSyntacticModifier(node, 32 /* Export */);
                    const isDefault = hasSyntacticModifier(node, 2048 /* Default */);
                    if (!node.name) {
                        node = injectClassNamedEvaluationHelperBlockIfMissing(context, node, className);
                    }
                    if (isExport && isDefault) {
                        const iife = transformClassLike(node);
                        if (node.name) {
                            const varDecl = factory2.createVariableDeclaration(factory2.getLocalName(node), 
                            /*exclamationToken*/
                            void 0, 
                            /*type*/
                            void 0, iife);
                            setOriginalNode(varDecl, node);
                            const varDecls = factory2.createVariableDeclarationList([varDecl], 1 /* Let */);
                            const varStatement = factory2.createVariableStatement(
                            /*modifiers*/
                            void 0, varDecls);
                            statements.push(varStatement);
                            const exportStatement = factory2.createExportDefault(factory2.getDeclarationName(node));
                            setOriginalNode(exportStatement, node);
                            setCommentRange(exportStatement, getCommentRange(node));
                            setSourceMapRange(exportStatement, moveRangePastDecorators(node));
                            statements.push(exportStatement);
                        }
                        else {
                            const exportStatement = factory2.createExportDefault(iife);
                            setOriginalNode(exportStatement, node);
                            setCommentRange(exportStatement, getCommentRange(node));
                            setSourceMapRange(exportStatement, moveRangePastDecorators(node));
                            statements.push(exportStatement);
                        }
                    }
                    else {
                        Debug.assertIsDefined(node.name, "A class declaration that is not a default export must have a name.");
                        const iife = transformClassLike(node);
                        const modifierVisitorNoExport = isExport ? (node2) => isExportModifier(node2) ? void 0 : modifierVisitor(node2) : modifierVisitor;
                        const modifiers = visitNodes2(node.modifiers, modifierVisitorNoExport, isModifier);
                        const declName = factory2.getLocalName(node, 
                        /*allowComments*/
                        false, 
                        /*allowSourceMaps*/
                        true);
                        const varDecl = factory2.createVariableDeclaration(declName, 
                        /*exclamationToken*/
                        void 0, 
                        /*type*/
                        void 0, iife);
                        setOriginalNode(varDecl, node);
                        const varDecls = factory2.createVariableDeclarationList([varDecl], 1 /* Let */);
                        const varStatement = factory2.createVariableStatement(modifiers, varDecls);
                        setOriginalNode(varStatement, node);
                        setCommentRange(varStatement, getCommentRange(node));
                        statements.push(varStatement);
                        if (isExport) {
                            const exportStatement = factory2.createExternalModuleExport(declName);
                            setOriginalNode(exportStatement, node);
                            statements.push(exportStatement);
                        }
                    }
                    return singleOrMany(statements);
                }
                else {
                    const modifiers = visitNodes2(node.modifiers, modifierVisitor, isModifier);
                    const heritageClauses = visitNodes2(node.heritageClauses, visitor, isHeritageClause);
                    enterClass(
                    /*classInfo*/
                    void 0);
                    const members = visitNodes2(node.members, classElementVisitor, isClassElement);
                    exitClass();
                    return factory2.updateClassDeclaration(node, modifiers, node.name, 
                    /*typeParameters*/
                    void 0, heritageClauses, members);
                }
            }
            function visitClassExpression(node) {
                if (isDecoratedClassLike(node)) {
                    const iife = transformClassLike(node);
                    setOriginalNode(iife, node);
                    return iife;
                }
                else {
                    const modifiers = visitNodes2(node.modifiers, modifierVisitor, isModifier);
                    const heritageClauses = visitNodes2(node.heritageClauses, visitor, isHeritageClause);
                    enterClass(
                    /*classInfo*/
                    void 0);
                    const members = visitNodes2(node.members, classElementVisitor, isClassElement);
                    exitClass();
                    return factory2.updateClassExpression(node, modifiers, node.name, 
                    /*typeParameters*/
                    void 0, heritageClauses, members);
                }
            }
            function prepareConstructor(_parent, classInfo2) {
                if (some(classInfo2.pendingInstanceInitializers)) {
                    const statements = [];
                    statements.push(factory2.createExpressionStatement(factory2.inlineExpressions(classInfo2.pendingInstanceInitializers)));
                    classInfo2.pendingInstanceInitializers = void 0;
                    return statements;
                }
            }
            function transformConstructorBodyWorker(statementsOut, statementsIn, statementOffset, superPath, superPathDepth, initializerStatements) {
                const superStatementIndex = superPath[superPathDepth];
                const superStatement = statementsIn[superStatementIndex];
                addRange(statementsOut, visitNodes2(statementsIn, visitor, isStatement, statementOffset, superStatementIndex - statementOffset));
                if (isTryStatement(superStatement)) {
                    const tryBlockStatements = [];
                    transformConstructorBodyWorker(tryBlockStatements, superStatement.tryBlock.statements, 
                    /*statementOffset*/
                    0, superPath, superPathDepth + 1, initializerStatements);
                    const tryBlockStatementsArray = factory2.createNodeArray(tryBlockStatements);
                    setTextRange(tryBlockStatementsArray, superStatement.tryBlock.statements);
                    statementsOut.push(factory2.updateTryStatement(superStatement, factory2.updateBlock(superStatement.tryBlock, tryBlockStatements), visitNode(superStatement.catchClause, visitor, isCatchClause), visitNode(superStatement.finallyBlock, visitor, isBlock)));
                }
                else {
                    addRange(statementsOut, visitNodes2(statementsIn, visitor, isStatement, superStatementIndex, 1));
                    addRange(statementsOut, initializerStatements);
                }
                addRange(statementsOut, visitNodes2(statementsIn, visitor, isStatement, superStatementIndex + 1));
            }
            function visitConstructorDeclaration(node) {
                enterClassElement(node);
                const modifiers = visitNodes2(node.modifiers, modifierVisitor, isModifier);
                const parameters = visitNodes2(node.parameters, visitor, isParameter);
                let body;
                if (node.body && classInfo) {
                    const initializerStatements = prepareConstructor(classInfo.class, classInfo);
                    if (initializerStatements) {
                        const statements = [];
                        const nonPrologueStart = factory2.copyPrologue(node.body.statements, statements, 
                        /*ensureUseStrict*/
                        false, visitor);
                        const superStatementIndices = findSuperStatementIndexPath(node.body.statements, nonPrologueStart);
                        if (superStatementIndices.length > 0) {
                            transformConstructorBodyWorker(statements, node.body.statements, nonPrologueStart, superStatementIndices, 0, initializerStatements);
                        }
                        else {
                            addRange(statements, initializerStatements);
                            addRange(statements, visitNodes2(node.body.statements, visitor, isStatement));
                        }
                        body = factory2.createBlock(statements, 
                        /*multiLine*/
                        true);
                        setOriginalNode(body, node.body);
                        setTextRange(body, node.body);
                    }
                }
                body ?? (body = visitNode(node.body, visitor, isBlock));
                exitClassElement();
                return factory2.updateConstructorDeclaration(node, modifiers, parameters, body);
            }
            function finishClassElement(updated, original) {
                if (updated !== original) {
                    setCommentRange(updated, original);
                    setSourceMapRange(updated, moveRangePastDecorators(original));
                }
                return updated;
            }
            function partialTransformClassElement(member, classInfo2, createDescriptor) {
                let referencedName;
                let name;
                let initializersName;
                let extraInitializersName;
                let thisArg;
                let descriptorName;
                if (!classInfo2) {
                    const modifiers2 = visitNodes2(member.modifiers, modifierVisitor, isModifier);
                    enterName();
                    name = visitPropertyName(member.name);
                    exitName();
                    return { modifiers: modifiers2, referencedName, name, initializersName, descriptorName, thisArg };
                }
                const memberDecorators = transformAllDecoratorsOfDeclaration(getAllDecoratorsOfClassElement(member, classInfo2.class, 
                /*useLegacyDecorators*/
                false));
                const modifiers = visitNodes2(member.modifiers, modifierVisitor, isModifier);
                if (memberDecorators) {
                    const memberDecoratorsName = createHelperVariable(member, "decorators");
                    const memberDecoratorsArray = factory2.createArrayLiteralExpression(memberDecorators);
                    const memberDecoratorsAssignment = factory2.createAssignment(memberDecoratorsName, memberDecoratorsArray);
                    const memberInfo = { memberDecoratorsName };
                    classInfo2.memberInfos ?? (classInfo2.memberInfos = /* @__PURE__ */ new Map());
                    classInfo2.memberInfos.set(member, memberInfo);
                    pendingExpressions ?? (pendingExpressions = []);
                    pendingExpressions.push(memberDecoratorsAssignment);
                    const statements = isMethodOrAccessor(member) || isAutoAccessorPropertyDeclaration(member) ? isStatic(member) ? classInfo2.staticNonFieldDecorationStatements ?? (classInfo2.staticNonFieldDecorationStatements = []) : classInfo2.nonStaticNonFieldDecorationStatements ?? (classInfo2.nonStaticNonFieldDecorationStatements = []) : isPropertyDeclaration(member) && !isAutoAccessorPropertyDeclaration(member) ? isStatic(member) ? classInfo2.staticFieldDecorationStatements ?? (classInfo2.staticFieldDecorationStatements = []) : classInfo2.nonStaticFieldDecorationStatements ?? (classInfo2.nonStaticFieldDecorationStatements = []) : Debug.fail();
                    const kind = isGetAccessorDeclaration(member) ? "getter" : isSetAccessorDeclaration(member) ? "setter" : isMethodDeclaration(member) ? "method" : isAutoAccessorPropertyDeclaration(member) ? "accessor" : isPropertyDeclaration(member) ? "field" : Debug.fail();
                    let propertyName;
                    if (isIdentifier(member.name) || isPrivateIdentifier(member.name)) {
                        propertyName = { computed: false, name: member.name };
                    }
                    else if (isPropertyNameLiteral(member.name)) {
                        propertyName = { computed: true, name: factory2.createStringLiteralFromNode(member.name) };
                    }
                    else {
                        const expression = member.name.expression;
                        if (isPropertyNameLiteral(expression) && !isIdentifier(expression)) {
                            propertyName = { computed: true, name: factory2.createStringLiteralFromNode(expression) };
                        }
                        else {
                            enterName();
                            ({ referencedName, name } = visitReferencedPropertyName(member.name));
                            propertyName = { computed: true, name: referencedName };
                            exitName();
                        }
                    }
                    const context2 = {
                        kind,
                        name: propertyName,
                        static: isStatic(member),
                        private: isPrivateIdentifier(member.name),
                        access: {
                            // 15.7.3 CreateDecoratorAccessObject (kind, name)
                            // 2. If _kind_ is ~field~, ~method~, ~accessor~, or ~getter~, then ...
                            get: isPropertyDeclaration(member) || isGetAccessorDeclaration(member) || isMethodDeclaration(member),
                            // 3. If _kind_ is ~field~, ~accessor~, or ~setter~, then ...
                            set: isPropertyDeclaration(member) || isSetAccessorDeclaration(member)
                        },
                        metadata: classInfo2.metadataReference
                    };
                    if (isMethodOrAccessor(member)) {
                        const methodExtraInitializersName = isStatic(member) ? classInfo2.staticMethodExtraInitializersName : classInfo2.instanceMethodExtraInitializersName;
                        Debug.assertIsDefined(methodExtraInitializersName);
                        let descriptor;
                        if (isPrivateIdentifierClassElementDeclaration(member) && createDescriptor) {
                            descriptor = createDescriptor(member, visitNodes2(modifiers, (node) => tryCast(node, isAsyncModifier), isModifier));
                            memberInfo.memberDescriptorName = descriptorName = createHelperVariable(member, "descriptor");
                            descriptor = factory2.createAssignment(descriptorName, descriptor);
                        }
                        const esDecorateExpression = emitHelpers().createESDecorateHelper(factory2.createThis(), descriptor ?? factory2.createNull(), memberDecoratorsName, context2, factory2.createNull(), methodExtraInitializersName);
                        const esDecorateStatement = factory2.createExpressionStatement(esDecorateExpression);
                        setSourceMapRange(esDecorateStatement, moveRangePastDecorators(member));
                        statements.push(esDecorateStatement);
                    }
                    else if (isPropertyDeclaration(member)) {
                        initializersName = memberInfo.memberInitializersName ?? (memberInfo.memberInitializersName = createHelperVariable(member, "initializers"));
                        extraInitializersName = memberInfo.memberExtraInitializersName ?? (memberInfo.memberExtraInitializersName = createHelperVariable(member, "extraInitializers"));
                        if (isStatic(member)) {
                            thisArg = classInfo2.classThis;
                        }
                        let descriptor;
                        if (isPrivateIdentifierClassElementDeclaration(member) && hasAccessorModifier(member) && createDescriptor) {
                            descriptor = createDescriptor(member, 
                            /*modifiers*/
                            void 0);
                            memberInfo.memberDescriptorName = descriptorName = createHelperVariable(member, "descriptor");
                            descriptor = factory2.createAssignment(descriptorName, descriptor);
                        }
                        const esDecorateExpression = emitHelpers().createESDecorateHelper(isAutoAccessorPropertyDeclaration(member) ? factory2.createThis() : factory2.createNull(), descriptor ?? factory2.createNull(), memberDecoratorsName, context2, initializersName, extraInitializersName);
                        const esDecorateStatement = factory2.createExpressionStatement(esDecorateExpression);
                        setSourceMapRange(esDecorateStatement, moveRangePastDecorators(member));
                        statements.push(esDecorateStatement);
                    }
                }
                if (name === void 0) {
                    enterName();
                    name = visitPropertyName(member.name);
                    exitName();
                }
                if (!some(modifiers) && (isMethodDeclaration(member) || isPropertyDeclaration(member))) {
                    setEmitFlags(name, 1024 /* NoLeadingComments */);
                }
                return { modifiers, referencedName, name, initializersName, extraInitializersName, descriptorName, thisArg };
            }
            function visitMethodDeclaration(node) {
                enterClassElement(node);
                const { modifiers, name, descriptorName } = partialTransformClassElement(node, classInfo, createMethodDescriptorObject);
                if (descriptorName) {
                    exitClassElement();
                    return finishClassElement(createMethodDescriptorForwarder(modifiers, name, descriptorName), node);
                }
                else {
                    const parameters = visitNodes2(node.parameters, visitor, isParameter);
                    const body = visitNode(node.body, visitor, isBlock);
                    exitClassElement();
                    return finishClassElement(factory2.updateMethodDeclaration(node, modifiers, node.asteriskToken, name, 
                    /*questionToken*/
                    void 0, 
                    /*typeParameters*/
                    void 0, parameters, 
                    /*type*/
                    void 0, body), node);
                }
            }
            function visitGetAccessorDeclaration(node) {
                enterClassElement(node);
                const { modifiers, name, descriptorName } = partialTransformClassElement(node, classInfo, createGetAccessorDescriptorObject);
                if (descriptorName) {
                    exitClassElement();
                    return finishClassElement(createGetAccessorDescriptorForwarder(modifiers, name, descriptorName), node);
                }
                else {
                    const parameters = visitNodes2(node.parameters, visitor, isParameter);
                    const body = visitNode(node.body, visitor, isBlock);
                    exitClassElement();
                    return finishClassElement(factory2.updateGetAccessorDeclaration(node, modifiers, name, parameters, 
                    /*type*/
                    void 0, body), node);
                }
            }
            function visitSetAccessorDeclaration(node) {
                enterClassElement(node);
                const { modifiers, name, descriptorName } = partialTransformClassElement(node, classInfo, createSetAccessorDescriptorObject);
                if (descriptorName) {
                    exitClassElement();
                    return finishClassElement(createSetAccessorDescriptorForwarder(modifiers, name, descriptorName), node);
                }
                else {
                    const parameters = visitNodes2(node.parameters, visitor, isParameter);
                    const body = visitNode(node.body, visitor, isBlock);
                    exitClassElement();
                    return finishClassElement(factory2.updateSetAccessorDeclaration(node, modifiers, name, parameters, body), node);
                }
            }
            function visitClassStaticBlockDeclaration(node) {
                enterClassElement(node);
                let result;
                if (isClassNamedEvaluationHelperBlock(node)) {
                    result = visitEachChild(node, visitor, context);
                }
                else if (isClassThisAssignmentBlock(node)) {
                    const savedClassThis = classThis;
                    classThis = void 0;
                    result = visitEachChild(node, visitor, context);
                    classThis = savedClassThis;
                }
                else {
                    node = visitEachChild(node, visitor, context);
                    result = node;
                    if (classInfo) {
                        classInfo.hasStaticInitializers = true;
                        if (some(classInfo.pendingStaticInitializers)) {
                            const statements = [];
                            for (const initializer of classInfo.pendingStaticInitializers) {
                                const initializerStatement = factory2.createExpressionStatement(initializer);
                                setSourceMapRange(initializerStatement, getSourceMapRange(initializer));
                                statements.push(initializerStatement);
                            }
                            const body = factory2.createBlock(statements, 
                            /*multiLine*/
                            true);
                            const staticBlock = factory2.createClassStaticBlockDeclaration(body);
                            result = [staticBlock, result];
                            classInfo.pendingStaticInitializers = void 0;
                        }
                    }
                }
                exitClassElement();
                return result;
            }
            function visitPropertyDeclaration(node) {
                if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                    node = transformNamedEvaluation(context, node, canIgnoreEmptyStringLiteralInAssignedName(node.initializer));
                }
                enterClassElement(node);
                Debug.assert(!isAmbientPropertyDeclaration(node), "Not yet implemented.");
                const { modifiers, name, initializersName, extraInitializersName, descriptorName, thisArg } = partialTransformClassElement(node, classInfo, hasAccessorModifier(node) ? createAccessorPropertyDescriptorObject : void 0);
                startLexicalEnvironment();
                let initializer = visitNode(node.initializer, visitor, isExpression);
                if (initializersName) {
                    initializer = emitHelpers().createRunInitializersHelper(thisArg ?? factory2.createThis(), initializersName, initializer ?? factory2.createVoidZero());
                }
                if (isStatic(node) && classInfo && initializer) {
                    classInfo.hasStaticInitializers = true;
                }
                const declarations = endLexicalEnvironment();
                if (some(declarations)) {
                    initializer = factory2.createImmediatelyInvokedArrowFunction([
                        ...declarations,
                        factory2.createReturnStatement(initializer)
                    ]);
                }
                if (classInfo) {
                    if (isStatic(node)) {
                        initializer = injectPendingInitializers(classInfo, 
                        /*isStatic*/
                        true, initializer);
                        if (extraInitializersName) {
                            classInfo.pendingStaticInitializers ?? (classInfo.pendingStaticInitializers = []);
                            classInfo.pendingStaticInitializers.push(emitHelpers().createRunInitializersHelper(classInfo.classThis ?? factory2.createThis(), extraInitializersName));
                        }
                    }
                    else {
                        initializer = injectPendingInitializers(classInfo, 
                        /*isStatic*/
                        false, initializer);
                        if (extraInitializersName) {
                            classInfo.pendingInstanceInitializers ?? (classInfo.pendingInstanceInitializers = []);
                            classInfo.pendingInstanceInitializers.push(emitHelpers().createRunInitializersHelper(factory2.createThis(), extraInitializersName));
                        }
                    }
                }
                exitClassElement();
                if (hasAccessorModifier(node) && descriptorName) {
                    const commentRange = getCommentRange(node);
                    const sourceMapRange = getSourceMapRange(node);
                    const name2 = node.name;
                    let getterName = name2;
                    let setterName = name2;
                    if (isComputedPropertyName(name2) && !isSimpleInlineableExpression(name2.expression)) {
                        const cacheAssignment = findComputedPropertyNameCacheAssignment(name2);
                        if (cacheAssignment) {
                            getterName = factory2.updateComputedPropertyName(name2, visitNode(name2.expression, visitor, isExpression));
                            setterName = factory2.updateComputedPropertyName(name2, cacheAssignment.left);
                        }
                        else {
                            const temp = factory2.createTempVariable(hoistVariableDeclaration);
                            setSourceMapRange(temp, name2.expression);
                            const expression = visitNode(name2.expression, visitor, isExpression);
                            const assignment = factory2.createAssignment(temp, expression);
                            setSourceMapRange(assignment, name2.expression);
                            getterName = factory2.updateComputedPropertyName(name2, assignment);
                            setterName = factory2.updateComputedPropertyName(name2, temp);
                        }
                    }
                    const modifiersWithoutAccessor = visitNodes2(modifiers, (node2) => node2.kind !== 129 /* AccessorKeyword */ ? node2 : void 0, isModifier);
                    const backingField = createAccessorPropertyBackingField(factory2, node, modifiersWithoutAccessor, initializer);
                    setOriginalNode(backingField, node);
                    setEmitFlags(backingField, 3072 /* NoComments */);
                    setSourceMapRange(backingField, sourceMapRange);
                    setSourceMapRange(backingField.name, node.name);
                    const getter = createGetAccessorDescriptorForwarder(modifiersWithoutAccessor, getterName, descriptorName);
                    setOriginalNode(getter, node);
                    setCommentRange(getter, commentRange);
                    setSourceMapRange(getter, sourceMapRange);
                    const setter = createSetAccessorDescriptorForwarder(modifiersWithoutAccessor, setterName, descriptorName);
                    setOriginalNode(setter, node);
                    setEmitFlags(setter, 3072 /* NoComments */);
                    setSourceMapRange(setter, sourceMapRange);
                    return [backingField, getter, setter];
                }
                return finishClassElement(factory2.updatePropertyDeclaration(node, modifiers, name, 
                /*questionOrExclamationToken*/
                void 0, 
                /*type*/
                void 0, initializer), node);
            }
            function visitThisExpression(node) {
                return classThis ?? node;
            }
            function visitCallExpression(node) {
                if (isSuperProperty(node.expression) && classThis) {
                    const expression = visitNode(node.expression, visitor, isExpression);
                    const argumentsList = visitNodes2(node.arguments, visitor, isExpression);
                    const invocation = factory2.createFunctionCallCall(expression, classThis, argumentsList);
                    setOriginalNode(invocation, node);
                    setTextRange(invocation, node);
                    return invocation;
                }
                return visitEachChild(node, visitor, context);
            }
            function visitTaggedTemplateExpression(node) {
                if (isSuperProperty(node.tag) && classThis) {
                    const tag = visitNode(node.tag, visitor, isExpression);
                    const boundTag = factory2.createFunctionBindCall(tag, classThis, []);
                    setOriginalNode(boundTag, node);
                    setTextRange(boundTag, node);
                    const template = visitNode(node.template, visitor, isTemplateLiteral);
                    return factory2.updateTaggedTemplateExpression(node, boundTag, 
                    /*typeArguments*/
                    void 0, template);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitPropertyAccessExpression(node) {
                if (isSuperProperty(node) && isIdentifier(node.name) && classThis && classSuper) {
                    const propertyName = factory2.createStringLiteralFromNode(node.name);
                    const superProperty = factory2.createReflectGetCall(classSuper, propertyName, classThis);
                    setOriginalNode(superProperty, node.expression);
                    setTextRange(superProperty, node.expression);
                    return superProperty;
                }
                return visitEachChild(node, visitor, context);
            }
            function visitElementAccessExpression(node) {
                if (isSuperProperty(node) && classThis && classSuper) {
                    const propertyName = visitNode(node.argumentExpression, visitor, isExpression);
                    const superProperty = factory2.createReflectGetCall(classSuper, propertyName, classThis);
                    setOriginalNode(superProperty, node.expression);
                    setTextRange(superProperty, node.expression);
                    return superProperty;
                }
                return visitEachChild(node, visitor, context);
            }
            function visitParameterDeclaration(node) {
                if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                    node = transformNamedEvaluation(context, node, canIgnoreEmptyStringLiteralInAssignedName(node.initializer));
                }
                const updated = factory2.updateParameterDeclaration(node, 
                /*modifiers*/
                void 0, node.dotDotDotToken, visitNode(node.name, visitor, isBindingName), 
                /*questionToken*/
                void 0, 
                /*type*/
                void 0, visitNode(node.initializer, visitor, isExpression));
                if (updated !== node) {
                    setCommentRange(updated, node);
                    setTextRange(updated, moveRangePastModifiers(node));
                    setSourceMapRange(updated, moveRangePastModifiers(node));
                    setEmitFlags(updated.name, 64 /* NoTrailingSourceMap */);
                }
                return updated;
            }
            function isAnonymousClassNeedingAssignedName(node) {
                return isClassExpression(node) && !node.name && isDecoratedClassLike(node);
            }
            function canIgnoreEmptyStringLiteralInAssignedName(node) {
                const innerExpression = skipOuterExpressions(node);
                return isClassExpression(innerExpression) && !innerExpression.name && !classOrConstructorParameterIsDecorated(
                /*useLegacyDecorators*/
                false, innerExpression);
            }
            function visitForStatement(node) {
                return factory2.updateForStatement(node, visitNode(node.initializer, discardedValueVisitor, isForInitializer), visitNode(node.condition, visitor, isExpression), visitNode(node.incrementor, discardedValueVisitor, isExpression), visitIterationBody(node.statement, visitor, context));
            }
            function visitExpressionStatement(node) {
                return visitEachChild(node, discardedValueVisitor, context);
            }
            function visitBinaryExpression(node, discarded) {
                if (isDestructuringAssignment(node)) {
                    const left = visitAssignmentPattern(node.left);
                    const right = visitNode(node.right, visitor, isExpression);
                    return factory2.updateBinaryExpression(node, left, node.operatorToken, right);
                }
                if (isAssignmentExpression(node)) {
                    if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                        node = transformNamedEvaluation(context, node, canIgnoreEmptyStringLiteralInAssignedName(node.right));
                        return visitEachChild(node, visitor, context);
                    }
                    if (isSuperProperty(node.left) && classThis && classSuper) {
                        let setterName = isElementAccessExpression(node.left) ? visitNode(node.left.argumentExpression, visitor, isExpression) : isIdentifier(node.left.name) ? factory2.createStringLiteralFromNode(node.left.name) : void 0;
                        if (setterName) {
                            let expression = visitNode(node.right, visitor, isExpression);
                            if (isCompoundAssignment(node.operatorToken.kind)) {
                                let getterName = setterName;
                                if (!isSimpleInlineableExpression(setterName)) {
                                    getterName = factory2.createTempVariable(hoistVariableDeclaration);
                                    setterName = factory2.createAssignment(getterName, setterName);
                                }
                                const superPropertyGet = factory2.createReflectGetCall(classSuper, getterName, classThis);
                                setOriginalNode(superPropertyGet, node.left);
                                setTextRange(superPropertyGet, node.left);
                                expression = factory2.createBinaryExpression(superPropertyGet, getNonAssignmentOperatorForCompoundAssignment(node.operatorToken.kind), expression);
                                setTextRange(expression, node);
                            }
                            const temp = discarded ? void 0 : factory2.createTempVariable(hoistVariableDeclaration);
                            if (temp) {
                                expression = factory2.createAssignment(temp, expression);
                                setTextRange(temp, node);
                            }
                            expression = factory2.createReflectSetCall(classSuper, setterName, expression, classThis);
                            setOriginalNode(expression, node);
                            setTextRange(expression, node);
                            if (temp) {
                                expression = factory2.createComma(expression, temp);
                                setTextRange(expression, node);
                            }
                            return expression;
                        }
                    }
                }
                if (node.operatorToken.kind === 28 /* CommaToken */) {
                    const left = visitNode(node.left, discardedValueVisitor, isExpression);
                    const right = visitNode(node.right, discarded ? discardedValueVisitor : visitor, isExpression);
                    return factory2.updateBinaryExpression(node, left, node.operatorToken, right);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitPreOrPostfixUnaryExpression(node, discarded) {
                if (node.operator === 46 /* PlusPlusToken */ || node.operator === 47 /* MinusMinusToken */) {
                    const operand = skipParentheses(node.operand);
                    if (isSuperProperty(operand) && classThis && classSuper) {
                        let setterName = isElementAccessExpression(operand) ? visitNode(operand.argumentExpression, visitor, isExpression) : isIdentifier(operand.name) ? factory2.createStringLiteralFromNode(operand.name) : void 0;
                        if (setterName) {
                            let getterName = setterName;
                            if (!isSimpleInlineableExpression(setterName)) {
                                getterName = factory2.createTempVariable(hoistVariableDeclaration);
                                setterName = factory2.createAssignment(getterName, setterName);
                            }
                            let expression = factory2.createReflectGetCall(classSuper, getterName, classThis);
                            setOriginalNode(expression, node);
                            setTextRange(expression, node);
                            const temp = discarded ? void 0 : factory2.createTempVariable(hoistVariableDeclaration);
                            expression = expandPreOrPostfixIncrementOrDecrementExpression(factory2, node, expression, hoistVariableDeclaration, temp);
                            expression = factory2.createReflectSetCall(classSuper, setterName, expression, classThis);
                            setOriginalNode(expression, node);
                            setTextRange(expression, node);
                            if (temp) {
                                expression = factory2.createComma(expression, temp);
                                setTextRange(expression, node);
                            }
                            return expression;
                        }
                    }
                }
                return visitEachChild(node, visitor, context);
            }
            function visitCommaListExpression(node, discarded) {
                const elements = discarded ? visitCommaListElements(node.elements, discardedValueVisitor) : visitCommaListElements(node.elements, visitor, discardedValueVisitor);
                return factory2.updateCommaListExpression(node, elements);
            }
            function visitReferencedPropertyName(node) {
                if (isPropertyNameLiteral(node) || isPrivateIdentifier(node)) {
                    const referencedName2 = factory2.createStringLiteralFromNode(node);
                    const name2 = visitNode(node, visitor, isPropertyName);
                    return { referencedName: referencedName2, name: name2 };
                }
                if (isPropertyNameLiteral(node.expression) && !isIdentifier(node.expression)) {
                    const referencedName2 = factory2.createStringLiteralFromNode(node.expression);
                    const name2 = visitNode(node, visitor, isPropertyName);
                    return { referencedName: referencedName2, name: name2 };
                }
                const referencedName = factory2.getGeneratedNameForNode(node);
                hoistVariableDeclaration(referencedName);
                const key = emitHelpers().createPropKeyHelper(visitNode(node.expression, visitor, isExpression));
                const assignment = factory2.createAssignment(referencedName, key);
                const name = factory2.updateComputedPropertyName(node, injectPendingExpressions(assignment));
                return { referencedName, name };
            }
            function visitPropertyName(node) {
                if (isComputedPropertyName(node)) {
                    return visitComputedPropertyName(node);
                }
                return visitNode(node, visitor, isPropertyName);
            }
            function visitComputedPropertyName(node) {
                let expression = visitNode(node.expression, visitor, isExpression);
                if (!isSimpleInlineableExpression(expression)) {
                    expression = injectPendingExpressions(expression);
                }
                return factory2.updateComputedPropertyName(node, expression);
            }
            function visitPropertyAssignment(node) {
                if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                    node = transformNamedEvaluation(context, node, canIgnoreEmptyStringLiteralInAssignedName(node.initializer));
                }
                return visitEachChild(node, visitor, context);
            }
            function visitVariableDeclaration(node) {
                if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                    node = transformNamedEvaluation(context, node, canIgnoreEmptyStringLiteralInAssignedName(node.initializer));
                }
                return visitEachChild(node, visitor, context);
            }
            function visitBindingElement(node) {
                if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                    node = transformNamedEvaluation(context, node, canIgnoreEmptyStringLiteralInAssignedName(node.initializer));
                }
                return visitEachChild(node, visitor, context);
            }
            function visitDestructuringAssignmentTarget(node) {
                if (isObjectLiteralExpression(node) || isArrayLiteralExpression(node)) {
                    return visitAssignmentPattern(node);
                }
                if (isSuperProperty(node) && classThis && classSuper) {
                    const propertyName = isElementAccessExpression(node) ? visitNode(node.argumentExpression, visitor, isExpression) : isIdentifier(node.name) ? factory2.createStringLiteralFromNode(node.name) : void 0;
                    if (propertyName) {
                        const paramName = factory2.createTempVariable(
                        /*recordTempVariable*/
                        void 0);
                        const expression = factory2.createAssignmentTargetWrapper(paramName, factory2.createReflectSetCall(classSuper, propertyName, paramName, classThis));
                        setOriginalNode(expression, node);
                        setTextRange(expression, node);
                        return expression;
                    }
                }
                return visitEachChild(node, visitor, context);
            }
            function visitAssignmentElement(node) {
                if (isAssignmentExpression(node, 
                /*excludeCompoundAssignment*/
                true)) {
                    if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                        node = transformNamedEvaluation(context, node, canIgnoreEmptyStringLiteralInAssignedName(node.right));
                    }
                    const assignmentTarget = visitDestructuringAssignmentTarget(node.left);
                    const initializer = visitNode(node.right, visitor, isExpression);
                    return factory2.updateBinaryExpression(node, assignmentTarget, node.operatorToken, initializer);
                }
                else {
                    return visitDestructuringAssignmentTarget(node);
                }
            }
            function visitAssignmentRestElement(node) {
                if (isLeftHandSideExpression(node.expression)) {
                    const expression = visitDestructuringAssignmentTarget(node.expression);
                    return factory2.updateSpreadElement(node, expression);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitArrayAssignmentElement(node) {
                Debug.assertNode(node, isArrayBindingOrAssignmentElement);
                if (isSpreadElement(node))
                    return visitAssignmentRestElement(node);
                if (!isOmittedExpression(node))
                    return visitAssignmentElement(node);
                return visitEachChild(node, visitor, context);
            }
            function visitAssignmentProperty(node) {
                const name = visitNode(node.name, visitor, isPropertyName);
                if (isAssignmentExpression(node.initializer, 
                /*excludeCompoundAssignment*/
                true)) {
                    const assignmentElement = visitAssignmentElement(node.initializer);
                    return factory2.updatePropertyAssignment(node, name, assignmentElement);
                }
                if (isLeftHandSideExpression(node.initializer)) {
                    const assignmentElement = visitDestructuringAssignmentTarget(node.initializer);
                    return factory2.updatePropertyAssignment(node, name, assignmentElement);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitShorthandAssignmentProperty(node) {
                if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                    node = transformNamedEvaluation(context, node, canIgnoreEmptyStringLiteralInAssignedName(node.objectAssignmentInitializer));
                }
                return visitEachChild(node, visitor, context);
            }
            function visitAssignmentRestProperty(node) {
                if (isLeftHandSideExpression(node.expression)) {
                    const expression = visitDestructuringAssignmentTarget(node.expression);
                    return factory2.updateSpreadAssignment(node, expression);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitObjectAssignmentElement(node) {
                Debug.assertNode(node, isObjectBindingOrAssignmentElement);
                if (isSpreadAssignment(node))
                    return visitAssignmentRestProperty(node);
                if (isShorthandPropertyAssignment(node))
                    return visitShorthandAssignmentProperty(node);
                if (isPropertyAssignment(node))
                    return visitAssignmentProperty(node);
                return visitEachChild(node, visitor, context);
            }
            function visitAssignmentPattern(node) {
                if (isArrayLiteralExpression(node)) {
                    const elements = visitNodes2(node.elements, visitArrayAssignmentElement, isExpression);
                    return factory2.updateArrayLiteralExpression(node, elements);
                }
                else {
                    const properties = visitNodes2(node.properties, visitObjectAssignmentElement, isObjectLiteralElementLike);
                    return factory2.updateObjectLiteralExpression(node, properties);
                }
            }
            function visitExportAssignment(node) {
                if (isNamedEvaluation(node, isAnonymousClassNeedingAssignedName)) {
                    node = transformNamedEvaluation(context, node, canIgnoreEmptyStringLiteralInAssignedName(node.expression));
                }
                return visitEachChild(node, visitor, context);
            }
            function visitParenthesizedExpression(node, discarded) {
                const visitorFunc = discarded ? discardedValueVisitor : visitor;
                const expression = visitNode(node.expression, visitorFunc, isExpression);
                return factory2.updateParenthesizedExpression(node, expression);
            }
            function visitPartiallyEmittedExpression(node, discarded) {
                const visitorFunc = discarded ? discardedValueVisitor : visitor;
                const expression = visitNode(node.expression, visitorFunc, isExpression);
                return factory2.updatePartiallyEmittedExpression(node, expression);
            }
            function injectPendingExpressionsCommon(pendingExpressions2, expression) {
                if (some(pendingExpressions2)) {
                    if (expression) {
                        if (isParenthesizedExpression(expression)) {
                            pendingExpressions2.push(expression.expression);
                            expression = factory2.updateParenthesizedExpression(expression, factory2.inlineExpressions(pendingExpressions2));
                        }
                        else {
                            pendingExpressions2.push(expression);
                            expression = factory2.inlineExpressions(pendingExpressions2);
                        }
                    }
                    else {
                        expression = factory2.inlineExpressions(pendingExpressions2);
                    }
                }
                return expression;
            }
            function injectPendingExpressions(expression) {
                const result = injectPendingExpressionsCommon(pendingExpressions, expression);
                Debug.assertIsDefined(result);
                if (result !== expression) {
                    pendingExpressions = void 0;
                }
                return result;
            }
            function injectPendingInitializers(classInfo2, isStatic2, expression) {
                const result = injectPendingExpressionsCommon(isStatic2 ? classInfo2.pendingStaticInitializers : classInfo2.pendingInstanceInitializers, expression);
                if (result !== expression) {
                    if (isStatic2) {
                        classInfo2.pendingStaticInitializers = void 0;
                    }
                    else {
                        classInfo2.pendingInstanceInitializers = void 0;
                    }
                }
                return result;
            }
            function transformAllDecoratorsOfDeclaration(allDecorators) {
                if (!allDecorators) {
                    return void 0;
                }
                const decoratorExpressions = [];
                addRange(decoratorExpressions, map(allDecorators.decorators, transformDecorator));
                return decoratorExpressions;
            }
            function transformDecorator(decorator) {
                const expression = visitNode(decorator.expression, visitor, isExpression);
                setEmitFlags(expression, 3072 /* NoComments */);
                const innerExpression = skipOuterExpressions(expression);
                if (isAccessExpression(innerExpression)) {
                    const { target, thisArg } = factory2.createCallBinding(expression, hoistVariableDeclaration, languageVersion, 
                    /*cacheIdentifiers*/
                    true);
                    return factory2.restoreOuterExpressions(expression, factory2.createFunctionBindCall(target, thisArg, []));
                }
                return expression;
            }
            function createDescriptorMethod(original, name, modifiers, asteriskToken, kind, parameters, body) {
                const func = factory2.createFunctionExpression(modifiers, asteriskToken, 
                /*name*/
                void 0, 
                /*typeParameters*/
                void 0, parameters, 
                /*type*/
                void 0, body ?? factory2.createBlock([]));
                setOriginalNode(func, original);
                setSourceMapRange(func, moveRangePastDecorators(original));
                setEmitFlags(func, 3072 /* NoComments */);
                const prefix = kind === "get" || kind === "set" ? kind : void 0;
                const functionName = factory2.createStringLiteralFromNode(name, 
                /*isSingleQuote*/
                void 0);
                const namedFunction = emitHelpers().createSetFunctionNameHelper(func, functionName, prefix);
                const method = factory2.createPropertyAssignment(factory2.createIdentifier(kind), namedFunction);
                setOriginalNode(method, original);
                setSourceMapRange(method, moveRangePastDecorators(original));
                setEmitFlags(method, 3072 /* NoComments */);
                return method;
            }
            function createMethodDescriptorObject(node, modifiers) {
                return factory2.createObjectLiteralExpression([
                    createDescriptorMethod(node, node.name, modifiers, node.asteriskToken, "value", visitNodes2(node.parameters, visitor, isParameter), visitNode(node.body, visitor, isBlock))
                ]);
            }
            function createGetAccessorDescriptorObject(node, modifiers) {
                return factory2.createObjectLiteralExpression([
                    createDescriptorMethod(node, node.name, modifiers, 
                    /*asteriskToken*/
                    void 0, "get", [], visitNode(node.body, visitor, isBlock))
                ]);
            }
            function createSetAccessorDescriptorObject(node, modifiers) {
                return factory2.createObjectLiteralExpression([
                    createDescriptorMethod(node, node.name, modifiers, 
                    /*asteriskToken*/
                    void 0, "set", visitNodes2(node.parameters, visitor, isParameter), visitNode(node.body, visitor, isBlock))
                ]);
            }
            function createAccessorPropertyDescriptorObject(node, modifiers) {
                return factory2.createObjectLiteralExpression([
                    createDescriptorMethod(node, node.name, modifiers, 
                    /*asteriskToken*/
                    void 0, "get", [], factory2.createBlock([
                        factory2.createReturnStatement(factory2.createPropertyAccessExpression(factory2.createThis(), factory2.getGeneratedPrivateNameForNode(node.name)))
                    ])),
                    createDescriptorMethod(node, node.name, modifiers, 
                    /*asteriskToken*/
                    void 0, "set", [factory2.createParameterDeclaration(
                        /*modifiers*/
                        void 0, 
                        /*dotDotDotToken*/
                        void 0, "value")], factory2.createBlock([
                        factory2.createExpressionStatement(factory2.createAssignment(factory2.createPropertyAccessExpression(factory2.createThis(), factory2.getGeneratedPrivateNameForNode(node.name)), factory2.createIdentifier("value")))
                    ]))
                ]);
            }
            function createMethodDescriptorForwarder(modifiers, name, descriptorName) {
                modifiers = visitNodes2(modifiers, (node) => isStaticModifier(node) ? node : void 0, isModifier);
                return factory2.createGetAccessorDeclaration(modifiers, name, [], 
                /*type*/
                void 0, factory2.createBlock([
                    factory2.createReturnStatement(factory2.createPropertyAccessExpression(descriptorName, factory2.createIdentifier("value")))
                ]));
            }
            function createGetAccessorDescriptorForwarder(modifiers, name, descriptorName) {
                modifiers = visitNodes2(modifiers, (node) => isStaticModifier(node) ? node : void 0, isModifier);
                return factory2.createGetAccessorDeclaration(modifiers, name, [], 
                /*type*/
                void 0, factory2.createBlock([
                    factory2.createReturnStatement(factory2.createFunctionCallCall(factory2.createPropertyAccessExpression(descriptorName, factory2.createIdentifier("get")), factory2.createThis(), []))
                ]));
            }
            function createSetAccessorDescriptorForwarder(modifiers, name, descriptorName) {
                modifiers = visitNodes2(modifiers, (node) => isStaticModifier(node) ? node : void 0, isModifier);
                return factory2.createSetAccessorDeclaration(modifiers, name, [factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, "value")], factory2.createBlock([
                    factory2.createReturnStatement(factory2.createFunctionCallCall(factory2.createPropertyAccessExpression(descriptorName, factory2.createIdentifier("set")), factory2.createThis(), [factory2.createIdentifier("value")]))
                ]));
            }
            function createMetadata(name, classSuper2) {
                const varDecl = factory2.createVariableDeclaration(name, 
                /*exclamationToken*/
                void 0, 
                /*type*/
                void 0, factory2.createConditionalExpression(factory2.createLogicalAnd(factory2.createTypeCheck(factory2.createIdentifier("Symbol"), "function"), factory2.createPropertyAccessExpression(factory2.createIdentifier("Symbol"), "metadata")), factory2.createToken(58 /* QuestionToken */), factory2.createCallExpression(factory2.createPropertyAccessExpression(factory2.createIdentifier("Object"), "create"), 
                /*typeArguments*/
                void 0, [classSuper2 ? createSymbolMetadataReference(classSuper2) : factory2.createNull()]), factory2.createToken(59 /* ColonToken */), factory2.createVoidZero()));
                return factory2.createVariableStatement(
                /*modifiers*/
                void 0, factory2.createVariableDeclarationList([varDecl], 2 /* Const */));
            }
            function createSymbolMetadata(target, value) {
                const defineProperty = factory2.createObjectDefinePropertyCall(target, factory2.createPropertyAccessExpression(factory2.createIdentifier("Symbol"), "metadata"), factory2.createPropertyDescriptor({ configurable: true, writable: true, enumerable: true, value }, 
                /*singleLine*/
                true));
                return setEmitFlags(factory2.createIfStatement(value, factory2.createExpressionStatement(defineProperty)), 1 /* SingleLine */);
            }
            function createSymbolMetadataReference(classSuper2) {
                return factory2.createBinaryExpression(factory2.createElementAccessExpression(classSuper2, factory2.createPropertyAccessExpression(factory2.createIdentifier("Symbol"), "metadata")), 61 /* QuestionQuestionToken */, factory2.createNull());
            }
        }
        var init_esDecorators = __esm({
            "src/compiler/transformers/esDecorators.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/es2017.ts
        function transformES2017(context) {
            const { factory: factory2, getEmitHelperFactory: emitHelpers, resumeLexicalEnvironment, endLexicalEnvironment, hoistVariableDeclaration } = context;
            const resolver = context.getEmitResolver();
            const compilerOptions = context.getCompilerOptions();
            const languageVersion = getEmitScriptTarget(compilerOptions);
            let enabledSubstitutions;
            let enclosingSuperContainerFlags = 0;
            let enclosingFunctionParameterNames;
            let capturedSuperProperties;
            let hasSuperElementAccess;
            let lexicalArgumentsBinding;
            const substitutedSuperAccessors = [];
            let contextFlags = 0 /* None */;
            const previousOnEmitNode = context.onEmitNode;
            const previousOnSubstituteNode = context.onSubstituteNode;
            context.onEmitNode = onEmitNode;
            context.onSubstituteNode = onSubstituteNode;
            return chainBundle(context, transformSourceFile);
            function transformSourceFile(node) {
                if (node.isDeclarationFile) {
                    return node;
                }
                setContextFlag(1 /* NonTopLevel */, false);
                setContextFlag(2 /* HasLexicalThis */, !isEffectiveStrictModeSourceFile(node, compilerOptions));
                const visited = visitEachChild(node, visitor, context);
                addEmitHelpers(visited, context.readEmitHelpers());
                return visited;
            }
            function setContextFlag(flag, val) {
                contextFlags = val ? contextFlags | flag : contextFlags & ~flag;
            }
            function inContext(flags) {
                return (contextFlags & flags) !== 0;
            }
            function inTopLevelContext() {
                return !inContext(1 /* NonTopLevel */);
            }
            function inHasLexicalThisContext() {
                return inContext(2 /* HasLexicalThis */);
            }
            function doWithContext(flags, cb, value) {
                const contextFlagsToSet = flags & ~contextFlags;
                if (contextFlagsToSet) {
                    setContextFlag(contextFlagsToSet, 
                    /*val*/
                    true);
                    const result = cb(value);
                    setContextFlag(contextFlagsToSet, 
                    /*val*/
                    false);
                    return result;
                }
                return cb(value);
            }
            function visitDefault(node) {
                return visitEachChild(node, visitor, context);
            }
            function argumentsVisitor(node) {
                switch (node.kind) {
                    case 218 /* FunctionExpression */:
                    case 262 /* FunctionDeclaration */:
                    case 174 /* MethodDeclaration */:
                    case 177 /* GetAccessor */:
                    case 178 /* SetAccessor */:
                    case 176 /* Constructor */:
                        return node;
                    case 169 /* Parameter */:
                    case 208 /* BindingElement */:
                    case 260 /* VariableDeclaration */:
                        break;
                    case 80 /* Identifier */:
                        if (lexicalArgumentsBinding && resolver.isArgumentsLocalBinding(node)) {
                            return lexicalArgumentsBinding;
                        }
                        break;
                }
                return visitEachChild(node, argumentsVisitor, context);
            }
            function visitor(node) {
                if ((node.transformFlags & 256 /* ContainsES2017 */) === 0) {
                    return lexicalArgumentsBinding ? argumentsVisitor(node) : node;
                }
                switch (node.kind) {
                    case 134 /* AsyncKeyword */:
                        return void 0;
                    case 223 /* AwaitExpression */:
                        return visitAwaitExpression(node);
                    case 174 /* MethodDeclaration */:
                        return doWithContext(1 /* NonTopLevel */ | 2 /* HasLexicalThis */, visitMethodDeclaration, node);
                    case 262 /* FunctionDeclaration */:
                        return doWithContext(1 /* NonTopLevel */ | 2 /* HasLexicalThis */, visitFunctionDeclaration, node);
                    case 218 /* FunctionExpression */:
                        return doWithContext(1 /* NonTopLevel */ | 2 /* HasLexicalThis */, visitFunctionExpression, node);
                    case 219 /* ArrowFunction */:
                        return doWithContext(1 /* NonTopLevel */, visitArrowFunction, node);
                    case 211 /* PropertyAccessExpression */:
                        if (capturedSuperProperties && isPropertyAccessExpression(node) && node.expression.kind === 108 /* SuperKeyword */) {
                            capturedSuperProperties.add(node.name.escapedText);
                        }
                        return visitEachChild(node, visitor, context);
                    case 212 /* ElementAccessExpression */:
                        if (capturedSuperProperties && node.expression.kind === 108 /* SuperKeyword */) {
                            hasSuperElementAccess = true;
                        }
                        return visitEachChild(node, visitor, context);
                    case 177 /* GetAccessor */:
                        return doWithContext(1 /* NonTopLevel */ | 2 /* HasLexicalThis */, visitGetAccessorDeclaration, node);
                    case 178 /* SetAccessor */:
                        return doWithContext(1 /* NonTopLevel */ | 2 /* HasLexicalThis */, visitSetAccessorDeclaration, node);
                    case 176 /* Constructor */:
                        return doWithContext(1 /* NonTopLevel */ | 2 /* HasLexicalThis */, visitConstructorDeclaration, node);
                    case 263 /* ClassDeclaration */:
                    case 231 /* ClassExpression */:
                        return doWithContext(1 /* NonTopLevel */ | 2 /* HasLexicalThis */, visitDefault, node);
                    default:
                        return visitEachChild(node, visitor, context);
                }
            }
            function asyncBodyVisitor(node) {
                if (isNodeWithPossibleHoistedDeclaration(node)) {
                    switch (node.kind) {
                        case 243 /* VariableStatement */:
                            return visitVariableStatementInAsyncBody(node);
                        case 248 /* ForStatement */:
                            return visitForStatementInAsyncBody(node);
                        case 249 /* ForInStatement */:
                            return visitForInStatementInAsyncBody(node);
                        case 250 /* ForOfStatement */:
                            return visitForOfStatementInAsyncBody(node);
                        case 299 /* CatchClause */:
                            return visitCatchClauseInAsyncBody(node);
                        case 241 /* Block */:
                        case 255 /* SwitchStatement */:
                        case 269 /* CaseBlock */:
                        case 296 /* CaseClause */:
                        case 297 /* DefaultClause */:
                        case 258 /* TryStatement */:
                        case 246 /* DoStatement */:
                        case 247 /* WhileStatement */:
                        case 245 /* IfStatement */:
                        case 254 /* WithStatement */:
                        case 256 /* LabeledStatement */:
                            return visitEachChild(node, asyncBodyVisitor, context);
                        default:
                            return Debug.assertNever(node, "Unhandled node.");
                    }
                }
                return visitor(node);
            }
            function visitCatchClauseInAsyncBody(node) {
                const catchClauseNames = /* @__PURE__ */ new Set();
                recordDeclarationName(node.variableDeclaration, catchClauseNames);
                let catchClauseUnshadowedNames;
                catchClauseNames.forEach((_, escapedName) => {
                    if (enclosingFunctionParameterNames.has(escapedName)) {
                        if (!catchClauseUnshadowedNames) {
                            catchClauseUnshadowedNames = new Set(enclosingFunctionParameterNames);
                        }
                        catchClauseUnshadowedNames.delete(escapedName);
                    }
                });
                if (catchClauseUnshadowedNames) {
                    const savedEnclosingFunctionParameterNames = enclosingFunctionParameterNames;
                    enclosingFunctionParameterNames = catchClauseUnshadowedNames;
                    const result = visitEachChild(node, asyncBodyVisitor, context);
                    enclosingFunctionParameterNames = savedEnclosingFunctionParameterNames;
                    return result;
                }
                else {
                    return visitEachChild(node, asyncBodyVisitor, context);
                }
            }
            function visitVariableStatementInAsyncBody(node) {
                if (isVariableDeclarationListWithCollidingName(node.declarationList)) {
                    const expression = visitVariableDeclarationListWithCollidingNames(node.declarationList, 
                    /*hasReceiver*/
                    false);
                    return expression ? factory2.createExpressionStatement(expression) : void 0;
                }
                return visitEachChild(node, visitor, context);
            }
            function visitForInStatementInAsyncBody(node) {
                return factory2.updateForInStatement(node, isVariableDeclarationListWithCollidingName(node.initializer) ? visitVariableDeclarationListWithCollidingNames(node.initializer, 
                /*hasReceiver*/
                true) : Debug.checkDefined(visitNode(node.initializer, visitor, isForInitializer)), Debug.checkDefined(visitNode(node.expression, visitor, isExpression)), visitIterationBody(node.statement, asyncBodyVisitor, context));
            }
            function visitForOfStatementInAsyncBody(node) {
                return factory2.updateForOfStatement(node, visitNode(node.awaitModifier, visitor, isAwaitKeyword), isVariableDeclarationListWithCollidingName(node.initializer) ? visitVariableDeclarationListWithCollidingNames(node.initializer, 
                /*hasReceiver*/
                true) : Debug.checkDefined(visitNode(node.initializer, visitor, isForInitializer)), Debug.checkDefined(visitNode(node.expression, visitor, isExpression)), visitIterationBody(node.statement, asyncBodyVisitor, context));
            }
            function visitForStatementInAsyncBody(node) {
                const initializer = node.initializer;
                return factory2.updateForStatement(node, isVariableDeclarationListWithCollidingName(initializer) ? visitVariableDeclarationListWithCollidingNames(initializer, 
                /*hasReceiver*/
                false) : visitNode(node.initializer, visitor, isForInitializer), visitNode(node.condition, visitor, isExpression), visitNode(node.incrementor, visitor, isExpression), visitIterationBody(node.statement, asyncBodyVisitor, context));
            }
            function visitAwaitExpression(node) {
                if (inTopLevelContext()) {
                    return visitEachChild(node, visitor, context);
                }
                return setOriginalNode(setTextRange(factory2.createYieldExpression(
                /*asteriskToken*/
                void 0, visitNode(node.expression, visitor, isExpression)), node), node);
            }
            function visitConstructorDeclaration(node) {
                const savedLexicalArgumentsBinding = lexicalArgumentsBinding;
                lexicalArgumentsBinding = void 0;
                const updated = factory2.updateConstructorDeclaration(node, visitNodes2(node.modifiers, visitor, isModifier), visitParameterList(node.parameters, visitor, context), transformMethodBody(node));
                lexicalArgumentsBinding = savedLexicalArgumentsBinding;
                return updated;
            }
            function visitMethodDeclaration(node) {
                let parameters;
                const functionFlags = getFunctionFlags(node);
                const savedLexicalArgumentsBinding = lexicalArgumentsBinding;
                lexicalArgumentsBinding = void 0;
                const updated = factory2.updateMethodDeclaration(node, visitNodes2(node.modifiers, visitor, isModifierLike), node.asteriskToken, node.name, 
                /*questionToken*/
                void 0, 
                /*typeParameters*/
                void 0, parameters = functionFlags & 2 /* Async */ ? transformAsyncFunctionParameterList(node) : visitParameterList(node.parameters, visitor, context), 
                /*type*/
                void 0, functionFlags & 2 /* Async */ ? transformAsyncFunctionBody(node, parameters) : transformMethodBody(node));
                lexicalArgumentsBinding = savedLexicalArgumentsBinding;
                return updated;
            }
            function visitGetAccessorDeclaration(node) {
                const savedLexicalArgumentsBinding = lexicalArgumentsBinding;
                lexicalArgumentsBinding = void 0;
                const updated = factory2.updateGetAccessorDeclaration(node, visitNodes2(node.modifiers, visitor, isModifierLike), node.name, visitParameterList(node.parameters, visitor, context), 
                /*type*/
                void 0, transformMethodBody(node));
                lexicalArgumentsBinding = savedLexicalArgumentsBinding;
                return updated;
            }
            function visitSetAccessorDeclaration(node) {
                const savedLexicalArgumentsBinding = lexicalArgumentsBinding;
                lexicalArgumentsBinding = void 0;
                const updated = factory2.updateSetAccessorDeclaration(node, visitNodes2(node.modifiers, visitor, isModifierLike), node.name, visitParameterList(node.parameters, visitor, context), transformMethodBody(node));
                lexicalArgumentsBinding = savedLexicalArgumentsBinding;
                return updated;
            }
            function visitFunctionDeclaration(node) {
                let parameters;
                const savedLexicalArgumentsBinding = lexicalArgumentsBinding;
                lexicalArgumentsBinding = void 0;
                const functionFlags = getFunctionFlags(node);
                const updated = factory2.updateFunctionDeclaration(node, visitNodes2(node.modifiers, visitor, isModifierLike), node.asteriskToken, node.name, 
                /*typeParameters*/
                void 0, parameters = functionFlags & 2 /* Async */ ? transformAsyncFunctionParameterList(node) : visitParameterList(node.parameters, visitor, context), 
                /*type*/
                void 0, functionFlags & 2 /* Async */ ? transformAsyncFunctionBody(node, parameters) : visitFunctionBody(node.body, visitor, context));
                lexicalArgumentsBinding = savedLexicalArgumentsBinding;
                return updated;
            }
            function visitFunctionExpression(node) {
                let parameters;
                const savedLexicalArgumentsBinding = lexicalArgumentsBinding;
                lexicalArgumentsBinding = void 0;
                const functionFlags = getFunctionFlags(node);
                const updated = factory2.updateFunctionExpression(node, visitNodes2(node.modifiers, visitor, isModifier), node.asteriskToken, node.name, 
                /*typeParameters*/
                void 0, parameters = functionFlags & 2 /* Async */ ? transformAsyncFunctionParameterList(node) : visitParameterList(node.parameters, visitor, context), 
                /*type*/
                void 0, functionFlags & 2 /* Async */ ? transformAsyncFunctionBody(node, parameters) : visitFunctionBody(node.body, visitor, context));
                lexicalArgumentsBinding = savedLexicalArgumentsBinding;
                return updated;
            }
            function visitArrowFunction(node) {
                let parameters;
                const functionFlags = getFunctionFlags(node);
                return factory2.updateArrowFunction(node, visitNodes2(node.modifiers, visitor, isModifier), 
                /*typeParameters*/
                void 0, parameters = functionFlags & 2 /* Async */ ? transformAsyncFunctionParameterList(node) : visitParameterList(node.parameters, visitor, context), 
                /*type*/
                void 0, node.equalsGreaterThanToken, functionFlags & 2 /* Async */ ? transformAsyncFunctionBody(node, parameters) : visitFunctionBody(node.body, visitor, context));
            }
            function recordDeclarationName({ name }, names) {
                if (isIdentifier(name)) {
                    names.add(name.escapedText);
                }
                else {
                    for (const element of name.elements) {
                        if (!isOmittedExpression(element)) {
                            recordDeclarationName(element, names);
                        }
                    }
                }
            }
            function isVariableDeclarationListWithCollidingName(node) {
                return !!node && isVariableDeclarationList(node) && !(node.flags & 7 /* BlockScoped */) && node.declarations.some(collidesWithParameterName);
            }
            function visitVariableDeclarationListWithCollidingNames(node, hasReceiver) {
                hoistVariableDeclarationList(node);
                const variables = getInitializedVariables(node);
                if (variables.length === 0) {
                    if (hasReceiver) {
                        return visitNode(factory2.converters.convertToAssignmentElementTarget(node.declarations[0].name), visitor, isExpression);
                    }
                    return void 0;
                }
                return factory2.inlineExpressions(map(variables, transformInitializedVariable));
            }
            function hoistVariableDeclarationList(node) {
                forEach(node.declarations, hoistVariable);
            }
            function hoistVariable({ name }) {
                if (isIdentifier(name)) {
                    hoistVariableDeclaration(name);
                }
                else {
                    for (const element of name.elements) {
                        if (!isOmittedExpression(element)) {
                            hoistVariable(element);
                        }
                    }
                }
            }
            function transformInitializedVariable(node) {
                const converted = setSourceMapRange(factory2.createAssignment(factory2.converters.convertToAssignmentElementTarget(node.name), node.initializer), node);
                return Debug.checkDefined(visitNode(converted, visitor, isExpression));
            }
            function collidesWithParameterName({ name }) {
                if (isIdentifier(name)) {
                    return enclosingFunctionParameterNames.has(name.escapedText);
                }
                else {
                    for (const element of name.elements) {
                        if (!isOmittedExpression(element) && collidesWithParameterName(element)) {
                            return true;
                        }
                    }
                }
                return false;
            }
            function transformMethodBody(node) {
                Debug.assertIsDefined(node.body);
                const savedCapturedSuperProperties = capturedSuperProperties;
                const savedHasSuperElementAccess = hasSuperElementAccess;
                capturedSuperProperties = /* @__PURE__ */ new Set();
                hasSuperElementAccess = false;
                let updated = visitFunctionBody(node.body, visitor, context);
                const originalMethod = getOriginalNode(node, isFunctionLikeDeclaration);
                const emitSuperHelpers = languageVersion >= 2 /* ES2015 */ && resolver.getNodeCheckFlags(node) & (256 /* MethodWithSuperPropertyAssignmentInAsync */ | 128 /* MethodWithSuperPropertyAccessInAsync */) && (getFunctionFlags(originalMethod) & 3 /* AsyncGenerator */) !== 3 /* AsyncGenerator */;
                if (emitSuperHelpers) {
                    enableSubstitutionForAsyncMethodsWithSuper();
                    if (capturedSuperProperties.size) {
                        const variableStatement = createSuperAccessVariableStatement(factory2, resolver, node, capturedSuperProperties);
                        substitutedSuperAccessors[getNodeId(variableStatement)] = true;
                        const statements = updated.statements.slice();
                        insertStatementsAfterStandardPrologue(statements, [variableStatement]);
                        updated = factory2.updateBlock(updated, statements);
                    }
                    if (hasSuperElementAccess) {
                        if (resolver.getNodeCheckFlags(node) & 256 /* MethodWithSuperPropertyAssignmentInAsync */) {
                            addEmitHelper(updated, advancedAsyncSuperHelper);
                        }
                        else if (resolver.getNodeCheckFlags(node) & 128 /* MethodWithSuperPropertyAccessInAsync */) {
                            addEmitHelper(updated, asyncSuperHelper);
                        }
                    }
                }
                capturedSuperProperties = savedCapturedSuperProperties;
                hasSuperElementAccess = savedHasSuperElementAccess;
                return updated;
            }
            function createCaptureArgumentsStatement() {
                Debug.assert(lexicalArgumentsBinding);
                const variable = factory2.createVariableDeclaration(lexicalArgumentsBinding, 
                /*exclamationToken*/
                void 0, 
                /*type*/
                void 0, factory2.createIdentifier("arguments"));
                const statement = factory2.createVariableStatement(
                /*modifiers*/
                void 0, [variable]);
                startOnNewLine(statement);
                addEmitFlags(statement, 2097152 /* CustomPrologue */);
                return statement;
            }
            function transformAsyncFunctionParameterList(node) {
                if (isSimpleParameterList(node.parameters)) {
                    return visitParameterList(node.parameters, visitor, context);
                }
                const newParameters = [];
                for (const parameter of node.parameters) {
                    if (parameter.initializer || parameter.dotDotDotToken) {
                        if (node.kind === 219 /* ArrowFunction */) {
                            const restParameter = factory2.createParameterDeclaration(
                            /*modifiers*/
                            void 0, factory2.createToken(26 /* DotDotDotToken */), factory2.createUniqueName("args", 8 /* ReservedInNestedScopes */));
                            newParameters.push(restParameter);
                        }
                        break;
                    }
                    const newParameter = factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, factory2.getGeneratedNameForNode(parameter.name, 8 /* ReservedInNestedScopes */));
                    newParameters.push(newParameter);
                }
                const newParametersArray = factory2.createNodeArray(newParameters);
                setTextRange(newParametersArray, node.parameters);
                return newParametersArray;
            }
            function transformAsyncFunctionBody(node, outerParameters) {
                const innerParameters = !isSimpleParameterList(node.parameters) ? visitParameterList(node.parameters, visitor, context) : void 0;
                resumeLexicalEnvironment();
                const original = getOriginalNode(node, isFunctionLike);
                const nodeType = original.type;
                const promiseConstructor = languageVersion < 2 /* ES2015 */ ? getPromiseConstructor(nodeType) : void 0;
                const isArrowFunction2 = node.kind === 219 /* ArrowFunction */;
                const savedLexicalArgumentsBinding = lexicalArgumentsBinding;
                const hasLexicalArguments = (resolver.getNodeCheckFlags(node) & 512 /* CaptureArguments */) !== 0;
                const captureLexicalArguments = hasLexicalArguments && !lexicalArgumentsBinding;
                if (captureLexicalArguments) {
                    lexicalArgumentsBinding = factory2.createUniqueName("arguments");
                }
                let argumentsExpression;
                if (innerParameters) {
                    if (isArrowFunction2) {
                        const parameterBindings = [];
                        Debug.assert(outerParameters.length <= node.parameters.length);
                        for (let i = 0; i < node.parameters.length; i++) {
                            Debug.assert(i < outerParameters.length);
                            const originalParameter = node.parameters[i];
                            const outerParameter = outerParameters[i];
                            Debug.assertNode(outerParameter.name, isIdentifier);
                            if (originalParameter.initializer || originalParameter.dotDotDotToken) {
                                Debug.assert(i === outerParameters.length - 1);
                                parameterBindings.push(factory2.createSpreadElement(outerParameter.name));
                                break;
                            }
                            parameterBindings.push(outerParameter.name);
                        }
                        argumentsExpression = factory2.createArrayLiteralExpression(parameterBindings);
                    }
                    else {
                        argumentsExpression = factory2.createIdentifier("arguments");
                    }
                }
                const savedEnclosingFunctionParameterNames = enclosingFunctionParameterNames;
                enclosingFunctionParameterNames = /* @__PURE__ */ new Set();
                for (const parameter of node.parameters) {
                    recordDeclarationName(parameter, enclosingFunctionParameterNames);
                }
                const savedCapturedSuperProperties = capturedSuperProperties;
                const savedHasSuperElementAccess = hasSuperElementAccess;
                if (!isArrowFunction2) {
                    capturedSuperProperties = /* @__PURE__ */ new Set();
                    hasSuperElementAccess = false;
                }
                const hasLexicalThis = inHasLexicalThisContext();
                let asyncBody = transformAsyncFunctionBodyWorker(node.body);
                asyncBody = factory2.updateBlock(asyncBody, factory2.mergeLexicalEnvironment(asyncBody.statements, endLexicalEnvironment()));
                let result;
                if (!isArrowFunction2) {
                    const statements = [];
                    statements.push(factory2.createReturnStatement(emitHelpers().createAwaiterHelper(hasLexicalThis, argumentsExpression, promiseConstructor, innerParameters, asyncBody)));
                    const emitSuperHelpers = languageVersion >= 2 /* ES2015 */ && resolver.getNodeCheckFlags(node) & (256 /* MethodWithSuperPropertyAssignmentInAsync */ | 128 /* MethodWithSuperPropertyAccessInAsync */);
                    if (emitSuperHelpers) {
                        enableSubstitutionForAsyncMethodsWithSuper();
                        if (capturedSuperProperties.size) {
                            const variableStatement = createSuperAccessVariableStatement(factory2, resolver, node, capturedSuperProperties);
                            substitutedSuperAccessors[getNodeId(variableStatement)] = true;
                            insertStatementsAfterStandardPrologue(statements, [variableStatement]);
                        }
                    }
                    if (captureLexicalArguments) {
                        insertStatementsAfterStandardPrologue(statements, [createCaptureArgumentsStatement()]);
                    }
                    const block = factory2.createBlock(statements, 
                    /*multiLine*/
                    true);
                    setTextRange(block, node.body);
                    if (emitSuperHelpers && hasSuperElementAccess) {
                        if (resolver.getNodeCheckFlags(node) & 256 /* MethodWithSuperPropertyAssignmentInAsync */) {
                            addEmitHelper(block, advancedAsyncSuperHelper);
                        }
                        else if (resolver.getNodeCheckFlags(node) & 128 /* MethodWithSuperPropertyAccessInAsync */) {
                            addEmitHelper(block, asyncSuperHelper);
                        }
                    }
                    result = block;
                }
                else {
                    result = emitHelpers().createAwaiterHelper(hasLexicalThis, argumentsExpression, promiseConstructor, innerParameters, asyncBody);
                    if (captureLexicalArguments) {
                        const block = factory2.converters.convertToFunctionBlock(result);
                        result = factory2.updateBlock(block, factory2.mergeLexicalEnvironment(block.statements, [createCaptureArgumentsStatement()]));
                    }
                }
                enclosingFunctionParameterNames = savedEnclosingFunctionParameterNames;
                if (!isArrowFunction2) {
                    capturedSuperProperties = savedCapturedSuperProperties;
                    hasSuperElementAccess = savedHasSuperElementAccess;
                    lexicalArgumentsBinding = savedLexicalArgumentsBinding;
                }
                return result;
            }
            function transformAsyncFunctionBodyWorker(body, start) {
                if (isBlock(body)) {
                    return factory2.updateBlock(body, visitNodes2(body.statements, asyncBodyVisitor, isStatement, start));
                }
                else {
                    return factory2.converters.convertToFunctionBlock(Debug.checkDefined(visitNode(body, asyncBodyVisitor, isConciseBody)));
                }
            }
            function getPromiseConstructor(type) {
                const typeName = type && getEntityNameFromTypeNode(type);
                if (typeName && isEntityName(typeName)) {
                    const serializationKind = resolver.getTypeReferenceSerializationKind(typeName);
                    if (serializationKind === 1 /* TypeWithConstructSignatureAndValue */ || serializationKind === 0 /* Unknown */) {
                        return typeName;
                    }
                }
                return void 0;
            }
            function enableSubstitutionForAsyncMethodsWithSuper() {
                if ((enabledSubstitutions & 1 /* AsyncMethodsWithSuper */) === 0) {
                    enabledSubstitutions |= 1 /* AsyncMethodsWithSuper */;
                    context.enableSubstitution(213 /* CallExpression */);
                    context.enableSubstitution(211 /* PropertyAccessExpression */);
                    context.enableSubstitution(212 /* ElementAccessExpression */);
                    context.enableEmitNotification(263 /* ClassDeclaration */);
                    context.enableEmitNotification(174 /* MethodDeclaration */);
                    context.enableEmitNotification(177 /* GetAccessor */);
                    context.enableEmitNotification(178 /* SetAccessor */);
                    context.enableEmitNotification(176 /* Constructor */);
                    context.enableEmitNotification(243 /* VariableStatement */);
                }
            }
            function onEmitNode(hint, node, emitCallback) {
                if (enabledSubstitutions & 1 /* AsyncMethodsWithSuper */ && isSuperContainer(node)) {
                    const superContainerFlags = resolver.getNodeCheckFlags(node) & (128 /* MethodWithSuperPropertyAccessInAsync */ | 256 /* MethodWithSuperPropertyAssignmentInAsync */);
                    if (superContainerFlags !== enclosingSuperContainerFlags) {
                        const savedEnclosingSuperContainerFlags = enclosingSuperContainerFlags;
                        enclosingSuperContainerFlags = superContainerFlags;
                        previousOnEmitNode(hint, node, emitCallback);
                        enclosingSuperContainerFlags = savedEnclosingSuperContainerFlags;
                        return;
                    }
                }
                else if (enabledSubstitutions && substitutedSuperAccessors[getNodeId(node)]) {
                    const savedEnclosingSuperContainerFlags = enclosingSuperContainerFlags;
                    enclosingSuperContainerFlags = 0;
                    previousOnEmitNode(hint, node, emitCallback);
                    enclosingSuperContainerFlags = savedEnclosingSuperContainerFlags;
                    return;
                }
                previousOnEmitNode(hint, node, emitCallback);
            }
            function onSubstituteNode(hint, node) {
                node = previousOnSubstituteNode(hint, node);
                if (hint === 1 /* Expression */ && enclosingSuperContainerFlags) {
                    return substituteExpression(node);
                }
                return node;
            }
            function substituteExpression(node) {
                switch (node.kind) {
                    case 211 /* PropertyAccessExpression */:
                        return substitutePropertyAccessExpression(node);
                    case 212 /* ElementAccessExpression */:
                        return substituteElementAccessExpression(node);
                    case 213 /* CallExpression */:
                        return substituteCallExpression(node);
                }
                return node;
            }
            function substitutePropertyAccessExpression(node) {
                if (node.expression.kind === 108 /* SuperKeyword */) {
                    return setTextRange(factory2.createPropertyAccessExpression(factory2.createUniqueName("_super", 16 /* Optimistic */ | 32 /* FileLevel */), node.name), node);
                }
                return node;
            }
            function substituteElementAccessExpression(node) {
                if (node.expression.kind === 108 /* SuperKeyword */) {
                    return createSuperElementAccessInAsyncMethod(node.argumentExpression, node);
                }
                return node;
            }
            function substituteCallExpression(node) {
                const expression = node.expression;
                if (isSuperProperty(expression)) {
                    const argumentExpression = isPropertyAccessExpression(expression) ? substitutePropertyAccessExpression(expression) : substituteElementAccessExpression(expression);
                    return factory2.createCallExpression(factory2.createPropertyAccessExpression(argumentExpression, "call"), 
                    /*typeArguments*/
                    void 0, [
                        factory2.createThis(),
                        ...node.arguments
                    ]);
                }
                return node;
            }
            function isSuperContainer(node) {
                const kind = node.kind;
                return kind === 263 /* ClassDeclaration */ || kind === 176 /* Constructor */ || kind === 174 /* MethodDeclaration */ || kind === 177 /* GetAccessor */ || kind === 178 /* SetAccessor */;
            }
            function createSuperElementAccessInAsyncMethod(argumentExpression, location) {
                if (enclosingSuperContainerFlags & 256 /* MethodWithSuperPropertyAssignmentInAsync */) {
                    return setTextRange(factory2.createPropertyAccessExpression(factory2.createCallExpression(factory2.createUniqueName("_superIndex", 16 /* Optimistic */ | 32 /* FileLevel */), 
                    /*typeArguments*/
                    void 0, [argumentExpression]), "value"), location);
                }
                else {
                    return setTextRange(factory2.createCallExpression(factory2.createUniqueName("_superIndex", 16 /* Optimistic */ | 32 /* FileLevel */), 
                    /*typeArguments*/
                    void 0, [argumentExpression]), location);
                }
            }
        }
        function createSuperAccessVariableStatement(factory2, resolver, node, names) {
            const hasBinding = (resolver.getNodeCheckFlags(node) & 256 /* MethodWithSuperPropertyAssignmentInAsync */) !== 0;
            const accessors = [];
            names.forEach((_, key) => {
                const name = unescapeLeadingUnderscores(key);
                const getterAndSetter = [];
                getterAndSetter.push(factory2.createPropertyAssignment("get", factory2.createArrowFunction(
                /*modifiers*/
                void 0, 
                /*typeParameters*/
                void 0, 
                /* parameters */
                [], 
                /*type*/
                void 0, 
                /*equalsGreaterThanToken*/
                void 0, setEmitFlags(factory2.createPropertyAccessExpression(setEmitFlags(factory2.createSuper(), 8 /* NoSubstitution */), name), 8 /* NoSubstitution */))));
                if (hasBinding) {
                    getterAndSetter.push(factory2.createPropertyAssignment("set", factory2.createArrowFunction(
                    /*modifiers*/
                    void 0, 
                    /*typeParameters*/
                    void 0, 
                    /* parameters */
                    [
                        factory2.createParameterDeclaration(
                        /*modifiers*/
                        void 0, 
                        /*dotDotDotToken*/
                        void 0, "v", 
                        /*questionToken*/
                        void 0, 
                        /*type*/
                        void 0, 
                        /*initializer*/
                        void 0)
                    ], 
                    /*type*/
                    void 0, 
                    /*equalsGreaterThanToken*/
                    void 0, factory2.createAssignment(setEmitFlags(factory2.createPropertyAccessExpression(setEmitFlags(factory2.createSuper(), 8 /* NoSubstitution */), name), 8 /* NoSubstitution */), factory2.createIdentifier("v")))));
                }
                accessors.push(factory2.createPropertyAssignment(name, factory2.createObjectLiteralExpression(getterAndSetter)));
            });
            return factory2.createVariableStatement(
            /*modifiers*/
            void 0, factory2.createVariableDeclarationList([
                factory2.createVariableDeclaration(factory2.createUniqueName("_super", 16 /* Optimistic */ | 32 /* FileLevel */), 
                /*exclamationToken*/
                void 0, 
                /*type*/
                void 0, factory2.createCallExpression(factory2.createPropertyAccessExpression(factory2.createIdentifier("Object"), "create"), 
                /*typeArguments*/
                void 0, [
                    factory2.createNull(),
                    factory2.createObjectLiteralExpression(accessors, 
                    /*multiLine*/
                    true)
                ]))
            ], 2 /* Const */));
        }
        var init_es2017 = __esm({
            "src/compiler/transformers/es2017.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/es2018.ts
        function transformES2018(context) {
            const { factory: factory2, getEmitHelperFactory: emitHelpers, resumeLexicalEnvironment, endLexicalEnvironment, hoistVariableDeclaration } = context;
            const resolver = context.getEmitResolver();
            const compilerOptions = context.getCompilerOptions();
            const languageVersion = getEmitScriptTarget(compilerOptions);
            const previousOnEmitNode = context.onEmitNode;
            context.onEmitNode = onEmitNode;
            const previousOnSubstituteNode = context.onSubstituteNode;
            context.onSubstituteNode = onSubstituteNode;
            let exportedVariableStatement = false;
            let enabledSubstitutions;
            let enclosingFunctionFlags;
            let parametersWithPrecedingObjectRestOrSpread;
            let enclosingSuperContainerFlags = 0;
            let hierarchyFacts = 0;
            let currentSourceFile;
            let taggedTemplateStringDeclarations;
            let capturedSuperProperties;
            let hasSuperElementAccess;
            const substitutedSuperAccessors = [];
            return chainBundle(context, transformSourceFile);
            function affectsSubtree(excludeFacts, includeFacts) {
                return hierarchyFacts !== (hierarchyFacts & ~excludeFacts | includeFacts);
            }
            function enterSubtree(excludeFacts, includeFacts) {
                const ancestorFacts = hierarchyFacts;
                hierarchyFacts = (hierarchyFacts & ~excludeFacts | includeFacts) & 3 /* AncestorFactsMask */;
                return ancestorFacts;
            }
            function exitSubtree(ancestorFacts) {
                hierarchyFacts = ancestorFacts;
            }
            function recordTaggedTemplateString(temp) {
                taggedTemplateStringDeclarations = append(taggedTemplateStringDeclarations, factory2.createVariableDeclaration(temp));
            }
            function transformSourceFile(node) {
                if (node.isDeclarationFile) {
                    return node;
                }
                currentSourceFile = node;
                const visited = visitSourceFile(node);
                addEmitHelpers(visited, context.readEmitHelpers());
                currentSourceFile = void 0;
                taggedTemplateStringDeclarations = void 0;
                return visited;
            }
            function visitor(node) {
                return visitorWorker(node, 
                /*expressionResultIsUnused*/
                false);
            }
            function visitorWithUnusedExpressionResult(node) {
                return visitorWorker(node, 
                /*expressionResultIsUnused*/
                true);
            }
            function visitorNoAsyncModifier(node) {
                if (node.kind === 134 /* AsyncKeyword */) {
                    return void 0;
                }
                return node;
            }
            function doWithHierarchyFacts(cb, value, excludeFacts, includeFacts) {
                if (affectsSubtree(excludeFacts, includeFacts)) {
                    const ancestorFacts = enterSubtree(excludeFacts, includeFacts);
                    const result = cb(value);
                    exitSubtree(ancestorFacts);
                    return result;
                }
                return cb(value);
            }
            function visitDefault(node) {
                return visitEachChild(node, visitor, context);
            }
            function visitorWorker(node, expressionResultIsUnused2) {
                if ((node.transformFlags & 128 /* ContainsES2018 */) === 0) {
                    return node;
                }
                switch (node.kind) {
                    case 223 /* AwaitExpression */:
                        return visitAwaitExpression(node);
                    case 229 /* YieldExpression */:
                        return visitYieldExpression(node);
                    case 253 /* ReturnStatement */:
                        return visitReturnStatement(node);
                    case 256 /* LabeledStatement */:
                        return visitLabeledStatement(node);
                    case 210 /* ObjectLiteralExpression */:
                        return visitObjectLiteralExpression(node);
                    case 226 /* BinaryExpression */:
                        return visitBinaryExpression(node, expressionResultIsUnused2);
                    case 361 /* CommaListExpression */:
                        return visitCommaListExpression(node, expressionResultIsUnused2);
                    case 299 /* CatchClause */:
                        return visitCatchClause(node);
                    case 243 /* VariableStatement */:
                        return visitVariableStatement(node);
                    case 260 /* VariableDeclaration */:
                        return visitVariableDeclaration(node);
                    case 246 /* DoStatement */:
                    case 247 /* WhileStatement */:
                    case 249 /* ForInStatement */:
                        return doWithHierarchyFacts(visitDefault, node, 0 /* IterationStatementExcludes */, 2 /* IterationStatementIncludes */);
                    case 250 /* ForOfStatement */:
                        return visitForOfStatement(node, 
                        /*outermostLabeledStatement*/
                        void 0);
                    case 248 /* ForStatement */:
                        return doWithHierarchyFacts(visitForStatement, node, 0 /* IterationStatementExcludes */, 2 /* IterationStatementIncludes */);
                    case 222 /* VoidExpression */:
                        return visitVoidExpression(node);
                    case 176 /* Constructor */:
                        return doWithHierarchyFacts(visitConstructorDeclaration, node, 2 /* ClassOrFunctionExcludes */, 1 /* ClassOrFunctionIncludes */);
                    case 174 /* MethodDeclaration */:
                        return doWithHierarchyFacts(visitMethodDeclaration, node, 2 /* ClassOrFunctionExcludes */, 1 /* ClassOrFunctionIncludes */);
                    case 177 /* GetAccessor */:
                        return doWithHierarchyFacts(visitGetAccessorDeclaration, node, 2 /* ClassOrFunctionExcludes */, 1 /* ClassOrFunctionIncludes */);
                    case 178 /* SetAccessor */:
                        return doWithHierarchyFacts(visitSetAccessorDeclaration, node, 2 /* ClassOrFunctionExcludes */, 1 /* ClassOrFunctionIncludes */);
                    case 262 /* FunctionDeclaration */:
                        return doWithHierarchyFacts(visitFunctionDeclaration, node, 2 /* ClassOrFunctionExcludes */, 1 /* ClassOrFunctionIncludes */);
                    case 218 /* FunctionExpression */:
                        return doWithHierarchyFacts(visitFunctionExpression, node, 2 /* ClassOrFunctionExcludes */, 1 /* ClassOrFunctionIncludes */);
                    case 219 /* ArrowFunction */:
                        return doWithHierarchyFacts(visitArrowFunction, node, 2 /* ArrowFunctionExcludes */, 0 /* ArrowFunctionIncludes */);
                    case 169 /* Parameter */:
                        return visitParameter(node);
                    case 244 /* ExpressionStatement */:
                        return visitExpressionStatement(node);
                    case 217 /* ParenthesizedExpression */:
                        return visitParenthesizedExpression(node, expressionResultIsUnused2);
                    case 215 /* TaggedTemplateExpression */:
                        return visitTaggedTemplateExpression(node);
                    case 211 /* PropertyAccessExpression */:
                        if (capturedSuperProperties && isPropertyAccessExpression(node) && node.expression.kind === 108 /* SuperKeyword */) {
                            capturedSuperProperties.add(node.name.escapedText);
                        }
                        return visitEachChild(node, visitor, context);
                    case 212 /* ElementAccessExpression */:
                        if (capturedSuperProperties && node.expression.kind === 108 /* SuperKeyword */) {
                            hasSuperElementAccess = true;
                        }
                        return visitEachChild(node, visitor, context);
                    case 263 /* ClassDeclaration */:
                    case 231 /* ClassExpression */:
                        return doWithHierarchyFacts(visitDefault, node, 2 /* ClassOrFunctionExcludes */, 1 /* ClassOrFunctionIncludes */);
                    default:
                        return visitEachChild(node, visitor, context);
                }
            }
            function visitAwaitExpression(node) {
                if (enclosingFunctionFlags & 2 /* Async */ && enclosingFunctionFlags & 1 /* Generator */) {
                    return setOriginalNode(setTextRange(factory2.createYieldExpression(
                    /*asteriskToken*/
                    void 0, emitHelpers().createAwaitHelper(visitNode(node.expression, visitor, isExpression))), 
                    /*location*/
                    node), node);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitYieldExpression(node) {
                if (enclosingFunctionFlags & 2 /* Async */ && enclosingFunctionFlags & 1 /* Generator */) {
                    if (node.asteriskToken) {
                        const expression = visitNode(Debug.checkDefined(node.expression), visitor, isExpression);
                        return setOriginalNode(setTextRange(factory2.createYieldExpression(
                        /*asteriskToken*/
                        void 0, emitHelpers().createAwaitHelper(factory2.updateYieldExpression(node, node.asteriskToken, setTextRange(emitHelpers().createAsyncDelegatorHelper(setTextRange(emitHelpers().createAsyncValuesHelper(expression), expression)), expression)))), node), node);
                    }
                    return setOriginalNode(setTextRange(factory2.createYieldExpression(
                    /*asteriskToken*/
                    void 0, createDownlevelAwait(node.expression ? visitNode(node.expression, visitor, isExpression) : factory2.createVoidZero())), node), node);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitReturnStatement(node) {
                if (enclosingFunctionFlags & 2 /* Async */ && enclosingFunctionFlags & 1 /* Generator */) {
                    return factory2.updateReturnStatement(node, createDownlevelAwait(node.expression ? visitNode(node.expression, visitor, isExpression) : factory2.createVoidZero()));
                }
                return visitEachChild(node, visitor, context);
            }
            function visitLabeledStatement(node) {
                if (enclosingFunctionFlags & 2 /* Async */) {
                    const statement = unwrapInnermostStatementOfLabel(node);
                    if (statement.kind === 250 /* ForOfStatement */ && statement.awaitModifier) {
                        return visitForOfStatement(statement, node);
                    }
                    return factory2.restoreEnclosingLabel(visitNode(statement, visitor, isStatement, factory2.liftToBlock), node);
                }
                return visitEachChild(node, visitor, context);
            }
            function chunkObjectLiteralElements(elements) {
                let chunkObject;
                const objects = [];
                for (const e of elements) {
                    if (e.kind === 305 /* SpreadAssignment */) {
                        if (chunkObject) {
                            objects.push(factory2.createObjectLiteralExpression(chunkObject));
                            chunkObject = void 0;
                        }
                        const target = e.expression;
                        objects.push(visitNode(target, visitor, isExpression));
                    }
                    else {
                        chunkObject = append(chunkObject, e.kind === 303 /* PropertyAssignment */ ? factory2.createPropertyAssignment(e.name, visitNode(e.initializer, visitor, isExpression)) : visitNode(e, visitor, isObjectLiteralElementLike));
                    }
                }
                if (chunkObject) {
                    objects.push(factory2.createObjectLiteralExpression(chunkObject));
                }
                return objects;
            }
            function visitObjectLiteralExpression(node) {
                if (node.transformFlags & 65536 /* ContainsObjectRestOrSpread */) {
                    const objects = chunkObjectLiteralElements(node.properties);
                    if (objects.length && objects[0].kind !== 210 /* ObjectLiteralExpression */) {
                        objects.unshift(factory2.createObjectLiteralExpression());
                    }
                    let expression = objects[0];
                    if (objects.length > 1) {
                        for (let i = 1; i < objects.length; i++) {
                            expression = emitHelpers().createAssignHelper([expression, objects[i]]);
                        }
                        return expression;
                    }
                    else {
                        return emitHelpers().createAssignHelper(objects);
                    }
                }
                return visitEachChild(node, visitor, context);
            }
            function visitExpressionStatement(node) {
                return visitEachChild(node, visitorWithUnusedExpressionResult, context);
            }
            function visitParenthesizedExpression(node, expressionResultIsUnused2) {
                return visitEachChild(node, expressionResultIsUnused2 ? visitorWithUnusedExpressionResult : visitor, context);
            }
            function visitSourceFile(node) {
                const ancestorFacts = enterSubtree(2 /* SourceFileExcludes */, isEffectiveStrictModeSourceFile(node, compilerOptions) ? 0 /* StrictModeSourceFileIncludes */ : 1 /* SourceFileIncludes */);
                exportedVariableStatement = false;
                const visited = visitEachChild(node, visitor, context);
                const statement = concatenate(visited.statements, taggedTemplateStringDeclarations && [
                    factory2.createVariableStatement(
                    /*modifiers*/
                    void 0, factory2.createVariableDeclarationList(taggedTemplateStringDeclarations))
                ]);
                const result = factory2.updateSourceFile(visited, setTextRange(factory2.createNodeArray(statement), node.statements));
                exitSubtree(ancestorFacts);
                return result;
            }
            function visitTaggedTemplateExpression(node) {
                return processTaggedTemplateExpression(context, node, visitor, currentSourceFile, recordTaggedTemplateString, 0 /* LiftRestriction */);
            }
            function visitBinaryExpression(node, expressionResultIsUnused2) {
                if (isDestructuringAssignment(node) && containsObjectRestOrSpread(node.left)) {
                    return flattenDestructuringAssignment(node, visitor, context, 1 /* ObjectRest */, !expressionResultIsUnused2);
                }
                if (node.operatorToken.kind === 28 /* CommaToken */) {
                    return factory2.updateBinaryExpression(node, visitNode(node.left, visitorWithUnusedExpressionResult, isExpression), node.operatorToken, visitNode(node.right, expressionResultIsUnused2 ? visitorWithUnusedExpressionResult : visitor, isExpression));
                }
                return visitEachChild(node, visitor, context);
            }
            function visitCommaListExpression(node, expressionResultIsUnused2) {
                if (expressionResultIsUnused2) {
                    return visitEachChild(node, visitorWithUnusedExpressionResult, context);
                }
                let result;
                for (let i = 0; i < node.elements.length; i++) {
                    const element = node.elements[i];
                    const visited = visitNode(element, i < node.elements.length - 1 ? visitorWithUnusedExpressionResult : visitor, isExpression);
                    if (result || visited !== element) {
                        result || (result = node.elements.slice(0, i));
                        result.push(visited);
                    }
                }
                const elements = result ? setTextRange(factory2.createNodeArray(result), node.elements) : node.elements;
                return factory2.updateCommaListExpression(node, elements);
            }
            function visitCatchClause(node) {
                if (node.variableDeclaration && isBindingPattern(node.variableDeclaration.name) && node.variableDeclaration.name.transformFlags & 65536 /* ContainsObjectRestOrSpread */) {
                    const name = factory2.getGeneratedNameForNode(node.variableDeclaration.name);
                    const updatedDecl = factory2.updateVariableDeclaration(node.variableDeclaration, node.variableDeclaration.name, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, name);
                    const visitedBindings = flattenDestructuringBinding(updatedDecl, visitor, context, 1 /* ObjectRest */);
                    let block = visitNode(node.block, visitor, isBlock);
                    if (some(visitedBindings)) {
                        block = factory2.updateBlock(block, [
                            factory2.createVariableStatement(
                            /*modifiers*/
                            void 0, visitedBindings),
                            ...block.statements
                        ]);
                    }
                    return factory2.updateCatchClause(node, factory2.updateVariableDeclaration(node.variableDeclaration, name, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, 
                    /*initializer*/
                    void 0), block);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitVariableStatement(node) {
                if (hasSyntacticModifier(node, 32 /* Export */)) {
                    const savedExportedVariableStatement = exportedVariableStatement;
                    exportedVariableStatement = true;
                    const visited = visitEachChild(node, visitor, context);
                    exportedVariableStatement = savedExportedVariableStatement;
                    return visited;
                }
                return visitEachChild(node, visitor, context);
            }
            function visitVariableDeclaration(node) {
                if (exportedVariableStatement) {
                    const savedExportedVariableStatement = exportedVariableStatement;
                    exportedVariableStatement = false;
                    const visited = visitVariableDeclarationWorker(node, 
                    /*exportedVariableStatement*/
                    true);
                    exportedVariableStatement = savedExportedVariableStatement;
                    return visited;
                }
                return visitVariableDeclarationWorker(node, 
                /*exportedVariableStatement*/
                false);
            }
            function visitVariableDeclarationWorker(node, exportedVariableStatement2) {
                if (isBindingPattern(node.name) && node.name.transformFlags & 65536 /* ContainsObjectRestOrSpread */) {
                    return flattenDestructuringBinding(node, visitor, context, 1 /* ObjectRest */, 
                    /*rval*/
                    void 0, exportedVariableStatement2);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitForStatement(node) {
                return factory2.updateForStatement(node, visitNode(node.initializer, visitorWithUnusedExpressionResult, isForInitializer), visitNode(node.condition, visitor, isExpression), visitNode(node.incrementor, visitorWithUnusedExpressionResult, isExpression), visitIterationBody(node.statement, visitor, context));
            }
            function visitVoidExpression(node) {
                return visitEachChild(node, visitorWithUnusedExpressionResult, context);
            }
            function visitForOfStatement(node, outermostLabeledStatement) {
                const ancestorFacts = enterSubtree(0 /* IterationStatementExcludes */, 2 /* IterationStatementIncludes */);
                if (node.initializer.transformFlags & 65536 /* ContainsObjectRestOrSpread */ || isAssignmentPattern(node.initializer) && containsObjectRestOrSpread(node.initializer)) {
                    node = transformForOfStatementWithObjectRest(node);
                }
                const result = node.awaitModifier ? transformForAwaitOfStatement(node, outermostLabeledStatement, ancestorFacts) : factory2.restoreEnclosingLabel(visitEachChild(node, visitor, context), outermostLabeledStatement);
                exitSubtree(ancestorFacts);
                return result;
            }
            function transformForOfStatementWithObjectRest(node) {
                const initializerWithoutParens = skipParentheses(node.initializer);
                if (isVariableDeclarationList(initializerWithoutParens) || isAssignmentPattern(initializerWithoutParens)) {
                    let bodyLocation;
                    let statementsLocation;
                    const temp = factory2.createTempVariable(
                    /*recordTempVariable*/
                    void 0);
                    const statements = [createForOfBindingStatement(factory2, initializerWithoutParens, temp)];
                    if (isBlock(node.statement)) {
                        addRange(statements, node.statement.statements);
                        bodyLocation = node.statement;
                        statementsLocation = node.statement.statements;
                    }
                    else if (node.statement) {
                        append(statements, node.statement);
                        bodyLocation = node.statement;
                        statementsLocation = node.statement;
                    }
                    return factory2.updateForOfStatement(node, node.awaitModifier, setTextRange(factory2.createVariableDeclarationList([
                        setTextRange(factory2.createVariableDeclaration(temp), node.initializer)
                    ], 1 /* Let */), node.initializer), node.expression, setTextRange(factory2.createBlock(setTextRange(factory2.createNodeArray(statements), statementsLocation), 
                    /*multiLine*/
                    true), bodyLocation));
                }
                return node;
            }
            function convertForOfStatementHead(node, boundValue, nonUserCode) {
                const value = factory2.createTempVariable(hoistVariableDeclaration);
                const iteratorValueExpression = factory2.createAssignment(value, boundValue);
                const iteratorValueStatement = factory2.createExpressionStatement(iteratorValueExpression);
                setSourceMapRange(iteratorValueStatement, node.expression);
                const exitNonUserCodeExpression = factory2.createAssignment(nonUserCode, factory2.createFalse());
                const exitNonUserCodeStatement = factory2.createExpressionStatement(exitNonUserCodeExpression);
                setSourceMapRange(exitNonUserCodeStatement, node.expression);
                const statements = [iteratorValueStatement, exitNonUserCodeStatement];
                const binding = createForOfBindingStatement(factory2, node.initializer, value);
                statements.push(visitNode(binding, visitor, isStatement));
                let bodyLocation;
                let statementsLocation;
                const statement = visitIterationBody(node.statement, visitor, context);
                if (isBlock(statement)) {
                    addRange(statements, statement.statements);
                    bodyLocation = statement;
                    statementsLocation = statement.statements;
                }
                else {
                    statements.push(statement);
                }
                return setTextRange(factory2.createBlock(setTextRange(factory2.createNodeArray(statements), statementsLocation), 
                /*multiLine*/
                true), bodyLocation);
            }
            function createDownlevelAwait(expression) {
                return enclosingFunctionFlags & 1 /* Generator */ ? factory2.createYieldExpression(
                /*asteriskToken*/
                void 0, emitHelpers().createAwaitHelper(expression)) : factory2.createAwaitExpression(expression);
            }
            function transformForAwaitOfStatement(node, outermostLabeledStatement, ancestorFacts) {
                const expression = visitNode(node.expression, visitor, isExpression);
                const iterator = isIdentifier(expression) ? factory2.getGeneratedNameForNode(expression) : factory2.createTempVariable(
                /*recordTempVariable*/
                void 0);
                const result = isIdentifier(expression) ? factory2.getGeneratedNameForNode(iterator) : factory2.createTempVariable(
                /*recordTempVariable*/
                void 0);
                const nonUserCode = factory2.createTempVariable(
                /*recordTempVariable*/
                void 0);
                const done = factory2.createTempVariable(hoistVariableDeclaration);
                const errorRecord = factory2.createUniqueName("e");
                const catchVariable = factory2.getGeneratedNameForNode(errorRecord);
                const returnMethod = factory2.createTempVariable(
                /*recordTempVariable*/
                void 0);
                const callValues = setTextRange(emitHelpers().createAsyncValuesHelper(expression), node.expression);
                const callNext = factory2.createCallExpression(factory2.createPropertyAccessExpression(iterator, "next"), 
                /*typeArguments*/
                void 0, []);
                const getDone = factory2.createPropertyAccessExpression(result, "done");
                const getValue = factory2.createPropertyAccessExpression(result, "value");
                const callReturn = factory2.createFunctionCallCall(returnMethod, iterator, []);
                hoistVariableDeclaration(errorRecord);
                hoistVariableDeclaration(returnMethod);
                const initializer = ancestorFacts & 2 /* IterationContainer */ ? factory2.inlineExpressions([factory2.createAssignment(errorRecord, factory2.createVoidZero()), callValues]) : callValues;
                const forStatement = setEmitFlags(setTextRange(factory2.createForStatement(
                /*initializer*/
                setEmitFlags(setTextRange(factory2.createVariableDeclarationList([
                    factory2.createVariableDeclaration(nonUserCode, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, factory2.createTrue()),
                    setTextRange(factory2.createVariableDeclaration(iterator, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, initializer), node.expression),
                    factory2.createVariableDeclaration(result)
                ]), node.expression), 4194304 /* NoHoisting */), 
                /*condition*/
                factory2.inlineExpressions([
                    factory2.createAssignment(result, createDownlevelAwait(callNext)),
                    factory2.createAssignment(done, getDone),
                    factory2.createLogicalNot(done)
                ]), 
                /*incrementor*/
                factory2.createAssignment(nonUserCode, factory2.createTrue()), 
                /*statement*/
                convertForOfStatementHead(node, getValue, nonUserCode)), 
                /*location*/
                node), 512 /* NoTokenTrailingSourceMaps */);
                setOriginalNode(forStatement, node);
                return factory2.createTryStatement(factory2.createBlock([
                    factory2.restoreEnclosingLabel(forStatement, outermostLabeledStatement)
                ]), factory2.createCatchClause(factory2.createVariableDeclaration(catchVariable), setEmitFlags(factory2.createBlock([
                    factory2.createExpressionStatement(factory2.createAssignment(errorRecord, factory2.createObjectLiteralExpression([
                        factory2.createPropertyAssignment("error", catchVariable)
                    ])))
                ]), 1 /* SingleLine */)), factory2.createBlock([
                    factory2.createTryStatement(
                    /*tryBlock*/
                    factory2.createBlock([
                        setEmitFlags(factory2.createIfStatement(factory2.createLogicalAnd(factory2.createLogicalAnd(factory2.createLogicalNot(nonUserCode), factory2.createLogicalNot(done)), factory2.createAssignment(returnMethod, factory2.createPropertyAccessExpression(iterator, "return"))), factory2.createExpressionStatement(createDownlevelAwait(callReturn))), 1 /* SingleLine */)
                    ]), 
                    /*catchClause*/
                    void 0, 
                    /*finallyBlock*/
                    setEmitFlags(factory2.createBlock([
                        setEmitFlags(factory2.createIfStatement(errorRecord, factory2.createThrowStatement(factory2.createPropertyAccessExpression(errorRecord, "error"))), 1 /* SingleLine */)
                    ]), 1 /* SingleLine */))
                ]));
            }
            function parameterVisitor(node) {
                Debug.assertNode(node, isParameter);
                return visitParameter(node);
            }
            function visitParameter(node) {
                if (parametersWithPrecedingObjectRestOrSpread == null ? void 0 : parametersWithPrecedingObjectRestOrSpread.has(node)) {
                    return factory2.updateParameterDeclaration(node, 
                    /*modifiers*/
                    void 0, node.dotDotDotToken, isBindingPattern(node.name) ? factory2.getGeneratedNameForNode(node) : node.name, 
                    /*questionToken*/
                    void 0, 
                    /*type*/
                    void 0, 
                    /*initializer*/
                    void 0);
                }
                if (node.transformFlags & 65536 /* ContainsObjectRestOrSpread */) {
                    return factory2.updateParameterDeclaration(node, 
                    /*modifiers*/
                    void 0, node.dotDotDotToken, factory2.getGeneratedNameForNode(node), 
                    /*questionToken*/
                    void 0, 
                    /*type*/
                    void 0, visitNode(node.initializer, visitor, isExpression));
                }
                return visitEachChild(node, visitor, context);
            }
            function collectParametersWithPrecedingObjectRestOrSpread(node) {
                let parameters;
                for (const parameter of node.parameters) {
                    if (parameters) {
                        parameters.add(parameter);
                    }
                    else if (parameter.transformFlags & 65536 /* ContainsObjectRestOrSpread */) {
                        parameters = /* @__PURE__ */ new Set();
                    }
                }
                return parameters;
            }
            function visitConstructorDeclaration(node) {
                const savedEnclosingFunctionFlags = enclosingFunctionFlags;
                const savedParametersWithPrecedingObjectRestOrSpread = parametersWithPrecedingObjectRestOrSpread;
                enclosingFunctionFlags = getFunctionFlags(node);
                parametersWithPrecedingObjectRestOrSpread = collectParametersWithPrecedingObjectRestOrSpread(node);
                const updated = factory2.updateConstructorDeclaration(node, node.modifiers, visitParameterList(node.parameters, parameterVisitor, context), transformFunctionBody2(node));
                enclosingFunctionFlags = savedEnclosingFunctionFlags;
                parametersWithPrecedingObjectRestOrSpread = savedParametersWithPrecedingObjectRestOrSpread;
                return updated;
            }
            function visitGetAccessorDeclaration(node) {
                const savedEnclosingFunctionFlags = enclosingFunctionFlags;
                const savedParametersWithPrecedingObjectRestOrSpread = parametersWithPrecedingObjectRestOrSpread;
                enclosingFunctionFlags = getFunctionFlags(node);
                parametersWithPrecedingObjectRestOrSpread = collectParametersWithPrecedingObjectRestOrSpread(node);
                const updated = factory2.updateGetAccessorDeclaration(node, node.modifiers, visitNode(node.name, visitor, isPropertyName), visitParameterList(node.parameters, parameterVisitor, context), 
                /*type*/
                void 0, transformFunctionBody2(node));
                enclosingFunctionFlags = savedEnclosingFunctionFlags;
                parametersWithPrecedingObjectRestOrSpread = savedParametersWithPrecedingObjectRestOrSpread;
                return updated;
            }
            function visitSetAccessorDeclaration(node) {
                const savedEnclosingFunctionFlags = enclosingFunctionFlags;
                const savedParametersWithPrecedingObjectRestOrSpread = parametersWithPrecedingObjectRestOrSpread;
                enclosingFunctionFlags = getFunctionFlags(node);
                parametersWithPrecedingObjectRestOrSpread = collectParametersWithPrecedingObjectRestOrSpread(node);
                const updated = factory2.updateSetAccessorDeclaration(node, node.modifiers, visitNode(node.name, visitor, isPropertyName), visitParameterList(node.parameters, parameterVisitor, context), transformFunctionBody2(node));
                enclosingFunctionFlags = savedEnclosingFunctionFlags;
                parametersWithPrecedingObjectRestOrSpread = savedParametersWithPrecedingObjectRestOrSpread;
                return updated;
            }
            function visitMethodDeclaration(node) {
                const savedEnclosingFunctionFlags = enclosingFunctionFlags;
                const savedParametersWithPrecedingObjectRestOrSpread = parametersWithPrecedingObjectRestOrSpread;
                enclosingFunctionFlags = getFunctionFlags(node);
                parametersWithPrecedingObjectRestOrSpread = collectParametersWithPrecedingObjectRestOrSpread(node);
                const updated = factory2.updateMethodDeclaration(node, enclosingFunctionFlags & 1 /* Generator */ ? visitNodes2(node.modifiers, visitorNoAsyncModifier, isModifierLike) : node.modifiers, enclosingFunctionFlags & 2 /* Async */ ? void 0 : node.asteriskToken, visitNode(node.name, visitor, isPropertyName), visitNode(
                /*node*/
                void 0, visitor, isQuestionToken), 
                /*typeParameters*/
                void 0, enclosingFunctionFlags & 2 /* Async */ && enclosingFunctionFlags & 1 /* Generator */ ? transformAsyncGeneratorFunctionParameterList(node) : visitParameterList(node.parameters, parameterVisitor, context), 
                /*type*/
                void 0, enclosingFunctionFlags & 2 /* Async */ && enclosingFunctionFlags & 1 /* Generator */ ? transformAsyncGeneratorFunctionBody(node) : transformFunctionBody2(node));
                enclosingFunctionFlags = savedEnclosingFunctionFlags;
                parametersWithPrecedingObjectRestOrSpread = savedParametersWithPrecedingObjectRestOrSpread;
                return updated;
            }
            function visitFunctionDeclaration(node) {
                const savedEnclosingFunctionFlags = enclosingFunctionFlags;
                const savedParametersWithPrecedingObjectRestOrSpread = parametersWithPrecedingObjectRestOrSpread;
                enclosingFunctionFlags = getFunctionFlags(node);
                parametersWithPrecedingObjectRestOrSpread = collectParametersWithPrecedingObjectRestOrSpread(node);
                const updated = factory2.updateFunctionDeclaration(node, enclosingFunctionFlags & 1 /* Generator */ ? visitNodes2(node.modifiers, visitorNoAsyncModifier, isModifier) : node.modifiers, enclosingFunctionFlags & 2 /* Async */ ? void 0 : node.asteriskToken, node.name, 
                /*typeParameters*/
                void 0, enclosingFunctionFlags & 2 /* Async */ && enclosingFunctionFlags & 1 /* Generator */ ? transformAsyncGeneratorFunctionParameterList(node) : visitParameterList(node.parameters, parameterVisitor, context), 
                /*type*/
                void 0, enclosingFunctionFlags & 2 /* Async */ && enclosingFunctionFlags & 1 /* Generator */ ? transformAsyncGeneratorFunctionBody(node) : transformFunctionBody2(node));
                enclosingFunctionFlags = savedEnclosingFunctionFlags;
                parametersWithPrecedingObjectRestOrSpread = savedParametersWithPrecedingObjectRestOrSpread;
                return updated;
            }
            function visitArrowFunction(node) {
                const savedEnclosingFunctionFlags = enclosingFunctionFlags;
                const savedParametersWithPrecedingObjectRestOrSpread = parametersWithPrecedingObjectRestOrSpread;
                enclosingFunctionFlags = getFunctionFlags(node);
                parametersWithPrecedingObjectRestOrSpread = collectParametersWithPrecedingObjectRestOrSpread(node);
                const updated = factory2.updateArrowFunction(node, node.modifiers, 
                /*typeParameters*/
                void 0, visitParameterList(node.parameters, parameterVisitor, context), 
                /*type*/
                void 0, node.equalsGreaterThanToken, transformFunctionBody2(node));
                enclosingFunctionFlags = savedEnclosingFunctionFlags;
                parametersWithPrecedingObjectRestOrSpread = savedParametersWithPrecedingObjectRestOrSpread;
                return updated;
            }
            function visitFunctionExpression(node) {
                const savedEnclosingFunctionFlags = enclosingFunctionFlags;
                const savedParametersWithPrecedingObjectRestOrSpread = parametersWithPrecedingObjectRestOrSpread;
                enclosingFunctionFlags = getFunctionFlags(node);
                parametersWithPrecedingObjectRestOrSpread = collectParametersWithPrecedingObjectRestOrSpread(node);
                const updated = factory2.updateFunctionExpression(node, enclosingFunctionFlags & 1 /* Generator */ ? visitNodes2(node.modifiers, visitorNoAsyncModifier, isModifier) : node.modifiers, enclosingFunctionFlags & 2 /* Async */ ? void 0 : node.asteriskToken, node.name, 
                /*typeParameters*/
                void 0, enclosingFunctionFlags & 2 /* Async */ && enclosingFunctionFlags & 1 /* Generator */ ? transformAsyncGeneratorFunctionParameterList(node) : visitParameterList(node.parameters, parameterVisitor, context), 
                /*type*/
                void 0, enclosingFunctionFlags & 2 /* Async */ && enclosingFunctionFlags & 1 /* Generator */ ? transformAsyncGeneratorFunctionBody(node) : transformFunctionBody2(node));
                enclosingFunctionFlags = savedEnclosingFunctionFlags;
                parametersWithPrecedingObjectRestOrSpread = savedParametersWithPrecedingObjectRestOrSpread;
                return updated;
            }
            function transformAsyncGeneratorFunctionParameterList(node) {
                if (isSimpleParameterList(node.parameters)) {
                    return visitParameterList(node.parameters, visitor, context);
                }
                const newParameters = [];
                for (const parameter of node.parameters) {
                    if (parameter.initializer || parameter.dotDotDotToken) {
                        break;
                    }
                    const newParameter = factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, factory2.getGeneratedNameForNode(parameter.name, 8 /* ReservedInNestedScopes */));
                    newParameters.push(newParameter);
                }
                const newParametersArray = factory2.createNodeArray(newParameters);
                setTextRange(newParametersArray, node.parameters);
                return newParametersArray;
            }
            function transformAsyncGeneratorFunctionBody(node) {
                const innerParameters = !isSimpleParameterList(node.parameters) ? visitParameterList(node.parameters, visitor, context) : void 0;
                resumeLexicalEnvironment();
                const savedCapturedSuperProperties = capturedSuperProperties;
                const savedHasSuperElementAccess = hasSuperElementAccess;
                capturedSuperProperties = /* @__PURE__ */ new Set();
                hasSuperElementAccess = false;
                const outerStatements = [];
                let asyncBody = factory2.updateBlock(node.body, visitNodes2(node.body.statements, visitor, isStatement));
                asyncBody = factory2.updateBlock(asyncBody, factory2.mergeLexicalEnvironment(asyncBody.statements, appendObjectRestAssignmentsIfNeeded(endLexicalEnvironment(), node)));
                const returnStatement = factory2.createReturnStatement(emitHelpers().createAsyncGeneratorHelper(factory2.createFunctionExpression(
                /*modifiers*/
                void 0, factory2.createToken(42 /* AsteriskToken */), node.name && factory2.getGeneratedNameForNode(node.name), 
                /*typeParameters*/
                void 0, innerParameters ?? [], 
                /*type*/
                void 0, asyncBody), !!(hierarchyFacts & 1 /* HasLexicalThis */)));
                const emitSuperHelpers = languageVersion >= 2 /* ES2015 */ && resolver.getNodeCheckFlags(node) & (256 /* MethodWithSuperPropertyAssignmentInAsync */ | 128 /* MethodWithSuperPropertyAccessInAsync */);
                if (emitSuperHelpers) {
                    enableSubstitutionForAsyncMethodsWithSuper();
                    const variableStatement = createSuperAccessVariableStatement(factory2, resolver, node, capturedSuperProperties);
                    substitutedSuperAccessors[getNodeId(variableStatement)] = true;
                    insertStatementsAfterStandardPrologue(outerStatements, [variableStatement]);
                }
                outerStatements.push(returnStatement);
                const block = factory2.updateBlock(node.body, outerStatements);
                if (emitSuperHelpers && hasSuperElementAccess) {
                    if (resolver.getNodeCheckFlags(node) & 256 /* MethodWithSuperPropertyAssignmentInAsync */) {
                        addEmitHelper(block, advancedAsyncSuperHelper);
                    }
                    else if (resolver.getNodeCheckFlags(node) & 128 /* MethodWithSuperPropertyAccessInAsync */) {
                        addEmitHelper(block, asyncSuperHelper);
                    }
                }
                capturedSuperProperties = savedCapturedSuperProperties;
                hasSuperElementAccess = savedHasSuperElementAccess;
                return block;
            }
            function transformFunctionBody2(node) {
                resumeLexicalEnvironment();
                let statementOffset = 0;
                const statements = [];
                const body = visitNode(node.body, visitor, isConciseBody) ?? factory2.createBlock([]);
                if (isBlock(body)) {
                    statementOffset = factory2.copyPrologue(body.statements, statements, 
                    /*ensureUseStrict*/
                    false, visitor);
                }
                addRange(statements, appendObjectRestAssignmentsIfNeeded(
                /*statements*/
                void 0, node));
                const leadingStatements = endLexicalEnvironment();
                if (statementOffset > 0 || some(statements) || some(leadingStatements)) {
                    const block = factory2.converters.convertToFunctionBlock(body, 
                    /*multiLine*/
                    true);
                    insertStatementsAfterStandardPrologue(statements, leadingStatements);
                    addRange(statements, block.statements.slice(statementOffset));
                    return factory2.updateBlock(block, setTextRange(factory2.createNodeArray(statements), block.statements));
                }
                return body;
            }
            function appendObjectRestAssignmentsIfNeeded(statements, node) {
                let containsPrecedingObjectRestOrSpread = false;
                for (const parameter of node.parameters) {
                    if (containsPrecedingObjectRestOrSpread) {
                        if (isBindingPattern(parameter.name)) {
                            if (parameter.name.elements.length > 0) {
                                const declarations = flattenDestructuringBinding(parameter, visitor, context, 0 /* All */, factory2.getGeneratedNameForNode(parameter));
                                if (some(declarations)) {
                                    const declarationList = factory2.createVariableDeclarationList(declarations);
                                    const statement = factory2.createVariableStatement(
                                    /*modifiers*/
                                    void 0, declarationList);
                                    setEmitFlags(statement, 2097152 /* CustomPrologue */);
                                    statements = append(statements, statement);
                                }
                            }
                            else if (parameter.initializer) {
                                const name = factory2.getGeneratedNameForNode(parameter);
                                const initializer = visitNode(parameter.initializer, visitor, isExpression);
                                const assignment = factory2.createAssignment(name, initializer);
                                const statement = factory2.createExpressionStatement(assignment);
                                setEmitFlags(statement, 2097152 /* CustomPrologue */);
                                statements = append(statements, statement);
                            }
                        }
                        else if (parameter.initializer) {
                            const name = factory2.cloneNode(parameter.name);
                            setTextRange(name, parameter.name);
                            setEmitFlags(name, 96 /* NoSourceMap */);
                            const initializer = visitNode(parameter.initializer, visitor, isExpression);
                            addEmitFlags(initializer, 96 /* NoSourceMap */ | 3072 /* NoComments */);
                            const assignment = factory2.createAssignment(name, initializer);
                            setTextRange(assignment, parameter);
                            setEmitFlags(assignment, 3072 /* NoComments */);
                            const block = factory2.createBlock([factory2.createExpressionStatement(assignment)]);
                            setTextRange(block, parameter);
                            setEmitFlags(block, 1 /* SingleLine */ | 64 /* NoTrailingSourceMap */ | 768 /* NoTokenSourceMaps */ | 3072 /* NoComments */);
                            const typeCheck = factory2.createTypeCheck(factory2.cloneNode(parameter.name), "undefined");
                            const statement = factory2.createIfStatement(typeCheck, block);
                            startOnNewLine(statement);
                            setTextRange(statement, parameter);
                            setEmitFlags(statement, 768 /* NoTokenSourceMaps */ | 64 /* NoTrailingSourceMap */ | 2097152 /* CustomPrologue */ | 3072 /* NoComments */);
                            statements = append(statements, statement);
                        }
                    }
                    else if (parameter.transformFlags & 65536 /* ContainsObjectRestOrSpread */) {
                        containsPrecedingObjectRestOrSpread = true;
                        const declarations = flattenDestructuringBinding(parameter, visitor, context, 1 /* ObjectRest */, factory2.getGeneratedNameForNode(parameter), 
                        /*hoistTempVariables*/
                        false, 
                        /*skipInitializer*/
                        true);
                        if (some(declarations)) {
                            const declarationList = factory2.createVariableDeclarationList(declarations);
                            const statement = factory2.createVariableStatement(
                            /*modifiers*/
                            void 0, declarationList);
                            setEmitFlags(statement, 2097152 /* CustomPrologue */);
                            statements = append(statements, statement);
                        }
                    }
                }
                return statements;
            }
            function enableSubstitutionForAsyncMethodsWithSuper() {
                if ((enabledSubstitutions & 1 /* AsyncMethodsWithSuper */) === 0) {
                    enabledSubstitutions |= 1 /* AsyncMethodsWithSuper */;
                    context.enableSubstitution(213 /* CallExpression */);
                    context.enableSubstitution(211 /* PropertyAccessExpression */);
                    context.enableSubstitution(212 /* ElementAccessExpression */);
                    context.enableEmitNotification(263 /* ClassDeclaration */);
                    context.enableEmitNotification(174 /* MethodDeclaration */);
                    context.enableEmitNotification(177 /* GetAccessor */);
                    context.enableEmitNotification(178 /* SetAccessor */);
                    context.enableEmitNotification(176 /* Constructor */);
                    context.enableEmitNotification(243 /* VariableStatement */);
                }
            }
            function onEmitNode(hint, node, emitCallback) {
                if (enabledSubstitutions & 1 /* AsyncMethodsWithSuper */ && isSuperContainer(node)) {
                    const superContainerFlags = resolver.getNodeCheckFlags(node) & (128 /* MethodWithSuperPropertyAccessInAsync */ | 256 /* MethodWithSuperPropertyAssignmentInAsync */);
                    if (superContainerFlags !== enclosingSuperContainerFlags) {
                        const savedEnclosingSuperContainerFlags = enclosingSuperContainerFlags;
                        enclosingSuperContainerFlags = superContainerFlags;
                        previousOnEmitNode(hint, node, emitCallback);
                        enclosingSuperContainerFlags = savedEnclosingSuperContainerFlags;
                        return;
                    }
                }
                else if (enabledSubstitutions && substitutedSuperAccessors[getNodeId(node)]) {
                    const savedEnclosingSuperContainerFlags = enclosingSuperContainerFlags;
                    enclosingSuperContainerFlags = 0;
                    previousOnEmitNode(hint, node, emitCallback);
                    enclosingSuperContainerFlags = savedEnclosingSuperContainerFlags;
                    return;
                }
                previousOnEmitNode(hint, node, emitCallback);
            }
            function onSubstituteNode(hint, node) {
                node = previousOnSubstituteNode(hint, node);
                if (hint === 1 /* Expression */ && enclosingSuperContainerFlags) {
                    return substituteExpression(node);
                }
                return node;
            }
            function substituteExpression(node) {
                switch (node.kind) {
                    case 211 /* PropertyAccessExpression */:
                        return substitutePropertyAccessExpression(node);
                    case 212 /* ElementAccessExpression */:
                        return substituteElementAccessExpression(node);
                    case 213 /* CallExpression */:
                        return substituteCallExpression(node);
                }
                return node;
            }
            function substitutePropertyAccessExpression(node) {
                if (node.expression.kind === 108 /* SuperKeyword */) {
                    return setTextRange(factory2.createPropertyAccessExpression(factory2.createUniqueName("_super", 16 /* Optimistic */ | 32 /* FileLevel */), node.name), node);
                }
                return node;
            }
            function substituteElementAccessExpression(node) {
                if (node.expression.kind === 108 /* SuperKeyword */) {
                    return createSuperElementAccessInAsyncMethod(node.argumentExpression, node);
                }
                return node;
            }
            function substituteCallExpression(node) {
                const expression = node.expression;
                if (isSuperProperty(expression)) {
                    const argumentExpression = isPropertyAccessExpression(expression) ? substitutePropertyAccessExpression(expression) : substituteElementAccessExpression(expression);
                    return factory2.createCallExpression(factory2.createPropertyAccessExpression(argumentExpression, "call"), 
                    /*typeArguments*/
                    void 0, [
                        factory2.createThis(),
                        ...node.arguments
                    ]);
                }
                return node;
            }
            function isSuperContainer(node) {
                const kind = node.kind;
                return kind === 263 /* ClassDeclaration */ || kind === 176 /* Constructor */ || kind === 174 /* MethodDeclaration */ || kind === 177 /* GetAccessor */ || kind === 178 /* SetAccessor */;
            }
            function createSuperElementAccessInAsyncMethod(argumentExpression, location) {
                if (enclosingSuperContainerFlags & 256 /* MethodWithSuperPropertyAssignmentInAsync */) {
                    return setTextRange(factory2.createPropertyAccessExpression(factory2.createCallExpression(factory2.createIdentifier("_superIndex"), 
                    /*typeArguments*/
                    void 0, [argumentExpression]), "value"), location);
                }
                else {
                    return setTextRange(factory2.createCallExpression(factory2.createIdentifier("_superIndex"), 
                    /*typeArguments*/
                    void 0, [argumentExpression]), location);
                }
            }
        }
        var init_es2018 = __esm({
            "src/compiler/transformers/es2018.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/es2019.ts
        function transformES2019(context) {
            const factory2 = context.factory;
            return chainBundle(context, transformSourceFile);
            function transformSourceFile(node) {
                if (node.isDeclarationFile) {
                    return node;
                }
                return visitEachChild(node, visitor, context);
            }
            function visitor(node) {
                if ((node.transformFlags & 64 /* ContainsES2019 */) === 0) {
                    return node;
                }
                switch (node.kind) {
                    case 299 /* CatchClause */:
                        return visitCatchClause(node);
                    default:
                        return visitEachChild(node, visitor, context);
                }
            }
            function visitCatchClause(node) {
                if (!node.variableDeclaration) {
                    return factory2.updateCatchClause(node, factory2.createVariableDeclaration(factory2.createTempVariable(
                    /*recordTempVariable*/
                    void 0)), visitNode(node.block, visitor, isBlock));
                }
                return visitEachChild(node, visitor, context);
            }
        }
        var init_es2019 = __esm({
            "src/compiler/transformers/es2019.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/es2020.ts
        function transformES2020(context) {
            const { factory: factory2, hoistVariableDeclaration } = context;
            return chainBundle(context, transformSourceFile);
            function transformSourceFile(node) {
                if (node.isDeclarationFile) {
                    return node;
                }
                return visitEachChild(node, visitor, context);
            }
            function visitor(node) {
                if ((node.transformFlags & 32 /* ContainsES2020 */) === 0) {
                    return node;
                }
                switch (node.kind) {
                    case 213 /* CallExpression */: {
                        const updated = visitNonOptionalCallExpression(node, 
                        /*captureThisArg*/
                        false);
                        Debug.assertNotNode(updated, isSyntheticReference);
                        return updated;
                    }
                    case 211 /* PropertyAccessExpression */:
                    case 212 /* ElementAccessExpression */:
                        if (isOptionalChain(node)) {
                            const updated = visitOptionalExpression(node, 
                            /*captureThisArg*/
                            false, 
                            /*isDelete*/
                            false);
                            Debug.assertNotNode(updated, isSyntheticReference);
                            return updated;
                        }
                        return visitEachChild(node, visitor, context);
                    case 226 /* BinaryExpression */:
                        if (node.operatorToken.kind === 61 /* QuestionQuestionToken */) {
                            return transformNullishCoalescingExpression(node);
                        }
                        return visitEachChild(node, visitor, context);
                    case 220 /* DeleteExpression */:
                        return visitDeleteExpression(node);
                    default:
                        return visitEachChild(node, visitor, context);
                }
            }
            function flattenChain(chain) {
                Debug.assertNotNode(chain, isNonNullChain);
                const links = [chain];
                while (!chain.questionDotToken && !isTaggedTemplateExpression(chain)) {
                    chain = cast(skipPartiallyEmittedExpressions(chain.expression), isOptionalChain);
                    Debug.assertNotNode(chain, isNonNullChain);
                    links.unshift(chain);
                }
                return { expression: chain.expression, chain: links };
            }
            function visitNonOptionalParenthesizedExpression(node, captureThisArg, isDelete) {
                const expression = visitNonOptionalExpression(node.expression, captureThisArg, isDelete);
                if (isSyntheticReference(expression)) {
                    return factory2.createSyntheticReferenceExpression(factory2.updateParenthesizedExpression(node, expression.expression), expression.thisArg);
                }
                return factory2.updateParenthesizedExpression(node, expression);
            }
            function visitNonOptionalPropertyOrElementAccessExpression(node, captureThisArg, isDelete) {
                if (isOptionalChain(node)) {
                    return visitOptionalExpression(node, captureThisArg, isDelete);
                }
                let expression = visitNode(node.expression, visitor, isExpression);
                Debug.assertNotNode(expression, isSyntheticReference);
                let thisArg;
                if (captureThisArg) {
                    if (!isSimpleCopiableExpression(expression)) {
                        thisArg = factory2.createTempVariable(hoistVariableDeclaration);
                        expression = factory2.createAssignment(thisArg, expression);
                    }
                    else {
                        thisArg = expression;
                    }
                }
                expression = node.kind === 211 /* PropertyAccessExpression */ ? factory2.updatePropertyAccessExpression(node, expression, visitNode(node.name, visitor, isIdentifier)) : factory2.updateElementAccessExpression(node, expression, visitNode(node.argumentExpression, visitor, isExpression));
                return thisArg ? factory2.createSyntheticReferenceExpression(expression, thisArg) : expression;
            }
            function visitNonOptionalCallExpression(node, captureThisArg) {
                if (isOptionalChain(node)) {
                    return visitOptionalExpression(node, captureThisArg, 
                    /*isDelete*/
                    false);
                }
                if (isParenthesizedExpression(node.expression) && isOptionalChain(skipParentheses(node.expression))) {
                    const expression = visitNonOptionalParenthesizedExpression(node.expression, 
                    /*captureThisArg*/
                    true, 
                    /*isDelete*/
                    false);
                    const args = visitNodes2(node.arguments, visitor, isExpression);
                    if (isSyntheticReference(expression)) {
                        return setTextRange(factory2.createFunctionCallCall(expression.expression, expression.thisArg, args), node);
                    }
                    return factory2.updateCallExpression(node, expression, 
                    /*typeArguments*/
                    void 0, args);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitNonOptionalExpression(node, captureThisArg, isDelete) {
                switch (node.kind) {
                    case 217 /* ParenthesizedExpression */:
                        return visitNonOptionalParenthesizedExpression(node, captureThisArg, isDelete);
                    case 211 /* PropertyAccessExpression */:
                    case 212 /* ElementAccessExpression */:
                        return visitNonOptionalPropertyOrElementAccessExpression(node, captureThisArg, isDelete);
                    case 213 /* CallExpression */:
                        return visitNonOptionalCallExpression(node, captureThisArg);
                    default:
                        return visitNode(node, visitor, isExpression);
                }
            }
            function visitOptionalExpression(node, captureThisArg, isDelete) {
                const { expression, chain } = flattenChain(node);
                const left = visitNonOptionalExpression(skipPartiallyEmittedExpressions(expression), isCallChain(chain[0]), 
                /*isDelete*/
                false);
                let leftThisArg = isSyntheticReference(left) ? left.thisArg : void 0;
                let capturedLeft = isSyntheticReference(left) ? left.expression : left;
                let leftExpression = factory2.restoreOuterExpressions(expression, capturedLeft, 8 /* PartiallyEmittedExpressions */);
                if (!isSimpleCopiableExpression(capturedLeft)) {
                    capturedLeft = factory2.createTempVariable(hoistVariableDeclaration);
                    leftExpression = factory2.createAssignment(capturedLeft, leftExpression);
                }
                let rightExpression = capturedLeft;
                let thisArg;
                for (let i = 0; i < chain.length; i++) {
                    const segment = chain[i];
                    switch (segment.kind) {
                        case 211 /* PropertyAccessExpression */:
                        case 212 /* ElementAccessExpression */:
                            if (i === chain.length - 1 && captureThisArg) {
                                if (!isSimpleCopiableExpression(rightExpression)) {
                                    thisArg = factory2.createTempVariable(hoistVariableDeclaration);
                                    rightExpression = factory2.createAssignment(thisArg, rightExpression);
                                }
                                else {
                                    thisArg = rightExpression;
                                }
                            }
                            rightExpression = segment.kind === 211 /* PropertyAccessExpression */ ? factory2.createPropertyAccessExpression(rightExpression, visitNode(segment.name, visitor, isIdentifier)) : factory2.createElementAccessExpression(rightExpression, visitNode(segment.argumentExpression, visitor, isExpression));
                            break;
                        case 213 /* CallExpression */:
                            if (i === 0 && leftThisArg) {
                                if (!isGeneratedIdentifier(leftThisArg)) {
                                    leftThisArg = factory2.cloneNode(leftThisArg);
                                    addEmitFlags(leftThisArg, 3072 /* NoComments */);
                                }
                                rightExpression = factory2.createFunctionCallCall(rightExpression, leftThisArg.kind === 108 /* SuperKeyword */ ? factory2.createThis() : leftThisArg, visitNodes2(segment.arguments, visitor, isExpression));
                            }
                            else {
                                rightExpression = factory2.createCallExpression(rightExpression, 
                                /*typeArguments*/
                                void 0, visitNodes2(segment.arguments, visitor, isExpression));
                            }
                            break;
                    }
                    setOriginalNode(rightExpression, segment);
                }
                const target = isDelete ? factory2.createConditionalExpression(createNotNullCondition(leftExpression, capturedLeft, 
                /*invert*/
                true), 
                /*questionToken*/
                void 0, factory2.createTrue(), 
                /*colonToken*/
                void 0, factory2.createDeleteExpression(rightExpression)) : factory2.createConditionalExpression(createNotNullCondition(leftExpression, capturedLeft, 
                /*invert*/
                true), 
                /*questionToken*/
                void 0, factory2.createVoidZero(), 
                /*colonToken*/
                void 0, rightExpression);
                setTextRange(target, node);
                return thisArg ? factory2.createSyntheticReferenceExpression(target, thisArg) : target;
            }
            function createNotNullCondition(left, right, invert) {
                return factory2.createBinaryExpression(factory2.createBinaryExpression(left, factory2.createToken(invert ? 37 /* EqualsEqualsEqualsToken */ : 38 /* ExclamationEqualsEqualsToken */), factory2.createNull()), factory2.createToken(invert ? 57 /* BarBarToken */ : 56 /* AmpersandAmpersandToken */), factory2.createBinaryExpression(right, factory2.createToken(invert ? 37 /* EqualsEqualsEqualsToken */ : 38 /* ExclamationEqualsEqualsToken */), factory2.createVoidZero()));
            }
            function transformNullishCoalescingExpression(node) {
                let left = visitNode(node.left, visitor, isExpression);
                let right = left;
                if (!isSimpleCopiableExpression(left)) {
                    right = factory2.createTempVariable(hoistVariableDeclaration);
                    left = factory2.createAssignment(right, left);
                }
                return setTextRange(factory2.createConditionalExpression(createNotNullCondition(left, right), 
                /*questionToken*/
                void 0, right, 
                /*colonToken*/
                void 0, visitNode(node.right, visitor, isExpression)), node);
            }
            function visitDeleteExpression(node) {
                return isOptionalChain(skipParentheses(node.expression)) ? setOriginalNode(visitNonOptionalExpression(node.expression, 
                /*captureThisArg*/
                false, 
                /*isDelete*/
                true), node) : factory2.updateDeleteExpression(node, visitNode(node.expression, visitor, isExpression));
            }
        }
        var init_es2020 = __esm({
            "src/compiler/transformers/es2020.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/es2021.ts
        function transformES2021(context) {
            const { hoistVariableDeclaration, factory: factory2 } = context;
            return chainBundle(context, transformSourceFile);
            function transformSourceFile(node) {
                if (node.isDeclarationFile) {
                    return node;
                }
                return visitEachChild(node, visitor, context);
            }
            function visitor(node) {
                if ((node.transformFlags & 16 /* ContainsES2021 */) === 0) {
                    return node;
                }
                if (isLogicalOrCoalescingAssignmentExpression(node)) {
                    return transformLogicalAssignment(node);
                }
                return visitEachChild(node, visitor, context);
            }
            function transformLogicalAssignment(binaryExpression) {
                const operator = binaryExpression.operatorToken;
                const nonAssignmentOperator = getNonAssignmentOperatorForCompoundAssignment(operator.kind);
                let left = skipParentheses(visitNode(binaryExpression.left, visitor, isLeftHandSideExpression));
                let assignmentTarget = left;
                const right = skipParentheses(visitNode(binaryExpression.right, visitor, isExpression));
                if (isAccessExpression(left)) {
                    const propertyAccessTargetSimpleCopiable = isSimpleCopiableExpression(left.expression);
                    const propertyAccessTarget = propertyAccessTargetSimpleCopiable ? left.expression : factory2.createTempVariable(hoistVariableDeclaration);
                    const propertyAccessTargetAssignment = propertyAccessTargetSimpleCopiable ? left.expression : factory2.createAssignment(propertyAccessTarget, left.expression);
                    if (isPropertyAccessExpression(left)) {
                        assignmentTarget = factory2.createPropertyAccessExpression(propertyAccessTarget, left.name);
                        left = factory2.createPropertyAccessExpression(propertyAccessTargetAssignment, left.name);
                    }
                    else {
                        const elementAccessArgumentSimpleCopiable = isSimpleCopiableExpression(left.argumentExpression);
                        const elementAccessArgument = elementAccessArgumentSimpleCopiable ? left.argumentExpression : factory2.createTempVariable(hoistVariableDeclaration);
                        assignmentTarget = factory2.createElementAccessExpression(propertyAccessTarget, elementAccessArgument);
                        left = factory2.createElementAccessExpression(propertyAccessTargetAssignment, elementAccessArgumentSimpleCopiable ? left.argumentExpression : factory2.createAssignment(elementAccessArgument, left.argumentExpression));
                    }
                }
                return factory2.createBinaryExpression(left, nonAssignmentOperator, factory2.createParenthesizedExpression(factory2.createAssignment(assignmentTarget, right)));
            }
        }
        var init_es2021 = __esm({
            "src/compiler/transformers/es2021.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/esnext.ts
        function transformESNext(context) {
            const { factory: factory2, getEmitHelperFactory: emitHelpers, hoistVariableDeclaration, startLexicalEnvironment, endLexicalEnvironment } = context;
            let exportBindings;
            let exportVars;
            let defaultExportBinding;
            let exportEqualsBinding;
            return chainBundle(context, transformSourceFile);
            function transformSourceFile(node) {
                if (node.isDeclarationFile) {
                    return node;
                }
                const visited = visitNode(node, visitor, isSourceFile);
                addEmitHelpers(visited, context.readEmitHelpers());
                exportVars = void 0;
                exportBindings = void 0;
                defaultExportBinding = void 0;
                return visited;
            }
            function visitor(node) {
                if ((node.transformFlags & 4 /* ContainsESNext */) === 0) {
                    return node;
                }
                switch (node.kind) {
                    case 312 /* SourceFile */:
                        return visitSourceFile(node);
                    case 241 /* Block */:
                        return visitBlock(node);
                    case 248 /* ForStatement */:
                        return visitForStatement(node);
                    case 250 /* ForOfStatement */:
                        return visitForOfStatement(node);
                    case 255 /* SwitchStatement */:
                        return visitSwitchStatement(node);
                    default:
                        return visitEachChild(node, visitor, context);
                }
            }
            function visitSourceFile(node) {
                const usingKind = getUsingKindOfStatements(node.statements);
                if (usingKind) {
                    startLexicalEnvironment();
                    exportBindings = new IdentifierNameMap();
                    exportVars = [];
                    const prologueCount = countPrologueStatements(node.statements);
                    const topLevelStatements = [];
                    addRange(topLevelStatements, visitArray(node.statements, visitor, isStatement, 0, prologueCount));
                    let pos = prologueCount;
                    while (pos < node.statements.length) {
                        const statement = node.statements[pos];
                        if (getUsingKind(statement) !== 0 /* None */) {
                            if (pos > prologueCount) {
                                addRange(topLevelStatements, visitNodes2(node.statements, visitor, isStatement, prologueCount, pos - prologueCount));
                            }
                            break;
                        }
                        pos++;
                    }
                    Debug.assert(pos < node.statements.length, "Should have encountered at least one 'using' statement.");
                    const envBinding = createEnvBinding();
                    const bodyStatements = transformUsingDeclarations(node.statements, pos, node.statements.length, envBinding, topLevelStatements);
                    if (exportBindings.size) {
                        append(topLevelStatements, factory2.createExportDeclaration(
                        /*modifiers*/
                        void 0, 
                        /*isTypeOnly*/
                        false, factory2.createNamedExports(arrayFrom(exportBindings.values()))));
                    }
                    addRange(topLevelStatements, endLexicalEnvironment());
                    if (exportVars.length) {
                        topLevelStatements.push(factory2.createVariableStatement(factory2.createModifiersFromModifierFlags(32 /* Export */), factory2.createVariableDeclarationList(exportVars, 1 /* Let */)));
                    }
                    addRange(topLevelStatements, createDownlevelUsingStatements(bodyStatements, envBinding, usingKind === 2 /* Async */));
                    if (exportEqualsBinding) {
                        topLevelStatements.push(factory2.createExportAssignment(
                        /*modifiers*/
                        void 0, 
                        /*isExportEquals*/
                        true, exportEqualsBinding));
                    }
                    return factory2.updateSourceFile(node, topLevelStatements);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitBlock(node) {
                const usingKind = getUsingKindOfStatements(node.statements);
                if (usingKind) {
                    const prologueCount = countPrologueStatements(node.statements);
                    const envBinding = createEnvBinding();
                    return factory2.updateBlock(node, [
                        ...visitArray(node.statements, visitor, isStatement, 0, prologueCount),
                        ...createDownlevelUsingStatements(transformUsingDeclarations(node.statements, prologueCount, node.statements.length, envBinding, 
                        /*topLevelStatements*/
                        void 0), envBinding, usingKind === 2 /* Async */)
                    ]);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitForStatement(node) {
                if (node.initializer && isUsingVariableDeclarationList(node.initializer)) {
                    return visitNode(factory2.createBlock([
                        factory2.createVariableStatement(
                        /*modifiers*/
                        void 0, node.initializer),
                        factory2.updateForStatement(node, 
                        /*initializer*/
                        void 0, node.condition, node.incrementor, node.statement)
                    ]), visitor, isStatement);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitForOfStatement(node) {
                if (isUsingVariableDeclarationList(node.initializer)) {
                    const forInitializer = node.initializer;
                    Debug.assertNode(forInitializer, isUsingVariableDeclarationList);
                    Debug.assert(forInitializer.declarations.length === 1, "ForInitializer may only have one declaration");
                    const forDecl = forInitializer.declarations[0];
                    Debug.assert(!forDecl.initializer, "ForInitializer may not have an initializer");
                    const isAwaitUsing = getUsingKindOfVariableDeclarationList(forInitializer) === 2 /* Async */;
                    const temp = factory2.getGeneratedNameForNode(forDecl.name);
                    const usingVar = factory2.updateVariableDeclaration(forDecl, forDecl.name, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, temp);
                    const usingVarList = factory2.createVariableDeclarationList([usingVar], isAwaitUsing ? 6 /* AwaitUsing */ : 4 /* Using */);
                    const usingVarStatement = factory2.createVariableStatement(
                    /*modifiers*/
                    void 0, usingVarList);
                    return visitNode(factory2.updateForOfStatement(node, node.awaitModifier, factory2.createVariableDeclarationList([
                        factory2.createVariableDeclaration(temp)
                    ], 2 /* Const */), node.expression, isBlock(node.statement) ? factory2.updateBlock(node.statement, [
                        usingVarStatement,
                        ...node.statement.statements
                    ]) : factory2.createBlock([
                        usingVarStatement,
                        node.statement
                    ], 
                    /*multiLine*/
                    true)), visitor, isStatement);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitCaseOrDefaultClause(node, envBinding) {
                if (getUsingKindOfStatements(node.statements) !== 0 /* None */) {
                    if (isCaseClause(node)) {
                        return factory2.updateCaseClause(node, visitNode(node.expression, visitor, isExpression), transformUsingDeclarations(node.statements, 
                        /*start*/
                        0, node.statements.length, envBinding, 
                        /*topLevelStatements*/
                        void 0));
                    }
                    else {
                        return factory2.updateDefaultClause(node, transformUsingDeclarations(node.statements, 
                        /*start*/
                        0, node.statements.length, envBinding, 
                        /*topLevelStatements*/
                        void 0));
                    }
                }
                return visitEachChild(node, visitor, context);
            }
            function visitSwitchStatement(node) {
                const usingKind = getUsingKindOfCaseOrDefaultClauses(node.caseBlock.clauses);
                if (usingKind) {
                    const envBinding = createEnvBinding();
                    return createDownlevelUsingStatements([
                        factory2.updateSwitchStatement(node, visitNode(node.expression, visitor, isExpression), factory2.updateCaseBlock(node.caseBlock, node.caseBlock.clauses.map((clause) => visitCaseOrDefaultClause(clause, envBinding))))
                    ], envBinding, usingKind === 2 /* Async */);
                }
                return visitEachChild(node, visitor, context);
            }
            function transformUsingDeclarations(statementsIn, start, end, envBinding, topLevelStatements) {
                const statements = [];
                for (let i = start; i < end; i++) {
                    const statement = statementsIn[i];
                    const usingKind = getUsingKind(statement);
                    if (usingKind) {
                        Debug.assertNode(statement, isVariableStatement);
                        const declarations = [];
                        for (let declaration of statement.declarationList.declarations) {
                            if (!isIdentifier(declaration.name)) {
                                declarations.length = 0;
                                break;
                            }
                            if (isNamedEvaluation(declaration)) {
                                declaration = transformNamedEvaluation(context, declaration);
                            }
                            const initializer = visitNode(declaration.initializer, visitor, isExpression) ?? factory2.createVoidZero();
                            declarations.push(factory2.updateVariableDeclaration(declaration, declaration.name, 
                            /*exclamationToken*/
                            void 0, 
                            /*type*/
                            void 0, emitHelpers().createAddDisposableResourceHelper(envBinding, initializer, usingKind === 2 /* Async */)));
                        }
                        if (declarations.length) {
                            const varList = factory2.createVariableDeclarationList(declarations, 2 /* Const */);
                            setOriginalNode(varList, statement.declarationList);
                            setTextRange(varList, statement.declarationList);
                            hoistOrAppendNode(factory2.updateVariableStatement(statement, 
                            /*modifiers*/
                            void 0, varList));
                            continue;
                        }
                    }
                    const result = visitor(statement);
                    if (isArray(result)) {
                        result.forEach(hoistOrAppendNode);
                    }
                    else if (result) {
                        hoistOrAppendNode(result);
                    }
                }
                return statements;
                function hoistOrAppendNode(node) {
                    Debug.assertNode(node, isStatement);
                    append(statements, hoist(node));
                }
                function hoist(node) {
                    if (!topLevelStatements)
                        return node;
                    switch (node.kind) {
                        case 272 /* ImportDeclaration */:
                        case 271 /* ImportEqualsDeclaration */:
                        case 278 /* ExportDeclaration */:
                        case 262 /* FunctionDeclaration */:
                            return hoistImportOrExportOrHoistedDeclaration(node, topLevelStatements);
                        case 277 /* ExportAssignment */:
                            return hoistExportAssignment(node);
                        case 263 /* ClassDeclaration */:
                            return hoistClassDeclaration(node);
                        case 243 /* VariableStatement */:
                            return hoistVariableStatement(node);
                    }
                    return node;
                }
            }
            function hoistImportOrExportOrHoistedDeclaration(node, topLevelStatements) {
                topLevelStatements.push(node);
                return void 0;
            }
            function hoistExportAssignment(node) {
                return node.isExportEquals ? hoistExportEquals(node) : hoistExportDefault(node);
            }
            function hoistExportDefault(node) {
                if (defaultExportBinding) {
                    return node;
                }
                defaultExportBinding = factory2.createUniqueName("_default", 8 /* ReservedInNestedScopes */ | 32 /* FileLevel */ | 16 /* Optimistic */);
                hoistBindingIdentifier(defaultExportBinding, 
                /*isExport*/
                true, "default", node);
                let expression = node.expression;
                let innerExpression = skipOuterExpressions(expression);
                if (isNamedEvaluation(innerExpression)) {
                    innerExpression = transformNamedEvaluation(context, innerExpression, 
                    /*ignoreEmptyStringLiteral*/
                    false, "default");
                    expression = factory2.restoreOuterExpressions(expression, innerExpression);
                }
                const assignment = factory2.createAssignment(defaultExportBinding, expression);
                return factory2.createExpressionStatement(assignment);
            }
            function hoistExportEquals(node) {
                if (exportEqualsBinding) {
                    return node;
                }
                exportEqualsBinding = factory2.createUniqueName("_default", 8 /* ReservedInNestedScopes */ | 32 /* FileLevel */ | 16 /* Optimistic */);
                hoistVariableDeclaration(exportEqualsBinding);
                const assignment = factory2.createAssignment(exportEqualsBinding, node.expression);
                return factory2.createExpressionStatement(assignment);
            }
            function hoistClassDeclaration(node) {
                if (!node.name && defaultExportBinding) {
                    return node;
                }
                const isExported2 = hasSyntacticModifier(node, 32 /* Export */);
                const isDefault = hasSyntacticModifier(node, 2048 /* Default */);
                let expression = factory2.converters.convertToClassExpression(node);
                if (node.name) {
                    hoistBindingIdentifier(factory2.getLocalName(node), isExported2 && !isDefault, 
                    /*exportAlias*/
                    void 0, node);
                    expression = factory2.createAssignment(factory2.getDeclarationName(node), expression);
                    if (isNamedEvaluation(expression)) {
                        expression = transformNamedEvaluation(context, expression, 
                        /*ignoreEmptyStringLiteral*/
                        false);
                    }
                    setOriginalNode(expression, node);
                    setSourceMapRange(expression, node);
                    setCommentRange(expression, node);
                }
                if (isDefault && !defaultExportBinding) {
                    defaultExportBinding = factory2.createUniqueName("_default", 8 /* ReservedInNestedScopes */ | 32 /* FileLevel */ | 16 /* Optimistic */);
                    hoistBindingIdentifier(defaultExportBinding, 
                    /*isExport*/
                    true, "default", node);
                    expression = factory2.createAssignment(defaultExportBinding, expression);
                    if (isNamedEvaluation(expression)) {
                        expression = transformNamedEvaluation(context, expression, 
                        /*ignoreEmptyStringLiteral*/
                        false, "default");
                    }
                    setOriginalNode(expression, node);
                }
                return factory2.createExpressionStatement(expression);
            }
            function hoistVariableStatement(node) {
                let expressions;
                const isExported2 = hasSyntacticModifier(node, 32 /* Export */);
                for (const variable of node.declarationList.declarations) {
                    hoistBindingElement(variable, isExported2, variable);
                    if (variable.initializer) {
                        expressions = append(expressions, hoistInitializedVariable(variable));
                    }
                }
                if (expressions) {
                    const statement = factory2.createExpressionStatement(factory2.inlineExpressions(expressions));
                    setOriginalNode(statement, node);
                    setCommentRange(statement, node);
                    setSourceMapRange(statement, node);
                    return statement;
                }
                return void 0;
            }
            function hoistInitializedVariable(node) {
                Debug.assertIsDefined(node.initializer);
                let target;
                if (isIdentifier(node.name)) {
                    target = factory2.cloneNode(node.name);
                    setEmitFlags(target, getEmitFlags(target) & ~(32768 /* LocalName */ | 16384 /* ExportName */ | 65536 /* InternalName */));
                }
                else {
                    target = factory2.converters.convertToAssignmentPattern(node.name);
                }
                const assignment = factory2.createAssignment(target, node.initializer);
                setOriginalNode(assignment, node);
                setCommentRange(assignment, node);
                setSourceMapRange(assignment, node);
                return assignment;
            }
            function hoistBindingElement(node, isExportedDeclaration, original) {
                if (isBindingPattern(node.name)) {
                    for (const element of node.name.elements) {
                        if (!isOmittedExpression(element)) {
                            hoistBindingElement(element, isExportedDeclaration, original);
                        }
                    }
                }
                else {
                    hoistBindingIdentifier(node.name, isExportedDeclaration, 
                    /*exportAlias*/
                    void 0, original);
                }
            }
            function hoistBindingIdentifier(node, isExport, exportAlias, original) {
                const name = isGeneratedIdentifier(node) ? node : factory2.cloneNode(node);
                if (isExport) {
                    if (exportAlias === void 0 && !isLocalName(name)) {
                        const varDecl = factory2.createVariableDeclaration(name);
                        if (original) {
                            setOriginalNode(varDecl, original);
                        }
                        exportVars.push(varDecl);
                        return;
                    }
                    const localName = exportAlias !== void 0 ? name : void 0;
                    const exportName = exportAlias !== void 0 ? exportAlias : name;
                    const specifier = factory2.createExportSpecifier(
                    /*isTypeOnly*/
                    false, localName, exportName);
                    if (original) {
                        setOriginalNode(specifier, original);
                    }
                    exportBindings.set(name, specifier);
                }
                hoistVariableDeclaration(name);
            }
            function createEnvBinding() {
                return factory2.createUniqueName("env");
            }
            function createDownlevelUsingStatements(bodyStatements, envBinding, async) {
                const statements = [];
                const envObject = factory2.createObjectLiteralExpression([
                    factory2.createPropertyAssignment("stack", factory2.createArrayLiteralExpression()),
                    factory2.createPropertyAssignment("error", factory2.createVoidZero()),
                    factory2.createPropertyAssignment("hasError", factory2.createFalse())
                ]);
                const envVar = factory2.createVariableDeclaration(envBinding, 
                /*exclamationToken*/
                void 0, 
                /*type*/
                void 0, envObject);
                const envVarList = factory2.createVariableDeclarationList([envVar], 2 /* Const */);
                const envVarStatement = factory2.createVariableStatement(
                /*modifiers*/
                void 0, envVarList);
                statements.push(envVarStatement);
                const tryBlock = factory2.createBlock(bodyStatements, 
                /*multiLine*/
                true);
                const bodyCatchBinding = factory2.createUniqueName("e");
                const catchClause = factory2.createCatchClause(bodyCatchBinding, factory2.createBlock([
                    factory2.createExpressionStatement(factory2.createAssignment(factory2.createPropertyAccessExpression(envBinding, "error"), bodyCatchBinding)),
                    factory2.createExpressionStatement(factory2.createAssignment(factory2.createPropertyAccessExpression(envBinding, "hasError"), factory2.createTrue()))
                ], 
                /*multiLine*/
                true));
                let finallyBlock;
                if (async) {
                    const result = factory2.createUniqueName("result");
                    finallyBlock = factory2.createBlock([
                        factory2.createVariableStatement(
                        /*modifiers*/
                        void 0, factory2.createVariableDeclarationList([
                            factory2.createVariableDeclaration(result, 
                            /*exclamationToken*/
                            void 0, 
                            /*type*/
                            void 0, emitHelpers().createDisposeResourcesHelper(envBinding))
                        ], 2 /* Const */)),
                        factory2.createIfStatement(result, factory2.createExpressionStatement(factory2.createAwaitExpression(result)))
                    ], 
                    /*multiLine*/
                    true);
                }
                else {
                    finallyBlock = factory2.createBlock([
                        factory2.createExpressionStatement(emitHelpers().createDisposeResourcesHelper(envBinding))
                    ], 
                    /*multiLine*/
                    true);
                }
                const tryStatement = factory2.createTryStatement(tryBlock, catchClause, finallyBlock);
                statements.push(tryStatement);
                return statements;
            }
        }
        function countPrologueStatements(statements) {
            for (let i = 0; i < statements.length; i++) {
                if (!isPrologueDirective(statements[i]) && !isCustomPrologue(statements[i])) {
                    return i;
                }
            }
            return 0;
        }
        function isUsingVariableDeclarationList(node) {
            return isVariableDeclarationList(node) && getUsingKindOfVariableDeclarationList(node) !== 0 /* None */;
        }
        function getUsingKindOfVariableDeclarationList(node) {
            return (node.flags & 7 /* BlockScoped */) === 6 /* AwaitUsing */ ? 2 /* Async */ : (node.flags & 7 /* BlockScoped */) === 4 /* Using */ ? 1 /* Sync */ : 0 /* None */;
        }
        function getUsingKindOfVariableStatement(node) {
            return getUsingKindOfVariableDeclarationList(node.declarationList);
        }
        function getUsingKind(statement) {
            return isVariableStatement(statement) ? getUsingKindOfVariableStatement(statement) : 0 /* None */;
        }
        function getUsingKindOfStatements(statements) {
            let result = 0 /* None */;
            for (const statement of statements) {
                const usingKind = getUsingKind(statement);
                if (usingKind === 2 /* Async */)
                    return 2 /* Async */;
                if (usingKind > result)
                    result = usingKind;
            }
            return result;
        }
        function getUsingKindOfCaseOrDefaultClauses(clauses) {
            let result = 0 /* None */;
            for (const clause of clauses) {
                const usingKind = getUsingKindOfStatements(clause.statements);
                if (usingKind === 2 /* Async */)
                    return 2 /* Async */;
                if (usingKind > result)
                    result = usingKind;
            }
            return result;
        }
        var init_esnext = __esm({
            "src/compiler/transformers/esnext.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/jsx.ts
        function transformJsx(context) {
            const { factory: factory2, getEmitHelperFactory: emitHelpers } = context;
            const compilerOptions = context.getCompilerOptions();
            let currentSourceFile;
            let currentFileState;
            return chainBundle(context, transformSourceFile);
            function getCurrentFileNameExpression() {
                if (currentFileState.filenameDeclaration) {
                    return currentFileState.filenameDeclaration.name;
                }
                const declaration = factory2.createVariableDeclaration(factory2.createUniqueName("_jsxFileName", 16 /* Optimistic */ | 32 /* FileLevel */), 
                /*exclamationToken*/
                void 0, 
                /*type*/
                void 0, factory2.createStringLiteral(currentSourceFile.fileName));
                currentFileState.filenameDeclaration = declaration;
                return currentFileState.filenameDeclaration.name;
            }
            function getJsxFactoryCalleePrimitive(isStaticChildren) {
                return compilerOptions.jsx === 5 /* ReactJSXDev */ ? "jsxDEV" : isStaticChildren ? "jsxs" : "jsx";
            }
            function getJsxFactoryCallee(isStaticChildren) {
                const type = getJsxFactoryCalleePrimitive(isStaticChildren);
                return getImplicitImportForName(type);
            }
            function getImplicitJsxFragmentReference() {
                return getImplicitImportForName("Fragment");
            }
            function getImplicitImportForName(name) {
                var _a, _b;
                const importSource = name === "createElement" ? currentFileState.importSpecifier : getJSXRuntimeImport(currentFileState.importSpecifier, compilerOptions);
                const existing = (_b = (_a = currentFileState.utilizedImplicitRuntimeImports) == null ? void 0 : _a.get(importSource)) == null ? void 0 : _b.get(name);
                if (existing) {
                    return existing.name;
                }
                if (!currentFileState.utilizedImplicitRuntimeImports) {
                    currentFileState.utilizedImplicitRuntimeImports = /* @__PURE__ */ new Map();
                }
                let specifierSourceImports = currentFileState.utilizedImplicitRuntimeImports.get(importSource);
                if (!specifierSourceImports) {
                    specifierSourceImports = /* @__PURE__ */ new Map();
                    currentFileState.utilizedImplicitRuntimeImports.set(importSource, specifierSourceImports);
                }
                const generatedName = factory2.createUniqueName(`_${name}`, 16 /* Optimistic */ | 32 /* FileLevel */ | 64 /* AllowNameSubstitution */);
                const specifier = factory2.createImportSpecifier(
                /*isTypeOnly*/
                false, factory2.createIdentifier(name), generatedName);
                setIdentifierGeneratedImportReference(generatedName, specifier);
                specifierSourceImports.set(name, specifier);
                return generatedName;
            }
            function transformSourceFile(node) {
                if (node.isDeclarationFile) {
                    return node;
                }
                currentSourceFile = node;
                currentFileState = {};
                currentFileState.importSpecifier = getJSXImplicitImportBase(compilerOptions, node);
                let visited = visitEachChild(node, visitor, context);
                addEmitHelpers(visited, context.readEmitHelpers());
                let statements = visited.statements;
                if (currentFileState.filenameDeclaration) {
                    statements = insertStatementAfterCustomPrologue(statements.slice(), factory2.createVariableStatement(
                    /*modifiers*/
                    void 0, factory2.createVariableDeclarationList([currentFileState.filenameDeclaration], 2 /* Const */)));
                }
                if (currentFileState.utilizedImplicitRuntimeImports) {
                    for (const [importSource, importSpecifiersMap] of arrayFrom(currentFileState.utilizedImplicitRuntimeImports.entries())) {
                        if (isExternalModule(node)) {
                            const importStatement = factory2.createImportDeclaration(
                            /*modifiers*/
                            void 0, factory2.createImportClause(
                            /*isTypeOnly*/
                            false, 
                            /*name*/
                            void 0, factory2.createNamedImports(arrayFrom(importSpecifiersMap.values()))), factory2.createStringLiteral(importSource), 
                            /*attributes*/
                            void 0);
                            setParentRecursive(importStatement, 
                            /*incremental*/
                            false);
                            statements = insertStatementAfterCustomPrologue(statements.slice(), importStatement);
                        }
                        else if (isExternalOrCommonJsModule(node)) {
                            const requireStatement = factory2.createVariableStatement(
                            /*modifiers*/
                            void 0, factory2.createVariableDeclarationList([
                                factory2.createVariableDeclaration(factory2.createObjectBindingPattern(arrayFrom(importSpecifiersMap.values(), (s) => factory2.createBindingElement(
                                /*dotDotDotToken*/
                                void 0, s.propertyName, s.name))), 
                                /*exclamationToken*/
                                void 0, 
                                /*type*/
                                void 0, factory2.createCallExpression(factory2.createIdentifier("require"), 
                                /*typeArguments*/
                                void 0, [factory2.createStringLiteral(importSource)]))
                            ], 2 /* Const */));
                            setParentRecursive(requireStatement, 
                            /*incremental*/
                            false);
                            statements = insertStatementAfterCustomPrologue(statements.slice(), requireStatement);
                        }
                        else {
                        }
                    }
                }
                if (statements !== visited.statements) {
                    visited = factory2.updateSourceFile(visited, statements);
                }
                currentFileState = void 0;
                return visited;
            }
            function visitor(node) {
                if (node.transformFlags & 2 /* ContainsJsx */) {
                    return visitorWorker(node);
                }
                else {
                    return node;
                }
            }
            function visitorWorker(node) {
                switch (node.kind) {
                    case 284 /* JsxElement */:
                        return visitJsxElement(node, 
                        /*isChild*/
                        false);
                    case 285 /* JsxSelfClosingElement */:
                        return visitJsxSelfClosingElement(node, 
                        /*isChild*/
                        false);
                    case 288 /* JsxFragment */:
                        return visitJsxFragment(node, 
                        /*isChild*/
                        false);
                    case 294 /* JsxExpression */:
                        return visitJsxExpression(node);
                    default:
                        return visitEachChild(node, visitor, context);
                }
            }
            function transformJsxChildToExpression(node) {
                switch (node.kind) {
                    case 12 /* JsxText */:
                        return visitJsxText(node);
                    case 294 /* JsxExpression */:
                        return visitJsxExpression(node);
                    case 284 /* JsxElement */:
                        return visitJsxElement(node, 
                        /*isChild*/
                        true);
                    case 285 /* JsxSelfClosingElement */:
                        return visitJsxSelfClosingElement(node, 
                        /*isChild*/
                        true);
                    case 288 /* JsxFragment */:
                        return visitJsxFragment(node, 
                        /*isChild*/
                        true);
                    default:
                        return Debug.failBadSyntaxKind(node);
                }
            }
            function hasProto(obj) {
                return obj.properties.some((p) => isPropertyAssignment(p) && (isIdentifier(p.name) && idText(p.name) === "__proto__" || isStringLiteral(p.name) && p.name.text === "__proto__"));
            }
            function hasKeyAfterPropsSpread(node) {
                let spread = false;
                for (const elem of node.attributes.properties) {
                    if (isJsxSpreadAttribute(elem) && (!isObjectLiteralExpression(elem.expression) || elem.expression.properties.some(isSpreadAssignment))) {
                        spread = true;
                    }
                    else if (spread && isJsxAttribute(elem) && isIdentifier(elem.name) && elem.name.escapedText === "key") {
                        return true;
                    }
                }
                return false;
            }
            function shouldUseCreateElement(node) {
                return currentFileState.importSpecifier === void 0 || hasKeyAfterPropsSpread(node);
            }
            function visitJsxElement(node, isChild) {
                const tagTransform = shouldUseCreateElement(node.openingElement) ? visitJsxOpeningLikeElementCreateElement : visitJsxOpeningLikeElementJSX;
                return tagTransform(node.openingElement, node.children, isChild, 
                /*location*/
                node);
            }
            function visitJsxSelfClosingElement(node, isChild) {
                const tagTransform = shouldUseCreateElement(node) ? visitJsxOpeningLikeElementCreateElement : visitJsxOpeningLikeElementJSX;
                return tagTransform(node, 
                /*children*/
                void 0, isChild, 
                /*location*/
                node);
            }
            function visitJsxFragment(node, isChild) {
                const tagTransform = currentFileState.importSpecifier === void 0 ? visitJsxOpeningFragmentCreateElement : visitJsxOpeningFragmentJSX;
                return tagTransform(node.openingFragment, node.children, isChild, 
                /*location*/
                node);
            }
            function convertJsxChildrenToChildrenPropObject(children) {
                const prop = convertJsxChildrenToChildrenPropAssignment(children);
                return prop && factory2.createObjectLiteralExpression([prop]);
            }
            function convertJsxChildrenToChildrenPropAssignment(children) {
                const nonWhitespaceChildren = getSemanticJsxChildren(children);
                if (length(nonWhitespaceChildren) === 1 && !nonWhitespaceChildren[0].dotDotDotToken) {
                    const result2 = transformJsxChildToExpression(nonWhitespaceChildren[0]);
                    return result2 && factory2.createPropertyAssignment("children", result2);
                }
                const result = mapDefined(children, transformJsxChildToExpression);
                return length(result) ? factory2.createPropertyAssignment("children", factory2.createArrayLiteralExpression(result)) : void 0;
            }
            function visitJsxOpeningLikeElementJSX(node, children, isChild, location) {
                const tagName = getTagName(node);
                const childrenProp = children && children.length ? convertJsxChildrenToChildrenPropAssignment(children) : void 0;
                const keyAttr = find(node.attributes.properties, (p) => !!p.name && isIdentifier(p.name) && p.name.escapedText === "key");
                const attrs = keyAttr ? filter(node.attributes.properties, (p) => p !== keyAttr) : node.attributes.properties;
                const objectProperties = length(attrs) ? transformJsxAttributesToObjectProps(attrs, childrenProp) : factory2.createObjectLiteralExpression(childrenProp ? [childrenProp] : emptyArray);
                return visitJsxOpeningLikeElementOrFragmentJSX(tagName, objectProperties, keyAttr, children || emptyArray, isChild, location);
            }
            function visitJsxOpeningLikeElementOrFragmentJSX(tagName, objectProperties, keyAttr, children, isChild, location) {
                var _a;
                const nonWhitespaceChildren = getSemanticJsxChildren(children);
                const isStaticChildren = length(nonWhitespaceChildren) > 1 || !!((_a = nonWhitespaceChildren[0]) == null ? void 0 : _a.dotDotDotToken);
                const args = [tagName, objectProperties];
                if (keyAttr) {
                    args.push(transformJsxAttributeInitializer(keyAttr.initializer));
                }
                if (compilerOptions.jsx === 5 /* ReactJSXDev */) {
                    const originalFile = getOriginalNode(currentSourceFile);
                    if (originalFile && isSourceFile(originalFile)) {
                        if (keyAttr === void 0) {
                            args.push(factory2.createVoidZero());
                        }
                        args.push(isStaticChildren ? factory2.createTrue() : factory2.createFalse());
                        const lineCol = getLineAndCharacterOfPosition(originalFile, location.pos);
                        args.push(factory2.createObjectLiteralExpression([
                            factory2.createPropertyAssignment("fileName", getCurrentFileNameExpression()),
                            factory2.createPropertyAssignment("lineNumber", factory2.createNumericLiteral(lineCol.line + 1)),
                            factory2.createPropertyAssignment("columnNumber", factory2.createNumericLiteral(lineCol.character + 1))
                        ]));
                        args.push(factory2.createThis());
                    }
                }
                const element = setTextRange(factory2.createCallExpression(getJsxFactoryCallee(isStaticChildren), 
                /*typeArguments*/
                void 0, args), location);
                if (isChild) {
                    startOnNewLine(element);
                }
                return element;
            }
            function visitJsxOpeningLikeElementCreateElement(node, children, isChild, location) {
                const tagName = getTagName(node);
                const attrs = node.attributes.properties;
                const objectProperties = length(attrs) ? transformJsxAttributesToObjectProps(attrs) : factory2.createNull();
                const callee = currentFileState.importSpecifier === void 0 ? createJsxFactoryExpression(factory2, context.getEmitResolver().getJsxFactoryEntity(currentSourceFile), compilerOptions.reactNamespace, 
                // TODO: GH#18217
                node) : getImplicitImportForName("createElement");
                const element = createExpressionForJsxElement(factory2, callee, tagName, objectProperties, mapDefined(children, transformJsxChildToExpression), location);
                if (isChild) {
                    startOnNewLine(element);
                }
                return element;
            }
            function visitJsxOpeningFragmentJSX(_node, children, isChild, location) {
                let childrenProps;
                if (children && children.length) {
                    const result = convertJsxChildrenToChildrenPropObject(children);
                    if (result) {
                        childrenProps = result;
                    }
                }
                return visitJsxOpeningLikeElementOrFragmentJSX(getImplicitJsxFragmentReference(), childrenProps || factory2.createObjectLiteralExpression([]), 
                /*keyAttr*/
                void 0, children, isChild, location);
            }
            function visitJsxOpeningFragmentCreateElement(node, children, isChild, location) {
                const element = createExpressionForJsxFragment(factory2, context.getEmitResolver().getJsxFactoryEntity(currentSourceFile), context.getEmitResolver().getJsxFragmentFactoryEntity(currentSourceFile), compilerOptions.reactNamespace, 
                // TODO: GH#18217
                mapDefined(children, transformJsxChildToExpression), node, location);
                if (isChild) {
                    startOnNewLine(element);
                }
                return element;
            }
            function transformJsxSpreadAttributeToProps(node) {
                if (isObjectLiteralExpression(node.expression) && !hasProto(node.expression)) {
                    return sameMap(node.expression.properties, (p) => Debug.checkDefined(visitNode(p, visitor, isObjectLiteralElementLike)));
                }
                return factory2.createSpreadAssignment(Debug.checkDefined(visitNode(node.expression, visitor, isExpression)));
            }
            function transformJsxAttributesToObjectProps(attrs, children) {
                const target = getEmitScriptTarget(compilerOptions);
                return target && target >= 5 /* ES2018 */ ? factory2.createObjectLiteralExpression(transformJsxAttributesToProps(attrs, children)) : transformJsxAttributesToExpression(attrs, children);
            }
            function transformJsxAttributesToProps(attrs, children) {
                const props = flatten(spanMap(attrs, isJsxSpreadAttribute, (attrs2, isSpread) => flatten(map(attrs2, (attr) => isSpread ? transformJsxSpreadAttributeToProps(attr) : transformJsxAttributeToObjectLiteralElement(attr)))));
                if (children) {
                    props.push(children);
                }
                return props;
            }
            function transformJsxAttributesToExpression(attrs, children) {
                const expressions = [];
                let properties = [];
                for (const attr of attrs) {
                    if (isJsxSpreadAttribute(attr)) {
                        if (isObjectLiteralExpression(attr.expression) && !hasProto(attr.expression)) {
                            for (const prop of attr.expression.properties) {
                                if (isSpreadAssignment(prop)) {
                                    finishObjectLiteralIfNeeded();
                                    expressions.push(Debug.checkDefined(visitNode(prop.expression, visitor, isExpression)));
                                    continue;
                                }
                                properties.push(Debug.checkDefined(visitNode(prop, visitor)));
                            }
                            continue;
                        }
                        finishObjectLiteralIfNeeded();
                        expressions.push(Debug.checkDefined(visitNode(attr.expression, visitor, isExpression)));
                        continue;
                    }
                    properties.push(transformJsxAttributeToObjectLiteralElement(attr));
                }
                if (children) {
                    properties.push(children);
                }
                finishObjectLiteralIfNeeded();
                if (expressions.length && !isObjectLiteralExpression(expressions[0])) {
                    expressions.unshift(factory2.createObjectLiteralExpression());
                }
                return singleOrUndefined(expressions) || emitHelpers().createAssignHelper(expressions);
                function finishObjectLiteralIfNeeded() {
                    if (properties.length) {
                        expressions.push(factory2.createObjectLiteralExpression(properties));
                        properties = [];
                    }
                }
            }
            function transformJsxAttributeToObjectLiteralElement(node) {
                const name = getAttributeName(node);
                const expression = transformJsxAttributeInitializer(node.initializer);
                return factory2.createPropertyAssignment(name, expression);
            }
            function transformJsxAttributeInitializer(node) {
                if (node === void 0) {
                    return factory2.createTrue();
                }
                if (node.kind === 11 /* StringLiteral */) {
                    const singleQuote = node.singleQuote !== void 0 ? node.singleQuote : !isStringDoubleQuoted(node, currentSourceFile);
                    const literal = factory2.createStringLiteral(tryDecodeEntities(node.text) || node.text, singleQuote);
                    return setTextRange(literal, node);
                }
                if (node.kind === 294 /* JsxExpression */) {
                    if (node.expression === void 0) {
                        return factory2.createTrue();
                    }
                    return Debug.checkDefined(visitNode(node.expression, visitor, isExpression));
                }
                if (isJsxElement(node)) {
                    return visitJsxElement(node, 
                    /*isChild*/
                    false);
                }
                if (isJsxSelfClosingElement(node)) {
                    return visitJsxSelfClosingElement(node, 
                    /*isChild*/
                    false);
                }
                if (isJsxFragment(node)) {
                    return visitJsxFragment(node, 
                    /*isChild*/
                    false);
                }
                return Debug.failBadSyntaxKind(node);
            }
            function visitJsxText(node) {
                const fixed = fixupWhitespaceAndDecodeEntities(node.text);
                return fixed === void 0 ? void 0 : factory2.createStringLiteral(fixed);
            }
            function fixupWhitespaceAndDecodeEntities(text) {
                let acc;
                let firstNonWhitespace = 0;
                let lastNonWhitespace = -1;
                for (let i = 0; i < text.length; i++) {
                    const c = text.charCodeAt(i);
                    if (isLineBreak(c)) {
                        if (firstNonWhitespace !== -1 && lastNonWhitespace !== -1) {
                            acc = addLineOfJsxText(acc, text.substr(firstNonWhitespace, lastNonWhitespace - firstNonWhitespace + 1));
                        }
                        firstNonWhitespace = -1;
                    }
                    else if (!isWhiteSpaceSingleLine(c)) {
                        lastNonWhitespace = i;
                        if (firstNonWhitespace === -1) {
                            firstNonWhitespace = i;
                        }
                    }
                }
                return firstNonWhitespace !== -1 ? addLineOfJsxText(acc, text.substr(firstNonWhitespace)) : acc;
            }
            function addLineOfJsxText(acc, trimmedLine) {
                const decoded = decodeEntities(trimmedLine);
                return acc === void 0 ? decoded : acc + " " + decoded;
            }
            function decodeEntities(text) {
                return text.replace(/&((#((\d+)|x([\da-fA-F]+)))|(\w+));/g, (match, _all, _number, _digits, decimal, hex, word) => {
                    if (decimal) {
                        return utf16EncodeAsString(parseInt(decimal, 10));
                    }
                    else if (hex) {
                        return utf16EncodeAsString(parseInt(hex, 16));
                    }
                    else {
                        const ch = entities.get(word);
                        return ch ? utf16EncodeAsString(ch) : match;
                    }
                });
            }
            function tryDecodeEntities(text) {
                const decoded = decodeEntities(text);
                return decoded === text ? void 0 : decoded;
            }
            function getTagName(node) {
                if (node.kind === 284 /* JsxElement */) {
                    return getTagName(node.openingElement);
                }
                else {
                    const tagName = node.tagName;
                    if (isIdentifier(tagName) && isIntrinsicJsxName(tagName.escapedText)) {
                        return factory2.createStringLiteral(idText(tagName));
                    }
                    else if (isJsxNamespacedName(tagName)) {
                        return factory2.createStringLiteral(idText(tagName.namespace) + ":" + idText(tagName.name));
                    }
                    else {
                        return createExpressionFromEntityName(factory2, tagName);
                    }
                }
            }
            function getAttributeName(node) {
                const name = node.name;
                if (isIdentifier(name)) {
                    const text = idText(name);
                    return /^[A-Za-z_]\w*$/.test(text) ? name : factory2.createStringLiteral(text);
                }
                return factory2.createStringLiteral(idText(name.namespace) + ":" + idText(name.name));
            }
            function visitJsxExpression(node) {
                const expression = visitNode(node.expression, visitor, isExpression);
                return node.dotDotDotToken ? factory2.createSpreadElement(expression) : expression;
            }
        }
        var entities;
        var init_jsx = __esm({
            "src/compiler/transformers/jsx.ts"() {
                "use strict";
                init_ts2();
                entities = new Map(Object.entries({
                    quot: 34,
                    amp: 38,
                    apos: 39,
                    lt: 60,
                    gt: 62,
                    nbsp: 160,
                    iexcl: 161,
                    cent: 162,
                    pound: 163,
                    curren: 164,
                    yen: 165,
                    brvbar: 166,
                    sect: 167,
                    uml: 168,
                    copy: 169,
                    ordf: 170,
                    laquo: 171,
                    not: 172,
                    shy: 173,
                    reg: 174,
                    macr: 175,
                    deg: 176,
                    plusmn: 177,
                    sup2: 178,
                    sup3: 179,
                    acute: 180,
                    micro: 181,
                    para: 182,
                    middot: 183,
                    cedil: 184,
                    sup1: 185,
                    ordm: 186,
                    raquo: 187,
                    frac14: 188,
                    frac12: 189,
                    frac34: 190,
                    iquest: 191,
                    Agrave: 192,
                    Aacute: 193,
                    Acirc: 194,
                    Atilde: 195,
                    Auml: 196,
                    Aring: 197,
                    AElig: 198,
                    Ccedil: 199,
                    Egrave: 200,
                    Eacute: 201,
                    Ecirc: 202,
                    Euml: 203,
                    Igrave: 204,
                    Iacute: 205,
                    Icirc: 206,
                    Iuml: 207,
                    ETH: 208,
                    Ntilde: 209,
                    Ograve: 210,
                    Oacute: 211,
                    Ocirc: 212,
                    Otilde: 213,
                    Ouml: 214,
                    times: 215,
                    Oslash: 216,
                    Ugrave: 217,
                    Uacute: 218,
                    Ucirc: 219,
                    Uuml: 220,
                    Yacute: 221,
                    THORN: 222,
                    szlig: 223,
                    agrave: 224,
                    aacute: 225,
                    acirc: 226,
                    atilde: 227,
                    auml: 228,
                    aring: 229,
                    aelig: 230,
                    ccedil: 231,
                    egrave: 232,
                    eacute: 233,
                    ecirc: 234,
                    euml: 235,
                    igrave: 236,
                    iacute: 237,
                    icirc: 238,
                    iuml: 239,
                    eth: 240,
                    ntilde: 241,
                    ograve: 242,
                    oacute: 243,
                    ocirc: 244,
                    otilde: 245,
                    ouml: 246,
                    divide: 247,
                    oslash: 248,
                    ugrave: 249,
                    uacute: 250,
                    ucirc: 251,
                    uuml: 252,
                    yacute: 253,
                    thorn: 254,
                    yuml: 255,
                    OElig: 338,
                    oelig: 339,
                    Scaron: 352,
                    scaron: 353,
                    Yuml: 376,
                    fnof: 402,
                    circ: 710,
                    tilde: 732,
                    Alpha: 913,
                    Beta: 914,
                    Gamma: 915,
                    Delta: 916,
                    Epsilon: 917,
                    Zeta: 918,
                    Eta: 919,
                    Theta: 920,
                    Iota: 921,
                    Kappa: 922,
                    Lambda: 923,
                    Mu: 924,
                    Nu: 925,
                    Xi: 926,
                    Omicron: 927,
                    Pi: 928,
                    Rho: 929,
                    Sigma: 931,
                    Tau: 932,
                    Upsilon: 933,
                    Phi: 934,
                    Chi: 935,
                    Psi: 936,
                    Omega: 937,
                    alpha: 945,
                    beta: 946,
                    gamma: 947,
                    delta: 948,
                    epsilon: 949,
                    zeta: 950,
                    eta: 951,
                    theta: 952,
                    iota: 953,
                    kappa: 954,
                    lambda: 955,
                    mu: 956,
                    nu: 957,
                    xi: 958,
                    omicron: 959,
                    pi: 960,
                    rho: 961,
                    sigmaf: 962,
                    sigma: 963,
                    tau: 964,
                    upsilon: 965,
                    phi: 966,
                    chi: 967,
                    psi: 968,
                    omega: 969,
                    thetasym: 977,
                    upsih: 978,
                    piv: 982,
                    ensp: 8194,
                    emsp: 8195,
                    thinsp: 8201,
                    zwnj: 8204,
                    zwj: 8205,
                    lrm: 8206,
                    rlm: 8207,
                    ndash: 8211,
                    mdash: 8212,
                    lsquo: 8216,
                    rsquo: 8217,
                    sbquo: 8218,
                    ldquo: 8220,
                    rdquo: 8221,
                    bdquo: 8222,
                    dagger: 8224,
                    Dagger: 8225,
                    bull: 8226,
                    hellip: 8230,
                    permil: 8240,
                    prime: 8242,
                    Prime: 8243,
                    lsaquo: 8249,
                    rsaquo: 8250,
                    oline: 8254,
                    frasl: 8260,
                    euro: 8364,
                    image: 8465,
                    weierp: 8472,
                    real: 8476,
                    trade: 8482,
                    alefsym: 8501,
                    larr: 8592,
                    uarr: 8593,
                    rarr: 8594,
                    darr: 8595,
                    harr: 8596,
                    crarr: 8629,
                    lArr: 8656,
                    uArr: 8657,
                    rArr: 8658,
                    dArr: 8659,
                    hArr: 8660,
                    forall: 8704,
                    part: 8706,
                    exist: 8707,
                    empty: 8709,
                    nabla: 8711,
                    isin: 8712,
                    notin: 8713,
                    ni: 8715,
                    prod: 8719,
                    sum: 8721,
                    minus: 8722,
                    lowast: 8727,
                    radic: 8730,
                    prop: 8733,
                    infin: 8734,
                    ang: 8736,
                    and: 8743,
                    or: 8744,
                    cap: 8745,
                    cup: 8746,
                    int: 8747,
                    there4: 8756,
                    sim: 8764,
                    cong: 8773,
                    asymp: 8776,
                    ne: 8800,
                    equiv: 8801,
                    le: 8804,
                    ge: 8805,
                    sub: 8834,
                    sup: 8835,
                    nsub: 8836,
                    sube: 8838,
                    supe: 8839,
                    oplus: 8853,
                    otimes: 8855,
                    perp: 8869,
                    sdot: 8901,
                    lceil: 8968,
                    rceil: 8969,
                    lfloor: 8970,
                    rfloor: 8971,
                    lang: 9001,
                    rang: 9002,
                    loz: 9674,
                    spades: 9824,
                    clubs: 9827,
                    hearts: 9829,
                    diams: 9830
                }));
            }
        });
        // src/compiler/transformers/es2016.ts
        function transformES2016(context) {
            const { factory: factory2, hoistVariableDeclaration } = context;
            return chainBundle(context, transformSourceFile);
            function transformSourceFile(node) {
                if (node.isDeclarationFile) {
                    return node;
                }
                return visitEachChild(node, visitor, context);
            }
            function visitor(node) {
                if ((node.transformFlags & 512 /* ContainsES2016 */) === 0) {
                    return node;
                }
                switch (node.kind) {
                    case 226 /* BinaryExpression */:
                        return visitBinaryExpression(node);
                    default:
                        return visitEachChild(node, visitor, context);
                }
            }
            function visitBinaryExpression(node) {
                switch (node.operatorToken.kind) {
                    case 68 /* AsteriskAsteriskEqualsToken */:
                        return visitExponentiationAssignmentExpression(node);
                    case 43 /* AsteriskAsteriskToken */:
                        return visitExponentiationExpression(node);
                    default:
                        return visitEachChild(node, visitor, context);
                }
            }
            function visitExponentiationAssignmentExpression(node) {
                let target;
                let value;
                const left = visitNode(node.left, visitor, isExpression);
                const right = visitNode(node.right, visitor, isExpression);
                if (isElementAccessExpression(left)) {
                    const expressionTemp = factory2.createTempVariable(hoistVariableDeclaration);
                    const argumentExpressionTemp = factory2.createTempVariable(hoistVariableDeclaration);
                    target = setTextRange(factory2.createElementAccessExpression(setTextRange(factory2.createAssignment(expressionTemp, left.expression), left.expression), setTextRange(factory2.createAssignment(argumentExpressionTemp, left.argumentExpression), left.argumentExpression)), left);
                    value = setTextRange(factory2.createElementAccessExpression(expressionTemp, argumentExpressionTemp), left);
                }
                else if (isPropertyAccessExpression(left)) {
                    const expressionTemp = factory2.createTempVariable(hoistVariableDeclaration);
                    target = setTextRange(factory2.createPropertyAccessExpression(setTextRange(factory2.createAssignment(expressionTemp, left.expression), left.expression), left.name), left);
                    value = setTextRange(factory2.createPropertyAccessExpression(expressionTemp, left.name), left);
                }
                else {
                    target = left;
                    value = left;
                }
                return setTextRange(factory2.createAssignment(target, setTextRange(factory2.createGlobalMethodCall("Math", "pow", [value, right]), node)), node);
            }
            function visitExponentiationExpression(node) {
                const left = visitNode(node.left, visitor, isExpression);
                const right = visitNode(node.right, visitor, isExpression);
                return setTextRange(factory2.createGlobalMethodCall("Math", "pow", [left, right]), node);
            }
        }
        var init_es2016 = __esm({
            "src/compiler/transformers/es2016.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/es2015.ts
        function createSpreadSegment(kind, expression) {
            return { kind, expression };
        }
        function transformES2015(context) {
            const { factory: factory2, getEmitHelperFactory: emitHelpers, startLexicalEnvironment, resumeLexicalEnvironment, endLexicalEnvironment, hoistVariableDeclaration } = context;
            const compilerOptions = context.getCompilerOptions();
            const resolver = context.getEmitResolver();
            const previousOnSubstituteNode = context.onSubstituteNode;
            const previousOnEmitNode = context.onEmitNode;
            context.onEmitNode = onEmitNode;
            context.onSubstituteNode = onSubstituteNode;
            let currentSourceFile;
            let currentText;
            let hierarchyFacts;
            let taggedTemplateStringDeclarations;
            function recordTaggedTemplateString(temp) {
                taggedTemplateStringDeclarations = append(taggedTemplateStringDeclarations, factory2.createVariableDeclaration(temp));
            }
            let convertedLoopState;
            let enabledSubstitutions;
            return chainBundle(context, transformSourceFile);
            function transformSourceFile(node) {
                if (node.isDeclarationFile) {
                    return node;
                }
                currentSourceFile = node;
                currentText = node.text;
                const visited = visitSourceFile(node);
                addEmitHelpers(visited, context.readEmitHelpers());
                currentSourceFile = void 0;
                currentText = void 0;
                taggedTemplateStringDeclarations = void 0;
                hierarchyFacts = 0 /* None */;
                return visited;
            }
            function enterSubtree(excludeFacts, includeFacts) {
                const ancestorFacts = hierarchyFacts;
                hierarchyFacts = (hierarchyFacts & ~excludeFacts | includeFacts) & 32767 /* AncestorFactsMask */;
                return ancestorFacts;
            }
            function exitSubtree(ancestorFacts, excludeFacts, includeFacts) {
                hierarchyFacts = (hierarchyFacts & ~excludeFacts | includeFacts) & -32768 /* SubtreeFactsMask */ | ancestorFacts;
            }
            function isReturnVoidStatementInConstructorWithCapturedSuper(node) {
                return (hierarchyFacts & 8192 /* ConstructorWithSuperCall */) !== 0 && node.kind === 253 /* ReturnStatement */ && !node.expression;
            }
            function isOrMayContainReturnCompletion(node) {
                return node.transformFlags & 4194304 /* ContainsHoistedDeclarationOrCompletion */ && (isReturnStatement(node) || isIfStatement(node) || isWithStatement(node) || isSwitchStatement(node) || isCaseBlock(node) || isCaseClause(node) || isDefaultClause(node) || isTryStatement(node) || isCatchClause(node) || isLabeledStatement(node) || isIterationStatement(node, 
                /*lookInLabeledStatements*/
                false) || isBlock(node));
            }
            function shouldVisitNode(node) {
                return (node.transformFlags & 1024 /* ContainsES2015 */) !== 0 || convertedLoopState !== void 0 || hierarchyFacts & 8192 /* ConstructorWithSuperCall */ && isOrMayContainReturnCompletion(node) || isIterationStatement(node, 
                /*lookInLabeledStatements*/
                false) && shouldConvertIterationStatement(node) || (getInternalEmitFlags(node) & 1 /* TypeScriptClassWrapper */) !== 0;
            }
            function visitor(node) {
                return shouldVisitNode(node) ? visitorWorker(node, 
                /*expressionResultIsUnused*/
                false) : node;
            }
            function visitorWithUnusedExpressionResult(node) {
                return shouldVisitNode(node) ? visitorWorker(node, 
                /*expressionResultIsUnused*/
                true) : node;
            }
            function classWrapperStatementVisitor(node) {
                if (shouldVisitNode(node)) {
                    const original = getOriginalNode(node);
                    if (isPropertyDeclaration(original) && hasStaticModifier(original)) {
                        const ancestorFacts = enterSubtree(32670 /* StaticInitializerExcludes */, 16449 /* StaticInitializerIncludes */);
                        const result = visitorWorker(node, 
                        /*expressionResultIsUnused*/
                        false);
                        exitSubtree(ancestorFacts, 229376 /* FunctionSubtreeExcludes */, 0 /* None */);
                        return result;
                    }
                    return visitorWorker(node, 
                    /*expressionResultIsUnused*/
                    false);
                }
                return node;
            }
            function callExpressionVisitor(node) {
                if (node.kind === 108 /* SuperKeyword */) {
                    return visitSuperKeyword(node, 
                    /*isExpressionOfCall*/
                    true);
                }
                return visitor(node);
            }
            function visitorWorker(node, expressionResultIsUnused2) {
                switch (node.kind) {
                    case 126 /* StaticKeyword */:
                        return void 0;
                    case 263 /* ClassDeclaration */:
                        return visitClassDeclaration(node);
                    case 231 /* ClassExpression */:
                        return visitClassExpression(node);
                    case 169 /* Parameter */:
                        return visitParameter(node);
                    case 262 /* FunctionDeclaration */:
                        return visitFunctionDeclaration(node);
                    case 219 /* ArrowFunction */:
                        return visitArrowFunction(node);
                    case 218 /* FunctionExpression */:
                        return visitFunctionExpression(node);
                    case 260 /* VariableDeclaration */:
                        return visitVariableDeclaration(node);
                    case 80 /* Identifier */:
                        return visitIdentifier(node);
                    case 261 /* VariableDeclarationList */:
                        return visitVariableDeclarationList(node);
                    case 255 /* SwitchStatement */:
                        return visitSwitchStatement(node);
                    case 269 /* CaseBlock */:
                        return visitCaseBlock(node);
                    case 241 /* Block */:
                        return visitBlock(node, 
                        /*isFunctionBody*/
                        false);
                    case 252 /* BreakStatement */:
                    case 251 /* ContinueStatement */:
                        return visitBreakOrContinueStatement(node);
                    case 256 /* LabeledStatement */:
                        return visitLabeledStatement(node);
                    case 246 /* DoStatement */:
                    case 247 /* WhileStatement */:
                        return visitDoOrWhileStatement(node, 
                        /*outermostLabeledStatement*/
                        void 0);
                    case 248 /* ForStatement */:
                        return visitForStatement(node, 
                        /*outermostLabeledStatement*/
                        void 0);
                    case 249 /* ForInStatement */:
                        return visitForInStatement(node, 
                        /*outermostLabeledStatement*/
                        void 0);
                    case 250 /* ForOfStatement */:
                        return visitForOfStatement(node, 
                        /*outermostLabeledStatement*/
                        void 0);
                    case 244 /* ExpressionStatement */:
                        return visitExpressionStatement(node);
                    case 210 /* ObjectLiteralExpression */:
                        return visitObjectLiteralExpression(node);
                    case 299 /* CatchClause */:
                        return visitCatchClause(node);
                    case 304 /* ShorthandPropertyAssignment */:
                        return visitShorthandPropertyAssignment(node);
                    case 167 /* ComputedPropertyName */:
                        return visitComputedPropertyName(node);
                    case 209 /* ArrayLiteralExpression */:
                        return visitArrayLiteralExpression(node);
                    case 213 /* CallExpression */:
                        return visitCallExpression(node);
                    case 214 /* NewExpression */:
                        return visitNewExpression(node);
                    case 217 /* ParenthesizedExpression */:
                        return visitParenthesizedExpression(node, expressionResultIsUnused2);
                    case 226 /* BinaryExpression */:
                        return visitBinaryExpression(node, expressionResultIsUnused2);
                    case 361 /* CommaListExpression */:
                        return visitCommaListExpression(node, expressionResultIsUnused2);
                    case 15 /* NoSubstitutionTemplateLiteral */:
                    case 16 /* TemplateHead */:
                    case 17 /* TemplateMiddle */:
                    case 18 /* TemplateTail */:
                        return visitTemplateLiteral(node);
                    case 11 /* StringLiteral */:
                        return visitStringLiteral(node);
                    case 9 /* NumericLiteral */:
                        return visitNumericLiteral(node);
                    case 215 /* TaggedTemplateExpression */:
                        return visitTaggedTemplateExpression(node);
                    case 228 /* TemplateExpression */:
                        return visitTemplateExpression(node);
                    case 229 /* YieldExpression */:
                        return visitYieldExpression(node);
                    case 230 /* SpreadElement */:
                        return visitSpreadElement(node);
                    case 108 /* SuperKeyword */:
                        return visitSuperKeyword(node, 
                        /*isExpressionOfCall*/
                        false);
                    case 110 /* ThisKeyword */:
                        return visitThisKeyword(node);
                    case 236 /* MetaProperty */:
                        return visitMetaProperty(node);
                    case 174 /* MethodDeclaration */:
                        return visitMethodDeclaration(node);
                    case 177 /* GetAccessor */:
                    case 178 /* SetAccessor */:
                        return visitAccessorDeclaration(node);
                    case 243 /* VariableStatement */:
                        return visitVariableStatement(node);
                    case 253 /* ReturnStatement */:
                        return visitReturnStatement(node);
                    case 222 /* VoidExpression */:
                        return visitVoidExpression(node);
                    default:
                        return visitEachChild(node, visitor, context);
                }
            }
            function visitSourceFile(node) {
                const ancestorFacts = enterSubtree(8064 /* SourceFileExcludes */, 64 /* SourceFileIncludes */);
                const prologue = [];
                const statements = [];
                startLexicalEnvironment();
                const statementOffset = factory2.copyPrologue(node.statements, prologue, 
                /*ensureUseStrict*/
                false, visitor);
                addRange(statements, visitNodes2(node.statements, visitor, isStatement, statementOffset));
                if (taggedTemplateStringDeclarations) {
                    statements.push(factory2.createVariableStatement(
                    /*modifiers*/
                    void 0, factory2.createVariableDeclarationList(taggedTemplateStringDeclarations)));
                }
                factory2.mergeLexicalEnvironment(prologue, endLexicalEnvironment());
                insertCaptureThisForNodeIfNeeded(prologue, node);
                exitSubtree(ancestorFacts, 0 /* None */, 0 /* None */);
                return factory2.updateSourceFile(node, setTextRange(factory2.createNodeArray(concatenate(prologue, statements)), node.statements));
            }
            function visitSwitchStatement(node) {
                if (convertedLoopState !== void 0) {
                    const savedAllowedNonLabeledJumps = convertedLoopState.allowedNonLabeledJumps;
                    convertedLoopState.allowedNonLabeledJumps |= 2 /* Break */;
                    const result = visitEachChild(node, visitor, context);
                    convertedLoopState.allowedNonLabeledJumps = savedAllowedNonLabeledJumps;
                    return result;
                }
                return visitEachChild(node, visitor, context);
            }
            function visitCaseBlock(node) {
                const ancestorFacts = enterSubtree(7104 /* BlockScopeExcludes */, 0 /* BlockScopeIncludes */);
                const updated = visitEachChild(node, visitor, context);
                exitSubtree(ancestorFacts, 0 /* None */, 0 /* None */);
                return updated;
            }
            function returnCapturedThis(node) {
                return setOriginalNode(factory2.createReturnStatement(createCapturedThis()), node);
            }
            function createCapturedThis() {
                return factory2.createUniqueName("_this", 16 /* Optimistic */ | 32 /* FileLevel */);
            }
            function visitReturnStatement(node) {
                if (convertedLoopState) {
                    convertedLoopState.nonLocalJumps |= 8 /* Return */;
                    if (isReturnVoidStatementInConstructorWithCapturedSuper(node)) {
                        node = returnCapturedThis(node);
                    }
                    return factory2.createReturnStatement(factory2.createObjectLiteralExpression([
                        factory2.createPropertyAssignment(factory2.createIdentifier("value"), node.expression ? Debug.checkDefined(visitNode(node.expression, visitor, isExpression)) : factory2.createVoidZero())
                    ]));
                }
                else if (isReturnVoidStatementInConstructorWithCapturedSuper(node)) {
                    return returnCapturedThis(node);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitThisKeyword(node) {
                hierarchyFacts |= 65536 /* LexicalThis */;
                if (hierarchyFacts & 2 /* ArrowFunction */ && !(hierarchyFacts & 16384 /* StaticInitializer */)) {
                    hierarchyFacts |= 131072 /* CapturedLexicalThis */;
                }
                if (convertedLoopState) {
                    if (hierarchyFacts & 2 /* ArrowFunction */) {
                        convertedLoopState.containsLexicalThis = true;
                        return node;
                    }
                    return convertedLoopState.thisName || (convertedLoopState.thisName = factory2.createUniqueName("this"));
                }
                return node;
            }
            function visitVoidExpression(node) {
                return visitEachChild(node, visitorWithUnusedExpressionResult, context);
            }
            function visitIdentifier(node) {
                if (convertedLoopState) {
                    if (resolver.isArgumentsLocalBinding(node)) {
                        return convertedLoopState.argumentsName || (convertedLoopState.argumentsName = factory2.createUniqueName("arguments"));
                    }
                }
                if (node.flags & 256 /* IdentifierHasExtendedUnicodeEscape */) {
                    return setOriginalNode(setTextRange(factory2.createIdentifier(unescapeLeadingUnderscores(node.escapedText)), node), node);
                }
                return node;
            }
            function visitBreakOrContinueStatement(node) {
                if (convertedLoopState) {
                    const jump = node.kind === 252 /* BreakStatement */ ? 2 /* Break */ : 4 /* Continue */;
                    const canUseBreakOrContinue = node.label && convertedLoopState.labels && convertedLoopState.labels.get(idText(node.label)) || !node.label && convertedLoopState.allowedNonLabeledJumps & jump;
                    if (!canUseBreakOrContinue) {
                        let labelMarker;
                        const label = node.label;
                        if (!label) {
                            if (node.kind === 252 /* BreakStatement */) {
                                convertedLoopState.nonLocalJumps |= 2 /* Break */;
                                labelMarker = "break";
                            }
                            else {
                                convertedLoopState.nonLocalJumps |= 4 /* Continue */;
                                labelMarker = "continue";
                            }
                        }
                        else {
                            if (node.kind === 252 /* BreakStatement */) {
                                labelMarker = `break-${label.escapedText}`;
                                setLabeledJump(convertedLoopState, 
                                /*isBreak*/
                                true, idText(label), labelMarker);
                            }
                            else {
                                labelMarker = `continue-${label.escapedText}`;
                                setLabeledJump(convertedLoopState, 
                                /*isBreak*/
                                false, idText(label), labelMarker);
                            }
                        }
                        let returnExpression = factory2.createStringLiteral(labelMarker);
                        if (convertedLoopState.loopOutParameters.length) {
                            const outParams = convertedLoopState.loopOutParameters;
                            let expr;
                            for (let i = 0; i < outParams.length; i++) {
                                const copyExpr = copyOutParameter(outParams[i], 1 /* ToOutParameter */);
                                if (i === 0) {
                                    expr = copyExpr;
                                }
                                else {
                                    expr = factory2.createBinaryExpression(expr, 28 /* CommaToken */, copyExpr);
                                }
                            }
                            returnExpression = factory2.createBinaryExpression(expr, 28 /* CommaToken */, returnExpression);
                        }
                        return factory2.createReturnStatement(returnExpression);
                    }
                }
                return visitEachChild(node, visitor, context);
            }
            function visitClassDeclaration(node) {
                const variable = factory2.createVariableDeclaration(factory2.getLocalName(node, 
                /*allowComments*/
                true), 
                /*exclamationToken*/
                void 0, 
                /*type*/
                void 0, transformClassLikeDeclarationToExpression(node));
                setOriginalNode(variable, node);
                const statements = [];
                const statement = factory2.createVariableStatement(
                /*modifiers*/
                void 0, factory2.createVariableDeclarationList([variable]));
                setOriginalNode(statement, node);
                setTextRange(statement, node);
                startOnNewLine(statement);
                statements.push(statement);
                if (hasSyntacticModifier(node, 32 /* Export */)) {
                    const exportStatement = hasSyntacticModifier(node, 2048 /* Default */) ? factory2.createExportDefault(factory2.getLocalName(node)) : factory2.createExternalModuleExport(factory2.getLocalName(node));
                    setOriginalNode(exportStatement, statement);
                    statements.push(exportStatement);
                }
                return singleOrMany(statements);
            }
            function visitClassExpression(node) {
                return transformClassLikeDeclarationToExpression(node);
            }
            function transformClassLikeDeclarationToExpression(node) {
                if (node.name) {
                    enableSubstitutionsForBlockScopedBindings();
                }
                const extendsClauseElement = getClassExtendsHeritageElement(node);
                const classFunction = factory2.createFunctionExpression(
                /*modifiers*/
                void 0, 
                /*asteriskToken*/
                void 0, 
                /*name*/
                void 0, 
                /*typeParameters*/
                void 0, extendsClauseElement ? [factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, createSyntheticSuper())] : [], 
                /*type*/
                void 0, transformClassBody(node, extendsClauseElement));
                setEmitFlags(classFunction, getEmitFlags(node) & 131072 /* Indented */ | 1048576 /* ReuseTempVariableScope */);
                const inner = factory2.createPartiallyEmittedExpression(classFunction);
                setTextRangeEnd(inner, node.end);
                setEmitFlags(inner, 3072 /* NoComments */);
                const outer = factory2.createPartiallyEmittedExpression(inner);
                setTextRangeEnd(outer, skipTrivia(currentText, node.pos));
                setEmitFlags(outer, 3072 /* NoComments */);
                const result = factory2.createParenthesizedExpression(factory2.createCallExpression(outer, 
                /*typeArguments*/
                void 0, extendsClauseElement ? [Debug.checkDefined(visitNode(extendsClauseElement.expression, visitor, isExpression))] : []));
                addSyntheticLeadingComment(result, 3 /* MultiLineCommentTrivia */, "* @class ");
                return result;
            }
            function transformClassBody(node, extendsClauseElement) {
                const statements = [];
                const name = factory2.getInternalName(node);
                const constructorLikeName = isIdentifierANonContextualKeyword(name) ? factory2.getGeneratedNameForNode(name) : name;
                startLexicalEnvironment();
                addExtendsHelperIfNeeded(statements, node, extendsClauseElement);
                addConstructor(statements, node, constructorLikeName, extendsClauseElement);
                addClassMembers(statements, node);
                const closingBraceLocation = createTokenRange(skipTrivia(currentText, node.members.end), 20 /* CloseBraceToken */);
                const outer = factory2.createPartiallyEmittedExpression(constructorLikeName);
                setTextRangeEnd(outer, closingBraceLocation.end);
                setEmitFlags(outer, 3072 /* NoComments */);
                const statement = factory2.createReturnStatement(outer);
                setTextRangePos(statement, closingBraceLocation.pos);
                setEmitFlags(statement, 3072 /* NoComments */ | 768 /* NoTokenSourceMaps */);
                statements.push(statement);
                insertStatementsAfterStandardPrologue(statements, endLexicalEnvironment());
                const block = factory2.createBlock(setTextRange(factory2.createNodeArray(statements), 
                /*location*/
                node.members), 
                /*multiLine*/
                true);
                setEmitFlags(block, 3072 /* NoComments */);
                return block;
            }
            function addExtendsHelperIfNeeded(statements, node, extendsClauseElement) {
                if (extendsClauseElement) {
                    statements.push(setTextRange(factory2.createExpressionStatement(emitHelpers().createExtendsHelper(factory2.getInternalName(node))), 
                    /*location*/
                    extendsClauseElement));
                }
            }
            function addConstructor(statements, node, name, extendsClauseElement) {
                const savedConvertedLoopState = convertedLoopState;
                convertedLoopState = void 0;
                const ancestorFacts = enterSubtree(32662 /* ConstructorExcludes */, 73 /* ConstructorIncludes */);
                const constructor = getFirstConstructorWithBody(node);
                const hasSynthesizedSuper = hasSynthesizedDefaultSuperCall(constructor, extendsClauseElement !== void 0);
                const constructorFunction = factory2.createFunctionDeclaration(
                /*modifiers*/
                void 0, 
                /*asteriskToken*/
                void 0, name, 
                /*typeParameters*/
                void 0, transformConstructorParameters(constructor, hasSynthesizedSuper), 
                /*type*/
                void 0, transformConstructorBody(constructor, node, extendsClauseElement, hasSynthesizedSuper));
                setTextRange(constructorFunction, constructor || node);
                if (extendsClauseElement) {
                    setEmitFlags(constructorFunction, 16 /* CapturesThis */);
                }
                statements.push(constructorFunction);
                exitSubtree(ancestorFacts, 229376 /* FunctionSubtreeExcludes */, 0 /* None */);
                convertedLoopState = savedConvertedLoopState;
            }
            function transformConstructorParameters(constructor, hasSynthesizedSuper) {
                return visitParameterList(constructor && !hasSynthesizedSuper ? constructor.parameters : void 0, visitor, context) || [];
            }
            function createDefaultConstructorBody(node, isDerivedClass) {
                const statements = [];
                resumeLexicalEnvironment();
                factory2.mergeLexicalEnvironment(statements, endLexicalEnvironment());
                if (isDerivedClass) {
                    statements.push(factory2.createReturnStatement(createDefaultSuperCallOrThis()));
                }
                const statementsArray = factory2.createNodeArray(statements);
                setTextRange(statementsArray, node.members);
                const block = factory2.createBlock(statementsArray, 
                /*multiLine*/
                true);
                setTextRange(block, node);
                setEmitFlags(block, 3072 /* NoComments */);
                return block;
            }
            function isUninitializedVariableStatement(node) {
                return isVariableStatement(node) && every(node.declarationList.declarations, (decl) => isIdentifier(decl.name) && !decl.initializer);
            }
            function containsSuperCall(node) {
                if (isSuperCall(node)) {
                    return true;
                }
                if (!(node.transformFlags & 134217728 /* ContainsLexicalSuper */)) {
                    return false;
                }
                switch (node.kind) {
                    case 219 /* ArrowFunction */:
                    case 218 /* FunctionExpression */:
                    case 262 /* FunctionDeclaration */:
                    case 176 /* Constructor */:
                    case 175 /* ClassStaticBlockDeclaration */:
                        return false;
                    case 177 /* GetAccessor */:
                    case 178 /* SetAccessor */:
                    case 174 /* MethodDeclaration */:
                    case 172 /* PropertyDeclaration */: {
                        const named = node;
                        if (isComputedPropertyName(named.name)) {
                            return !!forEachChild(named.name, containsSuperCall);
                        }
                        return false;
                    }
                }
                return !!forEachChild(node, containsSuperCall);
            }
            function transformConstructorBody(constructor, node, extendsClauseElement, hasSynthesizedSuper) {
                const isDerivedClass = !!extendsClauseElement && skipOuterExpressions(extendsClauseElement.expression).kind !== 106 /* NullKeyword */;
                if (!constructor)
                    return createDefaultConstructorBody(node, isDerivedClass);
                const prologue = [];
                const statements = [];
                resumeLexicalEnvironment();
                const standardPrologueEnd = factory2.copyStandardPrologue(constructor.body.statements, prologue, 
                /*statementOffset*/
                0);
                if (hasSynthesizedSuper || containsSuperCall(constructor.body)) {
                    hierarchyFacts |= 8192 /* ConstructorWithSuperCall */;
                }
                addRange(statements, visitNodes2(constructor.body.statements, visitor, isStatement, standardPrologueEnd));
                const mayReplaceThis = isDerivedClass || hierarchyFacts & 8192 /* ConstructorWithSuperCall */;
                addDefaultValueAssignmentsIfNeeded2(prologue, constructor);
                addRestParameterIfNeeded(prologue, constructor, hasSynthesizedSuper);
                insertCaptureNewTargetIfNeeded(prologue, constructor);
                if (mayReplaceThis) {
                    insertCaptureThisForNode(prologue, constructor, createActualThis());
                }
                else {
                    insertCaptureThisForNodeIfNeeded(prologue, constructor);
                }
                factory2.mergeLexicalEnvironment(prologue, endLexicalEnvironment());
                if (mayReplaceThis && !isSufficientlyCoveredByReturnStatements(constructor.body)) {
                    statements.push(factory2.createReturnStatement(createCapturedThis()));
                }
                const body = factory2.createBlock(setTextRange(factory2.createNodeArray([
                    ...prologue,
                    ...statements
                ]), 
                /*location*/
                constructor.body.statements), 
                /*multiLine*/
                true);
                setTextRange(body, constructor.body);
                return simplifyConstructor(body, constructor.body, hasSynthesizedSuper);
            }
            function isCapturedThis(node) {
                return isGeneratedIdentifier(node) && idText(node) === "_this";
            }
            function isSyntheticSuper(node) {
                return isGeneratedIdentifier(node) && idText(node) === "_super";
            }
            function isThisCapturingVariableStatement(node) {
                return isVariableStatement(node) && node.declarationList.declarations.length === 1 && isThisCapturingVariableDeclaration(node.declarationList.declarations[0]);
            }
            function isThisCapturingVariableDeclaration(node) {
                return isVariableDeclaration(node) && isCapturedThis(node.name) && !!node.initializer;
            }
            function isThisCapturingAssignment(node) {
                return isAssignmentExpression(node, 
                /*excludeCompoundAssignment*/
                true) && isCapturedThis(node.left);
            }
            function isTransformedSuperCall(node) {
                return isCallExpression(node) && isPropertyAccessExpression(node.expression) && isSyntheticSuper(node.expression.expression) && isIdentifier(node.expression.name) && (idText(node.expression.name) === "call" || idText(node.expression.name) === "apply") && node.arguments.length >= 1 && node.arguments[0].kind === 110 /* ThisKeyword */;
            }
            function isTransformedSuperCallWithFallback(node) {
                return isBinaryExpression(node) && node.operatorToken.kind === 57 /* BarBarToken */ && node.right.kind === 110 /* ThisKeyword */ && isTransformedSuperCall(node.left);
            }
            function isImplicitSuperCall(node) {
                return isBinaryExpression(node) && node.operatorToken.kind === 56 /* AmpersandAmpersandToken */ && isBinaryExpression(node.left) && node.left.operatorToken.kind === 38 /* ExclamationEqualsEqualsToken */ && isSyntheticSuper(node.left.left) && node.left.right.kind === 106 /* NullKeyword */ && isTransformedSuperCall(node.right) && idText(node.right.expression.name) === "apply";
            }
            function isImplicitSuperCallWithFallback(node) {
                return isBinaryExpression(node) && node.operatorToken.kind === 57 /* BarBarToken */ && node.right.kind === 110 /* ThisKeyword */ && isImplicitSuperCall(node.left);
            }
            function isThisCapturingTransformedSuperCallWithFallback(node) {
                return isThisCapturingAssignment(node) && isTransformedSuperCallWithFallback(node.right);
            }
            function isThisCapturingImplicitSuperCallWithFallback(node) {
                return isThisCapturingAssignment(node) && isImplicitSuperCallWithFallback(node.right);
            }
            function isTransformedSuperCallLike(node) {
                return isTransformedSuperCall(node) || isTransformedSuperCallWithFallback(node) || isThisCapturingTransformedSuperCallWithFallback(node) || isImplicitSuperCall(node) || isImplicitSuperCallWithFallback(node) || isThisCapturingImplicitSuperCallWithFallback(node);
            }
            function simplifyConstructorInlineSuperInThisCaptureVariable(body) {
                for (let i = 0; i < body.statements.length - 1; i++) {
                    const statement = body.statements[i];
                    if (!isThisCapturingVariableStatement(statement)) {
                        continue;
                    }
                    const varDecl = statement.declarationList.declarations[0];
                    if (varDecl.initializer.kind !== 110 /* ThisKeyword */) {
                        continue;
                    }
                    const thisCaptureStatementIndex = i;
                    let superCallIndex = i + 1;
                    while (superCallIndex < body.statements.length) {
                        const statement2 = body.statements[superCallIndex];
                        if (isExpressionStatement(statement2)) {
                            if (isTransformedSuperCallLike(skipOuterExpressions(statement2.expression))) {
                                break;
                            }
                        }
                        if (isUninitializedVariableStatement(statement2)) {
                            superCallIndex++;
                            continue;
                        }
                        return body;
                    }
                    const following = body.statements[superCallIndex];
                    let expression = following.expression;
                    if (isThisCapturingAssignment(expression)) {
                        expression = expression.right;
                    }
                    const newVarDecl = factory2.updateVariableDeclaration(varDecl, varDecl.name, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, expression);
                    const newDeclList = factory2.updateVariableDeclarationList(statement.declarationList, [newVarDecl]);
                    const newVarStatement = factory2.createVariableStatement(statement.modifiers, newDeclList);
                    setOriginalNode(newVarStatement, following);
                    setTextRange(newVarStatement, following);
                    const newStatements = factory2.createNodeArray([
                        ...body.statements.slice(0, thisCaptureStatementIndex),
                        // copy statements preceding to `var _this`
                        ...body.statements.slice(thisCaptureStatementIndex + 1, superCallIndex),
                        // copy intervening temp variables
                        newVarStatement,
                        ...body.statements.slice(superCallIndex + 1)
                        // copy statements following `super.call(this, ...)`
                    ]);
                    setTextRange(newStatements, body.statements);
                    return factory2.updateBlock(body, newStatements);
                }
                return body;
            }
            function simplifyConstructorInlineSuperReturn(body, original) {
                for (const statement of original.statements) {
                    if (statement.transformFlags & 134217728 /* ContainsLexicalSuper */ && !getSuperCallFromStatement(statement)) {
                        return body;
                    }
                }
                const canElideThisCapturingVariable = !(original.transformFlags & 16384 /* ContainsLexicalThis */) && !(hierarchyFacts & 65536 /* LexicalThis */) && !(hierarchyFacts & 131072 /* CapturedLexicalThis */);
                for (let i = body.statements.length - 1; i > 0; i--) {
                    const statement = body.statements[i];
                    if (isReturnStatement(statement) && statement.expression && isCapturedThis(statement.expression)) {
                        const preceding = body.statements[i - 1];
                        let expression;
                        if (isExpressionStatement(preceding) && isThisCapturingTransformedSuperCallWithFallback(skipOuterExpressions(preceding.expression))) {
                            expression = preceding.expression;
                        }
                        else if (canElideThisCapturingVariable && isThisCapturingVariableStatement(preceding)) {
                            const varDecl = preceding.declarationList.declarations[0];
                            if (isTransformedSuperCallLike(skipOuterExpressions(varDecl.initializer))) {
                                expression = factory2.createAssignment(createCapturedThis(), varDecl.initializer);
                            }
                        }
                        if (!expression) {
                            break;
                        }
                        const newReturnStatement = factory2.createReturnStatement(expression);
                        setOriginalNode(newReturnStatement, preceding);
                        setTextRange(newReturnStatement, preceding);
                        const newStatements = factory2.createNodeArray([
                            ...body.statements.slice(0, i - 1),
                            // copy all statements preceding `_super.call(this, ...)`
                            newReturnStatement,
                            ...body.statements.slice(i + 1)
                            // copy all statements following `return _this;`
                        ]);
                        setTextRange(newStatements, body.statements);
                        return factory2.updateBlock(body, newStatements);
                    }
                }
                return body;
            }
            function elideUnusedThisCaptureWorker(node) {
                if (isThisCapturingVariableStatement(node)) {
                    const varDecl = node.declarationList.declarations[0];
                    if (varDecl.initializer.kind === 110 /* ThisKeyword */) {
                        return void 0;
                    }
                }
                else if (isThisCapturingAssignment(node)) {
                    return factory2.createPartiallyEmittedExpression(node.right, node);
                }
                switch (node.kind) {
                    case 219 /* ArrowFunction */:
                    case 218 /* FunctionExpression */:
                    case 262 /* FunctionDeclaration */:
                    case 176 /* Constructor */:
                    case 175 /* ClassStaticBlockDeclaration */:
                        return node;
                    case 177 /* GetAccessor */:
                    case 178 /* SetAccessor */:
                    case 174 /* MethodDeclaration */:
                    case 172 /* PropertyDeclaration */: {
                        const named = node;
                        if (isComputedPropertyName(named.name)) {
                            return factory2.replacePropertyName(named, visitEachChild(named.name, elideUnusedThisCaptureWorker, 
                            /*context*/
                            void 0));
                        }
                        return node;
                    }
                }
                return visitEachChild(node, elideUnusedThisCaptureWorker, 
                /*context*/
                void 0);
            }
            function simplifyConstructorElideUnusedThisCapture(body, original) {
                if (original.transformFlags & 16384 /* ContainsLexicalThis */ || hierarchyFacts & 65536 /* LexicalThis */ || hierarchyFacts & 131072 /* CapturedLexicalThis */) {
                    return body;
                }
                for (const statement of original.statements) {
                    if (statement.transformFlags & 134217728 /* ContainsLexicalSuper */ && !getSuperCallFromStatement(statement)) {
                        return body;
                    }
                }
                return factory2.updateBlock(body, visitNodes2(body.statements, elideUnusedThisCaptureWorker, isStatement));
            }
            function injectSuperPresenceCheckWorker(node) {
                if (isTransformedSuperCall(node) && node.arguments.length === 2 && isIdentifier(node.arguments[1]) && idText(node.arguments[1]) === "arguments") {
                    return factory2.createLogicalAnd(factory2.createStrictInequality(createSyntheticSuper(), factory2.createNull()), node);
                }
                switch (node.kind) {
                    case 219 /* ArrowFunction */:
                    case 218 /* FunctionExpression */:
                    case 262 /* FunctionDeclaration */:
                    case 176 /* Constructor */:
                    case 175 /* ClassStaticBlockDeclaration */:
                        return node;
                    case 177 /* GetAccessor */:
                    case 178 /* SetAccessor */:
                    case 174 /* MethodDeclaration */:
                    case 172 /* PropertyDeclaration */: {
                        const named = node;
                        if (isComputedPropertyName(named.name)) {
                            return factory2.replacePropertyName(named, visitEachChild(named.name, injectSuperPresenceCheckWorker, 
                            /*context*/
                            void 0));
                        }
                        return node;
                    }
                }
                return visitEachChild(node, injectSuperPresenceCheckWorker, 
                /*context*/
                void 0);
            }
            function complicateConstructorInjectSuperPresenceCheck(body) {
                return factory2.updateBlock(body, visitNodes2(body.statements, injectSuperPresenceCheckWorker, isStatement));
            }
            function simplifyConstructor(body, original, hasSynthesizedSuper) {
                const inputBody = body;
                body = simplifyConstructorInlineSuperInThisCaptureVariable(body);
                body = simplifyConstructorInlineSuperReturn(body, original);
                if (body !== inputBody) {
                    body = simplifyConstructorElideUnusedThisCapture(body, original);
                }
                if (hasSynthesizedSuper) {
                    body = complicateConstructorInjectSuperPresenceCheck(body);
                }
                return body;
            }
            function isSufficientlyCoveredByReturnStatements(statement) {
                if (statement.kind === 253 /* ReturnStatement */) {
                    return true;
                }
                else if (statement.kind === 245 /* IfStatement */) {
                    const ifStatement = statement;
                    if (ifStatement.elseStatement) {
                        return isSufficientlyCoveredByReturnStatements(ifStatement.thenStatement) && isSufficientlyCoveredByReturnStatements(ifStatement.elseStatement);
                    }
                }
                else if (statement.kind === 241 /* Block */) {
                    const lastStatement = lastOrUndefined(statement.statements);
                    if (lastStatement && isSufficientlyCoveredByReturnStatements(lastStatement)) {
                        return true;
                    }
                }
                return false;
            }
            function createActualThis() {
                return setEmitFlags(factory2.createThis(), 8 /* NoSubstitution */);
            }
            function createDefaultSuperCallOrThis() {
                return factory2.createLogicalOr(factory2.createLogicalAnd(factory2.createStrictInequality(createSyntheticSuper(), factory2.createNull()), factory2.createFunctionApplyCall(createSyntheticSuper(), createActualThis(), factory2.createIdentifier("arguments"))), createActualThis());
            }
            function visitParameter(node) {
                if (node.dotDotDotToken) {
                    return void 0;
                }
                else if (isBindingPattern(node.name)) {
                    return setOriginalNode(setTextRange(factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, factory2.getGeneratedNameForNode(node), 
                    /*questionToken*/
                    void 0, 
                    /*type*/
                    void 0, 
                    /*initializer*/
                    void 0), 
                    /*location*/
                    node), 
                    /*original*/
                    node);
                }
                else if (node.initializer) {
                    return setOriginalNode(setTextRange(factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, node.name, 
                    /*questionToken*/
                    void 0, 
                    /*type*/
                    void 0, 
                    /*initializer*/
                    void 0), 
                    /*location*/
                    node), 
                    /*original*/
                    node);
                }
                else {
                    return node;
                }
            }
            function hasDefaultValueOrBindingPattern(node) {
                return node.initializer !== void 0 || isBindingPattern(node.name);
            }
            function addDefaultValueAssignmentsIfNeeded2(statements, node) {
                if (!some(node.parameters, hasDefaultValueOrBindingPattern)) {
                    return false;
                }
                let added = false;
                for (const parameter of node.parameters) {
                    const { name, initializer, dotDotDotToken } = parameter;
                    if (dotDotDotToken) {
                        continue;
                    }
                    if (isBindingPattern(name)) {
                        added = insertDefaultValueAssignmentForBindingPattern(statements, parameter, name, initializer) || added;
                    }
                    else if (initializer) {
                        insertDefaultValueAssignmentForInitializer(statements, parameter, name, initializer);
                        added = true;
                    }
                }
                return added;
            }
            function insertDefaultValueAssignmentForBindingPattern(statements, parameter, name, initializer) {
                if (name.elements.length > 0) {
                    insertStatementAfterCustomPrologue(statements, setEmitFlags(factory2.createVariableStatement(
                    /*modifiers*/
                    void 0, factory2.createVariableDeclarationList(flattenDestructuringBinding(parameter, visitor, context, 0 /* All */, factory2.getGeneratedNameForNode(parameter)))), 2097152 /* CustomPrologue */));
                    return true;
                }
                else if (initializer) {
                    insertStatementAfterCustomPrologue(statements, setEmitFlags(factory2.createExpressionStatement(factory2.createAssignment(factory2.getGeneratedNameForNode(parameter), Debug.checkDefined(visitNode(initializer, visitor, isExpression)))), 2097152 /* CustomPrologue */));
                    return true;
                }
                return false;
            }
            function insertDefaultValueAssignmentForInitializer(statements, parameter, name, initializer) {
                initializer = Debug.checkDefined(visitNode(initializer, visitor, isExpression));
                const statement = factory2.createIfStatement(factory2.createTypeCheck(factory2.cloneNode(name), "undefined"), setEmitFlags(setTextRange(factory2.createBlock([
                    factory2.createExpressionStatement(setEmitFlags(setTextRange(factory2.createAssignment(
                    // TODO(rbuckton): Does this need to be parented?
                    setEmitFlags(setParent(setTextRange(factory2.cloneNode(name), name), name.parent), 96 /* NoSourceMap */), setEmitFlags(initializer, 96 /* NoSourceMap */ | getEmitFlags(initializer) | 3072 /* NoComments */)), parameter), 3072 /* NoComments */))
                ]), parameter), 1 /* SingleLine */ | 64 /* NoTrailingSourceMap */ | 768 /* NoTokenSourceMaps */ | 3072 /* NoComments */));
                startOnNewLine(statement);
                setTextRange(statement, parameter);
                setEmitFlags(statement, 768 /* NoTokenSourceMaps */ | 64 /* NoTrailingSourceMap */ | 2097152 /* CustomPrologue */ | 3072 /* NoComments */);
                insertStatementAfterCustomPrologue(statements, statement);
            }
            function shouldAddRestParameter(node, inConstructorWithSynthesizedSuper) {
                return !!(node && node.dotDotDotToken && !inConstructorWithSynthesizedSuper);
            }
            function addRestParameterIfNeeded(statements, node, inConstructorWithSynthesizedSuper) {
                const prologueStatements = [];
                const parameter = lastOrUndefined(node.parameters);
                if (!shouldAddRestParameter(parameter, inConstructorWithSynthesizedSuper)) {
                    return false;
                }
                const declarationName = parameter.name.kind === 80 /* Identifier */ ? setParent(setTextRange(factory2.cloneNode(parameter.name), parameter.name), parameter.name.parent) : factory2.createTempVariable(
                /*recordTempVariable*/
                void 0);
                setEmitFlags(declarationName, 96 /* NoSourceMap */);
                const expressionName = parameter.name.kind === 80 /* Identifier */ ? factory2.cloneNode(parameter.name) : declarationName;
                const restIndex = node.parameters.length - 1;
                const temp = factory2.createLoopVariable();
                prologueStatements.push(setEmitFlags(setTextRange(factory2.createVariableStatement(
                /*modifiers*/
                void 0, factory2.createVariableDeclarationList([
                    factory2.createVariableDeclaration(declarationName, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, factory2.createArrayLiteralExpression([]))
                ])), 
                /*location*/
                parameter), 2097152 /* CustomPrologue */));
                const forStatement = factory2.createForStatement(setTextRange(factory2.createVariableDeclarationList([
                    factory2.createVariableDeclaration(temp, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, factory2.createNumericLiteral(restIndex))
                ]), parameter), setTextRange(factory2.createLessThan(temp, factory2.createPropertyAccessExpression(factory2.createIdentifier("arguments"), "length")), parameter), setTextRange(factory2.createPostfixIncrement(temp), parameter), factory2.createBlock([
                    startOnNewLine(setTextRange(factory2.createExpressionStatement(factory2.createAssignment(factory2.createElementAccessExpression(expressionName, restIndex === 0 ? temp : factory2.createSubtract(temp, factory2.createNumericLiteral(restIndex))), factory2.createElementAccessExpression(factory2.createIdentifier("arguments"), temp))), 
                    /*location*/
                    parameter))
                ]));
                setEmitFlags(forStatement, 2097152 /* CustomPrologue */);
                startOnNewLine(forStatement);
                prologueStatements.push(forStatement);
                if (parameter.name.kind !== 80 /* Identifier */) {
                    prologueStatements.push(setEmitFlags(setTextRange(factory2.createVariableStatement(
                    /*modifiers*/
                    void 0, factory2.createVariableDeclarationList(flattenDestructuringBinding(parameter, visitor, context, 0 /* All */, expressionName))), parameter), 2097152 /* CustomPrologue */));
                }
                insertStatementsAfterCustomPrologue(statements, prologueStatements);
                return true;
            }
            function insertCaptureThisForNodeIfNeeded(statements, node) {
                if (hierarchyFacts & 131072 /* CapturedLexicalThis */ && node.kind !== 219 /* ArrowFunction */) {
                    insertCaptureThisForNode(statements, node, factory2.createThis());
                    return true;
                }
                return false;
            }
            function insertCaptureThisForNode(statements, node, initializer) {
                enableSubstitutionsForCapturedThis();
                const captureThisStatement = factory2.createVariableStatement(
                /*modifiers*/
                void 0, factory2.createVariableDeclarationList([
                    factory2.createVariableDeclaration(createCapturedThis(), 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, initializer)
                ]));
                setEmitFlags(captureThisStatement, 3072 /* NoComments */ | 2097152 /* CustomPrologue */);
                setSourceMapRange(captureThisStatement, node);
                insertStatementAfterCustomPrologue(statements, captureThisStatement);
            }
            function insertCaptureNewTargetIfNeeded(statements, node) {
                if (hierarchyFacts & 32768 /* NewTarget */) {
                    let newTarget;
                    switch (node.kind) {
                        case 219 /* ArrowFunction */:
                            return statements;
                        case 174 /* MethodDeclaration */:
                        case 177 /* GetAccessor */:
                        case 178 /* SetAccessor */:
                            newTarget = factory2.createVoidZero();
                            break;
                        case 176 /* Constructor */:
                            newTarget = factory2.createPropertyAccessExpression(setEmitFlags(factory2.createThis(), 8 /* NoSubstitution */), "constructor");
                            break;
                        case 262 /* FunctionDeclaration */:
                        case 218 /* FunctionExpression */:
                            newTarget = factory2.createConditionalExpression(factory2.createLogicalAnd(setEmitFlags(factory2.createThis(), 8 /* NoSubstitution */), factory2.createBinaryExpression(setEmitFlags(factory2.createThis(), 8 /* NoSubstitution */), 104 /* InstanceOfKeyword */, factory2.getLocalName(node))), 
                            /*questionToken*/
                            void 0, factory2.createPropertyAccessExpression(setEmitFlags(factory2.createThis(), 8 /* NoSubstitution */), "constructor"), 
                            /*colonToken*/
                            void 0, factory2.createVoidZero());
                            break;
                        default:
                            return Debug.failBadSyntaxKind(node);
                    }
                    const captureNewTargetStatement = factory2.createVariableStatement(
                    /*modifiers*/
                    void 0, factory2.createVariableDeclarationList([
                        factory2.createVariableDeclaration(factory2.createUniqueName("_newTarget", 16 /* Optimistic */ | 32 /* FileLevel */), 
                        /*exclamationToken*/
                        void 0, 
                        /*type*/
                        void 0, newTarget)
                    ]));
                    setEmitFlags(captureNewTargetStatement, 3072 /* NoComments */ | 2097152 /* CustomPrologue */);
                    insertStatementAfterCustomPrologue(statements, captureNewTargetStatement);
                }
                return statements;
            }
            function addClassMembers(statements, node) {
                for (const member of node.members) {
                    switch (member.kind) {
                        case 240 /* SemicolonClassElement */:
                            statements.push(transformSemicolonClassElementToStatement(member));
                            break;
                        case 174 /* MethodDeclaration */:
                            statements.push(transformClassMethodDeclarationToStatement(getClassMemberPrefix(node, member), member, node));
                            break;
                        case 177 /* GetAccessor */:
                        case 178 /* SetAccessor */:
                            const accessors = getAllAccessorDeclarations(node.members, member);
                            if (member === accessors.firstAccessor) {
                                statements.push(transformAccessorsToStatement(getClassMemberPrefix(node, member), accessors, node));
                            }
                            break;
                        case 176 /* Constructor */:
                        case 175 /* ClassStaticBlockDeclaration */:
                            break;
                        default:
                            Debug.failBadSyntaxKind(member, currentSourceFile && currentSourceFile.fileName);
                            break;
                    }
                }
            }
            function transformSemicolonClassElementToStatement(member) {
                return setTextRange(factory2.createEmptyStatement(), member);
            }
            function transformClassMethodDeclarationToStatement(receiver, member, container) {
                const commentRange = getCommentRange(member);
                const sourceMapRange = getSourceMapRange(member);
                const memberFunction = transformFunctionLikeToExpression(member, 
                /*location*/
                member, 
                /*name*/
                void 0, container);
                const propertyName = visitNode(member.name, visitor, isPropertyName);
                Debug.assert(propertyName);
                let e;
                if (!isPrivateIdentifier(propertyName) && getUseDefineForClassFields(context.getCompilerOptions())) {
                    const name = isComputedPropertyName(propertyName) ? propertyName.expression : isIdentifier(propertyName) ? factory2.createStringLiteral(unescapeLeadingUnderscores(propertyName.escapedText)) : propertyName;
                    e = factory2.createObjectDefinePropertyCall(receiver, name, factory2.createPropertyDescriptor({ value: memberFunction, enumerable: false, writable: true, configurable: true }));
                }
                else {
                    const memberName = createMemberAccessForPropertyName(factory2, receiver, propertyName, 
                    /*location*/
                    member.name);
                    e = factory2.createAssignment(memberName, memberFunction);
                }
                setEmitFlags(memberFunction, 3072 /* NoComments */);
                setSourceMapRange(memberFunction, sourceMapRange);
                const statement = setTextRange(factory2.createExpressionStatement(e), 
                /*location*/
                member);
                setOriginalNode(statement, member);
                setCommentRange(statement, commentRange);
                setEmitFlags(statement, 96 /* NoSourceMap */);
                return statement;
            }
            function transformAccessorsToStatement(receiver, accessors, container) {
                const statement = factory2.createExpressionStatement(transformAccessorsToExpression(receiver, accessors, container, 
                /*startsOnNewLine*/
                false));
                setEmitFlags(statement, 3072 /* NoComments */);
                setSourceMapRange(statement, getSourceMapRange(accessors.firstAccessor));
                return statement;
            }
            function transformAccessorsToExpression(receiver, { firstAccessor, getAccessor, setAccessor }, container, startsOnNewLine) {
                const target = setParent(setTextRange(factory2.cloneNode(receiver), receiver), receiver.parent);
                setEmitFlags(target, 3072 /* NoComments */ | 64 /* NoTrailingSourceMap */);
                setSourceMapRange(target, firstAccessor.name);
                const visitedAccessorName = visitNode(firstAccessor.name, visitor, isPropertyName);
                Debug.assert(visitedAccessorName);
                if (isPrivateIdentifier(visitedAccessorName)) {
                    return Debug.failBadSyntaxKind(visitedAccessorName, "Encountered unhandled private identifier while transforming ES2015.");
                }
                const propertyName = createExpressionForPropertyName(factory2, visitedAccessorName);
                setEmitFlags(propertyName, 3072 /* NoComments */ | 32 /* NoLeadingSourceMap */);
                setSourceMapRange(propertyName, firstAccessor.name);
                const properties = [];
                if (getAccessor) {
                    const getterFunction = transformFunctionLikeToExpression(getAccessor, 
                    /*location*/
                    void 0, 
                    /*name*/
                    void 0, container);
                    setSourceMapRange(getterFunction, getSourceMapRange(getAccessor));
                    setEmitFlags(getterFunction, 1024 /* NoLeadingComments */);
                    const getter = factory2.createPropertyAssignment("get", getterFunction);
                    setCommentRange(getter, getCommentRange(getAccessor));
                    properties.push(getter);
                }
                if (setAccessor) {
                    const setterFunction = transformFunctionLikeToExpression(setAccessor, 
                    /*location*/
                    void 0, 
                    /*name*/
                    void 0, container);
                    setSourceMapRange(setterFunction, getSourceMapRange(setAccessor));
                    setEmitFlags(setterFunction, 1024 /* NoLeadingComments */);
                    const setter = factory2.createPropertyAssignment("set", setterFunction);
                    setCommentRange(setter, getCommentRange(setAccessor));
                    properties.push(setter);
                }
                properties.push(factory2.createPropertyAssignment("enumerable", getAccessor || setAccessor ? factory2.createFalse() : factory2.createTrue()), factory2.createPropertyAssignment("configurable", factory2.createTrue()));
                const call = factory2.createCallExpression(factory2.createPropertyAccessExpression(factory2.createIdentifier("Object"), "defineProperty"), 
                /*typeArguments*/
                void 0, [
                    target,
                    propertyName,
                    factory2.createObjectLiteralExpression(properties, 
                    /*multiLine*/
                    true)
                ]);
                if (startsOnNewLine) {
                    startOnNewLine(call);
                }
                return call;
            }
            function visitArrowFunction(node) {
                if (node.transformFlags & 16384 /* ContainsLexicalThis */ && !(hierarchyFacts & 16384 /* StaticInitializer */)) {
                    hierarchyFacts |= 131072 /* CapturedLexicalThis */;
                }
                const savedConvertedLoopState = convertedLoopState;
                convertedLoopState = void 0;
                const ancestorFacts = enterSubtree(15232 /* ArrowFunctionExcludes */, 66 /* ArrowFunctionIncludes */);
                const func = factory2.createFunctionExpression(
                /*modifiers*/
                void 0, 
                /*asteriskToken*/
                void 0, 
                /*name*/
                void 0, 
                /*typeParameters*/
                void 0, visitParameterList(node.parameters, visitor, context), 
                /*type*/
                void 0, transformFunctionBody2(node));
                setTextRange(func, node);
                setOriginalNode(func, node);
                setEmitFlags(func, 16 /* CapturesThis */);
                exitSubtree(ancestorFacts, 0 /* ArrowFunctionSubtreeExcludes */, 0 /* None */);
                convertedLoopState = savedConvertedLoopState;
                return func;
            }
            function visitFunctionExpression(node) {
                const ancestorFacts = getEmitFlags(node) & 524288 /* AsyncFunctionBody */ ? enterSubtree(32662 /* AsyncFunctionBodyExcludes */, 69 /* AsyncFunctionBodyIncludes */) : enterSubtree(32670 /* FunctionExcludes */, 65 /* FunctionIncludes */);
                const savedConvertedLoopState = convertedLoopState;
                convertedLoopState = void 0;
                const parameters = visitParameterList(node.parameters, visitor, context);
                const body = transformFunctionBody2(node);
                const name = hierarchyFacts & 32768 /* NewTarget */ ? factory2.getLocalName(node) : node.name;
                exitSubtree(ancestorFacts, 229376 /* FunctionSubtreeExcludes */, 0 /* None */);
                convertedLoopState = savedConvertedLoopState;
                return factory2.updateFunctionExpression(node, 
                /*modifiers*/
                void 0, node.asteriskToken, name, 
                /*typeParameters*/
                void 0, parameters, 
                /*type*/
                void 0, body);
            }
            function visitFunctionDeclaration(node) {
                const savedConvertedLoopState = convertedLoopState;
                convertedLoopState = void 0;
                const ancestorFacts = enterSubtree(32670 /* FunctionExcludes */, 65 /* FunctionIncludes */);
                const parameters = visitParameterList(node.parameters, visitor, context);
                const body = transformFunctionBody2(node);
                const name = hierarchyFacts & 32768 /* NewTarget */ ? factory2.getLocalName(node) : node.name;
                exitSubtree(ancestorFacts, 229376 /* FunctionSubtreeExcludes */, 0 /* None */);
                convertedLoopState = savedConvertedLoopState;
                return factory2.updateFunctionDeclaration(node, visitNodes2(node.modifiers, visitor, isModifier), node.asteriskToken, name, 
                /*typeParameters*/
                void 0, parameters, 
                /*type*/
                void 0, body);
            }
            function transformFunctionLikeToExpression(node, location, name, container) {
                const savedConvertedLoopState = convertedLoopState;
                convertedLoopState = void 0;
                const ancestorFacts = container && isClassLike(container) && !isStatic(node) ? enterSubtree(32670 /* FunctionExcludes */, 65 /* FunctionIncludes */ | 8 /* NonStaticClassElement */) : enterSubtree(32670 /* FunctionExcludes */, 65 /* FunctionIncludes */);
                const parameters = visitParameterList(node.parameters, visitor, context);
                const body = transformFunctionBody2(node);
                if (hierarchyFacts & 32768 /* NewTarget */ && !name && (node.kind === 262 /* FunctionDeclaration */ || node.kind === 218 /* FunctionExpression */)) {
                    name = factory2.getGeneratedNameForNode(node);
                }
                exitSubtree(ancestorFacts, 229376 /* FunctionSubtreeExcludes */, 0 /* None */);
                convertedLoopState = savedConvertedLoopState;
                return setOriginalNode(setTextRange(factory2.createFunctionExpression(
                /*modifiers*/
                void 0, node.asteriskToken, name, 
                /*typeParameters*/
                void 0, parameters, 
                /*type*/
                void 0, body), location), 
                /*original*/
                node);
            }
            function transformFunctionBody2(node) {
                let multiLine = false;
                let singleLine = false;
                let statementsLocation;
                let closeBraceLocation;
                const prologue = [];
                const statements = [];
                const body = node.body;
                let statementOffset;
                resumeLexicalEnvironment();
                if (isBlock(body)) {
                    statementOffset = factory2.copyStandardPrologue(body.statements, prologue, 0, 
                    /*ensureUseStrict*/
                    false);
                    statementOffset = factory2.copyCustomPrologue(body.statements, statements, statementOffset, visitor, isHoistedFunction);
                    statementOffset = factory2.copyCustomPrologue(body.statements, statements, statementOffset, visitor, isHoistedVariableStatement);
                }
                multiLine = addDefaultValueAssignmentsIfNeeded2(statements, node) || multiLine;
                multiLine = addRestParameterIfNeeded(statements, node, 
                /*inConstructorWithSynthesizedSuper*/
                false) || multiLine;
                if (isBlock(body)) {
                    statementOffset = factory2.copyCustomPrologue(body.statements, statements, statementOffset, visitor);
                    statementsLocation = body.statements;
                    addRange(statements, visitNodes2(body.statements, visitor, isStatement, statementOffset));
                    if (!multiLine && body.multiLine) {
                        multiLine = true;
                    }
                }
                else {
                    Debug.assert(node.kind === 219 /* ArrowFunction */);
                    statementsLocation = moveRangeEnd(body, -1);
                    const equalsGreaterThanToken = node.equalsGreaterThanToken;
                    if (!nodeIsSynthesized(equalsGreaterThanToken) && !nodeIsSynthesized(body)) {
                        if (rangeEndIsOnSameLineAsRangeStart(equalsGreaterThanToken, body, currentSourceFile)) {
                            singleLine = true;
                        }
                        else {
                            multiLine = true;
                        }
                    }
                    const expression = visitNode(body, visitor, isExpression);
                    const returnStatement = factory2.createReturnStatement(expression);
                    setTextRange(returnStatement, body);
                    moveSyntheticComments(returnStatement, body);
                    setEmitFlags(returnStatement, 768 /* NoTokenSourceMaps */ | 64 /* NoTrailingSourceMap */ | 2048 /* NoTrailingComments */);
                    statements.push(returnStatement);
                    closeBraceLocation = body;
                }
                factory2.mergeLexicalEnvironment(prologue, endLexicalEnvironment());
                insertCaptureNewTargetIfNeeded(prologue, node);
                insertCaptureThisForNodeIfNeeded(prologue, node);
                if (some(prologue)) {
                    multiLine = true;
                }
                statements.unshift(...prologue);
                if (isBlock(body) && arrayIsEqualTo(statements, body.statements)) {
                    return body;
                }
                const block = factory2.createBlock(setTextRange(factory2.createNodeArray(statements), statementsLocation), multiLine);
                setTextRange(block, node.body);
                if (!multiLine && singleLine) {
                    setEmitFlags(block, 1 /* SingleLine */);
                }
                if (closeBraceLocation) {
                    setTokenSourceMapRange(block, 20 /* CloseBraceToken */, closeBraceLocation);
                }
                setOriginalNode(block, node.body);
                return block;
            }
            function visitBlock(node, isFunctionBody2) {
                if (isFunctionBody2) {
                    return visitEachChild(node, visitor, context);
                }
                const ancestorFacts = hierarchyFacts & 256 /* IterationStatement */ ? enterSubtree(7104 /* IterationStatementBlockExcludes */, 512 /* IterationStatementBlockIncludes */) : enterSubtree(6976 /* BlockExcludes */, 128 /* BlockIncludes */);
                const updated = visitEachChild(node, visitor, context);
                exitSubtree(ancestorFacts, 0 /* None */, 0 /* None */);
                return updated;
            }
            function visitExpressionStatement(node) {
                return visitEachChild(node, visitorWithUnusedExpressionResult, context);
            }
            function visitParenthesizedExpression(node, expressionResultIsUnused2) {
                return visitEachChild(node, expressionResultIsUnused2 ? visitorWithUnusedExpressionResult : visitor, context);
            }
            function visitBinaryExpression(node, expressionResultIsUnused2) {
                if (isDestructuringAssignment(node)) {
                    return flattenDestructuringAssignment(node, visitor, context, 0 /* All */, !expressionResultIsUnused2);
                }
                if (node.operatorToken.kind === 28 /* CommaToken */) {
                    return factory2.updateBinaryExpression(node, Debug.checkDefined(visitNode(node.left, visitorWithUnusedExpressionResult, isExpression)), node.operatorToken, Debug.checkDefined(visitNode(node.right, expressionResultIsUnused2 ? visitorWithUnusedExpressionResult : visitor, isExpression)));
                }
                return visitEachChild(node, visitor, context);
            }
            function visitCommaListExpression(node, expressionResultIsUnused2) {
                if (expressionResultIsUnused2) {
                    return visitEachChild(node, visitorWithUnusedExpressionResult, context);
                }
                let result;
                for (let i = 0; i < node.elements.length; i++) {
                    const element = node.elements[i];
                    const visited = visitNode(element, i < node.elements.length - 1 ? visitorWithUnusedExpressionResult : visitor, isExpression);
                    if (result || visited !== element) {
                        result || (result = node.elements.slice(0, i));
                        Debug.assert(visited);
                        result.push(visited);
                    }
                }
                const elements = result ? setTextRange(factory2.createNodeArray(result), node.elements) : node.elements;
                return factory2.updateCommaListExpression(node, elements);
            }
            function isVariableStatementOfTypeScriptClassWrapper(node) {
                return node.declarationList.declarations.length === 1 && !!node.declarationList.declarations[0].initializer && !!(getInternalEmitFlags(node.declarationList.declarations[0].initializer) & 1 /* TypeScriptClassWrapper */);
            }
            function visitVariableStatement(node) {
                const ancestorFacts = enterSubtree(0 /* None */, hasSyntacticModifier(node, 32 /* Export */) ? 32 /* ExportedVariableStatement */ : 0 /* None */);
                let updated;
                if (convertedLoopState && (node.declarationList.flags & 7 /* BlockScoped */) === 0 && !isVariableStatementOfTypeScriptClassWrapper(node)) {
                    let assignments;
                    for (const decl of node.declarationList.declarations) {
                        hoistVariableDeclarationDeclaredInConvertedLoop(convertedLoopState, decl);
                        if (decl.initializer) {
                            let assignment;
                            if (isBindingPattern(decl.name)) {
                                assignment = flattenDestructuringAssignment(decl, visitor, context, 0 /* All */);
                            }
                            else {
                                assignment = factory2.createBinaryExpression(decl.name, 64 /* EqualsToken */, Debug.checkDefined(visitNode(decl.initializer, visitor, isExpression)));
                                setTextRange(assignment, decl);
                            }
                            assignments = append(assignments, assignment);
                        }
                    }
                    if (assignments) {
                        updated = setTextRange(factory2.createExpressionStatement(factory2.inlineExpressions(assignments)), node);
                    }
                    else {
                        updated = void 0;
                    }
                }
                else {
                    updated = visitEachChild(node, visitor, context);
                }
                exitSubtree(ancestorFacts, 0 /* None */, 0 /* None */);
                return updated;
            }
            function visitVariableDeclarationList(node) {
                if (node.flags & 7 /* BlockScoped */ || node.transformFlags & 524288 /* ContainsBindingPattern */) {
                    if (node.flags & 7 /* BlockScoped */) {
                        enableSubstitutionsForBlockScopedBindings();
                    }
                    const declarations = visitNodes2(node.declarations, node.flags & 1 /* Let */ ? visitVariableDeclarationInLetDeclarationList : visitVariableDeclaration, isVariableDeclaration);
                    const declarationList = factory2.createVariableDeclarationList(declarations);
                    setOriginalNode(declarationList, node);
                    setTextRange(declarationList, node);
                    setCommentRange(declarationList, node);
                    if (node.transformFlags & 524288 /* ContainsBindingPattern */ && (isBindingPattern(node.declarations[0].name) || isBindingPattern(last(node.declarations).name))) {
                        setSourceMapRange(declarationList, getRangeUnion(declarations));
                    }
                    return declarationList;
                }
                return visitEachChild(node, visitor, context);
            }
            function getRangeUnion(declarations) {
                let pos = -1, end = -1;
                for (const node of declarations) {
                    pos = pos === -1 ? node.pos : node.pos === -1 ? pos : Math.min(pos, node.pos);
                    end = Math.max(end, node.end);
                }
                return createRange(pos, end);
            }
            function shouldEmitExplicitInitializerForLetDeclaration(node) {
                const flags = resolver.getNodeCheckFlags(node);
                const isCapturedInFunction = flags & 16384 /* CapturedBlockScopedBinding */;
                const isDeclaredInLoop = flags & 32768 /* BlockScopedBindingInLoop */;
                const emittedAsTopLevel = (hierarchyFacts & 64 /* TopLevel */) !== 0 || isCapturedInFunction && isDeclaredInLoop && (hierarchyFacts & 512 /* IterationStatementBlock */) !== 0;
                const emitExplicitInitializer = !emittedAsTopLevel && (hierarchyFacts & 4096 /* ForInOrForOfStatement */) === 0 && (!resolver.isDeclarationWithCollidingName(node) || isDeclaredInLoop && !isCapturedInFunction && (hierarchyFacts & (2048 /* ForStatement */ | 4096 /* ForInOrForOfStatement */)) === 0);
                return emitExplicitInitializer;
            }
            function visitVariableDeclarationInLetDeclarationList(node) {
                const name = node.name;
                if (isBindingPattern(name)) {
                    return visitVariableDeclaration(node);
                }
                if (!node.initializer && shouldEmitExplicitInitializerForLetDeclaration(node)) {
                    return factory2.updateVariableDeclaration(node, node.name, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, factory2.createVoidZero());
                }
                return visitEachChild(node, visitor, context);
            }
            function visitVariableDeclaration(node) {
                const ancestorFacts = enterSubtree(32 /* ExportedVariableStatement */, 0 /* None */);
                let updated;
                if (isBindingPattern(node.name)) {
                    updated = flattenDestructuringBinding(node, visitor, context, 0 /* All */, 
                    /*rval*/
                    void 0, (ancestorFacts & 32 /* ExportedVariableStatement */) !== 0);
                }
                else {
                    updated = visitEachChild(node, visitor, context);
                }
                exitSubtree(ancestorFacts, 0 /* None */, 0 /* None */);
                return updated;
            }
            function recordLabel(node) {
                convertedLoopState.labels.set(idText(node.label), true);
            }
            function resetLabel(node) {
                convertedLoopState.labels.set(idText(node.label), false);
            }
            function visitLabeledStatement(node) {
                if (convertedLoopState && !convertedLoopState.labels) {
                    convertedLoopState.labels = /* @__PURE__ */ new Map();
                }
                const statement = unwrapInnermostStatementOfLabel(node, convertedLoopState && recordLabel);
                return isIterationStatement(statement, 
                /*lookInLabeledStatements*/
                false) ? visitIterationStatement(statement, 
                /*outermostLabeledStatement*/
                node) : factory2.restoreEnclosingLabel(Debug.checkDefined(visitNode(statement, visitor, isStatement, factory2.liftToBlock)), node, convertedLoopState && resetLabel);
            }
            function visitIterationStatement(node, outermostLabeledStatement) {
                switch (node.kind) {
                    case 246 /* DoStatement */:
                    case 247 /* WhileStatement */:
                        return visitDoOrWhileStatement(node, outermostLabeledStatement);
                    case 248 /* ForStatement */:
                        return visitForStatement(node, outermostLabeledStatement);
                    case 249 /* ForInStatement */:
                        return visitForInStatement(node, outermostLabeledStatement);
                    case 250 /* ForOfStatement */:
                        return visitForOfStatement(node, outermostLabeledStatement);
                }
            }
            function visitIterationStatementWithFacts(excludeFacts, includeFacts, node, outermostLabeledStatement, convert) {
                const ancestorFacts = enterSubtree(excludeFacts, includeFacts);
                const updated = convertIterationStatementBodyIfNecessary(node, outermostLabeledStatement, ancestorFacts, convert);
                exitSubtree(ancestorFacts, 0 /* None */, 0 /* None */);
                return updated;
            }
            function visitDoOrWhileStatement(node, outermostLabeledStatement) {
                return visitIterationStatementWithFacts(0 /* DoOrWhileStatementExcludes */, 1280 /* DoOrWhileStatementIncludes */, node, outermostLabeledStatement);
            }
            function visitForStatement(node, outermostLabeledStatement) {
                return visitIterationStatementWithFacts(5056 /* ForStatementExcludes */, 3328 /* ForStatementIncludes */, node, outermostLabeledStatement);
            }
            function visitEachChildOfForStatement2(node) {
                return factory2.updateForStatement(node, visitNode(node.initializer, visitorWithUnusedExpressionResult, isForInitializer), visitNode(node.condition, visitor, isExpression), visitNode(node.incrementor, visitorWithUnusedExpressionResult, isExpression), Debug.checkDefined(visitNode(node.statement, visitor, isStatement, factory2.liftToBlock)));
            }
            function visitForInStatement(node, outermostLabeledStatement) {
                return visitIterationStatementWithFacts(3008 /* ForInOrForOfStatementExcludes */, 5376 /* ForInOrForOfStatementIncludes */, node, outermostLabeledStatement);
            }
            function visitForOfStatement(node, outermostLabeledStatement) {
                return visitIterationStatementWithFacts(3008 /* ForInOrForOfStatementExcludes */, 5376 /* ForInOrForOfStatementIncludes */, node, outermostLabeledStatement, compilerOptions.downlevelIteration ? convertForOfStatementForIterable : convertForOfStatementForArray);
            }
            function convertForOfStatementHead(node, boundValue, convertedLoopBodyStatements) {
                const statements = [];
                const initializer = node.initializer;
                if (isVariableDeclarationList(initializer)) {
                    if (node.initializer.flags & 7 /* BlockScoped */) {
                        enableSubstitutionsForBlockScopedBindings();
                    }
                    const firstOriginalDeclaration = firstOrUndefined(initializer.declarations);
                    if (firstOriginalDeclaration && isBindingPattern(firstOriginalDeclaration.name)) {
                        const declarations = flattenDestructuringBinding(firstOriginalDeclaration, visitor, context, 0 /* All */, boundValue);
                        const declarationList = setTextRange(factory2.createVariableDeclarationList(declarations), node.initializer);
                        setOriginalNode(declarationList, node.initializer);
                        setSourceMapRange(declarationList, createRange(declarations[0].pos, last(declarations).end));
                        statements.push(factory2.createVariableStatement(
                        /*modifiers*/
                        void 0, declarationList));
                    }
                    else {
                        statements.push(setTextRange(factory2.createVariableStatement(
                        /*modifiers*/
                        void 0, setOriginalNode(setTextRange(factory2.createVariableDeclarationList([
                            factory2.createVariableDeclaration(firstOriginalDeclaration ? firstOriginalDeclaration.name : factory2.createTempVariable(
                            /*recordTempVariable*/
                            void 0), 
                            /*exclamationToken*/
                            void 0, 
                            /*type*/
                            void 0, boundValue)
                        ]), moveRangePos(initializer, -1)), initializer)), moveRangeEnd(initializer, -1)));
                    }
                }
                else {
                    const assignment = factory2.createAssignment(initializer, boundValue);
                    if (isDestructuringAssignment(assignment)) {
                        statements.push(factory2.createExpressionStatement(visitBinaryExpression(assignment, 
                        /*expressionResultIsUnused*/
                        true)));
                    }
                    else {
                        setTextRangeEnd(assignment, initializer.end);
                        statements.push(setTextRange(factory2.createExpressionStatement(Debug.checkDefined(visitNode(assignment, visitor, isExpression))), moveRangeEnd(initializer, -1)));
                    }
                }
                if (convertedLoopBodyStatements) {
                    return createSyntheticBlockForConvertedStatements(addRange(statements, convertedLoopBodyStatements));
                }
                else {
                    const statement = visitNode(node.statement, visitor, isStatement, factory2.liftToBlock);
                    Debug.assert(statement);
                    if (isBlock(statement)) {
                        return factory2.updateBlock(statement, setTextRange(factory2.createNodeArray(concatenate(statements, statement.statements)), statement.statements));
                    }
                    else {
                        statements.push(statement);
                        return createSyntheticBlockForConvertedStatements(statements);
                    }
                }
            }
            function createSyntheticBlockForConvertedStatements(statements) {
                return setEmitFlags(factory2.createBlock(factory2.createNodeArray(statements), 
                /*multiLine*/
                true), 96 /* NoSourceMap */ | 768 /* NoTokenSourceMaps */);
            }
            function convertForOfStatementForArray(node, outermostLabeledStatement, convertedLoopBodyStatements) {
                const expression = visitNode(node.expression, visitor, isExpression);
                Debug.assert(expression);
                const counter = factory2.createLoopVariable();
                const rhsReference = isIdentifier(expression) ? factory2.getGeneratedNameForNode(expression) : factory2.createTempVariable(
                /*recordTempVariable*/
                void 0);
                setEmitFlags(expression, 96 /* NoSourceMap */ | getEmitFlags(expression));
                const forStatement = setTextRange(factory2.createForStatement(
                /*initializer*/
                setEmitFlags(setTextRange(factory2.createVariableDeclarationList([
                    setTextRange(factory2.createVariableDeclaration(counter, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, factory2.createNumericLiteral(0)), moveRangePos(node.expression, -1)),
                    setTextRange(factory2.createVariableDeclaration(rhsReference, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, expression), node.expression)
                ]), node.expression), 4194304 /* NoHoisting */), 
                /*condition*/
                setTextRange(factory2.createLessThan(counter, factory2.createPropertyAccessExpression(rhsReference, "length")), node.expression), 
                /*incrementor*/
                setTextRange(factory2.createPostfixIncrement(counter), node.expression), 
                /*statement*/
                convertForOfStatementHead(node, factory2.createElementAccessExpression(rhsReference, counter), convertedLoopBodyStatements)), 
                /*location*/
                node);
                setEmitFlags(forStatement, 512 /* NoTokenTrailingSourceMaps */);
                setTextRange(forStatement, node);
                return factory2.restoreEnclosingLabel(forStatement, outermostLabeledStatement, convertedLoopState && resetLabel);
            }
            function convertForOfStatementForIterable(node, outermostLabeledStatement, convertedLoopBodyStatements, ancestorFacts) {
                const expression = visitNode(node.expression, visitor, isExpression);
                Debug.assert(expression);
                const iterator = isIdentifier(expression) ? factory2.getGeneratedNameForNode(expression) : factory2.createTempVariable(
                /*recordTempVariable*/
                void 0);
                const result = isIdentifier(expression) ? factory2.getGeneratedNameForNode(iterator) : factory2.createTempVariable(
                /*recordTempVariable*/
                void 0);
                const errorRecord = factory2.createUniqueName("e");
                const catchVariable = factory2.getGeneratedNameForNode(errorRecord);
                const returnMethod = factory2.createTempVariable(
                /*recordTempVariable*/
                void 0);
                const values = setTextRange(emitHelpers().createValuesHelper(expression), node.expression);
                const next = factory2.createCallExpression(factory2.createPropertyAccessExpression(iterator, "next"), 
                /*typeArguments*/
                void 0, []);
                hoistVariableDeclaration(errorRecord);
                hoistVariableDeclaration(returnMethod);
                const initializer = ancestorFacts & 1024 /* IterationContainer */ ? factory2.inlineExpressions([factory2.createAssignment(errorRecord, factory2.createVoidZero()), values]) : values;
                const forStatement = setEmitFlags(setTextRange(factory2.createForStatement(
                /*initializer*/
                setEmitFlags(setTextRange(factory2.createVariableDeclarationList([
                    setTextRange(factory2.createVariableDeclaration(iterator, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, initializer), node.expression),
                    factory2.createVariableDeclaration(result, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, next)
                ]), node.expression), 4194304 /* NoHoisting */), 
                /*condition*/
                factory2.createLogicalNot(factory2.createPropertyAccessExpression(result, "done")), 
                /*incrementor*/
                factory2.createAssignment(result, next), 
                /*statement*/
                convertForOfStatementHead(node, factory2.createPropertyAccessExpression(result, "value"), convertedLoopBodyStatements)), 
                /*location*/
                node), 512 /* NoTokenTrailingSourceMaps */);
                return factory2.createTryStatement(factory2.createBlock([
                    factory2.restoreEnclosingLabel(forStatement, outermostLabeledStatement, convertedLoopState && resetLabel)
                ]), factory2.createCatchClause(factory2.createVariableDeclaration(catchVariable), setEmitFlags(factory2.createBlock([
                    factory2.createExpressionStatement(factory2.createAssignment(errorRecord, factory2.createObjectLiteralExpression([
                        factory2.createPropertyAssignment("error", catchVariable)
                    ])))
                ]), 1 /* SingleLine */)), factory2.createBlock([
                    factory2.createTryStatement(
                    /*tryBlock*/
                    factory2.createBlock([
                        setEmitFlags(factory2.createIfStatement(factory2.createLogicalAnd(factory2.createLogicalAnd(result, factory2.createLogicalNot(factory2.createPropertyAccessExpression(result, "done"))), factory2.createAssignment(returnMethod, factory2.createPropertyAccessExpression(iterator, "return"))), factory2.createExpressionStatement(factory2.createFunctionCallCall(returnMethod, iterator, []))), 1 /* SingleLine */)
                    ]), 
                    /*catchClause*/
                    void 0, 
                    /*finallyBlock*/
                    setEmitFlags(factory2.createBlock([
                        setEmitFlags(factory2.createIfStatement(errorRecord, factory2.createThrowStatement(factory2.createPropertyAccessExpression(errorRecord, "error"))), 1 /* SingleLine */)
                    ]), 1 /* SingleLine */))
                ]));
            }
            function visitObjectLiteralExpression(node) {
                const properties = node.properties;
                let numInitialProperties = -1, hasComputed = false;
                for (let i = 0; i < properties.length; i++) {
                    const property = properties[i];
                    if (property.transformFlags & 1048576 /* ContainsYield */ && hierarchyFacts & 4 /* AsyncFunctionBody */ || (hasComputed = Debug.checkDefined(property.name).kind === 167 /* ComputedPropertyName */)) {
                        numInitialProperties = i;
                        break;
                    }
                }
                if (numInitialProperties < 0) {
                    return visitEachChild(node, visitor, context);
                }
                const temp = factory2.createTempVariable(hoistVariableDeclaration);
                const expressions = [];
                const assignment = factory2.createAssignment(temp, setEmitFlags(factory2.createObjectLiteralExpression(visitNodes2(properties, visitor, isObjectLiteralElementLike, 0, numInitialProperties), node.multiLine), hasComputed ? 131072 /* Indented */ : 0));
                if (node.multiLine) {
                    startOnNewLine(assignment);
                }
                expressions.push(assignment);
                addObjectLiteralMembers(expressions, node, temp, numInitialProperties);
                expressions.push(node.multiLine ? startOnNewLine(setParent(setTextRange(factory2.cloneNode(temp), temp), temp.parent)) : temp);
                return factory2.inlineExpressions(expressions);
            }
            function shouldConvertPartOfIterationStatement(node) {
                return (resolver.getNodeCheckFlags(node) & 8192 /* ContainsCapturedBlockScopeBinding */) !== 0;
            }
            function shouldConvertInitializerOfForStatement(node) {
                return isForStatement(node) && !!node.initializer && shouldConvertPartOfIterationStatement(node.initializer);
            }
            function shouldConvertConditionOfForStatement(node) {
                return isForStatement(node) && !!node.condition && shouldConvertPartOfIterationStatement(node.condition);
            }
            function shouldConvertIncrementorOfForStatement(node) {
                return isForStatement(node) && !!node.incrementor && shouldConvertPartOfIterationStatement(node.incrementor);
            }
            function shouldConvertIterationStatement(node) {
                return shouldConvertBodyOfIterationStatement(node) || shouldConvertInitializerOfForStatement(node);
            }
            function shouldConvertBodyOfIterationStatement(node) {
                return (resolver.getNodeCheckFlags(node) & 4096 /* LoopWithCapturedBlockScopedBinding */) !== 0;
            }
            function hoistVariableDeclarationDeclaredInConvertedLoop(state, node) {
                if (!state.hoistedLocalVariables) {
                    state.hoistedLocalVariables = [];
                }
                visit(node.name);
                function visit(node2) {
                    if (node2.kind === 80 /* Identifier */) {
                        state.hoistedLocalVariables.push(node2);
                    }
                    else {
                        for (const element of node2.elements) {
                            if (!isOmittedExpression(element)) {
                                visit(element.name);
                            }
                        }
                    }
                }
            }
            function convertIterationStatementBodyIfNecessary(node, outermostLabeledStatement, ancestorFacts, convert) {
                if (!shouldConvertIterationStatement(node)) {
                    let saveAllowedNonLabeledJumps;
                    if (convertedLoopState) {
                        saveAllowedNonLabeledJumps = convertedLoopState.allowedNonLabeledJumps;
                        convertedLoopState.allowedNonLabeledJumps = 2 /* Break */ | 4 /* Continue */;
                    }
                    const result = convert ? convert(node, outermostLabeledStatement, 
                    /*convertedLoopBodyStatements*/
                    void 0, ancestorFacts) : factory2.restoreEnclosingLabel(isForStatement(node) ? visitEachChildOfForStatement2(node) : visitEachChild(node, visitor, context), outermostLabeledStatement, convertedLoopState && resetLabel);
                    if (convertedLoopState) {
                        convertedLoopState.allowedNonLabeledJumps = saveAllowedNonLabeledJumps;
                    }
                    return result;
                }
                const currentState = createConvertedLoopState(node);
                const statements = [];
                const outerConvertedLoopState = convertedLoopState;
                convertedLoopState = currentState;
                const initializerFunction = shouldConvertInitializerOfForStatement(node) ? createFunctionForInitializerOfForStatement(node, currentState) : void 0;
                const bodyFunction = shouldConvertBodyOfIterationStatement(node) ? createFunctionForBodyOfIterationStatement(node, currentState, outerConvertedLoopState) : void 0;
                convertedLoopState = outerConvertedLoopState;
                if (initializerFunction)
                    statements.push(initializerFunction.functionDeclaration);
                if (bodyFunction)
                    statements.push(bodyFunction.functionDeclaration);
                addExtraDeclarationsForConvertedLoop(statements, currentState, outerConvertedLoopState);
                if (initializerFunction) {
                    statements.push(generateCallToConvertedLoopInitializer(initializerFunction.functionName, initializerFunction.containsYield));
                }
                let loop;
                if (bodyFunction) {
                    if (convert) {
                        loop = convert(node, outermostLabeledStatement, bodyFunction.part, ancestorFacts);
                    }
                    else {
                        const clone2 = convertIterationStatementCore(node, initializerFunction, factory2.createBlock(bodyFunction.part, 
                        /*multiLine*/
                        true));
                        loop = factory2.restoreEnclosingLabel(clone2, outermostLabeledStatement, convertedLoopState && resetLabel);
                    }
                }
                else {
                    const clone2 = convertIterationStatementCore(node, initializerFunction, Debug.checkDefined(visitNode(node.statement, visitor, isStatement, factory2.liftToBlock)));
                    loop = factory2.restoreEnclosingLabel(clone2, outermostLabeledStatement, convertedLoopState && resetLabel);
                }
                statements.push(loop);
                return statements;
            }
            function convertIterationStatementCore(node, initializerFunction, convertedLoopBody) {
                switch (node.kind) {
                    case 248 /* ForStatement */:
                        return convertForStatement(node, initializerFunction, convertedLoopBody);
                    case 249 /* ForInStatement */:
                        return convertForInStatement(node, convertedLoopBody);
                    case 250 /* ForOfStatement */:
                        return convertForOfStatement(node, convertedLoopBody);
                    case 246 /* DoStatement */:
                        return convertDoStatement(node, convertedLoopBody);
                    case 247 /* WhileStatement */:
                        return convertWhileStatement(node, convertedLoopBody);
                    default:
                        return Debug.failBadSyntaxKind(node, "IterationStatement expected");
                }
            }
            function convertForStatement(node, initializerFunction, convertedLoopBody) {
                const shouldConvertCondition = node.condition && shouldConvertPartOfIterationStatement(node.condition);
                const shouldConvertIncrementor = shouldConvertCondition || node.incrementor && shouldConvertPartOfIterationStatement(node.incrementor);
                return factory2.updateForStatement(node, visitNode(initializerFunction ? initializerFunction.part : node.initializer, visitorWithUnusedExpressionResult, isForInitializer), visitNode(shouldConvertCondition ? void 0 : node.condition, visitor, isExpression), visitNode(shouldConvertIncrementor ? void 0 : node.incrementor, visitorWithUnusedExpressionResult, isExpression), convertedLoopBody);
            }
            function convertForOfStatement(node, convertedLoopBody) {
                return factory2.updateForOfStatement(node, 
                /*awaitModifier*/
                void 0, Debug.checkDefined(visitNode(node.initializer, visitor, isForInitializer)), Debug.checkDefined(visitNode(node.expression, visitor, isExpression)), convertedLoopBody);
            }
            function convertForInStatement(node, convertedLoopBody) {
                return factory2.updateForInStatement(node, Debug.checkDefined(visitNode(node.initializer, visitor, isForInitializer)), Debug.checkDefined(visitNode(node.expression, visitor, isExpression)), convertedLoopBody);
            }
            function convertDoStatement(node, convertedLoopBody) {
                return factory2.updateDoStatement(node, convertedLoopBody, Debug.checkDefined(visitNode(node.expression, visitor, isExpression)));
            }
            function convertWhileStatement(node, convertedLoopBody) {
                return factory2.updateWhileStatement(node, Debug.checkDefined(visitNode(node.expression, visitor, isExpression)), convertedLoopBody);
            }
            function createConvertedLoopState(node) {
                let loopInitializer;
                switch (node.kind) {
                    case 248 /* ForStatement */:
                    case 249 /* ForInStatement */:
                    case 250 /* ForOfStatement */:
                        const initializer = node.initializer;
                        if (initializer && initializer.kind === 261 /* VariableDeclarationList */) {
                            loopInitializer = initializer;
                        }
                        break;
                }
                const loopParameters = [];
                const loopOutParameters = [];
                if (loopInitializer && getCombinedNodeFlags(loopInitializer) & 7 /* BlockScoped */) {
                    const hasCapturedBindingsInForHead = shouldConvertInitializerOfForStatement(node) || shouldConvertConditionOfForStatement(node) || shouldConvertIncrementorOfForStatement(node);
                    for (const decl of loopInitializer.declarations) {
                        processLoopVariableDeclaration(node, decl, loopParameters, loopOutParameters, hasCapturedBindingsInForHead);
                    }
                }
                const currentState = { loopParameters, loopOutParameters };
                if (convertedLoopState) {
                    if (convertedLoopState.argumentsName) {
                        currentState.argumentsName = convertedLoopState.argumentsName;
                    }
                    if (convertedLoopState.thisName) {
                        currentState.thisName = convertedLoopState.thisName;
                    }
                    if (convertedLoopState.hoistedLocalVariables) {
                        currentState.hoistedLocalVariables = convertedLoopState.hoistedLocalVariables;
                    }
                }
                return currentState;
            }
            function addExtraDeclarationsForConvertedLoop(statements, state, outerState) {
                let extraVariableDeclarations;
                if (state.argumentsName) {
                    if (outerState) {
                        outerState.argumentsName = state.argumentsName;
                    }
                    else {
                        (extraVariableDeclarations || (extraVariableDeclarations = [])).push(factory2.createVariableDeclaration(state.argumentsName, 
                        /*exclamationToken*/
                        void 0, 
                        /*type*/
                        void 0, factory2.createIdentifier("arguments")));
                    }
                }
                if (state.thisName) {
                    if (outerState) {
                        outerState.thisName = state.thisName;
                    }
                    else {
                        (extraVariableDeclarations || (extraVariableDeclarations = [])).push(factory2.createVariableDeclaration(state.thisName, 
                        /*exclamationToken*/
                        void 0, 
                        /*type*/
                        void 0, factory2.createIdentifier("this")));
                    }
                }
                if (state.hoistedLocalVariables) {
                    if (outerState) {
                        outerState.hoistedLocalVariables = state.hoistedLocalVariables;
                    }
                    else {
                        if (!extraVariableDeclarations) {
                            extraVariableDeclarations = [];
                        }
                        for (const identifier of state.hoistedLocalVariables) {
                            extraVariableDeclarations.push(factory2.createVariableDeclaration(identifier));
                        }
                    }
                }
                if (state.loopOutParameters.length) {
                    if (!extraVariableDeclarations) {
                        extraVariableDeclarations = [];
                    }
                    for (const outParam of state.loopOutParameters) {
                        extraVariableDeclarations.push(factory2.createVariableDeclaration(outParam.outParamName));
                    }
                }
                if (state.conditionVariable) {
                    if (!extraVariableDeclarations) {
                        extraVariableDeclarations = [];
                    }
                    extraVariableDeclarations.push(factory2.createVariableDeclaration(state.conditionVariable, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, factory2.createFalse()));
                }
                if (extraVariableDeclarations) {
                    statements.push(factory2.createVariableStatement(
                    /*modifiers*/
                    void 0, factory2.createVariableDeclarationList(extraVariableDeclarations)));
                }
            }
            function createOutVariable(p) {
                return factory2.createVariableDeclaration(p.originalName, 
                /*exclamationToken*/
                void 0, 
                /*type*/
                void 0, p.outParamName);
            }
            function createFunctionForInitializerOfForStatement(node, currentState) {
                const functionName = factory2.createUniqueName("_loop_init");
                const containsYield = (node.initializer.transformFlags & 1048576 /* ContainsYield */) !== 0;
                let emitFlags = 0 /* None */;
                if (currentState.containsLexicalThis)
                    emitFlags |= 16 /* CapturesThis */;
                if (containsYield && hierarchyFacts & 4 /* AsyncFunctionBody */)
                    emitFlags |= 524288 /* AsyncFunctionBody */;
                const statements = [];
                statements.push(factory2.createVariableStatement(
                /*modifiers*/
                void 0, node.initializer));
                copyOutParameters(currentState.loopOutParameters, 2 /* Initializer */, 1 /* ToOutParameter */, statements);
                const functionDeclaration = factory2.createVariableStatement(
                /*modifiers*/
                void 0, setEmitFlags(factory2.createVariableDeclarationList([
                    factory2.createVariableDeclaration(functionName, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, setEmitFlags(factory2.createFunctionExpression(
                    /*modifiers*/
                    void 0, containsYield ? factory2.createToken(42 /* AsteriskToken */) : void 0, 
                    /*name*/
                    void 0, 
                    /*typeParameters*/
                    void 0, 
                    /*parameters*/
                    void 0, 
                    /*type*/
                    void 0, Debug.checkDefined(visitNode(factory2.createBlock(statements, 
                    /*multiLine*/
                    true), visitor, isBlock))), emitFlags))
                ]), 4194304 /* NoHoisting */));
                const part = factory2.createVariableDeclarationList(map(currentState.loopOutParameters, createOutVariable));
                return { functionName, containsYield, functionDeclaration, part };
            }
            function createFunctionForBodyOfIterationStatement(node, currentState, outerState) {
                const functionName = factory2.createUniqueName("_loop");
                startLexicalEnvironment();
                const statement = visitNode(node.statement, visitor, isStatement, factory2.liftToBlock);
                const lexicalEnvironment = endLexicalEnvironment();
                const statements = [];
                if (shouldConvertConditionOfForStatement(node) || shouldConvertIncrementorOfForStatement(node)) {
                    currentState.conditionVariable = factory2.createUniqueName("inc");
                    if (node.incrementor) {
                        statements.push(factory2.createIfStatement(currentState.conditionVariable, factory2.createExpressionStatement(Debug.checkDefined(visitNode(node.incrementor, visitor, isExpression))), factory2.createExpressionStatement(factory2.createAssignment(currentState.conditionVariable, factory2.createTrue()))));
                    }
                    else {
                        statements.push(factory2.createIfStatement(factory2.createLogicalNot(currentState.conditionVariable), factory2.createExpressionStatement(factory2.createAssignment(currentState.conditionVariable, factory2.createTrue()))));
                    }
                    if (shouldConvertConditionOfForStatement(node)) {
                        statements.push(factory2.createIfStatement(factory2.createPrefixUnaryExpression(54 /* ExclamationToken */, Debug.checkDefined(visitNode(node.condition, visitor, isExpression))), Debug.checkDefined(visitNode(factory2.createBreakStatement(), visitor, isStatement))));
                    }
                }
                Debug.assert(statement);
                if (isBlock(statement)) {
                    addRange(statements, statement.statements);
                }
                else {
                    statements.push(statement);
                }
                copyOutParameters(currentState.loopOutParameters, 1 /* Body */, 1 /* ToOutParameter */, statements);
                insertStatementsAfterStandardPrologue(statements, lexicalEnvironment);
                const loopBody = factory2.createBlock(statements, 
                /*multiLine*/
                true);
                if (isBlock(statement))
                    setOriginalNode(loopBody, statement);
                const containsYield = (node.statement.transformFlags & 1048576 /* ContainsYield */) !== 0;
                let emitFlags = 1048576 /* ReuseTempVariableScope */;
                if (currentState.containsLexicalThis)
                    emitFlags |= 16 /* CapturesThis */;
                if (containsYield && (hierarchyFacts & 4 /* AsyncFunctionBody */) !== 0)
                    emitFlags |= 524288 /* AsyncFunctionBody */;
                const functionDeclaration = factory2.createVariableStatement(
                /*modifiers*/
                void 0, setEmitFlags(factory2.createVariableDeclarationList([
                    factory2.createVariableDeclaration(functionName, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, setEmitFlags(factory2.createFunctionExpression(
                    /*modifiers*/
                    void 0, containsYield ? factory2.createToken(42 /* AsteriskToken */) : void 0, 
                    /*name*/
                    void 0, 
                    /*typeParameters*/
                    void 0, currentState.loopParameters, 
                    /*type*/
                    void 0, loopBody), emitFlags))
                ]), 4194304 /* NoHoisting */));
                const part = generateCallToConvertedLoop(functionName, currentState, outerState, containsYield);
                return { functionName, containsYield, functionDeclaration, part };
            }
            function copyOutParameter(outParam, copyDirection) {
                const source = copyDirection === 0 /* ToOriginal */ ? outParam.outParamName : outParam.originalName;
                const target = copyDirection === 0 /* ToOriginal */ ? outParam.originalName : outParam.outParamName;
                return factory2.createBinaryExpression(target, 64 /* EqualsToken */, source);
            }
            function copyOutParameters(outParams, partFlags, copyDirection, statements) {
                for (const outParam of outParams) {
                    if (outParam.flags & partFlags) {
                        statements.push(factory2.createExpressionStatement(copyOutParameter(outParam, copyDirection)));
                    }
                }
            }
            function generateCallToConvertedLoopInitializer(initFunctionExpressionName, containsYield) {
                const call = factory2.createCallExpression(initFunctionExpressionName, 
                /*typeArguments*/
                void 0, []);
                const callResult = containsYield ? factory2.createYieldExpression(factory2.createToken(42 /* AsteriskToken */), setEmitFlags(call, 8388608 /* Iterator */)) : call;
                return factory2.createExpressionStatement(callResult);
            }
            function generateCallToConvertedLoop(loopFunctionExpressionName, state, outerState, containsYield) {
                const statements = [];
                const isSimpleLoop = !(state.nonLocalJumps & ~4 /* Continue */) && !state.labeledNonLocalBreaks && !state.labeledNonLocalContinues;
                const call = factory2.createCallExpression(loopFunctionExpressionName, 
                /*typeArguments*/
                void 0, map(state.loopParameters, (p) => p.name));
                const callResult = containsYield ? factory2.createYieldExpression(factory2.createToken(42 /* AsteriskToken */), setEmitFlags(call, 8388608 /* Iterator */)) : call;
                if (isSimpleLoop) {
                    statements.push(factory2.createExpressionStatement(callResult));
                    copyOutParameters(state.loopOutParameters, 1 /* Body */, 0 /* ToOriginal */, statements);
                }
                else {
                    const loopResultName = factory2.createUniqueName("state");
                    const stateVariable = factory2.createVariableStatement(
                    /*modifiers*/
                    void 0, factory2.createVariableDeclarationList([factory2.createVariableDeclaration(loopResultName, 
                        /*exclamationToken*/
                        void 0, 
                        /*type*/
                        void 0, callResult)]));
                    statements.push(stateVariable);
                    copyOutParameters(state.loopOutParameters, 1 /* Body */, 0 /* ToOriginal */, statements);
                    if (state.nonLocalJumps & 8 /* Return */) {
                        let returnStatement;
                        if (outerState) {
                            outerState.nonLocalJumps |= 8 /* Return */;
                            returnStatement = factory2.createReturnStatement(loopResultName);
                        }
                        else {
                            returnStatement = factory2.createReturnStatement(factory2.createPropertyAccessExpression(loopResultName, "value"));
                        }
                        statements.push(factory2.createIfStatement(factory2.createTypeCheck(loopResultName, "object"), returnStatement));
                    }
                    if (state.nonLocalJumps & 2 /* Break */) {
                        statements.push(factory2.createIfStatement(factory2.createStrictEquality(loopResultName, factory2.createStringLiteral("break")), factory2.createBreakStatement()));
                    }
                    if (state.labeledNonLocalBreaks || state.labeledNonLocalContinues) {
                        const caseClauses = [];
                        processLabeledJumps(state.labeledNonLocalBreaks, 
                        /*isBreak*/
                        true, loopResultName, outerState, caseClauses);
                        processLabeledJumps(state.labeledNonLocalContinues, 
                        /*isBreak*/
                        false, loopResultName, outerState, caseClauses);
                        statements.push(factory2.createSwitchStatement(loopResultName, factory2.createCaseBlock(caseClauses)));
                    }
                }
                return statements;
            }
            function setLabeledJump(state, isBreak, labelText, labelMarker) {
                if (isBreak) {
                    if (!state.labeledNonLocalBreaks) {
                        state.labeledNonLocalBreaks = /* @__PURE__ */ new Map();
                    }
                    state.labeledNonLocalBreaks.set(labelText, labelMarker);
                }
                else {
                    if (!state.labeledNonLocalContinues) {
                        state.labeledNonLocalContinues = /* @__PURE__ */ new Map();
                    }
                    state.labeledNonLocalContinues.set(labelText, labelMarker);
                }
            }
            function processLabeledJumps(table, isBreak, loopResultName, outerLoop, caseClauses) {
                if (!table) {
                    return;
                }
                table.forEach((labelMarker, labelText) => {
                    const statements = [];
                    if (!outerLoop || outerLoop.labels && outerLoop.labels.get(labelText)) {
                        const label = factory2.createIdentifier(labelText);
                        statements.push(isBreak ? factory2.createBreakStatement(label) : factory2.createContinueStatement(label));
                    }
                    else {
                        setLabeledJump(outerLoop, isBreak, labelText, labelMarker);
                        statements.push(factory2.createReturnStatement(loopResultName));
                    }
                    caseClauses.push(factory2.createCaseClause(factory2.createStringLiteral(labelMarker), statements));
                });
            }
            function processLoopVariableDeclaration(container, decl, loopParameters, loopOutParameters, hasCapturedBindingsInForHead) {
                const name = decl.name;
                if (isBindingPattern(name)) {
                    for (const element of name.elements) {
                        if (!isOmittedExpression(element)) {
                            processLoopVariableDeclaration(container, element, loopParameters, loopOutParameters, hasCapturedBindingsInForHead);
                        }
                    }
                }
                else {
                    loopParameters.push(factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, name));
                    const checkFlags = resolver.getNodeCheckFlags(decl);
                    if (checkFlags & 65536 /* NeedsLoopOutParameter */ || hasCapturedBindingsInForHead) {
                        const outParamName = factory2.createUniqueName("out_" + idText(name));
                        let flags = 0 /* None */;
                        if (checkFlags & 65536 /* NeedsLoopOutParameter */) {
                            flags |= 1 /* Body */;
                        }
                        if (isForStatement(container)) {
                            if (container.initializer && resolver.isBindingCapturedByNode(container.initializer, decl)) {
                                flags |= 2 /* Initializer */;
                            }
                            if (container.condition && resolver.isBindingCapturedByNode(container.condition, decl) || container.incrementor && resolver.isBindingCapturedByNode(container.incrementor, decl)) {
                                flags |= 1 /* Body */;
                            }
                        }
                        loopOutParameters.push({ flags, originalName: name, outParamName });
                    }
                }
            }
            function addObjectLiteralMembers(expressions, node, receiver, start) {
                const properties = node.properties;
                const numProperties = properties.length;
                for (let i = start; i < numProperties; i++) {
                    const property = properties[i];
                    switch (property.kind) {
                        case 177 /* GetAccessor */:
                        case 178 /* SetAccessor */:
                            const accessors = getAllAccessorDeclarations(node.properties, property);
                            if (property === accessors.firstAccessor) {
                                expressions.push(transformAccessorsToExpression(receiver, accessors, node, !!node.multiLine));
                            }
                            break;
                        case 174 /* MethodDeclaration */:
                            expressions.push(transformObjectLiteralMethodDeclarationToExpression(property, receiver, node, node.multiLine));
                            break;
                        case 303 /* PropertyAssignment */:
                            expressions.push(transformPropertyAssignmentToExpression(property, receiver, node.multiLine));
                            break;
                        case 304 /* ShorthandPropertyAssignment */:
                            expressions.push(transformShorthandPropertyAssignmentToExpression(property, receiver, node.multiLine));
                            break;
                        default:
                            Debug.failBadSyntaxKind(node);
                            break;
                    }
                }
            }
            function transformPropertyAssignmentToExpression(property, receiver, startsOnNewLine) {
                const expression = factory2.createAssignment(createMemberAccessForPropertyName(factory2, receiver, Debug.checkDefined(visitNode(property.name, visitor, isPropertyName))), Debug.checkDefined(visitNode(property.initializer, visitor, isExpression)));
                setTextRange(expression, property);
                if (startsOnNewLine) {
                    startOnNewLine(expression);
                }
                return expression;
            }
            function transformShorthandPropertyAssignmentToExpression(property, receiver, startsOnNewLine) {
                const expression = factory2.createAssignment(createMemberAccessForPropertyName(factory2, receiver, Debug.checkDefined(visitNode(property.name, visitor, isPropertyName))), factory2.cloneNode(property.name));
                setTextRange(expression, property);
                if (startsOnNewLine) {
                    startOnNewLine(expression);
                }
                return expression;
            }
            function transformObjectLiteralMethodDeclarationToExpression(method, receiver, container, startsOnNewLine) {
                const expression = factory2.createAssignment(createMemberAccessForPropertyName(factory2, receiver, Debug.checkDefined(visitNode(method.name, visitor, isPropertyName))), transformFunctionLikeToExpression(method, 
                /*location*/
                method, 
                /*name*/
                void 0, container));
                setTextRange(expression, method);
                if (startsOnNewLine) {
                    startOnNewLine(expression);
                }
                return expression;
            }
            function visitCatchClause(node) {
                const ancestorFacts = enterSubtree(7104 /* BlockScopeExcludes */, 0 /* BlockScopeIncludes */);
                let updated;
                Debug.assert(!!node.variableDeclaration, "Catch clause variable should always be present when downleveling ES2015.");
                if (isBindingPattern(node.variableDeclaration.name)) {
                    const temp = factory2.createTempVariable(
                    /*recordTempVariable*/
                    void 0);
                    const newVariableDeclaration = factory2.createVariableDeclaration(temp);
                    setTextRange(newVariableDeclaration, node.variableDeclaration);
                    const vars = flattenDestructuringBinding(node.variableDeclaration, visitor, context, 0 /* All */, temp);
                    const list = factory2.createVariableDeclarationList(vars);
                    setTextRange(list, node.variableDeclaration);
                    const destructure = factory2.createVariableStatement(
                    /*modifiers*/
                    void 0, list);
                    updated = factory2.updateCatchClause(node, newVariableDeclaration, addStatementToStartOfBlock(node.block, destructure));
                }
                else {
                    updated = visitEachChild(node, visitor, context);
                }
                exitSubtree(ancestorFacts, 0 /* None */, 0 /* None */);
                return updated;
            }
            function addStatementToStartOfBlock(block, statement) {
                const transformedStatements = visitNodes2(block.statements, visitor, isStatement);
                return factory2.updateBlock(block, [statement, ...transformedStatements]);
            }
            function visitMethodDeclaration(node) {
                Debug.assert(!isComputedPropertyName(node.name));
                const functionExpression = transformFunctionLikeToExpression(node, 
                /*location*/
                moveRangePos(node, -1), 
                /*name*/
                void 0, 
                /*container*/
                void 0);
                setEmitFlags(functionExpression, 1024 /* NoLeadingComments */ | getEmitFlags(functionExpression));
                return setTextRange(factory2.createPropertyAssignment(node.name, functionExpression), 
                /*location*/
                node);
            }
            function visitAccessorDeclaration(node) {
                Debug.assert(!isComputedPropertyName(node.name));
                const savedConvertedLoopState = convertedLoopState;
                convertedLoopState = void 0;
                const ancestorFacts = enterSubtree(32670 /* FunctionExcludes */, 65 /* FunctionIncludes */);
                let updated;
                const parameters = visitParameterList(node.parameters, visitor, context);
                const body = transformFunctionBody2(node);
                if (node.kind === 177 /* GetAccessor */) {
                    updated = factory2.updateGetAccessorDeclaration(node, node.modifiers, node.name, parameters, node.type, body);
                }
                else {
                    updated = factory2.updateSetAccessorDeclaration(node, node.modifiers, node.name, parameters, body);
                }
                exitSubtree(ancestorFacts, 229376 /* FunctionSubtreeExcludes */, 0 /* None */);
                convertedLoopState = savedConvertedLoopState;
                return updated;
            }
            function visitShorthandPropertyAssignment(node) {
                return setTextRange(factory2.createPropertyAssignment(node.name, visitIdentifier(factory2.cloneNode(node.name))), 
                /*location*/
                node);
            }
            function visitComputedPropertyName(node) {
                return visitEachChild(node, visitor, context);
            }
            function visitYieldExpression(node) {
                return visitEachChild(node, visitor, context);
            }
            function visitArrayLiteralExpression(node) {
                if (some(node.elements, isSpreadElement)) {
                    return transformAndSpreadElements(node.elements, 
                    /*isArgumentList*/
                    false, !!node.multiLine, 
                    /*hasTrailingComma*/
                    !!node.elements.hasTrailingComma);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitCallExpression(node) {
                if (getInternalEmitFlags(node) & 1 /* TypeScriptClassWrapper */) {
                    return visitTypeScriptClassWrapper(node);
                }
                const expression = skipOuterExpressions(node.expression);
                if (expression.kind === 108 /* SuperKeyword */ || isSuperProperty(expression) || some(node.arguments, isSpreadElement)) {
                    return visitCallExpressionWithPotentialCapturedThisAssignment(node, 
                    /*assignToCapturedThis*/
                    true);
                }
                return factory2.updateCallExpression(node, Debug.checkDefined(visitNode(node.expression, callExpressionVisitor, isExpression)), 
                /*typeArguments*/
                void 0, visitNodes2(node.arguments, visitor, isExpression));
            }
            function visitTypeScriptClassWrapper(node) {
                const body = cast(cast(skipOuterExpressions(node.expression), isArrowFunction).body, isBlock);
                const isVariableStatementWithInitializer = (stmt) => isVariableStatement(stmt) && !!first(stmt.declarationList.declarations).initializer;
                const savedConvertedLoopState = convertedLoopState;
                convertedLoopState = void 0;
                const bodyStatements = visitNodes2(body.statements, classWrapperStatementVisitor, isStatement);
                convertedLoopState = savedConvertedLoopState;
                const classStatements = filter(bodyStatements, isVariableStatementWithInitializer);
                const remainingStatements = filter(bodyStatements, (stmt) => !isVariableStatementWithInitializer(stmt));
                const varStatement = cast(first(classStatements), isVariableStatement);
                const variable = varStatement.declarationList.declarations[0];
                const initializer = skipOuterExpressions(variable.initializer);
                let aliasAssignment = tryCast(initializer, isAssignmentExpression);
                if (!aliasAssignment && isBinaryExpression(initializer) && initializer.operatorToken.kind === 28 /* CommaToken */) {
                    aliasAssignment = tryCast(initializer.left, isAssignmentExpression);
                }
                const call = cast(aliasAssignment ? skipOuterExpressions(aliasAssignment.right) : initializer, isCallExpression);
                const func = cast(skipOuterExpressions(call.expression), isFunctionExpression);
                const funcStatements = func.body.statements;
                let classBodyStart = 0;
                let classBodyEnd = -1;
                const statements = [];
                if (aliasAssignment) {
                    const extendsCall = tryCast(funcStatements[classBodyStart], isExpressionStatement);
                    if (extendsCall) {
                        statements.push(extendsCall);
                        classBodyStart++;
                    }
                    statements.push(funcStatements[classBodyStart]);
                    classBodyStart++;
                    statements.push(factory2.createExpressionStatement(factory2.createAssignment(aliasAssignment.left, cast(variable.name, isIdentifier))));
                }
                while (!isReturnStatement(elementAt(funcStatements, classBodyEnd))) {
                    classBodyEnd--;
                }
                addRange(statements, funcStatements, classBodyStart, classBodyEnd);
                if (classBodyEnd < -1) {
                    addRange(statements, funcStatements, classBodyEnd + 1);
                }
                const returnStatement = tryCast(elementAt(funcStatements, classBodyEnd), isReturnStatement);
                for (const statement of remainingStatements) {
                    if (isReturnStatement(statement) && (returnStatement == null ? void 0 : returnStatement.expression) && !isIdentifier(returnStatement.expression)) {
                        statements.push(returnStatement);
                    }
                    else {
                        statements.push(statement);
                    }
                }
                addRange(statements, classStatements, 
                /*start*/
                1);
                return factory2.restoreOuterExpressions(node.expression, factory2.restoreOuterExpressions(variable.initializer, factory2.restoreOuterExpressions(aliasAssignment && aliasAssignment.right, factory2.updateCallExpression(call, factory2.restoreOuterExpressions(call.expression, factory2.updateFunctionExpression(func, 
                /*modifiers*/
                void 0, 
                /*asteriskToken*/
                void 0, 
                /*name*/
                void 0, 
                /*typeParameters*/
                void 0, func.parameters, 
                /*type*/
                void 0, factory2.updateBlock(func.body, statements))), 
                /*typeArguments*/
                void 0, call.arguments))));
            }
            function visitCallExpressionWithPotentialCapturedThisAssignment(node, assignToCapturedThis) {
                if (node.transformFlags & 32768 /* ContainsRestOrSpread */ || node.expression.kind === 108 /* SuperKeyword */ || isSuperProperty(skipOuterExpressions(node.expression))) {
                    const { target, thisArg } = factory2.createCallBinding(node.expression, hoistVariableDeclaration);
                    if (node.expression.kind === 108 /* SuperKeyword */) {
                        setEmitFlags(thisArg, 8 /* NoSubstitution */);
                    }
                    let resultingCall;
                    if (node.transformFlags & 32768 /* ContainsRestOrSpread */) {
                        resultingCall = factory2.createFunctionApplyCall(Debug.checkDefined(visitNode(target, callExpressionVisitor, isExpression)), node.expression.kind === 108 /* SuperKeyword */ ? thisArg : Debug.checkDefined(visitNode(thisArg, visitor, isExpression)), transformAndSpreadElements(node.arguments, 
                        /*isArgumentList*/
                        true, 
                        /*multiLine*/
                        false, 
                        /*hasTrailingComma*/
                        false));
                    }
                    else {
                        resultingCall = setTextRange(factory2.createFunctionCallCall(Debug.checkDefined(visitNode(target, callExpressionVisitor, isExpression)), node.expression.kind === 108 /* SuperKeyword */ ? thisArg : Debug.checkDefined(visitNode(thisArg, visitor, isExpression)), visitNodes2(node.arguments, visitor, isExpression)), node);
                    }
                    if (node.expression.kind === 108 /* SuperKeyword */) {
                        const initializer = factory2.createLogicalOr(resultingCall, createActualThis());
                        resultingCall = assignToCapturedThis ? factory2.createAssignment(createCapturedThis(), initializer) : initializer;
                    }
                    return setOriginalNode(resultingCall, node);
                }
                if (isSuperCall(node)) {
                    hierarchyFacts |= 131072 /* CapturedLexicalThis */;
                }
                return visitEachChild(node, visitor, context);
            }
            function visitNewExpression(node) {
                if (some(node.arguments, isSpreadElement)) {
                    const { target, thisArg } = factory2.createCallBinding(factory2.createPropertyAccessExpression(node.expression, "bind"), hoistVariableDeclaration);
                    return factory2.createNewExpression(factory2.createFunctionApplyCall(Debug.checkDefined(visitNode(target, visitor, isExpression)), thisArg, transformAndSpreadElements(factory2.createNodeArray([factory2.createVoidZero(), ...node.arguments]), 
                    /*isArgumentList*/
                    true, 
                    /*multiLine*/
                    false, 
                    /*hasTrailingComma*/
                    false)), 
                    /*typeArguments*/
                    void 0, []);
                }
                return visitEachChild(node, visitor, context);
            }
            function transformAndSpreadElements(elements, isArgumentList, multiLine, hasTrailingComma) {
                const numElements = elements.length;
                const segments = flatten(
                // As we visit each element, we return one of two functions to use as the "key":
                // - `visitSpanOfSpreads` for one or more contiguous `...` spread expressions, i.e. `...a, ...b` in `[1, 2, ...a, ...b]`
                // - `visitSpanOfNonSpreads` for one or more contiguous non-spread elements, i.e. `1, 2`, in `[1, 2, ...a, ...b]`
                spanMap(elements, partitionSpread, (partition, visitPartition, _start, end) => visitPartition(partition, multiLine, hasTrailingComma && end === numElements)));
                if (segments.length === 1) {
                    const firstSegment = segments[0];
                    if (isArgumentList && !compilerOptions.downlevelIteration || isPackedArrayLiteral(firstSegment.expression) || isCallToHelper(firstSegment.expression, "___spreadArray")) {
                        return firstSegment.expression;
                    }
                }
                const helpers = emitHelpers();
                const startsWithSpread = segments[0].kind !== 0 /* None */;
                let expression = startsWithSpread ? factory2.createArrayLiteralExpression() : segments[0].expression;
                for (let i = startsWithSpread ? 0 : 1; i < segments.length; i++) {
                    const segment = segments[i];
                    expression = helpers.createSpreadArrayHelper(expression, segment.expression, segment.kind === 1 /* UnpackedSpread */ && !isArgumentList);
                }
                return expression;
            }
            function partitionSpread(node) {
                return isSpreadElement(node) ? visitSpanOfSpreads : visitSpanOfNonSpreads;
            }
            function visitSpanOfSpreads(chunk) {
                return map(chunk, visitExpressionOfSpread);
            }
            function visitExpressionOfSpread(node) {
                Debug.assertNode(node, isSpreadElement);
                let expression = visitNode(node.expression, visitor, isExpression);
                Debug.assert(expression);
                const isCallToReadHelper = isCallToHelper(expression, "___read");
                let kind = isCallToReadHelper || isPackedArrayLiteral(expression) ? 2 /* PackedSpread */ : 1 /* UnpackedSpread */;
                if (compilerOptions.downlevelIteration && kind === 1 /* UnpackedSpread */ && !isArrayLiteralExpression(expression) && !isCallToReadHelper) {
                    expression = emitHelpers().createReadHelper(expression, 
                    /*count*/
                    void 0);
                    kind = 2 /* PackedSpread */;
                }
                return createSpreadSegment(kind, expression);
            }
            function visitSpanOfNonSpreads(chunk, multiLine, hasTrailingComma) {
                const expression = factory2.createArrayLiteralExpression(visitNodes2(factory2.createNodeArray(chunk, hasTrailingComma), visitor, isExpression), multiLine);
                return createSpreadSegment(0 /* None */, expression);
            }
            function visitSpreadElement(node) {
                return visitNode(node.expression, visitor, isExpression);
            }
            function visitTemplateLiteral(node) {
                return setTextRange(factory2.createStringLiteral(node.text), node);
            }
            function visitStringLiteral(node) {
                if (node.hasExtendedUnicodeEscape) {
                    return setTextRange(factory2.createStringLiteral(node.text), node);
                }
                return node;
            }
            function visitNumericLiteral(node) {
                if (node.numericLiteralFlags & 384 /* BinaryOrOctalSpecifier */) {
                    return setTextRange(factory2.createNumericLiteral(node.text), node);
                }
                return node;
            }
            function visitTaggedTemplateExpression(node) {
                return processTaggedTemplateExpression(context, node, visitor, currentSourceFile, recordTaggedTemplateString, 1 /* All */);
            }
            function visitTemplateExpression(node) {
                let expression = factory2.createStringLiteral(node.head.text);
                for (const span of node.templateSpans) {
                    const args = [Debug.checkDefined(visitNode(span.expression, visitor, isExpression))];
                    if (span.literal.text.length > 0) {
                        args.push(factory2.createStringLiteral(span.literal.text));
                    }
                    expression = factory2.createCallExpression(factory2.createPropertyAccessExpression(expression, "concat"), 
                    /*typeArguments*/
                    void 0, args);
                }
                return setTextRange(expression, node);
            }
            function createSyntheticSuper() {
                return factory2.createUniqueName("_super", 16 /* Optimistic */ | 32 /* FileLevel */);
            }
            function visitSuperKeyword(node, isExpressionOfCall) {
                const expression = hierarchyFacts & 8 /* NonStaticClassElement */ && !isExpressionOfCall ? factory2.createPropertyAccessExpression(setOriginalNode(createSyntheticSuper(), node), "prototype") : createSyntheticSuper();
                setOriginalNode(expression, node);
                setCommentRange(expression, node);
                setSourceMapRange(expression, node);
                return expression;
            }
            function visitMetaProperty(node) {
                if (node.keywordToken === 105 /* NewKeyword */ && node.name.escapedText === "target") {
                    hierarchyFacts |= 32768 /* NewTarget */;
                    return factory2.createUniqueName("_newTarget", 16 /* Optimistic */ | 32 /* FileLevel */);
                }
                return node;
            }
            function onEmitNode(hint, node, emitCallback) {
                if (enabledSubstitutions & 1 /* CapturedThis */ && isFunctionLike(node)) {
                    const ancestorFacts = enterSubtree(32670 /* FunctionExcludes */, getEmitFlags(node) & 16 /* CapturesThis */ ? 65 /* FunctionIncludes */ | 16 /* CapturesThis */ : 65 /* FunctionIncludes */);
                    previousOnEmitNode(hint, node, emitCallback);
                    exitSubtree(ancestorFacts, 0 /* None */, 0 /* None */);
                    return;
                }
                previousOnEmitNode(hint, node, emitCallback);
            }
            function enableSubstitutionsForBlockScopedBindings() {
                if ((enabledSubstitutions & 2 /* BlockScopedBindings */) === 0) {
                    enabledSubstitutions |= 2 /* BlockScopedBindings */;
                    context.enableSubstitution(80 /* Identifier */);
                }
            }
            function enableSubstitutionsForCapturedThis() {
                if ((enabledSubstitutions & 1 /* CapturedThis */) === 0) {
                    enabledSubstitutions |= 1 /* CapturedThis */;
                    context.enableSubstitution(110 /* ThisKeyword */);
                    context.enableEmitNotification(176 /* Constructor */);
                    context.enableEmitNotification(174 /* MethodDeclaration */);
                    context.enableEmitNotification(177 /* GetAccessor */);
                    context.enableEmitNotification(178 /* SetAccessor */);
                    context.enableEmitNotification(219 /* ArrowFunction */);
                    context.enableEmitNotification(218 /* FunctionExpression */);
                    context.enableEmitNotification(262 /* FunctionDeclaration */);
                }
            }
            function onSubstituteNode(hint, node) {
                node = previousOnSubstituteNode(hint, node);
                if (hint === 1 /* Expression */) {
                    return substituteExpression(node);
                }
                if (isIdentifier(node)) {
                    return substituteIdentifier(node);
                }
                return node;
            }
            function substituteIdentifier(node) {
                if (enabledSubstitutions & 2 /* BlockScopedBindings */ && !isInternalName(node)) {
                    const original = getParseTreeNode(node, isIdentifier);
                    if (original && isNameOfDeclarationWithCollidingName(original)) {
                        return setTextRange(factory2.getGeneratedNameForNode(original), node);
                    }
                }
                return node;
            }
            function isNameOfDeclarationWithCollidingName(node) {
                switch (node.parent.kind) {
                    case 208 /* BindingElement */:
                    case 263 /* ClassDeclaration */:
                    case 266 /* EnumDeclaration */:
                    case 260 /* VariableDeclaration */:
                        return node.parent.name === node && resolver.isDeclarationWithCollidingName(node.parent);
                }
                return false;
            }
            function substituteExpression(node) {
                switch (node.kind) {
                    case 80 /* Identifier */:
                        return substituteExpressionIdentifier(node);
                    case 110 /* ThisKeyword */:
                        return substituteThisKeyword(node);
                }
                return node;
            }
            function substituteExpressionIdentifier(node) {
                if (enabledSubstitutions & 2 /* BlockScopedBindings */ && !isInternalName(node)) {
                    const declaration = resolver.getReferencedDeclarationWithCollidingName(node);
                    if (declaration && !(isClassLike(declaration) && isPartOfClassBody(declaration, node))) {
                        return setTextRange(factory2.getGeneratedNameForNode(getNameOfDeclaration(declaration)), node);
                    }
                }
                return node;
            }
            function isPartOfClassBody(declaration, node) {
                let currentNode = getParseTreeNode(node);
                if (!currentNode || currentNode === declaration || currentNode.end <= declaration.pos || currentNode.pos >= declaration.end) {
                    return false;
                }
                const blockScope = getEnclosingBlockScopeContainer(declaration);
                while (currentNode) {
                    if (currentNode === blockScope || currentNode === declaration) {
                        return false;
                    }
                    if (isClassElement(currentNode) && currentNode.parent === declaration) {
                        return true;
                    }
                    currentNode = currentNode.parent;
                }
                return false;
            }
            function substituteThisKeyword(node) {
                if (enabledSubstitutions & 1 /* CapturedThis */ && hierarchyFacts & 16 /* CapturesThis */) {
                    return setTextRange(createCapturedThis(), node);
                }
                return node;
            }
            function getClassMemberPrefix(node, member) {
                return isStatic(member) ? factory2.getInternalName(node) : factory2.createPropertyAccessExpression(factory2.getInternalName(node), "prototype");
            }
            function hasSynthesizedDefaultSuperCall(constructor, hasExtendsClause) {
                if (!constructor || !hasExtendsClause) {
                    return false;
                }
                if (some(constructor.parameters)) {
                    return false;
                }
                const statement = firstOrUndefined(constructor.body.statements);
                if (!statement || !nodeIsSynthesized(statement) || statement.kind !== 244 /* ExpressionStatement */) {
                    return false;
                }
                const statementExpression = statement.expression;
                if (!nodeIsSynthesized(statementExpression) || statementExpression.kind !== 213 /* CallExpression */) {
                    return false;
                }
                const callTarget = statementExpression.expression;
                if (!nodeIsSynthesized(callTarget) || callTarget.kind !== 108 /* SuperKeyword */) {
                    return false;
                }
                const callArgument = singleOrUndefined(statementExpression.arguments);
                if (!callArgument || !nodeIsSynthesized(callArgument) || callArgument.kind !== 230 /* SpreadElement */) {
                    return false;
                }
                const expression = callArgument.expression;
                return isIdentifier(expression) && expression.escapedText === "arguments";
            }
        }
        var init_es2015 = __esm({
            "src/compiler/transformers/es2015.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/es5.ts
        function transformES5(context) {
            const { factory: factory2 } = context;
            const compilerOptions = context.getCompilerOptions();
            let previousOnEmitNode;
            let noSubstitution;
            if (compilerOptions.jsx === 1 /* Preserve */ || compilerOptions.jsx === 3 /* ReactNative */) {
                previousOnEmitNode = context.onEmitNode;
                context.onEmitNode = onEmitNode;
                context.enableEmitNotification(286 /* JsxOpeningElement */);
                context.enableEmitNotification(287 /* JsxClosingElement */);
                context.enableEmitNotification(285 /* JsxSelfClosingElement */);
                noSubstitution = [];
            }
            const previousOnSubstituteNode = context.onSubstituteNode;
            context.onSubstituteNode = onSubstituteNode;
            context.enableSubstitution(211 /* PropertyAccessExpression */);
            context.enableSubstitution(303 /* PropertyAssignment */);
            return chainBundle(context, transformSourceFile);
            function transformSourceFile(node) {
                return node;
            }
            function onEmitNode(hint, node, emitCallback) {
                switch (node.kind) {
                    case 286 /* JsxOpeningElement */:
                    case 287 /* JsxClosingElement */:
                    case 285 /* JsxSelfClosingElement */:
                        const tagName = node.tagName;
                        noSubstitution[getOriginalNodeId(tagName)] = true;
                        break;
                }
                previousOnEmitNode(hint, node, emitCallback);
            }
            function onSubstituteNode(hint, node) {
                if (node.id && noSubstitution && noSubstitution[node.id]) {
                    return previousOnSubstituteNode(hint, node);
                }
                node = previousOnSubstituteNode(hint, node);
                if (isPropertyAccessExpression(node)) {
                    return substitutePropertyAccessExpression(node);
                }
                else if (isPropertyAssignment(node)) {
                    return substitutePropertyAssignment(node);
                }
                return node;
            }
            function substitutePropertyAccessExpression(node) {
                if (isPrivateIdentifier(node.name)) {
                    return node;
                }
                const literalName = trySubstituteReservedName(node.name);
                if (literalName) {
                    return setTextRange(factory2.createElementAccessExpression(node.expression, literalName), node);
                }
                return node;
            }
            function substitutePropertyAssignment(node) {
                const literalName = isIdentifier(node.name) && trySubstituteReservedName(node.name);
                if (literalName) {
                    return factory2.updatePropertyAssignment(node, literalName, node.initializer);
                }
                return node;
            }
            function trySubstituteReservedName(name) {
                const token = identifierToKeywordKind(name);
                if (token !== void 0 && token >= 83 /* FirstReservedWord */ && token <= 118 /* LastReservedWord */) {
                    return setTextRange(factory2.createStringLiteralFromNode(name), name);
                }
                return void 0;
            }
        }
        var init_es5 = __esm({
            "src/compiler/transformers/es5.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/generators.ts
        function getInstructionName(instruction) {
            switch (instruction) {
                case 2 /* Return */:
                    return "return";
                case 3 /* Break */:
                    return "break";
                case 4 /* Yield */:
                    return "yield";
                case 5 /* YieldStar */:
                    return "yield*";
                case 7 /* Endfinally */:
                    return "endfinally";
                default:
                    return void 0;
            }
        }
        function transformGenerators(context) {
            const { factory: factory2, getEmitHelperFactory: emitHelpers, resumeLexicalEnvironment, endLexicalEnvironment, hoistFunctionDeclaration, hoistVariableDeclaration } = context;
            const compilerOptions = context.getCompilerOptions();
            const languageVersion = getEmitScriptTarget(compilerOptions);
            const resolver = context.getEmitResolver();
            const previousOnSubstituteNode = context.onSubstituteNode;
            context.onSubstituteNode = onSubstituteNode;
            let renamedCatchVariables;
            let renamedCatchVariableDeclarations;
            let inGeneratorFunctionBody;
            let inStatementContainingYield;
            let blocks;
            let blockOffsets;
            let blockActions;
            let blockStack;
            let labelOffsets;
            let labelExpressions;
            let nextLabelId = 1;
            let operations;
            let operationArguments;
            let operationLocations;
            let state;
            let blockIndex = 0;
            let labelNumber = 0;
            let labelNumbers;
            let lastOperationWasAbrupt;
            let lastOperationWasCompletion;
            let clauses;
            let statements;
            let exceptionBlockStack;
            let currentExceptionBlock;
            let withBlockStack;
            return chainBundle(context, transformSourceFile);
            function transformSourceFile(node) {
                if (node.isDeclarationFile || (node.transformFlags & 2048 /* ContainsGenerator */) === 0) {
                    return node;
                }
                const visited = visitEachChild(node, visitor, context);
                addEmitHelpers(visited, context.readEmitHelpers());
                return visited;
            }
            function visitor(node) {
                const transformFlags = node.transformFlags;
                if (inStatementContainingYield) {
                    return visitJavaScriptInStatementContainingYield(node);
                }
                else if (inGeneratorFunctionBody) {
                    return visitJavaScriptInGeneratorFunctionBody(node);
                }
                else if (isFunctionLikeDeclaration(node) && node.asteriskToken) {
                    return visitGenerator(node);
                }
                else if (transformFlags & 2048 /* ContainsGenerator */) {
                    return visitEachChild(node, visitor, context);
                }
                else {
                    return node;
                }
            }
            function visitJavaScriptInStatementContainingYield(node) {
                switch (node.kind) {
                    case 246 /* DoStatement */:
                        return visitDoStatement(node);
                    case 247 /* WhileStatement */:
                        return visitWhileStatement(node);
                    case 255 /* SwitchStatement */:
                        return visitSwitchStatement(node);
                    case 256 /* LabeledStatement */:
                        return visitLabeledStatement(node);
                    default:
                        return visitJavaScriptInGeneratorFunctionBody(node);
                }
            }
            function visitJavaScriptInGeneratorFunctionBody(node) {
                switch (node.kind) {
                    case 262 /* FunctionDeclaration */:
                        return visitFunctionDeclaration(node);
                    case 218 /* FunctionExpression */:
                        return visitFunctionExpression(node);
                    case 177 /* GetAccessor */:
                    case 178 /* SetAccessor */:
                        return visitAccessorDeclaration(node);
                    case 243 /* VariableStatement */:
                        return visitVariableStatement(node);
                    case 248 /* ForStatement */:
                        return visitForStatement(node);
                    case 249 /* ForInStatement */:
                        return visitForInStatement(node);
                    case 252 /* BreakStatement */:
                        return visitBreakStatement(node);
                    case 251 /* ContinueStatement */:
                        return visitContinueStatement(node);
                    case 253 /* ReturnStatement */:
                        return visitReturnStatement(node);
                    default:
                        if (node.transformFlags & 1048576 /* ContainsYield */) {
                            return visitJavaScriptContainingYield(node);
                        }
                        else if (node.transformFlags & (2048 /* ContainsGenerator */ | 4194304 /* ContainsHoistedDeclarationOrCompletion */)) {
                            return visitEachChild(node, visitor, context);
                        }
                        else {
                            return node;
                        }
                }
            }
            function visitJavaScriptContainingYield(node) {
                switch (node.kind) {
                    case 226 /* BinaryExpression */:
                        return visitBinaryExpression(node);
                    case 361 /* CommaListExpression */:
                        return visitCommaListExpression(node);
                    case 227 /* ConditionalExpression */:
                        return visitConditionalExpression(node);
                    case 229 /* YieldExpression */:
                        return visitYieldExpression(node);
                    case 209 /* ArrayLiteralExpression */:
                        return visitArrayLiteralExpression(node);
                    case 210 /* ObjectLiteralExpression */:
                        return visitObjectLiteralExpression(node);
                    case 212 /* ElementAccessExpression */:
                        return visitElementAccessExpression(node);
                    case 213 /* CallExpression */:
                        return visitCallExpression(node);
                    case 214 /* NewExpression */:
                        return visitNewExpression(node);
                    default:
                        return visitEachChild(node, visitor, context);
                }
            }
            function visitGenerator(node) {
                switch (node.kind) {
                    case 262 /* FunctionDeclaration */:
                        return visitFunctionDeclaration(node);
                    case 218 /* FunctionExpression */:
                        return visitFunctionExpression(node);
                    default:
                        return Debug.failBadSyntaxKind(node);
                }
            }
            function visitFunctionDeclaration(node) {
                if (node.asteriskToken) {
                    node = setOriginalNode(setTextRange(factory2.createFunctionDeclaration(node.modifiers, 
                    /*asteriskToken*/
                    void 0, node.name, 
                    /*typeParameters*/
                    void 0, visitParameterList(node.parameters, visitor, context), 
                    /*type*/
                    void 0, transformGeneratorFunctionBody(node.body)), 
                    /*location*/
                    node), node);
                }
                else {
                    const savedInGeneratorFunctionBody = inGeneratorFunctionBody;
                    const savedInStatementContainingYield = inStatementContainingYield;
                    inGeneratorFunctionBody = false;
                    inStatementContainingYield = false;
                    node = visitEachChild(node, visitor, context);
                    inGeneratorFunctionBody = savedInGeneratorFunctionBody;
                    inStatementContainingYield = savedInStatementContainingYield;
                }
                if (inGeneratorFunctionBody) {
                    hoistFunctionDeclaration(node);
                    return void 0;
                }
                else {
                    return node;
                }
            }
            function visitFunctionExpression(node) {
                if (node.asteriskToken) {
                    node = setOriginalNode(setTextRange(factory2.createFunctionExpression(
                    /*modifiers*/
                    void 0, 
                    /*asteriskToken*/
                    void 0, node.name, 
                    /*typeParameters*/
                    void 0, visitParameterList(node.parameters, visitor, context), 
                    /*type*/
                    void 0, transformGeneratorFunctionBody(node.body)), 
                    /*location*/
                    node), node);
                }
                else {
                    const savedInGeneratorFunctionBody = inGeneratorFunctionBody;
                    const savedInStatementContainingYield = inStatementContainingYield;
                    inGeneratorFunctionBody = false;
                    inStatementContainingYield = false;
                    node = visitEachChild(node, visitor, context);
                    inGeneratorFunctionBody = savedInGeneratorFunctionBody;
                    inStatementContainingYield = savedInStatementContainingYield;
                }
                return node;
            }
            function visitAccessorDeclaration(node) {
                const savedInGeneratorFunctionBody = inGeneratorFunctionBody;
                const savedInStatementContainingYield = inStatementContainingYield;
                inGeneratorFunctionBody = false;
                inStatementContainingYield = false;
                node = visitEachChild(node, visitor, context);
                inGeneratorFunctionBody = savedInGeneratorFunctionBody;
                inStatementContainingYield = savedInStatementContainingYield;
                return node;
            }
            function transformGeneratorFunctionBody(body) {
                const statements2 = [];
                const savedInGeneratorFunctionBody = inGeneratorFunctionBody;
                const savedInStatementContainingYield = inStatementContainingYield;
                const savedBlocks = blocks;
                const savedBlockOffsets = blockOffsets;
                const savedBlockActions = blockActions;
                const savedBlockStack = blockStack;
                const savedLabelOffsets = labelOffsets;
                const savedLabelExpressions = labelExpressions;
                const savedNextLabelId = nextLabelId;
                const savedOperations = operations;
                const savedOperationArguments = operationArguments;
                const savedOperationLocations = operationLocations;
                const savedState = state;
                inGeneratorFunctionBody = true;
                inStatementContainingYield = false;
                blocks = void 0;
                blockOffsets = void 0;
                blockActions = void 0;
                blockStack = void 0;
                labelOffsets = void 0;
                labelExpressions = void 0;
                nextLabelId = 1;
                operations = void 0;
                operationArguments = void 0;
                operationLocations = void 0;
                state = factory2.createTempVariable(
                /*recordTempVariable*/
                void 0);
                resumeLexicalEnvironment();
                const statementOffset = factory2.copyPrologue(body.statements, statements2, 
                /*ensureUseStrict*/
                false, visitor);
                transformAndEmitStatements(body.statements, statementOffset);
                const buildResult = build2();
                insertStatementsAfterStandardPrologue(statements2, endLexicalEnvironment());
                statements2.push(factory2.createReturnStatement(buildResult));
                inGeneratorFunctionBody = savedInGeneratorFunctionBody;
                inStatementContainingYield = savedInStatementContainingYield;
                blocks = savedBlocks;
                blockOffsets = savedBlockOffsets;
                blockActions = savedBlockActions;
                blockStack = savedBlockStack;
                labelOffsets = savedLabelOffsets;
                labelExpressions = savedLabelExpressions;
                nextLabelId = savedNextLabelId;
                operations = savedOperations;
                operationArguments = savedOperationArguments;
                operationLocations = savedOperationLocations;
                state = savedState;
                return setTextRange(factory2.createBlock(statements2, body.multiLine), body);
            }
            function visitVariableStatement(node) {
                if (node.transformFlags & 1048576 /* ContainsYield */) {
                    transformAndEmitVariableDeclarationList(node.declarationList);
                    return void 0;
                }
                else {
                    if (getEmitFlags(node) & 2097152 /* CustomPrologue */) {
                        return node;
                    }
                    for (const variable of node.declarationList.declarations) {
                        hoistVariableDeclaration(variable.name);
                    }
                    const variables = getInitializedVariables(node.declarationList);
                    if (variables.length === 0) {
                        return void 0;
                    }
                    return setSourceMapRange(factory2.createExpressionStatement(factory2.inlineExpressions(map(variables, transformInitializedVariable))), node);
                }
            }
            function visitBinaryExpression(node) {
                const assoc = getExpressionAssociativity(node);
                switch (assoc) {
                    case 0 /* Left */:
                        return visitLeftAssociativeBinaryExpression(node);
                    case 1 /* Right */:
                        return visitRightAssociativeBinaryExpression(node);
                    default:
                        return Debug.assertNever(assoc);
                }
            }
            function visitRightAssociativeBinaryExpression(node) {
                const { left, right } = node;
                if (containsYield(right)) {
                    let target;
                    switch (left.kind) {
                        case 211 /* PropertyAccessExpression */:
                            target = factory2.updatePropertyAccessExpression(left, cacheExpression(Debug.checkDefined(visitNode(left.expression, visitor, isLeftHandSideExpression))), left.name);
                            break;
                        case 212 /* ElementAccessExpression */:
                            target = factory2.updateElementAccessExpression(left, cacheExpression(Debug.checkDefined(visitNode(left.expression, visitor, isLeftHandSideExpression))), cacheExpression(Debug.checkDefined(visitNode(left.argumentExpression, visitor, isExpression))));
                            break;
                        default:
                            target = Debug.checkDefined(visitNode(left, visitor, isExpression));
                            break;
                    }
                    const operator = node.operatorToken.kind;
                    if (isCompoundAssignment(operator)) {
                        return setTextRange(factory2.createAssignment(target, setTextRange(factory2.createBinaryExpression(cacheExpression(target), getNonAssignmentOperatorForCompoundAssignment(operator), Debug.checkDefined(visitNode(right, visitor, isExpression))), node)), node);
                    }
                    else {
                        return factory2.updateBinaryExpression(node, target, node.operatorToken, Debug.checkDefined(visitNode(right, visitor, isExpression)));
                    }
                }
                return visitEachChild(node, visitor, context);
            }
            function visitLeftAssociativeBinaryExpression(node) {
                if (containsYield(node.right)) {
                    if (isLogicalOperator(node.operatorToken.kind)) {
                        return visitLogicalBinaryExpression(node);
                    }
                    else if (node.operatorToken.kind === 28 /* CommaToken */) {
                        return visitCommaExpression(node);
                    }
                    return factory2.updateBinaryExpression(node, cacheExpression(Debug.checkDefined(visitNode(node.left, visitor, isExpression))), node.operatorToken, Debug.checkDefined(visitNode(node.right, visitor, isExpression)));
                }
                return visitEachChild(node, visitor, context);
            }
            function visitCommaExpression(node) {
                let pendingExpressions = [];
                visit(node.left);
                visit(node.right);
                return factory2.inlineExpressions(pendingExpressions);
                function visit(node2) {
                    if (isBinaryExpression(node2) && node2.operatorToken.kind === 28 /* CommaToken */) {
                        visit(node2.left);
                        visit(node2.right);
                    }
                    else {
                        if (containsYield(node2) && pendingExpressions.length > 0) {
                            emitWorker(1 /* Statement */, [factory2.createExpressionStatement(factory2.inlineExpressions(pendingExpressions))]);
                            pendingExpressions = [];
                        }
                        pendingExpressions.push(Debug.checkDefined(visitNode(node2, visitor, isExpression)));
                    }
                }
            }
            function visitCommaListExpression(node) {
                let pendingExpressions = [];
                for (const elem of node.elements) {
                    if (isBinaryExpression(elem) && elem.operatorToken.kind === 28 /* CommaToken */) {
                        pendingExpressions.push(visitCommaExpression(elem));
                    }
                    else {
                        if (containsYield(elem) && pendingExpressions.length > 0) {
                            emitWorker(1 /* Statement */, [factory2.createExpressionStatement(factory2.inlineExpressions(pendingExpressions))]);
                            pendingExpressions = [];
                        }
                        pendingExpressions.push(Debug.checkDefined(visitNode(elem, visitor, isExpression)));
                    }
                }
                return factory2.inlineExpressions(pendingExpressions);
            }
            function visitLogicalBinaryExpression(node) {
                const resultLabel = defineLabel();
                const resultLocal = declareLocal();
                emitAssignment(resultLocal, Debug.checkDefined(visitNode(node.left, visitor, isExpression)), 
                /*location*/
                node.left);
                if (node.operatorToken.kind === 56 /* AmpersandAmpersandToken */) {
                    emitBreakWhenFalse(resultLabel, resultLocal, 
                    /*location*/
                    node.left);
                }
                else {
                    emitBreakWhenTrue(resultLabel, resultLocal, 
                    /*location*/
                    node.left);
                }
                emitAssignment(resultLocal, Debug.checkDefined(visitNode(node.right, visitor, isExpression)), 
                /*location*/
                node.right);
                markLabel(resultLabel);
                return resultLocal;
            }
            function visitConditionalExpression(node) {
                if (containsYield(node.whenTrue) || containsYield(node.whenFalse)) {
                    const whenFalseLabel = defineLabel();
                    const resultLabel = defineLabel();
                    const resultLocal = declareLocal();
                    emitBreakWhenFalse(whenFalseLabel, Debug.checkDefined(visitNode(node.condition, visitor, isExpression)), 
                    /*location*/
                    node.condition);
                    emitAssignment(resultLocal, Debug.checkDefined(visitNode(node.whenTrue, visitor, isExpression)), 
                    /*location*/
                    node.whenTrue);
                    emitBreak(resultLabel);
                    markLabel(whenFalseLabel);
                    emitAssignment(resultLocal, Debug.checkDefined(visitNode(node.whenFalse, visitor, isExpression)), 
                    /*location*/
                    node.whenFalse);
                    markLabel(resultLabel);
                    return resultLocal;
                }
                return visitEachChild(node, visitor, context);
            }
            function visitYieldExpression(node) {
                const resumeLabel = defineLabel();
                const expression = visitNode(node.expression, visitor, isExpression);
                if (node.asteriskToken) {
                    const iterator = (getEmitFlags(node.expression) & 8388608 /* Iterator */) === 0 ? setTextRange(emitHelpers().createValuesHelper(expression), node) : expression;
                    emitYieldStar(iterator, 
                    /*location*/
                    node);
                }
                else {
                    emitYield(expression, 
                    /*location*/
                    node);
                }
                markLabel(resumeLabel);
                return createGeneratorResume(
                /*location*/
                node);
            }
            function visitArrayLiteralExpression(node) {
                return visitElements(node.elements, 
                /*leadingElement*/
                void 0, 
                /*location*/
                void 0, node.multiLine);
            }
            function visitElements(elements, leadingElement, location, multiLine) {
                const numInitialElements = countInitialNodesWithoutYield(elements);
                let temp;
                if (numInitialElements > 0) {
                    temp = declareLocal();
                    const initialElements = visitNodes2(elements, visitor, isExpression, 0, numInitialElements);
                    emitAssignment(temp, factory2.createArrayLiteralExpression(leadingElement ? [leadingElement, ...initialElements] : initialElements));
                    leadingElement = void 0;
                }
                const expressions = reduceLeft(elements, reduceElement, [], numInitialElements);
                return temp ? factory2.createArrayConcatCall(temp, [factory2.createArrayLiteralExpression(expressions, multiLine)]) : setTextRange(factory2.createArrayLiteralExpression(leadingElement ? [leadingElement, ...expressions] : expressions, multiLine), location);
                function reduceElement(expressions2, element) {
                    if (containsYield(element) && expressions2.length > 0) {
                        const hasAssignedTemp = temp !== void 0;
                        if (!temp) {
                            temp = declareLocal();
                        }
                        emitAssignment(temp, hasAssignedTemp ? factory2.createArrayConcatCall(temp, [factory2.createArrayLiteralExpression(expressions2, multiLine)]) : factory2.createArrayLiteralExpression(leadingElement ? [leadingElement, ...expressions2] : expressions2, multiLine));
                        leadingElement = void 0;
                        expressions2 = [];
                    }
                    expressions2.push(Debug.checkDefined(visitNode(element, visitor, isExpression)));
                    return expressions2;
                }
            }
            function visitObjectLiteralExpression(node) {
                const properties = node.properties;
                const multiLine = node.multiLine;
                const numInitialProperties = countInitialNodesWithoutYield(properties);
                const temp = declareLocal();
                emitAssignment(temp, factory2.createObjectLiteralExpression(visitNodes2(properties, visitor, isObjectLiteralElementLike, 0, numInitialProperties), multiLine));
                const expressions = reduceLeft(properties, reduceProperty, [], numInitialProperties);
                expressions.push(multiLine ? startOnNewLine(setParent(setTextRange(factory2.cloneNode(temp), temp), temp.parent)) : temp);
                return factory2.inlineExpressions(expressions);
                function reduceProperty(expressions2, property) {
                    if (containsYield(property) && expressions2.length > 0) {
                        emitStatement(factory2.createExpressionStatement(factory2.inlineExpressions(expressions2)));
                        expressions2 = [];
                    }
                    const expression = createExpressionForObjectLiteralElementLike(factory2, node, property, temp);
                    const visited = visitNode(expression, visitor, isExpression);
                    if (visited) {
                        if (multiLine) {
                            startOnNewLine(visited);
                        }
                        expressions2.push(visited);
                    }
                    return expressions2;
                }
            }
            function visitElementAccessExpression(node) {
                if (containsYield(node.argumentExpression)) {
                    return factory2.updateElementAccessExpression(node, cacheExpression(Debug.checkDefined(visitNode(node.expression, visitor, isLeftHandSideExpression))), Debug.checkDefined(visitNode(node.argumentExpression, visitor, isExpression)));
                }
                return visitEachChild(node, visitor, context);
            }
            function visitCallExpression(node) {
                if (!isImportCall(node) && forEach(node.arguments, containsYield)) {
                    const { target, thisArg } = factory2.createCallBinding(node.expression, hoistVariableDeclaration, languageVersion, 
                    /*cacheIdentifiers*/
                    true);
                    return setOriginalNode(setTextRange(factory2.createFunctionApplyCall(cacheExpression(Debug.checkDefined(visitNode(target, visitor, isLeftHandSideExpression))), thisArg, visitElements(node.arguments)), node), node);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitNewExpression(node) {
                if (forEach(node.arguments, containsYield)) {
                    const { target, thisArg } = factory2.createCallBinding(factory2.createPropertyAccessExpression(node.expression, "bind"), hoistVariableDeclaration);
                    return setOriginalNode(setTextRange(factory2.createNewExpression(factory2.createFunctionApplyCall(cacheExpression(Debug.checkDefined(visitNode(target, visitor, isExpression))), thisArg, visitElements(node.arguments, 
                    /*leadingElement*/
                    factory2.createVoidZero())), 
                    /*typeArguments*/
                    void 0, []), node), node);
                }
                return visitEachChild(node, visitor, context);
            }
            function transformAndEmitStatements(statements2, start = 0) {
                const numStatements = statements2.length;
                for (let i = start; i < numStatements; i++) {
                    transformAndEmitStatement(statements2[i]);
                }
            }
            function transformAndEmitEmbeddedStatement(node) {
                if (isBlock(node)) {
                    transformAndEmitStatements(node.statements);
                }
                else {
                    transformAndEmitStatement(node);
                }
            }
            function transformAndEmitStatement(node) {
                const savedInStatementContainingYield = inStatementContainingYield;
                if (!inStatementContainingYield) {
                    inStatementContainingYield = containsYield(node);
                }
                transformAndEmitStatementWorker(node);
                inStatementContainingYield = savedInStatementContainingYield;
            }
            function transformAndEmitStatementWorker(node) {
                switch (node.kind) {
                    case 241 /* Block */:
                        return transformAndEmitBlock(node);
                    case 244 /* ExpressionStatement */:
                        return transformAndEmitExpressionStatement(node);
                    case 245 /* IfStatement */:
                        return transformAndEmitIfStatement(node);
                    case 246 /* DoStatement */:
                        return transformAndEmitDoStatement(node);
                    case 247 /* WhileStatement */:
                        return transformAndEmitWhileStatement(node);
                    case 248 /* ForStatement */:
                        return transformAndEmitForStatement(node);
                    case 249 /* ForInStatement */:
                        return transformAndEmitForInStatement(node);
                    case 251 /* ContinueStatement */:
                        return transformAndEmitContinueStatement(node);
                    case 252 /* BreakStatement */:
                        return transformAndEmitBreakStatement(node);
                    case 253 /* ReturnStatement */:
                        return transformAndEmitReturnStatement(node);
                    case 254 /* WithStatement */:
                        return transformAndEmitWithStatement(node);
                    case 255 /* SwitchStatement */:
                        return transformAndEmitSwitchStatement(node);
                    case 256 /* LabeledStatement */:
                        return transformAndEmitLabeledStatement(node);
                    case 257 /* ThrowStatement */:
                        return transformAndEmitThrowStatement(node);
                    case 258 /* TryStatement */:
                        return transformAndEmitTryStatement(node);
                    default:
                        return emitStatement(visitNode(node, visitor, isStatement));
                }
            }
            function transformAndEmitBlock(node) {
                if (containsYield(node)) {
                    transformAndEmitStatements(node.statements);
                }
                else {
                    emitStatement(visitNode(node, visitor, isStatement));
                }
            }
            function transformAndEmitExpressionStatement(node) {
                emitStatement(visitNode(node, visitor, isStatement));
            }
            function transformAndEmitVariableDeclarationList(node) {
                for (const variable of node.declarations) {
                    const name = factory2.cloneNode(variable.name);
                    setCommentRange(name, variable.name);
                    hoistVariableDeclaration(name);
                }
                const variables = getInitializedVariables(node);
                const numVariables = variables.length;
                let variablesWritten = 0;
                let pendingExpressions = [];
                while (variablesWritten < numVariables) {
                    for (let i = variablesWritten; i < numVariables; i++) {
                        const variable = variables[i];
                        if (containsYield(variable.initializer) && pendingExpressions.length > 0) {
                            break;
                        }
                        pendingExpressions.push(transformInitializedVariable(variable));
                    }
                    if (pendingExpressions.length) {
                        emitStatement(factory2.createExpressionStatement(factory2.inlineExpressions(pendingExpressions)));
                        variablesWritten += pendingExpressions.length;
                        pendingExpressions = [];
                    }
                }
                return void 0;
            }
            function transformInitializedVariable(node) {
                return setSourceMapRange(factory2.createAssignment(setSourceMapRange(factory2.cloneNode(node.name), node.name), Debug.checkDefined(visitNode(node.initializer, visitor, isExpression))), node);
            }
            function transformAndEmitIfStatement(node) {
                if (containsYield(node)) {
                    if (containsYield(node.thenStatement) || containsYield(node.elseStatement)) {
                        const endLabel = defineLabel();
                        const elseLabel = node.elseStatement ? defineLabel() : void 0;
                        emitBreakWhenFalse(node.elseStatement ? elseLabel : endLabel, Debug.checkDefined(visitNode(node.expression, visitor, isExpression)), 
                        /*location*/
                        node.expression);
                        transformAndEmitEmbeddedStatement(node.thenStatement);
                        if (node.elseStatement) {
                            emitBreak(endLabel);
                            markLabel(elseLabel);
                            transformAndEmitEmbeddedStatement(node.elseStatement);
                        }
                        markLabel(endLabel);
                    }
                    else {
                        emitStatement(visitNode(node, visitor, isStatement));
                    }
                }
                else {
                    emitStatement(visitNode(node, visitor, isStatement));
                }
            }
            function transformAndEmitDoStatement(node) {
                if (containsYield(node)) {
                    const conditionLabel = defineLabel();
                    const loopLabel = defineLabel();
                    beginLoopBlock(
                    /*continueLabel*/
                    conditionLabel);
                    markLabel(loopLabel);
                    transformAndEmitEmbeddedStatement(node.statement);
                    markLabel(conditionLabel);
                    emitBreakWhenTrue(loopLabel, Debug.checkDefined(visitNode(node.expression, visitor, isExpression)));
                    endLoopBlock();
                }
                else {
                    emitStatement(visitNode(node, visitor, isStatement));
                }
            }
            function visitDoStatement(node) {
                if (inStatementContainingYield) {
                    beginScriptLoopBlock();
                    node = visitEachChild(node, visitor, context);
                    endLoopBlock();
                    return node;
                }
                else {
                    return visitEachChild(node, visitor, context);
                }
            }
            function transformAndEmitWhileStatement(node) {
                if (containsYield(node)) {
                    const loopLabel = defineLabel();
                    const endLabel = beginLoopBlock(loopLabel);
                    markLabel(loopLabel);
                    emitBreakWhenFalse(endLabel, Debug.checkDefined(visitNode(node.expression, visitor, isExpression)));
                    transformAndEmitEmbeddedStatement(node.statement);
                    emitBreak(loopLabel);
                    endLoopBlock();
                }
                else {
                    emitStatement(visitNode(node, visitor, isStatement));
                }
            }
            function visitWhileStatement(node) {
                if (inStatementContainingYield) {
                    beginScriptLoopBlock();
                    node = visitEachChild(node, visitor, context);
                    endLoopBlock();
                    return node;
                }
                else {
                    return visitEachChild(node, visitor, context);
                }
            }
            function transformAndEmitForStatement(node) {
                if (containsYield(node)) {
                    const conditionLabel = defineLabel();
                    const incrementLabel = defineLabel();
                    const endLabel = beginLoopBlock(incrementLabel);
                    if (node.initializer) {
                        const initializer = node.initializer;
                        if (isVariableDeclarationList(initializer)) {
                            transformAndEmitVariableDeclarationList(initializer);
                        }
                        else {
                            emitStatement(setTextRange(factory2.createExpressionStatement(Debug.checkDefined(visitNode(initializer, visitor, isExpression))), initializer));
                        }
                    }
                    markLabel(conditionLabel);
                    if (node.condition) {
                        emitBreakWhenFalse(endLabel, Debug.checkDefined(visitNode(node.condition, visitor, isExpression)));
                    }
                    transformAndEmitEmbeddedStatement(node.statement);
                    markLabel(incrementLabel);
                    if (node.incrementor) {
                        emitStatement(setTextRange(factory2.createExpressionStatement(Debug.checkDefined(visitNode(node.incrementor, visitor, isExpression))), node.incrementor));
                    }
                    emitBreak(conditionLabel);
                    endLoopBlock();
                }
                else {
                    emitStatement(visitNode(node, visitor, isStatement));
                }
            }
            function visitForStatement(node) {
                if (inStatementContainingYield) {
                    beginScriptLoopBlock();
                }
                const initializer = node.initializer;
                if (initializer && isVariableDeclarationList(initializer)) {
                    for (const variable of initializer.declarations) {
                        hoistVariableDeclaration(variable.name);
                    }
                    const variables = getInitializedVariables(initializer);
                    node = factory2.updateForStatement(node, variables.length > 0 ? factory2.inlineExpressions(map(variables, transformInitializedVariable)) : void 0, visitNode(node.condition, visitor, isExpression), visitNode(node.incrementor, visitor, isExpression), visitIterationBody(node.statement, visitor, context));
                }
                else {
                    node = visitEachChild(node, visitor, context);
                }
                if (inStatementContainingYield) {
                    endLoopBlock();
                }
                return node;
            }
            function transformAndEmitForInStatement(node) {
                if (containsYield(node)) {
                    const obj = declareLocal();
                    const keysArray = declareLocal();
                    const key = declareLocal();
                    const keysIndex = factory2.createLoopVariable();
                    const initializer = node.initializer;
                    hoistVariableDeclaration(keysIndex);
                    emitAssignment(obj, Debug.checkDefined(visitNode(node.expression, visitor, isExpression)));
                    emitAssignment(keysArray, factory2.createArrayLiteralExpression());
                    emitStatement(factory2.createForInStatement(key, obj, factory2.createExpressionStatement(factory2.createCallExpression(factory2.createPropertyAccessExpression(keysArray, "push"), 
                    /*typeArguments*/
                    void 0, [key]))));
                    emitAssignment(keysIndex, factory2.createNumericLiteral(0));
                    const conditionLabel = defineLabel();
                    const incrementLabel = defineLabel();
                    const endLoopLabel = beginLoopBlock(incrementLabel);
                    markLabel(conditionLabel);
                    emitBreakWhenFalse(endLoopLabel, factory2.createLessThan(keysIndex, factory2.createPropertyAccessExpression(keysArray, "length")));
                    emitAssignment(key, factory2.createElementAccessExpression(keysArray, keysIndex));
                    emitBreakWhenFalse(incrementLabel, factory2.createBinaryExpression(key, 103 /* InKeyword */, obj));
                    let variable;
                    if (isVariableDeclarationList(initializer)) {
                        for (const variable2 of initializer.declarations) {
                            hoistVariableDeclaration(variable2.name);
                        }
                        variable = factory2.cloneNode(initializer.declarations[0].name);
                    }
                    else {
                        variable = Debug.checkDefined(visitNode(initializer, visitor, isExpression));
                        Debug.assert(isLeftHandSideExpression(variable));
                    }
                    emitAssignment(variable, key);
                    transformAndEmitEmbeddedStatement(node.statement);
                    markLabel(incrementLabel);
                    emitStatement(factory2.createExpressionStatement(factory2.createPostfixIncrement(keysIndex)));
                    emitBreak(conditionLabel);
                    endLoopBlock();
                }
                else {
                    emitStatement(visitNode(node, visitor, isStatement));
                }
            }
            function visitForInStatement(node) {
                if (inStatementContainingYield) {
                    beginScriptLoopBlock();
                }
                const initializer = node.initializer;
                if (isVariableDeclarationList(initializer)) {
                    for (const variable of initializer.declarations) {
                        hoistVariableDeclaration(variable.name);
                    }
                    node = factory2.updateForInStatement(node, initializer.declarations[0].name, Debug.checkDefined(visitNode(node.expression, visitor, isExpression)), Debug.checkDefined(visitNode(node.statement, visitor, isStatement, factory2.liftToBlock)));
                }
                else {
                    node = visitEachChild(node, visitor, context);
                }
                if (inStatementContainingYield) {
                    endLoopBlock();
                }
                return node;
            }
            function transformAndEmitContinueStatement(node) {
                const label = findContinueTarget(node.label ? idText(node.label) : void 0);
                if (label > 0) {
                    emitBreak(label, 
                    /*location*/
                    node);
                }
                else {
                    emitStatement(node);
                }
            }
            function visitContinueStatement(node) {
                if (inStatementContainingYield) {
                    const label = findContinueTarget(node.label && idText(node.label));
                    if (label > 0) {
                        return createInlineBreak(label, 
                        /*location*/
                        node);
                    }
                }
                return visitEachChild(node, visitor, context);
            }
            function transformAndEmitBreakStatement(node) {
                const label = findBreakTarget(node.label ? idText(node.label) : void 0);
                if (label > 0) {
                    emitBreak(label, 
                    /*location*/
                    node);
                }
                else {
                    emitStatement(node);
                }
            }
            function visitBreakStatement(node) {
                if (inStatementContainingYield) {
                    const label = findBreakTarget(node.label && idText(node.label));
                    if (label > 0) {
                        return createInlineBreak(label, 
                        /*location*/
                        node);
                    }
                }
                return visitEachChild(node, visitor, context);
            }
            function transformAndEmitReturnStatement(node) {
                emitReturn(visitNode(node.expression, visitor, isExpression), 
                /*location*/
                node);
            }
            function visitReturnStatement(node) {
                return createInlineReturn(visitNode(node.expression, visitor, isExpression), 
                /*location*/
                node);
            }
            function transformAndEmitWithStatement(node) {
                if (containsYield(node)) {
                    beginWithBlock(cacheExpression(Debug.checkDefined(visitNode(node.expression, visitor, isExpression))));
                    transformAndEmitEmbeddedStatement(node.statement);
                    endWithBlock();
                }
                else {
                    emitStatement(visitNode(node, visitor, isStatement));
                }
            }
            function transformAndEmitSwitchStatement(node) {
                if (containsYield(node.caseBlock)) {
                    const caseBlock = node.caseBlock;
                    const numClauses = caseBlock.clauses.length;
                    const endLabel = beginSwitchBlock();
                    const expression = cacheExpression(Debug.checkDefined(visitNode(node.expression, visitor, isExpression)));
                    const clauseLabels = [];
                    let defaultClauseIndex = -1;
                    for (let i = 0; i < numClauses; i++) {
                        const clause = caseBlock.clauses[i];
                        clauseLabels.push(defineLabel());
                        if (clause.kind === 297 /* DefaultClause */ && defaultClauseIndex === -1) {
                            defaultClauseIndex = i;
                        }
                    }
                    let clausesWritten = 0;
                    let pendingClauses = [];
                    while (clausesWritten < numClauses) {
                        let defaultClausesSkipped = 0;
                        for (let i = clausesWritten; i < numClauses; i++) {
                            const clause = caseBlock.clauses[i];
                            if (clause.kind === 296 /* CaseClause */) {
                                if (containsYield(clause.expression) && pendingClauses.length > 0) {
                                    break;
                                }
                                pendingClauses.push(factory2.createCaseClause(Debug.checkDefined(visitNode(clause.expression, visitor, isExpression)), [
                                    createInlineBreak(clauseLabels[i], 
                                    /*location*/
                                    clause.expression)
                                ]));
                            }
                            else {
                                defaultClausesSkipped++;
                            }
                        }
                        if (pendingClauses.length) {
                            emitStatement(factory2.createSwitchStatement(expression, factory2.createCaseBlock(pendingClauses)));
                            clausesWritten += pendingClauses.length;
                            pendingClauses = [];
                        }
                        if (defaultClausesSkipped > 0) {
                            clausesWritten += defaultClausesSkipped;
                            defaultClausesSkipped = 0;
                        }
                    }
                    if (defaultClauseIndex >= 0) {
                        emitBreak(clauseLabels[defaultClauseIndex]);
                    }
                    else {
                        emitBreak(endLabel);
                    }
                    for (let i = 0; i < numClauses; i++) {
                        markLabel(clauseLabels[i]);
                        transformAndEmitStatements(caseBlock.clauses[i].statements);
                    }
                    endSwitchBlock();
                }
                else {
                    emitStatement(visitNode(node, visitor, isStatement));
                }
            }
            function visitSwitchStatement(node) {
                if (inStatementContainingYield) {
                    beginScriptSwitchBlock();
                }
                node = visitEachChild(node, visitor, context);
                if (inStatementContainingYield) {
                    endSwitchBlock();
                }
                return node;
            }
            function transformAndEmitLabeledStatement(node) {
                if (containsYield(node)) {
                    beginLabeledBlock(idText(node.label));
                    transformAndEmitEmbeddedStatement(node.statement);
                    endLabeledBlock();
                }
                else {
                    emitStatement(visitNode(node, visitor, isStatement));
                }
            }
            function visitLabeledStatement(node) {
                if (inStatementContainingYield) {
                    beginScriptLabeledBlock(idText(node.label));
                }
                node = visitEachChild(node, visitor, context);
                if (inStatementContainingYield) {
                    endLabeledBlock();
                }
                return node;
            }
            function transformAndEmitThrowStatement(node) {
                emitThrow(Debug.checkDefined(visitNode(node.expression ?? factory2.createVoidZero(), visitor, isExpression)), 
                /*location*/
                node);
            }
            function transformAndEmitTryStatement(node) {
                if (containsYield(node)) {
                    beginExceptionBlock();
                    transformAndEmitEmbeddedStatement(node.tryBlock);
                    if (node.catchClause) {
                        beginCatchBlock(node.catchClause.variableDeclaration);
                        transformAndEmitEmbeddedStatement(node.catchClause.block);
                    }
                    if (node.finallyBlock) {
                        beginFinallyBlock();
                        transformAndEmitEmbeddedStatement(node.finallyBlock);
                    }
                    endExceptionBlock();
                }
                else {
                    emitStatement(visitEachChild(node, visitor, context));
                }
            }
            function containsYield(node) {
                return !!node && (node.transformFlags & 1048576 /* ContainsYield */) !== 0;
            }
            function countInitialNodesWithoutYield(nodes) {
                const numNodes = nodes.length;
                for (let i = 0; i < numNodes; i++) {
                    if (containsYield(nodes[i])) {
                        return i;
                    }
                }
                return -1;
            }
            function onSubstituteNode(hint, node) {
                node = previousOnSubstituteNode(hint, node);
                if (hint === 1 /* Expression */) {
                    return substituteExpression(node);
                }
                return node;
            }
            function substituteExpression(node) {
                if (isIdentifier(node)) {
                    return substituteExpressionIdentifier(node);
                }
                return node;
            }
            function substituteExpressionIdentifier(node) {
                if (!isGeneratedIdentifier(node) && renamedCatchVariables && renamedCatchVariables.has(idText(node))) {
                    const original = getOriginalNode(node);
                    if (isIdentifier(original) && original.parent) {
                        const declaration = resolver.getReferencedValueDeclaration(original);
                        if (declaration) {
                            const name = renamedCatchVariableDeclarations[getOriginalNodeId(declaration)];
                            if (name) {
                                const clone2 = setParent(setTextRange(factory2.cloneNode(name), name), name.parent);
                                setSourceMapRange(clone2, node);
                                setCommentRange(clone2, node);
                                return clone2;
                            }
                        }
                    }
                }
                return node;
            }
            function cacheExpression(node) {
                if (isGeneratedIdentifier(node) || getEmitFlags(node) & 8192 /* HelperName */) {
                    return node;
                }
                const temp = factory2.createTempVariable(hoistVariableDeclaration);
                emitAssignment(temp, node, 
                /*location*/
                node);
                return temp;
            }
            function declareLocal(name) {
                const temp = name ? factory2.createUniqueName(name) : factory2.createTempVariable(
                /*recordTempVariable*/
                void 0);
                hoistVariableDeclaration(temp);
                return temp;
            }
            function defineLabel() {
                if (!labelOffsets) {
                    labelOffsets = [];
                }
                const label = nextLabelId;
                nextLabelId++;
                labelOffsets[label] = -1;
                return label;
            }
            function markLabel(label) {
                Debug.assert(labelOffsets !== void 0, "No labels were defined.");
                labelOffsets[label] = operations ? operations.length : 0;
            }
            function beginBlock(block) {
                if (!blocks) {
                    blocks = [];
                    blockActions = [];
                    blockOffsets = [];
                    blockStack = [];
                }
                const index = blockActions.length;
                blockActions[index] = 0 /* Open */;
                blockOffsets[index] = operations ? operations.length : 0;
                blocks[index] = block;
                blockStack.push(block);
                return index;
            }
            function endBlock() {
                const block = peekBlock();
                if (block === void 0)
                    return Debug.fail("beginBlock was never called.");
                const index = blockActions.length;
                blockActions[index] = 1 /* Close */;
                blockOffsets[index] = operations ? operations.length : 0;
                blocks[index] = block;
                blockStack.pop();
                return block;
            }
            function peekBlock() {
                return lastOrUndefined(blockStack);
            }
            function peekBlockKind() {
                const block = peekBlock();
                return block && block.kind;
            }
            function beginWithBlock(expression) {
                const startLabel = defineLabel();
                const endLabel = defineLabel();
                markLabel(startLabel);
                beginBlock({
                    kind: 1 /* With */,
                    expression,
                    startLabel,
                    endLabel
                });
            }
            function endWithBlock() {
                Debug.assert(peekBlockKind() === 1 /* With */);
                const block = endBlock();
                markLabel(block.endLabel);
            }
            function beginExceptionBlock() {
                const startLabel = defineLabel();
                const endLabel = defineLabel();
                markLabel(startLabel);
                beginBlock({
                    kind: 0 /* Exception */,
                    state: 0 /* Try */,
                    startLabel,
                    endLabel
                });
                emitNop();
                return endLabel;
            }
            function beginCatchBlock(variable) {
                Debug.assert(peekBlockKind() === 0 /* Exception */);
                let name;
                if (isGeneratedIdentifier(variable.name)) {
                    name = variable.name;
                    hoistVariableDeclaration(variable.name);
                }
                else {
                    const text = idText(variable.name);
                    name = declareLocal(text);
                    if (!renamedCatchVariables) {
                        renamedCatchVariables = /* @__PURE__ */ new Map();
                        renamedCatchVariableDeclarations = [];
                        context.enableSubstitution(80 /* Identifier */);
                    }
                    renamedCatchVariables.set(text, true);
                    renamedCatchVariableDeclarations[getOriginalNodeId(variable)] = name;
                }
                const exception = peekBlock();
                Debug.assert(exception.state < 1 /* Catch */);
                const endLabel = exception.endLabel;
                emitBreak(endLabel);
                const catchLabel = defineLabel();
                markLabel(catchLabel);
                exception.state = 1 /* Catch */;
                exception.catchVariable = name;
                exception.catchLabel = catchLabel;
                emitAssignment(name, factory2.createCallExpression(factory2.createPropertyAccessExpression(state, "sent"), 
                /*typeArguments*/
                void 0, []));
                emitNop();
            }
            function beginFinallyBlock() {
                Debug.assert(peekBlockKind() === 0 /* Exception */);
                const exception = peekBlock();
                Debug.assert(exception.state < 2 /* Finally */);
                const endLabel = exception.endLabel;
                emitBreak(endLabel);
                const finallyLabel = defineLabel();
                markLabel(finallyLabel);
                exception.state = 2 /* Finally */;
                exception.finallyLabel = finallyLabel;
            }
            function endExceptionBlock() {
                Debug.assert(peekBlockKind() === 0 /* Exception */);
                const exception = endBlock();
                const state2 = exception.state;
                if (state2 < 2 /* Finally */) {
                    emitBreak(exception.endLabel);
                }
                else {
                    emitEndfinally();
                }
                markLabel(exception.endLabel);
                emitNop();
                exception.state = 3 /* Done */;
            }
            function beginScriptLoopBlock() {
                beginBlock({
                    kind: 3 /* Loop */,
                    isScript: true,
                    breakLabel: -1,
                    continueLabel: -1
                });
            }
            function beginLoopBlock(continueLabel) {
                const breakLabel = defineLabel();
                beginBlock({
                    kind: 3 /* Loop */,
                    isScript: false,
                    breakLabel,
                    continueLabel
                });
                return breakLabel;
            }
            function endLoopBlock() {
                Debug.assert(peekBlockKind() === 3 /* Loop */);
                const block = endBlock();
                const breakLabel = block.breakLabel;
                if (!block.isScript) {
                    markLabel(breakLabel);
                }
            }
            function beginScriptSwitchBlock() {
                beginBlock({
                    kind: 2 /* Switch */,
                    isScript: true,
                    breakLabel: -1
                });
            }
            function beginSwitchBlock() {
                const breakLabel = defineLabel();
                beginBlock({
                    kind: 2 /* Switch */,
                    isScript: false,
                    breakLabel
                });
                return breakLabel;
            }
            function endSwitchBlock() {
                Debug.assert(peekBlockKind() === 2 /* Switch */);
                const block = endBlock();
                const breakLabel = block.breakLabel;
                if (!block.isScript) {
                    markLabel(breakLabel);
                }
            }
            function beginScriptLabeledBlock(labelText) {
                beginBlock({
                    kind: 4 /* Labeled */,
                    isScript: true,
                    labelText,
                    breakLabel: -1
                });
            }
            function beginLabeledBlock(labelText) {
                const breakLabel = defineLabel();
                beginBlock({
                    kind: 4 /* Labeled */,
                    isScript: false,
                    labelText,
                    breakLabel
                });
            }
            function endLabeledBlock() {
                Debug.assert(peekBlockKind() === 4 /* Labeled */);
                const block = endBlock();
                if (!block.isScript) {
                    markLabel(block.breakLabel);
                }
            }
            function supportsUnlabeledBreak(block) {
                return block.kind === 2 /* Switch */ || block.kind === 3 /* Loop */;
            }
            function supportsLabeledBreakOrContinue(block) {
                return block.kind === 4 /* Labeled */;
            }
            function supportsUnlabeledContinue(block) {
                return block.kind === 3 /* Loop */;
            }
            function hasImmediateContainingLabeledBlock(labelText, start) {
                for (let j = start; j >= 0; j--) {
                    const containingBlock = blockStack[j];
                    if (supportsLabeledBreakOrContinue(containingBlock)) {
                        if (containingBlock.labelText === labelText) {
                            return true;
                        }
                    }
                    else {
                        break;
                    }
                }
                return false;
            }
            function findBreakTarget(labelText) {
                if (blockStack) {
                    if (labelText) {
                        for (let i = blockStack.length - 1; i >= 0; i--) {
                            const block = blockStack[i];
                            if (supportsLabeledBreakOrContinue(block) && block.labelText === labelText) {
                                return block.breakLabel;
                            }
                            else if (supportsUnlabeledBreak(block) && hasImmediateContainingLabeledBlock(labelText, i - 1)) {
                                return block.breakLabel;
                            }
                        }
                    }
                    else {
                        for (let i = blockStack.length - 1; i >= 0; i--) {
                            const block = blockStack[i];
                            if (supportsUnlabeledBreak(block)) {
                                return block.breakLabel;
                            }
                        }
                    }
                }
                return 0;
            }
            function findContinueTarget(labelText) {
                if (blockStack) {
                    if (labelText) {
                        for (let i = blockStack.length - 1; i >= 0; i--) {
                            const block = blockStack[i];
                            if (supportsUnlabeledContinue(block) && hasImmediateContainingLabeledBlock(labelText, i - 1)) {
                                return block.continueLabel;
                            }
                        }
                    }
                    else {
                        for (let i = blockStack.length - 1; i >= 0; i--) {
                            const block = blockStack[i];
                            if (supportsUnlabeledContinue(block)) {
                                return block.continueLabel;
                            }
                        }
                    }
                }
                return 0;
            }
            function createLabel(label) {
                if (label !== void 0 && label > 0) {
                    if (labelExpressions === void 0) {
                        labelExpressions = [];
                    }
                    const expression = factory2.createNumericLiteral(Number.MAX_SAFE_INTEGER);
                    if (labelExpressions[label] === void 0) {
                        labelExpressions[label] = [expression];
                    }
                    else {
                        labelExpressions[label].push(expression);
                    }
                    return expression;
                }
                return factory2.createOmittedExpression();
            }
            function createInstruction(instruction) {
                const literal = factory2.createNumericLiteral(instruction);
                addSyntheticTrailingComment(literal, 3 /* MultiLineCommentTrivia */, getInstructionName(instruction));
                return literal;
            }
            function createInlineBreak(label, location) {
                Debug.assertLessThan(0, label, "Invalid label");
                return setTextRange(factory2.createReturnStatement(factory2.createArrayLiteralExpression([
                    createInstruction(3 /* Break */),
                    createLabel(label)
                ])), location);
            }
            function createInlineReturn(expression, location) {
                return setTextRange(factory2.createReturnStatement(factory2.createArrayLiteralExpression(expression ? [createInstruction(2 /* Return */), expression] : [createInstruction(2 /* Return */)])), location);
            }
            function createGeneratorResume(location) {
                return setTextRange(factory2.createCallExpression(factory2.createPropertyAccessExpression(state, "sent"), 
                /*typeArguments*/
                void 0, []), location);
            }
            function emitNop() {
                emitWorker(0 /* Nop */);
            }
            function emitStatement(node) {
                if (node) {
                    emitWorker(1 /* Statement */, [node]);
                }
                else {
                    emitNop();
                }
            }
            function emitAssignment(left, right, location) {
                emitWorker(2 /* Assign */, [left, right], location);
            }
            function emitBreak(label, location) {
                emitWorker(3 /* Break */, [label], location);
            }
            function emitBreakWhenTrue(label, condition, location) {
                emitWorker(4 /* BreakWhenTrue */, [label, condition], location);
            }
            function emitBreakWhenFalse(label, condition, location) {
                emitWorker(5 /* BreakWhenFalse */, [label, condition], location);
            }
            function emitYieldStar(expression, location) {
                emitWorker(7 /* YieldStar */, [expression], location);
            }
            function emitYield(expression, location) {
                emitWorker(6 /* Yield */, [expression], location);
            }
            function emitReturn(expression, location) {
                emitWorker(8 /* Return */, [expression], location);
            }
            function emitThrow(expression, location) {
                emitWorker(9 /* Throw */, [expression], location);
            }
            function emitEndfinally() {
                emitWorker(10 /* Endfinally */);
            }
            function emitWorker(code, args, location) {
                if (operations === void 0) {
                    operations = [];
                    operationArguments = [];
                    operationLocations = [];
                }
                if (labelOffsets === void 0) {
                    markLabel(defineLabel());
                }
                const operationIndex = operations.length;
                operations[operationIndex] = code;
                operationArguments[operationIndex] = args;
                operationLocations[operationIndex] = location;
            }
            function build2() {
                blockIndex = 0;
                labelNumber = 0;
                labelNumbers = void 0;
                lastOperationWasAbrupt = false;
                lastOperationWasCompletion = false;
                clauses = void 0;
                statements = void 0;
                exceptionBlockStack = void 0;
                currentExceptionBlock = void 0;
                withBlockStack = void 0;
                const buildResult = buildStatements();
                return emitHelpers().createGeneratorHelper(setEmitFlags(factory2.createFunctionExpression(
                /*modifiers*/
                void 0, 
                /*asteriskToken*/
                void 0, 
                /*name*/
                void 0, 
                /*typeParameters*/
                void 0, [factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, state)], 
                /*type*/
                void 0, factory2.createBlock(buildResult, 
                /*multiLine*/
                buildResult.length > 0)), 1048576 /* ReuseTempVariableScope */));
            }
            function buildStatements() {
                if (operations) {
                    for (let operationIndex = 0; operationIndex < operations.length; operationIndex++) {
                        writeOperation(operationIndex);
                    }
                    flushFinalLabel(operations.length);
                }
                else {
                    flushFinalLabel(0);
                }
                if (clauses) {
                    const labelExpression = factory2.createPropertyAccessExpression(state, "label");
                    const switchStatement = factory2.createSwitchStatement(labelExpression, factory2.createCaseBlock(clauses));
                    return [startOnNewLine(switchStatement)];
                }
                if (statements) {
                    return statements;
                }
                return [];
            }
            function flushLabel() {
                if (!statements) {
                    return;
                }
                appendLabel(
                /*markLabelEnd*/
                !lastOperationWasAbrupt);
                lastOperationWasAbrupt = false;
                lastOperationWasCompletion = false;
                labelNumber++;
            }
            function flushFinalLabel(operationIndex) {
                if (isFinalLabelReachable(operationIndex)) {
                    tryEnterLabel(operationIndex);
                    withBlockStack = void 0;
                    writeReturn(
                    /*expression*/
                    void 0, 
                    /*operationLocation*/
                    void 0);
                }
                if (statements && clauses) {
                    appendLabel(
                    /*markLabelEnd*/
                    false);
                }
                updateLabelExpressions();
            }
            function isFinalLabelReachable(operationIndex) {
                if (!lastOperationWasCompletion) {
                    return true;
                }
                if (!labelOffsets || !labelExpressions) {
                    return false;
                }
                for (let label = 0; label < labelOffsets.length; label++) {
                    if (labelOffsets[label] === operationIndex && labelExpressions[label]) {
                        return true;
                    }
                }
                return false;
            }
            function appendLabel(markLabelEnd) {
                if (!clauses) {
                    clauses = [];
                }
                if (statements) {
                    if (withBlockStack) {
                        for (let i = withBlockStack.length - 1; i >= 0; i--) {
                            const withBlock = withBlockStack[i];
                            statements = [factory2.createWithStatement(withBlock.expression, factory2.createBlock(statements))];
                        }
                    }
                    if (currentExceptionBlock) {
                        const { startLabel, catchLabel, finallyLabel, endLabel } = currentExceptionBlock;
                        statements.unshift(factory2.createExpressionStatement(factory2.createCallExpression(factory2.createPropertyAccessExpression(factory2.createPropertyAccessExpression(state, "trys"), "push"), 
                        /*typeArguments*/
                        void 0, [
                            factory2.createArrayLiteralExpression([
                                createLabel(startLabel),
                                createLabel(catchLabel),
                                createLabel(finallyLabel),
                                createLabel(endLabel)
                            ])
                        ])));
                        currentExceptionBlock = void 0;
                    }
                    if (markLabelEnd) {
                        statements.push(factory2.createExpressionStatement(factory2.createAssignment(factory2.createPropertyAccessExpression(state, "label"), factory2.createNumericLiteral(labelNumber + 1))));
                    }
                }
                clauses.push(factory2.createCaseClause(factory2.createNumericLiteral(labelNumber), statements || []));
                statements = void 0;
            }
            function tryEnterLabel(operationIndex) {
                if (!labelOffsets) {
                    return;
                }
                for (let label = 0; label < labelOffsets.length; label++) {
                    if (labelOffsets[label] === operationIndex) {
                        flushLabel();
                        if (labelNumbers === void 0) {
                            labelNumbers = [];
                        }
                        if (labelNumbers[labelNumber] === void 0) {
                            labelNumbers[labelNumber] = [label];
                        }
                        else {
                            labelNumbers[labelNumber].push(label);
                        }
                    }
                }
            }
            function updateLabelExpressions() {
                if (labelExpressions !== void 0 && labelNumbers !== void 0) {
                    for (let labelNumber2 = 0; labelNumber2 < labelNumbers.length; labelNumber2++) {
                        const labels = labelNumbers[labelNumber2];
                        if (labels !== void 0) {
                            for (const label of labels) {
                                const expressions = labelExpressions[label];
                                if (expressions !== void 0) {
                                    for (const expression of expressions) {
                                        expression.text = String(labelNumber2);
                                    }
                                }
                            }
                        }
                    }
                }
            }
            function tryEnterOrLeaveBlock(operationIndex) {
                if (blocks) {
                    for (; blockIndex < blockActions.length && blockOffsets[blockIndex] <= operationIndex; blockIndex++) {
                        const block = blocks[blockIndex];
                        const blockAction = blockActions[blockIndex];
                        switch (block.kind) {
                            case 0 /* Exception */:
                                if (blockAction === 0 /* Open */) {
                                    if (!exceptionBlockStack) {
                                        exceptionBlockStack = [];
                                    }
                                    if (!statements) {
                                        statements = [];
                                    }
                                    exceptionBlockStack.push(currentExceptionBlock);
                                    currentExceptionBlock = block;
                                }
                                else if (blockAction === 1 /* Close */) {
                                    currentExceptionBlock = exceptionBlockStack.pop();
                                }
                                break;
                            case 1 /* With */:
                                if (blockAction === 0 /* Open */) {
                                    if (!withBlockStack) {
                                        withBlockStack = [];
                                    }
                                    withBlockStack.push(block);
                                }
                                else if (blockAction === 1 /* Close */) {
                                    withBlockStack.pop();
                                }
                                break;
                        }
                    }
                }
            }
            function writeOperation(operationIndex) {
                tryEnterLabel(operationIndex);
                tryEnterOrLeaveBlock(operationIndex);
                if (lastOperationWasAbrupt) {
                    return;
                }
                lastOperationWasAbrupt = false;
                lastOperationWasCompletion = false;
                const opcode = operations[operationIndex];
                if (opcode === 0 /* Nop */) {
                    return;
                }
                else if (opcode === 10 /* Endfinally */) {
                    return writeEndfinally();
                }
                const args = operationArguments[operationIndex];
                if (opcode === 1 /* Statement */) {
                    return writeStatement(args[0]);
                }
                const location = operationLocations[operationIndex];
                switch (opcode) {
                    case 2 /* Assign */:
                        return writeAssign(args[0], args[1], location);
                    case 3 /* Break */:
                        return writeBreak(args[0], location);
                    case 4 /* BreakWhenTrue */:
                        return writeBreakWhenTrue(args[0], args[1], location);
                    case 5 /* BreakWhenFalse */:
                        return writeBreakWhenFalse(args[0], args[1], location);
                    case 6 /* Yield */:
                        return writeYield(args[0], location);
                    case 7 /* YieldStar */:
                        return writeYieldStar(args[0], location);
                    case 8 /* Return */:
                        return writeReturn(args[0], location);
                    case 9 /* Throw */:
                        return writeThrow(args[0], location);
                }
            }
            function writeStatement(statement) {
                if (statement) {
                    if (!statements) {
                        statements = [statement];
                    }
                    else {
                        statements.push(statement);
                    }
                }
            }
            function writeAssign(left, right, operationLocation) {
                writeStatement(setTextRange(factory2.createExpressionStatement(factory2.createAssignment(left, right)), operationLocation));
            }
            function writeThrow(expression, operationLocation) {
                lastOperationWasAbrupt = true;
                lastOperationWasCompletion = true;
                writeStatement(setTextRange(factory2.createThrowStatement(expression), operationLocation));
            }
            function writeReturn(expression, operationLocation) {
                lastOperationWasAbrupt = true;
                lastOperationWasCompletion = true;
                writeStatement(setEmitFlags(setTextRange(factory2.createReturnStatement(factory2.createArrayLiteralExpression(expression ? [createInstruction(2 /* Return */), expression] : [createInstruction(2 /* Return */)])), operationLocation), 768 /* NoTokenSourceMaps */));
            }
            function writeBreak(label, operationLocation) {
                lastOperationWasAbrupt = true;
                writeStatement(setEmitFlags(setTextRange(factory2.createReturnStatement(factory2.createArrayLiteralExpression([
                    createInstruction(3 /* Break */),
                    createLabel(label)
                ])), operationLocation), 768 /* NoTokenSourceMaps */));
            }
            function writeBreakWhenTrue(label, condition, operationLocation) {
                writeStatement(setEmitFlags(factory2.createIfStatement(condition, setEmitFlags(setTextRange(factory2.createReturnStatement(factory2.createArrayLiteralExpression([
                    createInstruction(3 /* Break */),
                    createLabel(label)
                ])), operationLocation), 768 /* NoTokenSourceMaps */)), 1 /* SingleLine */));
            }
            function writeBreakWhenFalse(label, condition, operationLocation) {
                writeStatement(setEmitFlags(factory2.createIfStatement(factory2.createLogicalNot(condition), setEmitFlags(setTextRange(factory2.createReturnStatement(factory2.createArrayLiteralExpression([
                    createInstruction(3 /* Break */),
                    createLabel(label)
                ])), operationLocation), 768 /* NoTokenSourceMaps */)), 1 /* SingleLine */));
            }
            function writeYield(expression, operationLocation) {
                lastOperationWasAbrupt = true;
                writeStatement(setEmitFlags(setTextRange(factory2.createReturnStatement(factory2.createArrayLiteralExpression(expression ? [createInstruction(4 /* Yield */), expression] : [createInstruction(4 /* Yield */)])), operationLocation), 768 /* NoTokenSourceMaps */));
            }
            function writeYieldStar(expression, operationLocation) {
                lastOperationWasAbrupt = true;
                writeStatement(setEmitFlags(setTextRange(factory2.createReturnStatement(factory2.createArrayLiteralExpression([
                    createInstruction(5 /* YieldStar */),
                    expression
                ])), operationLocation), 768 /* NoTokenSourceMaps */));
            }
            function writeEndfinally() {
                lastOperationWasAbrupt = true;
                writeStatement(factory2.createReturnStatement(factory2.createArrayLiteralExpression([
                    createInstruction(7 /* Endfinally */)
                ])));
            }
        }
        var init_generators = __esm({
            "src/compiler/transformers/generators.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/module/module.ts
        function transformModule(context) {
            function getTransformModuleDelegate(moduleKind2) {
                switch (moduleKind2) {
                    case 2 /* AMD */:
                        return transformAMDModule;
                    case 3 /* UMD */:
                        return transformUMDModule;
                    default:
                        return transformCommonJSModule;
                }
            }
            const { factory: factory2, getEmitHelperFactory: emitHelpers, startLexicalEnvironment, endLexicalEnvironment, hoistVariableDeclaration } = context;
            const compilerOptions = context.getCompilerOptions();
            const resolver = context.getEmitResolver();
            const host = context.getEmitHost();
            const languageVersion = getEmitScriptTarget(compilerOptions);
            const moduleKind = getEmitModuleKind(compilerOptions);
            const previousOnSubstituteNode = context.onSubstituteNode;
            const previousOnEmitNode = context.onEmitNode;
            context.onSubstituteNode = onSubstituteNode;
            context.onEmitNode = onEmitNode;
            context.enableSubstitution(213 /* CallExpression */);
            context.enableSubstitution(215 /* TaggedTemplateExpression */);
            context.enableSubstitution(80 /* Identifier */);
            context.enableSubstitution(226 /* BinaryExpression */);
            context.enableSubstitution(304 /* ShorthandPropertyAssignment */);
            context.enableEmitNotification(312 /* SourceFile */);
            const moduleInfoMap = [];
            let currentSourceFile;
            let currentModuleInfo;
            const noSubstitution = [];
            let needUMDDynamicImportHelper;
            return chainBundle(context, transformSourceFile);
            function transformSourceFile(node) {
                if (node.isDeclarationFile || !(isEffectiveExternalModule(node, compilerOptions) || node.transformFlags & 8388608 /* ContainsDynamicImport */ || isJsonSourceFile(node) && hasJsonModuleEmitEnabled(compilerOptions) && outFile(compilerOptions))) {
                    return node;
                }
                currentSourceFile = node;
                currentModuleInfo = collectExternalModuleInfo(context, node);
                moduleInfoMap[getOriginalNodeId(node)] = currentModuleInfo;
                const transformModule2 = getTransformModuleDelegate(moduleKind);
                const updated = transformModule2(node);
                currentSourceFile = void 0;
                currentModuleInfo = void 0;
                needUMDDynamicImportHelper = false;
                return updated;
            }
            function shouldEmitUnderscoreUnderscoreESModule() {
                if (!currentModuleInfo.exportEquals && isExternalModule(currentSourceFile)) {
                    return true;
                }
                return false;
            }
            function transformCommonJSModule(node) {
                startLexicalEnvironment();
                const statements = [];
                const ensureUseStrict = getStrictOptionValue(compilerOptions, "alwaysStrict") || !compilerOptions.noImplicitUseStrict && isExternalModule(currentSourceFile);
                const statementOffset = factory2.copyPrologue(node.statements, statements, ensureUseStrict && !isJsonSourceFile(node), topLevelVisitor);
                if (shouldEmitUnderscoreUnderscoreESModule()) {
                    append(statements, createUnderscoreUnderscoreESModule());
                }
                if (length(currentModuleInfo.exportedNames)) {
                    const chunkSize = 50;
                    for (let i = 0; i < currentModuleInfo.exportedNames.length; i += chunkSize) {
                        append(statements, factory2.createExpressionStatement(reduceLeft(currentModuleInfo.exportedNames.slice(i, i + chunkSize), (prev, nextId) => factory2.createAssignment(factory2.createPropertyAccessExpression(factory2.createIdentifier("exports"), factory2.createIdentifier(idText(nextId))), prev), factory2.createVoidZero())));
                    }
                }
                append(statements, visitNode(currentModuleInfo.externalHelpersImportDeclaration, topLevelVisitor, isStatement));
                addRange(statements, visitNodes2(node.statements, topLevelVisitor, isStatement, statementOffset));
                addExportEqualsIfNeeded(statements, 
                /*emitAsReturn*/
                false);
                insertStatementsAfterStandardPrologue(statements, endLexicalEnvironment());
                const updated = factory2.updateSourceFile(node, setTextRange(factory2.createNodeArray(statements), node.statements));
                addEmitHelpers(updated, context.readEmitHelpers());
                return updated;
            }
            function transformAMDModule(node) {
                const define = factory2.createIdentifier("define");
                const moduleName = tryGetModuleNameFromFile(factory2, node, host, compilerOptions);
                const jsonSourceFile = isJsonSourceFile(node) && node;
                const { aliasedModuleNames, unaliasedModuleNames, importAliasNames } = collectAsynchronousDependencies(node, 
                /*includeNonAmdDependencies*/
                true);
                const updated = factory2.updateSourceFile(node, setTextRange(factory2.createNodeArray([
                    factory2.createExpressionStatement(factory2.createCallExpression(define, 
                    /*typeArguments*/
                    void 0, [
                        // Add the module name (if provided).
                        ...moduleName ? [moduleName] : [],
                        // Add the dependency array argument:
                        //
                        //     ["require", "exports", module1", "module2", ...]
                        factory2.createArrayLiteralExpression(jsonSourceFile ? emptyArray : [
                            factory2.createStringLiteral("require"),
                            factory2.createStringLiteral("exports"),
                            ...aliasedModuleNames,
                            ...unaliasedModuleNames
                        ]),
                        // Add the module body function argument:
                        //
                        //     function (require, exports, module1, module2) ...
                        jsonSourceFile ? jsonSourceFile.statements.length ? jsonSourceFile.statements[0].expression : factory2.createObjectLiteralExpression() : factory2.createFunctionExpression(
                        /*modifiers*/
                        void 0, 
                        /*asteriskToken*/
                        void 0, 
                        /*name*/
                        void 0, 
                        /*typeParameters*/
                        void 0, [
                            factory2.createParameterDeclaration(
                            /*modifiers*/
                            void 0, 
                            /*dotDotDotToken*/
                            void 0, "require"),
                            factory2.createParameterDeclaration(
                            /*modifiers*/
                            void 0, 
                            /*dotDotDotToken*/
                            void 0, "exports"),
                            ...importAliasNames
                        ], 
                        /*type*/
                        void 0, transformAsynchronousModuleBody(node))
                    ]))
                ]), 
                /*location*/
                node.statements));
                addEmitHelpers(updated, context.readEmitHelpers());
                return updated;
            }
            function transformUMDModule(node) {
                const { aliasedModuleNames, unaliasedModuleNames, importAliasNames } = collectAsynchronousDependencies(node, 
                /*includeNonAmdDependencies*/
                false);
                const moduleName = tryGetModuleNameFromFile(factory2, node, host, compilerOptions);
                const umdHeader = factory2.createFunctionExpression(
                /*modifiers*/
                void 0, 
                /*asteriskToken*/
                void 0, 
                /*name*/
                void 0, 
                /*typeParameters*/
                void 0, [factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, "factory")], 
                /*type*/
                void 0, setTextRange(factory2.createBlock([
                    factory2.createIfStatement(factory2.createLogicalAnd(factory2.createTypeCheck(factory2.createIdentifier("module"), "object"), factory2.createTypeCheck(factory2.createPropertyAccessExpression(factory2.createIdentifier("module"), "exports"), "object")), factory2.createBlock([
                        factory2.createVariableStatement(
                        /*modifiers*/
                        void 0, [
                            factory2.createVariableDeclaration("v", 
                            /*exclamationToken*/
                            void 0, 
                            /*type*/
                            void 0, factory2.createCallExpression(factory2.createIdentifier("factory"), 
                            /*typeArguments*/
                            void 0, [
                                factory2.createIdentifier("require"),
                                factory2.createIdentifier("exports")
                            ]))
                        ]),
                        setEmitFlags(factory2.createIfStatement(factory2.createStrictInequality(factory2.createIdentifier("v"), factory2.createIdentifier("undefined")), factory2.createExpressionStatement(factory2.createAssignment(factory2.createPropertyAccessExpression(factory2.createIdentifier("module"), "exports"), factory2.createIdentifier("v")))), 1 /* SingleLine */)
                    ]), factory2.createIfStatement(factory2.createLogicalAnd(factory2.createTypeCheck(factory2.createIdentifier("define"), "function"), factory2.createPropertyAccessExpression(factory2.createIdentifier("define"), "amd")), factory2.createBlock([
                        factory2.createExpressionStatement(factory2.createCallExpression(factory2.createIdentifier("define"), 
                        /*typeArguments*/
                        void 0, [
                            // Add the module name (if provided).
                            ...moduleName ? [moduleName] : [],
                            factory2.createArrayLiteralExpression([
                                factory2.createStringLiteral("require"),
                                factory2.createStringLiteral("exports"),
                                ...aliasedModuleNames,
                                ...unaliasedModuleNames
                            ]),
                            factory2.createIdentifier("factory")
                        ]))
                    ])))
                ], 
                /*multiLine*/
                true), 
                /*location*/
                void 0));
                const updated = factory2.updateSourceFile(node, setTextRange(factory2.createNodeArray([
                    factory2.createExpressionStatement(factory2.createCallExpression(umdHeader, 
                    /*typeArguments*/
                    void 0, [
                        // Add the module body function argument:
                        //
                        //     function (require, exports) ...
                        factory2.createFunctionExpression(
                        /*modifiers*/
                        void 0, 
                        /*asteriskToken*/
                        void 0, 
                        /*name*/
                        void 0, 
                        /*typeParameters*/
                        void 0, [
                            factory2.createParameterDeclaration(
                            /*modifiers*/
                            void 0, 
                            /*dotDotDotToken*/
                            void 0, "require"),
                            factory2.createParameterDeclaration(
                            /*modifiers*/
                            void 0, 
                            /*dotDotDotToken*/
                            void 0, "exports"),
                            ...importAliasNames
                        ], 
                        /*type*/
                        void 0, transformAsynchronousModuleBody(node))
                    ]))
                ]), 
                /*location*/
                node.statements));
                addEmitHelpers(updated, context.readEmitHelpers());
                return updated;
            }
            function collectAsynchronousDependencies(node, includeNonAmdDependencies) {
                const aliasedModuleNames = [];
                const unaliasedModuleNames = [];
                const importAliasNames = [];
                for (const amdDependency of node.amdDependencies) {
                    if (amdDependency.name) {
                        aliasedModuleNames.push(factory2.createStringLiteral(amdDependency.path));
                        importAliasNames.push(factory2.createParameterDeclaration(
                        /*modifiers*/
                        void 0, 
                        /*dotDotDotToken*/
                        void 0, amdDependency.name));
                    }
                    else {
                        unaliasedModuleNames.push(factory2.createStringLiteral(amdDependency.path));
                    }
                }
                for (const importNode of currentModuleInfo.externalImports) {
                    const externalModuleName = getExternalModuleNameLiteral(factory2, importNode, currentSourceFile, host, resolver, compilerOptions);
                    const importAliasName = getLocalNameForExternalImport(factory2, importNode, currentSourceFile);
                    if (externalModuleName) {
                        if (includeNonAmdDependencies && importAliasName) {
                            setEmitFlags(importAliasName, 8 /* NoSubstitution */);
                            aliasedModuleNames.push(externalModuleName);
                            importAliasNames.push(factory2.createParameterDeclaration(
                            /*modifiers*/
                            void 0, 
                            /*dotDotDotToken*/
                            void 0, importAliasName));
                        }
                        else {
                            unaliasedModuleNames.push(externalModuleName);
                        }
                    }
                }
                return { aliasedModuleNames, unaliasedModuleNames, importAliasNames };
            }
            function getAMDImportExpressionForImport(node) {
                if (isImportEqualsDeclaration(node) || isExportDeclaration(node) || !getExternalModuleNameLiteral(factory2, node, currentSourceFile, host, resolver, compilerOptions)) {
                    return void 0;
                }
                const name = getLocalNameForExternalImport(factory2, node, currentSourceFile);
                const expr = getHelperExpressionForImport(node, name);
                if (expr === name) {
                    return void 0;
                }
                return factory2.createExpressionStatement(factory2.createAssignment(name, expr));
            }
            function transformAsynchronousModuleBody(node) {
                startLexicalEnvironment();
                const statements = [];
                const statementOffset = factory2.copyPrologue(node.statements, statements, 
                /*ensureUseStrict*/
                !compilerOptions.noImplicitUseStrict, topLevelVisitor);
                if (shouldEmitUnderscoreUnderscoreESModule()) {
                    append(statements, createUnderscoreUnderscoreESModule());
                }
                if (length(currentModuleInfo.exportedNames)) {
                    append(statements, factory2.createExpressionStatement(reduceLeft(currentModuleInfo.exportedNames, (prev, nextId) => factory2.createAssignment(factory2.createPropertyAccessExpression(factory2.createIdentifier("exports"), factory2.createIdentifier(idText(nextId))), prev), factory2.createVoidZero())));
                }
                append(statements, visitNode(currentModuleInfo.externalHelpersImportDeclaration, topLevelVisitor, isStatement));
                if (moduleKind === 2 /* AMD */) {
                    addRange(statements, mapDefined(currentModuleInfo.externalImports, getAMDImportExpressionForImport));
                }
                addRange(statements, visitNodes2(node.statements, topLevelVisitor, isStatement, statementOffset));
                addExportEqualsIfNeeded(statements, 
                /*emitAsReturn*/
                true);
                insertStatementsAfterStandardPrologue(statements, endLexicalEnvironment());
                const body = factory2.createBlock(statements, 
                /*multiLine*/
                true);
                if (needUMDDynamicImportHelper) {
                    addEmitHelper(body, dynamicImportUMDHelper);
                }
                return body;
            }
            function addExportEqualsIfNeeded(statements, emitAsReturn) {
                if (currentModuleInfo.exportEquals) {
                    const expressionResult = visitNode(currentModuleInfo.exportEquals.expression, visitor, isExpression);
                    if (expressionResult) {
                        if (emitAsReturn) {
                            const statement = factory2.createReturnStatement(expressionResult);
                            setTextRange(statement, currentModuleInfo.exportEquals);
                            setEmitFlags(statement, 768 /* NoTokenSourceMaps */ | 3072 /* NoComments */);
                            statements.push(statement);
                        }
                        else {
                            const statement = factory2.createExpressionStatement(factory2.createAssignment(factory2.createPropertyAccessExpression(factory2.createIdentifier("module"), "exports"), expressionResult));
                            setTextRange(statement, currentModuleInfo.exportEquals);
                            setEmitFlags(statement, 3072 /* NoComments */);
                            statements.push(statement);
                        }
                    }
                }
            }
            function topLevelVisitor(node) {
                switch (node.kind) {
                    case 272 /* ImportDeclaration */:
                        return visitTopLevelImportDeclaration(node);
                    case 271 /* ImportEqualsDeclaration */:
                        return visitTopLevelImportEqualsDeclaration(node);
                    case 278 /* ExportDeclaration */:
                        return visitTopLevelExportDeclaration(node);
                    case 277 /* ExportAssignment */:
                        return visitTopLevelExportAssignment(node);
                    default:
                        return topLevelNestedVisitor(node);
                }
            }
            function topLevelNestedVisitor(node) {
                switch (node.kind) {
                    case 243 /* VariableStatement */:
                        return visitVariableStatement(node);
                    case 262 /* FunctionDeclaration */:
                        return visitFunctionDeclaration(node);
                    case 263 /* ClassDeclaration */:
                        return visitClassDeclaration(node);
                    case 248 /* ForStatement */:
                        return visitForStatement(node, 
                        /*isTopLevel*/
                        true);
                    case 249 /* ForInStatement */:
                        return visitForInStatement(node);
                    case 250 /* ForOfStatement */:
                        return visitForOfStatement(node);
                    case 246 /* DoStatement */:
                        return visitDoStatement(node);
                    case 247 /* WhileStatement */:
                        return visitWhileStatement(node);
                    case 256 /* LabeledStatement */:
                        return visitLabeledStatement(node);
                    case 254 /* WithStatement */:
                        return visitWithStatement(node);
                    case 245 /* IfStatement */:
                        return visitIfStatement(node);
                    case 255 /* SwitchStatement */:
                        return visitSwitchStatement(node);
                    case 269 /* CaseBlock */:
                        return visitCaseBlock(node);
                    case 296 /* CaseClause */:
                        return visitCaseClause(node);
                    case 297 /* DefaultClause */:
                        return visitDefaultClause(node);
                    case 258 /* TryStatement */:
                        return visitTryStatement(node);
                    case 299 /* CatchClause */:
                        return visitCatchClause(node);
                    case 241 /* Block */:
                        return visitBlock(node);
                    default:
                        return visitor(node);
                }
            }
            function visitorWorker(node, valueIsDiscarded) {
                if (!(node.transformFlags & (8388608 /* ContainsDynamicImport */ | 4096 /* ContainsDestructuringAssignment */ | 268435456 /* ContainsUpdateExpressionForIdentifier */))) {
                    return node;
                }
                switch (node.kind) {
                    case 248 /* ForStatement */:
                        return visitForStatement(node, 
                        /*isTopLevel*/
                        false);
                    case 244 /* ExpressionStatement */:
                        return visitExpressionStatement(node);
                    case 217 /* ParenthesizedExpression */:
                        return visitParenthesizedExpression(node, valueIsDiscarded);
                    case 360 /* PartiallyEmittedExpression */:
                        return visitPartiallyEmittedExpression(node, valueIsDiscarded);
                    case 213 /* CallExpression */:
                        if (isImportCall(node) && currentSourceFile.impliedNodeFormat === void 0) {
                            return visitImportCallExpression(node);
                        }
                        break;
                    case 226 /* BinaryExpression */:
                        if (isDestructuringAssignment(node)) {
                            return visitDestructuringAssignment(node, valueIsDiscarded);
                        }
                        break;
                    case 224 /* PrefixUnaryExpression */:
                    case 225 /* PostfixUnaryExpression */:
                        return visitPreOrPostfixUnaryExpression(node, valueIsDiscarded);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitor(node) {
                return visitorWorker(node, 
                /*valueIsDiscarded*/
                false);
            }
            function discardedValueVisitor(node) {
                return visitorWorker(node, 
                /*valueIsDiscarded*/
                true);
            }
            function destructuringNeedsFlattening(node) {
                if (isObjectLiteralExpression(node)) {
                    for (const elem of node.properties) {
                        switch (elem.kind) {
                            case 303 /* PropertyAssignment */:
                                if (destructuringNeedsFlattening(elem.initializer)) {
                                    return true;
                                }
                                break;
                            case 304 /* ShorthandPropertyAssignment */:
                                if (destructuringNeedsFlattening(elem.name)) {
                                    return true;
                                }
                                break;
                            case 305 /* SpreadAssignment */:
                                if (destructuringNeedsFlattening(elem.expression)) {
                                    return true;
                                }
                                break;
                            case 174 /* MethodDeclaration */:
                            case 177 /* GetAccessor */:
                            case 178 /* SetAccessor */:
                                return false;
                            default:
                                Debug.assertNever(elem, "Unhandled object member kind");
                        }
                    }
                }
                else if (isArrayLiteralExpression(node)) {
                    for (const elem of node.elements) {
                        if (isSpreadElement(elem)) {
                            if (destructuringNeedsFlattening(elem.expression)) {
                                return true;
                            }
                        }
                        else if (destructuringNeedsFlattening(elem)) {
                            return true;
                        }
                    }
                }
                else if (isIdentifier(node)) {
                    return length(getExports(node)) > (isExportName(node) ? 1 : 0);
                }
                return false;
            }
            function visitDestructuringAssignment(node, valueIsDiscarded) {
                if (destructuringNeedsFlattening(node.left)) {
                    return flattenDestructuringAssignment(node, visitor, context, 0 /* All */, !valueIsDiscarded, createAllExportExpressions);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitForStatement(node, isTopLevel) {
                if (isTopLevel && node.initializer && isVariableDeclarationList(node.initializer) && !(node.initializer.flags & 7 /* BlockScoped */)) {
                    const exportStatements = appendExportsOfVariableDeclarationList(
                    /*statements*/
                    void 0, node.initializer, 
                    /*isForInOrOfInitializer*/
                    false);
                    if (exportStatements) {
                        const statements = [];
                        const varDeclList = visitNode(node.initializer, discardedValueVisitor, isVariableDeclarationList);
                        const varStatement = factory2.createVariableStatement(
                        /*modifiers*/
                        void 0, varDeclList);
                        statements.push(varStatement);
                        addRange(statements, exportStatements);
                        const condition = visitNode(node.condition, visitor, isExpression);
                        const incrementor = visitNode(node.incrementor, discardedValueVisitor, isExpression);
                        const body = visitIterationBody(node.statement, isTopLevel ? topLevelNestedVisitor : visitor, context);
                        statements.push(factory2.updateForStatement(node, 
                        /*initializer*/
                        void 0, condition, incrementor, body));
                        return statements;
                    }
                }
                return factory2.updateForStatement(node, visitNode(node.initializer, discardedValueVisitor, isForInitializer), visitNode(node.condition, visitor, isExpression), visitNode(node.incrementor, discardedValueVisitor, isExpression), visitIterationBody(node.statement, isTopLevel ? topLevelNestedVisitor : visitor, context));
            }
            function visitForInStatement(node) {
                if (isVariableDeclarationList(node.initializer) && !(node.initializer.flags & 7 /* BlockScoped */)) {
                    const exportStatements = appendExportsOfVariableDeclarationList(
                    /*statements*/
                    void 0, node.initializer, 
                    /*isForInOrOfInitializer*/
                    true);
                    if (some(exportStatements)) {
                        const initializer = visitNode(node.initializer, discardedValueVisitor, isForInitializer);
                        const expression = visitNode(node.expression, visitor, isExpression);
                        const body = visitIterationBody(node.statement, topLevelNestedVisitor, context);
                        const mergedBody = isBlock(body) ? factory2.updateBlock(body, [...exportStatements, ...body.statements]) : factory2.createBlock([...exportStatements, body], 
                        /*multiLine*/
                        true);
                        return factory2.updateForInStatement(node, initializer, expression, mergedBody);
                    }
                }
                return factory2.updateForInStatement(node, visitNode(node.initializer, discardedValueVisitor, isForInitializer), visitNode(node.expression, visitor, isExpression), visitIterationBody(node.statement, topLevelNestedVisitor, context));
            }
            function visitForOfStatement(node) {
                if (isVariableDeclarationList(node.initializer) && !(node.initializer.flags & 7 /* BlockScoped */)) {
                    const exportStatements = appendExportsOfVariableDeclarationList(
                    /*statements*/
                    void 0, node.initializer, 
                    /*isForInOrOfInitializer*/
                    true);
                    const initializer = visitNode(node.initializer, discardedValueVisitor, isForInitializer);
                    const expression = visitNode(node.expression, visitor, isExpression);
                    let body = visitIterationBody(node.statement, topLevelNestedVisitor, context);
                    if (some(exportStatements)) {
                        body = isBlock(body) ? factory2.updateBlock(body, [...exportStatements, ...body.statements]) : factory2.createBlock([...exportStatements, body], 
                        /*multiLine*/
                        true);
                    }
                    return factory2.updateForOfStatement(node, node.awaitModifier, initializer, expression, body);
                }
                return factory2.updateForOfStatement(node, node.awaitModifier, visitNode(node.initializer, discardedValueVisitor, isForInitializer), visitNode(node.expression, visitor, isExpression), visitIterationBody(node.statement, topLevelNestedVisitor, context));
            }
            function visitDoStatement(node) {
                return factory2.updateDoStatement(node, visitIterationBody(node.statement, topLevelNestedVisitor, context), visitNode(node.expression, visitor, isExpression));
            }
            function visitWhileStatement(node) {
                return factory2.updateWhileStatement(node, visitNode(node.expression, visitor, isExpression), visitIterationBody(node.statement, topLevelNestedVisitor, context));
            }
            function visitLabeledStatement(node) {
                return factory2.updateLabeledStatement(node, node.label, Debug.checkDefined(visitNode(node.statement, topLevelNestedVisitor, isStatement, factory2.liftToBlock)));
            }
            function visitWithStatement(node) {
                return factory2.updateWithStatement(node, visitNode(node.expression, visitor, isExpression), Debug.checkDefined(visitNode(node.statement, topLevelNestedVisitor, isStatement, factory2.liftToBlock)));
            }
            function visitIfStatement(node) {
                return factory2.updateIfStatement(node, visitNode(node.expression, visitor, isExpression), Debug.checkDefined(visitNode(node.thenStatement, topLevelNestedVisitor, isStatement, factory2.liftToBlock)), visitNode(node.elseStatement, topLevelNestedVisitor, isStatement, factory2.liftToBlock));
            }
            function visitSwitchStatement(node) {
                return factory2.updateSwitchStatement(node, visitNode(node.expression, visitor, isExpression), Debug.checkDefined(visitNode(node.caseBlock, topLevelNestedVisitor, isCaseBlock)));
            }
            function visitCaseBlock(node) {
                return factory2.updateCaseBlock(node, visitNodes2(node.clauses, topLevelNestedVisitor, isCaseOrDefaultClause));
            }
            function visitCaseClause(node) {
                return factory2.updateCaseClause(node, visitNode(node.expression, visitor, isExpression), visitNodes2(node.statements, topLevelNestedVisitor, isStatement));
            }
            function visitDefaultClause(node) {
                return visitEachChild(node, topLevelNestedVisitor, context);
            }
            function visitTryStatement(node) {
                return visitEachChild(node, topLevelNestedVisitor, context);
            }
            function visitCatchClause(node) {
                return factory2.updateCatchClause(node, node.variableDeclaration, Debug.checkDefined(visitNode(node.block, topLevelNestedVisitor, isBlock)));
            }
            function visitBlock(node) {
                node = visitEachChild(node, topLevelNestedVisitor, context);
                return node;
            }
            function visitExpressionStatement(node) {
                return factory2.updateExpressionStatement(node, visitNode(node.expression, discardedValueVisitor, isExpression));
            }
            function visitParenthesizedExpression(node, valueIsDiscarded) {
                return factory2.updateParenthesizedExpression(node, visitNode(node.expression, valueIsDiscarded ? discardedValueVisitor : visitor, isExpression));
            }
            function visitPartiallyEmittedExpression(node, valueIsDiscarded) {
                return factory2.updatePartiallyEmittedExpression(node, visitNode(node.expression, valueIsDiscarded ? discardedValueVisitor : visitor, isExpression));
            }
            function visitPreOrPostfixUnaryExpression(node, valueIsDiscarded) {
                if ((node.operator === 46 /* PlusPlusToken */ || node.operator === 47 /* MinusMinusToken */) && isIdentifier(node.operand) && !isGeneratedIdentifier(node.operand) && !isLocalName(node.operand) && !isDeclarationNameOfEnumOrNamespace(node.operand)) {
                    const exportedNames = getExports(node.operand);
                    if (exportedNames) {
                        let temp;
                        let expression = visitNode(node.operand, visitor, isExpression);
                        if (isPrefixUnaryExpression(node)) {
                            expression = factory2.updatePrefixUnaryExpression(node, expression);
                        }
                        else {
                            expression = factory2.updatePostfixUnaryExpression(node, expression);
                            if (!valueIsDiscarded) {
                                temp = factory2.createTempVariable(hoistVariableDeclaration);
                                expression = factory2.createAssignment(temp, expression);
                                setTextRange(expression, node);
                            }
                            expression = factory2.createComma(expression, factory2.cloneNode(node.operand));
                            setTextRange(expression, node);
                        }
                        for (const exportName of exportedNames) {
                            noSubstitution[getNodeId(expression)] = true;
                            expression = createExportExpression(exportName, expression);
                            setTextRange(expression, node);
                        }
                        if (temp) {
                            noSubstitution[getNodeId(expression)] = true;
                            expression = factory2.createComma(expression, temp);
                            setTextRange(expression, node);
                        }
                        return expression;
                    }
                }
                return visitEachChild(node, visitor, context);
            }
            function visitImportCallExpression(node) {
                if (moduleKind === 0 /* None */ && languageVersion >= 7 /* ES2020 */) {
                    return visitEachChild(node, visitor, context);
                }
                const externalModuleName = getExternalModuleNameLiteral(factory2, node, currentSourceFile, host, resolver, compilerOptions);
                const firstArgument = visitNode(firstOrUndefined(node.arguments), visitor, isExpression);
                const argument = externalModuleName && (!firstArgument || !isStringLiteral(firstArgument) || firstArgument.text !== externalModuleName.text) ? externalModuleName : firstArgument;
                const containsLexicalThis = !!(node.transformFlags & 16384 /* ContainsLexicalThis */);
                switch (compilerOptions.module) {
                    case 2 /* AMD */:
                        return createImportCallExpressionAMD(argument, containsLexicalThis);
                    case 3 /* UMD */:
                        return createImportCallExpressionUMD(argument ?? factory2.createVoidZero(), containsLexicalThis);
                    case 1 /* CommonJS */:
                    default:
                        return createImportCallExpressionCommonJS(argument);
                }
            }
            function createImportCallExpressionUMD(arg, containsLexicalThis) {
                needUMDDynamicImportHelper = true;
                if (isSimpleCopiableExpression(arg)) {
                    const argClone = isGeneratedIdentifier(arg) ? arg : isStringLiteral(arg) ? factory2.createStringLiteralFromNode(arg) : setEmitFlags(setTextRange(factory2.cloneNode(arg), arg), 3072 /* NoComments */);
                    return factory2.createConditionalExpression(
                    /*condition*/
                    factory2.createIdentifier("__syncRequire"), 
                    /*questionToken*/
                    void 0, 
                    /*whenTrue*/
                    createImportCallExpressionCommonJS(arg), 
                    /*colonToken*/
                    void 0, 
                    /*whenFalse*/
                    createImportCallExpressionAMD(argClone, containsLexicalThis));
                }
                else {
                    const temp = factory2.createTempVariable(hoistVariableDeclaration);
                    return factory2.createComma(factory2.createAssignment(temp, arg), factory2.createConditionalExpression(
                    /*condition*/
                    factory2.createIdentifier("__syncRequire"), 
                    /*questionToken*/
                    void 0, 
                    /*whenTrue*/
                    createImportCallExpressionCommonJS(temp, 
                    /*isInlineable*/
                    true), 
                    /*colonToken*/
                    void 0, 
                    /*whenFalse*/
                    createImportCallExpressionAMD(temp, containsLexicalThis)));
                }
            }
            function createImportCallExpressionAMD(arg, containsLexicalThis) {
                const resolve = factory2.createUniqueName("resolve");
                const reject = factory2.createUniqueName("reject");
                const parameters = [
                    factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, 
                    /*name*/
                    resolve),
                    factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, 
                    /*name*/
                    reject)
                ];
                const body = factory2.createBlock([
                    factory2.createExpressionStatement(factory2.createCallExpression(factory2.createIdentifier("require"), 
                    /*typeArguments*/
                    void 0, [factory2.createArrayLiteralExpression([arg || factory2.createOmittedExpression()]), resolve, reject]))
                ]);
                let func;
                if (languageVersion >= 2 /* ES2015 */) {
                    func = factory2.createArrowFunction(
                    /*modifiers*/
                    void 0, 
                    /*typeParameters*/
                    void 0, parameters, 
                    /*type*/
                    void 0, 
                    /*equalsGreaterThanToken*/
                    void 0, body);
                }
                else {
                    func = factory2.createFunctionExpression(
                    /*modifiers*/
                    void 0, 
                    /*asteriskToken*/
                    void 0, 
                    /*name*/
                    void 0, 
                    /*typeParameters*/
                    void 0, parameters, 
                    /*type*/
                    void 0, body);
                    if (containsLexicalThis) {
                        setEmitFlags(func, 16 /* CapturesThis */);
                    }
                }
                const promise = factory2.createNewExpression(factory2.createIdentifier("Promise"), 
                /*typeArguments*/
                void 0, [func]);
                if (getESModuleInterop(compilerOptions)) {
                    return factory2.createCallExpression(factory2.createPropertyAccessExpression(promise, factory2.createIdentifier("then")), 
                    /*typeArguments*/
                    void 0, [emitHelpers().createImportStarCallbackHelper()]);
                }
                return promise;
            }
            function createImportCallExpressionCommonJS(arg, isInlineable) {
                const needSyncEval = arg && !isSimpleInlineableExpression(arg) && !isInlineable;
                const promiseResolveCall = factory2.createCallExpression(factory2.createPropertyAccessExpression(factory2.createIdentifier("Promise"), "resolve"), 
                /*typeArguments*/
                void 0, 
                /*argumentsArray*/
                needSyncEval ? languageVersion >= 2 /* ES2015 */ ? [
                    factory2.createTemplateExpression(factory2.createTemplateHead(""), [
                        factory2.createTemplateSpan(arg, factory2.createTemplateTail(""))
                    ])
                ] : [
                    factory2.createCallExpression(factory2.createPropertyAccessExpression(factory2.createStringLiteral(""), "concat"), 
                    /*typeArguments*/
                    void 0, [arg])
                ] : []);
                let requireCall = factory2.createCallExpression(factory2.createIdentifier("require"), 
                /*typeArguments*/
                void 0, needSyncEval ? [factory2.createIdentifier("s")] : arg ? [arg] : []);
                if (getESModuleInterop(compilerOptions)) {
                    requireCall = emitHelpers().createImportStarHelper(requireCall);
                }
                const parameters = needSyncEval ? [
                    factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, 
                    /*name*/
                    "s")
                ] : [];
                let func;
                if (languageVersion >= 2 /* ES2015 */) {
                    func = factory2.createArrowFunction(
                    /*modifiers*/
                    void 0, 
                    /*typeParameters*/
                    void 0, 
                    /*parameters*/
                    parameters, 
                    /*type*/
                    void 0, 
                    /*equalsGreaterThanToken*/
                    void 0, requireCall);
                }
                else {
                    func = factory2.createFunctionExpression(
                    /*modifiers*/
                    void 0, 
                    /*asteriskToken*/
                    void 0, 
                    /*name*/
                    void 0, 
                    /*typeParameters*/
                    void 0, 
                    /*parameters*/
                    parameters, 
                    /*type*/
                    void 0, factory2.createBlock([factory2.createReturnStatement(requireCall)]));
                }
                const downleveledImport = factory2.createCallExpression(factory2.createPropertyAccessExpression(promiseResolveCall, "then"), 
                /*typeArguments*/
                void 0, [func]);
                return downleveledImport;
            }
            function getHelperExpressionForExport(node, innerExpr) {
                if (!getESModuleInterop(compilerOptions) || getInternalEmitFlags(node) & 2 /* NeverApplyImportHelper */) {
                    return innerExpr;
                }
                if (getExportNeedsImportStarHelper(node)) {
                    return emitHelpers().createImportStarHelper(innerExpr);
                }
                return innerExpr;
            }
            function getHelperExpressionForImport(node, innerExpr) {
                if (!getESModuleInterop(compilerOptions) || getInternalEmitFlags(node) & 2 /* NeverApplyImportHelper */) {
                    return innerExpr;
                }
                if (getImportNeedsImportStarHelper(node)) {
                    return emitHelpers().createImportStarHelper(innerExpr);
                }
                if (getImportNeedsImportDefaultHelper(node)) {
                    return emitHelpers().createImportDefaultHelper(innerExpr);
                }
                return innerExpr;
            }
            function visitTopLevelImportDeclaration(node) {
                let statements;
                const namespaceDeclaration = getNamespaceDeclarationNode(node);
                if (moduleKind !== 2 /* AMD */) {
                    if (!node.importClause) {
                        return setOriginalNode(setTextRange(factory2.createExpressionStatement(createRequireCall2(node)), node), node);
                    }
                    else {
                        const variables = [];
                        if (namespaceDeclaration && !isDefaultImport(node)) {
                            variables.push(factory2.createVariableDeclaration(factory2.cloneNode(namespaceDeclaration.name), 
                            /*exclamationToken*/
                            void 0, 
                            /*type*/
                            void 0, getHelperExpressionForImport(node, createRequireCall2(node))));
                        }
                        else {
                            variables.push(factory2.createVariableDeclaration(factory2.getGeneratedNameForNode(node), 
                            /*exclamationToken*/
                            void 0, 
                            /*type*/
                            void 0, getHelperExpressionForImport(node, createRequireCall2(node))));
                            if (namespaceDeclaration && isDefaultImport(node)) {
                                variables.push(factory2.createVariableDeclaration(factory2.cloneNode(namespaceDeclaration.name), 
                                /*exclamationToken*/
                                void 0, 
                                /*type*/
                                void 0, factory2.getGeneratedNameForNode(node)));
                            }
                        }
                        statements = append(statements, setOriginalNode(setTextRange(factory2.createVariableStatement(
                        /*modifiers*/
                        void 0, factory2.createVariableDeclarationList(variables, languageVersion >= 2 /* ES2015 */ ? 2 /* Const */ : 0 /* None */)), 
                        /*location*/
                        node), 
                        /*original*/
                        node));
                    }
                }
                else if (namespaceDeclaration && isDefaultImport(node)) {
                    statements = append(statements, factory2.createVariableStatement(
                    /*modifiers*/
                    void 0, factory2.createVariableDeclarationList([
                        setOriginalNode(setTextRange(factory2.createVariableDeclaration(factory2.cloneNode(namespaceDeclaration.name), 
                        /*exclamationToken*/
                        void 0, 
                        /*type*/
                        void 0, factory2.getGeneratedNameForNode(node)), 
                        /*location*/
                        node), 
                        /*original*/
                        node)
                    ], languageVersion >= 2 /* ES2015 */ ? 2 /* Const */ : 0 /* None */)));
                }
                statements = appendExportsOfImportDeclaration(statements, node);
                return singleOrMany(statements);
            }
            function createRequireCall2(importNode) {
                const moduleName = getExternalModuleNameLiteral(factory2, importNode, currentSourceFile, host, resolver, compilerOptions);
                const args = [];
                if (moduleName) {
                    args.push(moduleName);
                }
                return factory2.createCallExpression(factory2.createIdentifier("require"), 
                /*typeArguments*/
                void 0, args);
            }
            function visitTopLevelImportEqualsDeclaration(node) {
                Debug.assert(isExternalModuleImportEqualsDeclaration(node), "import= for internal module references should be handled in an earlier transformer.");
                let statements;
                if (moduleKind !== 2 /* AMD */) {
                    if (hasSyntacticModifier(node, 32 /* Export */)) {
                        statements = append(statements, setOriginalNode(setTextRange(factory2.createExpressionStatement(createExportExpression(node.name, createRequireCall2(node))), node), node));
                    }
                    else {
                        statements = append(statements, setOriginalNode(setTextRange(factory2.createVariableStatement(
                        /*modifiers*/
                        void 0, factory2.createVariableDeclarationList([
                            factory2.createVariableDeclaration(factory2.cloneNode(node.name), 
                            /*exclamationToken*/
                            void 0, 
                            /*type*/
                            void 0, createRequireCall2(node))
                        ], 
                        /*flags*/
                        languageVersion >= 2 /* ES2015 */ ? 2 /* Const */ : 0 /* None */)), node), node));
                    }
                }
                else {
                    if (hasSyntacticModifier(node, 32 /* Export */)) {
                        statements = append(statements, setOriginalNode(setTextRange(factory2.createExpressionStatement(createExportExpression(factory2.getExportName(node), factory2.getLocalName(node))), node), node));
                    }
                }
                statements = appendExportsOfImportEqualsDeclaration(statements, node);
                return singleOrMany(statements);
            }
            function visitTopLevelExportDeclaration(node) {
                if (!node.moduleSpecifier) {
                    return void 0;
                }
                const generatedName = factory2.getGeneratedNameForNode(node);
                if (node.exportClause && isNamedExports(node.exportClause)) {
                    const statements = [];
                    if (moduleKind !== 2 /* AMD */) {
                        statements.push(setOriginalNode(setTextRange(factory2.createVariableStatement(
                        /*modifiers*/
                        void 0, factory2.createVariableDeclarationList([
                            factory2.createVariableDeclaration(generatedName, 
                            /*exclamationToken*/
                            void 0, 
                            /*type*/
                            void 0, createRequireCall2(node))
                        ])), 
                        /*location*/
                        node), 
                        /* original */
                        node));
                    }
                    for (const specifier of node.exportClause.elements) {
                        if (languageVersion === 0 /* ES3 */) {
                            statements.push(setOriginalNode(setTextRange(factory2.createExpressionStatement(emitHelpers().createCreateBindingHelper(generatedName, factory2.createStringLiteralFromNode(specifier.propertyName || specifier.name), specifier.propertyName ? factory2.createStringLiteralFromNode(specifier.name) : void 0)), specifier), specifier));
                        }
                        else {
                            const exportNeedsImportDefault = !!getESModuleInterop(compilerOptions) && !(getInternalEmitFlags(node) & 2 /* NeverApplyImportHelper */) && idText(specifier.propertyName || specifier.name) === "default";
                            const exportedValue = factory2.createPropertyAccessExpression(exportNeedsImportDefault ? emitHelpers().createImportDefaultHelper(generatedName) : generatedName, specifier.propertyName || specifier.name);
                            statements.push(setOriginalNode(setTextRange(factory2.createExpressionStatement(createExportExpression(factory2.getExportName(specifier), exportedValue, 
                            /*location*/
                            void 0, 
                            /*liveBinding*/
                            true)), specifier), specifier));
                        }
                    }
                    return singleOrMany(statements);
                }
                else if (node.exportClause) {
                    const statements = [];
                    statements.push(setOriginalNode(setTextRange(factory2.createExpressionStatement(createExportExpression(factory2.cloneNode(node.exportClause.name), getHelperExpressionForExport(node, moduleKind !== 2 /* AMD */ ? createRequireCall2(node) : isExportNamespaceAsDefaultDeclaration(node) ? generatedName : factory2.createIdentifier(idText(node.exportClause.name))))), node), node));
                    return singleOrMany(statements);
                }
                else {
                    return setOriginalNode(setTextRange(factory2.createExpressionStatement(emitHelpers().createExportStarHelper(moduleKind !== 2 /* AMD */ ? createRequireCall2(node) : generatedName)), node), node);
                }
            }
            function visitTopLevelExportAssignment(node) {
                if (node.isExportEquals) {
                    return void 0;
                }
                return createExportStatement(factory2.createIdentifier("default"), visitNode(node.expression, visitor, isExpression), 
                /*location*/
                node, 
                /*allowComments*/
                true);
            }
            function visitFunctionDeclaration(node) {
                let statements;
                if (hasSyntacticModifier(node, 32 /* Export */)) {
                    statements = append(statements, setOriginalNode(setTextRange(factory2.createFunctionDeclaration(visitNodes2(node.modifiers, modifierVisitor, isModifier), node.asteriskToken, factory2.getDeclarationName(node, 
                    /*allowComments*/
                    true, 
                    /*allowSourceMaps*/
                    true), 
                    /*typeParameters*/
                    void 0, visitNodes2(node.parameters, visitor, isParameter), 
                    /*type*/
                    void 0, visitEachChild(node.body, visitor, context)), 
                    /*location*/
                    node), 
                    /*original*/
                    node));
                }
                else {
                    statements = append(statements, visitEachChild(node, visitor, context));
                }
                statements = appendExportsOfHoistedDeclaration(statements, node);
                return singleOrMany(statements);
            }
            function visitClassDeclaration(node) {
                let statements;
                if (hasSyntacticModifier(node, 32 /* Export */)) {
                    statements = append(statements, setOriginalNode(setTextRange(factory2.createClassDeclaration(visitNodes2(node.modifiers, modifierVisitor, isModifierLike), factory2.getDeclarationName(node, 
                    /*allowComments*/
                    true, 
                    /*allowSourceMaps*/
                    true), 
                    /*typeParameters*/
                    void 0, visitNodes2(node.heritageClauses, visitor, isHeritageClause), visitNodes2(node.members, visitor, isClassElement)), node), node));
                }
                else {
                    statements = append(statements, visitEachChild(node, visitor, context));
                }
                statements = appendExportsOfHoistedDeclaration(statements, node);
                return singleOrMany(statements);
            }
            function visitVariableStatement(node) {
                let statements;
                let variables;
                let expressions;
                if (hasSyntacticModifier(node, 32 /* Export */)) {
                    let modifiers;
                    let removeCommentsOnExpressions = false;
                    for (const variable of node.declarationList.declarations) {
                        if (isIdentifier(variable.name) && isLocalName(variable.name)) {
                            if (!modifiers) {
                                modifiers = visitNodes2(node.modifiers, modifierVisitor, isModifier);
                            }
                            if (variable.initializer) {
                                const updatedVariable = factory2.updateVariableDeclaration(variable, variable.name, 
                                /*exclamationToken*/
                                void 0, 
                                /*type*/
                                void 0, createExportExpression(variable.name, visitNode(variable.initializer, visitor, isExpression)));
                                variables = append(variables, updatedVariable);
                            }
                            else {
                                variables = append(variables, variable);
                            }
                        }
                        else if (variable.initializer) {
                            if (!isBindingPattern(variable.name) && (isArrowFunction(variable.initializer) || isFunctionExpression(variable.initializer) || isClassExpression(variable.initializer))) {
                                const expression = factory2.createAssignment(setTextRange(factory2.createPropertyAccessExpression(factory2.createIdentifier("exports"), variable.name), 
                                /*location*/
                                variable.name), factory2.createIdentifier(getTextOfIdentifierOrLiteral(variable.name)));
                                const updatedVariable = factory2.createVariableDeclaration(variable.name, variable.exclamationToken, variable.type, visitNode(variable.initializer, visitor, isExpression));
                                variables = append(variables, updatedVariable);
                                expressions = append(expressions, expression);
                                removeCommentsOnExpressions = true;
                            }
                            else {
                                expressions = append(expressions, transformInitializedVariable(variable));
                            }
                        }
                    }
                    if (variables) {
                        statements = append(statements, factory2.updateVariableStatement(node, modifiers, factory2.updateVariableDeclarationList(node.declarationList, variables)));
                    }
                    if (expressions) {
                        const statement = setOriginalNode(setTextRange(factory2.createExpressionStatement(factory2.inlineExpressions(expressions)), node), node);
                        if (removeCommentsOnExpressions) {
                            removeAllComments(statement);
                        }
                        statements = append(statements, statement);
                    }
                }
                else {
                    statements = append(statements, visitEachChild(node, visitor, context));
                }
                statements = appendExportsOfVariableStatement(statements, node);
                return singleOrMany(statements);
            }
            function createAllExportExpressions(name, value, location) {
                const exportedNames = getExports(name);
                if (exportedNames) {
                    let expression = isExportName(name) ? value : factory2.createAssignment(name, value);
                    for (const exportName of exportedNames) {
                        setEmitFlags(expression, 8 /* NoSubstitution */);
                        expression = createExportExpression(exportName, expression, 
                        /*location*/
                        location);
                    }
                    return expression;
                }
                return factory2.createAssignment(name, value);
            }
            function transformInitializedVariable(node) {
                if (isBindingPattern(node.name)) {
                    return flattenDestructuringAssignment(visitNode(node, visitor, isInitializedVariable), visitor, context, 0 /* All */, 
                    /*needsValue*/
                    false, createAllExportExpressions);
                }
                else {
                    return factory2.createAssignment(setTextRange(factory2.createPropertyAccessExpression(factory2.createIdentifier("exports"), node.name), 
                    /*location*/
                    node.name), node.initializer ? visitNode(node.initializer, visitor, isExpression) : factory2.createVoidZero());
                }
            }
            function appendExportsOfImportDeclaration(statements, decl) {
                if (currentModuleInfo.exportEquals) {
                    return statements;
                }
                const importClause = decl.importClause;
                if (!importClause) {
                    return statements;
                }
                const seen = new IdentifierNameMap();
                if (importClause.name) {
                    statements = appendExportsOfDeclaration(statements, seen, importClause);
                }
                const namedBindings = importClause.namedBindings;
                if (namedBindings) {
                    switch (namedBindings.kind) {
                        case 274 /* NamespaceImport */:
                            statements = appendExportsOfDeclaration(statements, seen, namedBindings);
                            break;
                        case 275 /* NamedImports */:
                            for (const importBinding of namedBindings.elements) {
                                statements = appendExportsOfDeclaration(statements, seen, importBinding, 
                                /*liveBinding*/
                                true);
                            }
                            break;
                    }
                }
                return statements;
            }
            function appendExportsOfImportEqualsDeclaration(statements, decl) {
                if (currentModuleInfo.exportEquals) {
                    return statements;
                }
                return appendExportsOfDeclaration(statements, new IdentifierNameMap(), decl);
            }
            function appendExportsOfVariableStatement(statements, node) {
                return appendExportsOfVariableDeclarationList(statements, node.declarationList, 
                /*isForInOrOfInitializer*/
                false);
            }
            function appendExportsOfVariableDeclarationList(statements, node, isForInOrOfInitializer) {
                if (currentModuleInfo.exportEquals) {
                    return statements;
                }
                for (const decl of node.declarations) {
                    statements = appendExportsOfBindingElement(statements, decl, isForInOrOfInitializer);
                }
                return statements;
            }
            function appendExportsOfBindingElement(statements, decl, isForInOrOfInitializer) {
                if (currentModuleInfo.exportEquals) {
                    return statements;
                }
                if (isBindingPattern(decl.name)) {
                    for (const element of decl.name.elements) {
                        if (!isOmittedExpression(element)) {
                            statements = appendExportsOfBindingElement(statements, element, isForInOrOfInitializer);
                        }
                    }
                }
                else if (!isGeneratedIdentifier(decl.name) && (!isVariableDeclaration(decl) || decl.initializer || isForInOrOfInitializer)) {
                    statements = appendExportsOfDeclaration(statements, new IdentifierNameMap(), decl);
                }
                return statements;
            }
            function appendExportsOfHoistedDeclaration(statements, decl) {
                if (currentModuleInfo.exportEquals) {
                    return statements;
                }
                const seen = new IdentifierNameMap();
                if (hasSyntacticModifier(decl, 32 /* Export */)) {
                    const exportName = hasSyntacticModifier(decl, 2048 /* Default */) ? factory2.createIdentifier("default") : factory2.getDeclarationName(decl);
                    statements = appendExportStatement(statements, seen, exportName, factory2.getLocalName(decl), 
                    /*location*/
                    decl);
                }
                if (decl.name) {
                    statements = appendExportsOfDeclaration(statements, seen, decl);
                }
                return statements;
            }
            function appendExportsOfDeclaration(statements, seen, decl, liveBinding) {
                const name = factory2.getDeclarationName(decl);
                const exportSpecifiers = currentModuleInfo.exportSpecifiers.get(name);
                if (exportSpecifiers) {
                    for (const exportSpecifier of exportSpecifiers) {
                        statements = appendExportStatement(statements, seen, exportSpecifier.name, name, 
                        /*location*/
                        exportSpecifier.name, 
                        /*allowComments*/
                        void 0, liveBinding);
                    }
                }
                return statements;
            }
            function appendExportStatement(statements, seen, exportName, expression, location, allowComments, liveBinding) {
                if (!seen.has(exportName)) {
                    seen.set(exportName, true);
                    statements = append(statements, createExportStatement(exportName, expression, location, allowComments, liveBinding));
                }
                return statements;
            }
            function createUnderscoreUnderscoreESModule() {
                let statement;
                if (languageVersion === 0 /* ES3 */) {
                    statement = factory2.createExpressionStatement(createExportExpression(factory2.createIdentifier("__esModule"), factory2.createTrue()));
                }
                else {
                    statement = factory2.createExpressionStatement(factory2.createCallExpression(factory2.createPropertyAccessExpression(factory2.createIdentifier("Object"), "defineProperty"), 
                    /*typeArguments*/
                    void 0, [
                        factory2.createIdentifier("exports"),
                        factory2.createStringLiteral("__esModule"),
                        factory2.createObjectLiteralExpression([
                            factory2.createPropertyAssignment("value", factory2.createTrue())
                        ])
                    ]));
                }
                setEmitFlags(statement, 2097152 /* CustomPrologue */);
                return statement;
            }
            function createExportStatement(name, value, location, allowComments, liveBinding) {
                const statement = setTextRange(factory2.createExpressionStatement(createExportExpression(name, value, 
                /*location*/
                void 0, liveBinding)), location);
                startOnNewLine(statement);
                if (!allowComments) {
                    setEmitFlags(statement, 3072 /* NoComments */);
                }
                return statement;
            }
            function createExportExpression(name, value, location, liveBinding) {
                return setTextRange(liveBinding && languageVersion !== 0 /* ES3 */ ? factory2.createCallExpression(factory2.createPropertyAccessExpression(factory2.createIdentifier("Object"), "defineProperty"), 
                /*typeArguments*/
                void 0, [
                    factory2.createIdentifier("exports"),
                    factory2.createStringLiteralFromNode(name),
                    factory2.createObjectLiteralExpression([
                        factory2.createPropertyAssignment("enumerable", factory2.createTrue()),
                        factory2.createPropertyAssignment("get", factory2.createFunctionExpression(
                        /*modifiers*/
                        void 0, 
                        /*asteriskToken*/
                        void 0, 
                        /*name*/
                        void 0, 
                        /*typeParameters*/
                        void 0, 
                        /*parameters*/
                        [], 
                        /*type*/
                        void 0, factory2.createBlock([factory2.createReturnStatement(value)])))
                    ])
                ]) : factory2.createAssignment(factory2.createPropertyAccessExpression(factory2.createIdentifier("exports"), factory2.cloneNode(name)), value), location);
            }
            function modifierVisitor(node) {
                switch (node.kind) {
                    case 95 /* ExportKeyword */:
                    case 90 /* DefaultKeyword */:
                        return void 0;
                }
                return node;
            }
            function onEmitNode(hint, node, emitCallback) {
                if (node.kind === 312 /* SourceFile */) {
                    currentSourceFile = node;
                    currentModuleInfo = moduleInfoMap[getOriginalNodeId(currentSourceFile)];
                    previousOnEmitNode(hint, node, emitCallback);
                    currentSourceFile = void 0;
                    currentModuleInfo = void 0;
                }
                else {
                    previousOnEmitNode(hint, node, emitCallback);
                }
            }
            function onSubstituteNode(hint, node) {
                node = previousOnSubstituteNode(hint, node);
                if (node.id && noSubstitution[node.id]) {
                    return node;
                }
                if (hint === 1 /* Expression */) {
                    return substituteExpression(node);
                }
                else if (isShorthandPropertyAssignment(node)) {
                    return substituteShorthandPropertyAssignment(node);
                }
                return node;
            }
            function substituteShorthandPropertyAssignment(node) {
                const name = node.name;
                const exportedOrImportedName = substituteExpressionIdentifier(name);
                if (exportedOrImportedName !== name) {
                    if (node.objectAssignmentInitializer) {
                        const initializer = factory2.createAssignment(exportedOrImportedName, node.objectAssignmentInitializer);
                        return setTextRange(factory2.createPropertyAssignment(name, initializer), node);
                    }
                    return setTextRange(factory2.createPropertyAssignment(name, exportedOrImportedName), node);
                }
                return node;
            }
            function substituteExpression(node) {
                switch (node.kind) {
                    case 80 /* Identifier */:
                        return substituteExpressionIdentifier(node);
                    case 213 /* CallExpression */:
                        return substituteCallExpression(node);
                    case 215 /* TaggedTemplateExpression */:
                        return substituteTaggedTemplateExpression(node);
                    case 226 /* BinaryExpression */:
                        return substituteBinaryExpression(node);
                }
                return node;
            }
            function substituteCallExpression(node) {
                if (isIdentifier(node.expression)) {
                    const expression = substituteExpressionIdentifier(node.expression);
                    noSubstitution[getNodeId(expression)] = true;
                    if (!isIdentifier(expression) && !(getEmitFlags(node.expression) & 8192 /* HelperName */)) {
                        return addInternalEmitFlags(factory2.updateCallExpression(node, expression, 
                        /*typeArguments*/
                        void 0, node.arguments), 16 /* IndirectCall */);
                    }
                }
                return node;
            }
            function substituteTaggedTemplateExpression(node) {
                if (isIdentifier(node.tag)) {
                    const tag = substituteExpressionIdentifier(node.tag);
                    noSubstitution[getNodeId(tag)] = true;
                    if (!isIdentifier(tag) && !(getEmitFlags(node.tag) & 8192 /* HelperName */)) {
                        return addInternalEmitFlags(factory2.updateTaggedTemplateExpression(node, tag, 
                        /*typeArguments*/
                        void 0, node.template), 16 /* IndirectCall */);
                    }
                }
                return node;
            }
            function substituteExpressionIdentifier(node) {
                var _a, _b;
                if (getEmitFlags(node) & 8192 /* HelperName */) {
                    const externalHelpersModuleName = getExternalHelpersModuleName(currentSourceFile);
                    if (externalHelpersModuleName) {
                        return factory2.createPropertyAccessExpression(externalHelpersModuleName, node);
                    }
                    return node;
                }
                else if (!(isGeneratedIdentifier(node) && !(node.emitNode.autoGenerate.flags & 64 /* AllowNameSubstitution */)) && !isLocalName(node)) {
                    const exportContainer = resolver.getReferencedExportContainer(node, isExportName(node));
                    if (exportContainer && exportContainer.kind === 312 /* SourceFile */) {
                        return setTextRange(factory2.createPropertyAccessExpression(factory2.createIdentifier("exports"), factory2.cloneNode(node)), 
                        /*location*/
                        node);
                    }
                    const importDeclaration = resolver.getReferencedImportDeclaration(node);
                    if (importDeclaration) {
                        if (isImportClause(importDeclaration)) {
                            return setTextRange(factory2.createPropertyAccessExpression(factory2.getGeneratedNameForNode(importDeclaration.parent), factory2.createIdentifier("default")), 
                            /*location*/
                            node);
                        }
                        else if (isImportSpecifier(importDeclaration)) {
                            const name = importDeclaration.propertyName || importDeclaration.name;
                            return setTextRange(factory2.createPropertyAccessExpression(factory2.getGeneratedNameForNode(((_b = (_a = importDeclaration.parent) == null ? void 0 : _a.parent) == null ? void 0 : _b.parent) || importDeclaration), factory2.cloneNode(name)), 
                            /*location*/
                            node);
                        }
                    }
                }
                return node;
            }
            function substituteBinaryExpression(node) {
                if (isAssignmentOperator(node.operatorToken.kind) && isIdentifier(node.left) && (!isGeneratedIdentifier(node.left) || isFileLevelReservedGeneratedIdentifier(node.left)) && !isLocalName(node.left)) {
                    const exportedNames = getExports(node.left);
                    if (exportedNames) {
                        let expression = node;
                        for (const exportName of exportedNames) {
                            noSubstitution[getNodeId(expression)] = true;
                            expression = createExportExpression(exportName, expression, 
                            /*location*/
                            node);
                        }
                        return expression;
                    }
                }
                return node;
            }
            function getExports(name) {
                if (!isGeneratedIdentifier(name)) {
                    const importDeclaration = resolver.getReferencedImportDeclaration(name);
                    if (importDeclaration) {
                        return currentModuleInfo == null ? void 0 : currentModuleInfo.exportedBindings[getOriginalNodeId(importDeclaration)];
                    }
                    const bindingsSet = /* @__PURE__ */ new Set();
                    const declarations = resolver.getReferencedValueDeclarations(name);
                    if (declarations) {
                        for (const declaration of declarations) {
                            const bindings = currentModuleInfo == null ? void 0 : currentModuleInfo.exportedBindings[getOriginalNodeId(declaration)];
                            if (bindings) {
                                for (const binding of bindings) {
                                    bindingsSet.add(binding);
                                }
                            }
                        }
                        if (bindingsSet.size) {
                            return arrayFrom(bindingsSet);
                        }
                    }
                }
                else if (isFileLevelReservedGeneratedIdentifier(name)) {
                    const exportSpecifiers = currentModuleInfo == null ? void 0 : currentModuleInfo.exportSpecifiers.get(name);
                    if (exportSpecifiers) {
                        const exportedNames = [];
                        for (const exportSpecifier of exportSpecifiers) {
                            exportedNames.push(exportSpecifier.name);
                        }
                        return exportedNames;
                    }
                }
            }
        }
        var dynamicImportUMDHelper;
        var init_module = __esm({
            "src/compiler/transformers/module/module.ts"() {
                "use strict";
                init_ts2();
                dynamicImportUMDHelper = {
                    name: "typescript:dynamicimport-sync-require",
                    scoped: true,
                    text: `
            var __syncRequire = typeof module === "object" && typeof module.exports === "object";`
                };
            }
        });
        // src/compiler/transformers/module/system.ts
        function transformSystemModule(context) {
            const { factory: factory2, startLexicalEnvironment, endLexicalEnvironment, hoistVariableDeclaration } = context;
            const compilerOptions = context.getCompilerOptions();
            const resolver = context.getEmitResolver();
            const host = context.getEmitHost();
            const previousOnSubstituteNode = context.onSubstituteNode;
            const previousOnEmitNode = context.onEmitNode;
            context.onSubstituteNode = onSubstituteNode;
            context.onEmitNode = onEmitNode;
            context.enableSubstitution(80 /* Identifier */);
            context.enableSubstitution(304 /* ShorthandPropertyAssignment */);
            context.enableSubstitution(226 /* BinaryExpression */);
            context.enableSubstitution(236 /* MetaProperty */);
            context.enableEmitNotification(312 /* SourceFile */);
            const moduleInfoMap = [];
            const exportFunctionsMap = [];
            const noSubstitutionMap = [];
            const contextObjectMap = [];
            let currentSourceFile;
            let moduleInfo;
            let exportFunction;
            let contextObject;
            let hoistedStatements;
            let enclosingBlockScopedContainer;
            let noSubstitution;
            return chainBundle(context, transformSourceFile);
            function transformSourceFile(node) {
                if (node.isDeclarationFile || !(isEffectiveExternalModule(node, compilerOptions) || node.transformFlags & 8388608 /* ContainsDynamicImport */)) {
                    return node;
                }
                const id = getOriginalNodeId(node);
                currentSourceFile = node;
                enclosingBlockScopedContainer = node;
                moduleInfo = moduleInfoMap[id] = collectExternalModuleInfo(context, node);
                exportFunction = factory2.createUniqueName("exports");
                exportFunctionsMap[id] = exportFunction;
                contextObject = contextObjectMap[id] = factory2.createUniqueName("context");
                const dependencyGroups = collectDependencyGroups(moduleInfo.externalImports);
                const moduleBodyBlock = createSystemModuleBody(node, dependencyGroups);
                const moduleBodyFunction = factory2.createFunctionExpression(
                /*modifiers*/
                void 0, 
                /*asteriskToken*/
                void 0, 
                /*name*/
                void 0, 
                /*typeParameters*/
                void 0, [
                    factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, exportFunction),
                    factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, contextObject)
                ], 
                /*type*/
                void 0, moduleBodyBlock);
                const moduleName = tryGetModuleNameFromFile(factory2, node, host, compilerOptions);
                const dependencies = factory2.createArrayLiteralExpression(map(dependencyGroups, (dependencyGroup) => dependencyGroup.name));
                const updated = setEmitFlags(factory2.updateSourceFile(node, setTextRange(factory2.createNodeArray([
                    factory2.createExpressionStatement(factory2.createCallExpression(factory2.createPropertyAccessExpression(factory2.createIdentifier("System"), "register"), 
                    /*typeArguments*/
                    void 0, moduleName ? [moduleName, dependencies, moduleBodyFunction] : [dependencies, moduleBodyFunction]))
                ]), node.statements)), 2048 /* NoTrailingComments */);
                if (!outFile(compilerOptions)) {
                    moveEmitHelpers(updated, moduleBodyBlock, (helper) => !helper.scoped);
                }
                if (noSubstitution) {
                    noSubstitutionMap[id] = noSubstitution;
                    noSubstitution = void 0;
                }
                currentSourceFile = void 0;
                moduleInfo = void 0;
                exportFunction = void 0;
                contextObject = void 0;
                hoistedStatements = void 0;
                enclosingBlockScopedContainer = void 0;
                return updated;
            }
            function collectDependencyGroups(externalImports) {
                const groupIndices = /* @__PURE__ */ new Map();
                const dependencyGroups = [];
                for (const externalImport of externalImports) {
                    const externalModuleName = getExternalModuleNameLiteral(factory2, externalImport, currentSourceFile, host, resolver, compilerOptions);
                    if (externalModuleName) {
                        const text = externalModuleName.text;
                        const groupIndex = groupIndices.get(text);
                        if (groupIndex !== void 0) {
                            dependencyGroups[groupIndex].externalImports.push(externalImport);
                        }
                        else {
                            groupIndices.set(text, dependencyGroups.length);
                            dependencyGroups.push({
                                name: externalModuleName,
                                externalImports: [externalImport]
                            });
                        }
                    }
                }
                return dependencyGroups;
            }
            function createSystemModuleBody(node, dependencyGroups) {
                const statements = [];
                startLexicalEnvironment();
                const ensureUseStrict = getStrictOptionValue(compilerOptions, "alwaysStrict") || !compilerOptions.noImplicitUseStrict && isExternalModule(currentSourceFile);
                const statementOffset = factory2.copyPrologue(node.statements, statements, ensureUseStrict, topLevelVisitor);
                statements.push(factory2.createVariableStatement(
                /*modifiers*/
                void 0, factory2.createVariableDeclarationList([
                    factory2.createVariableDeclaration("__moduleName", 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, factory2.createLogicalAnd(contextObject, factory2.createPropertyAccessExpression(contextObject, "id")))
                ])));
                visitNode(moduleInfo.externalHelpersImportDeclaration, topLevelVisitor, isStatement);
                const executeStatements = visitNodes2(node.statements, topLevelVisitor, isStatement, statementOffset);
                addRange(statements, hoistedStatements);
                insertStatementsAfterStandardPrologue(statements, endLexicalEnvironment());
                const exportStarFunction = addExportStarIfNeeded(statements);
                const modifiers = node.transformFlags & 2097152 /* ContainsAwait */ ? factory2.createModifiersFromModifierFlags(1024 /* Async */) : void 0;
                const moduleObject = factory2.createObjectLiteralExpression([
                    factory2.createPropertyAssignment("setters", createSettersArray(exportStarFunction, dependencyGroups)),
                    factory2.createPropertyAssignment("execute", factory2.createFunctionExpression(modifiers, 
                    /*asteriskToken*/
                    void 0, 
                    /*name*/
                    void 0, 
                    /*typeParameters*/
                    void 0, 
                    /*parameters*/
                    [], 
                    /*type*/
                    void 0, factory2.createBlock(executeStatements, 
                    /*multiLine*/
                    true)))
                ], 
                /*multiLine*/
                true);
                statements.push(factory2.createReturnStatement(moduleObject));
                return factory2.createBlock(statements, 
                /*multiLine*/
                true);
            }
            function addExportStarIfNeeded(statements) {
                if (!moduleInfo.hasExportStarsToExportValues) {
                    return;
                }
                if (!moduleInfo.exportedNames && moduleInfo.exportSpecifiers.size === 0) {
                    let hasExportDeclarationWithExportClause = false;
                    for (const externalImport of moduleInfo.externalImports) {
                        if (externalImport.kind === 278 /* ExportDeclaration */ && externalImport.exportClause) {
                            hasExportDeclarationWithExportClause = true;
                            break;
                        }
                    }
                    if (!hasExportDeclarationWithExportClause) {
                        const exportStarFunction2 = createExportStarFunction(
                        /*localNames*/
                        void 0);
                        statements.push(exportStarFunction2);
                        return exportStarFunction2.name;
                    }
                }
                const exportedNames = [];
                if (moduleInfo.exportedNames) {
                    for (const exportedLocalName of moduleInfo.exportedNames) {
                        if (exportedLocalName.escapedText === "default") {
                            continue;
                        }
                        exportedNames.push(factory2.createPropertyAssignment(factory2.createStringLiteralFromNode(exportedLocalName), factory2.createTrue()));
                    }
                }
                const exportedNamesStorageRef = factory2.createUniqueName("exportedNames");
                statements.push(factory2.createVariableStatement(
                /*modifiers*/
                void 0, factory2.createVariableDeclarationList([
                    factory2.createVariableDeclaration(exportedNamesStorageRef, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, factory2.createObjectLiteralExpression(exportedNames, 
                    /*multiLine*/
                    true))
                ])));
                const exportStarFunction = createExportStarFunction(exportedNamesStorageRef);
                statements.push(exportStarFunction);
                return exportStarFunction.name;
            }
            function createExportStarFunction(localNames) {
                const exportStarFunction = factory2.createUniqueName("exportStar");
                const m = factory2.createIdentifier("m");
                const n = factory2.createIdentifier("n");
                const exports = factory2.createIdentifier("exports");
                let condition = factory2.createStrictInequality(n, factory2.createStringLiteral("default"));
                if (localNames) {
                    condition = factory2.createLogicalAnd(condition, factory2.createLogicalNot(factory2.createCallExpression(factory2.createPropertyAccessExpression(localNames, "hasOwnProperty"), 
                    /*typeArguments*/
                    void 0, [n])));
                }
                return factory2.createFunctionDeclaration(
                /*modifiers*/
                void 0, 
                /*asteriskToken*/
                void 0, exportStarFunction, 
                /*typeParameters*/
                void 0, [factory2.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, m)], 
                /*type*/
                void 0, factory2.createBlock([
                    factory2.createVariableStatement(
                    /*modifiers*/
                    void 0, factory2.createVariableDeclarationList([
                        factory2.createVariableDeclaration(exports, 
                        /*exclamationToken*/
                        void 0, 
                        /*type*/
                        void 0, factory2.createObjectLiteralExpression([]))
                    ])),
                    factory2.createForInStatement(factory2.createVariableDeclarationList([
                        factory2.createVariableDeclaration(n)
                    ]), m, factory2.createBlock([
                        setEmitFlags(factory2.createIfStatement(condition, factory2.createExpressionStatement(factory2.createAssignment(factory2.createElementAccessExpression(exports, n), factory2.createElementAccessExpression(m, n)))), 1 /* SingleLine */)
                    ])),
                    factory2.createExpressionStatement(factory2.createCallExpression(exportFunction, 
                    /*typeArguments*/
                    void 0, [exports]))
                ], 
                /*multiLine*/
                true));
            }
            function createSettersArray(exportStarFunction, dependencyGroups) {
                const setters = [];
                for (const group2 of dependencyGroups) {
                    const localName = forEach(group2.externalImports, (i) => getLocalNameForExternalImport(factory2, i, currentSourceFile));
                    const parameterName = localName ? factory2.getGeneratedNameForNode(localName) : factory2.createUniqueName("");
                    const statements = [];
                    for (const entry of group2.externalImports) {
                        const importVariableName = getLocalNameForExternalImport(factory2, entry, currentSourceFile);
                        switch (entry.kind) {
                            case 272 /* ImportDeclaration */:
                                if (!entry.importClause) {
                                    break;
                                }
                            case 271 /* ImportEqualsDeclaration */:
                                Debug.assert(importVariableName !== void 0);
                                statements.push(factory2.createExpressionStatement(factory2.createAssignment(importVariableName, parameterName)));
                                if (hasSyntacticModifier(entry, 32 /* Export */)) {
                                    statements.push(factory2.createExpressionStatement(factory2.createCallExpression(exportFunction, 
                                    /*typeArguments*/
                                    void 0, [
                                        factory2.createStringLiteral(idText(importVariableName)),
                                        parameterName
                                    ])));
                                }
                                break;
                            case 278 /* ExportDeclaration */:
                                Debug.assert(importVariableName !== void 0);
                                if (entry.exportClause) {
                                    if (isNamedExports(entry.exportClause)) {
                                        const properties = [];
                                        for (const e of entry.exportClause.elements) {
                                            properties.push(factory2.createPropertyAssignment(factory2.createStringLiteral(idText(e.name)), factory2.createElementAccessExpression(parameterName, factory2.createStringLiteral(idText(e.propertyName || e.name)))));
                                        }
                                        statements.push(factory2.createExpressionStatement(factory2.createCallExpression(exportFunction, 
                                        /*typeArguments*/
                                        void 0, [factory2.createObjectLiteralExpression(properties, 
                                            /*multiLine*/
                                            true)])));
                                    }
                                    else {
                                        statements.push(factory2.createExpressionStatement(factory2.createCallExpression(exportFunction, 
                                        /*typeArguments*/
                                        void 0, [
                                            factory2.createStringLiteral(idText(entry.exportClause.name)),
                                            parameterName
                                        ])));
                                    }
                                }
                                else {
                                    statements.push(factory2.createExpressionStatement(factory2.createCallExpression(exportStarFunction, 
                                    /*typeArguments*/
                                    void 0, [parameterName])));
                                }
                                break;
                        }
                    }
                    setters.push(factory2.createFunctionExpression(
                    /*modifiers*/
                    void 0, 
                    /*asteriskToken*/
                    void 0, 
                    /*name*/
                    void 0, 
                    /*typeParameters*/
                    void 0, [factory2.createParameterDeclaration(
                        /*modifiers*/
                        void 0, 
                        /*dotDotDotToken*/
                        void 0, parameterName)], 
                    /*type*/
                    void 0, factory2.createBlock(statements, 
                    /*multiLine*/
                    true)));
                }
                return factory2.createArrayLiteralExpression(setters, 
                /*multiLine*/
                true);
            }
            function topLevelVisitor(node) {
                switch (node.kind) {
                    case 272 /* ImportDeclaration */:
                        return visitImportDeclaration(node);
                    case 271 /* ImportEqualsDeclaration */:
                        return visitImportEqualsDeclaration(node);
                    case 278 /* ExportDeclaration */:
                        return visitExportDeclaration(node);
                    case 277 /* ExportAssignment */:
                        return visitExportAssignment(node);
                    default:
                        return topLevelNestedVisitor(node);
                }
            }
            function visitImportDeclaration(node) {
                let statements;
                if (node.importClause) {
                    hoistVariableDeclaration(getLocalNameForExternalImport(factory2, node, currentSourceFile));
                }
                return singleOrMany(appendExportsOfImportDeclaration(statements, node));
            }
            function visitExportDeclaration(node) {
                Debug.assertIsDefined(node);
                return void 0;
            }
            function visitImportEqualsDeclaration(node) {
                Debug.assert(isExternalModuleImportEqualsDeclaration(node), "import= for internal module references should be handled in an earlier transformer.");
                let statements;
                hoistVariableDeclaration(getLocalNameForExternalImport(factory2, node, currentSourceFile));
                return singleOrMany(appendExportsOfImportEqualsDeclaration(statements, node));
            }
            function visitExportAssignment(node) {
                if (node.isExportEquals) {
                    return void 0;
                }
                const expression = visitNode(node.expression, visitor, isExpression);
                return createExportStatement(factory2.createIdentifier("default"), expression, 
                /*allowComments*/
                true);
            }
            function visitFunctionDeclaration(node) {
                if (hasSyntacticModifier(node, 32 /* Export */)) {
                    hoistedStatements = append(hoistedStatements, factory2.updateFunctionDeclaration(node, visitNodes2(node.modifiers, modifierVisitor, isModifierLike), node.asteriskToken, factory2.getDeclarationName(node, 
                    /*allowComments*/
                    true, 
                    /*allowSourceMaps*/
                    true), 
                    /*typeParameters*/
                    void 0, visitNodes2(node.parameters, visitor, isParameter), 
                    /*type*/
                    void 0, visitNode(node.body, visitor, isBlock)));
                }
                else {
                    hoistedStatements = append(hoistedStatements, visitEachChild(node, visitor, context));
                }
                hoistedStatements = appendExportsOfHoistedDeclaration(hoistedStatements, node);
                return void 0;
            }
            function visitClassDeclaration(node) {
                let statements;
                const name = factory2.getLocalName(node);
                hoistVariableDeclaration(name);
                statements = append(statements, setTextRange(factory2.createExpressionStatement(factory2.createAssignment(name, setTextRange(factory2.createClassExpression(visitNodes2(node.modifiers, modifierVisitor, isModifierLike), node.name, 
                /*typeParameters*/
                void 0, visitNodes2(node.heritageClauses, visitor, isHeritageClause), visitNodes2(node.members, visitor, isClassElement)), node))), node));
                statements = appendExportsOfHoistedDeclaration(statements, node);
                return singleOrMany(statements);
            }
            function visitVariableStatement(node) {
                if (!shouldHoistVariableDeclarationList(node.declarationList)) {
                    return visitNode(node, visitor, isStatement);
                }
                let statements;
                if (isVarUsing(node.declarationList) || isVarAwaitUsing(node.declarationList)) {
                    const modifiers = visitNodes2(node.modifiers, modifierVisitor, isModifierLike);
                    const declarations = [];
                    for (const variable of node.declarationList.declarations) {
                        declarations.push(factory2.updateVariableDeclaration(variable, factory2.getGeneratedNameForNode(variable.name), 
                        /*exclamationToken*/
                        void 0, 
                        /*type*/
                        void 0, transformInitializedVariable(variable, 
                        /*isExportedDeclaration*/
                        false)));
                    }
                    const declarationList = factory2.updateVariableDeclarationList(node.declarationList, declarations);
                    statements = append(statements, factory2.updateVariableStatement(node, modifiers, declarationList));
                }
                else {
                    let expressions;
                    const isExportedDeclaration = hasSyntacticModifier(node, 32 /* Export */);
                    for (const variable of node.declarationList.declarations) {
                        if (variable.initializer) {
                            expressions = append(expressions, transformInitializedVariable(variable, isExportedDeclaration));
                        }
                        else {
                            hoistBindingElement(variable);
                        }
                    }
                    if (expressions) {
                        statements = append(statements, setTextRange(factory2.createExpressionStatement(factory2.inlineExpressions(expressions)), node));
                    }
                }
                statements = appendExportsOfVariableStatement(statements, node, 
                /*exportSelf*/
                false);
                return singleOrMany(statements);
            }
            function hoistBindingElement(node) {
                if (isBindingPattern(node.name)) {
                    for (const element of node.name.elements) {
                        if (!isOmittedExpression(element)) {
                            hoistBindingElement(element);
                        }
                    }
                }
                else {
                    hoistVariableDeclaration(factory2.cloneNode(node.name));
                }
            }
            function shouldHoistVariableDeclarationList(node) {
                return (getEmitFlags(node) & 4194304 /* NoHoisting */) === 0 && (enclosingBlockScopedContainer.kind === 312 /* SourceFile */ || (getOriginalNode(node).flags & 7 /* BlockScoped */) === 0);
            }
            function transformInitializedVariable(node, isExportedDeclaration) {
                const createAssignment = isExportedDeclaration ? createExportedVariableAssignment : createNonExportedVariableAssignment;
                return isBindingPattern(node.name) ? flattenDestructuringAssignment(node, visitor, context, 0 /* All */, 
                /*needsValue*/
                false, createAssignment) : node.initializer ? createAssignment(node.name, visitNode(node.initializer, visitor, isExpression)) : node.name;
            }
            function createExportedVariableAssignment(name, value, location) {
                return createVariableAssignment(name, value, location, 
                /*isExportedDeclaration*/
                true);
            }
            function createNonExportedVariableAssignment(name, value, location) {
                return createVariableAssignment(name, value, location, 
                /*isExportedDeclaration*/
                false);
            }
            function createVariableAssignment(name, value, location, isExportedDeclaration) {
                hoistVariableDeclaration(factory2.cloneNode(name));
                return isExportedDeclaration ? createExportExpression(name, preventSubstitution(setTextRange(factory2.createAssignment(name, value), location))) : preventSubstitution(setTextRange(factory2.createAssignment(name, value), location));
            }
            function appendExportsOfImportDeclaration(statements, decl) {
                if (moduleInfo.exportEquals) {
                    return statements;
                }
                const importClause = decl.importClause;
                if (!importClause) {
                    return statements;
                }
                if (importClause.name) {
                    statements = appendExportsOfDeclaration(statements, importClause);
                }
                const namedBindings = importClause.namedBindings;
                if (namedBindings) {
                    switch (namedBindings.kind) {
                        case 274 /* NamespaceImport */:
                            statements = appendExportsOfDeclaration(statements, namedBindings);
                            break;
                        case 275 /* NamedImports */:
                            for (const importBinding of namedBindings.elements) {
                                statements = appendExportsOfDeclaration(statements, importBinding);
                            }
                            break;
                    }
                }
                return statements;
            }
            function appendExportsOfImportEqualsDeclaration(statements, decl) {
                if (moduleInfo.exportEquals) {
                    return statements;
                }
                return appendExportsOfDeclaration(statements, decl);
            }
            function appendExportsOfVariableStatement(statements, node, exportSelf) {
                if (moduleInfo.exportEquals) {
                    return statements;
                }
                for (const decl of node.declarationList.declarations) {
                    if (decl.initializer || exportSelf) {
                        statements = appendExportsOfBindingElement(statements, decl, exportSelf);
                    }
                }
                return statements;
            }
            function appendExportsOfBindingElement(statements, decl, exportSelf) {
                if (moduleInfo.exportEquals) {
                    return statements;
                }
                if (isBindingPattern(decl.name)) {
                    for (const element of decl.name.elements) {
                        if (!isOmittedExpression(element)) {
                            statements = appendExportsOfBindingElement(statements, element, exportSelf);
                        }
                    }
                }
                else if (!isGeneratedIdentifier(decl.name)) {
                    let excludeName;
                    if (exportSelf) {
                        statements = appendExportStatement(statements, decl.name, factory2.getLocalName(decl));
                        excludeName = idText(decl.name);
                    }
                    statements = appendExportsOfDeclaration(statements, decl, excludeName);
                }
                return statements;
            }
            function appendExportsOfHoistedDeclaration(statements, decl) {
                if (moduleInfo.exportEquals) {
                    return statements;
                }
                let excludeName;
                if (hasSyntacticModifier(decl, 32 /* Export */)) {
                    const exportName = hasSyntacticModifier(decl, 2048 /* Default */) ? factory2.createStringLiteral("default") : decl.name;
                    statements = appendExportStatement(statements, exportName, factory2.getLocalName(decl));
                    excludeName = getTextOfIdentifierOrLiteral(exportName);
                }
                if (decl.name) {
                    statements = appendExportsOfDeclaration(statements, decl, excludeName);
                }
                return statements;
            }
            function appendExportsOfDeclaration(statements, decl, excludeName) {
                if (moduleInfo.exportEquals) {
                    return statements;
                }
                const name = factory2.getDeclarationName(decl);
                const exportSpecifiers = moduleInfo.exportSpecifiers.get(name);
                if (exportSpecifiers) {
                    for (const exportSpecifier of exportSpecifiers) {
                        if (exportSpecifier.name.escapedText !== excludeName) {
                            statements = appendExportStatement(statements, exportSpecifier.name, name);
                        }
                    }
                }
                return statements;
            }
            function appendExportStatement(statements, exportName, expression, allowComments) {
                statements = append(statements, createExportStatement(exportName, expression, allowComments));
                return statements;
            }
            function createExportStatement(name, value, allowComments) {
                const statement = factory2.createExpressionStatement(createExportExpression(name, value));
                startOnNewLine(statement);
                if (!allowComments) {
                    setEmitFlags(statement, 3072 /* NoComments */);
                }
                return statement;
            }
            function createExportExpression(name, value) {
                const exportName = isIdentifier(name) ? factory2.createStringLiteralFromNode(name) : name;
                setEmitFlags(value, getEmitFlags(value) | 3072 /* NoComments */);
                return setCommentRange(factory2.createCallExpression(exportFunction, 
                /*typeArguments*/
                void 0, [exportName, value]), value);
            }
            function topLevelNestedVisitor(node) {
                switch (node.kind) {
                    case 243 /* VariableStatement */:
                        return visitVariableStatement(node);
                    case 262 /* FunctionDeclaration */:
                        return visitFunctionDeclaration(node);
                    case 263 /* ClassDeclaration */:
                        return visitClassDeclaration(node);
                    case 248 /* ForStatement */:
                        return visitForStatement(node, 
                        /*isTopLevel*/
                        true);
                    case 249 /* ForInStatement */:
                        return visitForInStatement(node);
                    case 250 /* ForOfStatement */:
                        return visitForOfStatement(node);
                    case 246 /* DoStatement */:
                        return visitDoStatement(node);
                    case 247 /* WhileStatement */:
                        return visitWhileStatement(node);
                    case 256 /* LabeledStatement */:
                        return visitLabeledStatement(node);
                    case 254 /* WithStatement */:
                        return visitWithStatement(node);
                    case 245 /* IfStatement */:
                        return visitIfStatement(node);
                    case 255 /* SwitchStatement */:
                        return visitSwitchStatement(node);
                    case 269 /* CaseBlock */:
                        return visitCaseBlock(node);
                    case 296 /* CaseClause */:
                        return visitCaseClause(node);
                    case 297 /* DefaultClause */:
                        return visitDefaultClause(node);
                    case 258 /* TryStatement */:
                        return visitTryStatement(node);
                    case 299 /* CatchClause */:
                        return visitCatchClause(node);
                    case 241 /* Block */:
                        return visitBlock(node);
                    default:
                        return visitor(node);
                }
            }
            function visitForStatement(node, isTopLevel) {
                const savedEnclosingBlockScopedContainer = enclosingBlockScopedContainer;
                enclosingBlockScopedContainer = node;
                node = factory2.updateForStatement(node, visitNode(node.initializer, isTopLevel ? visitForInitializer : discardedValueVisitor, isForInitializer), visitNode(node.condition, visitor, isExpression), visitNode(node.incrementor, discardedValueVisitor, isExpression), visitIterationBody(node.statement, isTopLevel ? topLevelNestedVisitor : visitor, context));
                enclosingBlockScopedContainer = savedEnclosingBlockScopedContainer;
                return node;
            }
            function visitForInStatement(node) {
                const savedEnclosingBlockScopedContainer = enclosingBlockScopedContainer;
                enclosingBlockScopedContainer = node;
                node = factory2.updateForInStatement(node, visitForInitializer(node.initializer), visitNode(node.expression, visitor, isExpression), visitIterationBody(node.statement, topLevelNestedVisitor, context));
                enclosingBlockScopedContainer = savedEnclosingBlockScopedContainer;
                return node;
            }
            function visitForOfStatement(node) {
                const savedEnclosingBlockScopedContainer = enclosingBlockScopedContainer;
                enclosingBlockScopedContainer = node;
                node = factory2.updateForOfStatement(node, node.awaitModifier, visitForInitializer(node.initializer), visitNode(node.expression, visitor, isExpression), visitIterationBody(node.statement, topLevelNestedVisitor, context));
                enclosingBlockScopedContainer = savedEnclosingBlockScopedContainer;
                return node;
            }
            function shouldHoistForInitializer(node) {
                return isVariableDeclarationList(node) && shouldHoistVariableDeclarationList(node);
            }
            function visitForInitializer(node) {
                if (shouldHoistForInitializer(node)) {
                    let expressions;
                    for (const variable of node.declarations) {
                        expressions = append(expressions, transformInitializedVariable(variable, 
                        /*isExportedDeclaration*/
                        false));
                        if (!variable.initializer) {
                            hoistBindingElement(variable);
                        }
                    }
                    return expressions ? factory2.inlineExpressions(expressions) : factory2.createOmittedExpression();
                }
                else {
                    return visitNode(node, discardedValueVisitor, isForInitializer);
                }
            }
            function visitDoStatement(node) {
                return factory2.updateDoStatement(node, visitIterationBody(node.statement, topLevelNestedVisitor, context), visitNode(node.expression, visitor, isExpression));
            }
            function visitWhileStatement(node) {
                return factory2.updateWhileStatement(node, visitNode(node.expression, visitor, isExpression), visitIterationBody(node.statement, topLevelNestedVisitor, context));
            }
            function visitLabeledStatement(node) {
                return factory2.updateLabeledStatement(node, node.label, Debug.checkDefined(visitNode(node.statement, topLevelNestedVisitor, isStatement, factory2.liftToBlock)));
            }
            function visitWithStatement(node) {
                return factory2.updateWithStatement(node, visitNode(node.expression, visitor, isExpression), Debug.checkDefined(visitNode(node.statement, topLevelNestedVisitor, isStatement, factory2.liftToBlock)));
            }
            function visitIfStatement(node) {
                return factory2.updateIfStatement(node, visitNode(node.expression, visitor, isExpression), Debug.checkDefined(visitNode(node.thenStatement, topLevelNestedVisitor, isStatement, factory2.liftToBlock)), visitNode(node.elseStatement, topLevelNestedVisitor, isStatement, factory2.liftToBlock));
            }
            function visitSwitchStatement(node) {
                return factory2.updateSwitchStatement(node, visitNode(node.expression, visitor, isExpression), Debug.checkDefined(visitNode(node.caseBlock, topLevelNestedVisitor, isCaseBlock)));
            }
            function visitCaseBlock(node) {
                const savedEnclosingBlockScopedContainer = enclosingBlockScopedContainer;
                enclosingBlockScopedContainer = node;
                node = factory2.updateCaseBlock(node, visitNodes2(node.clauses, topLevelNestedVisitor, isCaseOrDefaultClause));
                enclosingBlockScopedContainer = savedEnclosingBlockScopedContainer;
                return node;
            }
            function visitCaseClause(node) {
                return factory2.updateCaseClause(node, visitNode(node.expression, visitor, isExpression), visitNodes2(node.statements, topLevelNestedVisitor, isStatement));
            }
            function visitDefaultClause(node) {
                return visitEachChild(node, topLevelNestedVisitor, context);
            }
            function visitTryStatement(node) {
                return visitEachChild(node, topLevelNestedVisitor, context);
            }
            function visitCatchClause(node) {
                const savedEnclosingBlockScopedContainer = enclosingBlockScopedContainer;
                enclosingBlockScopedContainer = node;
                node = factory2.updateCatchClause(node, node.variableDeclaration, Debug.checkDefined(visitNode(node.block, topLevelNestedVisitor, isBlock)));
                enclosingBlockScopedContainer = savedEnclosingBlockScopedContainer;
                return node;
            }
            function visitBlock(node) {
                const savedEnclosingBlockScopedContainer = enclosingBlockScopedContainer;
                enclosingBlockScopedContainer = node;
                node = visitEachChild(node, topLevelNestedVisitor, context);
                enclosingBlockScopedContainer = savedEnclosingBlockScopedContainer;
                return node;
            }
            function visitorWorker(node, valueIsDiscarded) {
                if (!(node.transformFlags & (4096 /* ContainsDestructuringAssignment */ | 8388608 /* ContainsDynamicImport */ | 268435456 /* ContainsUpdateExpressionForIdentifier */))) {
                    return node;
                }
                switch (node.kind) {
                    case 248 /* ForStatement */:
                        return visitForStatement(node, 
                        /*isTopLevel*/
                        false);
                    case 244 /* ExpressionStatement */:
                        return visitExpressionStatement(node);
                    case 217 /* ParenthesizedExpression */:
                        return visitParenthesizedExpression(node, valueIsDiscarded);
                    case 360 /* PartiallyEmittedExpression */:
                        return visitPartiallyEmittedExpression(node, valueIsDiscarded);
                    case 226 /* BinaryExpression */:
                        if (isDestructuringAssignment(node)) {
                            return visitDestructuringAssignment(node, valueIsDiscarded);
                        }
                        break;
                    case 213 /* CallExpression */:
                        if (isImportCall(node)) {
                            return visitImportCallExpression(node);
                        }
                        break;
                    case 224 /* PrefixUnaryExpression */:
                    case 225 /* PostfixUnaryExpression */:
                        return visitPrefixOrPostfixUnaryExpression(node, valueIsDiscarded);
                }
                return visitEachChild(node, visitor, context);
            }
            function visitor(node) {
                return visitorWorker(node, 
                /*valueIsDiscarded*/
                false);
            }
            function discardedValueVisitor(node) {
                return visitorWorker(node, 
                /*valueIsDiscarded*/
                true);
            }
            function visitExpressionStatement(node) {
                return factory2.updateExpressionStatement(node, visitNode(node.expression, discardedValueVisitor, isExpression));
            }
            function visitParenthesizedExpression(node, valueIsDiscarded) {
                return factory2.updateParenthesizedExpression(node, visitNode(node.expression, valueIsDiscarded ? discardedValueVisitor : visitor, isExpression));
            }
            function visitPartiallyEmittedExpression(node, valueIsDiscarded) {
                return factory2.updatePartiallyEmittedExpression(node, visitNode(node.expression, valueIsDiscarded ? discardedValueVisitor : visitor, isExpression));
            }
            function visitImportCallExpression(node) {
                const externalModuleName = getExternalModuleNameLiteral(factory2, node, currentSourceFile, host, resolver, compilerOptions);
                const firstArgument = visitNode(firstOrUndefined(node.arguments), visitor, isExpression);
                const argument = externalModuleName && (!firstArgument || !isStringLiteral(firstArgument) || firstArgument.text !== externalModuleName.text) ? externalModuleName : firstArgument;
                return factory2.createCallExpression(factory2.createPropertyAccessExpression(contextObject, factory2.createIdentifier("import")), 
                /*typeArguments*/
                void 0, argument ? [argument] : []);
            }
            function visitDestructuringAssignment(node, valueIsDiscarded) {
                if (hasExportedReferenceInDestructuringTarget(node.left)) {
                    return flattenDestructuringAssignment(node, visitor, context, 0 /* All */, !valueIsDiscarded);
                }
                return visitEachChild(node, visitor, context);
            }
            function hasExportedReferenceInDestructuringTarget(node) {
                if (isAssignmentExpression(node, 
                /*excludeCompoundAssignment*/
                true)) {
                    return hasExportedReferenceInDestructuringTarget(node.left);
                }
                else if (isSpreadElement(node)) {
                    return hasExportedReferenceInDestructuringTarget(node.expression);
                }
                else if (isObjectLiteralExpression(node)) {
                    return some(node.properties, hasExportedReferenceInDestructuringTarget);
                }
                else if (isArrayLiteralExpression(node)) {
                    return some(node.elements, hasExportedReferenceInDestructuringTarget);
                }
                else if (isShorthandPropertyAssignment(node)) {
                    return hasExportedReferenceInDestructuringTarget(node.name);
                }
                else if (isPropertyAssignment(node)) {
                    return hasExportedReferenceInDestructuringTarget(node.initializer);
                }
                else if (isIdentifier(node)) {
                    const container = resolver.getReferencedExportContainer(node);
                    return container !== void 0 && container.kind === 312 /* SourceFile */;
                }
                else {
                    return false;
                }
            }
            function visitPrefixOrPostfixUnaryExpression(node, valueIsDiscarded) {
                if ((node.operator === 46 /* PlusPlusToken */ || node.operator === 47 /* MinusMinusToken */) && isIdentifier(node.operand) && !isGeneratedIdentifier(node.operand) && !isLocalName(node.operand) && !isDeclarationNameOfEnumOrNamespace(node.operand)) {
                    const exportedNames = getExports(node.operand);
                    if (exportedNames) {
                        let temp;
                        let expression = visitNode(node.operand, visitor, isExpression);
                        if (isPrefixUnaryExpression(node)) {
                            expression = factory2.updatePrefixUnaryExpression(node, expression);
                        }
                        else {
                            expression = factory2.updatePostfixUnaryExpression(node, expression);
                            if (!valueIsDiscarded) {
                                temp = factory2.createTempVariable(hoistVariableDeclaration);
                                expression = factory2.createAssignment(temp, expression);
                                setTextRange(expression, node);
                            }
                            expression = factory2.createComma(expression, factory2.cloneNode(node.operand));
                            setTextRange(expression, node);
                        }
                        for (const exportName of exportedNames) {
                            expression = createExportExpression(exportName, preventSubstitution(expression));
                        }
                        if (temp) {
                            expression = factory2.createComma(expression, temp);
                            setTextRange(expression, node);
                        }
                        return expression;
                    }
                }
                return visitEachChild(node, visitor, context);
            }
            function modifierVisitor(node) {
                switch (node.kind) {
                    case 95 /* ExportKeyword */:
                    case 90 /* DefaultKeyword */:
                        return void 0;
                }
                return node;
            }
            function onEmitNode(hint, node, emitCallback) {
                if (node.kind === 312 /* SourceFile */) {
                    const id = getOriginalNodeId(node);
                    currentSourceFile = node;
                    moduleInfo = moduleInfoMap[id];
                    exportFunction = exportFunctionsMap[id];
                    noSubstitution = noSubstitutionMap[id];
                    contextObject = contextObjectMap[id];
                    if (noSubstitution) {
                        delete noSubstitutionMap[id];
                    }
                    previousOnEmitNode(hint, node, emitCallback);
                    currentSourceFile = void 0;
                    moduleInfo = void 0;
                    exportFunction = void 0;
                    contextObject = void 0;
                    noSubstitution = void 0;
                }
                else {
                    previousOnEmitNode(hint, node, emitCallback);
                }
            }
            function onSubstituteNode(hint, node) {
                node = previousOnSubstituteNode(hint, node);
                if (isSubstitutionPrevented(node)) {
                    return node;
                }
                if (hint === 1 /* Expression */) {
                    return substituteExpression(node);
                }
                else if (hint === 4 /* Unspecified */) {
                    return substituteUnspecified(node);
                }
                return node;
            }
            function substituteUnspecified(node) {
                switch (node.kind) {
                    case 304 /* ShorthandPropertyAssignment */:
                        return substituteShorthandPropertyAssignment(node);
                }
                return node;
            }
            function substituteShorthandPropertyAssignment(node) {
                var _a, _b;
                const name = node.name;
                if (!isGeneratedIdentifier(name) && !isLocalName(name)) {
                    const importDeclaration = resolver.getReferencedImportDeclaration(name);
                    if (importDeclaration) {
                        if (isImportClause(importDeclaration)) {
                            return setTextRange(factory2.createPropertyAssignment(factory2.cloneNode(name), factory2.createPropertyAccessExpression(factory2.getGeneratedNameForNode(importDeclaration.parent), factory2.createIdentifier("default"))), 
                            /*location*/
                            node);
                        }
                        else if (isImportSpecifier(importDeclaration)) {
                            return setTextRange(factory2.createPropertyAssignment(factory2.cloneNode(name), factory2.createPropertyAccessExpression(factory2.getGeneratedNameForNode(((_b = (_a = importDeclaration.parent) == null ? void 0 : _a.parent) == null ? void 0 : _b.parent) || importDeclaration), factory2.cloneNode(importDeclaration.propertyName || importDeclaration.name))), 
                            /*location*/
                            node);
                        }
                    }
                }
                return node;
            }
            function substituteExpression(node) {
                switch (node.kind) {
                    case 80 /* Identifier */:
                        return substituteExpressionIdentifier(node);
                    case 226 /* BinaryExpression */:
                        return substituteBinaryExpression(node);
                    case 236 /* MetaProperty */:
                        return substituteMetaProperty(node);
                }
                return node;
            }
            function substituteExpressionIdentifier(node) {
                var _a, _b;
                if (getEmitFlags(node) & 8192 /* HelperName */) {
                    const externalHelpersModuleName = getExternalHelpersModuleName(currentSourceFile);
                    if (externalHelpersModuleName) {
                        return factory2.createPropertyAccessExpression(externalHelpersModuleName, node);
                    }
                    return node;
                }
                if (!isGeneratedIdentifier(node) && !isLocalName(node)) {
                    const importDeclaration = resolver.getReferencedImportDeclaration(node);
                    if (importDeclaration) {
                        if (isImportClause(importDeclaration)) {
                            return setTextRange(factory2.createPropertyAccessExpression(factory2.getGeneratedNameForNode(importDeclaration.parent), factory2.createIdentifier("default")), 
                            /*location*/
                            node);
                        }
                        else if (isImportSpecifier(importDeclaration)) {
                            return setTextRange(factory2.createPropertyAccessExpression(factory2.getGeneratedNameForNode(((_b = (_a = importDeclaration.parent) == null ? void 0 : _a.parent) == null ? void 0 : _b.parent) || importDeclaration), factory2.cloneNode(importDeclaration.propertyName || importDeclaration.name)), 
                            /*location*/
                            node);
                        }
                    }
                }
                return node;
            }
            function substituteBinaryExpression(node) {
                if (isAssignmentOperator(node.operatorToken.kind) && isIdentifier(node.left) && (!isGeneratedIdentifier(node.left) || isFileLevelReservedGeneratedIdentifier(node.left)) && !isLocalName(node.left)) {
                    const exportedNames = getExports(node.left);
                    if (exportedNames) {
                        let expression = node;
                        for (const exportName of exportedNames) {
                            expression = createExportExpression(exportName, preventSubstitution(expression));
                        }
                        return expression;
                    }
                }
                return node;
            }
            function substituteMetaProperty(node) {
                if (isImportMeta(node)) {
                    return factory2.createPropertyAccessExpression(contextObject, factory2.createIdentifier("meta"));
                }
                return node;
            }
            function getExports(name) {
                let exportedNames;
                const valueDeclaration = getReferencedDeclaration(name);
                if (valueDeclaration) {
                    const exportContainer = resolver.getReferencedExportContainer(name, 
                    /*prefixLocals*/
                    false);
                    if (exportContainer && exportContainer.kind === 312 /* SourceFile */) {
                        exportedNames = append(exportedNames, factory2.getDeclarationName(valueDeclaration));
                    }
                    exportedNames = addRange(exportedNames, moduleInfo == null ? void 0 : moduleInfo.exportedBindings[getOriginalNodeId(valueDeclaration)]);
                }
                else if (isGeneratedIdentifier(name) && isFileLevelReservedGeneratedIdentifier(name)) {
                    const exportSpecifiers = moduleInfo == null ? void 0 : moduleInfo.exportSpecifiers.get(name);
                    if (exportSpecifiers) {
                        const exportedNames2 = [];
                        for (const exportSpecifier of exportSpecifiers) {
                            exportedNames2.push(exportSpecifier.name);
                        }
                        return exportedNames2;
                    }
                }
                return exportedNames;
            }
            function getReferencedDeclaration(name) {
                if (!isGeneratedIdentifier(name)) {
                    const importDeclaration = resolver.getReferencedImportDeclaration(name);
                    if (importDeclaration)
                        return importDeclaration;
                    const valueDeclaration = resolver.getReferencedValueDeclaration(name);
                    if (valueDeclaration && (moduleInfo == null ? void 0 : moduleInfo.exportedBindings[getOriginalNodeId(valueDeclaration)]))
                        return valueDeclaration;
                    const declarations = resolver.getReferencedValueDeclarations(name);
                    if (declarations) {
                        for (const declaration of declarations) {
                            if (declaration !== valueDeclaration && (moduleInfo == null ? void 0 : moduleInfo.exportedBindings[getOriginalNodeId(declaration)]))
                                return declaration;
                        }
                    }
                    return valueDeclaration;
                }
            }
            function preventSubstitution(node) {
                if (noSubstitution === void 0)
                    noSubstitution = [];
                noSubstitution[getNodeId(node)] = true;
                return node;
            }
            function isSubstitutionPrevented(node) {
                return noSubstitution && node.id && noSubstitution[node.id];
            }
        }
        var init_system = __esm({
            "src/compiler/transformers/module/system.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/module/esnextAnd2015.ts
        function transformECMAScriptModule(context) {
            const { factory: factory2, getEmitHelperFactory: emitHelpers } = context;
            const host = context.getEmitHost();
            const resolver = context.getEmitResolver();
            const compilerOptions = context.getCompilerOptions();
            const languageVersion = getEmitScriptTarget(compilerOptions);
            const previousOnEmitNode = context.onEmitNode;
            const previousOnSubstituteNode = context.onSubstituteNode;
            context.onEmitNode = onEmitNode;
            context.onSubstituteNode = onSubstituteNode;
            context.enableEmitNotification(312 /* SourceFile */);
            context.enableSubstitution(80 /* Identifier */);
            let helperNameSubstitutions;
            let currentSourceFile;
            let importRequireStatements;
            return chainBundle(context, transformSourceFile);
            function transformSourceFile(node) {
                if (node.isDeclarationFile) {
                    return node;
                }
                if (isExternalModule(node) || getIsolatedModules(compilerOptions)) {
                    currentSourceFile = node;
                    importRequireStatements = void 0;
                    let result = updateExternalModule(node);
                    currentSourceFile = void 0;
                    if (importRequireStatements) {
                        result = factory2.updateSourceFile(result, setTextRange(factory2.createNodeArray(insertStatementsAfterCustomPrologue(result.statements.slice(), importRequireStatements)), result.statements));
                    }
                    if (!isExternalModule(node) || getEmitModuleKind(compilerOptions) === 200 /* Preserve */ || some(result.statements, isExternalModuleIndicator)) {
                        return result;
                    }
                    return factory2.updateSourceFile(result, setTextRange(factory2.createNodeArray([...result.statements, createEmptyExports(factory2)]), result.statements));
                }
                return node;
            }
            function updateExternalModule(node) {
                const externalHelpersImportDeclaration = createExternalHelpersImportDeclarationIfNeeded(factory2, emitHelpers(), node, compilerOptions);
                if (externalHelpersImportDeclaration) {
                    const statements = [];
                    const statementOffset = factory2.copyPrologue(node.statements, statements);
                    append(statements, externalHelpersImportDeclaration);
                    addRange(statements, visitNodes2(node.statements, visitor, isStatement, statementOffset));
                    return factory2.updateSourceFile(node, setTextRange(factory2.createNodeArray(statements), node.statements));
                }
                else {
                    return visitEachChild(node, visitor, context);
                }
            }
            function visitor(node) {
                switch (node.kind) {
                    case 271 /* ImportEqualsDeclaration */:
                        return getEmitModuleKind(compilerOptions) >= 100 /* Node16 */ ? visitImportEqualsDeclaration(node) : void 0;
                    case 277 /* ExportAssignment */:
                        return visitExportAssignment(node);
                    case 278 /* ExportDeclaration */:
                        const exportDecl = node;
                        return visitExportDeclaration(exportDecl);
                }
                return node;
            }
            function createRequireCall2(importNode) {
                const moduleName = getExternalModuleNameLiteral(factory2, importNode, Debug.checkDefined(currentSourceFile), host, resolver, compilerOptions);
                const args = [];
                if (moduleName) {
                    args.push(moduleName);
                }
                if (getEmitModuleKind(compilerOptions) === 200 /* Preserve */) {
                    return factory2.createCallExpression(factory2.createIdentifier("require"), 
                    /*typeArguments*/
                    void 0, args);
                }
                if (!importRequireStatements) {
                    const createRequireName = factory2.createUniqueName("_createRequire", 16 /* Optimistic */ | 32 /* FileLevel */);
                    const importStatement = factory2.createImportDeclaration(
                    /*modifiers*/
                    void 0, factory2.createImportClause(
                    /*isTypeOnly*/
                    false, 
                    /*name*/
                    void 0, factory2.createNamedImports([
                        factory2.createImportSpecifier(
                        /*isTypeOnly*/
                        false, factory2.createIdentifier("createRequire"), createRequireName)
                    ])), factory2.createStringLiteral("module"), 
                    /*attributes*/
                    void 0);
                    const requireHelperName = factory2.createUniqueName("__require", 16 /* Optimistic */ | 32 /* FileLevel */);
                    const requireStatement = factory2.createVariableStatement(
                    /*modifiers*/
                    void 0, factory2.createVariableDeclarationList([
                        factory2.createVariableDeclaration(requireHelperName, 
                        /*exclamationToken*/
                        void 0, 
                        /*type*/
                        void 0, factory2.createCallExpression(factory2.cloneNode(createRequireName), 
                        /*typeArguments*/
                        void 0, [
                            factory2.createPropertyAccessExpression(factory2.createMetaProperty(102 /* ImportKeyword */, factory2.createIdentifier("meta")), factory2.createIdentifier("url"))
                        ]))
                    ], 
                    /*flags*/
                    languageVersion >= 2 /* ES2015 */ ? 2 /* Const */ : 0 /* None */));
                    importRequireStatements = [importStatement, requireStatement];
                }
                const name = importRequireStatements[1].declarationList.declarations[0].name;
                Debug.assertNode(name, isIdentifier);
                return factory2.createCallExpression(factory2.cloneNode(name), 
                /*typeArguments*/
                void 0, args);
            }
            function visitImportEqualsDeclaration(node) {
                Debug.assert(isExternalModuleImportEqualsDeclaration(node), "import= for internal module references should be handled in an earlier transformer.");
                let statements;
                statements = append(statements, setOriginalNode(setTextRange(factory2.createVariableStatement(
                /*modifiers*/
                void 0, factory2.createVariableDeclarationList([
                    factory2.createVariableDeclaration(factory2.cloneNode(node.name), 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, createRequireCall2(node))
                ], 
                /*flags*/
                languageVersion >= 2 /* ES2015 */ ? 2 /* Const */ : 0 /* None */)), node), node));
                statements = appendExportsOfImportEqualsDeclaration(statements, node);
                return singleOrMany(statements);
            }
            function appendExportsOfImportEqualsDeclaration(statements, node) {
                if (hasSyntacticModifier(node, 32 /* Export */)) {
                    statements = append(statements, factory2.createExportDeclaration(
                    /*modifiers*/
                    void 0, node.isTypeOnly, factory2.createNamedExports([factory2.createExportSpecifier(
                        /*isTypeOnly*/
                        false, 
                        /*propertyName*/
                        void 0, idText(node.name))])));
                }
                return statements;
            }
            function visitExportAssignment(node) {
                if (node.isExportEquals) {
                    if (getEmitModuleKind(compilerOptions) === 200 /* Preserve */) {
                        const statement = setOriginalNode(factory2.createExpressionStatement(factory2.createAssignment(factory2.createPropertyAccessExpression(factory2.createIdentifier("module"), "exports"), node.expression)), node);
                        return statement;
                    }
                    return void 0;
                }
                return node;
            }
            function visitExportDeclaration(node) {
                if (compilerOptions.module !== void 0 && compilerOptions.module > 5 /* ES2015 */) {
                    return node;
                }
                if (!node.exportClause || !isNamespaceExport(node.exportClause) || !node.moduleSpecifier) {
                    return node;
                }
                const oldIdentifier = node.exportClause.name;
                const synthName = factory2.getGeneratedNameForNode(oldIdentifier);
                const importDecl = factory2.createImportDeclaration(
                /*modifiers*/
                void 0, factory2.createImportClause(
                /*isTypeOnly*/
                false, 
                /*name*/
                void 0, factory2.createNamespaceImport(synthName)), node.moduleSpecifier, node.attributes);
                setOriginalNode(importDecl, node.exportClause);
                const exportDecl = isExportNamespaceAsDefaultDeclaration(node) ? factory2.createExportDefault(synthName) : factory2.createExportDeclaration(
                /*modifiers*/
                void 0, 
                /*isTypeOnly*/
                false, factory2.createNamedExports([factory2.createExportSpecifier(
                    /*isTypeOnly*/
                    false, synthName, oldIdentifier)]));
                setOriginalNode(exportDecl, node);
                return [importDecl, exportDecl];
            }
            function onEmitNode(hint, node, emitCallback) {
                if (isSourceFile(node)) {
                    if ((isExternalModule(node) || getIsolatedModules(compilerOptions)) && compilerOptions.importHelpers) {
                        helperNameSubstitutions = /* @__PURE__ */ new Map();
                    }
                    previousOnEmitNode(hint, node, emitCallback);
                    helperNameSubstitutions = void 0;
                }
                else {
                    previousOnEmitNode(hint, node, emitCallback);
                }
            }
            function onSubstituteNode(hint, node) {
                node = previousOnSubstituteNode(hint, node);
                if (helperNameSubstitutions && isIdentifier(node) && getEmitFlags(node) & 8192 /* HelperName */) {
                    return substituteHelperName(node);
                }
                return node;
            }
            function substituteHelperName(node) {
                const name = idText(node);
                let substitution = helperNameSubstitutions.get(name);
                if (!substitution) {
                    helperNameSubstitutions.set(name, substitution = factory2.createUniqueName(name, 16 /* Optimistic */ | 32 /* FileLevel */));
                }
                return substitution;
            }
        }
        var init_esnextAnd2015 = __esm({
            "src/compiler/transformers/module/esnextAnd2015.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/module/node.ts
        function transformNodeModule(context) {
            const previousOnSubstituteNode = context.onSubstituteNode;
            const previousOnEmitNode = context.onEmitNode;
            const esmTransform = transformECMAScriptModule(context);
            const esmOnSubstituteNode = context.onSubstituteNode;
            const esmOnEmitNode = context.onEmitNode;
            context.onSubstituteNode = previousOnSubstituteNode;
            context.onEmitNode = previousOnEmitNode;
            const cjsTransform = transformModule(context);
            const cjsOnSubstituteNode = context.onSubstituteNode;
            const cjsOnEmitNode = context.onEmitNode;
            context.onSubstituteNode = onSubstituteNode;
            context.onEmitNode = onEmitNode;
            context.enableSubstitution(312 /* SourceFile */);
            context.enableEmitNotification(312 /* SourceFile */);
            let currentSourceFile;
            return transformSourceFileOrBundle;
            function onSubstituteNode(hint, node) {
                if (isSourceFile(node)) {
                    currentSourceFile = node;
                    return previousOnSubstituteNode(hint, node);
                }
                else {
                    if (!currentSourceFile) {
                        return previousOnSubstituteNode(hint, node);
                    }
                    if (currentSourceFile.impliedNodeFormat === 99 /* ESNext */) {
                        return esmOnSubstituteNode(hint, node);
                    }
                    return cjsOnSubstituteNode(hint, node);
                }
            }
            function onEmitNode(hint, node, emitCallback) {
                if (isSourceFile(node)) {
                    currentSourceFile = node;
                }
                if (!currentSourceFile) {
                    return previousOnEmitNode(hint, node, emitCallback);
                }
                if (currentSourceFile.impliedNodeFormat === 99 /* ESNext */) {
                    return esmOnEmitNode(hint, node, emitCallback);
                }
                return cjsOnEmitNode(hint, node, emitCallback);
            }
            function getModuleTransformForFile(file) {
                return file.impliedNodeFormat === 99 /* ESNext */ ? esmTransform : cjsTransform;
            }
            function transformSourceFile(node) {
                if (node.isDeclarationFile) {
                    return node;
                }
                currentSourceFile = node;
                const result = getModuleTransformForFile(node)(node);
                currentSourceFile = void 0;
                Debug.assert(isSourceFile(result));
                return result;
            }
            function transformSourceFileOrBundle(node) {
                return node.kind === 312 /* SourceFile */ ? transformSourceFile(node) : transformBundle(node);
            }
            function transformBundle(node) {
                return context.factory.createBundle(map(node.sourceFiles, transformSourceFile), node.prepends);
            }
        }
        var init_node = __esm({
            "src/compiler/transformers/module/node.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/declarations/diagnostics.ts
        function canProduceDiagnostics(node) {
            return isVariableDeclaration(node) || isPropertyDeclaration(node) || isPropertySignature(node) || isBindingElement(node) || isSetAccessor(node) || isGetAccessor(node) || isConstructSignatureDeclaration(node) || isCallSignatureDeclaration(node) || isMethodDeclaration(node) || isMethodSignature(node) || isFunctionDeclaration(node) || isParameter(node) || isTypeParameterDeclaration(node) || isExpressionWithTypeArguments(node) || isImportEqualsDeclaration(node) || isTypeAliasDeclaration(node) || isConstructorDeclaration(node) || isIndexSignatureDeclaration(node) || isPropertyAccessExpression(node) || isElementAccessExpression(node) || isBinaryExpression(node) || isJSDocTypeAlias(node);
        }
        function createGetSymbolAccessibilityDiagnosticForNodeName(node) {
            if (isSetAccessor(node) || isGetAccessor(node)) {
                return getAccessorNameVisibilityError;
            }
            else if (isMethodSignature(node) || isMethodDeclaration(node)) {
                return getMethodNameVisibilityError;
            }
            else {
                return createGetSymbolAccessibilityDiagnosticForNode(node);
            }
            function getAccessorNameVisibilityError(symbolAccessibilityResult) {
                const diagnosticMessage = getAccessorNameVisibilityDiagnosticMessage(symbolAccessibilityResult);
                return diagnosticMessage !== void 0 ? {
                    diagnosticMessage,
                    errorNode: node,
                    typeName: node.name
                } : void 0;
            }
            function getAccessorNameVisibilityDiagnosticMessage(symbolAccessibilityResult) {
                if (isStatic(node)) {
                    return symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named : Diagnostics.Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Public_static_property_0_of_exported_class_has_or_is_using_private_name_1;
                }
                else if (node.parent.kind === 263 /* ClassDeclaration */) {
                    return symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Public_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named : Diagnostics.Public_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Public_property_0_of_exported_class_has_or_is_using_private_name_1;
                }
                else {
                    return symbolAccessibilityResult.errorModuleName ? Diagnostics.Property_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Property_0_of_exported_interface_has_or_is_using_private_name_1;
                }
            }
            function getMethodNameVisibilityError(symbolAccessibilityResult) {
                const diagnosticMessage = getMethodNameVisibilityDiagnosticMessage(symbolAccessibilityResult);
                return diagnosticMessage !== void 0 ? {
                    diagnosticMessage,
                    errorNode: node,
                    typeName: node.name
                } : void 0;
            }
            function getMethodNameVisibilityDiagnosticMessage(symbolAccessibilityResult) {
                if (isStatic(node)) {
                    return symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Public_static_method_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named : Diagnostics.Public_static_method_0_of_exported_class_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Public_static_method_0_of_exported_class_has_or_is_using_private_name_1;
                }
                else if (node.parent.kind === 263 /* ClassDeclaration */) {
                    return symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Public_method_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named : Diagnostics.Public_method_0_of_exported_class_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Public_method_0_of_exported_class_has_or_is_using_private_name_1;
                }
                else {
                    return symbolAccessibilityResult.errorModuleName ? Diagnostics.Method_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Method_0_of_exported_interface_has_or_is_using_private_name_1;
                }
            }
        }
        function createGetSymbolAccessibilityDiagnosticForNode(node) {
            if (isVariableDeclaration(node) || isPropertyDeclaration(node) || isPropertySignature(node) || isPropertyAccessExpression(node) || isElementAccessExpression(node) || isBinaryExpression(node) || isBindingElement(node) || isConstructorDeclaration(node)) {
                return getVariableDeclarationTypeVisibilityError;
            }
            else if (isSetAccessor(node) || isGetAccessor(node)) {
                return getAccessorDeclarationTypeVisibilityError;
            }
            else if (isConstructSignatureDeclaration(node) || isCallSignatureDeclaration(node) || isMethodDeclaration(node) || isMethodSignature(node) || isFunctionDeclaration(node) || isIndexSignatureDeclaration(node)) {
                return getReturnTypeVisibilityError;
            }
            else if (isParameter(node)) {
                if (isParameterPropertyDeclaration(node, node.parent) && hasSyntacticModifier(node.parent, 2 /* Private */)) {
                    return getVariableDeclarationTypeVisibilityError;
                }
                return getParameterDeclarationTypeVisibilityError;
            }
            else if (isTypeParameterDeclaration(node)) {
                return getTypeParameterConstraintVisibilityError;
            }
            else if (isExpressionWithTypeArguments(node)) {
                return getHeritageClauseVisibilityError;
            }
            else if (isImportEqualsDeclaration(node)) {
                return getImportEntityNameVisibilityError;
            }
            else if (isTypeAliasDeclaration(node) || isJSDocTypeAlias(node)) {
                return getTypeAliasDeclarationVisibilityError;
            }
            else {
                return Debug.assertNever(node, `Attempted to set a declaration diagnostic context for unhandled node kind: ${Debug.formatSyntaxKind(node.kind)}`);
            }
            function getVariableDeclarationTypeVisibilityDiagnosticMessage(symbolAccessibilityResult) {
                if (node.kind === 260 /* VariableDeclaration */ || node.kind === 208 /* BindingElement */) {
                    return symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Exported_variable_0_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named : Diagnostics.Exported_variable_0_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Exported_variable_0_has_or_is_using_private_name_1;
                }
                else if (node.kind === 172 /* PropertyDeclaration */ || node.kind === 211 /* PropertyAccessExpression */ || node.kind === 212 /* ElementAccessExpression */ || node.kind === 226 /* BinaryExpression */ || node.kind === 171 /* PropertySignature */ || node.kind === 169 /* Parameter */ && hasSyntacticModifier(node.parent, 2 /* Private */)) {
                    if (isStatic(node)) {
                        return symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named : Diagnostics.Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Public_static_property_0_of_exported_class_has_or_is_using_private_name_1;
                    }
                    else if (node.parent.kind === 263 /* ClassDeclaration */ || node.kind === 169 /* Parameter */) {
                        return symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Public_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named : Diagnostics.Public_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Public_property_0_of_exported_class_has_or_is_using_private_name_1;
                    }
                    else {
                        return symbolAccessibilityResult.errorModuleName ? Diagnostics.Property_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Property_0_of_exported_interface_has_or_is_using_private_name_1;
                    }
                }
            }
            function getVariableDeclarationTypeVisibilityError(symbolAccessibilityResult) {
                const diagnosticMessage = getVariableDeclarationTypeVisibilityDiagnosticMessage(symbolAccessibilityResult);
                return diagnosticMessage !== void 0 ? {
                    diagnosticMessage,
                    errorNode: node,
                    typeName: node.name
                } : void 0;
            }
            function getAccessorDeclarationTypeVisibilityError(symbolAccessibilityResult) {
                let diagnosticMessage;
                if (node.kind === 178 /* SetAccessor */) {
                    if (isStatic(node)) {
                        diagnosticMessage = symbolAccessibilityResult.errorModuleName ? Diagnostics.Parameter_type_of_public_static_setter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Parameter_type_of_public_static_setter_0_from_exported_class_has_or_is_using_private_name_1;
                    }
                    else {
                        diagnosticMessage = symbolAccessibilityResult.errorModuleName ? Diagnostics.Parameter_type_of_public_setter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Parameter_type_of_public_setter_0_from_exported_class_has_or_is_using_private_name_1;
                    }
                }
                else {
                    if (isStatic(node)) {
                        diagnosticMessage = symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named : Diagnostics.Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_private_name_1;
                    }
                    else {
                        diagnosticMessage = symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Return_type_of_public_getter_0_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named : Diagnostics.Return_type_of_public_getter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Return_type_of_public_getter_0_from_exported_class_has_or_is_using_private_name_1;
                    }
                }
                return {
                    diagnosticMessage,
                    errorNode: node.name,
                    typeName: node.name
                };
            }
            function getReturnTypeVisibilityError(symbolAccessibilityResult) {
                let diagnosticMessage;
                switch (node.kind) {
                    case 180 /* ConstructSignature */:
                        diagnosticMessage = symbolAccessibilityResult.errorModuleName ? Diagnostics.Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1 : Diagnostics.Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_0;
                        break;
                    case 179 /* CallSignature */:
                        diagnosticMessage = symbolAccessibilityResult.errorModuleName ? Diagnostics.Return_type_of_call_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1 : Diagnostics.Return_type_of_call_signature_from_exported_interface_has_or_is_using_private_name_0;
                        break;
                    case 181 /* IndexSignature */:
                        diagnosticMessage = symbolAccessibilityResult.errorModuleName ? Diagnostics.Return_type_of_index_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1 : Diagnostics.Return_type_of_index_signature_from_exported_interface_has_or_is_using_private_name_0;
                        break;
                    case 174 /* MethodDeclaration */:
                    case 173 /* MethodSignature */:
                        if (isStatic(node)) {
                            diagnosticMessage = symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named : Diagnostics.Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_private_module_1 : Diagnostics.Return_type_of_public_static_method_from_exported_class_has_or_is_using_private_name_0;
                        }
                        else if (node.parent.kind === 263 /* ClassDeclaration */) {
                            diagnosticMessage = symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named : Diagnostics.Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_private_module_1 : Diagnostics.Return_type_of_public_method_from_exported_class_has_or_is_using_private_name_0;
                        }
                        else {
                            diagnosticMessage = symbolAccessibilityResult.errorModuleName ? Diagnostics.Return_type_of_method_from_exported_interface_has_or_is_using_name_0_from_private_module_1 : Diagnostics.Return_type_of_method_from_exported_interface_has_or_is_using_private_name_0;
                        }
                        break;
                    case 262 /* FunctionDeclaration */:
                        diagnosticMessage = symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Return_type_of_exported_function_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named : Diagnostics.Return_type_of_exported_function_has_or_is_using_name_0_from_private_module_1 : Diagnostics.Return_type_of_exported_function_has_or_is_using_private_name_0;
                        break;
                    default:
                        return Debug.fail("This is unknown kind for signature: " + node.kind);
                }
                return {
                    diagnosticMessage,
                    errorNode: node.name || node
                };
            }
            function getParameterDeclarationTypeVisibilityError(symbolAccessibilityResult) {
                const diagnosticMessage = getParameterDeclarationTypeVisibilityDiagnosticMessage(symbolAccessibilityResult);
                return diagnosticMessage !== void 0 ? {
                    diagnosticMessage,
                    errorNode: node,
                    typeName: node.name
                } : void 0;
            }
            function getParameterDeclarationTypeVisibilityDiagnosticMessage(symbolAccessibilityResult) {
                switch (node.parent.kind) {
                    case 176 /* Constructor */:
                        return symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named : Diagnostics.Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Parameter_0_of_constructor_from_exported_class_has_or_is_using_private_name_1;
                    case 180 /* ConstructSignature */:
                    case 185 /* ConstructorType */:
                        return symbolAccessibilityResult.errorModuleName ? Diagnostics.Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1;
                    case 179 /* CallSignature */:
                        return symbolAccessibilityResult.errorModuleName ? Diagnostics.Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1;
                    case 181 /* IndexSignature */:
                        return symbolAccessibilityResult.errorModuleName ? Diagnostics.Parameter_0_of_index_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Parameter_0_of_index_signature_from_exported_interface_has_or_is_using_private_name_1;
                    case 174 /* MethodDeclaration */:
                    case 173 /* MethodSignature */:
                        if (isStatic(node.parent)) {
                            return symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named : Diagnostics.Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1;
                        }
                        else if (node.parent.parent.kind === 263 /* ClassDeclaration */) {
                            return symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named : Diagnostics.Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1;
                        }
                        else {
                            return symbolAccessibilityResult.errorModuleName ? Diagnostics.Parameter_0_of_method_from_exported_interface_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1;
                        }
                    case 262 /* FunctionDeclaration */:
                    case 184 /* FunctionType */:
                        return symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Parameter_0_of_exported_function_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named : Diagnostics.Parameter_0_of_exported_function_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Parameter_0_of_exported_function_has_or_is_using_private_name_1;
                    case 178 /* SetAccessor */:
                    case 177 /* GetAccessor */:
                        return symbolAccessibilityResult.errorModuleName ? symbolAccessibilityResult.accessibility === 2 /* CannotBeNamed */ ? Diagnostics.Parameter_0_of_accessor_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named : Diagnostics.Parameter_0_of_accessor_has_or_is_using_name_1_from_private_module_2 : Diagnostics.Parameter_0_of_accessor_has_or_is_using_private_name_1;
                    default:
                        return Debug.fail(`Unknown parent for parameter: ${Debug.formatSyntaxKind(node.parent.kind)}`);
                }
            }
            function getTypeParameterConstraintVisibilityError() {
                let diagnosticMessage;
                switch (node.parent.kind) {
                    case 263 /* ClassDeclaration */:
                        diagnosticMessage = Diagnostics.Type_parameter_0_of_exported_class_has_or_is_using_private_name_1;
                        break;
                    case 264 /* InterfaceDeclaration */:
                        diagnosticMessage = Diagnostics.Type_parameter_0_of_exported_interface_has_or_is_using_private_name_1;
                        break;
                    case 200 /* MappedType */:
                        diagnosticMessage = Diagnostics.Type_parameter_0_of_exported_mapped_object_type_is_using_private_name_1;
                        break;
                    case 185 /* ConstructorType */:
                    case 180 /* ConstructSignature */:
                        diagnosticMessage = Diagnostics.Type_parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1;
                        break;
                    case 179 /* CallSignature */:
                        diagnosticMessage = Diagnostics.Type_parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1;
                        break;
                    case 174 /* MethodDeclaration */:
                    case 173 /* MethodSignature */:
                        if (isStatic(node.parent)) {
                            diagnosticMessage = Diagnostics.Type_parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1;
                        }
                        else if (node.parent.parent.kind === 263 /* ClassDeclaration */) {
                            diagnosticMessage = Diagnostics.Type_parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1;
                        }
                        else {
                            diagnosticMessage = Diagnostics.Type_parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1;
                        }
                        break;
                    case 184 /* FunctionType */:
                    case 262 /* FunctionDeclaration */:
                        diagnosticMessage = Diagnostics.Type_parameter_0_of_exported_function_has_or_is_using_private_name_1;
                        break;
                    case 195 /* InferType */:
                        diagnosticMessage = Diagnostics.Extends_clause_for_inferred_type_0_has_or_is_using_private_name_1;
                        break;
                    case 265 /* TypeAliasDeclaration */:
                        diagnosticMessage = Diagnostics.Type_parameter_0_of_exported_type_alias_has_or_is_using_private_name_1;
                        break;
                    default:
                        return Debug.fail("This is unknown parent for type parameter: " + node.parent.kind);
                }
                return {
                    diagnosticMessage,
                    errorNode: node,
                    typeName: node.name
                };
            }
            function getHeritageClauseVisibilityError() {
                let diagnosticMessage;
                if (isClassDeclaration(node.parent.parent)) {
                    diagnosticMessage = isHeritageClause(node.parent) && node.parent.token === 119 /* ImplementsKeyword */ ? Diagnostics.Implements_clause_of_exported_class_0_has_or_is_using_private_name_1 : node.parent.parent.name ? Diagnostics.extends_clause_of_exported_class_0_has_or_is_using_private_name_1 : Diagnostics.extends_clause_of_exported_class_has_or_is_using_private_name_0;
                }
                else {
                    diagnosticMessage = Diagnostics.extends_clause_of_exported_interface_0_has_or_is_using_private_name_1;
                }
                return {
                    diagnosticMessage,
                    errorNode: node,
                    typeName: getNameOfDeclaration(node.parent.parent)
                };
            }
            function getImportEntityNameVisibilityError() {
                return {
                    diagnosticMessage: Diagnostics.Import_declaration_0_is_using_private_name_1,
                    errorNode: node,
                    typeName: node.name
                };
            }
            function getTypeAliasDeclarationVisibilityError(symbolAccessibilityResult) {
                return {
                    diagnosticMessage: symbolAccessibilityResult.errorModuleName ? Diagnostics.Exported_type_alias_0_has_or_is_using_private_name_1_from_module_2 : Diagnostics.Exported_type_alias_0_has_or_is_using_private_name_1,
                    errorNode: isJSDocTypeAlias(node) ? Debug.checkDefined(node.typeExpression) : node.type,
                    typeName: isJSDocTypeAlias(node) ? getNameOfDeclaration(node) : node.name
                };
            }
        }
        var init_diagnostics = __esm({
            "src/compiler/transformers/declarations/diagnostics.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/transformers/declarations.ts
        function getDeclarationDiagnostics(host, resolver, file) {
            const compilerOptions = host.getCompilerOptions();
            const result = transformNodes(resolver, host, factory, compilerOptions, file ? [file] : filter(host.getSourceFiles(), isSourceFileNotJson), [transformDeclarations], 
            /*allowDtsFiles*/
            false);
            return result.diagnostics;
        }
        function transformDeclarations(context) {
            const throwDiagnostic = () => Debug.fail("Diagnostic emitted without context");
            let getSymbolAccessibilityDiagnostic = throwDiagnostic;
            let needsDeclare = true;
            let isBundledEmit = false;
            let resultHasExternalModuleIndicator = false;
            let needsScopeFixMarker = false;
            let resultHasScopeMarker = false;
            let enclosingDeclaration;
            let necessaryTypeReferences;
            let lateMarkedStatements;
            let lateStatementReplacementMap;
            let suppressNewDiagnosticContexts;
            let exportedModulesFromDeclarationEmit;
            const { factory: factory2 } = context;
            const host = context.getEmitHost();
            const symbolTracker = {
                trackSymbol,
                reportInaccessibleThisError,
                reportInaccessibleUniqueSymbolError,
                reportCyclicStructureError,
                reportPrivateInBaseOfClassExpression,
                reportLikelyUnsafeImportRequiredError,
                reportTruncationError,
                moduleResolverHost: host,
                trackReferencedAmbientModule,
                trackExternalModuleSymbolOfImportTypeNode,
                reportNonlocalAugmentation,
                reportNonSerializableProperty
            };
            let errorNameNode;
            let errorFallbackNode;
            let currentSourceFile;
            let refs;
            let libs2;
            let emittedImports;
            const resolver = context.getEmitResolver();
            const options = context.getCompilerOptions();
            const { noResolve, stripInternal } = options;
            return transformRoot;
            function recordTypeReferenceDirectivesIfNecessary(typeReferenceDirectives) {
                if (!typeReferenceDirectives) {
                    return;
                }
                necessaryTypeReferences = necessaryTypeReferences || /* @__PURE__ */ new Set();
                for (const ref of typeReferenceDirectives) {
                    necessaryTypeReferences.add(ref);
                }
            }
            function trackReferencedAmbientModule(node, symbol) {
                const directives = resolver.getTypeReferenceDirectivesForSymbol(symbol, -1 /* All */);
                if (length(directives)) {
                    return recordTypeReferenceDirectivesIfNecessary(directives);
                }
                const container = getSourceFileOfNode(node);
                refs.set(getOriginalNodeId(container), container);
            }
            function trackReferencedAmbientModuleFromImport(node) {
                const moduleSpecifier = tryGetModuleSpecifierFromDeclaration(node);
                const symbol = moduleSpecifier && resolver.tryFindAmbientModule(moduleSpecifier);
                if (symbol == null ? void 0 : symbol.declarations) {
                    for (const decl of symbol.declarations) {
                        if (isAmbientModule(decl) && getSourceFileOfNode(decl) !== currentSourceFile) {
                            trackReferencedAmbientModule(decl, symbol);
                        }
                    }
                }
            }
            function handleSymbolAccessibilityError(symbolAccessibilityResult) {
                if (symbolAccessibilityResult.accessibility === 0 /* Accessible */) {
                    if (symbolAccessibilityResult.aliasesToMakeVisible) {
                        if (!lateMarkedStatements) {
                            lateMarkedStatements = symbolAccessibilityResult.aliasesToMakeVisible;
                        }
                        else {
                            for (const ref of symbolAccessibilityResult.aliasesToMakeVisible) {
                                pushIfUnique(lateMarkedStatements, ref);
                            }
                        }
                    }
                }
                else {
                    const errorInfo = getSymbolAccessibilityDiagnostic(symbolAccessibilityResult);
                    if (errorInfo) {
                        if (errorInfo.typeName) {
                            context.addDiagnostic(createDiagnosticForNode(symbolAccessibilityResult.errorNode || errorInfo.errorNode, errorInfo.diagnosticMessage, getTextOfNode(errorInfo.typeName), symbolAccessibilityResult.errorSymbolName, symbolAccessibilityResult.errorModuleName));
                        }
                        else {
                            context.addDiagnostic(createDiagnosticForNode(symbolAccessibilityResult.errorNode || errorInfo.errorNode, errorInfo.diagnosticMessage, symbolAccessibilityResult.errorSymbolName, symbolAccessibilityResult.errorModuleName));
                        }
                        return true;
                    }
                }
                return false;
            }
            function trackExternalModuleSymbolOfImportTypeNode(symbol) {
                if (!isBundledEmit) {
                    (exportedModulesFromDeclarationEmit || (exportedModulesFromDeclarationEmit = [])).push(symbol);
                }
            }
            function trackSymbol(symbol, enclosingDeclaration2, meaning) {
                if (symbol.flags & 262144 /* TypeParameter */)
                    return false;
                const issuedDiagnostic = handleSymbolAccessibilityError(resolver.isSymbolAccessible(symbol, enclosingDeclaration2, meaning, 
                /*shouldComputeAliasToMarkVisible*/
                true));
                recordTypeReferenceDirectivesIfNecessary(resolver.getTypeReferenceDirectivesForSymbol(symbol, meaning));
                return issuedDiagnostic;
            }
            function reportPrivateInBaseOfClassExpression(propertyName) {
                if (errorNameNode || errorFallbackNode) {
                    context.addDiagnostic(createDiagnosticForNode(errorNameNode || errorFallbackNode, Diagnostics.Property_0_of_exported_class_expression_may_not_be_private_or_protected, propertyName));
                }
            }
            function errorDeclarationNameWithFallback() {
                return errorNameNode ? declarationNameToString(errorNameNode) : errorFallbackNode && getNameOfDeclaration(errorFallbackNode) ? declarationNameToString(getNameOfDeclaration(errorFallbackNode)) : errorFallbackNode && isExportAssignment(errorFallbackNode) ? errorFallbackNode.isExportEquals ? "export=" : "default" : "(Missing)";
            }
            function reportInaccessibleUniqueSymbolError() {
                if (errorNameNode || errorFallbackNode) {
                    context.addDiagnostic(createDiagnosticForNode(errorNameNode || errorFallbackNode, Diagnostics.The_inferred_type_of_0_references_an_inaccessible_1_type_A_type_annotation_is_necessary, errorDeclarationNameWithFallback(), "unique symbol"));
                }
            }
            function reportCyclicStructureError() {
                if (errorNameNode || errorFallbackNode) {
                    context.addDiagnostic(createDiagnosticForNode(errorNameNode || errorFallbackNode, Diagnostics.The_inferred_type_of_0_references_a_type_with_a_cyclic_structure_which_cannot_be_trivially_serialized_A_type_annotation_is_necessary, errorDeclarationNameWithFallback()));
                }
            }
            function reportInaccessibleThisError() {
                if (errorNameNode || errorFallbackNode) {
                    context.addDiagnostic(createDiagnosticForNode(errorNameNode || errorFallbackNode, Diagnostics.The_inferred_type_of_0_references_an_inaccessible_1_type_A_type_annotation_is_necessary, errorDeclarationNameWithFallback(), "this"));
                }
            }
            function reportLikelyUnsafeImportRequiredError(specifier) {
                if (errorNameNode || errorFallbackNode) {
                    context.addDiagnostic(createDiagnosticForNode(errorNameNode || errorFallbackNode, Diagnostics.The_inferred_type_of_0_cannot_be_named_without_a_reference_to_1_This_is_likely_not_portable_A_type_annotation_is_necessary, errorDeclarationNameWithFallback(), specifier));
                }
            }
            function reportTruncationError() {
                if (errorNameNode || errorFallbackNode) {
                    context.addDiagnostic(createDiagnosticForNode(errorNameNode || errorFallbackNode, Diagnostics.The_inferred_type_of_this_node_exceeds_the_maximum_length_the_compiler_will_serialize_An_explicit_type_annotation_is_needed));
                }
            }
            function reportNonlocalAugmentation(containingFile, parentSymbol, symbol) {
                var _a;
                const primaryDeclaration = (_a = parentSymbol.declarations) == null ? void 0 : _a.find((d) => getSourceFileOfNode(d) === containingFile);
                const augmentingDeclarations = filter(symbol.declarations, (d) => getSourceFileOfNode(d) !== containingFile);
                if (primaryDeclaration && augmentingDeclarations) {
                    for (const augmentations of augmentingDeclarations) {
                        context.addDiagnostic(addRelatedInfo(createDiagnosticForNode(augmentations, Diagnostics.Declaration_augments_declaration_in_another_file_This_cannot_be_serialized), createDiagnosticForNode(primaryDeclaration, Diagnostics.This_is_the_declaration_being_augmented_Consider_moving_the_augmenting_declaration_into_the_same_file)));
                    }
                }
            }
            function reportNonSerializableProperty(propertyName) {
                if (errorNameNode || errorFallbackNode) {
                    context.addDiagnostic(createDiagnosticForNode(errorNameNode || errorFallbackNode, Diagnostics.The_type_of_this_node_cannot_be_serialized_because_its_property_0_cannot_be_serialized, propertyName));
                }
            }
            function transformDeclarationsForJS(sourceFile, bundled) {
                const oldDiag = getSymbolAccessibilityDiagnostic;
                getSymbolAccessibilityDiagnostic = (s) => s.errorNode && canProduceDiagnostics(s.errorNode) ? createGetSymbolAccessibilityDiagnosticForNode(s.errorNode)(s) : {
                    diagnosticMessage: s.errorModuleName ? Diagnostics.Declaration_emit_for_this_file_requires_using_private_name_0_from_module_1_An_explicit_type_annotation_may_unblock_declaration_emit : Diagnostics.Declaration_emit_for_this_file_requires_using_private_name_0_An_explicit_type_annotation_may_unblock_declaration_emit,
                    errorNode: s.errorNode || sourceFile
                };
                const result = resolver.getDeclarationStatementsForSourceFile(sourceFile, declarationEmitNodeBuilderFlags, symbolTracker, bundled);
                getSymbolAccessibilityDiagnostic = oldDiag;
                return result;
            }
            function transformRoot(node) {
                if (node.kind === 312 /* SourceFile */ && node.isDeclarationFile) {
                    return node;
                }
                if (node.kind === 313 /* Bundle */) {
                    isBundledEmit = true;
                    refs = /* @__PURE__ */ new Map();
                    libs2 = /* @__PURE__ */ new Map();
                    let hasNoDefaultLib = false;
                    const bundle = factory2.createBundle(map(node.sourceFiles, (sourceFile) => {
                        if (sourceFile.isDeclarationFile)
                            return void 0;
                        hasNoDefaultLib = hasNoDefaultLib || sourceFile.hasNoDefaultLib;
                        currentSourceFile = sourceFile;
                        enclosingDeclaration = sourceFile;
                        lateMarkedStatements = void 0;
                        suppressNewDiagnosticContexts = false;
                        lateStatementReplacementMap = /* @__PURE__ */ new Map();
                        getSymbolAccessibilityDiagnostic = throwDiagnostic;
                        needsScopeFixMarker = false;
                        resultHasScopeMarker = false;
                        collectReferences(sourceFile, refs);
                        collectLibs(sourceFile, libs2);
                        if (isExternalOrCommonJsModule(sourceFile) || isJsonSourceFile(sourceFile)) {
                            resultHasExternalModuleIndicator = false;
                            needsDeclare = false;
                            const statements = isSourceFileJS(sourceFile) ? factory2.createNodeArray(transformDeclarationsForJS(sourceFile, 
                            /*bundled*/
                            true)) : visitNodes2(sourceFile.statements, visitDeclarationStatements, isStatement);
                            const newFile = factory2.updateSourceFile(sourceFile, [factory2.createModuleDeclaration([factory2.createModifier(138 /* DeclareKeyword */)], factory2.createStringLiteral(getResolvedExternalModuleName(context.getEmitHost(), sourceFile)), factory2.createModuleBlock(setTextRange(factory2.createNodeArray(transformAndReplaceLatePaintedStatements(statements)), sourceFile.statements)))], 
                            /*isDeclarationFile*/
                            true, 
                            /*referencedFiles*/
                            [], 
                            /*typeReferences*/
                            [], 
                            /*hasNoDefaultLib*/
                            false, 
                            /*libReferences*/
                            []);
                            return newFile;
                        }
                        needsDeclare = true;
                        const updated2 = isSourceFileJS(sourceFile) ? factory2.createNodeArray(transformDeclarationsForJS(sourceFile)) : visitNodes2(sourceFile.statements, visitDeclarationStatements, isStatement);
                        return factory2.updateSourceFile(sourceFile, transformAndReplaceLatePaintedStatements(updated2), 
                        /*isDeclarationFile*/
                        true, 
                        /*referencedFiles*/
                        [], 
                        /*typeReferences*/
                        [], 
                        /*hasNoDefaultLib*/
                        false, 
                        /*libReferences*/
                        []);
                    }), mapDefined(node.prepends, (prepend) => {
                        if (prepend.kind === 315 /* InputFiles */) {
                            const sourceFile = createUnparsedSourceFile(prepend, "dts", stripInternal);
                            hasNoDefaultLib = hasNoDefaultLib || !!sourceFile.hasNoDefaultLib;
                            collectReferences(sourceFile, refs);
                            recordTypeReferenceDirectivesIfNecessary(map(sourceFile.typeReferenceDirectives, (ref) => [ref.fileName, ref.resolutionMode]));
                            collectLibs(sourceFile, libs2);
                            return sourceFile;
                        }
                        return prepend;
                    }));
                    bundle.syntheticFileReferences = [];
                    bundle.syntheticTypeReferences = getFileReferencesForUsedTypeReferences();
                    bundle.syntheticLibReferences = getLibReferences();
                    bundle.hasNoDefaultLib = hasNoDefaultLib;
                    const outputFilePath2 = getDirectoryPath(normalizeSlashes(getOutputPathsFor(node, host, 
                    /*forceDtsPaths*/
                    true).declarationFilePath));
                    const referenceVisitor2 = mapReferencesIntoArray(bundle.syntheticFileReferences, outputFilePath2);
                    refs.forEach(referenceVisitor2);
                    return bundle;
                }
                needsDeclare = true;
                needsScopeFixMarker = false;
                resultHasScopeMarker = false;
                enclosingDeclaration = node;
                currentSourceFile = node;
                getSymbolAccessibilityDiagnostic = throwDiagnostic;
                isBundledEmit = false;
                resultHasExternalModuleIndicator = false;
                suppressNewDiagnosticContexts = false;
                lateMarkedStatements = void 0;
                lateStatementReplacementMap = /* @__PURE__ */ new Map();
                necessaryTypeReferences = void 0;
                refs = collectReferences(currentSourceFile, /* @__PURE__ */ new Map());
                libs2 = collectLibs(currentSourceFile, /* @__PURE__ */ new Map());
                const references = [];
                const outputFilePath = getDirectoryPath(normalizeSlashes(getOutputPathsFor(node, host, 
                /*forceDtsPaths*/
                true).declarationFilePath));
                const referenceVisitor = mapReferencesIntoArray(references, outputFilePath);
                let combinedStatements;
                if (isSourceFileJS(currentSourceFile)) {
                    combinedStatements = factory2.createNodeArray(transformDeclarationsForJS(node));
                    refs.forEach(referenceVisitor);
                    emittedImports = filter(combinedStatements, isAnyImportSyntax);
                }
                else {
                    const statements = visitNodes2(node.statements, visitDeclarationStatements, isStatement);
                    combinedStatements = setTextRange(factory2.createNodeArray(transformAndReplaceLatePaintedStatements(statements)), node.statements);
                    refs.forEach(referenceVisitor);
                    emittedImports = filter(combinedStatements, isAnyImportSyntax);
                    if (isExternalModule(node) && (!resultHasExternalModuleIndicator || needsScopeFixMarker && !resultHasScopeMarker)) {
                        combinedStatements = setTextRange(factory2.createNodeArray([...combinedStatements, createEmptyExports(factory2)]), combinedStatements);
                    }
                }
                const updated = factory2.updateSourceFile(node, combinedStatements, 
                /*isDeclarationFile*/
                true, references, getFileReferencesForUsedTypeReferences(), node.hasNoDefaultLib, getLibReferences());
                updated.exportedModulesFromDeclarationEmit = exportedModulesFromDeclarationEmit;
                return updated;
                function getLibReferences() {
                    return arrayFrom(libs2.keys(), (lib) => ({ fileName: lib, pos: -1, end: -1 }));
                }
                function getFileReferencesForUsedTypeReferences() {
                    return necessaryTypeReferences ? mapDefined(arrayFrom(necessaryTypeReferences.keys()), getFileReferenceForSpecifierModeTuple) : [];
                }
                function getFileReferenceForSpecifierModeTuple([typeName, mode]) {
                    if (emittedImports) {
                        for (const importStatement of emittedImports) {
                            if (isImportEqualsDeclaration(importStatement) && isExternalModuleReference(importStatement.moduleReference)) {
                                const expr = importStatement.moduleReference.expression;
                                if (isStringLiteralLike(expr) && expr.text === typeName) {
                                    return void 0;
                                }
                            }
                            else if (isImportDeclaration(importStatement) && isStringLiteral(importStatement.moduleSpecifier) && importStatement.moduleSpecifier.text === typeName) {
                                return void 0;
                            }
                        }
                    }
                    return { fileName: typeName, pos: -1, end: -1, ...mode ? { resolutionMode: mode } : void 0 };
                }
                function mapReferencesIntoArray(references2, outputFilePath2) {
                    return (file) => {
                        if (exportedModulesFromDeclarationEmit == null ? void 0 : exportedModulesFromDeclarationEmit.includes(file.symbol)) {
                            return;
                        }
                        let declFileName;
                        if (file.isDeclarationFile) {
                            declFileName = file.fileName;
                        }
                        else {
                            if (isBundledEmit && contains(node.sourceFiles, file))
                                return;
                            const paths = getOutputPathsFor(file, host, 
                            /*forceDtsPaths*/
                            true);
                            declFileName = paths.declarationFilePath || paths.jsFilePath || file.fileName;
                        }
                        if (declFileName) {
                            const specifier = getModuleSpecifier(options, currentSourceFile, getNormalizedAbsolutePath(outputFilePath2, host.getCurrentDirectory()), getNormalizedAbsolutePath(declFileName, host.getCurrentDirectory()), host);
                            if (!pathIsRelative(specifier)) {
                                recordTypeReferenceDirectivesIfNecessary([[
                                        specifier,
                                        /*mode*/
                                        void 0
                                    ]]);
                                return;
                            }
                            let fileName = getRelativePathToDirectoryOrUrl(outputFilePath2, declFileName, host.getCurrentDirectory(), host.getCanonicalFileName, 
                            /*isAbsolutePathAnUrl*/
                            false);
                            if (startsWith(fileName, "./") && hasExtension(fileName)) {
                                fileName = fileName.substring(2);
                            }
                            if (startsWith(fileName, "node_modules/") || pathContainsNodeModules(fileName)) {
                                return;
                            }
                            references2.push({ pos: -1, end: -1, fileName });
                        }
                    };
                }
            }
            function collectReferences(sourceFile, ret) {
                if (noResolve || !isUnparsedSource(sourceFile) && isSourceFileJS(sourceFile))
                    return ret;
                forEach(sourceFile.referencedFiles, (f) => {
                    const elem = host.getSourceFileFromReference(sourceFile, f);
                    if (elem) {
                        ret.set(getOriginalNodeId(elem), elem);
                    }
                });
                return ret;
            }
            function collectLibs(sourceFile, ret) {
                forEach(sourceFile.libReferenceDirectives, (ref) => {
                    const lib = host.getLibFileFromReference(ref);
                    if (lib) {
                        ret.set(toFileNameLowerCase(ref.fileName), true);
                    }
                });
                return ret;
            }
            function filterBindingPatternInitializers(name) {
                if (name.kind === 80 /* Identifier */) {
                    return name;
                }
                else {
                    if (name.kind === 207 /* ArrayBindingPattern */) {
                        return factory2.updateArrayBindingPattern(name, visitNodes2(name.elements, visitBindingElement, isArrayBindingElement));
                    }
                    else {
                        return factory2.updateObjectBindingPattern(name, visitNodes2(name.elements, visitBindingElement, isBindingElement));
                    }
                }
                function visitBindingElement(elem) {
                    if (elem.kind === 232 /* OmittedExpression */) {
                        return elem;
                    }
                    if (elem.propertyName && isComputedPropertyName(elem.propertyName) && isEntityNameExpression(elem.propertyName.expression)) {
                        checkEntityNameVisibility(elem.propertyName.expression, enclosingDeclaration);
                    }
                    return factory2.updateBindingElement(elem, elem.dotDotDotToken, elem.propertyName, filterBindingPatternInitializers(elem.name), shouldPrintWithInitializer(elem) ? elem.initializer : void 0);
                }
            }
            function ensureParameter(p, modifierMask, type) {
                let oldDiag;
                if (!suppressNewDiagnosticContexts) {
                    oldDiag = getSymbolAccessibilityDiagnostic;
                    getSymbolAccessibilityDiagnostic = createGetSymbolAccessibilityDiagnosticForNode(p);
                }
                const newParam = factory2.updateParameterDeclaration(p, maskModifiers(factory2, p, modifierMask), p.dotDotDotToken, filterBindingPatternInitializers(p.name), resolver.isOptionalParameter(p) ? p.questionToken || factory2.createToken(58 /* QuestionToken */) : void 0, ensureType(p, type || p.type, 
                /*ignorePrivate*/
                true), 
                // Ignore private param props, since this type is going straight back into a param
                ensureNoInitializer(p));
                if (!suppressNewDiagnosticContexts) {
                    getSymbolAccessibilityDiagnostic = oldDiag;
                }
                return newParam;
            }
            function shouldPrintWithInitializer(node) {
                return canHaveLiteralInitializer(node) && resolver.isLiteralConstDeclaration(getParseTreeNode(node));
            }
            function ensureNoInitializer(node) {
                if (shouldPrintWithInitializer(node)) {
                    return resolver.createLiteralConstValue(getParseTreeNode(node), symbolTracker);
                }
                return void 0;
            }
            function ensureType(node, type, ignorePrivate) {
                if (!ignorePrivate && hasEffectiveModifier(node, 2 /* Private */)) {
                    return;
                }
                if (shouldPrintWithInitializer(node)) {
                    return;
                }
                const shouldUseResolverType = node.kind === 169 /* Parameter */ && (resolver.isRequiredInitializedParameter(node) || resolver.isOptionalUninitializedParameterProperty(node));
                if (type && !shouldUseResolverType) {
                    return visitNode(type, visitDeclarationSubtree, isTypeNode);
                }
                if (!getParseTreeNode(node)) {
                    return type ? visitNode(type, visitDeclarationSubtree, isTypeNode) : factory2.createKeywordTypeNode(133 /* AnyKeyword */);
                }
                if (node.kind === 178 /* SetAccessor */) {
                    return factory2.createKeywordTypeNode(133 /* AnyKeyword */);
                }
                errorNameNode = node.name;
                let oldDiag;
                if (!suppressNewDiagnosticContexts) {
                    oldDiag = getSymbolAccessibilityDiagnostic;
                    getSymbolAccessibilityDiagnostic = createGetSymbolAccessibilityDiagnosticForNode(node);
                }
                if (node.kind === 260 /* VariableDeclaration */ || node.kind === 208 /* BindingElement */) {
                    return cleanup(resolver.createTypeOfDeclaration(node, enclosingDeclaration, declarationEmitNodeBuilderFlags, symbolTracker));
                }
                if (node.kind === 169 /* Parameter */ || node.kind === 172 /* PropertyDeclaration */ || node.kind === 171 /* PropertySignature */) {
                    if (isPropertySignature(node) || !node.initializer)
                        return cleanup(resolver.createTypeOfDeclaration(node, enclosingDeclaration, declarationEmitNodeBuilderFlags, symbolTracker, shouldUseResolverType));
                    return cleanup(resolver.createTypeOfDeclaration(node, enclosingDeclaration, declarationEmitNodeBuilderFlags, symbolTracker, shouldUseResolverType) || resolver.createTypeOfExpression(node.initializer, enclosingDeclaration, declarationEmitNodeBuilderFlags, symbolTracker));
                }
                return cleanup(resolver.createReturnTypeOfSignatureDeclaration(node, enclosingDeclaration, declarationEmitNodeBuilderFlags, symbolTracker));
                function cleanup(returnValue) {
                    errorNameNode = void 0;
                    if (!suppressNewDiagnosticContexts) {
                        getSymbolAccessibilityDiagnostic = oldDiag;
                    }
                    return returnValue || factory2.createKeywordTypeNode(133 /* AnyKeyword */);
                }
            }
            function isDeclarationAndNotVisible(node) {
                node = getParseTreeNode(node);
                switch (node.kind) {
                    case 262 /* FunctionDeclaration */:
                    case 267 /* ModuleDeclaration */:
                    case 264 /* InterfaceDeclaration */:
                    case 263 /* ClassDeclaration */:
                    case 265 /* TypeAliasDeclaration */:
                    case 266 /* EnumDeclaration */:
                        return !resolver.isDeclarationVisible(node);
                    case 260 /* VariableDeclaration */:
                        return !getBindingNameVisible(node);
                    case 271 /* ImportEqualsDeclaration */:
                    case 272 /* ImportDeclaration */:
                    case 278 /* ExportDeclaration */:
                    case 277 /* ExportAssignment */:
                        return false;
                    case 175 /* ClassStaticBlockDeclaration */:
                        return true;
                }
                return false;
            }
            function shouldEmitFunctionProperties(input) {
                var _a;
                if (input.body) {
                    return true;
                }
                const overloadSignatures = (_a = input.symbol.declarations) == null ? void 0 : _a.filter((decl) => isFunctionDeclaration(decl) && !decl.body);
                return !overloadSignatures || overloadSignatures.indexOf(input) === overloadSignatures.length - 1;
            }
            function getBindingNameVisible(elem) {
                if (isOmittedExpression(elem)) {
                    return false;
                }
                if (isBindingPattern(elem.name)) {
                    return some(elem.name.elements, getBindingNameVisible);
                }
                else {
                    return resolver.isDeclarationVisible(elem);
                }
            }
            function updateParamsList(node, params, modifierMask) {
                if (hasEffectiveModifier(node, 2 /* Private */)) {
                    return factory2.createNodeArray();
                }
                const newParams = map(params, (p) => ensureParameter(p, modifierMask));
                if (!newParams) {
                    return factory2.createNodeArray();
                }
                return factory2.createNodeArray(newParams, params.hasTrailingComma);
            }
            function updateAccessorParamsList(input, isPrivate) {
                let newParams;
                if (!isPrivate) {
                    const thisParameter = getThisParameter(input);
                    if (thisParameter) {
                        newParams = [ensureParameter(thisParameter)];
                    }
                }
                if (isSetAccessorDeclaration(input)) {
                    let newValueParameter;
                    if (!isPrivate) {
                        const valueParameter = getSetAccessorValueParameter(input);
                        if (valueParameter) {
                            const accessorType = getTypeAnnotationFromAllAccessorDeclarations(input, resolver.getAllAccessorDeclarations(input));
                            newValueParameter = ensureParameter(valueParameter, 
                            /*modifierMask*/
                            void 0, accessorType);
                        }
                    }
                    if (!newValueParameter) {
                        newValueParameter = factory2.createParameterDeclaration(
                        /*modifiers*/
                        void 0, 
                        /*dotDotDotToken*/
                        void 0, "value");
                    }
                    newParams = append(newParams, newValueParameter);
                }
                return factory2.createNodeArray(newParams || emptyArray);
            }
            function ensureTypeParams(node, params) {
                return hasEffectiveModifier(node, 2 /* Private */) ? void 0 : visitNodes2(params, visitDeclarationSubtree, isTypeParameterDeclaration);
            }
            function isEnclosingDeclaration(node) {
                return isSourceFile(node) || isTypeAliasDeclaration(node) || isModuleDeclaration(node) || isClassDeclaration(node) || isInterfaceDeclaration(node) || isFunctionLike(node) || isIndexSignatureDeclaration(node) || isMappedTypeNode(node);
            }
            function checkEntityNameVisibility(entityName, enclosingDeclaration2) {
                const visibilityResult = resolver.isEntityNameVisible(entityName, enclosingDeclaration2);
                handleSymbolAccessibilityError(visibilityResult);
                recordTypeReferenceDirectivesIfNecessary(resolver.getTypeReferenceDirectivesForEntityName(entityName));
            }
            function preserveJsDoc(updated, original) {
                if (hasJSDocNodes(updated) && hasJSDocNodes(original)) {
                    updated.jsDoc = original.jsDoc;
                }
                return setCommentRange(updated, getCommentRange(original));
            }
            function rewriteModuleSpecifier(parent2, input) {
                if (!input)
                    return void 0;
                resultHasExternalModuleIndicator = resultHasExternalModuleIndicator || parent2.kind !== 267 /* ModuleDeclaration */ && parent2.kind !== 205 /* ImportType */;
                if (isStringLiteralLike(input)) {
                    if (isBundledEmit) {
                        const newName = getExternalModuleNameFromDeclaration(context.getEmitHost(), resolver, parent2);
                        if (newName) {
                            return factory2.createStringLiteral(newName);
                        }
                    }
                    else {
                        const symbol = resolver.getSymbolOfExternalModuleSpecifier(input);
                        if (symbol) {
                            (exportedModulesFromDeclarationEmit || (exportedModulesFromDeclarationEmit = [])).push(symbol);
                        }
                    }
                }
                return input;
            }
            function transformImportEqualsDeclaration(decl) {
                if (!resolver.isDeclarationVisible(decl))
                    return;
                if (decl.moduleReference.kind === 283 /* ExternalModuleReference */) {
                    const specifier = getExternalModuleImportEqualsDeclarationExpression(decl);
                    return factory2.updateImportEqualsDeclaration(decl, decl.modifiers, decl.isTypeOnly, decl.name, factory2.updateExternalModuleReference(decl.moduleReference, rewriteModuleSpecifier(decl, specifier)));
                }
                else {
                    const oldDiag = getSymbolAccessibilityDiagnostic;
                    getSymbolAccessibilityDiagnostic = createGetSymbolAccessibilityDiagnosticForNode(decl);
                    checkEntityNameVisibility(decl.moduleReference, enclosingDeclaration);
                    getSymbolAccessibilityDiagnostic = oldDiag;
                    return decl;
                }
            }
            function transformImportDeclaration(decl) {
                if (!decl.importClause) {
                    return factory2.updateImportDeclaration(decl, decl.modifiers, decl.importClause, rewriteModuleSpecifier(decl, decl.moduleSpecifier), tryGetResolutionModeOverride(decl.attributes));
                }
                const visibleDefaultBinding = decl.importClause && decl.importClause.name && resolver.isDeclarationVisible(decl.importClause) ? decl.importClause.name : void 0;
                if (!decl.importClause.namedBindings) {
                    return visibleDefaultBinding && factory2.updateImportDeclaration(decl, decl.modifiers, factory2.updateImportClause(decl.importClause, decl.importClause.isTypeOnly, visibleDefaultBinding, 
                    /*namedBindings*/
                    void 0), rewriteModuleSpecifier(decl, decl.moduleSpecifier), tryGetResolutionModeOverride(decl.attributes));
                }
                if (decl.importClause.namedBindings.kind === 274 /* NamespaceImport */) {
                    const namedBindings = resolver.isDeclarationVisible(decl.importClause.namedBindings) ? decl.importClause.namedBindings : (
                    /*namedBindings*/
                    void 0);
                    return visibleDefaultBinding || namedBindings ? factory2.updateImportDeclaration(decl, decl.modifiers, factory2.updateImportClause(decl.importClause, decl.importClause.isTypeOnly, visibleDefaultBinding, namedBindings), rewriteModuleSpecifier(decl, decl.moduleSpecifier), tryGetResolutionModeOverride(decl.attributes)) : void 0;
                }
                const bindingList = mapDefined(decl.importClause.namedBindings.elements, (b) => resolver.isDeclarationVisible(b) ? b : void 0);
                if (bindingList && bindingList.length || visibleDefaultBinding) {
                    return factory2.updateImportDeclaration(decl, decl.modifiers, factory2.updateImportClause(decl.importClause, decl.importClause.isTypeOnly, visibleDefaultBinding, bindingList && bindingList.length ? factory2.updateNamedImports(decl.importClause.namedBindings, bindingList) : void 0), rewriteModuleSpecifier(decl, decl.moduleSpecifier), tryGetResolutionModeOverride(decl.attributes));
                }
                if (resolver.isImportRequiredByAugmentation(decl)) {
                    return factory2.updateImportDeclaration(decl, decl.modifiers, 
                    /*importClause*/
                    void 0, rewriteModuleSpecifier(decl, decl.moduleSpecifier), tryGetResolutionModeOverride(decl.attributes));
                }
            }
            function tryGetResolutionModeOverride(node) {
                const mode = getResolutionModeOverride(node);
                return node && mode !== void 0 ? node : void 0;
            }
            function transformAndReplaceLatePaintedStatements(statements) {
                while (length(lateMarkedStatements)) {
                    const i = lateMarkedStatements.shift();
                    if (!isLateVisibilityPaintedStatement(i)) {
                        return Debug.fail(`Late replaced statement was found which is not handled by the declaration transformer!: ${Debug.formatSyntaxKind(i.kind)}`);
                    }
                    const priorNeedsDeclare = needsDeclare;
                    needsDeclare = i.parent && isSourceFile(i.parent) && !(isExternalModule(i.parent) && isBundledEmit);
                    const result = transformTopLevelDeclaration(i);
                    needsDeclare = priorNeedsDeclare;
                    lateStatementReplacementMap.set(getOriginalNodeId(i), result);
                }
                return visitNodes2(statements, visitLateVisibilityMarkedStatements, isStatement);
                function visitLateVisibilityMarkedStatements(statement) {
                    if (isLateVisibilityPaintedStatement(statement)) {
                        const key = getOriginalNodeId(statement);
                        if (lateStatementReplacementMap.has(key)) {
                            const result = lateStatementReplacementMap.get(key);
                            lateStatementReplacementMap.delete(key);
                            if (result) {
                                if (isArray(result) ? some(result, needsScopeMarker) : needsScopeMarker(result)) {
                                    needsScopeFixMarker = true;
                                }
                                if (isSourceFile(statement.parent) && (isArray(result) ? some(result, isExternalModuleIndicator) : isExternalModuleIndicator(result))) {
                                    resultHasExternalModuleIndicator = true;
                                }
                            }
                            return result;
                        }
                    }
                    return statement;
                }
            }
            function visitDeclarationSubtree(input) {
                if (shouldStripInternal(input))
                    return;
                if (isDeclaration(input)) {
                    if (isDeclarationAndNotVisible(input))
                        return;
                    if (hasDynamicName(input) && !resolver.isLateBound(getParseTreeNode(input))) {
                        return;
                    }
                }
                if (isFunctionLike(input) && resolver.isImplementationOfOverload(input))
                    return;
                if (isSemicolonClassElement(input))
                    return;
                let previousEnclosingDeclaration;
                if (isEnclosingDeclaration(input)) {
                    previousEnclosingDeclaration = enclosingDeclaration;
                    enclosingDeclaration = input;
                }
                const oldDiag = getSymbolAccessibilityDiagnostic;
                const canProduceDiagnostic = canProduceDiagnostics(input);
                const oldWithinObjectLiteralType = suppressNewDiagnosticContexts;
                let shouldEnterSuppressNewDiagnosticsContextContext = (input.kind === 187 /* TypeLiteral */ || input.kind === 200 /* MappedType */) && input.parent.kind !== 265 /* TypeAliasDeclaration */;
                if (isMethodDeclaration(input) || isMethodSignature(input)) {
                    if (hasEffectiveModifier(input, 2 /* Private */)) {
                        if (input.symbol && input.symbol.declarations && input.symbol.declarations[0] !== input)
                            return;
                        return cleanup(factory2.createPropertyDeclaration(ensureModifiers(input), input.name, 
                        /*questionOrExclamationToken*/
                        void 0, 
                        /*type*/
                        void 0, 
                        /*initializer*/
                        void 0));
                    }
                }
                if (canProduceDiagnostic && !suppressNewDiagnosticContexts) {
                    getSymbolAccessibilityDiagnostic = createGetSymbolAccessibilityDiagnosticForNode(input);
                }
                if (isTypeQueryNode(input)) {
                    checkEntityNameVisibility(input.exprName, enclosingDeclaration);
                }
                if (shouldEnterSuppressNewDiagnosticsContextContext) {
                    suppressNewDiagnosticContexts = true;
                }
                if (isProcessedComponent(input)) {
                    switch (input.kind) {
                        case 233 /* ExpressionWithTypeArguments */: {
                            if (isEntityName(input.expression) || isEntityNameExpression(input.expression)) {
                                checkEntityNameVisibility(input.expression, enclosingDeclaration);
                            }
                            const node = visitEachChild(input, visitDeclarationSubtree, context);
                            return cleanup(factory2.updateExpressionWithTypeArguments(node, node.expression, node.typeArguments));
                        }
                        case 183 /* TypeReference */: {
                            checkEntityNameVisibility(input.typeName, enclosingDeclaration);
                            const node = visitEachChild(input, visitDeclarationSubtree, context);
                            return cleanup(factory2.updateTypeReferenceNode(node, node.typeName, node.typeArguments));
                        }
                        case 180 /* ConstructSignature */:
                            return cleanup(factory2.updateConstructSignature(input, ensureTypeParams(input, input.typeParameters), updateParamsList(input, input.parameters), ensureType(input, input.type)));
                        case 176 /* Constructor */: {
                            const ctor = factory2.createConstructorDeclaration(
                            /*modifiers*/
                            ensureModifiers(input), updateParamsList(input, input.parameters, 0 /* None */), 
                            /*body*/
                            void 0);
                            return cleanup(ctor);
                        }
                        case 174 /* MethodDeclaration */: {
                            if (isPrivateIdentifier(input.name)) {
                                return cleanup(
                                /*returnValue*/
                                void 0);
                            }
                            const sig = factory2.createMethodDeclaration(ensureModifiers(input), 
                            /*asteriskToken*/
                            void 0, input.name, input.questionToken, ensureTypeParams(input, input.typeParameters), updateParamsList(input, input.parameters), ensureType(input, input.type), 
                            /*body*/
                            void 0);
                            return cleanup(sig);
                        }
                        case 177 /* GetAccessor */: {
                            if (isPrivateIdentifier(input.name)) {
                                return cleanup(
                                /*returnValue*/
                                void 0);
                            }
                            const accessorType = getTypeAnnotationFromAllAccessorDeclarations(input, resolver.getAllAccessorDeclarations(input));
                            return cleanup(factory2.updateGetAccessorDeclaration(input, ensureModifiers(input), input.name, updateAccessorParamsList(input, hasEffectiveModifier(input, 2 /* Private */)), ensureType(input, accessorType), 
                            /*body*/
                            void 0));
                        }
                        case 178 /* SetAccessor */: {
                            if (isPrivateIdentifier(input.name)) {
                                return cleanup(
                                /*returnValue*/
                                void 0);
                            }
                            return cleanup(factory2.updateSetAccessorDeclaration(input, ensureModifiers(input), input.name, updateAccessorParamsList(input, hasEffectiveModifier(input, 2 /* Private */)), 
                            /*body*/
                            void 0));
                        }
                        case 172 /* PropertyDeclaration */:
                            if (isPrivateIdentifier(input.name)) {
                                return cleanup(
                                /*returnValue*/
                                void 0);
                            }
                            return cleanup(factory2.updatePropertyDeclaration(input, ensureModifiers(input), input.name, input.questionToken, ensureType(input, input.type), ensureNoInitializer(input)));
                        case 171 /* PropertySignature */:
                            if (isPrivateIdentifier(input.name)) {
                                return cleanup(
                                /*returnValue*/
                                void 0);
                            }
                            return cleanup(factory2.updatePropertySignature(input, ensureModifiers(input), input.name, input.questionToken, ensureType(input, input.type)));
                        case 173 /* MethodSignature */: {
                            if (isPrivateIdentifier(input.name)) {
                                return cleanup(
                                /*returnValue*/
                                void 0);
                            }
                            return cleanup(factory2.updateMethodSignature(input, ensureModifiers(input), input.name, input.questionToken, ensureTypeParams(input, input.typeParameters), updateParamsList(input, input.parameters), ensureType(input, input.type)));
                        }
                        case 179 /* CallSignature */: {
                            return cleanup(factory2.updateCallSignature(input, ensureTypeParams(input, input.typeParameters), updateParamsList(input, input.parameters), ensureType(input, input.type)));
                        }
                        case 181 /* IndexSignature */: {
                            return cleanup(factory2.updateIndexSignature(input, ensureModifiers(input), updateParamsList(input, input.parameters), visitNode(input.type, visitDeclarationSubtree, isTypeNode) || factory2.createKeywordTypeNode(133 /* AnyKeyword */)));
                        }
                        case 260 /* VariableDeclaration */: {
                            if (isBindingPattern(input.name)) {
                                return recreateBindingPattern(input.name);
                            }
                            shouldEnterSuppressNewDiagnosticsContextContext = true;
                            suppressNewDiagnosticContexts = true;
                            return cleanup(factory2.updateVariableDeclaration(input, input.name, 
                            /*exclamationToken*/
                            void 0, ensureType(input, input.type), ensureNoInitializer(input)));
                        }
                        case 168 /* TypeParameter */: {
                            if (isPrivateMethodTypeParameter(input) && (input.default || input.constraint)) {
                                return cleanup(factory2.updateTypeParameterDeclaration(input, input.modifiers, input.name, 
                                /*constraint*/
                                void 0, 
                                /*defaultType*/
                                void 0));
                            }
                            return cleanup(visitEachChild(input, visitDeclarationSubtree, context));
                        }
                        case 194 /* ConditionalType */: {
                            const checkType = visitNode(input.checkType, visitDeclarationSubtree, isTypeNode);
                            const extendsType = visitNode(input.extendsType, visitDeclarationSubtree, isTypeNode);
                            const oldEnclosingDecl = enclosingDeclaration;
                            enclosingDeclaration = input.trueType;
                            const trueType = visitNode(input.trueType, visitDeclarationSubtree, isTypeNode);
                            enclosingDeclaration = oldEnclosingDecl;
                            const falseType = visitNode(input.falseType, visitDeclarationSubtree, isTypeNode);
                            Debug.assert(checkType);
                            Debug.assert(extendsType);
                            Debug.assert(trueType);
                            Debug.assert(falseType);
                            return cleanup(factory2.updateConditionalTypeNode(input, checkType, extendsType, trueType, falseType));
                        }
                        case 184 /* FunctionType */: {
                            return cleanup(factory2.updateFunctionTypeNode(input, visitNodes2(input.typeParameters, visitDeclarationSubtree, isTypeParameterDeclaration), updateParamsList(input, input.parameters), Debug.checkDefined(visitNode(input.type, visitDeclarationSubtree, isTypeNode))));
                        }
                        case 185 /* ConstructorType */: {
                            return cleanup(factory2.updateConstructorTypeNode(input, ensureModifiers(input), visitNodes2(input.typeParameters, visitDeclarationSubtree, isTypeParameterDeclaration), updateParamsList(input, input.parameters), Debug.checkDefined(visitNode(input.type, visitDeclarationSubtree, isTypeNode))));
                        }
                        case 205 /* ImportType */: {
                            if (!isLiteralImportTypeNode(input))
                                return cleanup(input);
                            trackReferencedAmbientModuleFromImport(input);
                            return cleanup(factory2.updateImportTypeNode(input, factory2.updateLiteralTypeNode(input.argument, rewriteModuleSpecifier(input, input.argument.literal)), input.attributes, input.qualifier, visitNodes2(input.typeArguments, visitDeclarationSubtree, isTypeNode), input.isTypeOf));
                        }
                        default:
                            Debug.assertNever(input, `Attempted to process unhandled node kind: ${Debug.formatSyntaxKind(input.kind)}`);
                    }
                }
                if (isTupleTypeNode(input) && getLineAndCharacterOfPosition(currentSourceFile, input.pos).line === getLineAndCharacterOfPosition(currentSourceFile, input.end).line) {
                    setEmitFlags(input, 1 /* SingleLine */);
                }
                return cleanup(visitEachChild(input, visitDeclarationSubtree, context));
                function cleanup(returnValue) {
                    if (returnValue && canProduceDiagnostic && hasDynamicName(input)) {
                        checkName(input);
                    }
                    if (isEnclosingDeclaration(input)) {
                        enclosingDeclaration = previousEnclosingDeclaration;
                    }
                    if (canProduceDiagnostic && !suppressNewDiagnosticContexts) {
                        getSymbolAccessibilityDiagnostic = oldDiag;
                    }
                    if (shouldEnterSuppressNewDiagnosticsContextContext) {
                        suppressNewDiagnosticContexts = oldWithinObjectLiteralType;
                    }
                    if (returnValue === input) {
                        return returnValue;
                    }
                    return returnValue && setOriginalNode(preserveJsDoc(returnValue, input), input);
                }
            }
            function isPrivateMethodTypeParameter(node) {
                return node.parent.kind === 174 /* MethodDeclaration */ && hasEffectiveModifier(node.parent, 2 /* Private */);
            }
            function visitDeclarationStatements(input) {
                if (!isPreservedDeclarationStatement(input)) {
                    return;
                }
                if (shouldStripInternal(input))
                    return;
                switch (input.kind) {
                    case 278 /* ExportDeclaration */: {
                        if (isSourceFile(input.parent)) {
                            resultHasExternalModuleIndicator = true;
                        }
                        resultHasScopeMarker = true;
                        trackReferencedAmbientModuleFromImport(input);
                        return factory2.updateExportDeclaration(input, input.modifiers, input.isTypeOnly, input.exportClause, rewriteModuleSpecifier(input, input.moduleSpecifier), tryGetResolutionModeOverride(input.attributes));
                    }
                    case 277 /* ExportAssignment */: {
                        if (isSourceFile(input.parent)) {
                            resultHasExternalModuleIndicator = true;
                        }
                        resultHasScopeMarker = true;
                        if (input.expression.kind === 80 /* Identifier */) {
                            return input;
                        }
                        else {
                            const newId = factory2.createUniqueName("_default", 16 /* Optimistic */);
                            getSymbolAccessibilityDiagnostic = () => ({
                                diagnosticMessage: Diagnostics.Default_export_of_the_module_has_or_is_using_private_name_0,
                                errorNode: input
                            });
                            errorFallbackNode = input;
                            const varDecl = factory2.createVariableDeclaration(newId, 
                            /*exclamationToken*/
                            void 0, resolver.createTypeOfExpression(input.expression, input, declarationEmitNodeBuilderFlags, symbolTracker), 
                            /*initializer*/
                            void 0);
                            errorFallbackNode = void 0;
                            const statement = factory2.createVariableStatement(needsDeclare ? [factory2.createModifier(138 /* DeclareKeyword */)] : [], factory2.createVariableDeclarationList([varDecl], 2 /* Const */));
                            preserveJsDoc(statement, input);
                            removeAllComments(input);
                            return [statement, factory2.updateExportAssignment(input, input.modifiers, newId)];
                        }
                    }
                }
                const result = transformTopLevelDeclaration(input);
                lateStatementReplacementMap.set(getOriginalNodeId(input), result);
                return input;
            }
            function stripExportModifiers(statement) {
                if (isImportEqualsDeclaration(statement) || hasEffectiveModifier(statement, 2048 /* Default */) || !canHaveModifiers(statement)) {
                    return statement;
                }
                const modifiers = factory2.createModifiersFromModifierFlags(getEffectiveModifierFlags(statement) & (131071 /* All */ ^ 32 /* Export */));
                return factory2.replaceModifiers(statement, modifiers);
            }
            function updateModuleDeclarationAndKeyword(node, modifiers, name, body) {
                const updated = factory2.updateModuleDeclaration(node, modifiers, name, body);
                if (isAmbientModule(updated) || updated.flags & 32 /* Namespace */) {
                    return updated;
                }
                const fixed = factory2.createModuleDeclaration(updated.modifiers, updated.name, updated.body, updated.flags | 32 /* Namespace */);
                setOriginalNode(fixed, updated);
                setTextRange(fixed, updated);
                return fixed;
            }
            function transformTopLevelDeclaration(input) {
                if (lateMarkedStatements) {
                    while (orderedRemoveItem(lateMarkedStatements, input))
                        ;
                }
                if (shouldStripInternal(input))
                    return;
                switch (input.kind) {
                    case 271 /* ImportEqualsDeclaration */: {
                        const transformed = transformImportEqualsDeclaration(input);
                        if (transformed) {
                            trackReferencedAmbientModuleFromImport(input);
                        }
                        return transformed;
                    }
                    case 272 /* ImportDeclaration */: {
                        const transformed = transformImportDeclaration(input);
                        if (transformed) {
                            trackReferencedAmbientModuleFromImport(input);
                        }
                        return transformed;
                    }
                }
                if (isDeclaration(input) && isDeclarationAndNotVisible(input))
                    return;
                if (isFunctionLike(input) && resolver.isImplementationOfOverload(input))
                    return;
                let previousEnclosingDeclaration;
                if (isEnclosingDeclaration(input)) {
                    previousEnclosingDeclaration = enclosingDeclaration;
                    enclosingDeclaration = input;
                }
                const canProdiceDiagnostic = canProduceDiagnostics(input);
                const oldDiag = getSymbolAccessibilityDiagnostic;
                if (canProdiceDiagnostic) {
                    getSymbolAccessibilityDiagnostic = createGetSymbolAccessibilityDiagnosticForNode(input);
                }
                const previousNeedsDeclare = needsDeclare;
                switch (input.kind) {
                    case 265 /* TypeAliasDeclaration */: {
                        needsDeclare = false;
                        const clean2 = cleanup(factory2.updateTypeAliasDeclaration(input, ensureModifiers(input), input.name, visitNodes2(input.typeParameters, visitDeclarationSubtree, isTypeParameterDeclaration), Debug.checkDefined(visitNode(input.type, visitDeclarationSubtree, isTypeNode))));
                        needsDeclare = previousNeedsDeclare;
                        return clean2;
                    }
                    case 264 /* InterfaceDeclaration */: {
                        return cleanup(factory2.updateInterfaceDeclaration(input, ensureModifiers(input), input.name, ensureTypeParams(input, input.typeParameters), transformHeritageClauses(input.heritageClauses), visitNodes2(input.members, visitDeclarationSubtree, isTypeElement)));
                    }
                    case 262 /* FunctionDeclaration */: {
                        const clean2 = cleanup(factory2.updateFunctionDeclaration(input, ensureModifiers(input), 
                        /*asteriskToken*/
                        void 0, input.name, ensureTypeParams(input, input.typeParameters), updateParamsList(input, input.parameters), ensureType(input, input.type), 
                        /*body*/
                        void 0));
                        if (clean2 && resolver.isExpandoFunctionDeclaration(input) && shouldEmitFunctionProperties(input)) {
                            const props = resolver.getPropertiesOfContainerFunction(input);
                            const fakespace = parseNodeFactory.createModuleDeclaration(
                            /*modifiers*/
                            void 0, clean2.name || factory2.createIdentifier("_default"), factory2.createModuleBlock([]), 32 /* Namespace */);
                            setParent(fakespace, enclosingDeclaration);
                            fakespace.locals = createSymbolTable(props);
                            fakespace.symbol = props[0].parent;
                            const exportMappings = [];
                            let declarations = mapDefined(props, (p) => {
                                if (!isExpandoPropertyDeclaration(p.valueDeclaration)) {
                                    return void 0;
                                }
                                const nameStr = unescapeLeadingUnderscores(p.escapedName);
                                if (!isIdentifierText(nameStr, 99 /* ESNext */)) {
                                    return void 0;
                                }
                                getSymbolAccessibilityDiagnostic = createGetSymbolAccessibilityDiagnosticForNode(p.valueDeclaration);
                                const type = resolver.createTypeOfDeclaration(p.valueDeclaration, fakespace, declarationEmitNodeBuilderFlags, symbolTracker);
                                getSymbolAccessibilityDiagnostic = oldDiag;
                                const isNonContextualKeywordName = isStringANonContextualKeyword(nameStr);
                                const name = isNonContextualKeywordName ? factory2.getGeneratedNameForNode(p.valueDeclaration) : factory2.createIdentifier(nameStr);
                                if (isNonContextualKeywordName) {
                                    exportMappings.push([name, nameStr]);
                                }
                                const varDecl = factory2.createVariableDeclaration(name, 
                                /*exclamationToken*/
                                void 0, type, 
                                /*initializer*/
                                void 0);
                                return factory2.createVariableStatement(isNonContextualKeywordName ? void 0 : [factory2.createToken(95 /* ExportKeyword */)], factory2.createVariableDeclarationList([varDecl]));
                            });
                            if (!exportMappings.length) {
                                declarations = mapDefined(declarations, (declaration) => factory2.replaceModifiers(declaration, 0 /* None */));
                            }
                            else {
                                declarations.push(factory2.createExportDeclaration(
                                /*modifiers*/
                                void 0, 
                                /*isTypeOnly*/
                                false, factory2.createNamedExports(map(exportMappings, ([gen, exp]) => {
                                    return factory2.createExportSpecifier(
                                    /*isTypeOnly*/
                                    false, gen, exp);
                                }))));
                            }
                            const namespaceDecl = factory2.createModuleDeclaration(ensureModifiers(input), input.name, factory2.createModuleBlock(declarations), 32 /* Namespace */);
                            if (!hasEffectiveModifier(clean2, 2048 /* Default */)) {
                                return [clean2, namespaceDecl];
                            }
                            const modifiers = factory2.createModifiersFromModifierFlags(getEffectiveModifierFlags(clean2) & ~2080 /* ExportDefault */ | 128 /* Ambient */);
                            const cleanDeclaration = factory2.updateFunctionDeclaration(clean2, modifiers, 
                            /*asteriskToken*/
                            void 0, clean2.name, clean2.typeParameters, clean2.parameters, clean2.type, 
                            /*body*/
                            void 0);
                            const namespaceDeclaration = factory2.updateModuleDeclaration(namespaceDecl, modifiers, namespaceDecl.name, namespaceDecl.body);
                            const exportDefaultDeclaration = factory2.createExportAssignment(
                            /*modifiers*/
                            void 0, 
                            /*isExportEquals*/
                            false, namespaceDecl.name);
                            if (isSourceFile(input.parent)) {
                                resultHasExternalModuleIndicator = true;
                            }
                            resultHasScopeMarker = true;
                            return [cleanDeclaration, namespaceDeclaration, exportDefaultDeclaration];
                        }
                        else {
                            return clean2;
                        }
                    }
                    case 267 /* ModuleDeclaration */: {
                        needsDeclare = false;
                        const inner = input.body;
                        if (inner && inner.kind === 268 /* ModuleBlock */) {
                            const oldNeedsScopeFix = needsScopeFixMarker;
                            const oldHasScopeFix = resultHasScopeMarker;
                            resultHasScopeMarker = false;
                            needsScopeFixMarker = false;
                            const statements = visitNodes2(inner.statements, visitDeclarationStatements, isStatement);
                            let lateStatements = transformAndReplaceLatePaintedStatements(statements);
                            if (input.flags & 33554432 /* Ambient */) {
                                needsScopeFixMarker = false;
                            }
                            if (!isGlobalScopeAugmentation(input) && !hasScopeMarker2(lateStatements) && !resultHasScopeMarker) {
                                if (needsScopeFixMarker) {
                                    lateStatements = factory2.createNodeArray([...lateStatements, createEmptyExports(factory2)]);
                                }
                                else {
                                    lateStatements = visitNodes2(lateStatements, stripExportModifiers, isStatement);
                                }
                            }
                            const body = factory2.updateModuleBlock(inner, lateStatements);
                            needsDeclare = previousNeedsDeclare;
                            needsScopeFixMarker = oldNeedsScopeFix;
                            resultHasScopeMarker = oldHasScopeFix;
                            const mods = ensureModifiers(input);
                            return cleanup(updateModuleDeclarationAndKeyword(input, mods, isExternalModuleAugmentation(input) ? rewriteModuleSpecifier(input, input.name) : input.name, body));
                        }
                        else {
                            needsDeclare = previousNeedsDeclare;
                            const mods = ensureModifiers(input);
                            needsDeclare = false;
                            visitNode(inner, visitDeclarationStatements);
                            const id = getOriginalNodeId(inner);
                            const body = lateStatementReplacementMap.get(id);
                            lateStatementReplacementMap.delete(id);
                            return cleanup(updateModuleDeclarationAndKeyword(input, mods, input.name, body));
                        }
                    }
                    case 263 /* ClassDeclaration */: {
                        errorNameNode = input.name;
                        errorFallbackNode = input;
                        const modifiers = factory2.createNodeArray(ensureModifiers(input));
                        const typeParameters = ensureTypeParams(input, input.typeParameters);
                        const ctor = getFirstConstructorWithBody(input);
                        let parameterProperties;
                        if (ctor) {
                            const oldDiag2 = getSymbolAccessibilityDiagnostic;
                            parameterProperties = compact(flatMap(ctor.parameters, (param) => {
                                if (!hasSyntacticModifier(param, 31 /* ParameterPropertyModifier */) || shouldStripInternal(param))
                                    return;
                                getSymbolAccessibilityDiagnostic = createGetSymbolAccessibilityDiagnosticForNode(param);
                                if (param.name.kind === 80 /* Identifier */) {
                                    return preserveJsDoc(factory2.createPropertyDeclaration(ensureModifiers(param), param.name, param.questionToken, ensureType(param, param.type), ensureNoInitializer(param)), param);
                                }
                                else {
                                    return walkBindingPattern(param.name);
                                }
                                function walkBindingPattern(pattern) {
                                    let elems;
                                    for (const elem of pattern.elements) {
                                        if (isOmittedExpression(elem))
                                            continue;
                                        if (isBindingPattern(elem.name)) {
                                            elems = concatenate(elems, walkBindingPattern(elem.name));
                                        }
                                        elems = elems || [];
                                        elems.push(factory2.createPropertyDeclaration(ensureModifiers(param), elem.name, 
                                        /*questionOrExclamationToken*/
                                        void 0, ensureType(elem, 
                                        /*type*/
                                        void 0), 
                                        /*initializer*/
                                        void 0));
                                    }
                                    return elems;
                                }
                            }));
                            getSymbolAccessibilityDiagnostic = oldDiag2;
                        }
                        const hasPrivateIdentifier = some(input.members, (member) => !!member.name && isPrivateIdentifier(member.name));
                        const privateIdentifier = hasPrivateIdentifier ? [
                            factory2.createPropertyDeclaration(
                            /*modifiers*/
                            void 0, factory2.createPrivateIdentifier("#private"), 
                            /*questionOrExclamationToken*/
                            void 0, 
                            /*type*/
                            void 0, 
                            /*initializer*/
                            void 0)
                        ] : void 0;
                        const memberNodes = concatenate(concatenate(privateIdentifier, parameterProperties), visitNodes2(input.members, visitDeclarationSubtree, isClassElement));
                        const members = factory2.createNodeArray(memberNodes);
                        const extendsClause = getEffectiveBaseTypeNode(input);
                        if (extendsClause && !isEntityNameExpression(extendsClause.expression) && extendsClause.expression.kind !== 106 /* NullKeyword */) {
                            const oldId = input.name ? unescapeLeadingUnderscores(input.name.escapedText) : "default";
                            const newId = factory2.createUniqueName(`${oldId}_base`, 16 /* Optimistic */);
                            getSymbolAccessibilityDiagnostic = () => ({
                                diagnosticMessage: Diagnostics.extends_clause_of_exported_class_0_has_or_is_using_private_name_1,
                                errorNode: extendsClause,
                                typeName: input.name
                            });
                            const varDecl = factory2.createVariableDeclaration(newId, 
                            /*exclamationToken*/
                            void 0, resolver.createTypeOfExpression(extendsClause.expression, input, declarationEmitNodeBuilderFlags, symbolTracker), 
                            /*initializer*/
                            void 0);
                            const statement = factory2.createVariableStatement(needsDeclare ? [factory2.createModifier(138 /* DeclareKeyword */)] : [], factory2.createVariableDeclarationList([varDecl], 2 /* Const */));
                            const heritageClauses = factory2.createNodeArray(map(input.heritageClauses, (clause) => {
                                if (clause.token === 96 /* ExtendsKeyword */) {
                                    const oldDiag2 = getSymbolAccessibilityDiagnostic;
                                    getSymbolAccessibilityDiagnostic = createGetSymbolAccessibilityDiagnosticForNode(clause.types[0]);
                                    const newClause = factory2.updateHeritageClause(clause, map(clause.types, (t) => factory2.updateExpressionWithTypeArguments(t, newId, visitNodes2(t.typeArguments, visitDeclarationSubtree, isTypeNode))));
                                    getSymbolAccessibilityDiagnostic = oldDiag2;
                                    return newClause;
                                }
                                return factory2.updateHeritageClause(clause, visitNodes2(factory2.createNodeArray(filter(clause.types, (t) => isEntityNameExpression(t.expression) || t.expression.kind === 106 /* NullKeyword */)), visitDeclarationSubtree, isExpressionWithTypeArguments));
                            }));
                            return [
                                statement,
                                cleanup(factory2.updateClassDeclaration(input, modifiers, input.name, typeParameters, heritageClauses, members))
                            ];
                        }
                        else {
                            const heritageClauses = transformHeritageClauses(input.heritageClauses);
                            return cleanup(factory2.updateClassDeclaration(input, modifiers, input.name, typeParameters, heritageClauses, members));
                        }
                    }
                    case 243 /* VariableStatement */: {
                        return cleanup(transformVariableStatement(input));
                    }
                    case 266 /* EnumDeclaration */: {
                        return cleanup(factory2.updateEnumDeclaration(input, factory2.createNodeArray(ensureModifiers(input)), input.name, factory2.createNodeArray(mapDefined(input.members, (m) => {
                            if (shouldStripInternal(m))
                                return;
                            const constValue = resolver.getConstantValue(m);
                            const newInitializer = constValue === void 0 ? void 0 : typeof constValue === "string" ? factory2.createStringLiteral(constValue) : constValue < 0 ? factory2.createPrefixUnaryExpression(41 /* MinusToken */, factory2.createNumericLiteral(-constValue)) : factory2.createNumericLiteral(constValue);
                            return preserveJsDoc(factory2.updateEnumMember(m, m.name, newInitializer), m);
                        }))));
                    }
                }
                return Debug.assertNever(input, `Unhandled top-level node in declaration emit: ${Debug.formatSyntaxKind(input.kind)}`);
                function cleanup(node) {
                    if (isEnclosingDeclaration(input)) {
                        enclosingDeclaration = previousEnclosingDeclaration;
                    }
                    if (canProdiceDiagnostic) {
                        getSymbolAccessibilityDiagnostic = oldDiag;
                    }
                    if (input.kind === 267 /* ModuleDeclaration */) {
                        needsDeclare = previousNeedsDeclare;
                    }
                    if (node === input) {
                        return node;
                    }
                    errorFallbackNode = void 0;
                    errorNameNode = void 0;
                    return node && setOriginalNode(preserveJsDoc(node, input), input);
                }
            }
            function transformVariableStatement(input) {
                if (!forEach(input.declarationList.declarations, getBindingNameVisible))
                    return;
                const nodes = visitNodes2(input.declarationList.declarations, visitDeclarationSubtree, isVariableDeclaration);
                if (!length(nodes))
                    return;
                const modifiers = factory2.createNodeArray(ensureModifiers(input));
                let declList;
                if (isVarUsing(input.declarationList) || isVarAwaitUsing(input.declarationList)) {
                    declList = factory2.createVariableDeclarationList(nodes, 2 /* Const */);
                    setOriginalNode(declList, input.declarationList);
                    setTextRange(declList, input.declarationList);
                    setCommentRange(declList, input.declarationList);
                }
                else {
                    declList = factory2.updateVariableDeclarationList(input.declarationList, nodes);
                }
                return factory2.updateVariableStatement(input, modifiers, declList);
            }
            function recreateBindingPattern(d) {
                return flatten(mapDefined(d.elements, (e) => recreateBindingElement(e)));
            }
            function recreateBindingElement(e) {
                if (e.kind === 232 /* OmittedExpression */) {
                    return;
                }
                if (e.name) {
                    if (!getBindingNameVisible(e))
                        return;
                    if (isBindingPattern(e.name)) {
                        return recreateBindingPattern(e.name);
                    }
                    else {
                        return factory2.createVariableDeclaration(e.name, 
                        /*exclamationToken*/
                        void 0, ensureType(e, 
                        /*type*/
                        void 0), 
                        /*initializer*/
                        void 0);
                    }
                }
            }
            function checkName(node) {
                let oldDiag;
                if (!suppressNewDiagnosticContexts) {
                    oldDiag = getSymbolAccessibilityDiagnostic;
                    getSymbolAccessibilityDiagnostic = createGetSymbolAccessibilityDiagnosticForNodeName(node);
                }
                errorNameNode = node.name;
                Debug.assert(resolver.isLateBound(getParseTreeNode(node)));
                const decl = node;
                const entityName = decl.name.expression;
                checkEntityNameVisibility(entityName, enclosingDeclaration);
                if (!suppressNewDiagnosticContexts) {
                    getSymbolAccessibilityDiagnostic = oldDiag;
                }
                errorNameNode = void 0;
            }
            function shouldStripInternal(node) {
                return !!stripInternal && !!node && isInternalDeclaration(node, currentSourceFile);
            }
            function isScopeMarker2(node) {
                return isExportAssignment(node) || isExportDeclaration(node);
            }
            function hasScopeMarker2(statements) {
                return some(statements, isScopeMarker2);
            }
            function ensureModifiers(node) {
                const currentFlags = getEffectiveModifierFlags(node);
                const newFlags = ensureModifierFlags(node);
                if (currentFlags === newFlags) {
                    return visitArray(node.modifiers, (n) => tryCast(n, isModifier), isModifier);
                }
                return factory2.createModifiersFromModifierFlags(newFlags);
            }
            function ensureModifierFlags(node) {
                let mask2 = 131071 /* All */ ^ (1 /* Public */ | 1024 /* Async */ | 16 /* Override */);
                let additions = needsDeclare && !isAlwaysType(node) ? 128 /* Ambient */ : 0 /* None */;
                const parentIsFile = node.parent.kind === 312 /* SourceFile */;
                if (!parentIsFile || isBundledEmit && parentIsFile && isExternalModule(node.parent)) {
                    mask2 ^= 128 /* Ambient */;
                    additions = 0 /* None */;
                }
                return maskModifierFlags(node, mask2, additions);
            }
            function getTypeAnnotationFromAllAccessorDeclarations(node, accessors) {
                let accessorType = getTypeAnnotationFromAccessor(node);
                if (!accessorType && node !== accessors.firstAccessor) {
                    accessorType = getTypeAnnotationFromAccessor(accessors.firstAccessor);
                    getSymbolAccessibilityDiagnostic = createGetSymbolAccessibilityDiagnosticForNode(accessors.firstAccessor);
                }
                if (!accessorType && accessors.secondAccessor && node !== accessors.secondAccessor) {
                    accessorType = getTypeAnnotationFromAccessor(accessors.secondAccessor);
                    getSymbolAccessibilityDiagnostic = createGetSymbolAccessibilityDiagnosticForNode(accessors.secondAccessor);
                }
                return accessorType;
            }
            function transformHeritageClauses(nodes) {
                return factory2.createNodeArray(filter(map(nodes, (clause) => factory2.updateHeritageClause(clause, visitNodes2(factory2.createNodeArray(filter(clause.types, (t) => {
                    return isEntityNameExpression(t.expression) || clause.token === 96 /* ExtendsKeyword */ && t.expression.kind === 106 /* NullKeyword */;
                })), visitDeclarationSubtree, isExpressionWithTypeArguments))), (clause) => clause.types && !!clause.types.length));
            }
        }
        function isAlwaysType(node) {
            if (node.kind === 264 /* InterfaceDeclaration */) {
                return true;
            }
            return false;
        }
        function maskModifiers(factory2, node, modifierMask, modifierAdditions) {
            return factory2.createModifiersFromModifierFlags(maskModifierFlags(node, modifierMask, modifierAdditions));
        }
        function maskModifierFlags(node, modifierMask = 131071 /* All */ ^ 1 /* Public */, modifierAdditions = 0 /* None */) {
            let flags = getEffectiveModifierFlags(node) & modifierMask | modifierAdditions;
            if (flags & 2048 /* Default */ && !(flags & 32 /* Export */)) {
                flags ^= 32 /* Export */;
            }
            if (flags & 2048 /* Default */ && flags & 128 /* Ambient */) {
                flags ^= 128 /* Ambient */;
            }
            return flags;
        }
        function getTypeAnnotationFromAccessor(accessor) {
            if (accessor) {
                return accessor.kind === 177 /* GetAccessor */ ? accessor.type : accessor.parameters.length > 0 ? accessor.parameters[0].type : void 0;
            }
        }
        function canHaveLiteralInitializer(node) {
            switch (node.kind) {
                case 172 /* PropertyDeclaration */:
                case 171 /* PropertySignature */:
                    return !hasEffectiveModifier(node, 2 /* Private */);
                case 169 /* Parameter */:
                case 260 /* VariableDeclaration */:
                    return true;
            }
            return false;
        }
        function isPreservedDeclarationStatement(node) {
            switch (node.kind) {
                case 262 /* FunctionDeclaration */:
                case 267 /* ModuleDeclaration */:
                case 271 /* ImportEqualsDeclaration */:
                case 264 /* InterfaceDeclaration */:
                case 263 /* ClassDeclaration */:
                case 265 /* TypeAliasDeclaration */:
                case 266 /* EnumDeclaration */:
                case 243 /* VariableStatement */:
                case 272 /* ImportDeclaration */:
                case 278 /* ExportDeclaration */:
                case 277 /* ExportAssignment */:
                    return true;
            }
            return false;
        }
        function isProcessedComponent(node) {
            switch (node.kind) {
                case 180 /* ConstructSignature */:
                case 176 /* Constructor */:
                case 174 /* MethodDeclaration */:
                case 177 /* GetAccessor */:
                case 178 /* SetAccessor */:
                case 172 /* PropertyDeclaration */:
                case 171 /* PropertySignature */:
                case 173 /* MethodSignature */:
                case 179 /* CallSignature */:
                case 181 /* IndexSignature */:
                case 260 /* VariableDeclaration */:
                case 168 /* TypeParameter */:
                case 233 /* ExpressionWithTypeArguments */:
                case 183 /* TypeReference */:
                case 194 /* ConditionalType */:
                case 184 /* FunctionType */:
                case 185 /* ConstructorType */:
                case 205 /* ImportType */:
                    return true;
            }
            return false;
        }
        var declarationEmitNodeBuilderFlags;
        var init_declarations = __esm({
            "src/compiler/transformers/declarations.ts"() {
                "use strict";
                init_ts2();
                init_ts_moduleSpecifiers();
                declarationEmitNodeBuilderFlags = 1024 /* MultilineObjectLiterals */ | 2048 /* WriteClassExpressionAsTypeLiteral */ | 4096 /* UseTypeOfFunction */ | 8 /* UseStructuralFallback */ | 524288 /* AllowEmptyTuple */ | 4 /* GenerateNamesForShadowedTypeParams */ | 1 /* NoTruncation */;
            }
        });
        // src/compiler/transformer.ts
        function getModuleTransformer(moduleKind) {
            switch (moduleKind) {
                case 99 /* ESNext */:
                case 7 /* ES2022 */:
                case 6 /* ES2020 */:
                case 5 /* ES2015 */:
                case 200 /* Preserve */:
                    return transformECMAScriptModule;
                case 4 /* System */:
                    return transformSystemModule;
                case 100 /* Node16 */:
                case 199 /* NodeNext */:
                    return transformNodeModule;
                default:
                    return transformModule;
            }
        }
        function getTransformers(compilerOptions, customTransformers, emitOnly) {
            return {
                scriptTransformers: getScriptTransformers(compilerOptions, customTransformers, emitOnly),
                declarationTransformers: getDeclarationTransformers(customTransformers)
            };
        }
        function getScriptTransformers(compilerOptions, customTransformers, emitOnly) {
            if (emitOnly)
                return emptyArray;
            const languageVersion = getEmitScriptTarget(compilerOptions);
            const moduleKind = getEmitModuleKind(compilerOptions);
            const useDefineForClassFields = getUseDefineForClassFields(compilerOptions);
            const transformers = [];
            addRange(transformers, customTransformers && map(customTransformers.before, wrapScriptTransformerFactory));
            transformers.push(transformTypeScript);
            if (compilerOptions.experimentalDecorators) {
                transformers.push(transformLegacyDecorators);
            }
            if (getJSXTransformEnabled(compilerOptions)) {
                transformers.push(transformJsx);
            }
            if (languageVersion < 99 /* ESNext */) {
                transformers.push(transformESNext);
            }
            if (!compilerOptions.experimentalDecorators && (languageVersion < 99 /* ESNext */ || !useDefineForClassFields)) {
                transformers.push(transformESDecorators);
            }
            transformers.push(transformClassFields);
            if (languageVersion < 8 /* ES2021 */) {
                transformers.push(transformES2021);
            }
            if (languageVersion < 7 /* ES2020 */) {
                transformers.push(transformES2020);
            }
            if (languageVersion < 6 /* ES2019 */) {
                transformers.push(transformES2019);
            }
            if (languageVersion < 5 /* ES2018 */) {
                transformers.push(transformES2018);
            }
            if (languageVersion < 4 /* ES2017 */) {
                transformers.push(transformES2017);
            }
            if (languageVersion < 3 /* ES2016 */) {
                transformers.push(transformES2016);
            }
            if (languageVersion < 2 /* ES2015 */) {
                transformers.push(transformES2015);
                transformers.push(transformGenerators);
            }
            transformers.push(getModuleTransformer(moduleKind));
            if (languageVersion < 1 /* ES5 */) {
                transformers.push(transformES5);
            }
            addRange(transformers, customTransformers && map(customTransformers.after, wrapScriptTransformerFactory));
            return transformers;
        }
        function getDeclarationTransformers(customTransformers) {
            const transformers = [];
            transformers.push(transformDeclarations);
            addRange(transformers, customTransformers && map(customTransformers.afterDeclarations, wrapDeclarationTransformerFactory));
            return transformers;
        }
        function wrapCustomTransformer(transformer) {
            return (node) => isBundle(node) ? transformer.transformBundle(node) : transformer.transformSourceFile(node);
        }
        function wrapCustomTransformerFactory(transformer, handleDefault) {
            return (context) => {
                const customTransformer = transformer(context);
                return typeof customTransformer === "function" ? handleDefault(context, customTransformer) : wrapCustomTransformer(customTransformer);
            };
        }
        function wrapScriptTransformerFactory(transformer) {
            return wrapCustomTransformerFactory(transformer, chainBundle);
        }
        function wrapDeclarationTransformerFactory(transformer) {
            return wrapCustomTransformerFactory(transformer, (_, node) => node);
        }
        function noEmitSubstitution(_hint, node) {
            return node;
        }
        function noEmitNotification(hint, node, callback) {
            callback(hint, node);
        }
        function transformNodes(resolver, host, factory2, options, nodes, transformers, allowDtsFiles) {
            var _a, _b;
            const enabledSyntaxKindFeatures = new Array(363 /* Count */);
            let lexicalEnvironmentVariableDeclarations;
            let lexicalEnvironmentFunctionDeclarations;
            let lexicalEnvironmentStatements;
            let lexicalEnvironmentFlags = 0 /* None */;
            let lexicalEnvironmentVariableDeclarationsStack = [];
            let lexicalEnvironmentFunctionDeclarationsStack = [];
            let lexicalEnvironmentStatementsStack = [];
            let lexicalEnvironmentFlagsStack = [];
            let lexicalEnvironmentStackOffset = 0;
            let lexicalEnvironmentSuspended = false;
            let blockScopedVariableDeclarationsStack = [];
            let blockScopeStackOffset = 0;
            let blockScopedVariableDeclarations;
            let emitHelpers;
            let onSubstituteNode = noEmitSubstitution;
            let onEmitNode = noEmitNotification;
            let state = 0 /* Uninitialized */;
            const diagnostics = [];
            const context = {
                factory: factory2,
                getCompilerOptions: () => options,
                getEmitResolver: () => resolver,
                // TODO: GH#18217
                getEmitHost: () => host,
                // TODO: GH#18217
                getEmitHelperFactory: memoize(() => createEmitHelperFactory(context)),
                startLexicalEnvironment,
                suspendLexicalEnvironment,
                resumeLexicalEnvironment,
                endLexicalEnvironment,
                setLexicalEnvironmentFlags,
                getLexicalEnvironmentFlags,
                hoistVariableDeclaration,
                hoistFunctionDeclaration,
                addInitializationStatement,
                startBlockScope,
                endBlockScope,
                addBlockScopedVariable,
                requestEmitHelper,
                readEmitHelpers,
                enableSubstitution,
                enableEmitNotification,
                isSubstitutionEnabled,
                isEmitNotificationEnabled,
                get onSubstituteNode() {
                    return onSubstituteNode;
                },
                set onSubstituteNode(value) {
                    Debug.assert(state < 1 /* Initialized */, "Cannot modify transformation hooks after initialization has completed.");
                    Debug.assert(value !== void 0, "Value must not be 'undefined'");
                    onSubstituteNode = value;
                },
                get onEmitNode() {
                    return onEmitNode;
                },
                set onEmitNode(value) {
                    Debug.assert(state < 1 /* Initialized */, "Cannot modify transformation hooks after initialization has completed.");
                    Debug.assert(value !== void 0, "Value must not be 'undefined'");
                    onEmitNode = value;
                },
                addDiagnostic(diag2) {
                    diagnostics.push(diag2);
                }
            };
            for (const node of nodes) {
                disposeEmitNodes(getSourceFileOfNode(getParseTreeNode(node)));
            }
            mark("beforeTransform");
            const transformersWithContext = transformers.map((t) => t(context));
            const transformation = (node) => {
                for (const transform2 of transformersWithContext) {
                    node = transform2(node);
                }
                return node;
            };
            state = 1 /* Initialized */;
            const transformed = [];
            for (const node of nodes) {
                (_a = tracing) == null ? void 0 : _a.push(tracing.Phase.Emit, "transformNodes", node.kind === 312 /* SourceFile */ ? { path: node.path } : { kind: node.kind, pos: node.pos, end: node.end });
                transformed.push((allowDtsFiles ? transformation : transformRoot)(node));
                (_b = tracing) == null ? void 0 : _b.pop();
            }
            state = 2 /* Completed */;
            mark("afterTransform");
            measure("transformTime", "beforeTransform", "afterTransform");
            return {
                transformed,
                substituteNode,
                emitNodeWithNotification,
                isEmitNotificationEnabled,
                dispose,
                diagnostics
            };
            function transformRoot(node) {
                return node && (!isSourceFile(node) || !node.isDeclarationFile) ? transformation(node) : node;
            }
            function enableSubstitution(kind) {
                Debug.assert(state < 2 /* Completed */, "Cannot modify the transformation context after transformation has completed.");
                enabledSyntaxKindFeatures[kind] |= 1 /* Substitution */;
            }
            function isSubstitutionEnabled(node) {
                return (enabledSyntaxKindFeatures[node.kind] & 1 /* Substitution */) !== 0 && (getEmitFlags(node) & 8 /* NoSubstitution */) === 0;
            }
            function substituteNode(hint, node) {
                Debug.assert(state < 3 /* Disposed */, "Cannot substitute a node after the result is disposed.");
                return node && isSubstitutionEnabled(node) && onSubstituteNode(hint, node) || node;
            }
            function enableEmitNotification(kind) {
                Debug.assert(state < 2 /* Completed */, "Cannot modify the transformation context after transformation has completed.");
                enabledSyntaxKindFeatures[kind] |= 2 /* EmitNotifications */;
            }
            function isEmitNotificationEnabled(node) {
                return (enabledSyntaxKindFeatures[node.kind] & 2 /* EmitNotifications */) !== 0 || (getEmitFlags(node) & 4 /* AdviseOnEmitNode */) !== 0;
            }
            function emitNodeWithNotification(hint, node, emitCallback) {
                Debug.assert(state < 3 /* Disposed */, "Cannot invoke TransformationResult callbacks after the result is disposed.");
                if (node) {
                    if (isEmitNotificationEnabled(node)) {
                        onEmitNode(hint, node, emitCallback);
                    }
                    else {
                        emitCallback(hint, node);
                    }
                }
            }
            function hoistVariableDeclaration(name) {
                Debug.assert(state > 0 /* Uninitialized */, "Cannot modify the lexical environment during initialization.");
                Debug.assert(state < 2 /* Completed */, "Cannot modify the lexical environment after transformation has completed.");
                const decl = setEmitFlags(factory2.createVariableDeclaration(name), 128 /* NoNestedSourceMaps */);
                if (!lexicalEnvironmentVariableDeclarations) {
                    lexicalEnvironmentVariableDeclarations = [decl];
                }
                else {
                    lexicalEnvironmentVariableDeclarations.push(decl);
                }
                if (lexicalEnvironmentFlags & 1 /* InParameters */) {
                    lexicalEnvironmentFlags |= 2 /* VariablesHoistedInParameters */;
                }
            }
            function hoistFunctionDeclaration(func) {
                Debug.assert(state > 0 /* Uninitialized */, "Cannot modify the lexical environment during initialization.");
                Debug.assert(state < 2 /* Completed */, "Cannot modify the lexical environment after transformation has completed.");
                setEmitFlags(func, 2097152 /* CustomPrologue */);
                if (!lexicalEnvironmentFunctionDeclarations) {
                    lexicalEnvironmentFunctionDeclarations = [func];
                }
                else {
                    lexicalEnvironmentFunctionDeclarations.push(func);
                }
            }
            function addInitializationStatement(node) {
                Debug.assert(state > 0 /* Uninitialized */, "Cannot modify the lexical environment during initialization.");
                Debug.assert(state < 2 /* Completed */, "Cannot modify the lexical environment after transformation has completed.");
                setEmitFlags(node, 2097152 /* CustomPrologue */);
                if (!lexicalEnvironmentStatements) {
                    lexicalEnvironmentStatements = [node];
                }
                else {
                    lexicalEnvironmentStatements.push(node);
                }
            }
            function startLexicalEnvironment() {
                Debug.assert(state > 0 /* Uninitialized */, "Cannot modify the lexical environment during initialization.");
                Debug.assert(state < 2 /* Completed */, "Cannot modify the lexical environment after transformation has completed.");
                Debug.assert(!lexicalEnvironmentSuspended, "Lexical environment is suspended.");
                lexicalEnvironmentVariableDeclarationsStack[lexicalEnvironmentStackOffset] = lexicalEnvironmentVariableDeclarations;
                lexicalEnvironmentFunctionDeclarationsStack[lexicalEnvironmentStackOffset] = lexicalEnvironmentFunctionDeclarations;
                lexicalEnvironmentStatementsStack[lexicalEnvironmentStackOffset] = lexicalEnvironmentStatements;
                lexicalEnvironmentFlagsStack[lexicalEnvironmentStackOffset] = lexicalEnvironmentFlags;
                lexicalEnvironmentStackOffset++;
                lexicalEnvironmentVariableDeclarations = void 0;
                lexicalEnvironmentFunctionDeclarations = void 0;
                lexicalEnvironmentStatements = void 0;
                lexicalEnvironmentFlags = 0 /* None */;
            }
            function suspendLexicalEnvironment() {
                Debug.assert(state > 0 /* Uninitialized */, "Cannot modify the lexical environment during initialization.");
                Debug.assert(state < 2 /* Completed */, "Cannot modify the lexical environment after transformation has completed.");
                Debug.assert(!lexicalEnvironmentSuspended, "Lexical environment is already suspended.");
                lexicalEnvironmentSuspended = true;
            }
            function resumeLexicalEnvironment() {
                Debug.assert(state > 0 /* Uninitialized */, "Cannot modify the lexical environment during initialization.");
                Debug.assert(state < 2 /* Completed */, "Cannot modify the lexical environment after transformation has completed.");
                Debug.assert(lexicalEnvironmentSuspended, "Lexical environment is not suspended.");
                lexicalEnvironmentSuspended = false;
            }
            function endLexicalEnvironment() {
                Debug.assert(state > 0 /* Uninitialized */, "Cannot modify the lexical environment during initialization.");
                Debug.assert(state < 2 /* Completed */, "Cannot modify the lexical environment after transformation has completed.");
                Debug.assert(!lexicalEnvironmentSuspended, "Lexical environment is suspended.");
                let statements;
                if (lexicalEnvironmentVariableDeclarations || lexicalEnvironmentFunctionDeclarations || lexicalEnvironmentStatements) {
                    if (lexicalEnvironmentFunctionDeclarations) {
                        statements = [...lexicalEnvironmentFunctionDeclarations];
                    }
                    if (lexicalEnvironmentVariableDeclarations) {
                        const statement = factory2.createVariableStatement(
                        /*modifiers*/
                        void 0, factory2.createVariableDeclarationList(lexicalEnvironmentVariableDeclarations));
                        setEmitFlags(statement, 2097152 /* CustomPrologue */);
                        if (!statements) {
                            statements = [statement];
                        }
                        else {
                            statements.push(statement);
                        }
                    }
                    if (lexicalEnvironmentStatements) {
                        if (!statements) {
                            statements = [...lexicalEnvironmentStatements];
                        }
                        else {
                            statements = [...statements, ...lexicalEnvironmentStatements];
                        }
                    }
                }
                lexicalEnvironmentStackOffset--;
                lexicalEnvironmentVariableDeclarations = lexicalEnvironmentVariableDeclarationsStack[lexicalEnvironmentStackOffset];
                lexicalEnvironmentFunctionDeclarations = lexicalEnvironmentFunctionDeclarationsStack[lexicalEnvironmentStackOffset];
                lexicalEnvironmentStatements = lexicalEnvironmentStatementsStack[lexicalEnvironmentStackOffset];
                lexicalEnvironmentFlags = lexicalEnvironmentFlagsStack[lexicalEnvironmentStackOffset];
                if (lexicalEnvironmentStackOffset === 0) {
                    lexicalEnvironmentVariableDeclarationsStack = [];
                    lexicalEnvironmentFunctionDeclarationsStack = [];
                    lexicalEnvironmentStatementsStack = [];
                    lexicalEnvironmentFlagsStack = [];
                }
                return statements;
            }
            function setLexicalEnvironmentFlags(flags, value) {
                lexicalEnvironmentFlags = value ? lexicalEnvironmentFlags | flags : lexicalEnvironmentFlags & ~flags;
            }
            function getLexicalEnvironmentFlags() {
                return lexicalEnvironmentFlags;
            }
            function startBlockScope() {
                Debug.assert(state > 0 /* Uninitialized */, "Cannot start a block scope during initialization.");
                Debug.assert(state < 2 /* Completed */, "Cannot start a block scope after transformation has completed.");
                blockScopedVariableDeclarationsStack[blockScopeStackOffset] = blockScopedVariableDeclarations;
                blockScopeStackOffset++;
                blockScopedVariableDeclarations = void 0;
            }
            function endBlockScope() {
                Debug.assert(state > 0 /* Uninitialized */, "Cannot end a block scope during initialization.");
                Debug.assert(state < 2 /* Completed */, "Cannot end a block scope after transformation has completed.");
                const statements = some(blockScopedVariableDeclarations) ? [
                    factory2.createVariableStatement(
                    /*modifiers*/
                    void 0, factory2.createVariableDeclarationList(blockScopedVariableDeclarations.map((identifier) => factory2.createVariableDeclaration(identifier)), 1 /* Let */))
                ] : void 0;
                blockScopeStackOffset--;
                blockScopedVariableDeclarations = blockScopedVariableDeclarationsStack[blockScopeStackOffset];
                if (blockScopeStackOffset === 0) {
                    blockScopedVariableDeclarationsStack = [];
                }
                return statements;
            }
            function addBlockScopedVariable(name) {
                Debug.assert(blockScopeStackOffset > 0, "Cannot add a block scoped variable outside of an iteration body.");
                (blockScopedVariableDeclarations || (blockScopedVariableDeclarations = [])).push(name);
            }
            function requestEmitHelper(helper) {
                Debug.assert(state > 0 /* Uninitialized */, "Cannot modify the transformation context during initialization.");
                Debug.assert(state < 2 /* Completed */, "Cannot modify the transformation context after transformation has completed.");
                Debug.assert(!helper.scoped, "Cannot request a scoped emit helper.");
                if (helper.dependencies) {
                    for (const h of helper.dependencies) {
                        requestEmitHelper(h);
                    }
                }
                emitHelpers = append(emitHelpers, helper);
            }
            function readEmitHelpers() {
                Debug.assert(state > 0 /* Uninitialized */, "Cannot modify the transformation context during initialization.");
                Debug.assert(state < 2 /* Completed */, "Cannot modify the transformation context after transformation has completed.");
                const helpers = emitHelpers;
                emitHelpers = void 0;
                return helpers;
            }
            function dispose() {
                if (state < 3 /* Disposed */) {
                    for (const node of nodes) {
                        disposeEmitNodes(getSourceFileOfNode(getParseTreeNode(node)));
                    }
                    lexicalEnvironmentVariableDeclarations = void 0;
                    lexicalEnvironmentVariableDeclarationsStack = void 0;
                    lexicalEnvironmentFunctionDeclarations = void 0;
                    lexicalEnvironmentFunctionDeclarationsStack = void 0;
                    onSubstituteNode = void 0;
                    onEmitNode = void 0;
                    emitHelpers = void 0;
                    state = 3 /* Disposed */;
                }
            }
        }
        var noTransformers, nullTransformationContext;
        var init_transformer = __esm({
            "src/compiler/transformer.ts"() {
                "use strict";
                init_ts2();
                init_ts_performance();
                noTransformers = { scriptTransformers: emptyArray, declarationTransformers: emptyArray };
                nullTransformationContext = {
                    factory,
                    // eslint-disable-line object-shorthand
                    getCompilerOptions: () => ({}),
                    getEmitResolver: notImplemented,
                    getEmitHost: notImplemented,
                    getEmitHelperFactory: notImplemented,
                    startLexicalEnvironment: noop,
                    resumeLexicalEnvironment: noop,
                    suspendLexicalEnvironment: noop,
                    endLexicalEnvironment: returnUndefined,
                    setLexicalEnvironmentFlags: noop,
                    getLexicalEnvironmentFlags: () => 0,
                    hoistVariableDeclaration: noop,
                    hoistFunctionDeclaration: noop,
                    addInitializationStatement: noop,
                    startBlockScope: noop,
                    endBlockScope: returnUndefined,
                    addBlockScopedVariable: noop,
                    requestEmitHelper: noop,
                    readEmitHelpers: notImplemented,
                    enableSubstitution: noop,
                    enableEmitNotification: noop,
                    isSubstitutionEnabled: notImplemented,
                    isEmitNotificationEnabled: notImplemented,
                    onSubstituteNode: noEmitSubstitution,
                    onEmitNode: noEmitNotification,
                    addDiagnostic: noop
                };
            }
        });
        // src/compiler/emitter.ts
        function isBuildInfoFile(file) {
            return fileExtensionIs(file, ".tsbuildinfo" /* TsBuildInfo */);
        }
        function forEachEmittedFile(host, action, sourceFilesOrTargetSourceFile, forceDtsEmit = false, onlyBuildInfo, includeBuildInfo) {
            const sourceFiles = isArray(sourceFilesOrTargetSourceFile) ? sourceFilesOrTargetSourceFile : getSourceFilesToEmit(host, sourceFilesOrTargetSourceFile, forceDtsEmit);
            const options = host.getCompilerOptions();
            if (outFile(options)) {
                const prepends = host.getPrependNodes();
                if (sourceFiles.length || prepends.length) {
                    const bundle = factory.createBundle(sourceFiles, prepends);
                    const result = action(getOutputPathsFor(bundle, host, forceDtsEmit), bundle);
                    if (result) {
                        return result;
                    }
                }
            }
            else {
                if (!onlyBuildInfo) {
                    for (const sourceFile of sourceFiles) {
                        const result = action(getOutputPathsFor(sourceFile, host, forceDtsEmit), sourceFile);
                        if (result) {
                            return result;
                        }
                    }
                }
                if (includeBuildInfo) {
                    const buildInfoPath = getTsBuildInfoEmitOutputFilePath(options);
                    if (buildInfoPath)
                        return action({ buildInfoPath }, 
                        /*sourceFileOrBundle*/
                        void 0);
                }
            }
        }
        function getTsBuildInfoEmitOutputFilePath(options) {
            const configFile = options.configFilePath;
            if (!isIncrementalCompilation(options))
                return void 0;
            if (options.tsBuildInfoFile)
                return options.tsBuildInfoFile;
            const outPath = outFile(options);
            let buildInfoExtensionLess;
            if (outPath) {
                buildInfoExtensionLess = removeFileExtension(outPath);
            }
            else {
                if (!configFile)
                    return void 0;
                const configFileExtensionLess = removeFileExtension(configFile);
                buildInfoExtensionLess = options.outDir ? options.rootDir ? resolvePath(options.outDir, getRelativePathFromDirectory(options.rootDir, configFileExtensionLess, 
                /*ignoreCase*/
                true)) : combinePaths(options.outDir, getBaseFileName(configFileExtensionLess)) : configFileExtensionLess;
            }
            return buildInfoExtensionLess + ".tsbuildinfo" /* TsBuildInfo */;
        }
        function getOutputPathsForBundle(options, forceDtsPaths) {
            const outPath = outFile(options);
            const jsFilePath = options.emitDeclarationOnly ? void 0 : outPath;
            const sourceMapFilePath = jsFilePath && getSourceMapFilePath(jsFilePath, options);
            const declarationFilePath = forceDtsPaths || getEmitDeclarations(options) ? removeFileExtension(outPath) + ".d.ts" /* Dts */ : void 0;
            const declarationMapPath = declarationFilePath && getAreDeclarationMapsEnabled(options) ? declarationFilePath + ".map" : void 0;
            const buildInfoPath = getTsBuildInfoEmitOutputFilePath(options);
            return { jsFilePath, sourceMapFilePath, declarationFilePath, declarationMapPath, buildInfoPath };
        }
        function getOutputPathsFor(sourceFile, host, forceDtsPaths) {
            const options = host.getCompilerOptions();
            if (sourceFile.kind === 313 /* Bundle */) {
                return getOutputPathsForBundle(options, forceDtsPaths);
            }
            else {
                const ownOutputFilePath = getOwnEmitOutputFilePath(sourceFile.fileName, host, getOutputExtension(sourceFile.fileName, options));
                const isJsonFile = isJsonSourceFile(sourceFile);
                const isJsonEmittedToSameLocation = isJsonFile && comparePaths(sourceFile.fileName, ownOutputFilePath, host.getCurrentDirectory(), !host.useCaseSensitiveFileNames()) === 0 /* EqualTo */;
                const jsFilePath = options.emitDeclarationOnly || isJsonEmittedToSameLocation ? void 0 : ownOutputFilePath;
                const sourceMapFilePath = !jsFilePath || isJsonSourceFile(sourceFile) ? void 0 : getSourceMapFilePath(jsFilePath, options);
                const declarationFilePath = forceDtsPaths || getEmitDeclarations(options) && !isJsonFile ? getDeclarationEmitOutputFilePath(sourceFile.fileName, host) : void 0;
                const declarationMapPath = declarationFilePath && getAreDeclarationMapsEnabled(options) ? declarationFilePath + ".map" : void 0;
                return { jsFilePath, sourceMapFilePath, declarationFilePath, declarationMapPath, buildInfoPath: void 0 };
            }
        }
        function getSourceMapFilePath(jsFilePath, options) {
            return options.sourceMap && !options.inlineSourceMap ? jsFilePath + ".map" : void 0;
        }
        function getOutputExtension(fileName, options) {
            return fileExtensionIs(fileName, ".json" /* Json */) ? ".json" /* Json */ : options.jsx === 1 /* Preserve */ && fileExtensionIsOneOf(fileName, [".jsx" /* Jsx */, ".tsx" /* Tsx */]) ? ".jsx" /* Jsx */ : fileExtensionIsOneOf(fileName, [".mts" /* Mts */, ".mjs" /* Mjs */]) ? ".mjs" /* Mjs */ : fileExtensionIsOneOf(fileName, [".cts" /* Cts */, ".cjs" /* Cjs */]) ? ".cjs" /* Cjs */ : ".js" /* Js */;
        }
        function getOutputPathWithoutChangingExt(inputFileName, ignoreCase, outputDir, getCommonSourceDirectory2) {
            return outputDir ? resolvePath(outputDir, getRelativePathFromDirectory(getCommonSourceDirectory2(), inputFileName, ignoreCase)) : inputFileName;
        }
        function getOutputDeclarationFileName(inputFileName, configFile, ignoreCase, getCommonSourceDirectory2 = () => getCommonSourceDirectoryOfConfig(configFile, ignoreCase)) {
            return getOutputDeclarationFileNameWorker(inputFileName, configFile.options, ignoreCase, getCommonSourceDirectory2);
        }
        function getOutputDeclarationFileNameWorker(inputFileName, options, ignoreCase, getCommonSourceDirectory2) {
            return changeExtension(getOutputPathWithoutChangingExt(inputFileName, ignoreCase, options.declarationDir || options.outDir, getCommonSourceDirectory2), getDeclarationEmitExtensionForPath(inputFileName));
        }
        function getOutputJSFileName(inputFileName, configFile, ignoreCase, getCommonSourceDirectory2 = () => getCommonSourceDirectoryOfConfig(configFile, ignoreCase)) {
            if (configFile.options.emitDeclarationOnly)
                return void 0;
            const isJsonFile = fileExtensionIs(inputFileName, ".json" /* Json */);
            const outputFileName = getOutputJSFileNameWorker(inputFileName, configFile.options, ignoreCase, getCommonSourceDirectory2);
            return !isJsonFile || comparePaths(inputFileName, outputFileName, Debug.checkDefined(configFile.options.configFilePath), ignoreCase) !== 0 /* EqualTo */ ? outputFileName : void 0;
        }
        function getOutputJSFileNameWorker(inputFileName, options, ignoreCase, getCommonSourceDirectory2) {
            return changeExtension(getOutputPathWithoutChangingExt(inputFileName, ignoreCase, options.outDir, getCommonSourceDirectory2), getOutputExtension(inputFileName, options));
        }
        function createAddOutput() {
            let outputs;
            return { addOutput, getOutputs };
            function addOutput(path) {
                if (path) {
                    (outputs || (outputs = [])).push(path);
                }
            }
            function getOutputs() {
                return outputs || emptyArray;
            }
        }
        function getSingleOutputFileNames(configFile, addOutput) {
            const { jsFilePath, sourceMapFilePath, declarationFilePath, declarationMapPath, buildInfoPath } = getOutputPathsForBundle(configFile.options, 
            /*forceDtsPaths*/
            false);
            addOutput(jsFilePath);
            addOutput(sourceMapFilePath);
            addOutput(declarationFilePath);
            addOutput(declarationMapPath);
            addOutput(buildInfoPath);
        }
        function getOwnOutputFileNames(configFile, inputFileName, ignoreCase, addOutput, getCommonSourceDirectory2) {
            if (isDeclarationFileName(inputFileName))
                return;
            const js = getOutputJSFileName(inputFileName, configFile, ignoreCase, getCommonSourceDirectory2);
            addOutput(js);
            if (fileExtensionIs(inputFileName, ".json" /* Json */))
                return;
            if (js && configFile.options.sourceMap) {
                addOutput(`${js}.map`);
            }
            if (getEmitDeclarations(configFile.options)) {
                const dts = getOutputDeclarationFileName(inputFileName, configFile, ignoreCase, getCommonSourceDirectory2);
                addOutput(dts);
                if (configFile.options.declarationMap) {
                    addOutput(`${dts}.map`);
                }
            }
        }
        function getCommonSourceDirectory(options, emittedFiles, currentDirectory, getCanonicalFileName, checkSourceFilesBelongToPath) {
            let commonSourceDirectory;
            if (options.rootDir) {
                commonSourceDirectory = getNormalizedAbsolutePath(options.rootDir, currentDirectory);
                checkSourceFilesBelongToPath == null ? void 0 : checkSourceFilesBelongToPath(options.rootDir);
            }
            else if (options.composite && options.configFilePath) {
                commonSourceDirectory = getDirectoryPath(normalizeSlashes(options.configFilePath));
                checkSourceFilesBelongToPath == null ? void 0 : checkSourceFilesBelongToPath(commonSourceDirectory);
            }
            else {
                commonSourceDirectory = computeCommonSourceDirectoryOfFilenames(emittedFiles(), currentDirectory, getCanonicalFileName);
            }
            if (commonSourceDirectory && commonSourceDirectory[commonSourceDirectory.length - 1] !== directorySeparator) {
                commonSourceDirectory += directorySeparator;
            }
            return commonSourceDirectory;
        }
        function getCommonSourceDirectoryOfConfig({ options, fileNames }, ignoreCase) {
            return getCommonSourceDirectory(options, () => filter(fileNames, (file) => !(options.noEmitForJsFiles && fileExtensionIsOneOf(file, supportedJSExtensionsFlat)) && !isDeclarationFileName(file)), getDirectoryPath(normalizeSlashes(Debug.checkDefined(options.configFilePath))), createGetCanonicalFileName(!ignoreCase));
        }
        function getAllProjectOutputs(configFile, ignoreCase) {
            const { addOutput, getOutputs } = createAddOutput();
            if (outFile(configFile.options)) {
                getSingleOutputFileNames(configFile, addOutput);
            }
            else {
                const getCommonSourceDirectory2 = memoize(() => getCommonSourceDirectoryOfConfig(configFile, ignoreCase));
                for (const inputFileName of configFile.fileNames) {
                    getOwnOutputFileNames(configFile, inputFileName, ignoreCase, addOutput, getCommonSourceDirectory2);
                }
                addOutput(getTsBuildInfoEmitOutputFilePath(configFile.options));
            }
            return getOutputs();
        }
        function getOutputFileNames(commandLine, inputFileName, ignoreCase) {
            inputFileName = normalizePath(inputFileName);
            Debug.assert(contains(commandLine.fileNames, inputFileName), `Expected fileName to be present in command line`);
            const { addOutput, getOutputs } = createAddOutput();
            if (outFile(commandLine.options)) {
                getSingleOutputFileNames(commandLine, addOutput);
            }
            else {
                getOwnOutputFileNames(commandLine, inputFileName, ignoreCase, addOutput);
            }
            return getOutputs();
        }
        function getFirstProjectOutput(configFile, ignoreCase) {
            if (outFile(configFile.options)) {
                const { jsFilePath, declarationFilePath } = getOutputPathsForBundle(configFile.options, 
                /*forceDtsPaths*/
                false);
                return Debug.checkDefined(jsFilePath || declarationFilePath, `project ${configFile.options.configFilePath} expected to have at least one output`);
            }
            const getCommonSourceDirectory2 = memoize(() => getCommonSourceDirectoryOfConfig(configFile, ignoreCase));
            for (const inputFileName of configFile.fileNames) {
                if (isDeclarationFileName(inputFileName))
                    continue;
                const jsFilePath = getOutputJSFileName(inputFileName, configFile, ignoreCase, getCommonSourceDirectory2);
                if (jsFilePath)
                    return jsFilePath;
                if (fileExtensionIs(inputFileName, ".json" /* Json */))
                    continue;
                if (getEmitDeclarations(configFile.options)) {
                    return getOutputDeclarationFileName(inputFileName, configFile, ignoreCase, getCommonSourceDirectory2);
                }
            }
            const buildInfoPath = getTsBuildInfoEmitOutputFilePath(configFile.options);
            if (buildInfoPath)
                return buildInfoPath;
            return Debug.fail(`project ${configFile.options.configFilePath} expected to have at least one output`);
        }
        function emitFiles(resolver, host, targetSourceFile, { scriptTransformers, declarationTransformers }, emitOnly, onlyBuildInfo, forceDtsEmit) {
            var compilerOptions = host.getCompilerOptions();
            var sourceMapDataList = compilerOptions.sourceMap || compilerOptions.inlineSourceMap || getAreDeclarationMapsEnabled(compilerOptions) ? [] : void 0;
            var emittedFilesList = compilerOptions.listEmittedFiles ? [] : void 0;
            var emitterDiagnostics = createDiagnosticCollection();
            var newLine = getNewLineCharacter(compilerOptions);
            var writer = createTextWriter(newLine);
            var { enter, exit } = createTimer("printTime", "beforePrint", "afterPrint");
            var bundleBuildInfo;
            var emitSkipped = false;
            enter();
            forEachEmittedFile(host, emitSourceFileOrBundle, getSourceFilesToEmit(host, targetSourceFile, forceDtsEmit), forceDtsEmit, onlyBuildInfo, !targetSourceFile);
            exit();
            return {
                emitSkipped,
                diagnostics: emitterDiagnostics.getDiagnostics(),
                emittedFiles: emittedFilesList,
                sourceMaps: sourceMapDataList
            };
            function emitSourceFileOrBundle({ jsFilePath, sourceMapFilePath, declarationFilePath, declarationMapPath, buildInfoPath }, sourceFileOrBundle) {
                var _a, _b, _c, _d, _e, _f;
                let buildInfoDirectory;
                if (buildInfoPath && sourceFileOrBundle && isBundle(sourceFileOrBundle)) {
                    buildInfoDirectory = getDirectoryPath(getNormalizedAbsolutePath(buildInfoPath, host.getCurrentDirectory()));
                    bundleBuildInfo = {
                        commonSourceDirectory: relativeToBuildInfo(host.getCommonSourceDirectory()),
                        sourceFiles: sourceFileOrBundle.sourceFiles.map((file) => relativeToBuildInfo(getNormalizedAbsolutePath(file.fileName, host.getCurrentDirectory())))
                    };
                }
                (_a = tracing) == null ? void 0 : _a.push(tracing.Phase.Emit, "emitJsFileOrBundle", { jsFilePath });
                emitJsFileOrBundle(sourceFileOrBundle, jsFilePath, sourceMapFilePath, relativeToBuildInfo);
                (_b = tracing) == null ? void 0 : _b.pop();
                (_c = tracing) == null ? void 0 : _c.push(tracing.Phase.Emit, "emitDeclarationFileOrBundle", { declarationFilePath });
                emitDeclarationFileOrBundle(sourceFileOrBundle, declarationFilePath, declarationMapPath, relativeToBuildInfo);
                (_d = tracing) == null ? void 0 : _d.pop();
                (_e = tracing) == null ? void 0 : _e.push(tracing.Phase.Emit, "emitBuildInfo", { buildInfoPath });
                emitBuildInfo(bundleBuildInfo, buildInfoPath);
                (_f = tracing) == null ? void 0 : _f.pop();
                function relativeToBuildInfo(path) {
                    return ensurePathIsNonModuleName(getRelativePathFromDirectory(buildInfoDirectory, path, host.getCanonicalFileName));
                }
            }
            function emitBuildInfo(bundle, buildInfoPath) {
                if (!buildInfoPath || targetSourceFile || emitSkipped)
                    return;
                if (host.isEmitBlocked(buildInfoPath)) {
                    emitSkipped = true;
                    return;
                }
                const buildInfo = host.getBuildInfo(bundle) || createBuildInfo(
                /*program*/
                void 0, bundle);
                writeFile(host, emitterDiagnostics, buildInfoPath, getBuildInfoText(buildInfo), 
                /*writeByteOrderMark*/
                false, 
                /*sourceFiles*/
                void 0, { buildInfo });
                emittedFilesList == null ? void 0 : emittedFilesList.push(buildInfoPath);
            }
            function emitJsFileOrBundle(sourceFileOrBundle, jsFilePath, sourceMapFilePath, relativeToBuildInfo) {
                if (!sourceFileOrBundle || emitOnly || !jsFilePath) {
                    return;
                }
                if (host.isEmitBlocked(jsFilePath) || compilerOptions.noEmit) {
                    emitSkipped = true;
                    return;
                }
                const transform2 = transformNodes(resolver, host, factory, compilerOptions, [sourceFileOrBundle], scriptTransformers, 
                /*allowDtsFiles*/
                false);
                const printerOptions = {
                    removeComments: compilerOptions.removeComments,
                    newLine: compilerOptions.newLine,
                    noEmitHelpers: compilerOptions.noEmitHelpers,
                    module: compilerOptions.module,
                    target: compilerOptions.target,
                    sourceMap: compilerOptions.sourceMap,
                    inlineSourceMap: compilerOptions.inlineSourceMap,
                    inlineSources: compilerOptions.inlineSources,
                    extendedDiagnostics: compilerOptions.extendedDiagnostics,
                    writeBundleFileInfo: !!bundleBuildInfo,
                    relativeToBuildInfo
                };
                const printer = createPrinter(printerOptions, {
                    // resolver hooks
                    hasGlobalName: resolver.hasGlobalName,
                    // transform hooks
                    onEmitNode: transform2.emitNodeWithNotification,
                    isEmitNotificationEnabled: transform2.isEmitNotificationEnabled,
                    substituteNode: transform2.substituteNode
                });
                Debug.assert(transform2.transformed.length === 1, "Should only see one output from the transform");
                printSourceFileOrBundle(jsFilePath, sourceMapFilePath, transform2, printer, compilerOptions);
                transform2.dispose();
                if (bundleBuildInfo)
                    bundleBuildInfo.js = printer.bundleFileInfo;
                if (emittedFilesList) {
                    emittedFilesList.push(jsFilePath);
                    if (sourceMapFilePath) {
                        emittedFilesList.push(sourceMapFilePath);
                    }
                }
            }
            function emitDeclarationFileOrBundle(sourceFileOrBundle, declarationFilePath, declarationMapPath, relativeToBuildInfo) {
                if (!sourceFileOrBundle || emitOnly === 0 /* Js */)
                    return;
                if (!declarationFilePath) {
                    if (emitOnly || compilerOptions.emitDeclarationOnly)
                        emitSkipped = true;
                    return;
                }
                const sourceFiles = isSourceFile(sourceFileOrBundle) ? [sourceFileOrBundle] : sourceFileOrBundle.sourceFiles;
                const filesForEmit = forceDtsEmit ? sourceFiles : filter(sourceFiles, isSourceFileNotJson);
                const inputListOrBundle = outFile(compilerOptions) ? [factory.createBundle(filesForEmit, !isSourceFile(sourceFileOrBundle) ? sourceFileOrBundle.prepends : void 0)] : filesForEmit;
                if (emitOnly && !getEmitDeclarations(compilerOptions)) {
                    filesForEmit.forEach(collectLinkedAliases);
                }
                const declarationTransform = transformNodes(resolver, host, factory, compilerOptions, inputListOrBundle, declarationTransformers, 
                /*allowDtsFiles*/
                false);
                if (length(declarationTransform.diagnostics)) {
                    for (const diagnostic of declarationTransform.diagnostics) {
                        emitterDiagnostics.add(diagnostic);
                    }
                }
                const declBlocked = !!declarationTransform.diagnostics && !!declarationTransform.diagnostics.length || !!host.isEmitBlocked(declarationFilePath) || !!compilerOptions.noEmit;
                emitSkipped = emitSkipped || declBlocked;
                if (!declBlocked || forceDtsEmit) {
                    Debug.assert(declarationTransform.transformed.length === 1, "Should only see one output from the decl transform");
                    const printerOptions = {
                        removeComments: compilerOptions.removeComments,
                        newLine: compilerOptions.newLine,
                        noEmitHelpers: true,
                        module: compilerOptions.module,
                        target: compilerOptions.target,
                        sourceMap: !forceDtsEmit && compilerOptions.declarationMap,
                        inlineSourceMap: compilerOptions.inlineSourceMap,
                        extendedDiagnostics: compilerOptions.extendedDiagnostics,
                        onlyPrintJsDocStyle: true,
                        omitBraceSourceMapPositions: true,
                        writeBundleFileInfo: !!bundleBuildInfo,
                        recordInternalSection: !!bundleBuildInfo,
                        relativeToBuildInfo
                    };
                    const declarationPrinter = createPrinter(printerOptions, {
                        // resolver hooks
                        hasGlobalName: resolver.hasGlobalName,
                        // transform hooks
                        onEmitNode: declarationTransform.emitNodeWithNotification,
                        isEmitNotificationEnabled: declarationTransform.isEmitNotificationEnabled,
                        substituteNode: declarationTransform.substituteNode
                    });
                    printSourceFileOrBundle(declarationFilePath, declarationMapPath, declarationTransform, declarationPrinter, {
                        sourceMap: printerOptions.sourceMap,
                        sourceRoot: compilerOptions.sourceRoot,
                        mapRoot: compilerOptions.mapRoot,
                        extendedDiagnostics: compilerOptions.extendedDiagnostics
                        // Explicitly do not passthru either `inline` option
                    });
                    if (emittedFilesList) {
                        emittedFilesList.push(declarationFilePath);
                        if (declarationMapPath) {
                            emittedFilesList.push(declarationMapPath);
                        }
                    }
                    if (bundleBuildInfo)
                        bundleBuildInfo.dts = declarationPrinter.bundleFileInfo;
                }
                declarationTransform.dispose();
            }
            function collectLinkedAliases(node) {
                if (isExportAssignment(node)) {
                    if (node.expression.kind === 80 /* Identifier */) {
                        resolver.collectLinkedAliases(node.expression, 
                        /*setVisibility*/
                        true);
                    }
                    return;
                }
                else if (isExportSpecifier(node)) {
                    resolver.collectLinkedAliases(node.propertyName || node.name, 
                    /*setVisibility*/
                    true);
                    return;
                }
                forEachChild(node, collectLinkedAliases);
            }
            function printSourceFileOrBundle(jsFilePath, sourceMapFilePath, transform2, printer, mapOptions) {
                const sourceFileOrBundle = transform2.transformed[0];
                const bundle = sourceFileOrBundle.kind === 313 /* Bundle */ ? sourceFileOrBundle : void 0;
                const sourceFile = sourceFileOrBundle.kind === 312 /* SourceFile */ ? sourceFileOrBundle : void 0;
                const sourceFiles = bundle ? bundle.sourceFiles : [sourceFile];
                let sourceMapGenerator;
                if (shouldEmitSourceMaps(mapOptions, sourceFileOrBundle)) {
                    sourceMapGenerator = createSourceMapGenerator(host, getBaseFileName(normalizeSlashes(jsFilePath)), getSourceRoot(mapOptions), getSourceMapDirectory(mapOptions, jsFilePath, sourceFile), mapOptions);
                }
                if (bundle) {
                    printer.writeBundle(bundle, writer, sourceMapGenerator);
                }
                else {
                    printer.writeFile(sourceFile, writer, sourceMapGenerator);
                }
                let sourceMapUrlPos;
                if (sourceMapGenerator) {
                    if (sourceMapDataList) {
                        sourceMapDataList.push({
                            inputSourceFileNames: sourceMapGenerator.getSources(),
                            sourceMap: sourceMapGenerator.toJSON()
                        });
                    }
                    const sourceMappingURL = getSourceMappingURL(mapOptions, sourceMapGenerator, jsFilePath, sourceMapFilePath, sourceFile);
                    if (sourceMappingURL) {
                        if (!writer.isAtStartOfLine())
                            writer.rawWrite(newLine);
                        sourceMapUrlPos = writer.getTextPos();
                        writer.writeComment(`//# ${"sourceMappingURL"}=${sourceMappingURL}`);
                    }
                    if (sourceMapFilePath) {
                        const sourceMap = sourceMapGenerator.toString();
                        writeFile(host, emitterDiagnostics, sourceMapFilePath, sourceMap, 
                        /*writeByteOrderMark*/
                        false, sourceFiles);
                        if (printer.bundleFileInfo)
                            printer.bundleFileInfo.mapHash = computeSignature(sourceMap, host);
                    }
                }
                else {
                    writer.writeLine();
                }
                const text = writer.getText();
                writeFile(host, emitterDiagnostics, jsFilePath, text, !!compilerOptions.emitBOM, sourceFiles, { sourceMapUrlPos, diagnostics: transform2.diagnostics });
                if (printer.bundleFileInfo)
                    printer.bundleFileInfo.hash = computeSignature(text, host);
                writer.clear();
            }
            function shouldEmitSourceMaps(mapOptions, sourceFileOrBundle) {
                return (mapOptions.sourceMap || mapOptions.inlineSourceMap) && (sourceFileOrBundle.kind !== 312 /* SourceFile */ || !fileExtensionIs(sourceFileOrBundle.fileName, ".json" /* Json */));
            }
            function getSourceRoot(mapOptions) {
                const sourceRoot = normalizeSlashes(mapOptions.sourceRoot || "");
                return sourceRoot ? ensureTrailingDirectorySeparator(sourceRoot) : sourceRoot;
            }
            function getSourceMapDirectory(mapOptions, filePath, sourceFile) {
                if (mapOptions.sourceRoot)
                    return host.getCommonSourceDirectory();
                if (mapOptions.mapRoot) {
                    let sourceMapDir = normalizeSlashes(mapOptions.mapRoot);
                    if (sourceFile) {
                        sourceMapDir = getDirectoryPath(getSourceFilePathInNewDir(sourceFile.fileName, host, sourceMapDir));
                    }
                    if (getRootLength(sourceMapDir) === 0) {
                        sourceMapDir = combinePaths(host.getCommonSourceDirectory(), sourceMapDir);
                    }
                    return sourceMapDir;
                }
                return getDirectoryPath(normalizePath(filePath));
            }
            function getSourceMappingURL(mapOptions, sourceMapGenerator, filePath, sourceMapFilePath, sourceFile) {
                if (mapOptions.inlineSourceMap) {
                    const sourceMapText = sourceMapGenerator.toString();
                    const base64SourceMapText = base64encode(sys, sourceMapText);
                    return `data:application/json;base64,${base64SourceMapText}`;
                }
                const sourceMapFile = getBaseFileName(normalizeSlashes(Debug.checkDefined(sourceMapFilePath)));
                if (mapOptions.mapRoot) {
                    let sourceMapDir = normalizeSlashes(mapOptions.mapRoot);
                    if (sourceFile) {
                        sourceMapDir = getDirectoryPath(getSourceFilePathInNewDir(sourceFile.fileName, host, sourceMapDir));
                    }
                    if (getRootLength(sourceMapDir) === 0) {
                        sourceMapDir = combinePaths(host.getCommonSourceDirectory(), sourceMapDir);
                        return encodeURI(getRelativePathToDirectoryOrUrl(getDirectoryPath(normalizePath(filePath)), 
                        // get the relative sourceMapDir path based on jsFilePath
                        combinePaths(sourceMapDir, sourceMapFile), 
                        // this is where user expects to see sourceMap
                        host.getCurrentDirectory(), host.getCanonicalFileName, 
                        /*isAbsolutePathAnUrl*/
                        true));
                    }
                    else {
                        return encodeURI(combinePaths(sourceMapDir, sourceMapFile));
                    }
                }
                return encodeURI(sourceMapFile);
            }
        }
        function createBuildInfo(program, bundle) {
            return { bundle, program, version };
        }
        function getBuildInfoText(buildInfo) {
            return JSON.stringify(buildInfo);
        }
        function getBuildInfo(buildInfoFile, buildInfoText) {
            return readJsonOrUndefined(buildInfoFile, buildInfoText);
        }
        function createSourceFilesFromBundleBuildInfo(bundle, buildInfoDirectory, host) {
            var _a;
            const jsBundle = Debug.checkDefined(bundle.js);
            const prologueMap = ((_a = jsBundle.sources) == null ? void 0 : _a.prologues) && arrayToMap(jsBundle.sources.prologues, (prologueInfo) => prologueInfo.file);
            return bundle.sourceFiles.map((fileName, index) => {
                const prologueInfo = prologueMap == null ? void 0 : prologueMap.get(index);
                const statements = prologueInfo == null ? void 0 : prologueInfo.directives.map((directive) => {
                    const literal = setTextRange(factory.createStringLiteral(directive.expression.text), directive.expression);
                    const statement = setTextRange(factory.createExpressionStatement(literal), directive);
                    setParent(literal, statement);
                    return statement;
                });
                const eofToken = factory.createToken(1 /* EndOfFileToken */);
                const sourceFile = factory.createSourceFile(statements ?? [], eofToken, 0 /* None */);
                sourceFile.fileName = getRelativePathFromDirectory(host.getCurrentDirectory(), getNormalizedAbsolutePath(fileName, buildInfoDirectory), !host.useCaseSensitiveFileNames());
                sourceFile.text = (prologueInfo == null ? void 0 : prologueInfo.text) ?? "";
                setTextRangePosWidth(sourceFile, 0, (prologueInfo == null ? void 0 : prologueInfo.text.length) ?? 0);
                setEachParent(sourceFile.statements, sourceFile);
                setTextRangePosWidth(eofToken, sourceFile.end, 0);
                setParent(eofToken, sourceFile);
                return sourceFile;
            });
        }
        function emitUsingBuildInfo(config, host, getCommandLine, customTransformers) {
            var _a, _b;
            (_a = tracing) == null ? void 0 : _a.push(tracing.Phase.Emit, "emitUsingBuildInfo", {}, 
            /*separateBeginAndEnd*/
            true);
            mark("beforeEmit");
            const result = emitUsingBuildInfoWorker(config, host, getCommandLine, customTransformers);
            mark("afterEmit");
            measure("Emit", "beforeEmit", "afterEmit");
            (_b = tracing) == null ? void 0 : _b.pop();
            return result;
        }
        function emitUsingBuildInfoWorker(config, host, getCommandLine, customTransformers) {
            const { buildInfoPath, jsFilePath, sourceMapFilePath, declarationFilePath, declarationMapPath } = getOutputPathsForBundle(config.options, 
            /*forceDtsPaths*/
            false);
            const buildInfo = host.getBuildInfo(buildInfoPath, config.options.configFilePath);
            if (!buildInfo)
                return buildInfoPath;
            if (!buildInfo.bundle || !buildInfo.bundle.js || declarationFilePath && !buildInfo.bundle.dts)
                return buildInfoPath;
            const jsFileText = host.readFile(Debug.checkDefined(jsFilePath));
            if (!jsFileText)
                return jsFilePath;
            if (computeSignature(jsFileText, host) !== buildInfo.bundle.js.hash)
                return jsFilePath;
            const sourceMapText = sourceMapFilePath && host.readFile(sourceMapFilePath);
            if (sourceMapFilePath && !sourceMapText || config.options.inlineSourceMap)
                return sourceMapFilePath || "inline sourcemap decoding";
            if (sourceMapFilePath && computeSignature(sourceMapText, host) !== buildInfo.bundle.js.mapHash)
                return sourceMapFilePath;
            const declarationText = declarationFilePath && host.readFile(declarationFilePath);
            if (declarationFilePath && !declarationText)
                return declarationFilePath;
            if (declarationFilePath && computeSignature(declarationText, host) !== buildInfo.bundle.dts.hash)
                return declarationFilePath;
            const declarationMapText = declarationMapPath && host.readFile(declarationMapPath);
            if (declarationMapPath && !declarationMapText || config.options.inlineSourceMap)
                return declarationMapPath || "inline sourcemap decoding";
            if (declarationMapPath && computeSignature(declarationMapText, host) !== buildInfo.bundle.dts.mapHash)
                return declarationMapPath;
            const buildInfoDirectory = getDirectoryPath(getNormalizedAbsolutePath(buildInfoPath, host.getCurrentDirectory()));
            const ownPrependInput = createInputFilesWithFileTexts(jsFilePath, jsFileText, sourceMapFilePath, sourceMapText, declarationFilePath, declarationText, declarationMapPath, declarationMapText, buildInfoPath, buildInfo, 
            /*oldFileOfCurrentEmit*/
            true);
            const outputFiles = [];
            const prependNodes = createPrependNodes(config.projectReferences, getCommandLine, (f) => host.readFile(f), host);
            const sourceFilesForJsEmit = createSourceFilesFromBundleBuildInfo(buildInfo.bundle, buildInfoDirectory, host);
            let changedDtsText;
            let changedDtsData;
            const emitHost = {
                getPrependNodes: memoize(() => [...prependNodes, ownPrependInput]),
                getCanonicalFileName: host.getCanonicalFileName,
                getCommonSourceDirectory: () => getNormalizedAbsolutePath(buildInfo.bundle.commonSourceDirectory, buildInfoDirectory),
                getCompilerOptions: () => config.options,
                getCurrentDirectory: () => host.getCurrentDirectory(),
                getSourceFile: returnUndefined,
                getSourceFileByPath: returnUndefined,
                getSourceFiles: () => sourceFilesForJsEmit,
                getLibFileFromReference: notImplemented,
                isSourceFileFromExternalLibrary: returnFalse,
                getResolvedProjectReferenceToRedirect: returnUndefined,
                getProjectReferenceRedirect: returnUndefined,
                isSourceOfProjectReferenceRedirect: returnFalse,
                writeFile: (name, text, writeByteOrderMark, _onError, _sourceFiles, data) => {
                    switch (name) {
                        case jsFilePath:
                            if (jsFileText === text)
                                return;
                            break;
                        case sourceMapFilePath:
                            if (sourceMapText === text)
                                return;
                            break;
                        case buildInfoPath:
                            break;
                        case declarationFilePath:
                            if (declarationText === text)
                                return;
                            changedDtsText = text;
                            changedDtsData = data;
                            break;
                        case declarationMapPath:
                            if (declarationMapText === text)
                                return;
                            break;
                        default:
                            Debug.fail(`Unexpected path: ${name}`);
                    }
                    outputFiles.push({ name, text, writeByteOrderMark, data });
                },
                isEmitBlocked: returnFalse,
                readFile: (f) => host.readFile(f),
                fileExists: (f) => host.fileExists(f),
                useCaseSensitiveFileNames: () => host.useCaseSensitiveFileNames(),
                getBuildInfo: (bundle) => {
                    const program = buildInfo.program;
                    if (program && changedDtsText !== void 0 && config.options.composite) {
                        program.outSignature = computeSignature(changedDtsText, host, changedDtsData);
                    }
                    const { js, dts, sourceFiles } = buildInfo.bundle;
                    bundle.js.sources = js.sources;
                    if (dts) {
                        bundle.dts.sources = dts.sources;
                    }
                    bundle.sourceFiles = sourceFiles;
                    return createBuildInfo(program, bundle);
                },
                getSourceFileFromReference: returnUndefined,
                redirectTargetsMap: createMultiMap(),
                getFileIncludeReasons: notImplemented,
                createHash: maybeBind(host, host.createHash)
            };
            emitFiles(notImplementedResolver, emitHost, 
            /*targetSourceFile*/
            void 0, getTransformers(config.options, customTransformers));
            return outputFiles;
        }
        function createPrinter(printerOptions = {}, handlers = {}) {
            var { hasGlobalName, onEmitNode = noEmitNotification, isEmitNotificationEnabled, substituteNode = noEmitSubstitution, onBeforeEmitNode, onAfterEmitNode, onBeforeEmitNodeArray, onAfterEmitNodeArray, onBeforeEmitToken, onAfterEmitToken } = handlers;
            var extendedDiagnostics = !!printerOptions.extendedDiagnostics;
            var omitBraceSourcePositions = !!printerOptions.omitBraceSourceMapPositions;
            var newLine = getNewLineCharacter(printerOptions);
            var moduleKind = getEmitModuleKind(printerOptions);
            var bundledHelpers = /* @__PURE__ */ new Map();
            var currentSourceFile;
            var nodeIdToGeneratedName;
            var nodeIdToGeneratedPrivateName;
            var autoGeneratedIdToGeneratedName;
            var generatedNames;
            var formattedNameTempFlagsStack;
            var formattedNameTempFlags;
            var privateNameTempFlagsStack;
            var privateNameTempFlags;
            var tempFlagsStack;
            var tempFlags;
            var reservedNamesStack;
            var reservedNames;
            var reservedPrivateNamesStack;
            var reservedPrivateNames;
            var preserveSourceNewlines = printerOptions.preserveSourceNewlines;
            var nextListElementPos;
            var writer;
            var ownWriter;
            var write = writeBase;
            var isOwnFileEmit;
            var bundleFileInfo = printerOptions.writeBundleFileInfo ? { sections: [] } : void 0;
            var relativeToBuildInfo = bundleFileInfo ? Debug.checkDefined(printerOptions.relativeToBuildInfo) : void 0;
            var recordInternalSection = printerOptions.recordInternalSection;
            var sourceFileTextPos = 0;
            var sourceFileTextKind = "text" /* Text */;
            var sourceMapsDisabled = true;
            var sourceMapGenerator;
            var sourceMapSource;
            var sourceMapSourceIndex = -1;
            var mostRecentlyAddedSourceMapSource;
            var mostRecentlyAddedSourceMapSourceIndex = -1;
            var containerPos = -1;
            var containerEnd = -1;
            var declarationListContainerEnd = -1;
            var currentLineMap;
            var detachedCommentsInfo;
            var hasWrittenComment = false;
            var commentsDisabled = !!printerOptions.removeComments;
            var lastSubstitution;
            var currentParenthesizerRule;
            var { enter: enterComment, exit: exitComment } = createTimerIf(extendedDiagnostics, "commentTime", "beforeComment", "afterComment");
            var parenthesizer = factory.parenthesizer;
            var typeArgumentParenthesizerRuleSelector = {
                select: (index) => index === 0 ? parenthesizer.parenthesizeLeadingTypeArgument : void 0
            };
            var emitBinaryExpression = createEmitBinaryExpression();
            reset2();
            return {
                // public API
                printNode,
                printList,
                printFile,
                printBundle,
                // internal API
                writeNode,
                writeList,
                writeFile: writeFile2,
                writeBundle,
                bundleFileInfo
            };
            function printNode(hint, node, sourceFile) {
                switch (hint) {
                    case 0 /* SourceFile */:
                        Debug.assert(isSourceFile(node), "Expected a SourceFile node.");
                        break;
                    case 2 /* IdentifierName */:
                        Debug.assert(isIdentifier(node), "Expected an Identifier node.");
                        break;
                    case 1 /* Expression */:
                        Debug.assert(isExpression(node), "Expected an Expression node.");
                        break;
                }
                switch (node.kind) {
                    case 312 /* SourceFile */:
                        return printFile(node);
                    case 313 /* Bundle */:
                        return printBundle(node);
                    case 314 /* UnparsedSource */:
                        return printUnparsedSource(node);
                }
                writeNode(hint, node, sourceFile, beginPrint());
                return endPrint();
            }
            function printList(format, nodes, sourceFile) {
                writeList(format, nodes, sourceFile, beginPrint());
                return endPrint();
            }
            function printBundle(bundle) {
                writeBundle(bundle, beginPrint(), 
                /*sourceMapGenerator*/
                void 0);
                return endPrint();
            }
            function printFile(sourceFile) {
                writeFile2(sourceFile, beginPrint(), 
                /*sourceMapGenerator*/
                void 0);
                return endPrint();
            }
            function printUnparsedSource(unparsed) {
                writeUnparsedSource(unparsed, beginPrint());
                return endPrint();
            }
            function writeNode(hint, node, sourceFile, output) {
                const previousWriter = writer;
                setWriter(output, 
                /*_sourceMapGenerator*/
                void 0);
                print(hint, node, sourceFile);
                reset2();
                writer = previousWriter;
            }
            function writeList(format, nodes, sourceFile, output) {
                const previousWriter = writer;
                setWriter(output, 
                /*_sourceMapGenerator*/
                void 0);
                if (sourceFile) {
                    setSourceFile(sourceFile);
                }
                emitList(
                /*parentNode*/
                void 0, nodes, format);
                reset2();
                writer = previousWriter;
            }
            function getTextPosWithWriteLine() {
                return writer.getTextPosWithWriteLine ? writer.getTextPosWithWriteLine() : writer.getTextPos();
            }
            function updateOrPushBundleFileTextLike(pos, end, kind) {
                const last2 = lastOrUndefined(bundleFileInfo.sections);
                if (last2 && last2.kind === kind) {
                    last2.end = end;
                }
                else {
                    bundleFileInfo.sections.push({ pos, end, kind });
                }
            }
            function recordBundleFileInternalSectionStart(node) {
                if (recordInternalSection && bundleFileInfo && currentSourceFile && (isDeclaration(node) || isVariableStatement(node)) && isInternalDeclaration(node, currentSourceFile) && sourceFileTextKind !== "internal" /* Internal */) {
                    const prevSourceFileTextKind = sourceFileTextKind;
                    recordBundleFileTextLikeSection(writer.getTextPos());
                    sourceFileTextPos = getTextPosWithWriteLine();
                    sourceFileTextKind = "internal" /* Internal */;
                    return prevSourceFileTextKind;
                }
                return void 0;
            }
            function recordBundleFileInternalSectionEnd(prevSourceFileTextKind) {
                if (prevSourceFileTextKind) {
                    recordBundleFileTextLikeSection(writer.getTextPos());
                    sourceFileTextPos = getTextPosWithWriteLine();
                    sourceFileTextKind = prevSourceFileTextKind;
                }
            }
            function recordBundleFileTextLikeSection(end) {
                if (sourceFileTextPos < end) {
                    updateOrPushBundleFileTextLike(sourceFileTextPos, end, sourceFileTextKind);
                    return true;
                }
                return false;
            }
            function writeBundle(bundle, output, sourceMapGenerator2) {
                isOwnFileEmit = false;
                const previousWriter = writer;
                setWriter(output, sourceMapGenerator2);
                emitShebangIfNeeded(bundle);
                emitPrologueDirectivesIfNeeded(bundle);
                emitHelpers(bundle);
                emitSyntheticTripleSlashReferencesIfNeeded(bundle);
                for (const prepend of bundle.prepends) {
                    writeLine();
                    const pos = writer.getTextPos();
                    const savedSections = bundleFileInfo && bundleFileInfo.sections;
                    if (savedSections)
                        bundleFileInfo.sections = [];
                    print(4 /* Unspecified */, prepend, 
                    /*sourceFile*/
                    void 0);
                    if (bundleFileInfo) {
                        const newSections = bundleFileInfo.sections;
                        bundleFileInfo.sections = savedSections;
                        if (prepend.oldFileOfCurrentEmit)
                            bundleFileInfo.sections.push(...newSections);
                        else {
                            newSections.forEach((section) => Debug.assert(isBundleFileTextLike(section)));
                            bundleFileInfo.sections.push({
                                pos,
                                end: writer.getTextPos(),
                                kind: "prepend" /* Prepend */,
                                data: relativeToBuildInfo(prepend.fileName),
                                texts: newSections
                            });
                        }
                    }
                }
                sourceFileTextPos = getTextPosWithWriteLine();
                for (const sourceFile of bundle.sourceFiles) {
                    print(0 /* SourceFile */, sourceFile, sourceFile);
                }
                if (bundleFileInfo && bundle.sourceFiles.length) {
                    const end = writer.getTextPos();
                    if (recordBundleFileTextLikeSection(end)) {
                        const prologues = getPrologueDirectivesFromBundledSourceFiles(bundle);
                        if (prologues) {
                            if (!bundleFileInfo.sources)
                                bundleFileInfo.sources = {};
                            bundleFileInfo.sources.prologues = prologues;
                        }
                        const helpers = getHelpersFromBundledSourceFiles(bundle);
                        if (helpers) {
                            if (!bundleFileInfo.sources)
                                bundleFileInfo.sources = {};
                            bundleFileInfo.sources.helpers = helpers;
                        }
                    }
                }
                reset2();
                writer = previousWriter;
            }
            function writeUnparsedSource(unparsed, output) {
                const previousWriter = writer;
                setWriter(output, 
                /*_sourceMapGenerator*/
                void 0);
                print(4 /* Unspecified */, unparsed, 
                /*sourceFile*/
                void 0);
                reset2();
                writer = previousWriter;
            }
            function writeFile2(sourceFile, output, sourceMapGenerator2) {
                isOwnFileEmit = true;
                const previousWriter = writer;
                setWriter(output, sourceMapGenerator2);
                emitShebangIfNeeded(sourceFile);
                emitPrologueDirectivesIfNeeded(sourceFile);
                print(0 /* SourceFile */, sourceFile, sourceFile);
                reset2();
                writer = previousWriter;
            }
            function beginPrint() {
                return ownWriter || (ownWriter = createTextWriter(newLine));
            }
            function endPrint() {
                const text = ownWriter.getText();
                ownWriter.clear();
                return text;
            }
            function print(hint, node, sourceFile) {
                if (sourceFile) {
                    setSourceFile(sourceFile);
                }
                pipelineEmit(hint, node, 
                /*parenthesizerRule*/
                void 0);
            }
            function setSourceFile(sourceFile) {
                currentSourceFile = sourceFile;
                currentLineMap = void 0;
                detachedCommentsInfo = void 0;
                if (sourceFile) {
                    setSourceMapSource(sourceFile);
                }
            }
            function setWriter(_writer, _sourceMapGenerator) {
                if (_writer && printerOptions.omitTrailingSemicolon) {
                    _writer = getTrailingSemicolonDeferringWriter(_writer);
                }
                writer = _writer;
                sourceMapGenerator = _sourceMapGenerator;
                sourceMapsDisabled = !writer || !sourceMapGenerator;
            }
            function reset2() {
                nodeIdToGeneratedName = [];
                nodeIdToGeneratedPrivateName = [];
                autoGeneratedIdToGeneratedName = [];
                generatedNames = /* @__PURE__ */ new Set();
                formattedNameTempFlagsStack = [];
                formattedNameTempFlags = /* @__PURE__ */ new Map();
                privateNameTempFlagsStack = [];
                privateNameTempFlags = 0 /* Auto */;
                tempFlagsStack = [];
                tempFlags = 0 /* Auto */;
                reservedNamesStack = [];
                reservedNames = void 0;
                reservedPrivateNamesStack = [];
                reservedPrivateNames = void 0;
                currentSourceFile = void 0;
                currentLineMap = void 0;
                detachedCommentsInfo = void 0;
                setWriter(
                /*output*/
                void 0, 
                /*_sourceMapGenerator*/
                void 0);
            }
            function getCurrentLineMap() {
                return currentLineMap || (currentLineMap = getLineStarts(Debug.checkDefined(currentSourceFile)));
            }
            function emit(node, parenthesizerRule) {
                if (node === void 0)
                    return;
                const prevSourceFileTextKind = recordBundleFileInternalSectionStart(node);
                pipelineEmit(4 /* Unspecified */, node, parenthesizerRule);
                recordBundleFileInternalSectionEnd(prevSourceFileTextKind);
            }
            function emitIdentifierName(node) {
                if (node === void 0)
                    return;
                pipelineEmit(2 /* IdentifierName */, node, 
                /*parenthesizerRule*/
                void 0);
            }
            function emitExpression(node, parenthesizerRule) {
                if (node === void 0)
                    return;
                pipelineEmit(1 /* Expression */, node, parenthesizerRule);
            }
            function emitJsxAttributeValue(node) {
                pipelineEmit(isStringLiteral(node) ? 6 /* JsxAttributeValue */ : 4 /* Unspecified */, node);
            }
            function beforeEmitNode(node) {
                if (preserveSourceNewlines && getInternalEmitFlags(node) & 4 /* IgnoreSourceNewlines */) {
                    preserveSourceNewlines = false;
                }
            }
            function afterEmitNode(savedPreserveSourceNewlines) {
                preserveSourceNewlines = savedPreserveSourceNewlines;
            }
            function pipelineEmit(emitHint, node, parenthesizerRule) {
                currentParenthesizerRule = parenthesizerRule;
                const pipelinePhase = getPipelinePhase(0 /* Notification */, emitHint, node);
                pipelinePhase(emitHint, node);
                currentParenthesizerRule = void 0;
            }
            function shouldEmitComments(node) {
                return !commentsDisabled && !isSourceFile(node);
            }
            function shouldEmitSourceMaps(node) {
                return !sourceMapsDisabled && !isSourceFile(node) && !isInJsonFile(node) && !isUnparsedSource(node) && !isUnparsedPrepend(node);
            }
            function getPipelinePhase(phase, emitHint, node) {
                switch (phase) {
                    case 0 /* Notification */:
                        if (onEmitNode !== noEmitNotification && (!isEmitNotificationEnabled || isEmitNotificationEnabled(node))) {
                            return pipelineEmitWithNotification;
                        }
                    case 1 /* Substitution */:
                        if (substituteNode !== noEmitSubstitution && (lastSubstitution = substituteNode(emitHint, node) || node) !== node) {
                            if (currentParenthesizerRule) {
                                lastSubstitution = currentParenthesizerRule(lastSubstitution);
                            }
                            return pipelineEmitWithSubstitution;
                        }
                    case 2 /* Comments */:
                        if (shouldEmitComments(node)) {
                            return pipelineEmitWithComments;
                        }
                    case 3 /* SourceMaps */:
                        if (shouldEmitSourceMaps(node)) {
                            return pipelineEmitWithSourceMaps;
                        }
                    case 4 /* Emit */:
                        return pipelineEmitWithHint;
                    default:
                        return Debug.assertNever(phase);
                }
            }
            function getNextPipelinePhase(currentPhase, emitHint, node) {
                return getPipelinePhase(currentPhase + 1, emitHint, node);
            }
            function pipelineEmitWithNotification(hint, node) {
                const pipelinePhase = getNextPipelinePhase(0 /* Notification */, hint, node);
                onEmitNode(hint, node, pipelinePhase);
            }
            function pipelineEmitWithHint(hint, node) {
                onBeforeEmitNode == null ? void 0 : onBeforeEmitNode(node);
                if (preserveSourceNewlines) {
                    const savedPreserveSourceNewlines = preserveSourceNewlines;
                    beforeEmitNode(node);
                    pipelineEmitWithHintWorker(hint, node);
                    afterEmitNode(savedPreserveSourceNewlines);
                }
                else {
                    pipelineEmitWithHintWorker(hint, node);
                }
                onAfterEmitNode == null ? void 0 : onAfterEmitNode(node);
                currentParenthesizerRule = void 0;
            }
            function pipelineEmitWithHintWorker(hint, node, allowSnippets = true) {
                if (allowSnippets) {
                    const snippet = getSnippetElement(node);
                    if (snippet) {
                        return emitSnippetNode(hint, node, snippet);
                    }
                }
                if (hint === 0 /* SourceFile */)
                    return emitSourceFile(cast(node, isSourceFile));
                if (hint === 2 /* IdentifierName */)
                    return emitIdentifier(cast(node, isIdentifier));
                if (hint === 6 /* JsxAttributeValue */)
                    return emitLiteral(cast(node, isStringLiteral), 
                    /*jsxAttributeEscape*/
                    true);
                if (hint === 3 /* MappedTypeParameter */)
                    return emitMappedTypeParameter(cast(node, isTypeParameterDeclaration));
                if (hint === 7 /* ImportTypeNodeAttributes */)
                    return emitImportTypeNodeAttributes(cast(node, isImportAttributes));
                if (hint === 5 /* EmbeddedStatement */) {
                    Debug.assertNode(node, isEmptyStatement);
                    return emitEmptyStatement(
                    /*isEmbeddedStatement*/
                    true);
                }
                if (hint === 4 /* Unspecified */) {
                    switch (node.kind) {
                        case 16 /* TemplateHead */:
                        case 17 /* TemplateMiddle */:
                        case 18 /* TemplateTail */:
                            return emitLiteral(node, 
                            /*jsxAttributeEscape*/
                            false);
                        case 80 /* Identifier */:
                            return emitIdentifier(node);
                        case 81 /* PrivateIdentifier */:
                            return emitPrivateIdentifier(node);
                        case 166 /* QualifiedName */:
                            return emitQualifiedName(node);
                        case 167 /* ComputedPropertyName */:
                            return emitComputedPropertyName(node);
                        case 168 /* TypeParameter */:
                            return emitTypeParameter(node);
                        case 169 /* Parameter */:
                            return emitParameter(node);
                        case 170 /* Decorator */:
                            return emitDecorator(node);
                        case 171 /* PropertySignature */:
                            return emitPropertySignature(node);
                        case 172 /* PropertyDeclaration */:
                            return emitPropertyDeclaration(node);
                        case 173 /* MethodSignature */:
                            return emitMethodSignature(node);
                        case 174 /* MethodDeclaration */:
                            return emitMethodDeclaration(node);
                        case 175 /* ClassStaticBlockDeclaration */:
                            return emitClassStaticBlockDeclaration(node);
                        case 176 /* Constructor */:
                            return emitConstructor(node);
                        case 177 /* GetAccessor */:
                        case 178 /* SetAccessor */:
                            return emitAccessorDeclaration(node);
                        case 179 /* CallSignature */:
                            return emitCallSignature(node);
                        case 180 /* ConstructSignature */:
                            return emitConstructSignature(node);
                        case 181 /* IndexSignature */:
                            return emitIndexSignature(node);
                        case 182 /* TypePredicate */:
                            return emitTypePredicate(node);
                        case 183 /* TypeReference */:
                            return emitTypeReference(node);
                        case 184 /* FunctionType */:
                            return emitFunctionType(node);
                        case 185 /* ConstructorType */:
                            return emitConstructorType(node);
                        case 186 /* TypeQuery */:
                            return emitTypeQuery(node);
                        case 187 /* TypeLiteral */:
                            return emitTypeLiteral(node);
                        case 188 /* ArrayType */:
                            return emitArrayType(node);
                        case 189 /* TupleType */:
                            return emitTupleType(node);
                        case 190 /* OptionalType */:
                            return emitOptionalType(node);
                        case 192 /* UnionType */:
                            return emitUnionType(node);
                        case 193 /* IntersectionType */:
                            return emitIntersectionType(node);
                        case 194 /* ConditionalType */:
                            return emitConditionalType(node);
                        case 195 /* InferType */:
                            return emitInferType(node);
                        case 196 /* ParenthesizedType */:
                            return emitParenthesizedType(node);
                        case 233 /* ExpressionWithTypeArguments */:
                            return emitExpressionWithTypeArguments(node);
                        case 197 /* ThisType */:
                            return emitThisType();
                        case 198 /* TypeOperator */:
                            return emitTypeOperator(node);
                        case 199 /* IndexedAccessType */:
                            return emitIndexedAccessType(node);
                        case 200 /* MappedType */:
                            return emitMappedType(node);
                        case 201 /* LiteralType */:
                            return emitLiteralType(node);
                        case 202 /* NamedTupleMember */:
                            return emitNamedTupleMember(node);
                        case 203 /* TemplateLiteralType */:
                            return emitTemplateType(node);
                        case 204 /* TemplateLiteralTypeSpan */:
                            return emitTemplateTypeSpan(node);
                        case 205 /* ImportType */:
                            return emitImportTypeNode(node);
                        case 206 /* ObjectBindingPattern */:
                            return emitObjectBindingPattern(node);
                        case 207 /* ArrayBindingPattern */:
                            return emitArrayBindingPattern(node);
                        case 208 /* BindingElement */:
                            return emitBindingElement(node);
                        case 239 /* TemplateSpan */:
                            return emitTemplateSpan(node);
                        case 240 /* SemicolonClassElement */:
                            return emitSemicolonClassElement();
                        case 241 /* Block */:
                            return emitBlock(node);
                        case 243 /* VariableStatement */:
                            return emitVariableStatement(node);
                        case 242 /* EmptyStatement */:
                            return emitEmptyStatement(
                            /*isEmbeddedStatement*/
                            false);
                        case 244 /* ExpressionStatement */:
                            return emitExpressionStatement(node);
                        case 245 /* IfStatement */:
                            return emitIfStatement(node);
                        case 246 /* DoStatement */:
                            return emitDoStatement(node);
                        case 247 /* WhileStatement */:
                            return emitWhileStatement(node);
                        case 248 /* ForStatement */:
                            return emitForStatement(node);
                        case 249 /* ForInStatement */:
                            return emitForInStatement(node);
                        case 250 /* ForOfStatement */:
                            return emitForOfStatement(node);
                        case 251 /* ContinueStatement */:
                            return emitContinueStatement(node);
                        case 252 /* BreakStatement */:
                            return emitBreakStatement(node);
                        case 253 /* ReturnStatement */:
                            return emitReturnStatement(node);
                        case 254 /* WithStatement */:
                            return emitWithStatement(node);
                        case 255 /* SwitchStatement */:
                            return emitSwitchStatement(node);
                        case 256 /* LabeledStatement */:
                            return emitLabeledStatement(node);
                        case 257 /* ThrowStatement */:
                            return emitThrowStatement(node);
                        case 258 /* TryStatement */:
                            return emitTryStatement(node);
                        case 259 /* DebuggerStatement */:
                            return emitDebuggerStatement(node);
                        case 260 /* VariableDeclaration */:
                            return emitVariableDeclaration(node);
                        case 261 /* VariableDeclarationList */:
                            return emitVariableDeclarationList(node);
                        case 262 /* FunctionDeclaration */:
                            return emitFunctionDeclaration(node);
                        case 263 /* ClassDeclaration */:
                            return emitClassDeclaration(node);
                        case 264 /* InterfaceDeclaration */:
                            return emitInterfaceDeclaration(node);
                        case 265 /* TypeAliasDeclaration */:
                            return emitTypeAliasDeclaration(node);
                        case 266 /* EnumDeclaration */:
                            return emitEnumDeclaration(node);
                        case 267 /* ModuleDeclaration */:
                            return emitModuleDeclaration(node);
                        case 268 /* ModuleBlock */:
                            return emitModuleBlock(node);
                        case 269 /* CaseBlock */:
                            return emitCaseBlock(node);
                        case 270 /* NamespaceExportDeclaration */:
                            return emitNamespaceExportDeclaration(node);
                        case 271 /* ImportEqualsDeclaration */:
                            return emitImportEqualsDeclaration(node);
                        case 272 /* ImportDeclaration */:
                            return emitImportDeclaration(node);
                        case 273 /* ImportClause */:
                            return emitImportClause(node);
                        case 274 /* NamespaceImport */:
                            return emitNamespaceImport(node);
                        case 280 /* NamespaceExport */:
                            return emitNamespaceExport(node);
                        case 275 /* NamedImports */:
                            return emitNamedImports(node);
                        case 276 /* ImportSpecifier */:
                            return emitImportSpecifier(node);
                        case 277 /* ExportAssignment */:
                            return emitExportAssignment(node);
                        case 278 /* ExportDeclaration */:
                            return emitExportDeclaration(node);
                        case 279 /* NamedExports */:
                            return emitNamedExports(node);
                        case 281 /* ExportSpecifier */:
                            return emitExportSpecifier(node);
                        case 300 /* ImportAttributes */:
                            return emitImportAttributes(node);
                        case 301 /* ImportAttribute */:
                            return emitImportAttribute(node);
                        case 282 /* MissingDeclaration */:
                            return;
                        case 283 /* ExternalModuleReference */:
                            return emitExternalModuleReference(node);
                        case 12 /* JsxText */:
                            return emitJsxText(node);
                        case 286 /* JsxOpeningElement */:
                        case 289 /* JsxOpeningFragment */:
                            return emitJsxOpeningElementOrFragment(node);
                        case 287 /* JsxClosingElement */:
                        case 290 /* JsxClosingFragment */:
                            return emitJsxClosingElementOrFragment(node);
                        case 291 /* JsxAttribute */:
                            return emitJsxAttribute(node);
                        case 292 /* JsxAttributes */:
                            return emitJsxAttributes(node);
                        case 293 /* JsxSpreadAttribute */:
                            return emitJsxSpreadAttribute(node);
                        case 294 /* JsxExpression */:
                            return emitJsxExpression(node);
                        case 295 /* JsxNamespacedName */:
                            return emitJsxNamespacedName(node);
                        case 296 /* CaseClause */:
                            return emitCaseClause(node);
                        case 297 /* DefaultClause */:
                            return emitDefaultClause(node);
                        case 298 /* HeritageClause */:
                            return emitHeritageClause(node);
                        case 299 /* CatchClause */:
                            return emitCatchClause(node);
                        case 303 /* PropertyAssignment */:
                            return emitPropertyAssignment(node);
                        case 304 /* ShorthandPropertyAssignment */:
                            return emitShorthandPropertyAssignment(node);
                        case 305 /* SpreadAssignment */:
                            return emitSpreadAssignment(node);
                        case 306 /* EnumMember */:
                            return emitEnumMember(node);
                        case 307 /* UnparsedPrologue */:
                            return writeUnparsedNode(node);
                        case 314 /* UnparsedSource */:
                        case 308 /* UnparsedPrepend */:
                            return emitUnparsedSourceOrPrepend(node);
                        case 309 /* UnparsedText */:
                        case 310 /* UnparsedInternalText */:
                            return emitUnparsedTextLike(node);
                        case 311 /* UnparsedSyntheticReference */:
                            return emitUnparsedSyntheticReference(node);
                        case 312 /* SourceFile */:
                            return emitSourceFile(node);
                        case 313 /* Bundle */:
                            return Debug.fail("Bundles should be printed using printBundle");
                        case 315 /* InputFiles */:
                            return Debug.fail("InputFiles should not be printed");
                        case 316 /* JSDocTypeExpression */:
                            return emitJSDocTypeExpression(node);
                        case 317 /* JSDocNameReference */:
                            return emitJSDocNameReference(node);
                        case 319 /* JSDocAllType */:
                            return writePunctuation("*");
                        case 320 /* JSDocUnknownType */:
                            return writePunctuation("?");
                        case 321 /* JSDocNullableType */:
                            return emitJSDocNullableType(node);
                        case 322 /* JSDocNonNullableType */:
                            return emitJSDocNonNullableType(node);
                        case 323 /* JSDocOptionalType */:
                            return emitJSDocOptionalType(node);
                        case 324 /* JSDocFunctionType */:
                            return emitJSDocFunctionType(node);
                        case 191 /* RestType */:
                        case 325 /* JSDocVariadicType */:
                            return emitRestOrJSDocVariadicType(node);
                        case 326 /* JSDocNamepathType */:
                            return;
                        case 327 /* JSDoc */:
                            return emitJSDoc(node);
                        case 329 /* JSDocTypeLiteral */:
                            return emitJSDocTypeLiteral(node);
                        case 330 /* JSDocSignature */:
                            return emitJSDocSignature(node);
                        case 334 /* JSDocTag */:
                        case 339 /* JSDocClassTag */:
                        case 344 /* JSDocOverrideTag */:
                            return emitJSDocSimpleTag(node);
                        case 335 /* JSDocAugmentsTag */:
                        case 336 /* JSDocImplementsTag */:
                            return emitJSDocHeritageTag(node);
                        case 337 /* JSDocAuthorTag */:
                        case 338 /* JSDocDeprecatedTag */:
                            return;
                        case 340 /* JSDocPublicTag */:
                        case 341 /* JSDocPrivateTag */:
                        case 342 /* JSDocProtectedTag */:
                        case 343 /* JSDocReadonlyTag */:
                            return;
                        case 345 /* JSDocCallbackTag */:
                            return emitJSDocCallbackTag(node);
                        case 346 /* JSDocOverloadTag */:
                            return emitJSDocOverloadTag(node);
                        case 348 /* JSDocParameterTag */:
                        case 355 /* JSDocPropertyTag */:
                            return emitJSDocPropertyLikeTag(node);
                        case 347 /* JSDocEnumTag */:
                        case 349 /* JSDocReturnTag */:
                        case 350 /* JSDocThisTag */:
                        case 351 /* JSDocTypeTag */:
                        case 356 /* JSDocThrowsTag */:
                        case 357 /* JSDocSatisfiesTag */:
                            return emitJSDocSimpleTypedTag(node);
                        case 352 /* JSDocTemplateTag */:
                            return emitJSDocTemplateTag(node);
                        case 353 /* JSDocTypedefTag */:
                            return emitJSDocTypedefTag(node);
                        case 354 /* JSDocSeeTag */:
                            return emitJSDocSeeTag(node);
                        case 359 /* NotEmittedStatement */:
                            return;
                    }
                    if (isExpression(node)) {
                        hint = 1 /* Expression */;
                        if (substituteNode !== noEmitSubstitution) {
                            const substitute = substituteNode(hint, node) || node;
                            if (substitute !== node) {
                                node = substitute;
                                if (currentParenthesizerRule) {
                                    node = currentParenthesizerRule(node);
                                }
                            }
                        }
                    }
                }
                if (hint === 1 /* Expression */) {
                    switch (node.kind) {
                        case 9 /* NumericLiteral */:
                        case 10 /* BigIntLiteral */:
                            return emitNumericOrBigIntLiteral(node);
                        case 11 /* StringLiteral */:
                        case 14 /* RegularExpressionLiteral */:
                        case 15 /* NoSubstitutionTemplateLiteral */:
                            return emitLiteral(node, 
                            /*jsxAttributeEscape*/
                            false);
                        case 80 /* Identifier */:
                            return emitIdentifier(node);
                        case 81 /* PrivateIdentifier */:
                            return emitPrivateIdentifier(node);
                        case 209 /* ArrayLiteralExpression */:
                            return emitArrayLiteralExpression(node);
                        case 210 /* ObjectLiteralExpression */:
                            return emitObjectLiteralExpression(node);
                        case 211 /* PropertyAccessExpression */:
                            return emitPropertyAccessExpression(node);
                        case 212 /* ElementAccessExpression */:
                            return emitElementAccessExpression(node);
                        case 213 /* CallExpression */:
                            return emitCallExpression(node);
                        case 214 /* NewExpression */:
                            return emitNewExpression(node);
                        case 215 /* TaggedTemplateExpression */:
                            return emitTaggedTemplateExpression(node);
                        case 216 /* TypeAssertionExpression */:
                            return emitTypeAssertionExpression(node);
                        case 217 /* ParenthesizedExpression */:
                            return emitParenthesizedExpression(node);
                        case 218 /* FunctionExpression */:
                            return emitFunctionExpression(node);
                        case 219 /* ArrowFunction */:
                            return emitArrowFunction(node);
                        case 220 /* DeleteExpression */:
                            return emitDeleteExpression(node);
                        case 221 /* TypeOfExpression */:
                            return emitTypeOfExpression(node);
                        case 222 /* VoidExpression */:
                            return emitVoidExpression(node);
                        case 223 /* AwaitExpression */:
                            return emitAwaitExpression(node);
                        case 224 /* PrefixUnaryExpression */:
                            return emitPrefixUnaryExpression(node);
                        case 225 /* PostfixUnaryExpression */:
                            return emitPostfixUnaryExpression(node);
                        case 226 /* BinaryExpression */:
                            return emitBinaryExpression(node);
                        case 227 /* ConditionalExpression */:
                            return emitConditionalExpression(node);
                        case 228 /* TemplateExpression */:
                            return emitTemplateExpression(node);
                        case 229 /* YieldExpression */:
                            return emitYieldExpression(node);
                        case 230 /* SpreadElement */:
                            return emitSpreadElement(node);
                        case 231 /* ClassExpression */:
                            return emitClassExpression(node);
                        case 232 /* OmittedExpression */:
                            return;
                        case 234 /* AsExpression */:
                            return emitAsExpression(node);
                        case 235 /* NonNullExpression */:
                            return emitNonNullExpression(node);
                        case 233 /* ExpressionWithTypeArguments */:
                            return emitExpressionWithTypeArguments(node);
                        case 238 /* SatisfiesExpression */:
                            return emitSatisfiesExpression(node);
                        case 236 /* MetaProperty */:
                            return emitMetaProperty(node);
                        case 237 /* SyntheticExpression */:
                            return Debug.fail("SyntheticExpression should never be printed.");
                        case 282 /* MissingDeclaration */:
                            return;
                        case 284 /* JsxElement */:
                            return emitJsxElement(node);
                        case 285 /* JsxSelfClosingElement */:
                            return emitJsxSelfClosingElement(node);
                        case 288 /* JsxFragment */:
                            return emitJsxFragment(node);
                        case 358 /* SyntaxList */:
                            return Debug.fail("SyntaxList should not be printed");
                        case 359 /* NotEmittedStatement */:
                            return;
                        case 360 /* PartiallyEmittedExpression */:
                            return emitPartiallyEmittedExpression(node);
                        case 361 /* CommaListExpression */:
                            return emitCommaList(node);
                        case 362 /* SyntheticReferenceExpression */:
                            return Debug.fail("SyntheticReferenceExpression should not be printed");
                    }
                }
                if (isKeyword(node.kind))
                    return writeTokenNode(node, writeKeyword);
                if (isTokenKind(node.kind))
                    return writeTokenNode(node, writePunctuation);
                Debug.fail(`Unhandled SyntaxKind: ${Debug.formatSyntaxKind(node.kind)}.`);
            }
            function emitMappedTypeParameter(node) {
                emit(node.name);
                writeSpace();
                writeKeyword("in");
                writeSpace();
                emit(node.constraint);
            }
            function pipelineEmitWithSubstitution(hint, node) {
                const pipelinePhase = getNextPipelinePhase(1 /* Substitution */, hint, node);
                Debug.assertIsDefined(lastSubstitution);
                node = lastSubstitution;
                lastSubstitution = void 0;
                pipelinePhase(hint, node);
            }
            function getHelpersFromBundledSourceFiles(bundle) {
                let result;
                if (moduleKind === 0 /* None */ || printerOptions.noEmitHelpers) {
                    return void 0;
                }
                const bundledHelpers2 = /* @__PURE__ */ new Map();
                for (const sourceFile of bundle.sourceFiles) {
                    const shouldSkip = getExternalHelpersModuleName(sourceFile) !== void 0;
                    const helpers = getSortedEmitHelpers(sourceFile);
                    if (!helpers)
                        continue;
                    for (const helper of helpers) {
                        if (!helper.scoped && !shouldSkip && !bundledHelpers2.get(helper.name)) {
                            bundledHelpers2.set(helper.name, true);
                            (result || (result = [])).push(helper.name);
                        }
                    }
                }
                return result;
            }
            function emitHelpers(node) {
                let helpersEmitted = false;
                const bundle = node.kind === 313 /* Bundle */ ? node : void 0;
                if (bundle && moduleKind === 0 /* None */) {
                    return;
                }
                const numPrepends = bundle ? bundle.prepends.length : 0;
                const numNodes = bundle ? bundle.sourceFiles.length + numPrepends : 1;
                for (let i = 0; i < numNodes; i++) {
                    const currentNode = bundle ? i < numPrepends ? bundle.prepends[i] : bundle.sourceFiles[i - numPrepends] : node;
                    const sourceFile = isSourceFile(currentNode) ? currentNode : isUnparsedSource(currentNode) ? void 0 : currentSourceFile;
                    const shouldSkip = printerOptions.noEmitHelpers || !!sourceFile && hasRecordedExternalHelpers(sourceFile);
                    const shouldBundle = (isSourceFile(currentNode) || isUnparsedSource(currentNode)) && !isOwnFileEmit;
                    const helpers = isUnparsedSource(currentNode) ? currentNode.helpers : getSortedEmitHelpers(currentNode);
                    if (helpers) {
                        for (const helper of helpers) {
                            if (!helper.scoped) {
                                if (shouldSkip)
                                    continue;
                                if (shouldBundle) {
                                    if (bundledHelpers.get(helper.name)) {
                                        continue;
                                    }
                                    bundledHelpers.set(helper.name, true);
                                }
                            }
                            else if (bundle) {
                                continue;
                            }
                            const pos = getTextPosWithWriteLine();
                            if (typeof helper.text === "string") {
                                writeLines(helper.text);
                            }
                            else {
                                writeLines(helper.text(makeFileLevelOptimisticUniqueName));
                            }
                            if (bundleFileInfo)
                                bundleFileInfo.sections.push({ pos, end: writer.getTextPos(), kind: "emitHelpers" /* EmitHelpers */, data: helper.name });
                            helpersEmitted = true;
                        }
                    }
                }
                return helpersEmitted;
            }
            function getSortedEmitHelpers(node) {
                const helpers = getEmitHelpers(node);
                return helpers && stableSort(helpers, compareEmitHelpers);
            }
            function emitNumericOrBigIntLiteral(node) {
                emitLiteral(node, 
                /*jsxAttributeEscape*/
                false);
            }
            function emitLiteral(node, jsxAttributeEscape) {
                const text = getLiteralTextOfNode(node, printerOptions.neverAsciiEscape, jsxAttributeEscape);
                if ((printerOptions.sourceMap || printerOptions.inlineSourceMap) && (node.kind === 11 /* StringLiteral */ || isTemplateLiteralKind(node.kind))) {
                    writeLiteral(text);
                }
                else {
                    writeStringLiteral(text);
                }
            }
            function emitUnparsedSourceOrPrepend(unparsed) {
                for (const text of unparsed.texts) {
                    writeLine();
                    emit(text);
                }
            }
            function writeUnparsedNode(unparsed) {
                writer.rawWrite(unparsed.parent.text.substring(unparsed.pos, unparsed.end));
            }
            function emitUnparsedTextLike(unparsed) {
                const pos = getTextPosWithWriteLine();
                writeUnparsedNode(unparsed);
                if (bundleFileInfo) {
                    updateOrPushBundleFileTextLike(pos, writer.getTextPos(), unparsed.kind === 309 /* UnparsedText */ ? "text" /* Text */ : "internal" /* Internal */);
                }
            }
            function emitUnparsedSyntheticReference(unparsed) {
                const pos = getTextPosWithWriteLine();
                writeUnparsedNode(unparsed);
                if (bundleFileInfo) {
                    const section = clone(unparsed.section);
                    section.pos = pos;
                    section.end = writer.getTextPos();
                    bundleFileInfo.sections.push(section);
                }
            }
            function emitSnippetNode(hint, node, snippet) {
                switch (snippet.kind) {
                    case 1 /* Placeholder */:
                        emitPlaceholder(hint, node, snippet);
                        break;
                    case 0 /* TabStop */:
                        emitTabStop(hint, node, snippet);
                        break;
                }
            }
            function emitPlaceholder(hint, node, snippet) {
                nonEscapingWrite(`\${${snippet.order}:`);
                pipelineEmitWithHintWorker(hint, node, 
                /*allowSnippets*/
                false);
                nonEscapingWrite(`}`);
            }
            function emitTabStop(hint, node, snippet) {
                Debug.assert(node.kind === 242 /* EmptyStatement */, `A tab stop cannot be attached to a node of kind ${Debug.formatSyntaxKind(node.kind)}.`);
                Debug.assert(hint !== 5 /* EmbeddedStatement */, `A tab stop cannot be attached to an embedded statement.`);
                nonEscapingWrite(`$${snippet.order}`);
            }
            function emitIdentifier(node) {
                const writeText = node.symbol ? writeSymbol : write;
                writeText(getTextOfNode2(node, 
                /*includeTrivia*/
                false), node.symbol);
                emitList(node, getIdentifierTypeArguments(node), 53776 /* TypeParameters */);
            }
            function emitPrivateIdentifier(node) {
                write(getTextOfNode2(node, 
                /*includeTrivia*/
                false));
            }
            function emitQualifiedName(node) {
                emitEntityName(node.left);
                writePunctuation(".");
                emit(node.right);
            }
            function emitEntityName(node) {
                if (node.kind === 80 /* Identifier */) {
                    emitExpression(node);
                }
                else {
                    emit(node);
                }
            }
            function emitComputedPropertyName(node) {
                const savedPrivateNameTempFlags = privateNameTempFlags;
                const savedReservedMemberNames = reservedPrivateNames;
                popPrivateNameGenerationScope();
                writePunctuation("[");
                emitExpression(node.expression, parenthesizer.parenthesizeExpressionOfComputedPropertyName);
                writePunctuation("]");
                pushPrivateNameGenerationScope(savedPrivateNameTempFlags, savedReservedMemberNames);
            }
            function emitTypeParameter(node) {
                emitModifierList(node, node.modifiers);
                emit(node.name);
                if (node.constraint) {
                    writeSpace();
                    writeKeyword("extends");
                    writeSpace();
                    emit(node.constraint);
                }
                if (node.default) {
                    writeSpace();
                    writeOperator("=");
                    writeSpace();
                    emit(node.default);
                }
            }
            function emitParameter(node) {
                emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                true);
                emit(node.dotDotDotToken);
                emitNodeWithWriter(node.name, writeParameter);
                emit(node.questionToken);
                if (node.parent && node.parent.kind === 324 /* JSDocFunctionType */ && !node.name) {
                    emit(node.type);
                }
                else {
                    emitTypeAnnotation(node.type);
                }
                emitInitializer(node.initializer, node.type ? node.type.end : node.questionToken ? node.questionToken.end : node.name ? node.name.end : node.modifiers ? node.modifiers.end : node.pos, node, parenthesizer.parenthesizeExpressionForDisallowedComma);
            }
            function emitDecorator(decorator) {
                writePunctuation("@");
                emitExpression(decorator.expression, parenthesizer.parenthesizeLeftSideOfAccess);
            }
            function emitPropertySignature(node) {
                emitModifierList(node, node.modifiers);
                emitNodeWithWriter(node.name, writeProperty);
                emit(node.questionToken);
                emitTypeAnnotation(node.type);
                writeTrailingSemicolon();
            }
            function emitPropertyDeclaration(node) {
                emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                true);
                emit(node.name);
                emit(node.questionToken);
                emit(node.exclamationToken);
                emitTypeAnnotation(node.type);
                emitInitializer(node.initializer, node.type ? node.type.end : node.questionToken ? node.questionToken.end : node.name.end, node);
                writeTrailingSemicolon();
            }
            function emitMethodSignature(node) {
                pushNameGenerationScope(node);
                emitModifierList(node, node.modifiers);
                emit(node.name);
                emit(node.questionToken);
                emitTypeParameters(node, node.typeParameters);
                emitParameters(node, node.parameters);
                emitTypeAnnotation(node.type);
                writeTrailingSemicolon();
                popNameGenerationScope(node);
            }
            function emitMethodDeclaration(node) {
                emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                true);
                emit(node.asteriskToken);
                emit(node.name);
                emit(node.questionToken);
                emitSignatureAndBody(node, emitSignatureHead);
            }
            function emitClassStaticBlockDeclaration(node) {
                writeKeyword("static");
                emitBlockFunctionBody(node.body);
            }
            function emitConstructor(node) {
                emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                false);
                writeKeyword("constructor");
                emitSignatureAndBody(node, emitSignatureHead);
            }
            function emitAccessorDeclaration(node) {
                const pos = emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                true);
                const token = node.kind === 177 /* GetAccessor */ ? 139 /* GetKeyword */ : 153 /* SetKeyword */;
                emitTokenWithComment(token, pos, writeKeyword, node);
                writeSpace();
                emit(node.name);
                emitSignatureAndBody(node, emitSignatureHead);
            }
            function emitCallSignature(node) {
                pushNameGenerationScope(node);
                emitTypeParameters(node, node.typeParameters);
                emitParameters(node, node.parameters);
                emitTypeAnnotation(node.type);
                writeTrailingSemicolon();
                popNameGenerationScope(node);
            }
            function emitConstructSignature(node) {
                pushNameGenerationScope(node);
                writeKeyword("new");
                writeSpace();
                emitTypeParameters(node, node.typeParameters);
                emitParameters(node, node.parameters);
                emitTypeAnnotation(node.type);
                writeTrailingSemicolon();
                popNameGenerationScope(node);
            }
            function emitIndexSignature(node) {
                emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                false);
                emitParametersForIndexSignature(node, node.parameters);
                emitTypeAnnotation(node.type);
                writeTrailingSemicolon();
            }
            function emitTemplateTypeSpan(node) {
                emit(node.type);
                emit(node.literal);
            }
            function emitSemicolonClassElement() {
                writeTrailingSemicolon();
            }
            function emitTypePredicate(node) {
                if (node.assertsModifier) {
                    emit(node.assertsModifier);
                    writeSpace();
                }
                emit(node.parameterName);
                if (node.type) {
                    writeSpace();
                    writeKeyword("is");
                    writeSpace();
                    emit(node.type);
                }
            }
            function emitTypeReference(node) {
                emit(node.typeName);
                emitTypeArguments(node, node.typeArguments);
            }
            function emitFunctionType(node) {
                pushNameGenerationScope(node);
                emitTypeParameters(node, node.typeParameters);
                emitParametersForArrow(node, node.parameters);
                writeSpace();
                writePunctuation("=>");
                writeSpace();
                emit(node.type);
                popNameGenerationScope(node);
            }
            function emitJSDocFunctionType(node) {
                writeKeyword("function");
                emitParameters(node, node.parameters);
                writePunctuation(":");
                emit(node.type);
            }
            function emitJSDocNullableType(node) {
                writePunctuation("?");
                emit(node.type);
            }
            function emitJSDocNonNullableType(node) {
                writePunctuation("!");
                emit(node.type);
            }
            function emitJSDocOptionalType(node) {
                emit(node.type);
                writePunctuation("=");
            }
            function emitConstructorType(node) {
                pushNameGenerationScope(node);
                emitModifierList(node, node.modifiers);
                writeKeyword("new");
                writeSpace();
                emitTypeParameters(node, node.typeParameters);
                emitParameters(node, node.parameters);
                writeSpace();
                writePunctuation("=>");
                writeSpace();
                emit(node.type);
                popNameGenerationScope(node);
            }
            function emitTypeQuery(node) {
                writeKeyword("typeof");
                writeSpace();
                emit(node.exprName);
                emitTypeArguments(node, node.typeArguments);
            }
            function emitTypeLiteral(node) {
                pushPrivateNameGenerationScope(0 /* Auto */, 
                /*newReservedMemberNames*/
                void 0);
                writePunctuation("{");
                const flags = getEmitFlags(node) & 1 /* SingleLine */ ? 768 /* SingleLineTypeLiteralMembers */ : 32897 /* MultiLineTypeLiteralMembers */;
                emitList(node, node.members, flags | 524288 /* NoSpaceIfEmpty */);
                writePunctuation("}");
                popPrivateNameGenerationScope();
            }
            function emitArrayType(node) {
                emit(node.elementType, parenthesizer.parenthesizeNonArrayTypeOfPostfixType);
                writePunctuation("[");
                writePunctuation("]");
            }
            function emitRestOrJSDocVariadicType(node) {
                writePunctuation("...");
                emit(node.type);
            }
            function emitTupleType(node) {
                emitTokenWithComment(23 /* OpenBracketToken */, node.pos, writePunctuation, node);
                const flags = getEmitFlags(node) & 1 /* SingleLine */ ? 528 /* SingleLineTupleTypeElements */ : 657 /* MultiLineTupleTypeElements */;
                emitList(node, node.elements, flags | 524288 /* NoSpaceIfEmpty */, parenthesizer.parenthesizeElementTypeOfTupleType);
                emitTokenWithComment(24 /* CloseBracketToken */, node.elements.end, writePunctuation, node);
            }
            function emitNamedTupleMember(node) {
                emit(node.dotDotDotToken);
                emit(node.name);
                emit(node.questionToken);
                emitTokenWithComment(59 /* ColonToken */, node.name.end, writePunctuation, node);
                writeSpace();
                emit(node.type);
            }
            function emitOptionalType(node) {
                emit(node.type, parenthesizer.parenthesizeTypeOfOptionalType);
                writePunctuation("?");
            }
            function emitUnionType(node) {
                emitList(node, node.types, 516 /* UnionTypeConstituents */, parenthesizer.parenthesizeConstituentTypeOfUnionType);
            }
            function emitIntersectionType(node) {
                emitList(node, node.types, 520 /* IntersectionTypeConstituents */, parenthesizer.parenthesizeConstituentTypeOfIntersectionType);
            }
            function emitConditionalType(node) {
                emit(node.checkType, parenthesizer.parenthesizeCheckTypeOfConditionalType);
                writeSpace();
                writeKeyword("extends");
                writeSpace();
                emit(node.extendsType, parenthesizer.parenthesizeExtendsTypeOfConditionalType);
                writeSpace();
                writePunctuation("?");
                writeSpace();
                emit(node.trueType);
                writeSpace();
                writePunctuation(":");
                writeSpace();
                emit(node.falseType);
            }
            function emitInferType(node) {
                writeKeyword("infer");
                writeSpace();
                emit(node.typeParameter);
            }
            function emitParenthesizedType(node) {
                writePunctuation("(");
                emit(node.type);
                writePunctuation(")");
            }
            function emitThisType() {
                writeKeyword("this");
            }
            function emitTypeOperator(node) {
                writeTokenText(node.operator, writeKeyword);
                writeSpace();
                const parenthesizerRule = node.operator === 148 /* ReadonlyKeyword */ ? parenthesizer.parenthesizeOperandOfReadonlyTypeOperator : parenthesizer.parenthesizeOperandOfTypeOperator;
                emit(node.type, parenthesizerRule);
            }
            function emitIndexedAccessType(node) {
                emit(node.objectType, parenthesizer.parenthesizeNonArrayTypeOfPostfixType);
                writePunctuation("[");
                emit(node.indexType);
                writePunctuation("]");
            }
            function emitMappedType(node) {
                const emitFlags = getEmitFlags(node);
                writePunctuation("{");
                if (emitFlags & 1 /* SingleLine */) {
                    writeSpace();
                }
                else {
                    writeLine();
                    increaseIndent();
                }
                if (node.readonlyToken) {
                    emit(node.readonlyToken);
                    if (node.readonlyToken.kind !== 148 /* ReadonlyKeyword */) {
                        writeKeyword("readonly");
                    }
                    writeSpace();
                }
                writePunctuation("[");
                pipelineEmit(3 /* MappedTypeParameter */, node.typeParameter);
                if (node.nameType) {
                    writeSpace();
                    writeKeyword("as");
                    writeSpace();
                    emit(node.nameType);
                }
                writePunctuation("]");
                if (node.questionToken) {
                    emit(node.questionToken);
                    if (node.questionToken.kind !== 58 /* QuestionToken */) {
                        writePunctuation("?");
                    }
                }
                writePunctuation(":");
                writeSpace();
                emit(node.type);
                writeTrailingSemicolon();
                if (emitFlags & 1 /* SingleLine */) {
                    writeSpace();
                }
                else {
                    writeLine();
                    decreaseIndent();
                }
                emitList(node, node.members, 2 /* PreserveLines */);
                writePunctuation("}");
            }
            function emitLiteralType(node) {
                emitExpression(node.literal);
            }
            function emitTemplateType(node) {
                emit(node.head);
                emitList(node, node.templateSpans, 262144 /* TemplateExpressionSpans */);
            }
            function emitImportTypeNode(node) {
                if (node.isTypeOf) {
                    writeKeyword("typeof");
                    writeSpace();
                }
                writeKeyword("import");
                writePunctuation("(");
                emit(node.argument);
                if (node.attributes) {
                    writePunctuation(",");
                    writeSpace();
                    pipelineEmit(7 /* ImportTypeNodeAttributes */, node.attributes);
                }
                writePunctuation(")");
                if (node.qualifier) {
                    writePunctuation(".");
                    emit(node.qualifier);
                }
                emitTypeArguments(node, node.typeArguments);
            }
            function emitObjectBindingPattern(node) {
                writePunctuation("{");
                emitList(node, node.elements, 525136 /* ObjectBindingPatternElements */);
                writePunctuation("}");
            }
            function emitArrayBindingPattern(node) {
                writePunctuation("[");
                emitList(node, node.elements, 524880 /* ArrayBindingPatternElements */);
                writePunctuation("]");
            }
            function emitBindingElement(node) {
                emit(node.dotDotDotToken);
                if (node.propertyName) {
                    emit(node.propertyName);
                    writePunctuation(":");
                    writeSpace();
                }
                emit(node.name);
                emitInitializer(node.initializer, node.name.end, node, parenthesizer.parenthesizeExpressionForDisallowedComma);
            }
            function emitArrayLiteralExpression(node) {
                const elements = node.elements;
                const preferNewLine = node.multiLine ? 65536 /* PreferNewLine */ : 0 /* None */;
                emitExpressionList(node, elements, 8914 /* ArrayLiteralExpressionElements */ | preferNewLine, parenthesizer.parenthesizeExpressionForDisallowedComma);
            }
            function emitObjectLiteralExpression(node) {
                pushPrivateNameGenerationScope(0 /* Auto */, 
                /*newReservedMemberNames*/
                void 0);
                forEach(node.properties, generateMemberNames);
                const indentedFlag = getEmitFlags(node) & 131072 /* Indented */;
                if (indentedFlag) {
                    increaseIndent();
                }
                const preferNewLine = node.multiLine ? 65536 /* PreferNewLine */ : 0 /* None */;
                const allowTrailingComma = currentSourceFile && currentSourceFile.languageVersion >= 1 /* ES5 */ && !isJsonSourceFile(currentSourceFile) ? 64 /* AllowTrailingComma */ : 0 /* None */;
                emitList(node, node.properties, 526226 /* ObjectLiteralExpressionProperties */ | allowTrailingComma | preferNewLine);
                if (indentedFlag) {
                    decreaseIndent();
                }
                popPrivateNameGenerationScope();
            }
            function emitPropertyAccessExpression(node) {
                emitExpression(node.expression, parenthesizer.parenthesizeLeftSideOfAccess);
                const token = node.questionDotToken || setTextRangePosEnd(factory.createToken(25 /* DotToken */), node.expression.end, node.name.pos);
                const linesBeforeDot = getLinesBetweenNodes(node, node.expression, token);
                const linesAfterDot = getLinesBetweenNodes(node, token, node.name);
                writeLinesAndIndent(linesBeforeDot, 
                /*writeSpaceIfNotIndenting*/
                false);
                const shouldEmitDotDot = token.kind !== 29 /* QuestionDotToken */ && mayNeedDotDotForPropertyAccess(node.expression) && !writer.hasTrailingComment() && !writer.hasTrailingWhitespace();
                if (shouldEmitDotDot) {
                    writePunctuation(".");
                }
                if (node.questionDotToken) {
                    emit(token);
                }
                else {
                    emitTokenWithComment(token.kind, node.expression.end, writePunctuation, node);
                }
                writeLinesAndIndent(linesAfterDot, 
                /*writeSpaceIfNotIndenting*/
                false);
                emit(node.name);
                decreaseIndentIf(linesBeforeDot, linesAfterDot);
            }
            function mayNeedDotDotForPropertyAccess(expression) {
                expression = skipPartiallyEmittedExpressions(expression);
                if (isNumericLiteral(expression)) {
                    const text = getLiteralTextOfNode(expression, 
                    /*neverAsciiEscape*/
                    true, 
                    /*jsxAttributeEscape*/
                    false);
                    return !(expression.numericLiteralFlags & 448 /* WithSpecifier */) && !text.includes(tokenToString(25 /* DotToken */)) && !text.includes(String.fromCharCode(69 /* E */)) && !text.includes(String.fromCharCode(101 /* e */));
                }
                else if (isAccessExpression(expression)) {
                    const constantValue = getConstantValue(expression);
                    return typeof constantValue === "number" && isFinite(constantValue) && constantValue >= 0 && Math.floor(constantValue) === constantValue;
                }
            }
            function emitElementAccessExpression(node) {
                emitExpression(node.expression, parenthesizer.parenthesizeLeftSideOfAccess);
                emit(node.questionDotToken);
                emitTokenWithComment(23 /* OpenBracketToken */, node.expression.end, writePunctuation, node);
                emitExpression(node.argumentExpression);
                emitTokenWithComment(24 /* CloseBracketToken */, node.argumentExpression.end, writePunctuation, node);
            }
            function emitCallExpression(node) {
                const indirectCall = getInternalEmitFlags(node) & 16 /* IndirectCall */;
                if (indirectCall) {
                    writePunctuation("(");
                    writeLiteral("0");
                    writePunctuation(",");
                    writeSpace();
                }
                emitExpression(node.expression, parenthesizer.parenthesizeLeftSideOfAccess);
                if (indirectCall) {
                    writePunctuation(")");
                }
                emit(node.questionDotToken);
                emitTypeArguments(node, node.typeArguments);
                emitExpressionList(node, node.arguments, 2576 /* CallExpressionArguments */, parenthesizer.parenthesizeExpressionForDisallowedComma);
            }
            function emitNewExpression(node) {
                emitTokenWithComment(105 /* NewKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                emitExpression(node.expression, parenthesizer.parenthesizeExpressionOfNew);
                emitTypeArguments(node, node.typeArguments);
                emitExpressionList(node, node.arguments, 18960 /* NewExpressionArguments */, parenthesizer.parenthesizeExpressionForDisallowedComma);
            }
            function emitTaggedTemplateExpression(node) {
                const indirectCall = getInternalEmitFlags(node) & 16 /* IndirectCall */;
                if (indirectCall) {
                    writePunctuation("(");
                    writeLiteral("0");
                    writePunctuation(",");
                    writeSpace();
                }
                emitExpression(node.tag, parenthesizer.parenthesizeLeftSideOfAccess);
                if (indirectCall) {
                    writePunctuation(")");
                }
                emitTypeArguments(node, node.typeArguments);
                writeSpace();
                emitExpression(node.template);
            }
            function emitTypeAssertionExpression(node) {
                writePunctuation("<");
                emit(node.type);
                writePunctuation(">");
                emitExpression(node.expression, parenthesizer.parenthesizeOperandOfPrefixUnary);
            }
            function emitParenthesizedExpression(node) {
                const openParenPos = emitTokenWithComment(21 /* OpenParenToken */, node.pos, writePunctuation, node);
                const indented = writeLineSeparatorsAndIndentBefore(node.expression, node);
                emitExpression(node.expression, 
                /*parenthesizerRule*/
                void 0);
                writeLineSeparatorsAfter(node.expression, node);
                decreaseIndentIf(indented);
                emitTokenWithComment(22 /* CloseParenToken */, node.expression ? node.expression.end : openParenPos, writePunctuation, node);
            }
            function emitFunctionExpression(node) {
                generateNameIfNeeded(node.name);
                emitFunctionDeclarationOrExpression(node);
            }
            function emitArrowFunction(node) {
                emitModifierList(node, node.modifiers);
                emitSignatureAndBody(node, emitArrowFunctionHead);
            }
            function emitArrowFunctionHead(node) {
                emitTypeParameters(node, node.typeParameters);
                emitParametersForArrow(node, node.parameters);
                emitTypeAnnotation(node.type);
                writeSpace();
                emit(node.equalsGreaterThanToken);
            }
            function emitDeleteExpression(node) {
                emitTokenWithComment(91 /* DeleteKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                emitExpression(node.expression, parenthesizer.parenthesizeOperandOfPrefixUnary);
            }
            function emitTypeOfExpression(node) {
                emitTokenWithComment(114 /* TypeOfKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                emitExpression(node.expression, parenthesizer.parenthesizeOperandOfPrefixUnary);
            }
            function emitVoidExpression(node) {
                emitTokenWithComment(116 /* VoidKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                emitExpression(node.expression, parenthesizer.parenthesizeOperandOfPrefixUnary);
            }
            function emitAwaitExpression(node) {
                emitTokenWithComment(135 /* AwaitKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                emitExpression(node.expression, parenthesizer.parenthesizeOperandOfPrefixUnary);
            }
            function emitPrefixUnaryExpression(node) {
                writeTokenText(node.operator, writeOperator);
                if (shouldEmitWhitespaceBeforeOperand(node)) {
                    writeSpace();
                }
                emitExpression(node.operand, parenthesizer.parenthesizeOperandOfPrefixUnary);
            }
            function shouldEmitWhitespaceBeforeOperand(node) {
                const operand = node.operand;
                return operand.kind === 224 /* PrefixUnaryExpression */ && (node.operator === 40 /* PlusToken */ && (operand.operator === 40 /* PlusToken */ || operand.operator === 46 /* PlusPlusToken */) || node.operator === 41 /* MinusToken */ && (operand.operator === 41 /* MinusToken */ || operand.operator === 47 /* MinusMinusToken */));
            }
            function emitPostfixUnaryExpression(node) {
                emitExpression(node.operand, parenthesizer.parenthesizeOperandOfPostfixUnary);
                writeTokenText(node.operator, writeOperator);
            }
            function createEmitBinaryExpression() {
                return createBinaryExpressionTrampoline(onEnter, onLeft, onOperator, onRight, onExit, 
                /*foldState*/
                void 0);
                function onEnter(node, state) {
                    if (state) {
                        state.stackIndex++;
                        state.preserveSourceNewlinesStack[state.stackIndex] = preserveSourceNewlines;
                        state.containerPosStack[state.stackIndex] = containerPos;
                        state.containerEndStack[state.stackIndex] = containerEnd;
                        state.declarationListContainerEndStack[state.stackIndex] = declarationListContainerEnd;
                        const emitComments2 = state.shouldEmitCommentsStack[state.stackIndex] = shouldEmitComments(node);
                        const emitSourceMaps = state.shouldEmitSourceMapsStack[state.stackIndex] = shouldEmitSourceMaps(node);
                        onBeforeEmitNode == null ? void 0 : onBeforeEmitNode(node);
                        if (emitComments2)
                            emitCommentsBeforeNode(node);
                        if (emitSourceMaps)
                            emitSourceMapsBeforeNode(node);
                        beforeEmitNode(node);
                    }
                    else {
                        state = {
                            stackIndex: 0,
                            preserveSourceNewlinesStack: [void 0],
                            containerPosStack: [-1],
                            containerEndStack: [-1],
                            declarationListContainerEndStack: [-1],
                            shouldEmitCommentsStack: [false],
                            shouldEmitSourceMapsStack: [false]
                        };
                    }
                    return state;
                }
                function onLeft(next, _workArea, parent2) {
                    return maybeEmitExpression(next, parent2, "left");
                }
                function onOperator(operatorToken, _state, node) {
                    const isCommaOperator = operatorToken.kind !== 28 /* CommaToken */;
                    const linesBeforeOperator = getLinesBetweenNodes(node, node.left, operatorToken);
                    const linesAfterOperator = getLinesBetweenNodes(node, operatorToken, node.right);
                    writeLinesAndIndent(linesBeforeOperator, isCommaOperator);
                    emitLeadingCommentsOfPosition(operatorToken.pos);
                    writeTokenNode(operatorToken, operatorToken.kind === 103 /* InKeyword */ ? writeKeyword : writeOperator);
                    emitTrailingCommentsOfPosition(operatorToken.end, 
                    /*prefixSpace*/
                    true);
                    writeLinesAndIndent(linesAfterOperator, 
                    /*writeSpaceIfNotIndenting*/
                    true);
                }
                function onRight(next, _workArea, parent2) {
                    return maybeEmitExpression(next, parent2, "right");
                }
                function onExit(node, state) {
                    const linesBeforeOperator = getLinesBetweenNodes(node, node.left, node.operatorToken);
                    const linesAfterOperator = getLinesBetweenNodes(node, node.operatorToken, node.right);
                    decreaseIndentIf(linesBeforeOperator, linesAfterOperator);
                    if (state.stackIndex > 0) {
                        const savedPreserveSourceNewlines = state.preserveSourceNewlinesStack[state.stackIndex];
                        const savedContainerPos = state.containerPosStack[state.stackIndex];
                        const savedContainerEnd = state.containerEndStack[state.stackIndex];
                        const savedDeclarationListContainerEnd = state.declarationListContainerEndStack[state.stackIndex];
                        const shouldEmitComments2 = state.shouldEmitCommentsStack[state.stackIndex];
                        const shouldEmitSourceMaps2 = state.shouldEmitSourceMapsStack[state.stackIndex];
                        afterEmitNode(savedPreserveSourceNewlines);
                        if (shouldEmitSourceMaps2)
                            emitSourceMapsAfterNode(node);
                        if (shouldEmitComments2)
                            emitCommentsAfterNode(node, savedContainerPos, savedContainerEnd, savedDeclarationListContainerEnd);
                        onAfterEmitNode == null ? void 0 : onAfterEmitNode(node);
                        state.stackIndex--;
                    }
                }
                function maybeEmitExpression(next, parent2, side) {
                    const parenthesizerRule = side === "left" ? parenthesizer.getParenthesizeLeftSideOfBinaryForOperator(parent2.operatorToken.kind) : parenthesizer.getParenthesizeRightSideOfBinaryForOperator(parent2.operatorToken.kind);
                    let pipelinePhase = getPipelinePhase(0 /* Notification */, 1 /* Expression */, next);
                    if (pipelinePhase === pipelineEmitWithSubstitution) {
                        Debug.assertIsDefined(lastSubstitution);
                        next = parenthesizerRule(cast(lastSubstitution, isExpression));
                        pipelinePhase = getNextPipelinePhase(1 /* Substitution */, 1 /* Expression */, next);
                        lastSubstitution = void 0;
                    }
                    if (pipelinePhase === pipelineEmitWithComments || pipelinePhase === pipelineEmitWithSourceMaps || pipelinePhase === pipelineEmitWithHint) {
                        if (isBinaryExpression(next)) {
                            return next;
                        }
                    }
                    currentParenthesizerRule = parenthesizerRule;
                    pipelinePhase(1 /* Expression */, next);
                }
            }
            function emitConditionalExpression(node) {
                const linesBeforeQuestion = getLinesBetweenNodes(node, node.condition, node.questionToken);
                const linesAfterQuestion = getLinesBetweenNodes(node, node.questionToken, node.whenTrue);
                const linesBeforeColon = getLinesBetweenNodes(node, node.whenTrue, node.colonToken);
                const linesAfterColon = getLinesBetweenNodes(node, node.colonToken, node.whenFalse);
                emitExpression(node.condition, parenthesizer.parenthesizeConditionOfConditionalExpression);
                writeLinesAndIndent(linesBeforeQuestion, 
                /*writeSpaceIfNotIndenting*/
                true);
                emit(node.questionToken);
                writeLinesAndIndent(linesAfterQuestion, 
                /*writeSpaceIfNotIndenting*/
                true);
                emitExpression(node.whenTrue, parenthesizer.parenthesizeBranchOfConditionalExpression);
                decreaseIndentIf(linesBeforeQuestion, linesAfterQuestion);
                writeLinesAndIndent(linesBeforeColon, 
                /*writeSpaceIfNotIndenting*/
                true);
                emit(node.colonToken);
                writeLinesAndIndent(linesAfterColon, 
                /*writeSpaceIfNotIndenting*/
                true);
                emitExpression(node.whenFalse, parenthesizer.parenthesizeBranchOfConditionalExpression);
                decreaseIndentIf(linesBeforeColon, linesAfterColon);
            }
            function emitTemplateExpression(node) {
                emit(node.head);
                emitList(node, node.templateSpans, 262144 /* TemplateExpressionSpans */);
            }
            function emitYieldExpression(node) {
                emitTokenWithComment(127 /* YieldKeyword */, node.pos, writeKeyword, node);
                emit(node.asteriskToken);
                emitExpressionWithLeadingSpace(node.expression && parenthesizeExpressionForNoAsi(node.expression), parenthesizeExpressionForNoAsiAndDisallowedComma);
            }
            function emitSpreadElement(node) {
                emitTokenWithComment(26 /* DotDotDotToken */, node.pos, writePunctuation, node);
                emitExpression(node.expression, parenthesizer.parenthesizeExpressionForDisallowedComma);
            }
            function emitClassExpression(node) {
                generateNameIfNeeded(node.name);
                emitClassDeclarationOrExpression(node);
            }
            function emitExpressionWithTypeArguments(node) {
                emitExpression(node.expression, parenthesizer.parenthesizeLeftSideOfAccess);
                emitTypeArguments(node, node.typeArguments);
            }
            function emitAsExpression(node) {
                emitExpression(node.expression, 
                /*parenthesizerRule*/
                void 0);
                if (node.type) {
                    writeSpace();
                    writeKeyword("as");
                    writeSpace();
                    emit(node.type);
                }
            }
            function emitNonNullExpression(node) {
                emitExpression(node.expression, parenthesizer.parenthesizeLeftSideOfAccess);
                writeOperator("!");
            }
            function emitSatisfiesExpression(node) {
                emitExpression(node.expression, 
                /*parenthesizerRule*/
                void 0);
                if (node.type) {
                    writeSpace();
                    writeKeyword("satisfies");
                    writeSpace();
                    emit(node.type);
                }
            }
            function emitMetaProperty(node) {
                writeToken(node.keywordToken, node.pos, writePunctuation);
                writePunctuation(".");
                emit(node.name);
            }
            function emitTemplateSpan(node) {
                emitExpression(node.expression);
                emit(node.literal);
            }
            function emitBlock(node) {
                emitBlockStatements(node, 
                /*forceSingleLine*/
                !node.multiLine && isEmptyBlock(node));
            }
            function emitBlockStatements(node, forceSingleLine) {
                emitTokenWithComment(19 /* OpenBraceToken */, node.pos, writePunctuation, 
                /*contextNode*/
                node);
                const format = forceSingleLine || getEmitFlags(node) & 1 /* SingleLine */ ? 768 /* SingleLineBlockStatements */ : 129 /* MultiLineBlockStatements */;
                emitList(node, node.statements, format);
                emitTokenWithComment(20 /* CloseBraceToken */, node.statements.end, writePunctuation, 
                /*contextNode*/
                node, 
                /*indentLeading*/
                !!(format & 1 /* MultiLine */));
            }
            function emitVariableStatement(node) {
                emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                false);
                emit(node.declarationList);
                writeTrailingSemicolon();
            }
            function emitEmptyStatement(isEmbeddedStatement) {
                if (isEmbeddedStatement) {
                    writePunctuation(";");
                }
                else {
                    writeTrailingSemicolon();
                }
            }
            function emitExpressionStatement(node) {
                emitExpression(node.expression, parenthesizer.parenthesizeExpressionOfExpressionStatement);
                if (!currentSourceFile || !isJsonSourceFile(currentSourceFile) || nodeIsSynthesized(node.expression)) {
                    writeTrailingSemicolon();
                }
            }
            function emitIfStatement(node) {
                const openParenPos = emitTokenWithComment(101 /* IfKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                emitTokenWithComment(21 /* OpenParenToken */, openParenPos, writePunctuation, node);
                emitExpression(node.expression);
                emitTokenWithComment(22 /* CloseParenToken */, node.expression.end, writePunctuation, node);
                emitEmbeddedStatement(node, node.thenStatement);
                if (node.elseStatement) {
                    writeLineOrSpace(node, node.thenStatement, node.elseStatement);
                    emitTokenWithComment(93 /* ElseKeyword */, node.thenStatement.end, writeKeyword, node);
                    if (node.elseStatement.kind === 245 /* IfStatement */) {
                        writeSpace();
                        emit(node.elseStatement);
                    }
                    else {
                        emitEmbeddedStatement(node, node.elseStatement);
                    }
                }
            }
            function emitWhileClause(node, startPos) {
                const openParenPos = emitTokenWithComment(117 /* WhileKeyword */, startPos, writeKeyword, node);
                writeSpace();
                emitTokenWithComment(21 /* OpenParenToken */, openParenPos, writePunctuation, node);
                emitExpression(node.expression);
                emitTokenWithComment(22 /* CloseParenToken */, node.expression.end, writePunctuation, node);
            }
            function emitDoStatement(node) {
                emitTokenWithComment(92 /* DoKeyword */, node.pos, writeKeyword, node);
                emitEmbeddedStatement(node, node.statement);
                if (isBlock(node.statement) && !preserveSourceNewlines) {
                    writeSpace();
                }
                else {
                    writeLineOrSpace(node, node.statement, node.expression);
                }
                emitWhileClause(node, node.statement.end);
                writeTrailingSemicolon();
            }
            function emitWhileStatement(node) {
                emitWhileClause(node, node.pos);
                emitEmbeddedStatement(node, node.statement);
            }
            function emitForStatement(node) {
                const openParenPos = emitTokenWithComment(99 /* ForKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                let pos = emitTokenWithComment(21 /* OpenParenToken */, openParenPos, writePunctuation, 
                /*contextNode*/
                node);
                emitForBinding(node.initializer);
                pos = emitTokenWithComment(27 /* SemicolonToken */, node.initializer ? node.initializer.end : pos, writePunctuation, node);
                emitExpressionWithLeadingSpace(node.condition);
                pos = emitTokenWithComment(27 /* SemicolonToken */, node.condition ? node.condition.end : pos, writePunctuation, node);
                emitExpressionWithLeadingSpace(node.incrementor);
                emitTokenWithComment(22 /* CloseParenToken */, node.incrementor ? node.incrementor.end : pos, writePunctuation, node);
                emitEmbeddedStatement(node, node.statement);
            }
            function emitForInStatement(node) {
                const openParenPos = emitTokenWithComment(99 /* ForKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                emitTokenWithComment(21 /* OpenParenToken */, openParenPos, writePunctuation, node);
                emitForBinding(node.initializer);
                writeSpace();
                emitTokenWithComment(103 /* InKeyword */, node.initializer.end, writeKeyword, node);
                writeSpace();
                emitExpression(node.expression);
                emitTokenWithComment(22 /* CloseParenToken */, node.expression.end, writePunctuation, node);
                emitEmbeddedStatement(node, node.statement);
            }
            function emitForOfStatement(node) {
                const openParenPos = emitTokenWithComment(99 /* ForKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                emitWithTrailingSpace(node.awaitModifier);
                emitTokenWithComment(21 /* OpenParenToken */, openParenPos, writePunctuation, node);
                emitForBinding(node.initializer);
                writeSpace();
                emitTokenWithComment(165 /* OfKeyword */, node.initializer.end, writeKeyword, node);
                writeSpace();
                emitExpression(node.expression);
                emitTokenWithComment(22 /* CloseParenToken */, node.expression.end, writePunctuation, node);
                emitEmbeddedStatement(node, node.statement);
            }
            function emitForBinding(node) {
                if (node !== void 0) {
                    if (node.kind === 261 /* VariableDeclarationList */) {
                        emit(node);
                    }
                    else {
                        emitExpression(node);
                    }
                }
            }
            function emitContinueStatement(node) {
                emitTokenWithComment(88 /* ContinueKeyword */, node.pos, writeKeyword, node);
                emitWithLeadingSpace(node.label);
                writeTrailingSemicolon();
            }
            function emitBreakStatement(node) {
                emitTokenWithComment(83 /* BreakKeyword */, node.pos, writeKeyword, node);
                emitWithLeadingSpace(node.label);
                writeTrailingSemicolon();
            }
            function emitTokenWithComment(token, pos, writer2, contextNode, indentLeading) {
                const node = getParseTreeNode(contextNode);
                const isSimilarNode = node && node.kind === contextNode.kind;
                const startPos = pos;
                if (isSimilarNode && currentSourceFile) {
                    pos = skipTrivia(currentSourceFile.text, pos);
                }
                if (isSimilarNode && contextNode.pos !== startPos) {
                    const needsIndent = indentLeading && currentSourceFile && !positionsAreOnSameLine(startPos, pos, currentSourceFile);
                    if (needsIndent) {
                        increaseIndent();
                    }
                    emitLeadingCommentsOfPosition(startPos);
                    if (needsIndent) {
                        decreaseIndent();
                    }
                }
                if (!omitBraceSourcePositions && (token === 19 /* OpenBraceToken */ || token === 20 /* CloseBraceToken */)) {
                    pos = writeToken(token, pos, writer2, contextNode);
                }
                else {
                    pos = writeTokenText(token, writer2, pos);
                }
                if (isSimilarNode && contextNode.end !== pos) {
                    const isJsxExprContext = contextNode.kind === 294 /* JsxExpression */;
                    emitTrailingCommentsOfPosition(pos, 
                    /*prefixSpace*/
                    !isJsxExprContext, 
                    /*forceNoNewline*/
                    isJsxExprContext);
                }
                return pos;
            }
            function commentWillEmitNewLine(node) {
                return node.kind === 2 /* SingleLineCommentTrivia */ || !!node.hasTrailingNewLine;
            }
            function willEmitLeadingNewLine(node) {
                if (!currentSourceFile)
                    return false;
                const leadingCommentRanges = getLeadingCommentRanges(currentSourceFile.text, node.pos);
                if (leadingCommentRanges) {
                    const parseNode = getParseTreeNode(node);
                    if (parseNode && isParenthesizedExpression(parseNode.parent)) {
                        return true;
                    }
                }
                if (some(leadingCommentRanges, commentWillEmitNewLine))
                    return true;
                if (some(getSyntheticLeadingComments(node), commentWillEmitNewLine))
                    return true;
                if (isPartiallyEmittedExpression(node)) {
                    if (node.pos !== node.expression.pos) {
                        if (some(getTrailingCommentRanges(currentSourceFile.text, node.expression.pos), commentWillEmitNewLine))
                            return true;
                    }
                    return willEmitLeadingNewLine(node.expression);
                }
                return false;
            }
            function parenthesizeExpressionForNoAsi(node) {
                if (!commentsDisabled && isPartiallyEmittedExpression(node) && willEmitLeadingNewLine(node)) {
                    const parseNode = getParseTreeNode(node);
                    if (parseNode && isParenthesizedExpression(parseNode)) {
                        const parens = factory.createParenthesizedExpression(node.expression);
                        setOriginalNode(parens, node);
                        setTextRange(parens, parseNode);
                        return parens;
                    }
                    return factory.createParenthesizedExpression(node);
                }
                return node;
            }
            function parenthesizeExpressionForNoAsiAndDisallowedComma(node) {
                return parenthesizeExpressionForNoAsi(parenthesizer.parenthesizeExpressionForDisallowedComma(node));
            }
            function emitReturnStatement(node) {
                emitTokenWithComment(107 /* ReturnKeyword */, node.pos, writeKeyword, 
                /*contextNode*/
                node);
                emitExpressionWithLeadingSpace(node.expression && parenthesizeExpressionForNoAsi(node.expression), parenthesizeExpressionForNoAsi);
                writeTrailingSemicolon();
            }
            function emitWithStatement(node) {
                const openParenPos = emitTokenWithComment(118 /* WithKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                emitTokenWithComment(21 /* OpenParenToken */, openParenPos, writePunctuation, node);
                emitExpression(node.expression);
                emitTokenWithComment(22 /* CloseParenToken */, node.expression.end, writePunctuation, node);
                emitEmbeddedStatement(node, node.statement);
            }
            function emitSwitchStatement(node) {
                const openParenPos = emitTokenWithComment(109 /* SwitchKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                emitTokenWithComment(21 /* OpenParenToken */, openParenPos, writePunctuation, node);
                emitExpression(node.expression);
                emitTokenWithComment(22 /* CloseParenToken */, node.expression.end, writePunctuation, node);
                writeSpace();
                emit(node.caseBlock);
            }
            function emitLabeledStatement(node) {
                emit(node.label);
                emitTokenWithComment(59 /* ColonToken */, node.label.end, writePunctuation, node);
                writeSpace();
                emit(node.statement);
            }
            function emitThrowStatement(node) {
                emitTokenWithComment(111 /* ThrowKeyword */, node.pos, writeKeyword, node);
                emitExpressionWithLeadingSpace(parenthesizeExpressionForNoAsi(node.expression), parenthesizeExpressionForNoAsi);
                writeTrailingSemicolon();
            }
            function emitTryStatement(node) {
                emitTokenWithComment(113 /* TryKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                emit(node.tryBlock);
                if (node.catchClause) {
                    writeLineOrSpace(node, node.tryBlock, node.catchClause);
                    emit(node.catchClause);
                }
                if (node.finallyBlock) {
                    writeLineOrSpace(node, node.catchClause || node.tryBlock, node.finallyBlock);
                    emitTokenWithComment(98 /* FinallyKeyword */, (node.catchClause || node.tryBlock).end, writeKeyword, node);
                    writeSpace();
                    emit(node.finallyBlock);
                }
            }
            function emitDebuggerStatement(node) {
                writeToken(89 /* DebuggerKeyword */, node.pos, writeKeyword);
                writeTrailingSemicolon();
            }
            function emitVariableDeclaration(node) {
                var _a, _b, _c;
                emit(node.name);
                emit(node.exclamationToken);
                emitTypeAnnotation(node.type);
                emitInitializer(node.initializer, ((_a = node.type) == null ? void 0 : _a.end) ?? ((_c = (_b = node.name.emitNode) == null ? void 0 : _b.typeNode) == null ? void 0 : _c.end) ?? node.name.end, node, parenthesizer.parenthesizeExpressionForDisallowedComma);
            }
            function emitVariableDeclarationList(node) {
                if (isVarAwaitUsing(node)) {
                    writeKeyword("await");
                    writeSpace();
                    writeKeyword("using");
                }
                else {
                    const head = isLet(node) ? "let" : isVarConst(node) ? "const" : isVarUsing(node) ? "using" : "var";
                    writeKeyword(head);
                }
                writeSpace();
                emitList(node, node.declarations, 528 /* VariableDeclarationList */);
            }
            function emitFunctionDeclaration(node) {
                emitFunctionDeclarationOrExpression(node);
            }
            function emitFunctionDeclarationOrExpression(node) {
                emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                false);
                writeKeyword("function");
                emit(node.asteriskToken);
                writeSpace();
                emitIdentifierName(node.name);
                emitSignatureAndBody(node, emitSignatureHead);
            }
            function emitSignatureAndBody(node, emitSignatureHead2) {
                const body = node.body;
                if (body) {
                    if (isBlock(body)) {
                        const indentedFlag = getEmitFlags(node) & 131072 /* Indented */;
                        if (indentedFlag) {
                            increaseIndent();
                        }
                        pushNameGenerationScope(node);
                        forEach(node.parameters, generateNames);
                        generateNames(node.body);
                        emitSignatureHead2(node);
                        emitBlockFunctionBody(body);
                        popNameGenerationScope(node);
                        if (indentedFlag) {
                            decreaseIndent();
                        }
                    }
                    else {
                        emitSignatureHead2(node);
                        writeSpace();
                        emitExpression(body, parenthesizer.parenthesizeConciseBodyOfArrowFunction);
                    }
                }
                else {
                    emitSignatureHead2(node);
                    writeTrailingSemicolon();
                }
            }
            function emitSignatureHead(node) {
                emitTypeParameters(node, node.typeParameters);
                emitParameters(node, node.parameters);
                emitTypeAnnotation(node.type);
            }
            function shouldEmitBlockFunctionBodyOnSingleLine(body) {
                if (getEmitFlags(body) & 1 /* SingleLine */) {
                    return true;
                }
                if (body.multiLine) {
                    return false;
                }
                if (!nodeIsSynthesized(body) && currentSourceFile && !rangeIsOnSingleLine(body, currentSourceFile)) {
                    return false;
                }
                if (getLeadingLineTerminatorCount(body, firstOrUndefined(body.statements), 2 /* PreserveLines */) || getClosingLineTerminatorCount(body, lastOrUndefined(body.statements), 2 /* PreserveLines */, body.statements)) {
                    return false;
                }
                let previousStatement;
                for (const statement of body.statements) {
                    if (getSeparatingLineTerminatorCount(previousStatement, statement, 2 /* PreserveLines */) > 0) {
                        return false;
                    }
                    previousStatement = statement;
                }
                return true;
            }
            function emitBlockFunctionBody(body) {
                onBeforeEmitNode == null ? void 0 : onBeforeEmitNode(body);
                writeSpace();
                writePunctuation("{");
                increaseIndent();
                const emitBlockFunctionBody2 = shouldEmitBlockFunctionBodyOnSingleLine(body) ? emitBlockFunctionBodyOnSingleLine : emitBlockFunctionBodyWorker;
                emitBodyWithDetachedComments(body, body.statements, emitBlockFunctionBody2);
                decreaseIndent();
                writeToken(20 /* CloseBraceToken */, body.statements.end, writePunctuation, body);
                onAfterEmitNode == null ? void 0 : onAfterEmitNode(body);
            }
            function emitBlockFunctionBodyOnSingleLine(body) {
                emitBlockFunctionBodyWorker(body, 
                /*emitBlockFunctionBodyOnSingleLine*/
                true);
            }
            function emitBlockFunctionBodyWorker(body, emitBlockFunctionBodyOnSingleLine2) {
                const statementOffset = emitPrologueDirectives(body.statements);
                const pos = writer.getTextPos();
                emitHelpers(body);
                if (statementOffset === 0 && pos === writer.getTextPos() && emitBlockFunctionBodyOnSingleLine2) {
                    decreaseIndent();
                    emitList(body, body.statements, 768 /* SingleLineFunctionBodyStatements */);
                    increaseIndent();
                }
                else {
                    emitList(body, body.statements, 1 /* MultiLineFunctionBodyStatements */, 
                    /*parenthesizerRule*/
                    void 0, statementOffset);
                }
            }
            function emitClassDeclaration(node) {
                emitClassDeclarationOrExpression(node);
            }
            function emitClassDeclarationOrExpression(node) {
                pushPrivateNameGenerationScope(0 /* Auto */, 
                /*newReservedMemberNames*/
                void 0);
                forEach(node.members, generateMemberNames);
                emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                true);
                emitTokenWithComment(86 /* ClassKeyword */, moveRangePastModifiers(node).pos, writeKeyword, node);
                if (node.name) {
                    writeSpace();
                    emitIdentifierName(node.name);
                }
                const indentedFlag = getEmitFlags(node) & 131072 /* Indented */;
                if (indentedFlag) {
                    increaseIndent();
                }
                emitTypeParameters(node, node.typeParameters);
                emitList(node, node.heritageClauses, 0 /* ClassHeritageClauses */);
                writeSpace();
                writePunctuation("{");
                emitList(node, node.members, 129 /* ClassMembers */);
                writePunctuation("}");
                if (indentedFlag) {
                    decreaseIndent();
                }
                popPrivateNameGenerationScope();
            }
            function emitInterfaceDeclaration(node) {
                pushPrivateNameGenerationScope(0 /* Auto */, 
                /*newReservedMemberNames*/
                void 0);
                emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                false);
                writeKeyword("interface");
                writeSpace();
                emit(node.name);
                emitTypeParameters(node, node.typeParameters);
                emitList(node, node.heritageClauses, 512 /* HeritageClauses */);
                writeSpace();
                writePunctuation("{");
                emitList(node, node.members, 129 /* InterfaceMembers */);
                writePunctuation("}");
                popPrivateNameGenerationScope();
            }
            function emitTypeAliasDeclaration(node) {
                emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                false);
                writeKeyword("type");
                writeSpace();
                emit(node.name);
                emitTypeParameters(node, node.typeParameters);
                writeSpace();
                writePunctuation("=");
                writeSpace();
                emit(node.type);
                writeTrailingSemicolon();
            }
            function emitEnumDeclaration(node) {
                emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                false);
                writeKeyword("enum");
                writeSpace();
                emit(node.name);
                writeSpace();
                writePunctuation("{");
                emitList(node, node.members, 145 /* EnumMembers */);
                writePunctuation("}");
            }
            function emitModuleDeclaration(node) {
                emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                false);
                if (~node.flags & 2048 /* GlobalAugmentation */) {
                    writeKeyword(node.flags & 32 /* Namespace */ ? "namespace" : "module");
                    writeSpace();
                }
                emit(node.name);
                let body = node.body;
                if (!body)
                    return writeTrailingSemicolon();
                while (body && isModuleDeclaration(body)) {
                    writePunctuation(".");
                    emit(body.name);
                    body = body.body;
                }
                writeSpace();
                emit(body);
            }
            function emitModuleBlock(node) {
                pushNameGenerationScope(node);
                forEach(node.statements, generateNames);
                emitBlockStatements(node, 
                /*forceSingleLine*/
                isEmptyBlock(node));
                popNameGenerationScope(node);
            }
            function emitCaseBlock(node) {
                emitTokenWithComment(19 /* OpenBraceToken */, node.pos, writePunctuation, node);
                emitList(node, node.clauses, 129 /* CaseBlockClauses */);
                emitTokenWithComment(20 /* CloseBraceToken */, node.clauses.end, writePunctuation, node, 
                /*indentLeading*/
                true);
            }
            function emitImportEqualsDeclaration(node) {
                emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                false);
                emitTokenWithComment(102 /* ImportKeyword */, node.modifiers ? node.modifiers.end : node.pos, writeKeyword, node);
                writeSpace();
                if (node.isTypeOnly) {
                    emitTokenWithComment(156 /* TypeKeyword */, node.pos, writeKeyword, node);
                    writeSpace();
                }
                emit(node.name);
                writeSpace();
                emitTokenWithComment(64 /* EqualsToken */, node.name.end, writePunctuation, node);
                writeSpace();
                emitModuleReference(node.moduleReference);
                writeTrailingSemicolon();
            }
            function emitModuleReference(node) {
                if (node.kind === 80 /* Identifier */) {
                    emitExpression(node);
                }
                else {
                    emit(node);
                }
            }
            function emitImportDeclaration(node) {
                emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                false);
                emitTokenWithComment(102 /* ImportKeyword */, node.modifiers ? node.modifiers.end : node.pos, writeKeyword, node);
                writeSpace();
                if (node.importClause) {
                    emit(node.importClause);
                    writeSpace();
                    emitTokenWithComment(161 /* FromKeyword */, node.importClause.end, writeKeyword, node);
                    writeSpace();
                }
                emitExpression(node.moduleSpecifier);
                if (node.attributes) {
                    emitWithLeadingSpace(node.attributes);
                }
                writeTrailingSemicolon();
            }
            function emitImportClause(node) {
                if (node.isTypeOnly) {
                    emitTokenWithComment(156 /* TypeKeyword */, node.pos, writeKeyword, node);
                    writeSpace();
                }
                emit(node.name);
                if (node.name && node.namedBindings) {
                    emitTokenWithComment(28 /* CommaToken */, node.name.end, writePunctuation, node);
                    writeSpace();
                }
                emit(node.namedBindings);
            }
            function emitNamespaceImport(node) {
                const asPos = emitTokenWithComment(42 /* AsteriskToken */, node.pos, writePunctuation, node);
                writeSpace();
                emitTokenWithComment(130 /* AsKeyword */, asPos, writeKeyword, node);
                writeSpace();
                emit(node.name);
            }
            function emitNamedImports(node) {
                emitNamedImportsOrExports(node);
            }
            function emitImportSpecifier(node) {
                emitImportOrExportSpecifier(node);
            }
            function emitExportAssignment(node) {
                const nextPos = emitTokenWithComment(95 /* ExportKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                if (node.isExportEquals) {
                    emitTokenWithComment(64 /* EqualsToken */, nextPos, writeOperator, node);
                }
                else {
                    emitTokenWithComment(90 /* DefaultKeyword */, nextPos, writeKeyword, node);
                }
                writeSpace();
                emitExpression(node.expression, node.isExportEquals ? parenthesizer.getParenthesizeRightSideOfBinaryForOperator(64 /* EqualsToken */) : parenthesizer.parenthesizeExpressionOfExportDefault);
                writeTrailingSemicolon();
            }
            function emitExportDeclaration(node) {
                emitDecoratorsAndModifiers(node, node.modifiers, 
                /*allowDecorators*/
                false);
                let nextPos = emitTokenWithComment(95 /* ExportKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                if (node.isTypeOnly) {
                    nextPos = emitTokenWithComment(156 /* TypeKeyword */, nextPos, writeKeyword, node);
                    writeSpace();
                }
                if (node.exportClause) {
                    emit(node.exportClause);
                }
                else {
                    nextPos = emitTokenWithComment(42 /* AsteriskToken */, nextPos, writePunctuation, node);
                }
                if (node.moduleSpecifier) {
                    writeSpace();
                    const fromPos = node.exportClause ? node.exportClause.end : nextPos;
                    emitTokenWithComment(161 /* FromKeyword */, fromPos, writeKeyword, node);
                    writeSpace();
                    emitExpression(node.moduleSpecifier);
                }
                if (node.attributes) {
                    emitWithLeadingSpace(node.attributes);
                }
                writeTrailingSemicolon();
            }
            function emitImportTypeNodeAttributes(node) {
                writePunctuation("{");
                writeSpace();
                writeKeyword(node.token === 132 /* AssertKeyword */ ? "assert" : "with");
                writePunctuation(":");
                writeSpace();
                const elements = node.elements;
                emitList(node, elements, 526226 /* ImportAttributes */);
                writeSpace();
                writePunctuation("}");
            }
            function emitImportAttributes(node) {
                emitTokenWithComment(node.token, node.pos, writeKeyword, node);
                writeSpace();
                const elements = node.elements;
                emitList(node, elements, 526226 /* ImportAttributes */);
            }
            function emitImportAttribute(node) {
                emit(node.name);
                writePunctuation(":");
                writeSpace();
                const value = node.value;
                if ((getEmitFlags(value) & 1024 /* NoLeadingComments */) === 0) {
                    const commentRange = getCommentRange(value);
                    emitTrailingCommentsOfPosition(commentRange.pos);
                }
                emit(value);
            }
            function emitNamespaceExportDeclaration(node) {
                let nextPos = emitTokenWithComment(95 /* ExportKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                nextPos = emitTokenWithComment(130 /* AsKeyword */, nextPos, writeKeyword, node);
                writeSpace();
                nextPos = emitTokenWithComment(145 /* NamespaceKeyword */, nextPos, writeKeyword, node);
                writeSpace();
                emit(node.name);
                writeTrailingSemicolon();
            }
            function emitNamespaceExport(node) {
                const asPos = emitTokenWithComment(42 /* AsteriskToken */, node.pos, writePunctuation, node);
                writeSpace();
                emitTokenWithComment(130 /* AsKeyword */, asPos, writeKeyword, node);
                writeSpace();
                emit(node.name);
            }
            function emitNamedExports(node) {
                emitNamedImportsOrExports(node);
            }
            function emitExportSpecifier(node) {
                emitImportOrExportSpecifier(node);
            }
            function emitNamedImportsOrExports(node) {
                writePunctuation("{");
                emitList(node, node.elements, 525136 /* NamedImportsOrExportsElements */);
                writePunctuation("}");
            }
            function emitImportOrExportSpecifier(node) {
                if (node.isTypeOnly) {
                    writeKeyword("type");
                    writeSpace();
                }
                if (node.propertyName) {
                    emit(node.propertyName);
                    writeSpace();
                    emitTokenWithComment(130 /* AsKeyword */, node.propertyName.end, writeKeyword, node);
                    writeSpace();
                }
                emit(node.name);
            }
            function emitExternalModuleReference(node) {
                writeKeyword("require");
                writePunctuation("(");
                emitExpression(node.expression);
                writePunctuation(")");
            }
            function emitJsxElement(node) {
                emit(node.openingElement);
                emitList(node, node.children, 262144 /* JsxElementOrFragmentChildren */);
                emit(node.closingElement);
            }
            function emitJsxSelfClosingElement(node) {
                writePunctuation("<");
                emitJsxTagName(node.tagName);
                emitTypeArguments(node, node.typeArguments);
                writeSpace();
                emit(node.attributes);
                writePunctuation("/>");
            }
            function emitJsxFragment(node) {
                emit(node.openingFragment);
                emitList(node, node.children, 262144 /* JsxElementOrFragmentChildren */);
                emit(node.closingFragment);
            }
            function emitJsxOpeningElementOrFragment(node) {
                writePunctuation("<");
                if (isJsxOpeningElement(node)) {
                    const indented = writeLineSeparatorsAndIndentBefore(node.tagName, node);
                    emitJsxTagName(node.tagName);
                    emitTypeArguments(node, node.typeArguments);
                    if (node.attributes.properties && node.attributes.properties.length > 0) {
                        writeSpace();
                    }
                    emit(node.attributes);
                    writeLineSeparatorsAfter(node.attributes, node);
                    decreaseIndentIf(indented);
                }
                writePunctuation(">");
            }
            function emitJsxText(node) {
                writer.writeLiteral(node.text);
            }
            function emitJsxClosingElementOrFragment(node) {
                writePunctuation("</");
                if (isJsxClosingElement(node)) {
                    emitJsxTagName(node.tagName);
                }
                writePunctuation(">");
            }
            function emitJsxAttributes(node) {
                emitList(node, node.properties, 262656 /* JsxElementAttributes */);
            }
            function emitJsxAttribute(node) {
                emit(node.name);
                emitNodeWithPrefix("=", writePunctuation, node.initializer, emitJsxAttributeValue);
            }
            function emitJsxSpreadAttribute(node) {
                writePunctuation("{...");
                emitExpression(node.expression);
                writePunctuation("}");
            }
            function hasTrailingCommentsAtPosition(pos) {
                let result = false;
                forEachTrailingCommentRange((currentSourceFile == null ? void 0 : currentSourceFile.text) || "", pos + 1, () => result = true);
                return result;
            }
            function hasLeadingCommentsAtPosition(pos) {
                let result = false;
                forEachLeadingCommentRange((currentSourceFile == null ? void 0 : currentSourceFile.text) || "", pos + 1, () => result = true);
                return result;
            }
            function hasCommentsAtPosition(pos) {
                return hasTrailingCommentsAtPosition(pos) || hasLeadingCommentsAtPosition(pos);
            }
            function emitJsxExpression(node) {
                var _a;
                if (node.expression || !commentsDisabled && !nodeIsSynthesized(node) && hasCommentsAtPosition(node.pos)) {
                    const isMultiline = currentSourceFile && !nodeIsSynthesized(node) && getLineAndCharacterOfPosition(currentSourceFile, node.pos).line !== getLineAndCharacterOfPosition(currentSourceFile, node.end).line;
                    if (isMultiline) {
                        writer.increaseIndent();
                    }
                    const end = emitTokenWithComment(19 /* OpenBraceToken */, node.pos, writePunctuation, node);
                    emit(node.dotDotDotToken);
                    emitExpression(node.expression);
                    emitTokenWithComment(20 /* CloseBraceToken */, ((_a = node.expression) == null ? void 0 : _a.end) || end, writePunctuation, node);
                    if (isMultiline) {
                        writer.decreaseIndent();
                    }
                }
            }
            function emitJsxNamespacedName(node) {
                emitIdentifierName(node.namespace);
                writePunctuation(":");
                emitIdentifierName(node.name);
            }
            function emitJsxTagName(node) {
                if (node.kind === 80 /* Identifier */) {
                    emitExpression(node);
                }
                else {
                    emit(node);
                }
            }
            function emitCaseClause(node) {
                emitTokenWithComment(84 /* CaseKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                emitExpression(node.expression, parenthesizer.parenthesizeExpressionForDisallowedComma);
                emitCaseOrDefaultClauseRest(node, node.statements, node.expression.end);
            }
            function emitDefaultClause(node) {
                const pos = emitTokenWithComment(90 /* DefaultKeyword */, node.pos, writeKeyword, node);
                emitCaseOrDefaultClauseRest(node, node.statements, pos);
            }
            function emitCaseOrDefaultClauseRest(parentNode, statements, colonPos) {
                const emitAsSingleStatement = statements.length === 1 && // treat synthesized nodes as located on the same line for emit purposes
                    (!currentSourceFile || nodeIsSynthesized(parentNode) || nodeIsSynthesized(statements[0]) || rangeStartPositionsAreOnSameLine(parentNode, statements[0], currentSourceFile));
                let format = 163969 /* CaseOrDefaultClauseStatements */;
                if (emitAsSingleStatement) {
                    writeToken(59 /* ColonToken */, colonPos, writePunctuation, parentNode);
                    writeSpace();
                    format &= ~(1 /* MultiLine */ | 128 /* Indented */);
                }
                else {
                    emitTokenWithComment(59 /* ColonToken */, colonPos, writePunctuation, parentNode);
                }
                emitList(parentNode, statements, format);
            }
            function emitHeritageClause(node) {
                writeSpace();
                writeTokenText(node.token, writeKeyword);
                writeSpace();
                emitList(node, node.types, 528 /* HeritageClauseTypes */);
            }
            function emitCatchClause(node) {
                const openParenPos = emitTokenWithComment(85 /* CatchKeyword */, node.pos, writeKeyword, node);
                writeSpace();
                if (node.variableDeclaration) {
                    emitTokenWithComment(21 /* OpenParenToken */, openParenPos, writePunctuation, node);
                    emit(node.variableDeclaration);
                    emitTokenWithComment(22 /* CloseParenToken */, node.variableDeclaration.end, writePunctuation, node);
                    writeSpace();
                }
                emit(node.block);
            }
            function emitPropertyAssignment(node) {
                emit(node.name);
                writePunctuation(":");
                writeSpace();
                const initializer = node.initializer;
                if ((getEmitFlags(initializer) & 1024 /* NoLeadingComments */) === 0) {
                    const commentRange = getCommentRange(initializer);
                    emitTrailingCommentsOfPosition(commentRange.pos);
                }
                emitExpression(initializer, parenthesizer.parenthesizeExpressionForDisallowedComma);
            }
            function emitShorthandPropertyAssignment(node) {
                emit(node.name);
                if (node.objectAssignmentInitializer) {
                    writeSpace();
                    writePunctuation("=");
                    writeSpace();
                    emitExpression(node.objectAssignmentInitializer, parenthesizer.parenthesizeExpressionForDisallowedComma);
                }
            }
            function emitSpreadAssignment(node) {
                if (node.expression) {
                    emitTokenWithComment(26 /* DotDotDotToken */, node.pos, writePunctuation, node);
                    emitExpression(node.expression, parenthesizer.parenthesizeExpressionForDisallowedComma);
                }
            }
            function emitEnumMember(node) {
                emit(node.name);
                emitInitializer(node.initializer, node.name.end, node, parenthesizer.parenthesizeExpressionForDisallowedComma);
            }
            function emitJSDoc(node) {
                write("/**");
                if (node.comment) {
                    const text = getTextOfJSDocComment(node.comment);
                    if (text) {
                        const lines = text.split(/\r\n?|\n/g);
                        for (const line of lines) {
                            writeLine();
                            writeSpace();
                            writePunctuation("*");
                            writeSpace();
                            write(line);
                        }
                    }
                }
                if (node.tags) {
                    if (node.tags.length === 1 && node.tags[0].kind === 351 /* JSDocTypeTag */ && !node.comment) {
                        writeSpace();
                        emit(node.tags[0]);
                    }
                    else {
                        emitList(node, node.tags, 33 /* JSDocComment */);
                    }
                }
                writeSpace();
                write("*/");
            }
            function emitJSDocSimpleTypedTag(tag) {
                emitJSDocTagName(tag.tagName);
                emitJSDocTypeExpression(tag.typeExpression);
                emitJSDocComment(tag.comment);
            }
            function emitJSDocSeeTag(tag) {
                emitJSDocTagName(tag.tagName);
                emit(tag.name);
                emitJSDocComment(tag.comment);
            }
            function emitJSDocNameReference(node) {
                writeSpace();
                writePunctuation("{");
                emit(node.name);
                writePunctuation("}");
            }
            function emitJSDocHeritageTag(tag) {
                emitJSDocTagName(tag.tagName);
                writeSpace();
                writePunctuation("{");
                emit(tag.class);
                writePunctuation("}");
                emitJSDocComment(tag.comment);
            }
            function emitJSDocTemplateTag(tag) {
                emitJSDocTagName(tag.tagName);
                emitJSDocTypeExpression(tag.constraint);
                writeSpace();
                emitList(tag, tag.typeParameters, 528 /* CommaListElements */);
                emitJSDocComment(tag.comment);
            }
            function emitJSDocTypedefTag(tag) {
                emitJSDocTagName(tag.tagName);
                if (tag.typeExpression) {
                    if (tag.typeExpression.kind === 316 /* JSDocTypeExpression */) {
                        emitJSDocTypeExpression(tag.typeExpression);
                    }
                    else {
                        writeSpace();
                        writePunctuation("{");
                        write("Object");
                        if (tag.typeExpression.isArrayType) {
                            writePunctuation("[");
                            writePunctuation("]");
                        }
                        writePunctuation("}");
                    }
                }
                if (tag.fullName) {
                    writeSpace();
                    emit(tag.fullName);
                }
                emitJSDocComment(tag.comment);
                if (tag.typeExpression && tag.typeExpression.kind === 329 /* JSDocTypeLiteral */) {
                    emitJSDocTypeLiteral(tag.typeExpression);
                }
            }
            function emitJSDocCallbackTag(tag) {
                emitJSDocTagName(tag.tagName);
                if (tag.name) {
                    writeSpace();
                    emit(tag.name);
                }
                emitJSDocComment(tag.comment);
                emitJSDocSignature(tag.typeExpression);
            }
            function emitJSDocOverloadTag(tag) {
                emitJSDocComment(tag.comment);
                emitJSDocSignature(tag.typeExpression);
            }
            function emitJSDocSimpleTag(tag) {
                emitJSDocTagName(tag.tagName);
                emitJSDocComment(tag.comment);
            }
            function emitJSDocTypeLiteral(lit) {
                emitList(lit, factory.createNodeArray(lit.jsDocPropertyTags), 33 /* JSDocComment */);
            }
            function emitJSDocSignature(sig) {
                if (sig.typeParameters) {
                    emitList(sig, factory.createNodeArray(sig.typeParameters), 33 /* JSDocComment */);
                }
                if (sig.parameters) {
                    emitList(sig, factory.createNodeArray(sig.parameters), 33 /* JSDocComment */);
                }
                if (sig.type) {
                    writeLine();
                    writeSpace();
                    writePunctuation("*");
                    writeSpace();
                    emit(sig.type);
                }
            }
            function emitJSDocPropertyLikeTag(param) {
                emitJSDocTagName(param.tagName);
                emitJSDocTypeExpression(param.typeExpression);
                writeSpace();
                if (param.isBracketed) {
                    writePunctuation("[");
                }
                emit(param.name);
                if (param.isBracketed) {
                    writePunctuation("]");
                }
                emitJSDocComment(param.comment);
            }
            function emitJSDocTagName(tagName) {
                writePunctuation("@");
                emit(tagName);
            }
            function emitJSDocComment(comment) {
                const text = getTextOfJSDocComment(comment);
                if (text) {
                    writeSpace();
                    write(text);
                }
            }
            function emitJSDocTypeExpression(typeExpression) {
                if (typeExpression) {
                    writeSpace();
                    writePunctuation("{");
                    emit(typeExpression.type);
                    writePunctuation("}");
                }
            }
            function emitSourceFile(node) {
                writeLine();
                const statements = node.statements;
                const shouldEmitDetachedComment = statements.length === 0 || !isPrologueDirective(statements[0]) || nodeIsSynthesized(statements[0]);
                if (shouldEmitDetachedComment) {
                    emitBodyWithDetachedComments(node, statements, emitSourceFileWorker);
                    return;
                }
                emitSourceFileWorker(node);
            }
            function emitSyntheticTripleSlashReferencesIfNeeded(node) {
                emitTripleSlashDirectives(!!node.hasNoDefaultLib, node.syntheticFileReferences || [], node.syntheticTypeReferences || [], node.syntheticLibReferences || []);
                for (const prepend of node.prepends) {
                    if (isUnparsedSource(prepend) && prepend.syntheticReferences) {
                        for (const ref of prepend.syntheticReferences) {
                            emit(ref);
                            writeLine();
                        }
                    }
                }
            }
            function emitTripleSlashDirectivesIfNeeded(node) {
                if (node.isDeclarationFile)
                    emitTripleSlashDirectives(node.hasNoDefaultLib, node.referencedFiles, node.typeReferenceDirectives, node.libReferenceDirectives);
            }
            function emitTripleSlashDirectives(hasNoDefaultLib, files, types, libs2) {
                if (hasNoDefaultLib) {
                    const pos = writer.getTextPos();
                    writeComment(`/// <reference no-default-lib="true"/>`);
                    if (bundleFileInfo)
                        bundleFileInfo.sections.push({ pos, end: writer.getTextPos(), kind: "no-default-lib" /* NoDefaultLib */ });
                    writeLine();
                }
                if (currentSourceFile && currentSourceFile.moduleName) {
                    writeComment(`/// <amd-module name="${currentSourceFile.moduleName}" />`);
                    writeLine();
                }
                if (currentSourceFile && currentSourceFile.amdDependencies) {
                    for (const dep of currentSourceFile.amdDependencies) {
                        if (dep.name) {
                            writeComment(`/// <amd-dependency name="${dep.name}" path="${dep.path}" />`);
                        }
                        else {
                            writeComment(`/// <amd-dependency path="${dep.path}" />`);
                        }
                        writeLine();
                    }
                }
                for (const directive of files) {
                    const pos = writer.getTextPos();
                    writeComment(`/// <reference path="${directive.fileName}" />`);
                    if (bundleFileInfo)
                        bundleFileInfo.sections.push({ pos, end: writer.getTextPos(), kind: "reference" /* Reference */, data: directive.fileName });
                    writeLine();
                }
                for (const directive of types) {
                    const pos = writer.getTextPos();
                    const resolutionMode = directive.resolutionMode && directive.resolutionMode !== (currentSourceFile == null ? void 0 : currentSourceFile.impliedNodeFormat) ? `resolution-mode="${directive.resolutionMode === 99 /* ESNext */ ? "import" : "require"}"` : "";
                    writeComment(`/// <reference types="${directive.fileName}" ${resolutionMode}/>`);
                    if (bundleFileInfo)
                        bundleFileInfo.sections.push({ pos, end: writer.getTextPos(), kind: !directive.resolutionMode ? "type" /* Type */ : directive.resolutionMode === 99 /* ESNext */ ? "type-import" /* TypeResolutionModeImport */ : "type-require" /* TypeResolutionModeRequire */, data: directive.fileName });
                    writeLine();
                }
                for (const directive of libs2) {
                    const pos = writer.getTextPos();
                    writeComment(`/// <reference lib="${directive.fileName}" />`);
                    if (bundleFileInfo)
                        bundleFileInfo.sections.push({ pos, end: writer.getTextPos(), kind: "lib" /* Lib */, data: directive.fileName });
                    writeLine();
                }
            }
            function emitSourceFileWorker(node) {
                const statements = node.statements;
                pushNameGenerationScope(node);
                forEach(node.statements, generateNames);
                emitHelpers(node);
                const index = findIndex(statements, (statement) => !isPrologueDirective(statement));
                emitTripleSlashDirectivesIfNeeded(node);
                emitList(node, statements, 1 /* MultiLine */, 
                /*parenthesizerRule*/
                void 0, index === -1 ? statements.length : index);
                popNameGenerationScope(node);
            }
            function emitPartiallyEmittedExpression(node) {
                const emitFlags = getEmitFlags(node);
                if (!(emitFlags & 1024 /* NoLeadingComments */) && node.pos !== node.expression.pos) {
                    emitTrailingCommentsOfPosition(node.expression.pos);
                }
                emitExpression(node.expression);
                if (!(emitFlags & 2048 /* NoTrailingComments */) && node.end !== node.expression.end) {
                    emitLeadingCommentsOfPosition(node.expression.end);
                }
            }
            function emitCommaList(node) {
                emitExpressionList(node, node.elements, 528 /* CommaListElements */, 
                /*parenthesizerRule*/
                void 0);
            }
            function emitPrologueDirectives(statements, sourceFile, seenPrologueDirectives, recordBundleFileSection) {
                let needsToSetSourceFile = !!sourceFile;
                for (let i = 0; i < statements.length; i++) {
                    const statement = statements[i];
                    if (isPrologueDirective(statement)) {
                        const shouldEmitPrologueDirective = seenPrologueDirectives ? !seenPrologueDirectives.has(statement.expression.text) : true;
                        if (shouldEmitPrologueDirective) {
                            if (needsToSetSourceFile) {
                                needsToSetSourceFile = false;
                                setSourceFile(sourceFile);
                            }
                            writeLine();
                            const pos = writer.getTextPos();
                            emit(statement);
                            if (recordBundleFileSection && bundleFileInfo)
                                bundleFileInfo.sections.push({ pos, end: writer.getTextPos(), kind: "prologue" /* Prologue */, data: statement.expression.text });
                            if (seenPrologueDirectives) {
                                seenPrologueDirectives.add(statement.expression.text);
                            }
                        }
                    }
                    else {
                        return i;
                    }
                }
                return statements.length;
            }
            function emitUnparsedPrologues(prologues, seenPrologueDirectives) {
                for (const prologue of prologues) {
                    if (!seenPrologueDirectives.has(prologue.data)) {
                        writeLine();
                        const pos = writer.getTextPos();
                        emit(prologue);
                        if (bundleFileInfo)
                            bundleFileInfo.sections.push({ pos, end: writer.getTextPos(), kind: "prologue" /* Prologue */, data: prologue.data });
                        if (seenPrologueDirectives) {
                            seenPrologueDirectives.add(prologue.data);
                        }
                    }
                }
            }
            function emitPrologueDirectivesIfNeeded(sourceFileOrBundle) {
                if (isSourceFile(sourceFileOrBundle)) {
                    emitPrologueDirectives(sourceFileOrBundle.statements, sourceFileOrBundle);
                }
                else {
                    const seenPrologueDirectives = /* @__PURE__ */ new Set();
                    for (const prepend of sourceFileOrBundle.prepends) {
                        emitUnparsedPrologues(prepend.prologues, seenPrologueDirectives);
                    }
                    for (const sourceFile of sourceFileOrBundle.sourceFiles) {
                        emitPrologueDirectives(sourceFile.statements, sourceFile, seenPrologueDirectives, 
                        /*recordBundleFileSection*/
                        true);
                    }
                    setSourceFile(void 0);
                }
            }
            function getPrologueDirectivesFromBundledSourceFiles(bundle) {
                const seenPrologueDirectives = /* @__PURE__ */ new Set();
                let prologues;
                for (let index = 0; index < bundle.sourceFiles.length; index++) {
                    const sourceFile = bundle.sourceFiles[index];
                    let directives;
                    let end = 0;
                    for (const statement of sourceFile.statements) {
                        if (!isPrologueDirective(statement))
                            break;
                        if (seenPrologueDirectives.has(statement.expression.text))
                            continue;
                        seenPrologueDirectives.add(statement.expression.text);
                        (directives || (directives = [])).push({
                            pos: statement.pos,
                            end: statement.end,
                            expression: {
                                pos: statement.expression.pos,
                                end: statement.expression.end,
                                text: statement.expression.text
                            }
                        });
                        end = end < statement.end ? statement.end : end;
                    }
                    if (directives)
                        (prologues || (prologues = [])).push({ file: index, text: sourceFile.text.substring(0, end), directives });
                }
                return prologues;
            }
            function emitShebangIfNeeded(sourceFileOrBundle) {
                if (isSourceFile(sourceFileOrBundle) || isUnparsedSource(sourceFileOrBundle)) {
                    const shebang = getShebang(sourceFileOrBundle.text);
                    if (shebang) {
                        writeComment(shebang);
                        writeLine();
                        return true;
                    }
                }
                else {
                    for (const prepend of sourceFileOrBundle.prepends) {
                        Debug.assertNode(prepend, isUnparsedSource);
                        if (emitShebangIfNeeded(prepend)) {
                            return true;
                        }
                    }
                    for (const sourceFile of sourceFileOrBundle.sourceFiles) {
                        if (emitShebangIfNeeded(sourceFile)) {
                            return true;
                        }
                    }
                }
            }
            function emitNodeWithWriter(node, writer2) {
                if (!node)
                    return;
                const savedWrite = write;
                write = writer2;
                emit(node);
                write = savedWrite;
            }
            function emitDecoratorsAndModifiers(node, modifiers, allowDecorators) {
                if (modifiers == null ? void 0 : modifiers.length) {
                    if (every(modifiers, isModifier)) {
                        return emitModifierList(node, modifiers);
                    }
                    if (every(modifiers, isDecorator)) {
                        if (allowDecorators) {
                            return emitDecoratorList(node, modifiers);
                        }
                        return node.pos;
                    }
                    onBeforeEmitNodeArray == null ? void 0 : onBeforeEmitNodeArray(modifiers);
                    let lastMode;
                    let mode;
                    let start = 0;
                    let pos = 0;
                    let lastModifier;
                    while (start < modifiers.length) {
                        while (pos < modifiers.length) {
                            lastModifier = modifiers[pos];
                            mode = isDecorator(lastModifier) ? "decorators" : "modifiers";
                            if (lastMode === void 0) {
                                lastMode = mode;
                            }
                            else if (mode !== lastMode) {
                                break;
                            }
                            pos++;
                        }
                        const textRange = { pos: -1, end: -1 };
                        if (start === 0)
                            textRange.pos = modifiers.pos;
                        if (pos === modifiers.length - 1)
                            textRange.end = modifiers.end;
                        if (lastMode === "modifiers" || allowDecorators) {
                            emitNodeListItems(emit, node, modifiers, lastMode === "modifiers" ? 2359808 /* Modifiers */ : 2146305 /* Decorators */, 
                            /*parenthesizerRule*/
                            void 0, start, pos - start, 
                            /*hasTrailingComma*/
                            false, textRange);
                        }
                        start = pos;
                        lastMode = mode;
                        pos++;
                    }
                    onAfterEmitNodeArray == null ? void 0 : onAfterEmitNodeArray(modifiers);
                    if (lastModifier && !positionIsSynthesized(lastModifier.end)) {
                        return lastModifier.end;
                    }
                }
                return node.pos;
            }
            function emitModifierList(node, modifiers) {
                emitList(node, modifiers, 2359808 /* Modifiers */);
                const lastModifier = lastOrUndefined(modifiers);
                return lastModifier && !positionIsSynthesized(lastModifier.end) ? lastModifier.end : node.pos;
            }
            function emitTypeAnnotation(node) {
                if (node) {
                    writePunctuation(":");
                    writeSpace();
                    emit(node);
                }
            }
            function emitInitializer(node, equalCommentStartPos, container, parenthesizerRule) {
                if (node) {
                    writeSpace();
                    emitTokenWithComment(64 /* EqualsToken */, equalCommentStartPos, writeOperator, container);
                    writeSpace();
                    emitExpression(node, parenthesizerRule);
                }
            }
            function emitNodeWithPrefix(prefix, prefixWriter, node, emit2) {
                if (node) {
                    prefixWriter(prefix);
                    emit2(node);
                }
            }
            function emitWithLeadingSpace(node) {
                if (node) {
                    writeSpace();
                    emit(node);
                }
            }
            function emitExpressionWithLeadingSpace(node, parenthesizerRule) {
                if (node) {
                    writeSpace();
                    emitExpression(node, parenthesizerRule);
                }
            }
            function emitWithTrailingSpace(node) {
                if (node) {
                    emit(node);
                    writeSpace();
                }
            }
            function emitEmbeddedStatement(parent2, node) {
                if (isBlock(node) || getEmitFlags(parent2) & 1 /* SingleLine */ || preserveSourceNewlines && !getLeadingLineTerminatorCount(parent2, node, 0 /* None */)) {
                    writeSpace();
                    emit(node);
                }
                else {
                    writeLine();
                    increaseIndent();
                    if (isEmptyStatement(node)) {
                        pipelineEmit(5 /* EmbeddedStatement */, node);
                    }
                    else {
                        emit(node);
                    }
                    decreaseIndent();
                }
            }
            function emitDecoratorList(parentNode, decorators) {
                emitList(parentNode, decorators, 2146305 /* Decorators */);
                const lastDecorator = lastOrUndefined(decorators);
                return lastDecorator && !positionIsSynthesized(lastDecorator.end) ? lastDecorator.end : parentNode.pos;
            }
            function emitTypeArguments(parentNode, typeArguments) {
                emitList(parentNode, typeArguments, 53776 /* TypeArguments */, typeArgumentParenthesizerRuleSelector);
            }
            function emitTypeParameters(parentNode, typeParameters) {
                if (isFunctionLike(parentNode) && parentNode.typeArguments) {
                    return emitTypeArguments(parentNode, parentNode.typeArguments);
                }
                emitList(parentNode, typeParameters, 53776 /* TypeParameters */);
            }
            function emitParameters(parentNode, parameters) {
                emitList(parentNode, parameters, 2576 /* Parameters */);
            }
            function canEmitSimpleArrowHead(parentNode, parameters) {
                const parameter = singleOrUndefined(parameters);
                return parameter && parameter.pos === parentNode.pos && isArrowFunction(parentNode) && !parentNode.type && !some(parentNode.modifiers) && !some(parentNode.typeParameters) && !some(parameter.modifiers) && !parameter.dotDotDotToken && !parameter.questionToken && !parameter.type && !parameter.initializer && isIdentifier(parameter.name);
            }
            function emitParametersForArrow(parentNode, parameters) {
                if (canEmitSimpleArrowHead(parentNode, parameters)) {
                    emitList(parentNode, parameters, 2576 /* Parameters */ & ~2048 /* Parenthesis */);
                }
                else {
                    emitParameters(parentNode, parameters);
                }
            }
            function emitParametersForIndexSignature(parentNode, parameters) {
                emitList(parentNode, parameters, 8848 /* IndexSignatureParameters */);
            }
            function writeDelimiter(format) {
                switch (format & 60 /* DelimitersMask */) {
                    case 0 /* None */:
                        break;
                    case 16 /* CommaDelimited */:
                        writePunctuation(",");
                        break;
                    case 4 /* BarDelimited */:
                        writeSpace();
                        writePunctuation("|");
                        break;
                    case 32 /* AsteriskDelimited */:
                        writeSpace();
                        writePunctuation("*");
                        writeSpace();
                        break;
                    case 8 /* AmpersandDelimited */:
                        writeSpace();
                        writePunctuation("&");
                        break;
                }
            }
            function emitList(parentNode, children, format, parenthesizerRule, start, count) {
                emitNodeList(emit, parentNode, children, format | (parentNode && getEmitFlags(parentNode) & 2 /* MultiLine */ ? 65536 /* PreferNewLine */ : 0), parenthesizerRule, start, count);
            }
            function emitExpressionList(parentNode, children, format, parenthesizerRule, start, count) {
                emitNodeList(emitExpression, parentNode, children, format, parenthesizerRule, start, count);
            }
            function emitNodeList(emit2, parentNode, children, format, parenthesizerRule, start = 0, count = children ? children.length - start : 0) {
                const isUndefined = children === void 0;
                if (isUndefined && format & 16384 /* OptionalIfUndefined */) {
                    return;
                }
                const isEmpty = children === void 0 || start >= children.length || count === 0;
                if (isEmpty && format & 32768 /* OptionalIfEmpty */) {
                    onBeforeEmitNodeArray == null ? void 0 : onBeforeEmitNodeArray(children);
                    onAfterEmitNodeArray == null ? void 0 : onAfterEmitNodeArray(children);
                    return;
                }
                if (format & 15360 /* BracketsMask */) {
                    writePunctuation(getOpeningBracket(format));
                    if (isEmpty && children) {
                        emitTrailingCommentsOfPosition(children.pos, 
                        /*prefixSpace*/
                        true);
                    }
                }
                onBeforeEmitNodeArray == null ? void 0 : onBeforeEmitNodeArray(children);
                if (isEmpty) {
                    if (format & 1 /* MultiLine */ && !(preserveSourceNewlines && (!parentNode || currentSourceFile && rangeIsOnSingleLine(parentNode, currentSourceFile)))) {
                        writeLine();
                    }
                    else if (format & 256 /* SpaceBetweenBraces */ && !(format & 524288 /* NoSpaceIfEmpty */)) {
                        writeSpace();
                    }
                }
                else {
                    emitNodeListItems(emit2, parentNode, children, format, parenthesizerRule, start, count, children.hasTrailingComma, children);
                }
                onAfterEmitNodeArray == null ? void 0 : onAfterEmitNodeArray(children);
                if (format & 15360 /* BracketsMask */) {
                    if (isEmpty && children) {
                        emitLeadingCommentsOfPosition(children.end);
                    }
                    writePunctuation(getClosingBracket(format));
                }
            }
            function emitNodeListItems(emit2, parentNode, children, format, parenthesizerRule, start, count, hasTrailingComma, childrenTextRange) {
                const mayEmitInterveningComments = (format & 262144 /* NoInterveningComments */) === 0;
                let shouldEmitInterveningComments = mayEmitInterveningComments;
                const leadingLineTerminatorCount = getLeadingLineTerminatorCount(parentNode, children[start], format);
                if (leadingLineTerminatorCount) {
                    writeLine(leadingLineTerminatorCount);
                    shouldEmitInterveningComments = false;
                }
                else if (format & 256 /* SpaceBetweenBraces */) {
                    writeSpace();
                }
                if (format & 128 /* Indented */) {
                    increaseIndent();
                }
                const emitListItem = getEmitListItem(emit2, parenthesizerRule);
                let previousSibling;
                let previousSourceFileTextKind;
                let shouldDecreaseIndentAfterEmit = false;
                for (let i = 0; i < count; i++) {
                    const child = children[start + i];
                    if (format & 32 /* AsteriskDelimited */) {
                        writeLine();
                        writeDelimiter(format);
                    }
                    else if (previousSibling) {
                        if (format & 60 /* DelimitersMask */ && previousSibling.end !== (parentNode ? parentNode.end : -1)) {
                            const previousSiblingEmitFlags = getEmitFlags(previousSibling);
                            if (!(previousSiblingEmitFlags & 2048 /* NoTrailingComments */)) {
                                emitLeadingCommentsOfPosition(previousSibling.end);
                            }
                        }
                        writeDelimiter(format);
                        recordBundleFileInternalSectionEnd(previousSourceFileTextKind);
                        const separatingLineTerminatorCount = getSeparatingLineTerminatorCount(previousSibling, child, format);
                        if (separatingLineTerminatorCount > 0) {
                            if ((format & (3 /* LinesMask */ | 128 /* Indented */)) === 0 /* SingleLine */) {
                                increaseIndent();
                                shouldDecreaseIndentAfterEmit = true;
                            }
                            if (shouldEmitInterveningComments && format & 60 /* DelimitersMask */ && !positionIsSynthesized(child.pos)) {
                                const commentRange = getCommentRange(child);
                                emitTrailingCommentsOfPosition(commentRange.pos, 
                                /*prefixSpace*/
                                !!(format & 512 /* SpaceBetweenSiblings */), 
                                /*forceNoNewline*/
                                true);
                            }
                            writeLine(separatingLineTerminatorCount);
                            shouldEmitInterveningComments = false;
                        }
                        else if (previousSibling && format & 512 /* SpaceBetweenSiblings */) {
                            writeSpace();
                        }
                    }
                    previousSourceFileTextKind = recordBundleFileInternalSectionStart(child);
                    if (shouldEmitInterveningComments) {
                        const commentRange = getCommentRange(child);
                        emitTrailingCommentsOfPosition(commentRange.pos);
                    }
                    else {
                        shouldEmitInterveningComments = mayEmitInterveningComments;
                    }
                    nextListElementPos = child.pos;
                    emitListItem(child, emit2, parenthesizerRule, i);
                    if (shouldDecreaseIndentAfterEmit) {
                        decreaseIndent();
                        shouldDecreaseIndentAfterEmit = false;
                    }
                    previousSibling = child;
                }
                const emitFlags = previousSibling ? getEmitFlags(previousSibling) : 0;
                const skipTrailingComments = commentsDisabled || !!(emitFlags & 2048 /* NoTrailingComments */);
                const emitTrailingComma = hasTrailingComma && format & 64 /* AllowTrailingComma */ && format & 16 /* CommaDelimited */;
                if (emitTrailingComma) {
                    if (previousSibling && !skipTrailingComments) {
                        emitTokenWithComment(28 /* CommaToken */, previousSibling.end, writePunctuation, previousSibling);
                    }
                    else {
                        writePunctuation(",");
                    }
                }
                if (previousSibling && (parentNode ? parentNode.end : -1) !== previousSibling.end && format & 60 /* DelimitersMask */ && !skipTrailingComments) {
                    emitLeadingCommentsOfPosition(emitTrailingComma && (childrenTextRange == null ? void 0 : childrenTextRange.end) ? childrenTextRange.end : previousSibling.end);
                }
                if (format & 128 /* Indented */) {
                    decreaseIndent();
                }
                recordBundleFileInternalSectionEnd(previousSourceFileTextKind);
                const closingLineTerminatorCount = getClosingLineTerminatorCount(parentNode, children[start + count - 1], format, childrenTextRange);
                if (closingLineTerminatorCount) {
                    writeLine(closingLineTerminatorCount);
                }
                else if (format & (2097152 /* SpaceAfterList */ | 256 /* SpaceBetweenBraces */)) {
                    writeSpace();
                }
            }
            function writeLiteral(s) {
                writer.writeLiteral(s);
            }
            function writeStringLiteral(s) {
                writer.writeStringLiteral(s);
            }
            function writeBase(s) {
                writer.write(s);
            }
            function writeSymbol(s, sym) {
                writer.writeSymbol(s, sym);
            }
            function writePunctuation(s) {
                writer.writePunctuation(s);
            }
            function writeTrailingSemicolon() {
                writer.writeTrailingSemicolon(";");
            }
            function writeKeyword(s) {
                writer.writeKeyword(s);
            }
            function writeOperator(s) {
                writer.writeOperator(s);
            }
            function writeParameter(s) {
                writer.writeParameter(s);
            }
            function writeComment(s) {
                writer.writeComment(s);
            }
            function writeSpace() {
                writer.writeSpace(" ");
            }
            function writeProperty(s) {
                writer.writeProperty(s);
            }
            function nonEscapingWrite(s) {
                if (writer.nonEscapingWrite) {
                    writer.nonEscapingWrite(s);
                }
                else {
                    writer.write(s);
                }
            }
            function writeLine(count = 1) {
                for (let i = 0; i < count; i++) {
                    writer.writeLine(i > 0);
                }
            }
            function increaseIndent() {
                writer.increaseIndent();
            }
            function decreaseIndent() {
                writer.decreaseIndent();
            }
            function writeToken(token, pos, writer2, contextNode) {
                return !sourceMapsDisabled ? emitTokenWithSourceMap(contextNode, token, writer2, pos, writeTokenText) : writeTokenText(token, writer2, pos);
            }
            function writeTokenNode(node, writer2) {
                if (onBeforeEmitToken) {
                    onBeforeEmitToken(node);
                }
                writer2(tokenToString(node.kind));
                if (onAfterEmitToken) {
                    onAfterEmitToken(node);
                }
            }
            function writeTokenText(token, writer2, pos) {
                const tokenString = tokenToString(token);
                writer2(tokenString);
                return pos < 0 ? pos : pos + tokenString.length;
            }
            function writeLineOrSpace(parentNode, prevChildNode, nextChildNode) {
                if (getEmitFlags(parentNode) & 1 /* SingleLine */) {
                    writeSpace();
                }
                else if (preserveSourceNewlines) {
                    const lines = getLinesBetweenNodes(parentNode, prevChildNode, nextChildNode);
                    if (lines) {
                        writeLine(lines);
                    }
                    else {
                        writeSpace();
                    }
                }
                else {
                    writeLine();
                }
            }
            function writeLines(text) {
                const lines = text.split(/\r\n?|\n/g);
                const indentation = guessIndentation(lines);
                for (const lineText of lines) {
                    const line = indentation ? lineText.slice(indentation) : lineText;
                    if (line.length) {
                        writeLine();
                        write(line);
                    }
                }
            }
            function writeLinesAndIndent(lineCount, writeSpaceIfNotIndenting) {
                if (lineCount) {
                    increaseIndent();
                    writeLine(lineCount);
                }
                else if (writeSpaceIfNotIndenting) {
                    writeSpace();
                }
            }
            function decreaseIndentIf(value1, value2) {
                if (value1) {
                    decreaseIndent();
                }
                if (value2) {
                    decreaseIndent();
                }
            }
            function getLeadingLineTerminatorCount(parentNode, firstChild, format) {
                if (format & 2 /* PreserveLines */ || preserveSourceNewlines) {
                    if (format & 65536 /* PreferNewLine */) {
                        return 1;
                    }
                    if (firstChild === void 0) {
                        return !parentNode || currentSourceFile && rangeIsOnSingleLine(parentNode, currentSourceFile) ? 0 : 1;
                    }
                    if (firstChild.pos === nextListElementPos) {
                        return 0;
                    }
                    if (firstChild.kind === 12 /* JsxText */) {
                        return 0;
                    }
                    if (currentSourceFile && parentNode && !positionIsSynthesized(parentNode.pos) && !nodeIsSynthesized(firstChild) && (!firstChild.parent || getOriginalNode(firstChild.parent) === getOriginalNode(parentNode))) {
                        if (preserveSourceNewlines) {
                            return getEffectiveLines((includeComments) => getLinesBetweenPositionAndPrecedingNonWhitespaceCharacter(firstChild.pos, parentNode.pos, currentSourceFile, includeComments));
                        }
                        return rangeStartPositionsAreOnSameLine(parentNode, firstChild, currentSourceFile) ? 0 : 1;
                    }
                    if (synthesizedNodeStartsOnNewLine(firstChild, format)) {
                        return 1;
                    }
                }
                return format & 1 /* MultiLine */ ? 1 : 0;
            }
            function getSeparatingLineTerminatorCount(previousNode, nextNode, format) {
                if (format & 2 /* PreserveLines */ || preserveSourceNewlines) {
                    if (previousNode === void 0 || nextNode === void 0) {
                        return 0;
                    }
                    if (nextNode.kind === 12 /* JsxText */) {
                        return 0;
                    }
                    else if (currentSourceFile && !nodeIsSynthesized(previousNode) && !nodeIsSynthesized(nextNode)) {
                        if (preserveSourceNewlines && siblingNodePositionsAreComparable(previousNode, nextNode)) {
                            return getEffectiveLines((includeComments) => getLinesBetweenRangeEndAndRangeStart(previousNode, nextNode, currentSourceFile, includeComments));
                        }
                        else if (!preserveSourceNewlines && originalNodesHaveSameParent(previousNode, nextNode)) {
                            return rangeEndIsOnSameLineAsRangeStart(previousNode, nextNode, currentSourceFile) ? 0 : 1;
                        }
                        return format & 65536 /* PreferNewLine */ ? 1 : 0;
                    }
                    else if (synthesizedNodeStartsOnNewLine(previousNode, format) || synthesizedNodeStartsOnNewLine(nextNode, format)) {
                        return 1;
                    }
                }
                else if (getStartsOnNewLine(nextNode)) {
                    return 1;
                }
                return format & 1 /* MultiLine */ ? 1 : 0;
            }
            function getClosingLineTerminatorCount(parentNode, lastChild, format, childrenTextRange) {
                if (format & 2 /* PreserveLines */ || preserveSourceNewlines) {
                    if (format & 65536 /* PreferNewLine */) {
                        return 1;
                    }
                    if (lastChild === void 0) {
                        return !parentNode || currentSourceFile && rangeIsOnSingleLine(parentNode, currentSourceFile) ? 0 : 1;
                    }
                    if (currentSourceFile && parentNode && !positionIsSynthesized(parentNode.pos) && !nodeIsSynthesized(lastChild) && (!lastChild.parent || lastChild.parent === parentNode)) {
                        if (preserveSourceNewlines) {
                            const end = childrenTextRange && !positionIsSynthesized(childrenTextRange.end) ? childrenTextRange.end : lastChild.end;
                            return getEffectiveLines((includeComments) => getLinesBetweenPositionAndNextNonWhitespaceCharacter(end, parentNode.end, currentSourceFile, includeComments));
                        }
                        return rangeEndPositionsAreOnSameLine(parentNode, lastChild, currentSourceFile) ? 0 : 1;
                    }
                    if (synthesizedNodeStartsOnNewLine(lastChild, format)) {
                        return 1;
                    }
                }
                if (format & 1 /* MultiLine */ && !(format & 131072 /* NoTrailingNewLine */)) {
                    return 1;
                }
                return 0;
            }
            function getEffectiveLines(getLineDifference) {
                Debug.assert(!!preserveSourceNewlines);
                const lines = getLineDifference(
                /*includeComments*/
                true);
                if (lines === 0) {
                    return getLineDifference(
                    /*includeComments*/
                    false);
                }
                return lines;
            }
            function writeLineSeparatorsAndIndentBefore(node, parent2) {
                const leadingNewlines = preserveSourceNewlines && getLeadingLineTerminatorCount(parent2, node, 0 /* None */);
                if (leadingNewlines) {
                    writeLinesAndIndent(leadingNewlines, 
                    /*writeSpaceIfNotIndenting*/
                    false);
                }
                return !!leadingNewlines;
            }
            function writeLineSeparatorsAfter(node, parent2) {
                const trailingNewlines = preserveSourceNewlines && getClosingLineTerminatorCount(parent2, node, 0 /* None */, 
                /*childrenTextRange*/
                void 0);
                if (trailingNewlines) {
                    writeLine(trailingNewlines);
                }
            }
            function synthesizedNodeStartsOnNewLine(node, format) {
                if (nodeIsSynthesized(node)) {
                    const startsOnNewLine = getStartsOnNewLine(node);
                    if (startsOnNewLine === void 0) {
                        return (format & 65536 /* PreferNewLine */) !== 0;
                    }
                    return startsOnNewLine;
                }
                return (format & 65536 /* PreferNewLine */) !== 0;
            }
            function getLinesBetweenNodes(parent2, node1, node2) {
                if (getEmitFlags(parent2) & 262144 /* NoIndentation */) {
                    return 0;
                }
                parent2 = skipSynthesizedParentheses(parent2);
                node1 = skipSynthesizedParentheses(node1);
                node2 = skipSynthesizedParentheses(node2);
                if (getStartsOnNewLine(node2)) {
                    return 1;
                }
                if (currentSourceFile && !nodeIsSynthesized(parent2) && !nodeIsSynthesized(node1) && !nodeIsSynthesized(node2)) {
                    if (preserveSourceNewlines) {
                        return getEffectiveLines((includeComments) => getLinesBetweenRangeEndAndRangeStart(node1, node2, currentSourceFile, includeComments));
                    }
                    return rangeEndIsOnSameLineAsRangeStart(node1, node2, currentSourceFile) ? 0 : 1;
                }
                return 0;
            }
            function isEmptyBlock(block) {
                return block.statements.length === 0 && (!currentSourceFile || rangeEndIsOnSameLineAsRangeStart(block, block, currentSourceFile));
            }
            function skipSynthesizedParentheses(node) {
                while (node.kind === 217 /* ParenthesizedExpression */ && nodeIsSynthesized(node)) {
                    node = node.expression;
                }
                return node;
            }
            function getTextOfNode2(node, includeTrivia) {
                if (isGeneratedIdentifier(node) || isGeneratedPrivateIdentifier(node)) {
                    return generateName(node);
                }
                if (isStringLiteral(node) && node.textSourceNode) {
                    return getTextOfNode2(node.textSourceNode, includeTrivia);
                }
                const sourceFile = currentSourceFile;
                const canUseSourceFile = !!sourceFile && !!node.parent && !nodeIsSynthesized(node);
                if (isMemberName(node)) {
                    if (!canUseSourceFile || getSourceFileOfNode(node) !== getOriginalNode(sourceFile)) {
                        return idText(node);
                    }
                }
                else if (isJsxNamespacedName(node)) {
                    if (!canUseSourceFile || getSourceFileOfNode(node) !== getOriginalNode(sourceFile)) {
                        return getTextOfJsxNamespacedName(node);
                    }
                }
                else {
                    Debug.assertNode(node, isLiteralExpression);
                    if (!canUseSourceFile) {
                        return node.text;
                    }
                }
                return getSourceTextOfNodeFromSourceFile(sourceFile, node, includeTrivia);
            }
            function getLiteralTextOfNode(node, neverAsciiEscape, jsxAttributeEscape) {
                if (node.kind === 11 /* StringLiteral */ && node.textSourceNode) {
                    const textSourceNode = node.textSourceNode;
                    if (isIdentifier(textSourceNode) || isPrivateIdentifier(textSourceNode) || isNumericLiteral(textSourceNode) || isJsxNamespacedName(textSourceNode)) {
                        const text = isNumericLiteral(textSourceNode) ? textSourceNode.text : getTextOfNode2(textSourceNode);
                        return jsxAttributeEscape ? `"${escapeJsxAttributeString(text)}"` : neverAsciiEscape || getEmitFlags(node) & 16777216 /* NoAsciiEscaping */ ? `"${escapeString(text)}"` : `"${escapeNonAsciiString(text)}"`;
                    }
                    else {
                        return getLiteralTextOfNode(textSourceNode, neverAsciiEscape, jsxAttributeEscape);
                    }
                }
                const flags = (neverAsciiEscape ? 1 /* NeverAsciiEscape */ : 0) | (jsxAttributeEscape ? 2 /* JsxAttributeEscape */ : 0) | (printerOptions.terminateUnterminatedLiterals ? 4 /* TerminateUnterminatedLiterals */ : 0) | (printerOptions.target && printerOptions.target >= 8 /* ES2021 */ ? 8 /* AllowNumericSeparator */ : 0);
                return getLiteralText(node, currentSourceFile, flags);
            }
            function pushNameGenerationScope(node) {
                if (node && getEmitFlags(node) & 1048576 /* ReuseTempVariableScope */) {
                    return;
                }
                tempFlagsStack.push(tempFlags);
                tempFlags = 0 /* Auto */;
                formattedNameTempFlagsStack.push(formattedNameTempFlags);
                formattedNameTempFlags = void 0;
                reservedNamesStack.push(reservedNames);
            }
            function popNameGenerationScope(node) {
                if (node && getEmitFlags(node) & 1048576 /* ReuseTempVariableScope */) {
                    return;
                }
                tempFlags = tempFlagsStack.pop();
                formattedNameTempFlags = formattedNameTempFlagsStack.pop();
                reservedNames = reservedNamesStack.pop();
            }
            function reserveNameInNestedScopes(name) {
                if (!reservedNames || reservedNames === lastOrUndefined(reservedNamesStack)) {
                    reservedNames = /* @__PURE__ */ new Set();
                }
                reservedNames.add(name);
            }
            function pushPrivateNameGenerationScope(newPrivateNameTempFlags, newReservedMemberNames) {
                privateNameTempFlagsStack.push(privateNameTempFlags);
                privateNameTempFlags = newPrivateNameTempFlags;
                reservedPrivateNamesStack.push(reservedNames);
                reservedPrivateNames = newReservedMemberNames;
            }
            function popPrivateNameGenerationScope() {
                privateNameTempFlags = privateNameTempFlagsStack.pop();
                reservedPrivateNames = reservedPrivateNamesStack.pop();
            }
            function reservePrivateNameInNestedScopes(name) {
                if (!reservedPrivateNames || reservedPrivateNames === lastOrUndefined(reservedPrivateNamesStack)) {
                    reservedPrivateNames = /* @__PURE__ */ new Set();
                }
                reservedPrivateNames.add(name);
            }
            function generateNames(node) {
                if (!node)
                    return;
                switch (node.kind) {
                    case 241 /* Block */:
                        forEach(node.statements, generateNames);
                        break;
                    case 256 /* LabeledStatement */:
                    case 254 /* WithStatement */:
                    case 246 /* DoStatement */:
                    case 247 /* WhileStatement */:
                        generateNames(node.statement);
                        break;
                    case 245 /* IfStatement */:
                        generateNames(node.thenStatement);
                        generateNames(node.elseStatement);
                        break;
                    case 248 /* ForStatement */:
                    case 250 /* ForOfStatement */:
                    case 249 /* ForInStatement */:
                        generateNames(node.initializer);
                        generateNames(node.statement);
                        break;
                    case 255 /* SwitchStatement */:
                        generateNames(node.caseBlock);
                        break;
                    case 269 /* CaseBlock */:
                        forEach(node.clauses, generateNames);
                        break;
                    case 296 /* CaseClause */:
                    case 297 /* DefaultClause */:
                        forEach(node.statements, generateNames);
                        break;
                    case 258 /* TryStatement */:
                        generateNames(node.tryBlock);
                        generateNames(node.catchClause);
                        generateNames(node.finallyBlock);
                        break;
                    case 299 /* CatchClause */:
                        generateNames(node.variableDeclaration);
                        generateNames(node.block);
                        break;
                    case 243 /* VariableStatement */:
                        generateNames(node.declarationList);
                        break;
                    case 261 /* VariableDeclarationList */:
                        forEach(node.declarations, generateNames);
                        break;
                    case 260 /* VariableDeclaration */:
                    case 169 /* Parameter */:
                    case 208 /* BindingElement */:
                    case 263 /* ClassDeclaration */:
                        generateNameIfNeeded(node.name);
                        break;
                    case 262 /* FunctionDeclaration */:
                        generateNameIfNeeded(node.name);
                        if (getEmitFlags(node) & 1048576 /* ReuseTempVariableScope */) {
                            forEach(node.parameters, generateNames);
                            generateNames(node.body);
                        }
                        break;
                    case 206 /* ObjectBindingPattern */:
                    case 207 /* ArrayBindingPattern */:
                        forEach(node.elements, generateNames);
                        break;
                    case 272 /* ImportDeclaration */:
                        generateNames(node.importClause);
                        break;
                    case 273 /* ImportClause */:
                        generateNameIfNeeded(node.name);
                        generateNames(node.namedBindings);
                        break;
                    case 274 /* NamespaceImport */:
                        generateNameIfNeeded(node.name);
                        break;
                    case 280 /* NamespaceExport */:
                        generateNameIfNeeded(node.name);
                        break;
                    case 275 /* NamedImports */:
                        forEach(node.elements, generateNames);
                        break;
                    case 276 /* ImportSpecifier */:
                        generateNameIfNeeded(node.propertyName || node.name);
                        break;
                }
            }
            function generateMemberNames(node) {
                if (!node)
                    return;
                switch (node.kind) {
                    case 303 /* PropertyAssignment */:
                    case 304 /* ShorthandPropertyAssignment */:
                    case 172 /* PropertyDeclaration */:
                    case 174 /* MethodDeclaration */:
                    case 177 /* GetAccessor */:
                    case 178 /* SetAccessor */:
                        generateNameIfNeeded(node.name);
                        break;
                }
            }
            function generateNameIfNeeded(name) {
                if (name) {
                    if (isGeneratedIdentifier(name) || isGeneratedPrivateIdentifier(name)) {
                        generateName(name);
                    }
                    else if (isBindingPattern(name)) {
                        generateNames(name);
                    }
                }
            }
            function generateName(name) {
                const autoGenerate = name.emitNode.autoGenerate;
                if ((autoGenerate.flags & 7 /* KindMask */) === 4 /* Node */) {
                    return generateNameCached(getNodeForGeneratedName(name), isPrivateIdentifier(name), autoGenerate.flags, autoGenerate.prefix, autoGenerate.suffix);
                }
                else {
                    const autoGenerateId = autoGenerate.id;
                    return autoGeneratedIdToGeneratedName[autoGenerateId] || (autoGeneratedIdToGeneratedName[autoGenerateId] = makeName(name));
                }
            }
            function generateNameCached(node, privateName, flags, prefix, suffix) {
                const nodeId = getNodeId(node);
                const cache = privateName ? nodeIdToGeneratedPrivateName : nodeIdToGeneratedName;
                return cache[nodeId] || (cache[nodeId] = generateNameForNode(node, privateName, flags ?? 0 /* None */, formatGeneratedNamePart(prefix, generateName), formatGeneratedNamePart(suffix)));
            }
            function isUniqueName(name, privateName) {
                return isFileLevelUniqueNameInCurrentFile(name, privateName) && !isReservedName(name, privateName) && !generatedNames.has(name);
            }
            function isReservedName(name, privateName) {
                return privateName ? !!(reservedPrivateNames == null ? void 0 : reservedPrivateNames.has(name)) : !!(reservedNames == null ? void 0 : reservedNames.has(name));
            }
            function isFileLevelUniqueNameInCurrentFile(name, _isPrivate) {
                return currentSourceFile ? isFileLevelUniqueName(currentSourceFile, name, hasGlobalName) : true;
            }
            function isUniqueLocalName(name, container) {
                for (let node = container; node && isNodeDescendantOf(node, container); node = node.nextContainer) {
                    if (canHaveLocals(node) && node.locals) {
                        const local = node.locals.get(escapeLeadingUnderscores(name));
                        if (local && local.flags & (111551 /* Value */ | 1048576 /* ExportValue */ | 2097152 /* Alias */)) {
                            return false;
                        }
                    }
                }
                return true;
            }
            function getTempFlags(formattedNameKey) {
                switch (formattedNameKey) {
                    case "":
                        return tempFlags;
                    case "#":
                        return privateNameTempFlags;
                    default:
                        return (formattedNameTempFlags == null ? void 0 : formattedNameTempFlags.get(formattedNameKey)) ?? 0 /* Auto */;
                }
            }
            function setTempFlags(formattedNameKey, flags) {
                switch (formattedNameKey) {
                    case "":
                        tempFlags = flags;
                        break;
                    case "#":
                        privateNameTempFlags = flags;
                        break;
                    default:
                        formattedNameTempFlags ?? (formattedNameTempFlags = /* @__PURE__ */ new Map());
                        formattedNameTempFlags.set(formattedNameKey, flags);
                        break;
                }
            }
            function makeTempVariableName(flags, reservedInNestedScopes, privateName, prefix, suffix) {
                if (prefix.length > 0 && prefix.charCodeAt(0) === 35 /* hash */) {
                    prefix = prefix.slice(1);
                }
                const key = formatGeneratedName(privateName, prefix, "", suffix);
                let tempFlags2 = getTempFlags(key);
                if (flags && !(tempFlags2 & flags)) {
                    const name = flags === 268435456 /* _i */ ? "_i" : "_n";
                    const fullName = formatGeneratedName(privateName, prefix, name, suffix);
                    if (isUniqueName(fullName, privateName)) {
                        tempFlags2 |= flags;
                        if (privateName) {
                            reservePrivateNameInNestedScopes(fullName);
                        }
                        else if (reservedInNestedScopes) {
                            reserveNameInNestedScopes(fullName);
                        }
                        setTempFlags(key, tempFlags2);
                        return fullName;
                    }
                }
                while (true) {
                    const count = tempFlags2 & 268435455 /* CountMask */;
                    tempFlags2++;
                    if (count !== 8 && count !== 13) {
                        const name = count < 26 ? "_" + String.fromCharCode(97 /* a */ + count) : "_" + (count - 26);
                        const fullName = formatGeneratedName(privateName, prefix, name, suffix);
                        if (isUniqueName(fullName, privateName)) {
                            if (privateName) {
                                reservePrivateNameInNestedScopes(fullName);
                            }
                            else if (reservedInNestedScopes) {
                                reserveNameInNestedScopes(fullName);
                            }
                            setTempFlags(key, tempFlags2);
                            return fullName;
                        }
                    }
                }
            }
            function makeUniqueName2(baseName, checkFn = isUniqueName, optimistic, scoped, privateName, prefix, suffix) {
                if (baseName.length > 0 && baseName.charCodeAt(0) === 35 /* hash */) {
                    baseName = baseName.slice(1);
                }
                if (prefix.length > 0 && prefix.charCodeAt(0) === 35 /* hash */) {
                    prefix = prefix.slice(1);
                }
                if (optimistic) {
                    const fullName = formatGeneratedName(privateName, prefix, baseName, suffix);
                    if (checkFn(fullName, privateName)) {
                        if (privateName) {
                            reservePrivateNameInNestedScopes(fullName);
                        }
                        else if (scoped) {
                            reserveNameInNestedScopes(fullName);
                        }
                        else {
                            generatedNames.add(fullName);
                        }
                        return fullName;
                    }
                }
                if (baseName.charCodeAt(baseName.length - 1) !== 95 /* _ */) {
                    baseName += "_";
                }
                let i = 1;
                while (true) {
                    const fullName = formatGeneratedName(privateName, prefix, baseName + i, suffix);
                    if (checkFn(fullName, privateName)) {
                        if (privateName) {
                            reservePrivateNameInNestedScopes(fullName);
                        }
                        else if (scoped) {
                            reserveNameInNestedScopes(fullName);
                        }
                        else {
                            generatedNames.add(fullName);
                        }
                        return fullName;
                    }
                    i++;
                }
            }
            function makeFileLevelOptimisticUniqueName(name) {
                return makeUniqueName2(name, isFileLevelUniqueNameInCurrentFile, 
                /*optimistic*/
                true, 
                /*scoped*/
                false, 
                /*privateName*/
                false, 
                /*prefix*/
                "", 
                /*suffix*/
                "");
            }
            function generateNameForModuleOrEnum(node) {
                const name = getTextOfNode2(node.name);
                return isUniqueLocalName(name, tryCast(node, canHaveLocals)) ? name : makeUniqueName2(name, isUniqueName, 
                /*optimistic*/
                false, 
                /*scoped*/
                false, 
                /*privateName*/
                false, 
                /*prefix*/
                "", 
                /*suffix*/
                "");
            }
            function generateNameForImportOrExportDeclaration(node) {
                const expr = getExternalModuleName(node);
                const baseName = isStringLiteral(expr) ? makeIdentifierFromModuleName(expr.text) : "module";
                return makeUniqueName2(baseName, isUniqueName, 
                /*optimistic*/
                false, 
                /*scoped*/
                false, 
                /*privateName*/
                false, 
                /*prefix*/
                "", 
                /*suffix*/
                "");
            }
            function generateNameForExportDefault() {
                return makeUniqueName2("default", isUniqueName, 
                /*optimistic*/
                false, 
                /*scoped*/
                false, 
                /*privateName*/
                false, 
                /*prefix*/
                "", 
                /*suffix*/
                "");
            }
            function generateNameForClassExpression() {
                return makeUniqueName2("class", isUniqueName, 
                /*optimistic*/
                false, 
                /*scoped*/
                false, 
                /*privateName*/
                false, 
                /*prefix*/
                "", 
                /*suffix*/
                "");
            }
            function generateNameForMethodOrAccessor(node, privateName, prefix, suffix) {
                if (isIdentifier(node.name)) {
                    return generateNameCached(node.name, privateName);
                }
                return makeTempVariableName(0 /* Auto */, 
                /*reservedInNestedScopes*/
                false, privateName, prefix, suffix);
            }
            function generateNameForNode(node, privateName, flags, prefix, suffix) {
                switch (node.kind) {
                    case 80 /* Identifier */:
                    case 81 /* PrivateIdentifier */:
                        return makeUniqueName2(getTextOfNode2(node), isUniqueName, !!(flags & 16 /* Optimistic */), !!(flags & 8 /* ReservedInNestedScopes */), privateName, prefix, suffix);
                    case 267 /* ModuleDeclaration */:
                    case 266 /* EnumDeclaration */:
                        Debug.assert(!prefix && !suffix && !privateName);
                        return generateNameForModuleOrEnum(node);
                    case 272 /* ImportDeclaration */:
                    case 278 /* ExportDeclaration */:
                        Debug.assert(!prefix && !suffix && !privateName);
                        return generateNameForImportOrExportDeclaration(node);
                    case 262 /* FunctionDeclaration */:
                    case 263 /* ClassDeclaration */: {
                        Debug.assert(!prefix && !suffix && !privateName);
                        const name = node.name;
                        if (name && !isGeneratedIdentifier(name)) {
                            return generateNameForNode(name, 
                            /*privateName*/
                            false, flags, prefix, suffix);
                        }
                        return generateNameForExportDefault();
                    }
                    case 277 /* ExportAssignment */:
                        Debug.assert(!prefix && !suffix && !privateName);
                        return generateNameForExportDefault();
                    case 231 /* ClassExpression */:
                        Debug.assert(!prefix && !suffix && !privateName);
                        return generateNameForClassExpression();
                    case 174 /* MethodDeclaration */:
                    case 177 /* GetAccessor */:
                    case 178 /* SetAccessor */:
                        return generateNameForMethodOrAccessor(node, privateName, prefix, suffix);
                    case 167 /* ComputedPropertyName */:
                        return makeTempVariableName(0 /* Auto */, 
                        /*reservedInNestedScopes*/
                        true, privateName, prefix, suffix);
                    default:
                        return makeTempVariableName(0 /* Auto */, 
                        /*reservedInNestedScopes*/
                        false, privateName, prefix, suffix);
                }
            }
            function makeName(name) {
                const autoGenerate = name.emitNode.autoGenerate;
                const prefix = formatGeneratedNamePart(autoGenerate.prefix, generateName);
                const suffix = formatGeneratedNamePart(autoGenerate.suffix);
                switch (autoGenerate.flags & 7 /* KindMask */) {
                    case 1 /* Auto */:
                        return makeTempVariableName(0 /* Auto */, !!(autoGenerate.flags & 8 /* ReservedInNestedScopes */), isPrivateIdentifier(name), prefix, suffix);
                    case 2 /* Loop */:
                        Debug.assertNode(name, isIdentifier);
                        return makeTempVariableName(268435456 /* _i */, !!(autoGenerate.flags & 8 /* ReservedInNestedScopes */), 
                        /*privateName*/
                        false, prefix, suffix);
                    case 3 /* Unique */:
                        return makeUniqueName2(idText(name), autoGenerate.flags & 32 /* FileLevel */ ? isFileLevelUniqueNameInCurrentFile : isUniqueName, !!(autoGenerate.flags & 16 /* Optimistic */), !!(autoGenerate.flags & 8 /* ReservedInNestedScopes */), isPrivateIdentifier(name), prefix, suffix);
                }
                return Debug.fail(`Unsupported GeneratedIdentifierKind: ${Debug.formatEnum(autoGenerate.flags & 7 /* KindMask */, GeneratedIdentifierFlags, 
                /*isFlags*/
                true)}.`);
            }
            function pipelineEmitWithComments(hint, node) {
                const pipelinePhase = getNextPipelinePhase(2 /* Comments */, hint, node);
                const savedContainerPos = containerPos;
                const savedContainerEnd = containerEnd;
                const savedDeclarationListContainerEnd = declarationListContainerEnd;
                emitCommentsBeforeNode(node);
                pipelinePhase(hint, node);
                emitCommentsAfterNode(node, savedContainerPos, savedContainerEnd, savedDeclarationListContainerEnd);
            }
            function emitCommentsBeforeNode(node) {
                const emitFlags = getEmitFlags(node);
                const commentRange = getCommentRange(node);
                emitLeadingCommentsOfNode(node, emitFlags, commentRange.pos, commentRange.end);
                if (emitFlags & 4096 /* NoNestedComments */) {
                    commentsDisabled = true;
                }
            }
            function emitCommentsAfterNode(node, savedContainerPos, savedContainerEnd, savedDeclarationListContainerEnd) {
                const emitFlags = getEmitFlags(node);
                const commentRange = getCommentRange(node);
                if (emitFlags & 4096 /* NoNestedComments */) {
                    commentsDisabled = false;
                }
                emitTrailingCommentsOfNode(node, emitFlags, commentRange.pos, commentRange.end, savedContainerPos, savedContainerEnd, savedDeclarationListContainerEnd);
                const typeNode = getTypeNode(node);
                if (typeNode) {
                    emitTrailingCommentsOfNode(node, emitFlags, typeNode.pos, typeNode.end, savedContainerPos, savedContainerEnd, savedDeclarationListContainerEnd);
                }
            }
            function emitLeadingCommentsOfNode(node, emitFlags, pos, end) {
                enterComment();
                hasWrittenComment = false;
                const skipLeadingComments = pos < 0 || (emitFlags & 1024 /* NoLeadingComments */) !== 0 || node.kind === 12 /* JsxText */;
                const skipTrailingComments = end < 0 || (emitFlags & 2048 /* NoTrailingComments */) !== 0 || node.kind === 12 /* JsxText */;
                if ((pos > 0 || end > 0) && pos !== end) {
                    if (!skipLeadingComments) {
                        emitLeadingComments(pos, 
                        /*isEmittedNode*/
                        node.kind !== 359 /* NotEmittedStatement */);
                    }
                    if (!skipLeadingComments || pos >= 0 && (emitFlags & 1024 /* NoLeadingComments */) !== 0) {
                        containerPos = pos;
                    }
                    if (!skipTrailingComments || end >= 0 && (emitFlags & 2048 /* NoTrailingComments */) !== 0) {
                        containerEnd = end;
                        if (node.kind === 261 /* VariableDeclarationList */) {
                            declarationListContainerEnd = end;
                        }
                    }
                }
                forEach(getSyntheticLeadingComments(node), emitLeadingSynthesizedComment);
                exitComment();
            }
            function emitTrailingCommentsOfNode(node, emitFlags, pos, end, savedContainerPos, savedContainerEnd, savedDeclarationListContainerEnd) {
                enterComment();
                const skipTrailingComments = end < 0 || (emitFlags & 2048 /* NoTrailingComments */) !== 0 || node.kind === 12 /* JsxText */;
                forEach(getSyntheticTrailingComments(node), emitTrailingSynthesizedComment);
                if ((pos > 0 || end > 0) && pos !== end) {
                    containerPos = savedContainerPos;
                    containerEnd = savedContainerEnd;
                    declarationListContainerEnd = savedDeclarationListContainerEnd;
                    if (!skipTrailingComments && node.kind !== 359 /* NotEmittedStatement */) {
                        emitTrailingComments(end);
                    }
                }
                exitComment();
            }
            function emitLeadingSynthesizedComment(comment) {
                if (comment.hasLeadingNewline || comment.kind === 2 /* SingleLineCommentTrivia */) {
                    writer.writeLine();
                }
                writeSynthesizedComment(comment);
                if (comment.hasTrailingNewLine || comment.kind === 2 /* SingleLineCommentTrivia */) {
                    writer.writeLine();
                }
                else {
                    writer.writeSpace(" ");
                }
            }
            function emitTrailingSynthesizedComment(comment) {
                if (!writer.isAtStartOfLine()) {
                    writer.writeSpace(" ");
                }
                writeSynthesizedComment(comment);
                if (comment.hasTrailingNewLine) {
                    writer.writeLine();
                }
            }
            function writeSynthesizedComment(comment) {
                const text = formatSynthesizedComment(comment);
                const lineMap = comment.kind === 3 /* MultiLineCommentTrivia */ ? computeLineStarts(text) : void 0;
                writeCommentRange(text, lineMap, writer, 0, text.length, newLine);
            }
            function formatSynthesizedComment(comment) {
                return comment.kind === 3 /* MultiLineCommentTrivia */ ? `/*${comment.text}*/` : `//${comment.text}`;
            }
            function emitBodyWithDetachedComments(node, detachedRange, emitCallback) {
                enterComment();
                const { pos, end } = detachedRange;
                const emitFlags = getEmitFlags(node);
                const skipLeadingComments = pos < 0 || (emitFlags & 1024 /* NoLeadingComments */) !== 0;
                const skipTrailingComments = commentsDisabled || end < 0 || (emitFlags & 2048 /* NoTrailingComments */) !== 0;
                if (!skipLeadingComments) {
                    emitDetachedCommentsAndUpdateCommentsInfo(detachedRange);
                }
                exitComment();
                if (emitFlags & 4096 /* NoNestedComments */ && !commentsDisabled) {
                    commentsDisabled = true;
                    emitCallback(node);
                    commentsDisabled = false;
                }
                else {
                    emitCallback(node);
                }
                enterComment();
                if (!skipTrailingComments) {
                    emitLeadingComments(detachedRange.end, 
                    /*isEmittedNode*/
                    true);
                    if (hasWrittenComment && !writer.isAtStartOfLine()) {
                        writer.writeLine();
                    }
                }
                exitComment();
            }
            function originalNodesHaveSameParent(nodeA, nodeB) {
                nodeA = getOriginalNode(nodeA);
                return nodeA.parent && nodeA.parent === getOriginalNode(nodeB).parent;
            }
            function siblingNodePositionsAreComparable(previousNode, nextNode) {
                if (nextNode.pos < previousNode.end) {
                    return false;
                }
                previousNode = getOriginalNode(previousNode);
                nextNode = getOriginalNode(nextNode);
                const parent2 = previousNode.parent;
                if (!parent2 || parent2 !== nextNode.parent) {
                    return false;
                }
                const parentNodeArray = getContainingNodeArray(previousNode);
                const prevNodeIndex = parentNodeArray == null ? void 0 : parentNodeArray.indexOf(previousNode);
                return prevNodeIndex !== void 0 && prevNodeIndex > -1 && parentNodeArray.indexOf(nextNode) === prevNodeIndex + 1;
            }
            function emitLeadingComments(pos, isEmittedNode) {
                hasWrittenComment = false;
                if (isEmittedNode) {
                    if (pos === 0 && (currentSourceFile == null ? void 0 : currentSourceFile.isDeclarationFile)) {
                        forEachLeadingCommentToEmit(pos, emitNonTripleSlashLeadingComment);
                    }
                    else {
                        forEachLeadingCommentToEmit(pos, emitLeadingComment);
                    }
                }
                else if (pos === 0) {
                    forEachLeadingCommentToEmit(pos, emitTripleSlashLeadingComment);
                }
            }
            function emitTripleSlashLeadingComment(commentPos, commentEnd, kind, hasTrailingNewLine, rangePos) {
                if (isTripleSlashComment(commentPos, commentEnd)) {
                    emitLeadingComment(commentPos, commentEnd, kind, hasTrailingNewLine, rangePos);
                }
            }
            function emitNonTripleSlashLeadingComment(commentPos, commentEnd, kind, hasTrailingNewLine, rangePos) {
                if (!isTripleSlashComment(commentPos, commentEnd)) {
                    emitLeadingComment(commentPos, commentEnd, kind, hasTrailingNewLine, rangePos);
                }
            }
            function shouldWriteComment(text, pos) {
                if (printerOptions.onlyPrintJsDocStyle) {
                    return isJSDocLikeText(text, pos) || isPinnedComment(text, pos);
                }
                return true;
            }
            function emitLeadingComment(commentPos, commentEnd, kind, hasTrailingNewLine, rangePos) {
                if (!currentSourceFile || !shouldWriteComment(currentSourceFile.text, commentPos))
                    return;
                if (!hasWrittenComment) {
                    emitNewLineBeforeLeadingCommentOfPosition(getCurrentLineMap(), writer, rangePos, commentPos);
                    hasWrittenComment = true;
                }
                emitPos(commentPos);
                writeCommentRange(currentSourceFile.text, getCurrentLineMap(), writer, commentPos, commentEnd, newLine);
                emitPos(commentEnd);
                if (hasTrailingNewLine) {
                    writer.writeLine();
                }
                else if (kind === 3 /* MultiLineCommentTrivia */) {
                    writer.writeSpace(" ");
                }
            }
            function emitLeadingCommentsOfPosition(pos) {
                if (commentsDisabled || pos === -1) {
                    return;
                }
                emitLeadingComments(pos, 
                /*isEmittedNode*/
                true);
            }
            function emitTrailingComments(pos) {
                forEachTrailingCommentToEmit(pos, emitTrailingComment);
            }
            function emitTrailingComment(commentPos, commentEnd, _kind, hasTrailingNewLine) {
                if (!currentSourceFile || !shouldWriteComment(currentSourceFile.text, commentPos))
                    return;
                if (!writer.isAtStartOfLine()) {
                    writer.writeSpace(" ");
                }
                emitPos(commentPos);
                writeCommentRange(currentSourceFile.text, getCurrentLineMap(), writer, commentPos, commentEnd, newLine);
                emitPos(commentEnd);
                if (hasTrailingNewLine) {
                    writer.writeLine();
                }
            }
            function emitTrailingCommentsOfPosition(pos, prefixSpace, forceNoNewline) {
                if (commentsDisabled) {
                    return;
                }
                enterComment();
                forEachTrailingCommentToEmit(pos, prefixSpace ? emitTrailingComment : forceNoNewline ? emitTrailingCommentOfPositionNoNewline : emitTrailingCommentOfPosition);
                exitComment();
            }
            function emitTrailingCommentOfPositionNoNewline(commentPos, commentEnd, kind) {
                if (!currentSourceFile)
                    return;
                emitPos(commentPos);
                writeCommentRange(currentSourceFile.text, getCurrentLineMap(), writer, commentPos, commentEnd, newLine);
                emitPos(commentEnd);
                if (kind === 2 /* SingleLineCommentTrivia */) {
                    writer.writeLine();
                }
            }
            function emitTrailingCommentOfPosition(commentPos, commentEnd, _kind, hasTrailingNewLine) {
                if (!currentSourceFile)
                    return;
                emitPos(commentPos);
                writeCommentRange(currentSourceFile.text, getCurrentLineMap(), writer, commentPos, commentEnd, newLine);
                emitPos(commentEnd);
                if (hasTrailingNewLine) {
                    writer.writeLine();
                }
                else {
                    writer.writeSpace(" ");
                }
            }
            function forEachLeadingCommentToEmit(pos, cb) {
                if (currentSourceFile && (containerPos === -1 || pos !== containerPos)) {
                    if (hasDetachedComments(pos)) {
                        forEachLeadingCommentWithoutDetachedComments(cb);
                    }
                    else {
                        forEachLeadingCommentRange(currentSourceFile.text, pos, cb, 
                        /*state*/
                        pos);
                    }
                }
            }
            function forEachTrailingCommentToEmit(end, cb) {
                if (currentSourceFile && (containerEnd === -1 || end !== containerEnd && end !== declarationListContainerEnd)) {
                    forEachTrailingCommentRange(currentSourceFile.text, end, cb);
                }
            }
            function hasDetachedComments(pos) {
                return detachedCommentsInfo !== void 0 && last(detachedCommentsInfo).nodePos === pos;
            }
            function forEachLeadingCommentWithoutDetachedComments(cb) {
                if (!currentSourceFile)
                    return;
                const pos = last(detachedCommentsInfo).detachedCommentEndPos;
                if (detachedCommentsInfo.length - 1) {
                    detachedCommentsInfo.pop();
                }
                else {
                    detachedCommentsInfo = void 0;
                }
                forEachLeadingCommentRange(currentSourceFile.text, pos, cb, 
                /*state*/
                pos);
            }
            function emitDetachedCommentsAndUpdateCommentsInfo(range) {
                const currentDetachedCommentInfo = currentSourceFile && emitDetachedComments(currentSourceFile.text, getCurrentLineMap(), writer, emitComment, range, newLine, commentsDisabled);
                if (currentDetachedCommentInfo) {
                    if (detachedCommentsInfo) {
                        detachedCommentsInfo.push(currentDetachedCommentInfo);
                    }
                    else {
                        detachedCommentsInfo = [currentDetachedCommentInfo];
                    }
                }
            }
            function emitComment(text, lineMap, writer2, commentPos, commentEnd, newLine2) {
                if (!currentSourceFile || !shouldWriteComment(currentSourceFile.text, commentPos))
                    return;
                emitPos(commentPos);
                writeCommentRange(text, lineMap, writer2, commentPos, commentEnd, newLine2);
                emitPos(commentEnd);
            }
            function isTripleSlashComment(commentPos, commentEnd) {
                return !!currentSourceFile && isRecognizedTripleSlashComment(currentSourceFile.text, commentPos, commentEnd);
            }
            function getParsedSourceMap(node) {
                if (node.parsedSourceMap === void 0 && node.sourceMapText !== void 0) {
                    node.parsedSourceMap = tryParseRawSourceMap(node.sourceMapText) || false;
                }
                return node.parsedSourceMap || void 0;
            }
            function pipelineEmitWithSourceMaps(hint, node) {
                const pipelinePhase = getNextPipelinePhase(3 /* SourceMaps */, hint, node);
                emitSourceMapsBeforeNode(node);
                pipelinePhase(hint, node);
                emitSourceMapsAfterNode(node);
            }
            function emitSourceMapsBeforeNode(node) {
                const emitFlags = getEmitFlags(node);
                const sourceMapRange = getSourceMapRange(node);
                if (isUnparsedNode(node)) {
                    Debug.assertIsDefined(node.parent, "UnparsedNodes must have parent pointers");
                    const parsed = getParsedSourceMap(node.parent);
                    if (parsed && sourceMapGenerator) {
                        sourceMapGenerator.appendSourceMap(writer.getLine(), writer.getColumn(), parsed, node.parent.sourceMapPath, node.parent.getLineAndCharacterOfPosition(node.pos), node.parent.getLineAndCharacterOfPosition(node.end));
                    }
                }
                else {
                    const source = sourceMapRange.source || sourceMapSource;
                    if (node.kind !== 359 /* NotEmittedStatement */ && (emitFlags & 32 /* NoLeadingSourceMap */) === 0 && sourceMapRange.pos >= 0) {
                        emitSourcePos(sourceMapRange.source || sourceMapSource, skipSourceTrivia(source, sourceMapRange.pos));
                    }
                    if (emitFlags & 128 /* NoNestedSourceMaps */) {
                        sourceMapsDisabled = true;
                    }
                }
            }
            function emitSourceMapsAfterNode(node) {
                const emitFlags = getEmitFlags(node);
                const sourceMapRange = getSourceMapRange(node);
                if (!isUnparsedNode(node)) {
                    if (emitFlags & 128 /* NoNestedSourceMaps */) {
                        sourceMapsDisabled = false;
                    }
                    if (node.kind !== 359 /* NotEmittedStatement */ && (emitFlags & 64 /* NoTrailingSourceMap */) === 0 && sourceMapRange.end >= 0) {
                        emitSourcePos(sourceMapRange.source || sourceMapSource, sourceMapRange.end);
                    }
                }
            }
            function skipSourceTrivia(source, pos) {
                return source.skipTrivia ? source.skipTrivia(pos) : skipTrivia(source.text, pos);
            }
            function emitPos(pos) {
                if (sourceMapsDisabled || positionIsSynthesized(pos) || isJsonSourceMapSource(sourceMapSource)) {
                    return;
                }
                const { line: sourceLine, character: sourceCharacter } = getLineAndCharacterOfPosition(sourceMapSource, pos);
                sourceMapGenerator.addMapping(writer.getLine(), writer.getColumn(), sourceMapSourceIndex, sourceLine, sourceCharacter, 
                /*nameIndex*/
                void 0);
            }
            function emitSourcePos(source, pos) {
                if (source !== sourceMapSource) {
                    const savedSourceMapSource = sourceMapSource;
                    const savedSourceMapSourceIndex = sourceMapSourceIndex;
                    setSourceMapSource(source);
                    emitPos(pos);
                    resetSourceMapSource(savedSourceMapSource, savedSourceMapSourceIndex);
                }
                else {
                    emitPos(pos);
                }
            }
            function emitTokenWithSourceMap(node, token, writer2, tokenPos, emitCallback) {
                if (sourceMapsDisabled || node && isInJsonFile(node)) {
                    return emitCallback(token, writer2, tokenPos);
                }
                const emitNode = node && node.emitNode;
                const emitFlags = emitNode && emitNode.flags || 0 /* None */;
                const range = emitNode && emitNode.tokenSourceMapRanges && emitNode.tokenSourceMapRanges[token];
                const source = range && range.source || sourceMapSource;
                tokenPos = skipSourceTrivia(source, range ? range.pos : tokenPos);
                if ((emitFlags & 256 /* NoTokenLeadingSourceMaps */) === 0 && tokenPos >= 0) {
                    emitSourcePos(source, tokenPos);
                }
                tokenPos = emitCallback(token, writer2, tokenPos);
                if (range)
                    tokenPos = range.end;
                if ((emitFlags & 512 /* NoTokenTrailingSourceMaps */) === 0 && tokenPos >= 0) {
                    emitSourcePos(source, tokenPos);
                }
                return tokenPos;
            }
            function setSourceMapSource(source) {
                if (sourceMapsDisabled) {
                    return;
                }
                sourceMapSource = source;
                if (source === mostRecentlyAddedSourceMapSource) {
                    sourceMapSourceIndex = mostRecentlyAddedSourceMapSourceIndex;
                    return;
                }
                if (isJsonSourceMapSource(source)) {
                    return;
                }
                sourceMapSourceIndex = sourceMapGenerator.addSource(source.fileName);
                if (printerOptions.inlineSources) {
                    sourceMapGenerator.setSourceContent(sourceMapSourceIndex, source.text);
                }
                mostRecentlyAddedSourceMapSource = source;
                mostRecentlyAddedSourceMapSourceIndex = sourceMapSourceIndex;
            }
            function resetSourceMapSource(source, sourceIndex) {
                sourceMapSource = source;
                sourceMapSourceIndex = sourceIndex;
            }
            function isJsonSourceMapSource(sourceFile) {
                return fileExtensionIs(sourceFile.fileName, ".json" /* Json */);
            }
        }
        function createBracketsMap() {
            const brackets2 = [];
            brackets2[1024 /* Braces */] = ["{", "}"];
            brackets2[2048 /* Parenthesis */] = ["(", ")"];
            brackets2[4096 /* AngleBrackets */] = ["<", ">"];
            brackets2[8192 /* SquareBrackets */] = ["[", "]"];
            return brackets2;
        }
        function getOpeningBracket(format) {
            return brackets[format & 15360 /* BracketsMask */][0];
        }
        function getClosingBracket(format) {
            return brackets[format & 15360 /* BracketsMask */][1];
        }
        function emitListItemNoParenthesizer(node, emit, _parenthesizerRule, _index) {
            emit(node);
        }
        function emitListItemWithParenthesizerRuleSelector(node, emit, parenthesizerRuleSelector, index) {
            emit(node, parenthesizerRuleSelector.select(index));
        }
        function emitListItemWithParenthesizerRule(node, emit, parenthesizerRule, _index) {
            emit(node, parenthesizerRule);
        }
        function getEmitListItem(emit, parenthesizerRule) {
            return emit.length === 1 ? emitListItemNoParenthesizer : typeof parenthesizerRule === "object" ? emitListItemWithParenthesizerRuleSelector : emitListItemWithParenthesizerRule;
        }
        var brackets, notImplementedResolver, createPrinterWithDefaults, createPrinterWithRemoveComments, createPrinterWithRemoveCommentsNeverAsciiEscape, createPrinterWithRemoveCommentsOmitTrailingSemicolon;
        var init_emitter = __esm({
            "src/compiler/emitter.ts"() {
                "use strict";
                init_ts2();
                init_ts2();
                init_ts_performance();
                brackets = createBracketsMap();
                notImplementedResolver = {
                    hasGlobalName: notImplemented,
                    getReferencedExportContainer: notImplemented,
                    getReferencedImportDeclaration: notImplemented,
                    getReferencedDeclarationWithCollidingName: notImplemented,
                    isDeclarationWithCollidingName: notImplemented,
                    isValueAliasDeclaration: notImplemented,
                    isReferencedAliasDeclaration: notImplemented,
                    isTopLevelValueImportEqualsWithEntityName: notImplemented,
                    getNodeCheckFlags: notImplemented,
                    isDeclarationVisible: notImplemented,
                    isLateBound: (_node) => false,
                    collectLinkedAliases: notImplemented,
                    isImplementationOfOverload: notImplemented,
                    isRequiredInitializedParameter: notImplemented,
                    isOptionalUninitializedParameterProperty: notImplemented,
                    isExpandoFunctionDeclaration: notImplemented,
                    getPropertiesOfContainerFunction: notImplemented,
                    createTypeOfDeclaration: notImplemented,
                    createReturnTypeOfSignatureDeclaration: notImplemented,
                    createTypeOfExpression: notImplemented,
                    createLiteralConstValue: notImplemented,
                    isSymbolAccessible: notImplemented,
                    isEntityNameVisible: notImplemented,
                    // Returns the constant value this property access resolves to: notImplemented, or 'undefined' for a non-constant
                    getConstantValue: notImplemented,
                    getReferencedValueDeclaration: notImplemented,
                    getReferencedValueDeclarations: notImplemented,
                    getTypeReferenceSerializationKind: notImplemented,
                    isOptionalParameter: notImplemented,
                    moduleExportsSomeValue: notImplemented,
                    isArgumentsLocalBinding: notImplemented,
                    getExternalModuleFileFromDeclaration: notImplemented,
                    getTypeReferenceDirectivesForEntityName: notImplemented,
                    getTypeReferenceDirectivesForSymbol: notImplemented,
                    isLiteralConstDeclaration: notImplemented,
                    getJsxFactoryEntity: notImplemented,
                    getJsxFragmentFactoryEntity: notImplemented,
                    getAllAccessorDeclarations: notImplemented,
                    getSymbolOfExternalModuleSpecifier: notImplemented,
                    isBindingCapturedByNode: notImplemented,
                    getDeclarationStatementsForSourceFile: notImplemented,
                    isImportRequiredByAugmentation: notImplemented,
                    tryFindAmbientModule: notImplemented
                };
                createPrinterWithDefaults = /* @__PURE__ */ memoize(() => createPrinter({}));
                createPrinterWithRemoveComments = /* @__PURE__ */ memoize(() => createPrinter({ removeComments: true }));
                createPrinterWithRemoveCommentsNeverAsciiEscape = /* @__PURE__ */ memoize(() => createPrinter({ removeComments: true, neverAsciiEscape: true }));
                createPrinterWithRemoveCommentsOmitTrailingSemicolon = /* @__PURE__ */ memoize(() => createPrinter({ removeComments: true, omitTrailingSemicolon: true }));
            }
        });
        // src/compiler/watchUtilities.ts
        function createCachedDirectoryStructureHost(host, currentDirectory, useCaseSensitiveFileNames2) {
            if (!host.getDirectories || !host.readDirectory) {
                return void 0;
            }
            const cachedReadDirectoryResult = /* @__PURE__ */ new Map();
            const getCanonicalFileName = createGetCanonicalFileName(useCaseSensitiveFileNames2);
            return {
                useCaseSensitiveFileNames: useCaseSensitiveFileNames2,
                fileExists,
                readFile: (path, encoding) => host.readFile(path, encoding),
                directoryExists: host.directoryExists && directoryExists,
                getDirectories,
                readDirectory,
                createDirectory: host.createDirectory && createDirectory,
                writeFile: host.writeFile && writeFile2,
                addOrDeleteFileOrDirectory,
                addOrDeleteFile,
                clearCache,
                realpath: host.realpath && realpath
            };
            function toPath3(fileName) {
                return toPath(fileName, currentDirectory, getCanonicalFileName);
            }
            function getCachedFileSystemEntries(rootDirPath) {
                return cachedReadDirectoryResult.get(ensureTrailingDirectorySeparator(rootDirPath));
            }
            function getCachedFileSystemEntriesForBaseDir(path) {
                const entries = getCachedFileSystemEntries(getDirectoryPath(path));
                if (!entries) {
                    return entries;
                }
                if (!entries.sortedAndCanonicalizedFiles) {
                    entries.sortedAndCanonicalizedFiles = entries.files.map(getCanonicalFileName).sort();
                    entries.sortedAndCanonicalizedDirectories = entries.directories.map(getCanonicalFileName).sort();
                }
                return entries;
            }
            function getBaseNameOfFileName(fileName) {
                return getBaseFileName(normalizePath(fileName));
            }
            function createCachedFileSystemEntries(rootDir, rootDirPath) {
                var _a;
                if (!host.realpath || ensureTrailingDirectorySeparator(toPath3(host.realpath(rootDir))) === rootDirPath) {
                    const resultFromHost = {
                        files: map(host.readDirectory(rootDir, 
                        /*extensions*/
                        void 0, 
                        /*exclude*/
                        void 0, 
                        /*include*/
                        ["*.*"]), getBaseNameOfFileName) || [],
                        directories: host.getDirectories(rootDir) || []
                    };
                    cachedReadDirectoryResult.set(ensureTrailingDirectorySeparator(rootDirPath), resultFromHost);
                    return resultFromHost;
                }
                if ((_a = host.directoryExists) == null ? void 0 : _a.call(host, rootDir)) {
                    cachedReadDirectoryResult.set(rootDirPath, false);
                    return false;
                }
                return void 0;
            }
            function tryReadDirectory2(rootDir, rootDirPath) {
                rootDirPath = ensureTrailingDirectorySeparator(rootDirPath);
                const cachedResult = getCachedFileSystemEntries(rootDirPath);
                if (cachedResult) {
                    return cachedResult;
                }
                try {
                    return createCachedFileSystemEntries(rootDir, rootDirPath);
                }
                catch (_e) {
                    Debug.assert(!cachedReadDirectoryResult.has(ensureTrailingDirectorySeparator(rootDirPath)));
                    return void 0;
                }
            }
            function hasEntry(entries, name) {
                const index = binarySearch(entries, name, identity, compareStringsCaseSensitive);
                return index >= 0;
            }
            function writeFile2(fileName, data, writeByteOrderMark) {
                const path = toPath3(fileName);
                const result = getCachedFileSystemEntriesForBaseDir(path);
                if (result) {
                    updateFilesOfFileSystemEntry(result, getBaseNameOfFileName(fileName), 
                    /*fileExists*/
                    true);
                }
                return host.writeFile(fileName, data, writeByteOrderMark);
            }
            function fileExists(fileName) {
                const path = toPath3(fileName);
                const result = getCachedFileSystemEntriesForBaseDir(path);
                return result && hasEntry(result.sortedAndCanonicalizedFiles, getCanonicalFileName(getBaseNameOfFileName(fileName))) || host.fileExists(fileName);
            }
            function directoryExists(dirPath) {
                const path = toPath3(dirPath);
                return cachedReadDirectoryResult.has(ensureTrailingDirectorySeparator(path)) || host.directoryExists(dirPath);
            }
            function createDirectory(dirPath) {
                const path = toPath3(dirPath);
                const result = getCachedFileSystemEntriesForBaseDir(path);
                if (result) {
                    const baseName = getBaseNameOfFileName(dirPath);
                    const canonicalizedBaseName = getCanonicalFileName(baseName);
                    const canonicalizedDirectories = result.sortedAndCanonicalizedDirectories;
                    if (insertSorted(canonicalizedDirectories, canonicalizedBaseName, compareStringsCaseSensitive)) {
                        result.directories.push(baseName);
                    }
                }
                host.createDirectory(dirPath);
            }
            function getDirectories(rootDir) {
                const rootDirPath = toPath3(rootDir);
                const result = tryReadDirectory2(rootDir, rootDirPath);
                if (result) {
                    return result.directories.slice();
                }
                return host.getDirectories(rootDir);
            }
            function readDirectory(rootDir, extensions, excludes, includes, depth) {
                const rootDirPath = toPath3(rootDir);
                const rootResult = tryReadDirectory2(rootDir, rootDirPath);
                let rootSymLinkResult;
                if (rootResult !== void 0) {
                    return matchFiles(rootDir, extensions, excludes, includes, useCaseSensitiveFileNames2, currentDirectory, depth, getFileSystemEntries, realpath);
                }
                return host.readDirectory(rootDir, extensions, excludes, includes, depth);
                function getFileSystemEntries(dir) {
                    const path = toPath3(dir);
                    if (path === rootDirPath) {
                        return rootResult || getFileSystemEntriesFromHost(dir, path);
                    }
                    const result = tryReadDirectory2(dir, path);
                    return result !== void 0 ? result || getFileSystemEntriesFromHost(dir, path) : emptyFileSystemEntries;
                }
                function getFileSystemEntriesFromHost(dir, path) {
                    if (rootSymLinkResult && path === rootDirPath)
                        return rootSymLinkResult;
                    const result = {
                        files: map(host.readDirectory(dir, 
                        /*extensions*/
                        void 0, 
                        /*exclude*/
                        void 0, 
                        /*include*/
                        ["*.*"]), getBaseNameOfFileName) || emptyArray,
                        directories: host.getDirectories(dir) || emptyArray
                    };
                    if (path === rootDirPath)
                        rootSymLinkResult = result;
                    return result;
                }
            }
            function realpath(s) {
                return host.realpath ? host.realpath(s) : s;
            }
            function addOrDeleteFileOrDirectory(fileOrDirectory, fileOrDirectoryPath) {
                const existingResult = getCachedFileSystemEntries(fileOrDirectoryPath);
                if (existingResult !== void 0) {
                    clearCache();
                    return void 0;
                }
                const parentResult = getCachedFileSystemEntriesForBaseDir(fileOrDirectoryPath);
                if (!parentResult) {
                    return void 0;
                }
                if (!host.directoryExists) {
                    clearCache();
                    return void 0;
                }
                const baseName = getBaseNameOfFileName(fileOrDirectory);
                const fsQueryResult = {
                    fileExists: host.fileExists(fileOrDirectory),
                    directoryExists: host.directoryExists(fileOrDirectory)
                };
                if (fsQueryResult.directoryExists || hasEntry(parentResult.sortedAndCanonicalizedDirectories, getCanonicalFileName(baseName))) {
                    clearCache();
                }
                else {
                    updateFilesOfFileSystemEntry(parentResult, baseName, fsQueryResult.fileExists);
                }
                return fsQueryResult;
            }
            function addOrDeleteFile(fileName, filePath, eventKind) {
                if (eventKind === 1 /* Changed */) {
                    return;
                }
                const parentResult = getCachedFileSystemEntriesForBaseDir(filePath);
                if (parentResult) {
                    updateFilesOfFileSystemEntry(parentResult, getBaseNameOfFileName(fileName), eventKind === 0 /* Created */);
                }
            }
            function updateFilesOfFileSystemEntry(parentResult, baseName, fileExists2) {
                const canonicalizedFiles = parentResult.sortedAndCanonicalizedFiles;
                const canonicalizedBaseName = getCanonicalFileName(baseName);
                if (fileExists2) {
                    if (insertSorted(canonicalizedFiles, canonicalizedBaseName, compareStringsCaseSensitive)) {
                        parentResult.files.push(baseName);
                    }
                }
                else {
                    const sortedIndex = binarySearch(canonicalizedFiles, canonicalizedBaseName, identity, compareStringsCaseSensitive);
                    if (sortedIndex >= 0) {
                        canonicalizedFiles.splice(sortedIndex, 1);
                        const unsortedIndex = parentResult.files.findIndex((entry) => getCanonicalFileName(entry) === canonicalizedBaseName);
                        parentResult.files.splice(unsortedIndex, 1);
                    }
                }
            }
            function clearCache() {
                cachedReadDirectoryResult.clear();
            }
        }
        function updateSharedExtendedConfigFileWatcher(projectPath, options, extendedConfigFilesMap, createExtendedConfigFileWatch, toPath3) {
            var _a;
            const extendedConfigs = arrayToMap(((_a = options == null ? void 0 : options.configFile) == null ? void 0 : _a.extendedSourceFiles) || emptyArray, toPath3);
            extendedConfigFilesMap.forEach((watcher, extendedConfigFilePath) => {
                if (!extendedConfigs.has(extendedConfigFilePath)) {
                    watcher.projects.delete(projectPath);
                    watcher.close();
                }
            });
            extendedConfigs.forEach((extendedConfigFileName, extendedConfigFilePath) => {
                const existing = extendedConfigFilesMap.get(extendedConfigFilePath);
                if (existing) {
                    existing.projects.add(projectPath);
                }
                else {
                    extendedConfigFilesMap.set(extendedConfigFilePath, {
                        projects: /* @__PURE__ */ new Set([projectPath]),
                        watcher: createExtendedConfigFileWatch(extendedConfigFileName, extendedConfigFilePath),
                        close: () => {
                            const existing2 = extendedConfigFilesMap.get(extendedConfigFilePath);
                            if (!existing2 || existing2.projects.size !== 0)
                                return;
                            existing2.watcher.close();
                            extendedConfigFilesMap.delete(extendedConfigFilePath);
                        }
                    });
                }
            });
        }
        function clearSharedExtendedConfigFileWatcher(projectPath, extendedConfigFilesMap) {
            extendedConfigFilesMap.forEach((watcher) => {
                if (watcher.projects.delete(projectPath))
                    watcher.close();
            });
        }
        function cleanExtendedConfigCache(extendedConfigCache, extendedConfigFilePath, toPath3) {
            if (!extendedConfigCache.delete(extendedConfigFilePath))
                return;
            extendedConfigCache.forEach(({ extendedResult }, key) => {
                var _a;
                if ((_a = extendedResult.extendedSourceFiles) == null ? void 0 : _a.some((extendedFile) => toPath3(extendedFile) === extendedConfigFilePath)) {
                    cleanExtendedConfigCache(extendedConfigCache, key, toPath3);
                }
            });
        }
        function updateMissingFilePathsWatch(program, missingFileWatches, createMissingFileWatch) {
            mutateMap(missingFileWatches, program.getMissingFilePaths(), {
                // Watch the missing files
                createNewValue: createMissingFileWatch,
                // Files that are no longer missing (e.g. because they are no longer required)
                // should no longer be watched.
                onDeleteValue: closeFileWatcher
            });
        }
        function updateWatchingWildcardDirectories(existingWatchedForWildcards, wildcardDirectories, watchDirectory) {
            if (wildcardDirectories) {
                mutateMap(existingWatchedForWildcards, new Map(Object.entries(wildcardDirectories)), {
                    // Create new watch and recursive info
                    createNewValue: createWildcardDirectoryWatcher,
                    // Close existing watch thats not needed any more
                    onDeleteValue: closeFileWatcherOf,
                    // Close existing watch that doesnt match in the flags
                    onExistingValue: updateWildcardDirectoryWatcher
                });
            }
            else {
                clearMap(existingWatchedForWildcards, closeFileWatcherOf);
            }
            function createWildcardDirectoryWatcher(directory, flags) {
                return {
                    watcher: watchDirectory(directory, flags),
                    flags
                };
            }
            function updateWildcardDirectoryWatcher(existingWatcher, flags, directory) {
                if (existingWatcher.flags === flags) {
                    return;
                }
                existingWatcher.watcher.close();
                existingWatchedForWildcards.set(directory, createWildcardDirectoryWatcher(directory, flags));
            }
        }
        function isIgnoredFileFromWildCardWatching({ watchedDirPath, fileOrDirectory, fileOrDirectoryPath, configFileName, options, program, extraFileExtensions, currentDirectory, useCaseSensitiveFileNames: useCaseSensitiveFileNames2, writeLog, toPath: toPath3, getScriptKind: getScriptKind2 }) {
            const newPath = removeIgnoredPath(fileOrDirectoryPath);
            if (!newPath) {
                writeLog(`Project: ${configFileName} Detected ignored path: ${fileOrDirectory}`);
                return true;
            }
            fileOrDirectoryPath = newPath;
            if (fileOrDirectoryPath === watchedDirPath)
                return false;
            if (hasExtension(fileOrDirectoryPath) && !(isSupportedSourceFileName(fileOrDirectory, options, extraFileExtensions) || isSupportedScriptKind())) {
                writeLog(`Project: ${configFileName} Detected file add/remove of non supported extension: ${fileOrDirectory}`);
                return true;
            }
            if (isExcludedFile(fileOrDirectory, options.configFile.configFileSpecs, getNormalizedAbsolutePath(getDirectoryPath(configFileName), currentDirectory), useCaseSensitiveFileNames2, currentDirectory)) {
                writeLog(`Project: ${configFileName} Detected excluded file: ${fileOrDirectory}`);
                return true;
            }
            if (!program)
                return false;
            if (outFile(options) || options.outDir)
                return false;
            if (isDeclarationFileName(fileOrDirectoryPath)) {
                if (options.declarationDir)
                    return false;
            }
            else if (!fileExtensionIsOneOf(fileOrDirectoryPath, supportedJSExtensionsFlat)) {
                return false;
            }
            const filePathWithoutExtension = removeFileExtension(fileOrDirectoryPath);
            const realProgram = isArray(program) ? void 0 : isBuilderProgram(program) ? program.getProgramOrUndefined() : program;
            const builderProgram = !realProgram && !isArray(program) ? program : void 0;
            if (hasSourceFile(filePathWithoutExtension + ".ts" /* Ts */) || hasSourceFile(filePathWithoutExtension + ".tsx" /* Tsx */)) {
                writeLog(`Project: ${configFileName} Detected output file: ${fileOrDirectory}`);
                return true;
            }
            return false;
            function hasSourceFile(file) {
                return realProgram ? !!realProgram.getSourceFileByPath(file) : builderProgram ? builderProgram.getState().fileInfos.has(file) : !!find(program, (rootFile) => toPath3(rootFile) === file);
            }
            function isSupportedScriptKind() {
                if (!getScriptKind2)
                    return false;
                const scriptKind = getScriptKind2(fileOrDirectory);
                switch (scriptKind) {
                    case 3 /* TS */:
                    case 4 /* TSX */:
                    case 7 /* Deferred */:
                    case 5 /* External */:
                        return true;
                    case 1 /* JS */:
                    case 2 /* JSX */:
                        return getAllowJSCompilerOption(options);
                    case 6 /* JSON */:
                        return getResolveJsonModule(options);
                    case 0 /* Unknown */:
                        return false;
                }
            }
        }
        function isBuilderProgram(program) {
            return !!program.getState;
        }
        function isEmittedFileOfProgram(program, file) {
            if (!program) {
                return false;
            }
            return program.isEmittedFile(file);
        }
        function getWatchFactory(host, watchLogLevel, log, getDetailWatchInfo2) {
            setSysLog(watchLogLevel === 2 /* Verbose */ ? log : noop);
            const plainInvokeFactory = {
                watchFile: (file, callback, pollingInterval, options) => host.watchFile(file, callback, pollingInterval, options),
                watchDirectory: (directory, callback, flags, options) => host.watchDirectory(directory, callback, (flags & 1 /* Recursive */) !== 0, options)
            };
            const triggerInvokingFactory = watchLogLevel !== 0 /* None */ ? {
                watchFile: createTriggerLoggingAddWatch("watchFile"),
                watchDirectory: createTriggerLoggingAddWatch("watchDirectory")
            } : void 0;
            const factory2 = watchLogLevel === 2 /* Verbose */ ? {
                watchFile: createFileWatcherWithLogging,
                watchDirectory: createDirectoryWatcherWithLogging
            } : triggerInvokingFactory || plainInvokeFactory;
            const excludeWatcherFactory = watchLogLevel === 2 /* Verbose */ ? createExcludeWatcherWithLogging : returnNoopFileWatcher;
            return {
                watchFile: createExcludeHandlingAddWatch("watchFile"),
                watchDirectory: createExcludeHandlingAddWatch("watchDirectory")
            };
            function createExcludeHandlingAddWatch(key) {
                return (file, cb, flags, options, detailInfo1, detailInfo2) => {
                    var _a;
                    return !matchesExclude(file, key === "watchFile" ? options == null ? void 0 : options.excludeFiles : options == null ? void 0 : options.excludeDirectories, useCaseSensitiveFileNames2(), ((_a = host.getCurrentDirectory) == null ? void 0 : _a.call(host)) || "") ? factory2[key].call(
                    /*thisArgs*/
                    void 0, file, cb, flags, options, detailInfo1, detailInfo2) : excludeWatcherFactory(file, flags, options, detailInfo1, detailInfo2);
                };
            }
            function useCaseSensitiveFileNames2() {
                return typeof host.useCaseSensitiveFileNames === "boolean" ? host.useCaseSensitiveFileNames : host.useCaseSensitiveFileNames();
            }
            function createExcludeWatcherWithLogging(file, flags, options, detailInfo1, detailInfo2) {
                log(`ExcludeWatcher:: Added:: ${getWatchInfo(file, flags, options, detailInfo1, detailInfo2, getDetailWatchInfo2)}`);
                return {
                    close: () => log(`ExcludeWatcher:: Close:: ${getWatchInfo(file, flags, options, detailInfo1, detailInfo2, getDetailWatchInfo2)}`)
                };
            }
            function createFileWatcherWithLogging(file, cb, flags, options, detailInfo1, detailInfo2) {
                log(`FileWatcher:: Added:: ${getWatchInfo(file, flags, options, detailInfo1, detailInfo2, getDetailWatchInfo2)}`);
                const watcher = triggerInvokingFactory.watchFile(file, cb, flags, options, detailInfo1, detailInfo2);
                return {
                    close: () => {
                        log(`FileWatcher:: Close:: ${getWatchInfo(file, flags, options, detailInfo1, detailInfo2, getDetailWatchInfo2)}`);
                        watcher.close();
                    }
                };
            }
            function createDirectoryWatcherWithLogging(file, cb, flags, options, detailInfo1, detailInfo2) {
                const watchInfo = `DirectoryWatcher:: Added:: ${getWatchInfo(file, flags, options, detailInfo1, detailInfo2, getDetailWatchInfo2)}`;
                log(watchInfo);
                const start = timestamp();
                const watcher = triggerInvokingFactory.watchDirectory(file, cb, flags, options, detailInfo1, detailInfo2);
                const elapsed = timestamp() - start;
                log(`Elapsed:: ${elapsed}ms ${watchInfo}`);
                return {
                    close: () => {
                        const watchInfo2 = `DirectoryWatcher:: Close:: ${getWatchInfo(file, flags, options, detailInfo1, detailInfo2, getDetailWatchInfo2)}`;
                        log(watchInfo2);
                        const start2 = timestamp();
                        watcher.close();
                        const elapsed2 = timestamp() - start2;
                        log(`Elapsed:: ${elapsed2}ms ${watchInfo2}`);
                    }
                };
            }
            function createTriggerLoggingAddWatch(key) {
                return (file, cb, flags, options, detailInfo1, detailInfo2) => plainInvokeFactory[key].call(
                /*thisArgs*/
                void 0, file, (...args) => {
                    const triggerredInfo = `${key === "watchFile" ? "FileWatcher" : "DirectoryWatcher"}:: Triggered with ${args[0]} ${args[1] !== void 0 ? args[1] : ""}:: ${getWatchInfo(file, flags, options, detailInfo1, detailInfo2, getDetailWatchInfo2)}`;
                    log(triggerredInfo);
                    const start = timestamp();
                    cb.call(
                    /*thisArg*/
                    void 0, ...args);
                    const elapsed = timestamp() - start;
                    log(`Elapsed:: ${elapsed}ms ${triggerredInfo}`);
                }, flags, options, detailInfo1, detailInfo2);
            }
            function getWatchInfo(file, flags, options, detailInfo1, detailInfo2, getDetailWatchInfo3) {
                return `WatchInfo: ${file} ${flags} ${JSON.stringify(options)} ${getDetailWatchInfo3 ? getDetailWatchInfo3(detailInfo1, detailInfo2) : detailInfo2 === void 0 ? detailInfo1 : `${detailInfo1} ${detailInfo2}`}`;
            }
        }
        function getFallbackOptions(options) {
            const fallbackPolling = options == null ? void 0 : options.fallbackPolling;
            return {
                watchFile: fallbackPolling !== void 0 ? fallbackPolling : 1 /* PriorityPollingInterval */
            };
        }
        function closeFileWatcherOf(objWithWatcher) {
            objWithWatcher.watcher.close();
        }
        var ProgramUpdateLevel, WatchLogLevel;
        var init_watchUtilities = __esm({
            "src/compiler/watchUtilities.ts"() {
                "use strict";
                init_ts2();
                ProgramUpdateLevel = /* @__PURE__ */ ((ProgramUpdateLevel2) => {
                    ProgramUpdateLevel2[ProgramUpdateLevel2["Update"] = 0] = "Update";
                    ProgramUpdateLevel2[ProgramUpdateLevel2["RootNamesAndUpdate"] = 1] = "RootNamesAndUpdate";
                    ProgramUpdateLevel2[ProgramUpdateLevel2["Full"] = 2] = "Full";
                    return ProgramUpdateLevel2;
                })(ProgramUpdateLevel || {});
                WatchLogLevel = /* @__PURE__ */ ((WatchLogLevel2) => {
                    WatchLogLevel2[WatchLogLevel2["None"] = 0] = "None";
                    WatchLogLevel2[WatchLogLevel2["TriggerOnly"] = 1] = "TriggerOnly";
                    WatchLogLevel2[WatchLogLevel2["Verbose"] = 2] = "Verbose";
                    return WatchLogLevel2;
                })(WatchLogLevel || {});
            }
        });
        // src/compiler/program.ts
        function findConfigFile(searchPath, fileExists, configName = "tsconfig.json") {
            return forEachAncestorDirectory(searchPath, (ancestor) => {
                const fileName = combinePaths(ancestor, configName);
                return fileExists(fileName) ? fileName : void 0;
            });
        }
        function resolveTripleslashReference(moduleName, containingFile) {
            const basePath = getDirectoryPath(containingFile);
            const referencedFileName = isRootedDiskPath(moduleName) ? moduleName : combinePaths(basePath, moduleName);
            return normalizePath(referencedFileName);
        }
        function computeCommonSourceDirectoryOfFilenames(fileNames, currentDirectory, getCanonicalFileName) {
            let commonPathComponents;
            const failed = forEach(fileNames, (sourceFile) => {
                const sourcePathComponents = getNormalizedPathComponents(sourceFile, currentDirectory);
                sourcePathComponents.pop();
                if (!commonPathComponents) {
                    commonPathComponents = sourcePathComponents;
                    return;
                }
                const n = Math.min(commonPathComponents.length, sourcePathComponents.length);
                for (let i = 0; i < n; i++) {
                    if (getCanonicalFileName(commonPathComponents[i]) !== getCanonicalFileName(sourcePathComponents[i])) {
                        if (i === 0) {
                            return true;
                        }
                        commonPathComponents.length = i;
                        break;
                    }
                }
                if (sourcePathComponents.length < commonPathComponents.length) {
                    commonPathComponents.length = sourcePathComponents.length;
                }
            });
            if (failed) {
                return "";
            }
            if (!commonPathComponents) {
                return currentDirectory;
            }
            return getPathFromPathComponents(commonPathComponents);
        }
        function createCompilerHost(options, setParentNodes) {
            return createCompilerHostWorker(options, setParentNodes);
        }
        function createGetSourceFile(readFile, getCompilerOptions, setParentNodes) {
            return (fileName, languageVersionOrOptions, onError) => {
                let text;
                try {
                    mark("beforeIORead");
                    text = readFile(fileName, getCompilerOptions().charset);
                    mark("afterIORead");
                    measure("I/O Read", "beforeIORead", "afterIORead");
                }
                catch (e) {
                    if (onError) {
                        onError(e.message);
                    }
                    text = "";
                }
                return text !== void 0 ? createSourceFile(fileName, text, languageVersionOrOptions, setParentNodes) : void 0;
            };
        }
        function createWriteFileMeasuringIO(actualWriteFile, createDirectory, directoryExists) {
            return (fileName, data, writeByteOrderMark, onError) => {
                try {
                    mark("beforeIOWrite");
                    writeFileEnsuringDirectories(fileName, data, writeByteOrderMark, actualWriteFile, createDirectory, directoryExists);
                    mark("afterIOWrite");
                    measure("I/O Write", "beforeIOWrite", "afterIOWrite");
                }
                catch (e) {
                    if (onError) {
                        onError(e.message);
                    }
                }
            };
        }
        function createCompilerHostWorker(options, setParentNodes, system = sys) {
            const existingDirectories = /* @__PURE__ */ new Map();
            const getCanonicalFileName = createGetCanonicalFileName(system.useCaseSensitiveFileNames);
            function directoryExists(directoryPath) {
                if (existingDirectories.has(directoryPath)) {
                    return true;
                }
                if ((compilerHost.directoryExists || system.directoryExists)(directoryPath)) {
                    existingDirectories.set(directoryPath, true);
                    return true;
                }
                return false;
            }
            function getDefaultLibLocation() {
                return getDirectoryPath(normalizePath(system.getExecutingFilePath()));
            }
            const newLine = getNewLineCharacter(options);
            const realpath = system.realpath && ((path) => system.realpath(path));
            const compilerHost = {
                getSourceFile: createGetSourceFile((fileName) => compilerHost.readFile(fileName), () => options, setParentNodes),
                getDefaultLibLocation,
                getDefaultLibFileName: (options2) => combinePaths(getDefaultLibLocation(), getDefaultLibFileName(options2)),
                writeFile: createWriteFileMeasuringIO((path, data, writeByteOrderMark) => system.writeFile(path, data, writeByteOrderMark), (path) => (compilerHost.createDirectory || system.createDirectory)(path), (path) => directoryExists(path)),
                getCurrentDirectory: memoize(() => system.getCurrentDirectory()),
                useCaseSensitiveFileNames: () => system.useCaseSensitiveFileNames,
                getCanonicalFileName,
                getNewLine: () => newLine,
                fileExists: (fileName) => system.fileExists(fileName),
                readFile: (fileName) => system.readFile(fileName),
                trace: (s) => system.write(s + newLine),
                directoryExists: (directoryName) => system.directoryExists(directoryName),
                getEnvironmentVariable: (name) => system.getEnvironmentVariable ? system.getEnvironmentVariable(name) : "",
                getDirectories: (path) => system.getDirectories(path),
                realpath,
                readDirectory: (path, extensions, include, exclude, depth) => system.readDirectory(path, extensions, include, exclude, depth),
                createDirectory: (d) => system.createDirectory(d),
                createHash: maybeBind(system, system.createHash)
            };
            return compilerHost;
        }
        function changeCompilerHostLikeToUseCache(host, toPath3, getSourceFile) {
            const originalReadFile = host.readFile;
            const originalFileExists = host.fileExists;
            const originalDirectoryExists = host.directoryExists;
            const originalCreateDirectory = host.createDirectory;
            const originalWriteFile = host.writeFile;
            const readFileCache = /* @__PURE__ */ new Map();
            const fileExistsCache = /* @__PURE__ */ new Map();
            const directoryExistsCache = /* @__PURE__ */ new Map();
            const sourceFileCache = /* @__PURE__ */ new Map();
            const readFileWithCache = (fileName) => {
                const key = toPath3(fileName);
                const value = readFileCache.get(key);
                if (value !== void 0)
                    return value !== false ? value : void 0;
                return setReadFileCache(key, fileName);
            };
            const setReadFileCache = (key, fileName) => {
                const newValue = originalReadFile.call(host, fileName);
                readFileCache.set(key, newValue !== void 0 ? newValue : false);
                return newValue;
            };
            host.readFile = (fileName) => {
                const key = toPath3(fileName);
                const value = readFileCache.get(key);
                if (value !== void 0)
                    return value !== false ? value : void 0;
                if (!fileExtensionIs(fileName, ".json" /* Json */) && !isBuildInfoFile(fileName)) {
                    return originalReadFile.call(host, fileName);
                }
                return setReadFileCache(key, fileName);
            };
            const getSourceFileWithCache = getSourceFile ? (fileName, languageVersionOrOptions, onError, shouldCreateNewSourceFile) => {
                const key = toPath3(fileName);
                const impliedNodeFormat = typeof languageVersionOrOptions === "object" ? languageVersionOrOptions.impliedNodeFormat : void 0;
                const forImpliedNodeFormat = sourceFileCache.get(impliedNodeFormat);
                const value = forImpliedNodeFormat == null ? void 0 : forImpliedNodeFormat.get(key);
                if (value)
                    return value;
                const sourceFile = getSourceFile(fileName, languageVersionOrOptions, onError, shouldCreateNewSourceFile);
                if (sourceFile && (isDeclarationFileName(fileName) || fileExtensionIs(fileName, ".json" /* Json */))) {
                    sourceFileCache.set(impliedNodeFormat, (forImpliedNodeFormat || /* @__PURE__ */ new Map()).set(key, sourceFile));
                }
                return sourceFile;
            } : void 0;
            host.fileExists = (fileName) => {
                const key = toPath3(fileName);
                const value = fileExistsCache.get(key);
                if (value !== void 0)
                    return value;
                const newValue = originalFileExists.call(host, fileName);
                fileExistsCache.set(key, !!newValue);
                return newValue;
            };
            if (originalWriteFile) {
                host.writeFile = (fileName, data, ...rest) => {
                    const key = toPath3(fileName);
                    fileExistsCache.delete(key);
                    const value = readFileCache.get(key);
                    if (value !== void 0 && value !== data) {
                        readFileCache.delete(key);
                        sourceFileCache.forEach((map2) => map2.delete(key));
                    }
                    else if (getSourceFileWithCache) {
                        sourceFileCache.forEach((map2) => {
                            const sourceFile = map2.get(key);
                            if (sourceFile && sourceFile.text !== data) {
                                map2.delete(key);
                            }
                        });
                    }
                    originalWriteFile.call(host, fileName, data, ...rest);
                };
            }
            if (originalDirectoryExists) {
                host.directoryExists = (directory) => {
                    const key = toPath3(directory);
                    const value = directoryExistsCache.get(key);
                    if (value !== void 0)
                        return value;
                    const newValue = originalDirectoryExists.call(host, directory);
                    directoryExistsCache.set(key, !!newValue);
                    return newValue;
                };
                if (originalCreateDirectory) {
                    host.createDirectory = (directory) => {
                        const key = toPath3(directory);
                        directoryExistsCache.delete(key);
                        originalCreateDirectory.call(host, directory);
                    };
                }
            }
            return {
                originalReadFile,
                originalFileExists,
                originalDirectoryExists,
                originalCreateDirectory,
                originalWriteFile,
                getSourceFileWithCache,
                readFileWithCache
            };
        }
        function getPreEmitDiagnostics(program, sourceFile, cancellationToken) {
            let diagnostics;
            diagnostics = addRange(diagnostics, program.getConfigFileParsingDiagnostics());
            diagnostics = addRange(diagnostics, program.getOptionsDiagnostics(cancellationToken));
            diagnostics = addRange(diagnostics, program.getSyntacticDiagnostics(sourceFile, cancellationToken));
            diagnostics = addRange(diagnostics, program.getGlobalDiagnostics(cancellationToken));
            diagnostics = addRange(diagnostics, program.getSemanticDiagnostics(sourceFile, cancellationToken));
            if (getEmitDeclarations(program.getCompilerOptions())) {
                diagnostics = addRange(diagnostics, program.getDeclarationDiagnostics(sourceFile, cancellationToken));
            }
            return sortAndDeduplicateDiagnostics(diagnostics || emptyArray);
        }
        function formatDiagnostics(diagnostics, host) {
            let output = "";
            for (const diagnostic of diagnostics) {
                output += formatDiagnostic(diagnostic, host);
            }
            return output;
        }
        function formatDiagnostic(diagnostic, host) {
            const errorMessage = `${diagnosticCategoryName(diagnostic)} TS${diagnostic.code}: ${flattenDiagnosticMessageText(diagnostic.messageText, host.getNewLine())}${host.getNewLine()}`;
            if (diagnostic.file) {
                const { line, character } = getLineAndCharacterOfPosition(diagnostic.file, diagnostic.start);
                const fileName = diagnostic.file.fileName;
                const relativeFileName = convertToRelativePath(fileName, host.getCurrentDirectory(), (fileName2) => host.getCanonicalFileName(fileName2));
                return `${relativeFileName}(${line + 1},${character + 1}): ` + errorMessage;
            }
            return errorMessage;
        }
        function getCategoryFormat(category) {
            switch (category) {
                case 1 /* Error */:
                    return "\x1B[91m" /* Red */;
                case 0 /* Warning */:
                    return "\x1B[93m" /* Yellow */;
                case 2 /* Suggestion */:
                    return Debug.fail("Should never get an Info diagnostic on the command line.");
                case 3 /* Message */:
                    return "\x1B[94m" /* Blue */;
            }
        }
        function formatColorAndReset(text, formatStyle) {
            return formatStyle + text + resetEscapeSequence;
        }
        function formatCodeSpan(file, start, length2, indent3, squiggleColor, host) {
            const { line: firstLine, character: firstLineChar } = getLineAndCharacterOfPosition(file, start);
            const { line: lastLine, character: lastLineChar } = getLineAndCharacterOfPosition(file, start + length2);
            const lastLineInFile = getLineAndCharacterOfPosition(file, file.text.length).line;
            const hasMoreThanFiveLines = lastLine - firstLine >= 4;
            let gutterWidth = (lastLine + 1 + "").length;
            if (hasMoreThanFiveLines) {
                gutterWidth = Math.max(ellipsis.length, gutterWidth);
            }
            let context = "";
            for (let i = firstLine; i <= lastLine; i++) {
                context += host.getNewLine();
                if (hasMoreThanFiveLines && firstLine + 1 < i && i < lastLine - 1) {
                    context += indent3 + formatColorAndReset(ellipsis.padStart(gutterWidth), gutterStyleSequence) + gutterSeparator + host.getNewLine();
                    i = lastLine - 1;
                }
                const lineStart = getPositionOfLineAndCharacter(file, i, 0);
                const lineEnd = i < lastLineInFile ? getPositionOfLineAndCharacter(file, i + 1, 0) : file.text.length;
                let lineContent = file.text.slice(lineStart, lineEnd);
                lineContent = lineContent.trimEnd();
                lineContent = lineContent.replace(/\t/g, " ");
                context += indent3 + formatColorAndReset((i + 1 + "").padStart(gutterWidth), gutterStyleSequence) + gutterSeparator;
                context += lineContent + host.getNewLine();
                context += indent3 + formatColorAndReset("".padStart(gutterWidth), gutterStyleSequence) + gutterSeparator;
                context += squiggleColor;
                if (i === firstLine) {
                    const lastCharForLine = i === lastLine ? lastLineChar : void 0;
                    context += lineContent.slice(0, firstLineChar).replace(/\S/g, " ");
                    context += lineContent.slice(firstLineChar, lastCharForLine).replace(/./g, "~");
                }
                else if (i === lastLine) {
                    context += lineContent.slice(0, lastLineChar).replace(/./g, "~");
                }
                else {
                    context += lineContent.replace(/./g, "~");
                }
                context += resetEscapeSequence;
            }
            return context;
        }
        function formatLocation(file, start, host, color = formatColorAndReset) {
            const { line: firstLine, character: firstLineChar } = getLineAndCharacterOfPosition(file, start);
            const relativeFileName = host ? convertToRelativePath(file.fileName, host.getCurrentDirectory(), (fileName) => host.getCanonicalFileName(fileName)) : file.fileName;
            let output = "";
            output += color(relativeFileName, "\x1B[96m" /* Cyan */);
            output += ":";
            output += color(`${firstLine + 1}`, "\x1B[93m" /* Yellow */);
            output += ":";
            output += color(`${firstLineChar + 1}`, "\x1B[93m" /* Yellow */);
            return output;
        }
        function formatDiagnosticsWithColorAndContext(diagnostics, host) {
            let output = "";
            for (const diagnostic of diagnostics) {
                if (diagnostic.file) {
                    const { file, start } = diagnostic;
                    output += formatLocation(file, start, host);
                    output += " - ";
                }
                output += formatColorAndReset(diagnosticCategoryName(diagnostic), getCategoryFormat(diagnostic.category));
                output += formatColorAndReset(` TS${diagnostic.code}: `, "\x1B[90m" /* Grey */);
                output += flattenDiagnosticMessageText(diagnostic.messageText, host.getNewLine());
                if (diagnostic.file && diagnostic.code !== Diagnostics.File_appears_to_be_binary.code) {
                    output += host.getNewLine();
                    output += formatCodeSpan(diagnostic.file, diagnostic.start, diagnostic.length, "", getCategoryFormat(diagnostic.category), host);
                }
                if (diagnostic.relatedInformation) {
                    output += host.getNewLine();
                    for (const { file, start, length: length2, messageText } of diagnostic.relatedInformation) {
                        if (file) {
                            output += host.getNewLine();
                            output += halfIndent + formatLocation(file, start, host);
                            output += formatCodeSpan(file, start, length2, indent, "\x1B[96m" /* Cyan */, host);
                        }
                        output += host.getNewLine();
                        output += indent + flattenDiagnosticMessageText(messageText, host.getNewLine());
                    }
                }
                output += host.getNewLine();
            }
            return output;
        }
        function flattenDiagnosticMessageText(diag2, newLine, indent3 = 0) {
            if (isString(diag2)) {
                return diag2;
            }
            else if (diag2 === void 0) {
                return "";
            }
            let result = "";
            if (indent3) {
                result += newLine;
                for (let i = 0; i < indent3; i++) {
                    result += "  ";
                }
            }
            result += diag2.messageText;
            indent3++;
            if (diag2.next) {
                for (const kid of diag2.next) {
                    result += flattenDiagnosticMessageText(kid, newLine, indent3);
                }
            }
            return result;
        }
        function getModeForFileReference(ref, containingFileMode) {
            return (isString(ref) ? containingFileMode : ref.resolutionMode) || containingFileMode;
        }
        function getModeForResolutionAtIndex(file, index, compilerOptions) {
            return getModeForUsageLocationWorker(file, getModuleNameStringLiteralAt(file, index), compilerOptions);
        }
        function isExclusivelyTypeOnlyImportOrExport(decl) {
            var _a;
            if (isExportDeclaration(decl)) {
                return decl.isTypeOnly;
            }
            if ((_a = decl.importClause) == null ? void 0 : _a.isTypeOnly) {
                return true;
            }
            return false;
        }
        function getModeForUsageLocation(file, usage, compilerOptions) {
            return getModeForUsageLocationWorker(file, usage, compilerOptions);
        }
        function getModeForUsageLocationWorker(file, usage, compilerOptions) {
            var _a;
            if (isImportDeclaration(usage.parent) || isExportDeclaration(usage.parent)) {
                const isTypeOnly = isExclusivelyTypeOnlyImportOrExport(usage.parent);
                if (isTypeOnly) {
                    const override = getResolutionModeOverride(usage.parent.attributes);
                    if (override) {
                        return override;
                    }
                }
            }
            if (usage.parent.parent && isImportTypeNode(usage.parent.parent)) {
                const override = getResolutionModeOverride(usage.parent.parent.attributes);
                if (override) {
                    return override;
                }
            }
            if (compilerOptions && getEmitModuleKind(compilerOptions) === 200 /* Preserve */) {
                return usage.parent.parent && isImportEqualsDeclaration(usage.parent.parent) || isRequireCall(usage.parent, 
                /*requireStringLiteralLikeArgument*/
                false) ? 1 /* CommonJS */ : 99 /* ESNext */;
            }
            if (file.impliedNodeFormat === void 0)
                return void 0;
            if (file.impliedNodeFormat !== 99 /* ESNext */) {
                return isImportCall(walkUpParenthesizedExpressions(usage.parent)) ? 99 /* ESNext */ : 1 /* CommonJS */;
            }
            const exprParentParent = (_a = walkUpParenthesizedExpressions(usage.parent)) == null ? void 0 : _a.parent;
            return exprParentParent && isImportEqualsDeclaration(exprParentParent) ? 1 /* CommonJS */ : 99 /* ESNext */;
        }
        function getResolutionModeOverride(node, grammarErrorOnNode) {
            if (!node)
                return void 0;
            if (length(node.elements) !== 1) {
                grammarErrorOnNode == null ? void 0 : grammarErrorOnNode(node, node.token === 118 /* WithKeyword */ ? Diagnostics.Type_import_attributes_should_have_exactly_one_key_resolution_mode_with_value_import_or_require : Diagnostics.Type_import_assertions_should_have_exactly_one_key_resolution_mode_with_value_import_or_require);
                return void 0;
            }
            const elem = node.elements[0];
            if (!isStringLiteralLike(elem.name))
                return void 0;
            if (elem.name.text !== "resolution-mode") {
                grammarErrorOnNode == null ? void 0 : grammarErrorOnNode(elem.name, node.token === 118 /* WithKeyword */ ? Diagnostics.resolution_mode_is_the_only_valid_key_for_type_import_attributes : Diagnostics.resolution_mode_is_the_only_valid_key_for_type_import_assertions);
                return void 0;
            }
            if (!isStringLiteralLike(elem.value))
                return void 0;
            if (elem.value.text !== "import" && elem.value.text !== "require") {
                grammarErrorOnNode == null ? void 0 : grammarErrorOnNode(elem.value, Diagnostics.resolution_mode_should_be_either_require_or_import);
                return void 0;
            }
            return elem.value.text === "import" ? 99 /* ESNext */ : 1 /* CommonJS */;
        }
        function getModuleResolutionName(literal) {
            return literal.text;
        }
        function createModuleResolutionLoader(containingFile, redirectedReference, options, host, cache) {
            return {
                nameAndMode: moduleResolutionNameAndModeGetter,
                resolve: (moduleName, resolutionMode) => resolveModuleName(moduleName, containingFile, options, host, cache, redirectedReference, resolutionMode)
            };
        }
        function getTypeReferenceResolutionName(entry) {
            return !isString(entry) ? toFileNameLowerCase(entry.fileName) : entry;
        }
        function createTypeReferenceResolutionLoader(containingFile, redirectedReference, options, host, cache) {
            return {
                nameAndMode: typeReferenceResolutionNameAndModeGetter,
                resolve: (typeRef, resoluionMode) => resolveTypeReferenceDirective(typeRef, containingFile, options, host, redirectedReference, cache, resoluionMode)
            };
        }
        function loadWithModeAwareCache(entries, containingFile, redirectedReference, options, containingSourceFile, host, resolutionCache, createLoader) {
            if (entries.length === 0)
                return emptyArray;
            const resolutions = [];
            const cache = /* @__PURE__ */ new Map();
            const loader = createLoader(containingFile, redirectedReference, options, host, resolutionCache);
            for (const entry of entries) {
                const name = loader.nameAndMode.getName(entry);
                const mode = loader.nameAndMode.getMode(entry, containingSourceFile, (redirectedReference == null ? void 0 : redirectedReference.commandLine.options) || options);
                const key = createModeAwareCacheKey(name, mode);
                let result = cache.get(key);
                if (!result) {
                    cache.set(key, result = loader.resolve(name, mode));
                }
                resolutions.push(result);
            }
            return resolutions;
        }
        function forEachResolvedProjectReference(resolvedProjectReferences, cb) {
            return forEachProjectReference(
            /*projectReferences*/
            void 0, resolvedProjectReferences, (resolvedRef, parent2) => resolvedRef && cb(resolvedRef, parent2));
        }
        function forEachProjectReference(projectReferences, resolvedProjectReferences, cbResolvedRef, cbRef) {
            let seenResolvedRefs;
            return worker(projectReferences, resolvedProjectReferences, 
            /*parent*/
            void 0);
            function worker(projectReferences2, resolvedProjectReferences2, parent2) {
                if (cbRef) {
                    const result = cbRef(projectReferences2, parent2);
                    if (result)
                        return result;
                }
                return forEach(resolvedProjectReferences2, (resolvedRef, index) => {
                    if (resolvedRef && (seenResolvedRefs == null ? void 0 : seenResolvedRefs.has(resolvedRef.sourceFile.path))) {
                        return void 0;
                    }
                    const result = cbResolvedRef(resolvedRef, parent2, index);
                    if (result || !resolvedRef)
                        return result;
                    (seenResolvedRefs || (seenResolvedRefs = /* @__PURE__ */ new Set())).add(resolvedRef.sourceFile.path);
                    return worker(resolvedRef.commandLine.projectReferences, resolvedRef.references, resolvedRef);
                });
            }
        }
        function getInferredLibraryNameResolveFrom(options, currentDirectory, libFileName) {
            const containingDirectory = options.configFilePath ? getDirectoryPath(options.configFilePath) : currentDirectory;
            return combinePaths(containingDirectory, `__lib_node_modules_lookup_${libFileName}__.ts`);
        }
        function getLibraryNameFromLibFileName(libFileName) {
            const components = libFileName.split(".");
            let path = components[1];
            let i = 2;
            while (components[i] && components[i] !== "d") {
                path += (i === 2 ? "/" : "-") + components[i];
                i++;
            }
            return "@typescript/lib-" + path;
        }
        function getLibFileNameFromLibReference(libReference) {
            const libName = toFileNameLowerCase(libReference.fileName);
            const libFileName = libMap.get(libName);
            return { libName, libFileName };
        }
        function isReferencedFile(reason) {
            switch (reason == null ? void 0 : reason.kind) {
                case 3 /* Import */:
                case 4 /* ReferenceFile */:
                case 5 /* TypeReferenceDirective */:
                case 7 /* LibReferenceDirective */:
                    return true;
                default:
                    return false;
            }
        }
        function isReferenceFileLocation(location) {
            return location.pos !== void 0;
        }
        function getReferencedFileLocation(program, ref) {
            var _a, _b, _c, _d;
            const file = Debug.checkDefined(program.getSourceFileByPath(ref.file));
            const { kind, index } = ref;
            let pos, end, packageId, resolutionMode;
            switch (kind) {
                case 3 /* Import */:
                    const importLiteral = getModuleNameStringLiteralAt(file, index);
                    packageId = (_b = (_a = program.getResolvedModule(file, importLiteral.text, program.getModeForUsageLocation(file, importLiteral))) == null ? void 0 : _a.resolvedModule) == null ? void 0 : _b.packageId;
                    if (importLiteral.pos === -1)
                        return { file, packageId, text: importLiteral.text };
                    pos = skipTrivia(file.text, importLiteral.pos);
                    end = importLiteral.end;
                    break;
                case 4 /* ReferenceFile */:
                    ({ pos, end } = file.referencedFiles[index]);
                    break;
                case 5 /* TypeReferenceDirective */:
                    ({ pos, end, resolutionMode } = file.typeReferenceDirectives[index]);
                    packageId = (_d = (_c = program.getResolvedTypeReferenceDirective(file, toFileNameLowerCase(file.typeReferenceDirectives[index].fileName), resolutionMode || file.impliedNodeFormat)) == null ? void 0 : _c.resolvedTypeReferenceDirective) == null ? void 0 : _d.packageId;
                    break;
                case 7 /* LibReferenceDirective */:
                    ({ pos, end } = file.libReferenceDirectives[index]);
                    break;
                default:
                    return Debug.assertNever(kind);
            }
            return { file, pos, end, packageId };
        }
        function isProgramUptoDate(program, rootFileNames, newOptions, getSourceVersion, fileExists, hasInvalidatedResolutions, hasInvalidatedLibResolutions, hasChangedAutomaticTypeDirectiveNames, getParsedCommandLine, projectReferences) {
            if (!program || (hasChangedAutomaticTypeDirectiveNames == null ? void 0 : hasChangedAutomaticTypeDirectiveNames()))
                return false;
            if (!arrayIsEqualTo(program.getRootFileNames(), rootFileNames))
                return false;
            let seenResolvedRefs;
            if (!arrayIsEqualTo(program.getProjectReferences(), projectReferences, projectReferenceUptoDate))
                return false;
            if (program.getSourceFiles().some(sourceFileNotUptoDate))
                return false;
            const missingPaths = program.getMissingFilePaths();
            if (missingPaths && forEachEntry(missingPaths, fileExists))
                return false;
            const currentOptions = program.getCompilerOptions();
            if (!compareDataObjects(currentOptions, newOptions))
                return false;
            if (program.resolvedLibReferences && forEachEntry(program.resolvedLibReferences, (_value, libFileName) => hasInvalidatedLibResolutions(libFileName)))
                return false;
            if (currentOptions.configFile && newOptions.configFile)
                return currentOptions.configFile.text === newOptions.configFile.text;
            return true;
            function sourceFileNotUptoDate(sourceFile) {
                return !sourceFileVersionUptoDate(sourceFile) || hasInvalidatedResolutions(sourceFile.path);
            }
            function sourceFileVersionUptoDate(sourceFile) {
                return sourceFile.version === getSourceVersion(sourceFile.resolvedPath, sourceFile.fileName);
            }
            function projectReferenceUptoDate(oldRef, newRef, index) {
                return projectReferenceIsEqualTo(oldRef, newRef) && resolvedProjectReferenceUptoDate(program.getResolvedProjectReferences()[index], oldRef);
            }
            function resolvedProjectReferenceUptoDate(oldResolvedRef, oldRef) {
                if (oldResolvedRef) {
                    if (contains(seenResolvedRefs, oldResolvedRef))
                        return true;
                    const refPath2 = resolveProjectReferencePath(oldRef);
                    const newParsedCommandLine = getParsedCommandLine(refPath2);
                    if (!newParsedCommandLine)
                        return false;
                    if (oldResolvedRef.commandLine.options.configFile !== newParsedCommandLine.options.configFile)
                        return false;
                    if (!arrayIsEqualTo(oldResolvedRef.commandLine.fileNames, newParsedCommandLine.fileNames))
                        return false;
                    (seenResolvedRefs || (seenResolvedRefs = [])).push(oldResolvedRef);
                    return !forEach(oldResolvedRef.references, (childResolvedRef, index) => !resolvedProjectReferenceUptoDate(childResolvedRef, oldResolvedRef.commandLine.projectReferences[index]));
                }
                const refPath = resolveProjectReferencePath(oldRef);
                return !getParsedCommandLine(refPath);
            }
        }
        function getConfigFileParsingDiagnostics(configFileParseResult) {
            return configFileParseResult.options.configFile ? [...configFileParseResult.options.configFile.parseDiagnostics, ...configFileParseResult.errors] : configFileParseResult.errors;
        }
        function getImpliedNodeFormatForFile(fileName, packageJsonInfoCache, host, options) {
            const result = getImpliedNodeFormatForFileWorker(fileName, packageJsonInfoCache, host, options);
            return typeof result === "object" ? result.impliedNodeFormat : result;
        }
        function getImpliedNodeFormatForFileWorker(fileName, packageJsonInfoCache, host, options) {
            switch (getEmitModuleResolutionKind(options)) {
                case 3 /* Node16 */:
                case 99 /* NodeNext */:
                    return fileExtensionIsOneOf(fileName, [".d.mts" /* Dmts */, ".mts" /* Mts */, ".mjs" /* Mjs */]) ? 99 /* ESNext */ : fileExtensionIsOneOf(fileName, [".d.cts" /* Dcts */, ".cts" /* Cts */, ".cjs" /* Cjs */]) ? 1 /* CommonJS */ : fileExtensionIsOneOf(fileName, [".d.ts" /* Dts */, ".ts" /* Ts */, ".tsx" /* Tsx */, ".js" /* Js */, ".jsx" /* Jsx */]) ? lookupFromPackageJson() : void 0;
                default:
                    return void 0;
            }
            function lookupFromPackageJson() {
                const state = getTemporaryModuleResolutionState(packageJsonInfoCache, host, options);
                const packageJsonLocations = [];
                state.failedLookupLocations = packageJsonLocations;
                state.affectingLocations = packageJsonLocations;
                const packageJsonScope = getPackageScopeForPath(fileName, state);
                const impliedNodeFormat = (packageJsonScope == null ? void 0 : packageJsonScope.contents.packageJsonContent.type) === "module" ? 99 /* ESNext */ : 1 /* CommonJS */;
                return { impliedNodeFormat, packageJsonLocations, packageJsonScope };
            }
        }
        function shouldProgramCreateNewSourceFiles(program, newOptions) {
            if (!program)
                return false;
            return optionsHaveChanges(program.getCompilerOptions(), newOptions, sourceFileAffectingCompilerOptions);
        }
        function createCreateProgramOptions(rootNames, options, host, oldProgram, configFileParsingDiagnostics, typeScriptVersion3) {
            return {
                rootNames,
                options,
                host,
                oldProgram,
                configFileParsingDiagnostics,
                typeScriptVersion: typeScriptVersion3
            };
        }
        function createProgram(rootNamesOrOptions, _options, _host, _oldProgram, _configFileParsingDiagnostics) {
            var _a, _b, _c, _d, _e, _f, _g, _h, _i, _j, _k, _l, _m, _n, _o, _p;
            const createProgramOptions = isArray(rootNamesOrOptions) ? createCreateProgramOptions(rootNamesOrOptions, _options, _host, _oldProgram, _configFileParsingDiagnostics) : rootNamesOrOptions;
            const { rootNames, options, configFileParsingDiagnostics, projectReferences, typeScriptVersion: typeScriptVersion3 } = createProgramOptions;
            let { oldProgram } = createProgramOptions;
            const reportInvalidIgnoreDeprecations = memoize(() => createOptionValueDiagnostic("ignoreDeprecations", Diagnostics.Invalid_value_for_ignoreDeprecations));
            let processingDefaultLibFiles;
            let processingOtherFiles;
            let files;
            let symlinks;
            let commonSourceDirectory;
            let typeChecker;
            let classifiableNames;
            const ambientModuleNameToUnmodifiedFileName = /* @__PURE__ */ new Map();
            let fileReasons = createMultiMap();
            const cachedBindAndCheckDiagnosticsForFile = {};
            const cachedDeclarationDiagnosticsForFile = {};
            let resolvedTypeReferenceDirectives = createModeAwareCache();
            let fileProcessingDiagnostics;
            let automaticTypeDirectiveNames;
            let automaticTypeDirectiveResolutions;
            let resolvedLibReferences;
            let resolvedLibProcessing;
            let resolvedModules;
            let resolvedModulesProcessing;
            let resolvedTypeReferenceDirectiveNames;
            let resolvedTypeReferenceDirectiveNamesProcessing;
            let packageMap;
            const maxNodeModuleJsDepth = typeof options.maxNodeModuleJsDepth === "number" ? options.maxNodeModuleJsDepth : 0;
            let currentNodeModulesDepth = 0;
            const modulesWithElidedImports = /* @__PURE__ */ new Map();
            const sourceFilesFoundSearchingNodeModules = /* @__PURE__ */ new Map();
            (_a = tracing) == null ? void 0 : _a.push(tracing.Phase.Program, "createProgram", { configFilePath: options.configFilePath, rootDir: options.rootDir }, 
            /*separateBeginAndEnd*/
            true);
            mark("beforeProgram");
            const host = createProgramOptions.host || createCompilerHost(options);
            const configParsingHost = parseConfigHostFromCompilerHostLike(host);
            let skipDefaultLib = options.noLib;
            const getDefaultLibraryFileName = memoize(() => host.getDefaultLibFileName(options));
            const defaultLibraryPath = host.getDefaultLibLocation ? host.getDefaultLibLocation() : getDirectoryPath(getDefaultLibraryFileName());
            const programDiagnostics = createDiagnosticCollection();
            const currentDirectory = host.getCurrentDirectory();
            const supportedExtensions = getSupportedExtensions(options);
            const supportedExtensionsWithJsonIfResolveJsonModule = getSupportedExtensionsWithJsonIfResolveJsonModule(options, supportedExtensions);
            const hasEmitBlockingDiagnostics = /* @__PURE__ */ new Map();
            let _compilerOptionsObjectLiteralSyntax;
            let moduleResolutionCache;
            let actualResolveModuleNamesWorker;
            const hasInvalidatedResolutions = host.hasInvalidatedResolutions || returnFalse;
            if (host.resolveModuleNameLiterals) {
                actualResolveModuleNamesWorker = host.resolveModuleNameLiterals.bind(host);
                moduleResolutionCache = (_b = host.getModuleResolutionCache) == null ? void 0 : _b.call(host);
            }
            else if (host.resolveModuleNames) {
                actualResolveModuleNamesWorker = (moduleNames, containingFile, redirectedReference, options2, containingSourceFile, reusedNames) => host.resolveModuleNames(moduleNames.map(getModuleResolutionName), containingFile, reusedNames == null ? void 0 : reusedNames.map(getModuleResolutionName), redirectedReference, options2, containingSourceFile).map((resolved) => resolved ? resolved.extension !== void 0 ? { resolvedModule: resolved } : (
                // An older host may have omitted extension, in which case we should infer it from the file extension of resolvedFileName.
                { resolvedModule: { ...resolved, extension: extensionFromPath(resolved.resolvedFileName) } }) : emptyResolution);
                moduleResolutionCache = (_c = host.getModuleResolutionCache) == null ? void 0 : _c.call(host);
            }
            else {
                moduleResolutionCache = createModuleResolutionCache(currentDirectory, getCanonicalFileName, options);
                actualResolveModuleNamesWorker = (moduleNames, containingFile, redirectedReference, options2, containingSourceFile) => loadWithModeAwareCache(moduleNames, containingFile, redirectedReference, options2, containingSourceFile, host, moduleResolutionCache, createModuleResolutionLoader);
            }
            let actualResolveTypeReferenceDirectiveNamesWorker;
            if (host.resolveTypeReferenceDirectiveReferences) {
                actualResolveTypeReferenceDirectiveNamesWorker = host.resolveTypeReferenceDirectiveReferences.bind(host);
            }
            else if (host.resolveTypeReferenceDirectives) {
                actualResolveTypeReferenceDirectiveNamesWorker = (typeDirectiveNames, containingFile, redirectedReference, options2, containingSourceFile) => host.resolveTypeReferenceDirectives(typeDirectiveNames.map(getTypeReferenceResolutionName), containingFile, redirectedReference, options2, containingSourceFile == null ? void 0 : containingSourceFile.impliedNodeFormat).map((resolvedTypeReferenceDirective) => ({ resolvedTypeReferenceDirective }));
            }
            else {
                const typeReferenceDirectiveResolutionCache = createTypeReferenceDirectiveResolutionCache(currentDirectory, getCanonicalFileName, 
                /*options*/
                void 0, moduleResolutionCache == null ? void 0 : moduleResolutionCache.getPackageJsonInfoCache(), moduleResolutionCache == null ? void 0 : moduleResolutionCache.optionsToRedirectsKey);
                actualResolveTypeReferenceDirectiveNamesWorker = (typeDirectiveNames, containingFile, redirectedReference, options2, containingSourceFile) => loadWithModeAwareCache(typeDirectiveNames, containingFile, redirectedReference, options2, containingSourceFile, host, typeReferenceDirectiveResolutionCache, createTypeReferenceResolutionLoader);
            }
            const hasInvalidatedLibResolutions = host.hasInvalidatedLibResolutions || returnFalse;
            let actualResolveLibrary;
            if (host.resolveLibrary) {
                actualResolveLibrary = host.resolveLibrary.bind(host);
            }
            else {
                const libraryResolutionCache = createModuleResolutionCache(currentDirectory, getCanonicalFileName, options, moduleResolutionCache == null ? void 0 : moduleResolutionCache.getPackageJsonInfoCache());
                actualResolveLibrary = (libraryName, resolveFrom, options2) => resolveLibrary(libraryName, resolveFrom, options2, host, libraryResolutionCache);
            }
            const packageIdToSourceFile = /* @__PURE__ */ new Map();
            let sourceFileToPackageName = /* @__PURE__ */ new Map();
            let redirectTargetsMap = createMultiMap();
            let usesUriStyleNodeCoreModules = false;
            const filesByName = /* @__PURE__ */ new Map();
            let missingFileNames = /* @__PURE__ */ new Map();
            const filesByNameIgnoreCase = host.useCaseSensitiveFileNames() ? /* @__PURE__ */ new Map() : void 0;
            let resolvedProjectReferences;
            let projectReferenceRedirects;
            let mapFromFileToProjectReferenceRedirects;
            let mapFromToProjectReferenceRedirectSource;
            const useSourceOfProjectReferenceRedirect = !!((_d = host.useSourceOfProjectReferenceRedirect) == null ? void 0 : _d.call(host)) && !options.disableSourceOfProjectReferenceRedirect;
            const { onProgramCreateComplete, fileExists, directoryExists } = updateHostForUseSourceOfProjectReferenceRedirect({
                compilerHost: host,
                getSymlinkCache,
                useSourceOfProjectReferenceRedirect,
                toPath: toPath3,
                getResolvedProjectReferences,
                getSourceOfProjectReferenceRedirect,
                forEachResolvedProjectReference: forEachResolvedProjectReference2
            });
            const readFile = host.readFile.bind(host);
            (_e = tracing) == null ? void 0 : _e.push(tracing.Phase.Program, "shouldProgramCreateNewSourceFiles", { hasOldProgram: !!oldProgram });
            const shouldCreateNewSourceFile = shouldProgramCreateNewSourceFiles(oldProgram, options);
            (_f = tracing) == null ? void 0 : _f.pop();
            let structureIsReused;
            (_g = tracing) == null ? void 0 : _g.push(tracing.Phase.Program, "tryReuseStructureFromOldProgram", {});
            structureIsReused = tryReuseStructureFromOldProgram();
            (_h = tracing) == null ? void 0 : _h.pop();
            if (structureIsReused !== 2 /* Completely */) {
                processingDefaultLibFiles = [];
                processingOtherFiles = [];
                if (projectReferences) {
                    if (!resolvedProjectReferences) {
                        resolvedProjectReferences = projectReferences.map(parseProjectReferenceConfigFile);
                    }
                    if (rootNames.length) {
                        resolvedProjectReferences == null ? void 0 : resolvedProjectReferences.forEach((parsedRef, index) => {
                            if (!parsedRef)
                                return;
                            const out = outFile(parsedRef.commandLine.options);
                            if (useSourceOfProjectReferenceRedirect) {
                                if (out || getEmitModuleKind(parsedRef.commandLine.options) === 0 /* None */) {
                                    for (const fileName of parsedRef.commandLine.fileNames) {
                                        processProjectReferenceFile(fileName, { kind: 1 /* SourceFromProjectReference */, index });
                                    }
                                }
                            }
                            else {
                                if (out) {
                                    processProjectReferenceFile(changeExtension(out, ".d.ts"), { kind: 2 /* OutputFromProjectReference */, index });
                                }
                                else if (getEmitModuleKind(parsedRef.commandLine.options) === 0 /* None */) {
                                    const getCommonSourceDirectory3 = memoize(() => getCommonSourceDirectoryOfConfig(parsedRef.commandLine, !host.useCaseSensitiveFileNames()));
                                    for (const fileName of parsedRef.commandLine.fileNames) {
                                        if (!isDeclarationFileName(fileName) && !fileExtensionIs(fileName, ".json" /* Json */)) {
                                            processProjectReferenceFile(getOutputDeclarationFileName(fileName, parsedRef.commandLine, !host.useCaseSensitiveFileNames(), getCommonSourceDirectory3), { kind: 2 /* OutputFromProjectReference */, index });
                                        }
                                    }
                                }
                            }
                        });
                    }
                }
                (_i = tracing) == null ? void 0 : _i.push(tracing.Phase.Program, "processRootFiles", { count: rootNames.length });
                forEach(rootNames, (name, index) => processRootFile(name, 
                /*isDefaultLib*/
                false, 
                /*ignoreNoDefaultLib*/
                false, { kind: 0 /* RootFile */, index }));
                (_j = tracing) == null ? void 0 : _j.pop();
                automaticTypeDirectiveNames ?? (automaticTypeDirectiveNames = rootNames.length ? getAutomaticTypeDirectiveNames(options, host) : emptyArray);
                automaticTypeDirectiveResolutions = createModeAwareCache();
                if (automaticTypeDirectiveNames.length) {
                    (_k = tracing) == null ? void 0 : _k.push(tracing.Phase.Program, "processTypeReferences", { count: automaticTypeDirectiveNames.length });
                    const containingDirectory = options.configFilePath ? getDirectoryPath(options.configFilePath) : currentDirectory;
                    const containingFilename = combinePaths(containingDirectory, inferredTypesContainingFile);
                    const resolutions = resolveTypeReferenceDirectiveNamesReusingOldState(automaticTypeDirectiveNames, containingFilename);
                    for (let i = 0; i < automaticTypeDirectiveNames.length; i++) {
                        automaticTypeDirectiveResolutions.set(automaticTypeDirectiveNames[i], 
                        /*mode*/
                        void 0, resolutions[i]);
                        processTypeReferenceDirective(automaticTypeDirectiveNames[i], 
                        /*mode*/
                        void 0, resolutions[i], {
                            kind: 8 /* AutomaticTypeDirectiveFile */,
                            typeReference: automaticTypeDirectiveNames[i],
                            packageId: (_m = (_l = resolutions[i]) == null ? void 0 : _l.resolvedTypeReferenceDirective) == null ? void 0 : _m.packageId
                        });
                    }
                    (_n = tracing) == null ? void 0 : _n.pop();
                }
                if (rootNames.length && !skipDefaultLib) {
                    const defaultLibraryFileName = getDefaultLibraryFileName();
                    if (!options.lib && defaultLibraryFileName) {
                        processRootFile(defaultLibraryFileName, 
                        /*isDefaultLib*/
                        true, 
                        /*ignoreNoDefaultLib*/
                        false, { kind: 6 /* LibFile */ });
                    }
                    else {
                        forEach(options.lib, (libFileName, index) => {
                            processRootFile(pathForLibFile(libFileName), 
                            /*isDefaultLib*/
                            true, 
                            /*ignoreNoDefaultLib*/
                            false, { kind: 6 /* LibFile */, index });
                        });
                    }
                }
                files = stableSort(processingDefaultLibFiles, compareDefaultLibFiles).concat(processingOtherFiles);
                processingDefaultLibFiles = void 0;
                processingOtherFiles = void 0;
            }
            if (oldProgram && host.onReleaseOldSourceFile) {
                const oldSourceFiles = oldProgram.getSourceFiles();
                for (const oldSourceFile of oldSourceFiles) {
                    const newFile = getSourceFileByPath(oldSourceFile.resolvedPath);
                    if (shouldCreateNewSourceFile || !newFile || newFile.impliedNodeFormat !== oldSourceFile.impliedNodeFormat || // old file wasn't redirect but new file is
                        oldSourceFile.resolvedPath === oldSourceFile.path && newFile.resolvedPath !== oldSourceFile.path) {
                        host.onReleaseOldSourceFile(oldSourceFile, oldProgram.getCompilerOptions(), !!getSourceFileByPath(oldSourceFile.path));
                    }
                }
                if (!host.getParsedCommandLine) {
                    oldProgram.forEachResolvedProjectReference((resolvedProjectReference) => {
                        if (!getResolvedProjectReferenceByPath(resolvedProjectReference.sourceFile.path)) {
                            host.onReleaseOldSourceFile(resolvedProjectReference.sourceFile, oldProgram.getCompilerOptions(), 
                            /*hasSourceFileByPath*/
                            false);
                        }
                    });
                }
            }
            if (oldProgram && host.onReleaseParsedCommandLine) {
                forEachProjectReference(oldProgram.getProjectReferences(), oldProgram.getResolvedProjectReferences(), (oldResolvedRef, parent2, index) => {
                    const oldReference = (parent2 == null ? void 0 : parent2.commandLine.projectReferences[index]) || oldProgram.getProjectReferences()[index];
                    const oldRefPath = resolveProjectReferencePath(oldReference);
                    if (!(projectReferenceRedirects == null ? void 0 : projectReferenceRedirects.has(toPath3(oldRefPath)))) {
                        host.onReleaseParsedCommandLine(oldRefPath, oldResolvedRef, oldProgram.getCompilerOptions());
                    }
                });
            }
            oldProgram = void 0;
            resolvedLibProcessing = void 0;
            resolvedModulesProcessing = void 0;
            resolvedTypeReferenceDirectiveNamesProcessing = void 0;
            const program = {
                getRootFileNames: () => rootNames,
                getSourceFile,
                getSourceFileByPath,
                getSourceFiles: () => files,
                getMissingFilePaths: () => missingFileNames,
                getModuleResolutionCache: () => moduleResolutionCache,
                getFilesByNameMap: () => filesByName,
                getCompilerOptions: () => options,
                getSyntacticDiagnostics,
                getOptionsDiagnostics,
                getGlobalDiagnostics,
                getSemanticDiagnostics,
                getCachedSemanticDiagnostics,
                getSuggestionDiagnostics,
                getDeclarationDiagnostics: getDeclarationDiagnostics2,
                getBindAndCheckDiagnostics,
                getProgramDiagnostics,
                getTypeChecker,
                getClassifiableNames,
                getCommonSourceDirectory: getCommonSourceDirectory2,
                emit,
                getCurrentDirectory: () => currentDirectory,
                getNodeCount: () => getTypeChecker().getNodeCount(),
                getIdentifierCount: () => getTypeChecker().getIdentifierCount(),
                getSymbolCount: () => getTypeChecker().getSymbolCount(),
                getTypeCount: () => getTypeChecker().getTypeCount(),
                getInstantiationCount: () => getTypeChecker().getInstantiationCount(),
                getRelationCacheSizes: () => getTypeChecker().getRelationCacheSizes(),
                getFileProcessingDiagnostics: () => fileProcessingDiagnostics,
                getResolvedTypeReferenceDirectives: () => resolvedTypeReferenceDirectives,
                getAutomaticTypeDirectiveNames: () => automaticTypeDirectiveNames,
                getAutomaticTypeDirectiveResolutions: () => automaticTypeDirectiveResolutions,
                isSourceFileFromExternalLibrary,
                isSourceFileDefaultLibrary,
                getModeForUsageLocation: getModeForUsageLocation2,
                getModeForResolutionAtIndex: getModeForResolutionAtIndex2,
                getSourceFileFromReference,
                getLibFileFromReference,
                sourceFileToPackageName,
                redirectTargetsMap,
                usesUriStyleNodeCoreModules,
                resolvedModules,
                resolvedTypeReferenceDirectiveNames,
                resolvedLibReferences,
                getResolvedModule,
                getResolvedModuleFromModuleSpecifier,
                getResolvedTypeReferenceDirective,
                forEachResolvedModule,
                forEachResolvedTypeReferenceDirective,
                getCurrentPackagesMap: () => packageMap,
                typesPackageExists,
                packageBundlesTypes,
                isEmittedFile,
                getConfigFileParsingDiagnostics: getConfigFileParsingDiagnostics2,
                getProjectReferences,
                getResolvedProjectReferences,
                getProjectReferenceRedirect,
                getResolvedProjectReferenceToRedirect,
                getResolvedProjectReferenceByPath,
                forEachResolvedProjectReference: forEachResolvedProjectReference2,
                isSourceOfProjectReferenceRedirect,
                emitBuildInfo,
                fileExists,
                readFile,
                directoryExists,
                getSymlinkCache,
                realpath: (_o = host.realpath) == null ? void 0 : _o.bind(host),
                useCaseSensitiveFileNames: () => host.useCaseSensitiveFileNames(),
                getCanonicalFileName,
                getFileIncludeReasons: () => fileReasons,
                structureIsReused,
                writeFile: writeFile2
            };
            onProgramCreateComplete();
            fileProcessingDiagnostics == null ? void 0 : fileProcessingDiagnostics.forEach((diagnostic) => {
                switch (diagnostic.kind) {
                    case 1 /* FilePreprocessingFileExplainingDiagnostic */:
                        return programDiagnostics.add(createDiagnosticExplainingFile(diagnostic.file && getSourceFileByPath(diagnostic.file), diagnostic.fileProcessingReason, diagnostic.diagnostic, diagnostic.args || emptyArray));
                    case 0 /* FilePreprocessingReferencedDiagnostic */:
                        const { file, pos, end } = getReferencedFileLocation(program, diagnostic.reason);
                        return programDiagnostics.add(createFileDiagnostic(file, Debug.checkDefined(pos), Debug.checkDefined(end) - pos, diagnostic.diagnostic, ...diagnostic.args || emptyArray));
                    case 2 /* ResolutionDiagnostics */:
                        return diagnostic.diagnostics.forEach((d) => programDiagnostics.add(d));
                    default:
                        Debug.assertNever(diagnostic);
                }
            });
            verifyCompilerOptions();
            mark("afterProgram");
            measure("Program", "beforeProgram", "afterProgram");
            (_p = tracing) == null ? void 0 : _p.pop();
            return program;
            function getResolvedModule(file, moduleName, mode) {
                var _a2;
                return (_a2 = resolvedModules == null ? void 0 : resolvedModules.get(file.path)) == null ? void 0 : _a2.get(moduleName, mode);
            }
            function getResolvedModuleFromModuleSpecifier(moduleSpecifier) {
                const sourceFile = getSourceFileOfNode(moduleSpecifier);
                Debug.assertIsDefined(sourceFile, "`moduleSpecifier` must have a `SourceFile` ancestor. Use `program.getResolvedModule` instead to provide the containing file and resolution mode.");
                return getResolvedModule(sourceFile, moduleSpecifier.text, getModeForUsageLocation2(sourceFile, moduleSpecifier));
            }
            function getResolvedTypeReferenceDirective(file, typeDirectiveName, mode) {
                var _a2;
                return (_a2 = resolvedTypeReferenceDirectiveNames == null ? void 0 : resolvedTypeReferenceDirectiveNames.get(file.path)) == null ? void 0 : _a2.get(typeDirectiveName, mode);
            }
            function forEachResolvedModule(callback, file) {
                forEachResolution(resolvedModules, callback, file);
            }
            function forEachResolvedTypeReferenceDirective(callback, file) {
                forEachResolution(resolvedTypeReferenceDirectiveNames, callback, file);
            }
            function forEachResolution(resolutionCache, callback, file) {
                var _a2;
                if (file)
                    (_a2 = resolutionCache == null ? void 0 : resolutionCache.get(file.path)) == null ? void 0 : _a2.forEach((resolution, name, mode) => callback(resolution, name, mode, file.path));
                else
                    resolutionCache == null ? void 0 : resolutionCache.forEach((resolutions, filePath) => resolutions.forEach((resolution, name, mode) => callback(resolution, name, mode, filePath)));
            }
            function getPackagesMap() {
                if (packageMap)
                    return packageMap;
                packageMap = /* @__PURE__ */ new Map();
                forEachResolvedModule(({ resolvedModule }) => {
                    if (resolvedModule == null ? void 0 : resolvedModule.packageId)
                        packageMap.set(resolvedModule.packageId.name, resolvedModule.extension === ".d.ts" /* Dts */ || !!packageMap.get(resolvedModule.packageId.name));
                });
                return packageMap;
            }
            function typesPackageExists(packageName) {
                return getPackagesMap().has(getTypesPackageName(packageName));
            }
            function packageBundlesTypes(packageName) {
                return !!getPackagesMap().get(packageName);
            }
            function addResolutionDiagnostics(resolution) {
                var _a2;
                if (!((_a2 = resolution.resolutionDiagnostics) == null ? void 0 : _a2.length))
                    return;
                (fileProcessingDiagnostics ?? (fileProcessingDiagnostics = [])).push({
                    kind: 2 /* ResolutionDiagnostics */,
                    diagnostics: resolution.resolutionDiagnostics
                });
            }
            function addResolutionDiagnosticsFromResolutionOrCache(containingFile, name, resolution, mode) {
                if (host.resolveModuleNameLiterals || !host.resolveModuleNames)
                    return addResolutionDiagnostics(resolution);
                if (!moduleResolutionCache || isExternalModuleNameRelative(name))
                    return;
                const containingFileName = getNormalizedAbsolutePath(containingFile.originalFileName, currentDirectory);
                const containingDir = getDirectoryPath(containingFileName);
                const redirectedReference = getRedirectReferenceForResolution(containingFile);
                const fromCache = moduleResolutionCache.getFromNonRelativeNameCache(name, mode, containingDir, redirectedReference);
                if (fromCache)
                    addResolutionDiagnostics(fromCache);
            }
            function resolveModuleNamesWorker(moduleNames, containingFile, reusedNames) {
                var _a2, _b2;
                if (!moduleNames.length)
                    return emptyArray;
                const containingFileName = getNormalizedAbsolutePath(containingFile.originalFileName, currentDirectory);
                const redirectedReference = getRedirectReferenceForResolution(containingFile);
                (_a2 = tracing) == null ? void 0 : _a2.push(tracing.Phase.Program, "resolveModuleNamesWorker", { containingFileName });
                mark("beforeResolveModule");
                const result = actualResolveModuleNamesWorker(moduleNames, containingFileName, redirectedReference, options, containingFile, reusedNames);
                mark("afterResolveModule");
                measure("ResolveModule", "beforeResolveModule", "afterResolveModule");
                (_b2 = tracing) == null ? void 0 : _b2.pop();
                return result;
            }
            function resolveTypeReferenceDirectiveNamesWorker(typeDirectiveNames, containingFile, reusedNames) {
                var _a2, _b2;
                if (!typeDirectiveNames.length)
                    return [];
                const containingSourceFile = !isString(containingFile) ? containingFile : void 0;
                const containingFileName = !isString(containingFile) ? getNormalizedAbsolutePath(containingFile.originalFileName, currentDirectory) : containingFile;
                const redirectedReference = containingSourceFile && getRedirectReferenceForResolution(containingSourceFile);
                (_a2 = tracing) == null ? void 0 : _a2.push(tracing.Phase.Program, "resolveTypeReferenceDirectiveNamesWorker", { containingFileName });
                mark("beforeResolveTypeReference");
                const result = actualResolveTypeReferenceDirectiveNamesWorker(typeDirectiveNames, containingFileName, redirectedReference, options, containingSourceFile, reusedNames);
                mark("afterResolveTypeReference");
                measure("ResolveTypeReference", "beforeResolveTypeReference", "afterResolveTypeReference");
                (_b2 = tracing) == null ? void 0 : _b2.pop();
                return result;
            }
            function getRedirectReferenceForResolution(file) {
                const redirect = getResolvedProjectReferenceToRedirect(file.originalFileName);
                if (redirect || !isDeclarationFileName(file.originalFileName))
                    return redirect;
                const resultFromDts = getRedirectReferenceForResolutionFromSourceOfProject(file.path);
                if (resultFromDts)
                    return resultFromDts;
                if (!host.realpath || !options.preserveSymlinks || !file.originalFileName.includes(nodeModulesPathPart))
                    return void 0;
                const realDeclarationPath = toPath3(host.realpath(file.originalFileName));
                return realDeclarationPath === file.path ? void 0 : getRedirectReferenceForResolutionFromSourceOfProject(realDeclarationPath);
            }
            function getRedirectReferenceForResolutionFromSourceOfProject(filePath) {
                const source = getSourceOfProjectReferenceRedirect(filePath);
                if (isString(source))
                    return getResolvedProjectReferenceToRedirect(source);
                if (!source)
                    return void 0;
                return forEachResolvedProjectReference2((resolvedRef) => {
                    const out = outFile(resolvedRef.commandLine.options);
                    if (!out)
                        return void 0;
                    return toPath3(out) === filePath ? resolvedRef : void 0;
                });
            }
            function compareDefaultLibFiles(a, b) {
                return compareValues(getDefaultLibFilePriority(a), getDefaultLibFilePriority(b));
            }
            function getDefaultLibFilePriority(a) {
                if (containsPath(defaultLibraryPath, a.fileName, 
                /*ignoreCase*/
                false)) {
                    const basename = getBaseFileName(a.fileName);
                    if (basename === "lib.d.ts" || basename === "lib.es6.d.ts")
                        return 0;
                    const name = removeSuffix(removePrefix(basename, "lib."), ".d.ts");
                    const index = libs.indexOf(name);
                    if (index !== -1)
                        return index + 1;
                }
                return libs.length + 2;
            }
            function toPath3(fileName) {
                return toPath(fileName, currentDirectory, getCanonicalFileName);
            }
            function getCommonSourceDirectory2() {
                if (commonSourceDirectory === void 0) {
                    const emittedFiles = filter(files, (file) => sourceFileMayBeEmitted(file, program));
                    commonSourceDirectory = getCommonSourceDirectory(options, () => mapDefined(emittedFiles, (file) => file.isDeclarationFile ? void 0 : file.fileName), currentDirectory, getCanonicalFileName, (commonSourceDirectory2) => checkSourceFilesBelongToPath(emittedFiles, commonSourceDirectory2));
                }
                return commonSourceDirectory;
            }
            function getClassifiableNames() {
                var _a2;
                if (!classifiableNames) {
                    getTypeChecker();
                    classifiableNames = /* @__PURE__ */ new Set();
                    for (const sourceFile of files) {
                        (_a2 = sourceFile.classifiableNames) == null ? void 0 : _a2.forEach((value) => classifiableNames.add(value));
                    }
                }
                return classifiableNames;
            }
            function resolveModuleNamesReusingOldState(moduleNames, file) {
                if (structureIsReused === 0 /* Not */ && !file.ambientModuleNames.length) {
                    return resolveModuleNamesWorker(moduleNames, file, 
                    /*reusedNames*/
                    void 0);
                }
                let unknownModuleNames;
                let result;
                let reusedNames;
                const predictedToResolveToAmbientModuleMarker = emptyResolution;
                const oldSourceFile = oldProgram && oldProgram.getSourceFile(file.fileName);
                for (let i = 0; i < moduleNames.length; i++) {
                    const moduleName = moduleNames[i];
                    if (file === oldSourceFile && !hasInvalidatedResolutions(file.path)) {
                        const oldResolution = oldProgram == null ? void 0 : oldProgram.getResolvedModule(file, moduleName.text, getModeForUsageLocation2(file, moduleName));
                        if (oldResolution == null ? void 0 : oldResolution.resolvedModule) {
                            if (isTraceEnabled(options, host)) {
                                trace(host, oldResolution.resolvedModule.packageId ? Diagnostics.Reusing_resolution_of_module_0_from_1_of_old_program_it_was_successfully_resolved_to_2_with_Package_ID_3 : Diagnostics.Reusing_resolution_of_module_0_from_1_of_old_program_it_was_successfully_resolved_to_2, moduleName.text, getNormalizedAbsolutePath(file.originalFileName, currentDirectory), oldResolution.resolvedModule.resolvedFileName, oldResolution.resolvedModule.packageId && packageIdToString(oldResolution.resolvedModule.packageId));
                            }
                            (result ?? (result = new Array(moduleNames.length)))[i] = oldResolution;
                            (reusedNames ?? (reusedNames = [])).push(moduleName);
                            continue;
                        }
                    }
                    let resolvesToAmbientModuleInNonModifiedFile = false;
                    if (contains(file.ambientModuleNames, moduleName.text)) {
                        resolvesToAmbientModuleInNonModifiedFile = true;
                        if (isTraceEnabled(options, host)) {
                            trace(host, Diagnostics.Module_0_was_resolved_as_locally_declared_ambient_module_in_file_1, moduleName.text, getNormalizedAbsolutePath(file.originalFileName, currentDirectory));
                        }
                    }
                    else {
                        resolvesToAmbientModuleInNonModifiedFile = moduleNameResolvesToAmbientModuleInNonModifiedFile(moduleName);
                    }
                    if (resolvesToAmbientModuleInNonModifiedFile) {
                        (result || (result = new Array(moduleNames.length)))[i] = predictedToResolveToAmbientModuleMarker;
                    }
                    else {
                        (unknownModuleNames ?? (unknownModuleNames = [])).push(moduleName);
                    }
                }
                const resolutions = unknownModuleNames && unknownModuleNames.length ? resolveModuleNamesWorker(unknownModuleNames, file, reusedNames) : emptyArray;
                if (!result) {
                    Debug.assert(resolutions.length === moduleNames.length);
                    return resolutions;
                }
                let j = 0;
                for (let i = 0; i < result.length; i++) {
                    if (!result[i]) {
                        result[i] = resolutions[j];
                        j++;
                    }
                }
                Debug.assert(j === resolutions.length);
                return result;
                function moduleNameResolvesToAmbientModuleInNonModifiedFile(moduleName) {
                    var _a2;
                    const resolutionToFile = (_a2 = oldProgram == null ? void 0 : oldProgram.getResolvedModule(file, moduleName.text, getModeForUsageLocation2(file, moduleName))) == null ? void 0 : _a2.resolvedModule;
                    const resolvedFile = resolutionToFile && oldProgram.getSourceFile(resolutionToFile.resolvedFileName);
                    if (resolutionToFile && resolvedFile) {
                        return false;
                    }
                    const unmodifiedFile = ambientModuleNameToUnmodifiedFileName.get(moduleName.text);
                    if (!unmodifiedFile) {
                        return false;
                    }
                    if (isTraceEnabled(options, host)) {
                        trace(host, Diagnostics.Module_0_was_resolved_as_ambient_module_declared_in_1_since_this_file_was_not_modified, moduleName.text, unmodifiedFile);
                    }
                    return true;
                }
            }
            function resolveTypeReferenceDirectiveNamesReusingOldState(typeDirectiveNames, containingFile) {
                var _a2;
                if (structureIsReused === 0 /* Not */) {
                    return resolveTypeReferenceDirectiveNamesWorker(typeDirectiveNames, containingFile, 
                    /*reusedNames*/
                    void 0);
                }
                let unknownTypeReferenceDirectiveNames;
                let result;
                let reusedNames;
                const containingSourceFile = !isString(containingFile) ? containingFile : void 0;
                const oldSourceFile = !isString(containingFile) ? oldProgram && oldProgram.getSourceFile(containingFile.fileName) : void 0;
                const canReuseResolutions = !isString(containingFile) ? containingFile === oldSourceFile && !hasInvalidatedResolutions(containingFile.path) : !hasInvalidatedResolutions(toPath3(containingFile));
                for (let i = 0; i < typeDirectiveNames.length; i++) {
                    const entry = typeDirectiveNames[i];
                    if (canReuseResolutions) {
                        const typeDirectiveName = getTypeReferenceResolutionName(entry);
                        const mode = getModeForFileReference(entry, containingSourceFile == null ? void 0 : containingSourceFile.impliedNodeFormat);
                        const oldResolution = !isString(containingFile) ? oldProgram == null ? void 0 : oldProgram.getResolvedTypeReferenceDirective(containingFile, typeDirectiveName, mode) : (_a2 = oldProgram == null ? void 0 : oldProgram.getAutomaticTypeDirectiveResolutions()) == null ? void 0 : _a2.get(typeDirectiveName, mode);
                        if (oldResolution == null ? void 0 : oldResolution.resolvedTypeReferenceDirective) {
                            if (isTraceEnabled(options, host)) {
                                trace(host, oldResolution.resolvedTypeReferenceDirective.packageId ? Diagnostics.Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_successfully_resolved_to_2_with_Package_ID_3 : Diagnostics.Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_successfully_resolved_to_2, typeDirectiveName, !isString(containingFile) ? getNormalizedAbsolutePath(containingFile.originalFileName, currentDirectory) : containingFile, oldResolution.resolvedTypeReferenceDirective.resolvedFileName, oldResolution.resolvedTypeReferenceDirective.packageId && packageIdToString(oldResolution.resolvedTypeReferenceDirective.packageId));
                            }
                            (result ?? (result = new Array(typeDirectiveNames.length)))[i] = oldResolution;
                            (reusedNames ?? (reusedNames = [])).push(entry);
                            continue;
                        }
                    }
                    (unknownTypeReferenceDirectiveNames ?? (unknownTypeReferenceDirectiveNames = [])).push(entry);
                }
                if (!unknownTypeReferenceDirectiveNames)
                    return result || emptyArray;
                const resolutions = resolveTypeReferenceDirectiveNamesWorker(unknownTypeReferenceDirectiveNames, containingFile, reusedNames);
                if (!result) {
                    Debug.assert(resolutions.length === typeDirectiveNames.length);
                    return resolutions;
                }
                let j = 0;
                for (let i = 0; i < result.length; i++) {
                    if (!result[i]) {
                        result[i] = resolutions[j];
                        j++;
                    }
                }
                Debug.assert(j === resolutions.length);
                return result;
            }
            function canReuseProjectReferences() {
                return !forEachProjectReference(oldProgram.getProjectReferences(), oldProgram.getResolvedProjectReferences(), (oldResolvedRef, parent2, index) => {
                    const newRef = (parent2 ? parent2.commandLine.projectReferences : projectReferences)[index];
                    const newResolvedRef = parseProjectReferenceConfigFile(newRef);
                    if (oldResolvedRef) {
                        return !newResolvedRef || newResolvedRef.sourceFile !== oldResolvedRef.sourceFile || !arrayIsEqualTo(oldResolvedRef.commandLine.fileNames, newResolvedRef.commandLine.fileNames);
                    }
                    else {
                        return newResolvedRef !== void 0;
                    }
                }, (oldProjectReferences, parent2) => {
                    const newReferences = parent2 ? getResolvedProjectReferenceByPath(parent2.sourceFile.path).commandLine.projectReferences : projectReferences;
                    return !arrayIsEqualTo(oldProjectReferences, newReferences, projectReferenceIsEqualTo);
                });
            }
            function tryReuseStructureFromOldProgram() {
                var _a2;
                if (!oldProgram) {
                    return 0 /* Not */;
                }
                const oldOptions = oldProgram.getCompilerOptions();
                if (changesAffectModuleResolution(oldOptions, options)) {
                    return 0 /* Not */;
                }
                const oldRootNames = oldProgram.getRootFileNames();
                if (!arrayIsEqualTo(oldRootNames, rootNames)) {
                    return 0 /* Not */;
                }
                if (!canReuseProjectReferences()) {
                    return 0 /* Not */;
                }
                if (projectReferences) {
                    resolvedProjectReferences = projectReferences.map(parseProjectReferenceConfigFile);
                }
                const newSourceFiles = [];
                const modifiedSourceFiles = [];
                structureIsReused = 2 /* Completely */;
                if (forEachEntry(oldProgram.getMissingFilePaths(), (missingFileName) => host.fileExists(missingFileName))) {
                    return 0 /* Not */;
                }
                const oldSourceFiles = oldProgram.getSourceFiles();
                let SeenPackageName;
                ((SeenPackageName2) => {
                    SeenPackageName2[SeenPackageName2["Exists"] = 0] = "Exists";
                    SeenPackageName2[SeenPackageName2["Modified"] = 1] = "Modified";
                })(SeenPackageName || (SeenPackageName = {}));
                const seenPackageNames = /* @__PURE__ */ new Map();
                for (const oldSourceFile of oldSourceFiles) {
                    const sourceFileOptions = getCreateSourceFileOptions(oldSourceFile.fileName, moduleResolutionCache, host, options);
                    let newSourceFile = host.getSourceFileByPath ? host.getSourceFileByPath(oldSourceFile.fileName, oldSourceFile.resolvedPath, sourceFileOptions, 
                    /*onError*/
                    void 0, shouldCreateNewSourceFile) : host.getSourceFile(oldSourceFile.fileName, sourceFileOptions, 
                    /*onError*/
                    void 0, shouldCreateNewSourceFile);
                    if (!newSourceFile) {
                        return 0 /* Not */;
                    }
                    newSourceFile.packageJsonLocations = ((_a2 = sourceFileOptions.packageJsonLocations) == null ? void 0 : _a2.length) ? sourceFileOptions.packageJsonLocations : void 0;
                    newSourceFile.packageJsonScope = sourceFileOptions.packageJsonScope;
                    Debug.assert(!newSourceFile.redirectInfo, "Host should not return a redirect source file from `getSourceFile`");
                    let fileChanged;
                    if (oldSourceFile.redirectInfo) {
                        if (newSourceFile !== oldSourceFile.redirectInfo.unredirected) {
                            return 0 /* Not */;
                        }
                        fileChanged = false;
                        newSourceFile = oldSourceFile;
                    }
                    else if (oldProgram.redirectTargetsMap.has(oldSourceFile.path)) {
                        if (newSourceFile !== oldSourceFile) {
                            return 0 /* Not */;
                        }
                        fileChanged = false;
                    }
                    else {
                        fileChanged = newSourceFile !== oldSourceFile;
                    }
                    newSourceFile.path = oldSourceFile.path;
                    newSourceFile.originalFileName = oldSourceFile.originalFileName;
                    newSourceFile.resolvedPath = oldSourceFile.resolvedPath;
                    newSourceFile.fileName = oldSourceFile.fileName;
                    const packageName = oldProgram.sourceFileToPackageName.get(oldSourceFile.path);
                    if (packageName !== void 0) {
                        const prevKind = seenPackageNames.get(packageName);
                        const newKind = fileChanged ? 1 /* Modified */ : 0 /* Exists */;
                        if (prevKind !== void 0 && newKind === 1 /* Modified */ || prevKind === 1 /* Modified */) {
                            return 0 /* Not */;
                        }
                        seenPackageNames.set(packageName, newKind);
                    }
                    if (fileChanged) {
                        if (oldSourceFile.impliedNodeFormat !== newSourceFile.impliedNodeFormat) {
                            structureIsReused = 1 /* SafeModules */;
                        }
                        else if (!arrayIsEqualTo(oldSourceFile.libReferenceDirectives, newSourceFile.libReferenceDirectives, fileReferenceIsEqualTo)) {
                            structureIsReused = 1 /* SafeModules */;
                        }
                        else if (oldSourceFile.hasNoDefaultLib !== newSourceFile.hasNoDefaultLib) {
                            structureIsReused = 1 /* SafeModules */;
                        }
                        else if (!arrayIsEqualTo(oldSourceFile.referencedFiles, newSourceFile.referencedFiles, fileReferenceIsEqualTo)) {
                            structureIsReused = 1 /* SafeModules */;
                        }
                        else {
                            collectExternalModuleReferences(newSourceFile);
                            if (!arrayIsEqualTo(oldSourceFile.imports, newSourceFile.imports, moduleNameIsEqualTo)) {
                                structureIsReused = 1 /* SafeModules */;
                            }
                            else if (!arrayIsEqualTo(oldSourceFile.moduleAugmentations, newSourceFile.moduleAugmentations, moduleNameIsEqualTo)) {
                                structureIsReused = 1 /* SafeModules */;
                            }
                            else if ((oldSourceFile.flags & 12582912 /* PermanentlySetIncrementalFlags */) !== (newSourceFile.flags & 12582912 /* PermanentlySetIncrementalFlags */)) {
                                structureIsReused = 1 /* SafeModules */;
                            }
                            else if (!arrayIsEqualTo(oldSourceFile.typeReferenceDirectives, newSourceFile.typeReferenceDirectives, fileReferenceIsEqualTo)) {
                                structureIsReused = 1 /* SafeModules */;
                            }
                        }
                        modifiedSourceFiles.push(newSourceFile);
                    }
                    else if (hasInvalidatedResolutions(oldSourceFile.path)) {
                        structureIsReused = 1 /* SafeModules */;
                        modifiedSourceFiles.push(newSourceFile);
                    }
                    else {
                        for (const moduleName of oldSourceFile.ambientModuleNames) {
                            ambientModuleNameToUnmodifiedFileName.set(moduleName, oldSourceFile.fileName);
                        }
                    }
                    newSourceFiles.push(newSourceFile);
                }
                if (structureIsReused !== 2 /* Completely */) {
                    return structureIsReused;
                }
                for (const newSourceFile of modifiedSourceFiles) {
                    const moduleNames = getModuleNames(newSourceFile);
                    const resolutions = resolveModuleNamesReusingOldState(moduleNames, newSourceFile);
                    (resolvedModulesProcessing ?? (resolvedModulesProcessing = /* @__PURE__ */ new Map())).set(newSourceFile.path, resolutions);
                    const resolutionsChanged = hasChangesInResolutions(moduleNames, resolutions, (name) => oldProgram.getResolvedModule(newSourceFile, name.text, getModeForUsageLocation2(newSourceFile, name)), moduleResolutionIsEqualTo);
                    if (resolutionsChanged)
                        structureIsReused = 1 /* SafeModules */;
                    const typesReferenceDirectives = newSourceFile.typeReferenceDirectives;
                    const typeReferenceResolutions = resolveTypeReferenceDirectiveNamesReusingOldState(typesReferenceDirectives, newSourceFile);
                    (resolvedTypeReferenceDirectiveNamesProcessing ?? (resolvedTypeReferenceDirectiveNamesProcessing = /* @__PURE__ */ new Map())).set(newSourceFile.path, typeReferenceResolutions);
                    const typeReferenceResolutionsChanged = hasChangesInResolutions(typesReferenceDirectives, typeReferenceResolutions, (name) => oldProgram.getResolvedTypeReferenceDirective(newSourceFile, getTypeReferenceResolutionName(name), getModeForFileReference(name, newSourceFile.impliedNodeFormat)), typeDirectiveIsEqualTo);
                    if (typeReferenceResolutionsChanged)
                        structureIsReused = 1 /* SafeModules */;
                }
                if (structureIsReused !== 2 /* Completely */) {
                    return structureIsReused;
                }
                if (changesAffectingProgramStructure(oldOptions, options)) {
                    return 1 /* SafeModules */;
                }
                if (oldProgram.resolvedLibReferences && forEachEntry(oldProgram.resolvedLibReferences, (resolution, libFileName) => pathForLibFileWorker(libFileName).actual !== resolution.actual)) {
                    return 1 /* SafeModules */;
                }
                if (host.hasChangedAutomaticTypeDirectiveNames) {
                    if (host.hasChangedAutomaticTypeDirectiveNames())
                        return 1 /* SafeModules */;
                }
                else {
                    automaticTypeDirectiveNames = getAutomaticTypeDirectiveNames(options, host);
                    if (!arrayIsEqualTo(oldProgram.getAutomaticTypeDirectiveNames(), automaticTypeDirectiveNames))
                        return 1 /* SafeModules */;
                }
                missingFileNames = oldProgram.getMissingFilePaths();
                Debug.assert(newSourceFiles.length === oldProgram.getSourceFiles().length);
                for (const newSourceFile of newSourceFiles) {
                    filesByName.set(newSourceFile.path, newSourceFile);
                }
                const oldFilesByNameMap = oldProgram.getFilesByNameMap();
                oldFilesByNameMap.forEach((oldFile, path) => {
                    if (!oldFile) {
                        filesByName.set(path, oldFile);
                        return;
                    }
                    if (oldFile.path === path) {
                        if (oldProgram.isSourceFileFromExternalLibrary(oldFile)) {
                            sourceFilesFoundSearchingNodeModules.set(oldFile.path, true);
                        }
                        return;
                    }
                    filesByName.set(path, filesByName.get(oldFile.path));
                });
                files = newSourceFiles;
                fileReasons = oldProgram.getFileIncludeReasons();
                fileProcessingDiagnostics = oldProgram.getFileProcessingDiagnostics();
                resolvedTypeReferenceDirectives = oldProgram.getResolvedTypeReferenceDirectives();
                automaticTypeDirectiveNames = oldProgram.getAutomaticTypeDirectiveNames();
                automaticTypeDirectiveResolutions = oldProgram.getAutomaticTypeDirectiveResolutions();
                sourceFileToPackageName = oldProgram.sourceFileToPackageName;
                redirectTargetsMap = oldProgram.redirectTargetsMap;
                usesUriStyleNodeCoreModules = oldProgram.usesUriStyleNodeCoreModules;
                resolvedModules = oldProgram.resolvedModules;
                resolvedTypeReferenceDirectiveNames = oldProgram.resolvedTypeReferenceDirectiveNames;
                resolvedLibReferences = oldProgram.resolvedLibReferences;
                packageMap = oldProgram.getCurrentPackagesMap();
                return 2 /* Completely */;
            }
            function getEmitHost(writeFileCallback) {
                return {
                    getPrependNodes,
                    getCanonicalFileName,
                    getCommonSourceDirectory: program.getCommonSourceDirectory,
                    getCompilerOptions: program.getCompilerOptions,
                    getCurrentDirectory: () => currentDirectory,
                    getSourceFile: program.getSourceFile,
                    getSourceFileByPath: program.getSourceFileByPath,
                    getSourceFiles: program.getSourceFiles,
                    getLibFileFromReference: program.getLibFileFromReference,
                    isSourceFileFromExternalLibrary,
                    getResolvedProjectReferenceToRedirect,
                    getProjectReferenceRedirect,
                    isSourceOfProjectReferenceRedirect,
                    getSymlinkCache,
                    writeFile: writeFileCallback || writeFile2,
                    isEmitBlocked,
                    readFile: (f) => host.readFile(f),
                    fileExists: (f) => {
                        const path = toPath3(f);
                        if (getSourceFileByPath(path))
                            return true;
                        if (missingFileNames.has(path))
                            return false;
                        return host.fileExists(f);
                    },
                    useCaseSensitiveFileNames: () => host.useCaseSensitiveFileNames(),
                    getBuildInfo: (bundle) => {
                        var _a2;
                        return (_a2 = program.getBuildInfo) == null ? void 0 : _a2.call(program, bundle);
                    },
                    getSourceFileFromReference: (file, ref) => program.getSourceFileFromReference(file, ref),
                    redirectTargetsMap,
                    getFileIncludeReasons: program.getFileIncludeReasons,
                    createHash: maybeBind(host, host.createHash)
                };
            }
            function writeFile2(fileName, text, writeByteOrderMark, onError, sourceFiles, data) {
                host.writeFile(fileName, text, writeByteOrderMark, onError, sourceFiles, data);
            }
            function emitBuildInfo(writeFileCallback) {
                var _a2, _b2;
                Debug.assert(!outFile(options));
                (_a2 = tracing) == null ? void 0 : _a2.push(tracing.Phase.Emit, "emitBuildInfo", {}, 
                /*separateBeginAndEnd*/
                true);
                mark("beforeEmit");
                const emitResult = emitFiles(notImplementedResolver, getEmitHost(writeFileCallback), 
                /*targetSourceFile*/
                void 0, 
                /*transformers*/
                noTransformers, 
                /*emitOnly*/
                false, 
                /*onlyBuildInfo*/
                true);
                mark("afterEmit");
                measure("Emit", "beforeEmit", "afterEmit");
                (_b2 = tracing) == null ? void 0 : _b2.pop();
                return emitResult;
            }
            function getResolvedProjectReferences() {
                return resolvedProjectReferences;
            }
            function getProjectReferences() {
                return projectReferences;
            }
            function getPrependNodes() {
                return createPrependNodes(projectReferences, (_ref, index) => {
                    var _a2;
                    return (_a2 = resolvedProjectReferences[index]) == null ? void 0 : _a2.commandLine;
                }, (fileName) => {
                    const path = toPath3(fileName);
                    const sourceFile = getSourceFileByPath(path);
                    return sourceFile ? sourceFile.text : filesByName.has(path) ? void 0 : host.readFile(path);
                }, host);
            }
            function isSourceFileFromExternalLibrary(file) {
                return !!sourceFilesFoundSearchingNodeModules.get(file.path);
            }
            function isSourceFileDefaultLibrary(file) {
                if (!file.isDeclarationFile) {
                    return false;
                }
                if (file.hasNoDefaultLib) {
                    return true;
                }
                if (!options.noLib) {
                    return false;
                }
                const equalityComparer = host.useCaseSensitiveFileNames() ? equateStringsCaseSensitive : equateStringsCaseInsensitive;
                if (!options.lib) {
                    return equalityComparer(file.fileName, getDefaultLibraryFileName());
                }
                else {
                    return some(options.lib, (libFileName) => equalityComparer(file.fileName, resolvedLibReferences.get(libFileName).actual));
                }
            }
            function getTypeChecker() {
                return typeChecker || (typeChecker = createTypeChecker(program));
            }
            function emit(sourceFile, writeFileCallback, cancellationToken, emitOnly, transformers, forceDtsEmit) {
                var _a2, _b2;
                (_a2 = tracing) == null ? void 0 : _a2.push(tracing.Phase.Emit, "emit", { path: sourceFile == null ? void 0 : sourceFile.path }, 
                /*separateBeginAndEnd*/
                true);
                const result = runWithCancellationToken(() => emitWorker(program, sourceFile, writeFileCallback, cancellationToken, emitOnly, transformers, forceDtsEmit));
                (_b2 = tracing) == null ? void 0 : _b2.pop();
                return result;
            }
            function isEmitBlocked(emitFileName) {
                return hasEmitBlockingDiagnostics.has(toPath3(emitFileName));
            }
            function emitWorker(program2, sourceFile, writeFileCallback, cancellationToken, emitOnly, customTransformers, forceDtsEmit) {
                if (!forceDtsEmit) {
                    const result = handleNoEmitOptions(program2, sourceFile, writeFileCallback, cancellationToken);
                    if (result)
                        return result;
                }
                const emitResolver = getTypeChecker().getEmitResolver(outFile(options) ? void 0 : sourceFile, cancellationToken);
                mark("beforeEmit");
                const emitResult = emitFiles(emitResolver, getEmitHost(writeFileCallback), sourceFile, getTransformers(options, customTransformers, emitOnly), emitOnly, 
                /*onlyBuildInfo*/
                false, forceDtsEmit);
                mark("afterEmit");
                measure("Emit", "beforeEmit", "afterEmit");
                return emitResult;
            }
            function getSourceFile(fileName) {
                return getSourceFileByPath(toPath3(fileName));
            }
            function getSourceFileByPath(path) {
                return filesByName.get(path) || void 0;
            }
            function getDiagnosticsHelper(sourceFile, getDiagnostics2, cancellationToken) {
                if (sourceFile) {
                    return sortAndDeduplicateDiagnostics(getDiagnostics2(sourceFile, cancellationToken));
                }
                return sortAndDeduplicateDiagnostics(flatMap(program.getSourceFiles(), (sourceFile2) => {
                    if (cancellationToken) {
                        cancellationToken.throwIfCancellationRequested();
                    }
                    return getDiagnostics2(sourceFile2, cancellationToken);
                }));
            }
            function getSyntacticDiagnostics(sourceFile, cancellationToken) {
                return getDiagnosticsHelper(sourceFile, getSyntacticDiagnosticsForFile, cancellationToken);
            }
            function getSemanticDiagnostics(sourceFile, cancellationToken) {
                return getDiagnosticsHelper(sourceFile, getSemanticDiagnosticsForFile, cancellationToken);
            }
            function getCachedSemanticDiagnostics(sourceFile) {
                var _a2;
                return sourceFile ? (_a2 = cachedBindAndCheckDiagnosticsForFile.perFile) == null ? void 0 : _a2.get(sourceFile.path) : cachedBindAndCheckDiagnosticsForFile.allDiagnostics;
            }
            function getBindAndCheckDiagnostics(sourceFile, cancellationToken) {
                return getBindAndCheckDiagnosticsForFile(sourceFile, cancellationToken);
            }
            function getProgramDiagnostics(sourceFile) {
                var _a2;
                if (skipTypeChecking(sourceFile, options, program)) {
                    return emptyArray;
                }
                const programDiagnosticsInFile = programDiagnostics.getDiagnostics(sourceFile.fileName);
                if (!((_a2 = sourceFile.commentDirectives) == null ? void 0 : _a2.length)) {
                    return programDiagnosticsInFile;
                }
                return getDiagnosticsWithPrecedingDirectives(sourceFile, sourceFile.commentDirectives, programDiagnosticsInFile).diagnostics;
            }
            function getDeclarationDiagnostics2(sourceFile, cancellationToken) {
                const options2 = program.getCompilerOptions();
                if (!sourceFile || outFile(options2)) {
                    return getDeclarationDiagnosticsWorker(sourceFile, cancellationToken);
                }
                else {
                    return getDiagnosticsHelper(sourceFile, getDeclarationDiagnosticsForFile, cancellationToken);
                }
            }
            function getSyntacticDiagnosticsForFile(sourceFile) {
                if (isSourceFileJS(sourceFile)) {
                    if (!sourceFile.additionalSyntacticDiagnostics) {
                        sourceFile.additionalSyntacticDiagnostics = getJSSyntacticDiagnosticsForFile(sourceFile);
                    }
                    return concatenate(sourceFile.additionalSyntacticDiagnostics, sourceFile.parseDiagnostics);
                }
                return sourceFile.parseDiagnostics;
            }
            function runWithCancellationToken(func) {
                try {
                    return func();
                }
                catch (e) {
                    if (e instanceof OperationCanceledException) {
                        typeChecker = void 0;
                    }
                    throw e;
                }
            }
            function getSemanticDiagnosticsForFile(sourceFile, cancellationToken) {
                return concatenate(filterSemanticDiagnostics(getBindAndCheckDiagnosticsForFile(sourceFile, cancellationToken), options), getProgramDiagnostics(sourceFile));
            }
            function getBindAndCheckDiagnosticsForFile(sourceFile, cancellationToken) {
                return getAndCacheDiagnostics(sourceFile, cancellationToken, cachedBindAndCheckDiagnosticsForFile, getBindAndCheckDiagnosticsForFileNoCache);
            }
            function getBindAndCheckDiagnosticsForFileNoCache(sourceFile, cancellationToken) {
                return runWithCancellationToken(() => {
                    if (skipTypeChecking(sourceFile, options, program)) {
                        return emptyArray;
                    }
                    const typeChecker2 = getTypeChecker();
                    Debug.assert(!!sourceFile.bindDiagnostics);
                    const isJs = sourceFile.scriptKind === 1 /* JS */ || sourceFile.scriptKind === 2 /* JSX */;
                    const isCheckJs = isJs && isCheckJsEnabledForFile(sourceFile, options);
                    const isPlainJs = isPlainJsFile(sourceFile, options.checkJs);
                    const isTsNoCheck = !!sourceFile.checkJsDirective && sourceFile.checkJsDirective.enabled === false;
                    const includeBindAndCheckDiagnostics = !isTsNoCheck && (sourceFile.scriptKind === 3 /* TS */ || sourceFile.scriptKind === 4 /* TSX */ || sourceFile.scriptKind === 5 /* External */ || isPlainJs || isCheckJs || sourceFile.scriptKind === 7 /* Deferred */);
                    let bindDiagnostics = includeBindAndCheckDiagnostics ? sourceFile.bindDiagnostics : emptyArray;
                    let checkDiagnostics = includeBindAndCheckDiagnostics ? typeChecker2.getDiagnostics(sourceFile, cancellationToken) : emptyArray;
                    if (isPlainJs) {
                        bindDiagnostics = filter(bindDiagnostics, (d) => plainJSErrors.has(d.code));
                        checkDiagnostics = filter(checkDiagnostics, (d) => plainJSErrors.has(d.code));
                    }
                    return getMergedBindAndCheckDiagnostics(sourceFile, includeBindAndCheckDiagnostics && !isPlainJs, bindDiagnostics, checkDiagnostics, isCheckJs ? sourceFile.jsDocDiagnostics : void 0);
                });
            }
            function getMergedBindAndCheckDiagnostics(sourceFile, includeBindAndCheckDiagnostics, ...allDiagnostics) {
                var _a2;
                const flatDiagnostics = flatten(allDiagnostics);
                if (!includeBindAndCheckDiagnostics || !((_a2 = sourceFile.commentDirectives) == null ? void 0 : _a2.length)) {
                    return flatDiagnostics;
                }
                const { diagnostics, directives } = getDiagnosticsWithPrecedingDirectives(sourceFile, sourceFile.commentDirectives, flatDiagnostics);
                for (const errorExpectation of directives.getUnusedExpectations()) {
                    diagnostics.push(createDiagnosticForRange(sourceFile, errorExpectation.range, Diagnostics.Unused_ts_expect_error_directive));
                }
                return diagnostics;
            }
            function getDiagnosticsWithPrecedingDirectives(sourceFile, commentDirectives, flatDiagnostics) {
                const directives = createCommentDirectivesMap(sourceFile, commentDirectives);
                const diagnostics = flatDiagnostics.filter((diagnostic) => markPrecedingCommentDirectiveLine(diagnostic, directives) === -1);
                return { diagnostics, directives };
            }
            function getSuggestionDiagnostics(sourceFile, cancellationToken) {
                return runWithCancellationToken(() => {
                    return getTypeChecker().getSuggestionDiagnostics(sourceFile, cancellationToken);
                });
            }
            function markPrecedingCommentDirectiveLine(diagnostic, directives) {
                const { file, start } = diagnostic;
                if (!file) {
                    return -1;
                }
                const lineStarts = getLineStarts(file);
                let line = computeLineAndCharacterOfPosition(lineStarts, start).line - 1;
                while (line >= 0) {
                    if (directives.markUsed(line)) {
                        return line;
                    }
                    const lineText = file.text.slice(lineStarts[line], lineStarts[line + 1]).trim();
                    if (lineText !== "" && !/^(\s*)\/\/(.*)$/.test(lineText)) {
                        return -1;
                    }
                    line--;
                }
                return -1;
            }
            function getJSSyntacticDiagnosticsForFile(sourceFile) {
                return runWithCancellationToken(() => {
                    const diagnostics = [];
                    walk(sourceFile, sourceFile);
                    forEachChildRecursively(sourceFile, walk, walkArray);
                    return diagnostics;
                    function walk(node, parent2) {
                        switch (parent2.kind) {
                            case 169 /* Parameter */:
                            case 172 /* PropertyDeclaration */:
                            case 174 /* MethodDeclaration */:
                                if (parent2.questionToken === node) {
                                    diagnostics.push(createDiagnosticForNode2(node, Diagnostics.The_0_modifier_can_only_be_used_in_TypeScript_files, "?"));
                                    return "skip";
                                }
                            case 173 /* MethodSignature */:
                            case 176 /* Constructor */:
                            case 177 /* GetAccessor */:
                            case 178 /* SetAccessor */:
                            case 218 /* FunctionExpression */:
                            case 262 /* FunctionDeclaration */:
                            case 219 /* ArrowFunction */:
                            case 260 /* VariableDeclaration */:
                                if (parent2.type === node) {
                                    diagnostics.push(createDiagnosticForNode2(node, Diagnostics.Type_annotations_can_only_be_used_in_TypeScript_files));
                                    return "skip";
                                }
                        }
                        switch (node.kind) {
                            case 273 /* ImportClause */:
                                if (node.isTypeOnly) {
                                    diagnostics.push(createDiagnosticForNode2(parent2, Diagnostics._0_declarations_can_only_be_used_in_TypeScript_files, "import type"));
                                    return "skip";
                                }
                                break;
                            case 278 /* ExportDeclaration */:
                                if (node.isTypeOnly) {
                                    diagnostics.push(createDiagnosticForNode2(node, Diagnostics._0_declarations_can_only_be_used_in_TypeScript_files, "export type"));
                                    return "skip";
                                }
                                break;
                            case 276 /* ImportSpecifier */:
                            case 281 /* ExportSpecifier */:
                                if (node.isTypeOnly) {
                                    diagnostics.push(createDiagnosticForNode2(node, Diagnostics._0_declarations_can_only_be_used_in_TypeScript_files, isImportSpecifier(node) ? "import...type" : "export...type"));
                                    return "skip";
                                }
                                break;
                            case 271 /* ImportEqualsDeclaration */:
                                diagnostics.push(createDiagnosticForNode2(node, Diagnostics.import_can_only_be_used_in_TypeScript_files));
                                return "skip";
                            case 277 /* ExportAssignment */:
                                if (node.isExportEquals) {
                                    diagnostics.push(createDiagnosticForNode2(node, Diagnostics.export_can_only_be_used_in_TypeScript_files));
                                    return "skip";
                                }
                                break;
                            case 298 /* HeritageClause */:
                                const heritageClause = node;
                                if (heritageClause.token === 119 /* ImplementsKeyword */) {
                                    diagnostics.push(createDiagnosticForNode2(node, Diagnostics.implements_clauses_can_only_be_used_in_TypeScript_files));
                                    return "skip";
                                }
                                break;
                            case 264 /* InterfaceDeclaration */:
                                const interfaceKeyword = tokenToString(120 /* InterfaceKeyword */);
                                Debug.assertIsDefined(interfaceKeyword);
                                diagnostics.push(createDiagnosticForNode2(node, Diagnostics._0_declarations_can_only_be_used_in_TypeScript_files, interfaceKeyword));
                                return "skip";
                            case 267 /* ModuleDeclaration */:
                                const moduleKeyword = node.flags & 32 /* Namespace */ ? tokenToString(145 /* NamespaceKeyword */) : tokenToString(144 /* ModuleKeyword */);
                                Debug.assertIsDefined(moduleKeyword);
                                diagnostics.push(createDiagnosticForNode2(node, Diagnostics._0_declarations_can_only_be_used_in_TypeScript_files, moduleKeyword));
                                return "skip";
                            case 265 /* TypeAliasDeclaration */:
                                diagnostics.push(createDiagnosticForNode2(node, Diagnostics.Type_aliases_can_only_be_used_in_TypeScript_files));
                                return "skip";
                            case 176 /* Constructor */:
                            case 174 /* MethodDeclaration */:
                            case 262 /* FunctionDeclaration */:
                                if (!node.body) {
                                    diagnostics.push(createDiagnosticForNode2(node, Diagnostics.Signature_declarations_can_only_be_used_in_TypeScript_files));
                                    return "skip";
                                }
                                return;
                            case 266 /* EnumDeclaration */:
                                const enumKeyword = Debug.checkDefined(tokenToString(94 /* EnumKeyword */));
                                diagnostics.push(createDiagnosticForNode2(node, Diagnostics._0_declarations_can_only_be_used_in_TypeScript_files, enumKeyword));
                                return "skip";
                            case 235 /* NonNullExpression */:
                                diagnostics.push(createDiagnosticForNode2(node, Diagnostics.Non_null_assertions_can_only_be_used_in_TypeScript_files));
                                return "skip";
                            case 234 /* AsExpression */:
                                diagnostics.push(createDiagnosticForNode2(node.type, Diagnostics.Type_assertion_expressions_can_only_be_used_in_TypeScript_files));
                                return "skip";
                            case 238 /* SatisfiesExpression */:
                                diagnostics.push(createDiagnosticForNode2(node.type, Diagnostics.Type_satisfaction_expressions_can_only_be_used_in_TypeScript_files));
                                return "skip";
                            case 216 /* TypeAssertionExpression */:
                                Debug.fail();
                        }
                    }
                    function walkArray(nodes, parent2) {
                        if (canHaveIllegalDecorators(parent2)) {
                            const decorator = find(parent2.modifiers, isDecorator);
                            if (decorator) {
                                diagnostics.push(createDiagnosticForNode2(decorator, Diagnostics.Decorators_are_not_valid_here));
                            }
                        }
                        else if (canHaveDecorators(parent2) && parent2.modifiers) {
                            const decoratorIndex = findIndex(parent2.modifiers, isDecorator);
                            if (decoratorIndex >= 0) {
                                if (isParameter(parent2) && !options.experimentalDecorators) {
                                    diagnostics.push(createDiagnosticForNode2(parent2.modifiers[decoratorIndex], Diagnostics.Decorators_are_not_valid_here));
                                }
                                else if (isClassDeclaration(parent2)) {
                                    const exportIndex = findIndex(parent2.modifiers, isExportModifier);
                                    if (exportIndex >= 0) {
                                        const defaultIndex = findIndex(parent2.modifiers, isDefaultModifier);
                                        if (decoratorIndex > exportIndex && defaultIndex >= 0 && decoratorIndex < defaultIndex) {
                                            diagnostics.push(createDiagnosticForNode2(parent2.modifiers[decoratorIndex], Diagnostics.Decorators_are_not_valid_here));
                                        }
                                        else if (exportIndex >= 0 && decoratorIndex < exportIndex) {
                                            const trailingDecoratorIndex = findIndex(parent2.modifiers, isDecorator, exportIndex);
                                            if (trailingDecoratorIndex >= 0) {
                                                diagnostics.push(addRelatedInfo(createDiagnosticForNode2(parent2.modifiers[trailingDecoratorIndex], Diagnostics.Decorators_may_not_appear_after_export_or_export_default_if_they_also_appear_before_export), createDiagnosticForNode2(parent2.modifiers[decoratorIndex], Diagnostics.Decorator_used_before_export_here)));
                                            }
                                        }
                                    }
                                }
                            }
                        }
                        switch (parent2.kind) {
                            case 263 /* ClassDeclaration */:
                            case 231 /* ClassExpression */:
                            case 174 /* MethodDeclaration */:
                            case 176 /* Constructor */:
                            case 177 /* GetAccessor */:
                            case 178 /* SetAccessor */:
                            case 218 /* FunctionExpression */:
                            case 262 /* FunctionDeclaration */:
                            case 219 /* ArrowFunction */:
                                if (nodes === parent2.typeParameters) {
                                    diagnostics.push(createDiagnosticForNodeArray2(nodes, Diagnostics.Type_parameter_declarations_can_only_be_used_in_TypeScript_files));
                                    return "skip";
                                }
                            case 243 /* VariableStatement */:
                                if (nodes === parent2.modifiers) {
                                    checkModifiers(parent2.modifiers, parent2.kind === 243 /* VariableStatement */);
                                    return "skip";
                                }
                                break;
                            case 172 /* PropertyDeclaration */:
                                if (nodes === parent2.modifiers) {
                                    for (const modifier of nodes) {
                                        if (isModifier(modifier) && modifier.kind !== 126 /* StaticKeyword */ && modifier.kind !== 129 /* AccessorKeyword */) {
                                            diagnostics.push(createDiagnosticForNode2(modifier, Diagnostics.The_0_modifier_can_only_be_used_in_TypeScript_files, tokenToString(modifier.kind)));
                                        }
                                    }
                                    return "skip";
                                }
                                break;
                            case 169 /* Parameter */:
                                if (nodes === parent2.modifiers && some(nodes, isModifier)) {
                                    diagnostics.push(createDiagnosticForNodeArray2(nodes, Diagnostics.Parameter_modifiers_can_only_be_used_in_TypeScript_files));
                                    return "skip";
                                }
                                break;
                            case 213 /* CallExpression */:
                            case 214 /* NewExpression */:
                            case 233 /* ExpressionWithTypeArguments */:
                            case 285 /* JsxSelfClosingElement */:
                            case 286 /* JsxOpeningElement */:
                            case 215 /* TaggedTemplateExpression */:
                                if (nodes === parent2.typeArguments) {
                                    diagnostics.push(createDiagnosticForNodeArray2(nodes, Diagnostics.Type_arguments_can_only_be_used_in_TypeScript_files));
                                    return "skip";
                                }
                                break;
                        }
                    }
                    function checkModifiers(modifiers, isConstValid) {
                        for (const modifier of modifiers) {
                            switch (modifier.kind) {
                                case 87 /* ConstKeyword */:
                                    if (isConstValid) {
                                        continue;
                                    }
                                case 125 /* PublicKeyword */:
                                case 123 /* PrivateKeyword */:
                                case 124 /* ProtectedKeyword */:
                                case 148 /* ReadonlyKeyword */:
                                case 138 /* DeclareKeyword */:
                                case 128 /* AbstractKeyword */:
                                case 164 /* OverrideKeyword */:
                                case 103 /* InKeyword */:
                                case 147 /* OutKeyword */:
                                    diagnostics.push(createDiagnosticForNode2(modifier, Diagnostics.The_0_modifier_can_only_be_used_in_TypeScript_files, tokenToString(modifier.kind)));
                                    break;
                                case 126 /* StaticKeyword */:
                                case 95 /* ExportKeyword */:
                                case 90 /* DefaultKeyword */:
                                case 129 /* AccessorKeyword */:
                            }
                        }
                    }
                    function createDiagnosticForNodeArray2(nodes, message, ...args) {
                        const start = nodes.pos;
                        return createFileDiagnostic(sourceFile, start, nodes.end - start, message, ...args);
                    }
                    function createDiagnosticForNode2(node, message, ...args) {
                        return createDiagnosticForNodeInSourceFile(sourceFile, node, message, ...args);
                    }
                });
            }
            function getDeclarationDiagnosticsWorker(sourceFile, cancellationToken) {
                return getAndCacheDiagnostics(sourceFile, cancellationToken, cachedDeclarationDiagnosticsForFile, getDeclarationDiagnosticsForFileNoCache);
            }
            function getDeclarationDiagnosticsForFileNoCache(sourceFile, cancellationToken) {
                return runWithCancellationToken(() => {
                    const resolver = getTypeChecker().getEmitResolver(sourceFile, cancellationToken);
                    return getDeclarationDiagnostics(getEmitHost(noop), resolver, sourceFile) || emptyArray;
                });
            }
            function getAndCacheDiagnostics(sourceFile, cancellationToken, cache, getDiagnostics2) {
                var _a2;
                const cachedResult = sourceFile ? (_a2 = cache.perFile) == null ? void 0 : _a2.get(sourceFile.path) : cache.allDiagnostics;
                if (cachedResult) {
                    return cachedResult;
                }
                const result = getDiagnostics2(sourceFile, cancellationToken);
                if (sourceFile) {
                    (cache.perFile || (cache.perFile = /* @__PURE__ */ new Map())).set(sourceFile.path, result);
                }
                else {
                    cache.allDiagnostics = result;
                }
                return result;
            }
            function getDeclarationDiagnosticsForFile(sourceFile, cancellationToken) {
                return sourceFile.isDeclarationFile ? [] : getDeclarationDiagnosticsWorker(sourceFile, cancellationToken);
            }
            function getOptionsDiagnostics() {
                return sortAndDeduplicateDiagnostics(concatenate(programDiagnostics.getGlobalDiagnostics(), getOptionsDiagnosticsOfConfigFile()));
            }
            function getOptionsDiagnosticsOfConfigFile() {
                if (!options.configFile)
                    return emptyArray;
                let diagnostics = programDiagnostics.getDiagnostics(options.configFile.fileName);
                forEachResolvedProjectReference2((resolvedRef) => {
                    diagnostics = concatenate(diagnostics, programDiagnostics.getDiagnostics(resolvedRef.sourceFile.fileName));
                });
                return diagnostics;
            }
            function getGlobalDiagnostics() {
                return rootNames.length ? sortAndDeduplicateDiagnostics(getTypeChecker().getGlobalDiagnostics().slice()) : emptyArray;
            }
            function getConfigFileParsingDiagnostics2() {
                return configFileParsingDiagnostics || emptyArray;
            }
            function processRootFile(fileName, isDefaultLib, ignoreNoDefaultLib, reason) {
                processSourceFile(normalizePath(fileName), isDefaultLib, ignoreNoDefaultLib, 
                /*packageId*/
                void 0, reason);
            }
            function fileReferenceIsEqualTo(a, b) {
                return a.fileName === b.fileName;
            }
            function moduleNameIsEqualTo(a, b) {
                return a.kind === 80 /* Identifier */ ? b.kind === 80 /* Identifier */ && a.escapedText === b.escapedText : b.kind === 11 /* StringLiteral */ && a.text === b.text;
            }
            function createSyntheticImport(text, file) {
                const externalHelpersModuleReference = factory.createStringLiteral(text);
                const importDecl = factory.createImportDeclaration(
                /*modifiers*/
                void 0, 
                /*importClause*/
                void 0, externalHelpersModuleReference, 
                /*attributes*/
                void 0);
                addInternalEmitFlags(importDecl, 2 /* NeverApplyImportHelper */);
                setParent(externalHelpersModuleReference, importDecl);
                setParent(importDecl, file);
                externalHelpersModuleReference.flags &= ~16 /* Synthesized */;
                importDecl.flags &= ~16 /* Synthesized */;
                return externalHelpersModuleReference;
            }
            function collectExternalModuleReferences(file) {
                if (file.imports) {
                    return;
                }
                const isJavaScriptFile = isSourceFileJS(file);
                const isExternalModuleFile = isExternalModule(file);
                let imports;
                let moduleAugmentations;
                let ambientModules;
                if ((getIsolatedModules(options) || isExternalModuleFile) && !file.isDeclarationFile) {
                    if (options.importHelpers) {
                        imports = [createSyntheticImport(externalHelpersModuleNameText, file)];
                    }
                    const jsxImport = getJSXRuntimeImport(getJSXImplicitImportBase(options, file), options);
                    if (jsxImport) {
                        (imports || (imports = [])).push(createSyntheticImport(jsxImport, file));
                    }
                }
                for (const node of file.statements) {
                    collectModuleReferences(node, 
                    /*inAmbientModule*/
                    false);
                }
                if (file.flags & 4194304 /* PossiblyContainsDynamicImport */ || isJavaScriptFile) {
                    collectDynamicImportOrRequireCalls(file);
                }
                file.imports = imports || emptyArray;
                file.moduleAugmentations = moduleAugmentations || emptyArray;
                file.ambientModuleNames = ambientModules || emptyArray;
                return;
                function collectModuleReferences(node, inAmbientModule) {
                    if (isAnyImportOrReExport(node)) {
                        const moduleNameExpr = getExternalModuleName(node);
                        if (moduleNameExpr && isStringLiteral(moduleNameExpr) && moduleNameExpr.text && (!inAmbientModule || !isExternalModuleNameRelative(moduleNameExpr.text))) {
                            setParentRecursive(node, 
                            /*incremental*/
                            false);
                            imports = append(imports, moduleNameExpr);
                            if (!usesUriStyleNodeCoreModules && currentNodeModulesDepth === 0 && !file.isDeclarationFile) {
                                usesUriStyleNodeCoreModules = startsWith(moduleNameExpr.text, "node:");
                            }
                        }
                    }
                    else if (isModuleDeclaration(node)) {
                        if (isAmbientModule(node) && (inAmbientModule || hasSyntacticModifier(node, 128 /* Ambient */) || file.isDeclarationFile)) {
                            node.name.parent = node;
                            const nameText = getTextOfIdentifierOrLiteral(node.name);
                            if (isExternalModuleFile || inAmbientModule && !isExternalModuleNameRelative(nameText)) {
                                (moduleAugmentations || (moduleAugmentations = [])).push(node.name);
                            }
                            else if (!inAmbientModule) {
                                if (file.isDeclarationFile) {
                                    (ambientModules || (ambientModules = [])).push(nameText);
                                }
                                const body = node.body;
                                if (body) {
                                    for (const statement of body.statements) {
                                        collectModuleReferences(statement, 
                                        /*inAmbientModule*/
                                        true);
                                    }
                                }
                            }
                        }
                    }
                }
                function collectDynamicImportOrRequireCalls(file2) {
                    const r = /import|require/g;
                    while (r.exec(file2.text) !== null) {
                        const node = getNodeAtPosition(file2, r.lastIndex);
                        if (isJavaScriptFile && isRequireCall(node, 
                        /*requireStringLiteralLikeArgument*/
                        true)) {
                            setParentRecursive(node, 
                            /*incremental*/
                            false);
                            imports = append(imports, node.arguments[0]);
                        }
                        else if (isImportCall(node) && node.arguments.length >= 1 && isStringLiteralLike(node.arguments[0])) {
                            setParentRecursive(node, 
                            /*incremental*/
                            false);
                            imports = append(imports, node.arguments[0]);
                        }
                        else if (isLiteralImportTypeNode(node)) {
                            setParentRecursive(node, 
                            /*incremental*/
                            false);
                            imports = append(imports, node.argument.literal);
                        }
                    }
                }
                function getNodeAtPosition(sourceFile, position) {
                    let current = sourceFile;
                    const getContainingChild = (child) => {
                        if (child.pos <= position && (position < child.end || position === child.end && child.kind === 1 /* EndOfFileToken */)) {
                            return child;
                        }
                    };
                    while (true) {
                        const child = isJavaScriptFile && hasJSDocNodes(current) && forEach(current.jsDoc, getContainingChild) || forEachChild(current, getContainingChild);
                        if (!child) {
                            return current;
                        }
                        current = child;
                    }
                }
            }
            function getLibFileFromReference(ref) {
                var _a2;
                const { libFileName } = getLibFileNameFromLibReference(ref);
                const actualFileName = libFileName && ((_a2 = resolvedLibReferences == null ? void 0 : resolvedLibReferences.get(libFileName)) == null ? void 0 : _a2.actual);
                return actualFileName !== void 0 ? getSourceFile(actualFileName) : void 0;
            }
            function getSourceFileFromReference(referencingFile, ref) {
                return getSourceFileFromReferenceWorker(resolveTripleslashReference(ref.fileName, referencingFile.fileName), getSourceFile);
            }
            function getSourceFileFromReferenceWorker(fileName, getSourceFile2, fail, reason) {
                if (hasExtension(fileName)) {
                    const canonicalFileName = host.getCanonicalFileName(fileName);
                    if (!options.allowNonTsExtensions && !forEach(flatten(supportedExtensionsWithJsonIfResolveJsonModule), (extension) => fileExtensionIs(canonicalFileName, extension))) {
                        if (fail) {
                            if (hasJSFileExtension(canonicalFileName)) {
                                fail(Diagnostics.File_0_is_a_JavaScript_file_Did_you_mean_to_enable_the_allowJs_option, fileName);
                            }
                            else {
                                fail(Diagnostics.File_0_has_an_unsupported_extension_The_only_supported_extensions_are_1, fileName, "'" + flatten(supportedExtensions).join("', '") + "'");
                            }
                        }
                        return void 0;
                    }
                    const sourceFile = getSourceFile2(fileName);
                    if (fail) {
                        if (!sourceFile) {
                            const redirect = getProjectReferenceRedirect(fileName);
                            if (redirect) {
                                fail(Diagnostics.Output_file_0_has_not_been_built_from_source_file_1, redirect, fileName);
                            }
                            else {
                                fail(Diagnostics.File_0_not_found, fileName);
                            }
                        }
                        else if (isReferencedFile(reason) && canonicalFileName === host.getCanonicalFileName(getSourceFileByPath(reason.file).fileName)) {
                            fail(Diagnostics.A_file_cannot_have_a_reference_to_itself);
                        }
                    }
                    return sourceFile;
                }
                else {
                    const sourceFileNoExtension = options.allowNonTsExtensions && getSourceFile2(fileName);
                    if (sourceFileNoExtension)
                        return sourceFileNoExtension;
                    if (fail && options.allowNonTsExtensions) {
                        fail(Diagnostics.File_0_not_found, fileName);
                        return void 0;
                    }
                    const sourceFileWithAddedExtension = forEach(supportedExtensions[0], (extension) => getSourceFile2(fileName + extension));
                    if (fail && !sourceFileWithAddedExtension)
                        fail(Diagnostics.Could_not_resolve_the_path_0_with_the_extensions_Colon_1, fileName, "'" + flatten(supportedExtensions).join("', '") + "'");
                    return sourceFileWithAddedExtension;
                }
            }
            function processSourceFile(fileName, isDefaultLib, ignoreNoDefaultLib, packageId, reason) {
                getSourceFileFromReferenceWorker(fileName, (fileName2) => findSourceFile(fileName2, isDefaultLib, ignoreNoDefaultLib, reason, packageId), 
                // TODO: GH#18217
                (diagnostic, ...args) => addFilePreprocessingFileExplainingDiagnostic(
                /*file*/
                void 0, reason, diagnostic, args), reason);
            }
            function processProjectReferenceFile(fileName, reason) {
                return processSourceFile(fileName, 
                /*isDefaultLib*/
                false, 
                /*ignoreNoDefaultLib*/
                false, 
                /*packageId*/
                void 0, reason);
            }
            function reportFileNamesDifferOnlyInCasingError(fileName, existingFile, reason) {
                const hasExistingReasonToReportErrorOn = !isReferencedFile(reason) && some(fileReasons.get(existingFile.path), isReferencedFile);
                if (hasExistingReasonToReportErrorOn) {
                    addFilePreprocessingFileExplainingDiagnostic(existingFile, reason, Diagnostics.Already_included_file_name_0_differs_from_file_name_1_only_in_casing, [existingFile.fileName, fileName]);
                }
                else {
                    addFilePreprocessingFileExplainingDiagnostic(existingFile, reason, Diagnostics.File_name_0_differs_from_already_included_file_name_1_only_in_casing, [fileName, existingFile.fileName]);
                }
            }
            function createRedirectedSourceFile(redirectTarget, unredirected, fileName, path, resolvedPath, originalFileName, sourceFileOptions) {
                var _a2;
                const redirect = parseNodeFactory.createRedirectedSourceFile({ redirectTarget, unredirected });
                redirect.fileName = fileName;
                redirect.path = path;
                redirect.resolvedPath = resolvedPath;
                redirect.originalFileName = originalFileName;
                redirect.packageJsonLocations = ((_a2 = sourceFileOptions.packageJsonLocations) == null ? void 0 : _a2.length) ? sourceFileOptions.packageJsonLocations : void 0;
                redirect.packageJsonScope = sourceFileOptions.packageJsonScope;
                sourceFilesFoundSearchingNodeModules.set(path, currentNodeModulesDepth > 0);
                return redirect;
            }
            function findSourceFile(fileName, isDefaultLib, ignoreNoDefaultLib, reason, packageId) {
                var _a2, _b2;
                (_a2 = tracing) == null ? void 0 : _a2.push(tracing.Phase.Program, "findSourceFile", {
                    fileName,
                    isDefaultLib: isDefaultLib || void 0,
                    fileIncludeKind: FileIncludeKind[reason.kind]
                });
                const result = findSourceFileWorker(fileName, isDefaultLib, ignoreNoDefaultLib, reason, packageId);
                (_b2 = tracing) == null ? void 0 : _b2.pop();
                return result;
            }
            function getCreateSourceFileOptions(fileName, moduleResolutionCache2, host2, options2) {
                const result = getImpliedNodeFormatForFileWorker(getNormalizedAbsolutePath(fileName, currentDirectory), moduleResolutionCache2 == null ? void 0 : moduleResolutionCache2.getPackageJsonInfoCache(), host2, options2);
                const languageVersion = getEmitScriptTarget(options2);
                const setExternalModuleIndicator2 = getSetExternalModuleIndicator(options2);
                return typeof result === "object" ? { ...result, languageVersion, setExternalModuleIndicator: setExternalModuleIndicator2, jsDocParsingMode: host2.jsDocParsingMode } : { languageVersion, impliedNodeFormat: result, setExternalModuleIndicator: setExternalModuleIndicator2, jsDocParsingMode: host2.jsDocParsingMode };
            }
            function findSourceFileWorker(fileName, isDefaultLib, ignoreNoDefaultLib, reason, packageId) {
                var _a2;
                const path = toPath3(fileName);
                if (useSourceOfProjectReferenceRedirect) {
                    let source = getSourceOfProjectReferenceRedirect(path);
                    if (!source && host.realpath && options.preserveSymlinks && isDeclarationFileName(fileName) && fileName.includes(nodeModulesPathPart)) {
                        const realPath2 = toPath3(host.realpath(fileName));
                        if (realPath2 !== path)
                            source = getSourceOfProjectReferenceRedirect(realPath2);
                    }
                    if (source) {
                        const file2 = isString(source) ? findSourceFile(source, isDefaultLib, ignoreNoDefaultLib, reason, packageId) : void 0;
                        if (file2)
                            addFileToFilesByName(file2, path, fileName, 
                            /*redirectedPath*/
                            void 0);
                        return file2;
                    }
                }
                const originalFileName = fileName;
                if (filesByName.has(path)) {
                    const file2 = filesByName.get(path);
                    addFileIncludeReason(file2 || void 0, reason);
                    if (file2 && !(options.forceConsistentCasingInFileNames === false)) {
                        const checkedName = file2.fileName;
                        const isRedirect = toPath3(checkedName) !== toPath3(fileName);
                        if (isRedirect) {
                            fileName = getProjectReferenceRedirect(fileName) || fileName;
                        }
                        const checkedAbsolutePath = getNormalizedAbsolutePathWithoutRoot(checkedName, currentDirectory);
                        const inputAbsolutePath = getNormalizedAbsolutePathWithoutRoot(fileName, currentDirectory);
                        if (checkedAbsolutePath !== inputAbsolutePath) {
                            reportFileNamesDifferOnlyInCasingError(fileName, file2, reason);
                        }
                    }
                    if (file2 && sourceFilesFoundSearchingNodeModules.get(file2.path) && currentNodeModulesDepth === 0) {
                        sourceFilesFoundSearchingNodeModules.set(file2.path, false);
                        if (!options.noResolve) {
                            processReferencedFiles(file2, isDefaultLib);
                            processTypeReferenceDirectives(file2);
                        }
                        if (!options.noLib) {
                            processLibReferenceDirectives(file2);
                        }
                        modulesWithElidedImports.set(file2.path, false);
                        processImportedModules(file2);
                    }
                    else if (file2 && modulesWithElidedImports.get(file2.path)) {
                        if (currentNodeModulesDepth < maxNodeModuleJsDepth) {
                            modulesWithElidedImports.set(file2.path, false);
                            processImportedModules(file2);
                        }
                    }
                    return file2 || void 0;
                }
                let redirectedPath;
                if (isReferencedFile(reason) && !useSourceOfProjectReferenceRedirect) {
                    const redirectProject = getProjectReferenceRedirectProject(fileName);
                    if (redirectProject) {
                        if (outFile(redirectProject.commandLine.options)) {
                            return void 0;
                        }
                        const redirect = getProjectReferenceOutputName(redirectProject, fileName);
                        fileName = redirect;
                        redirectedPath = toPath3(redirect);
                    }
                }
                const sourceFileOptions = getCreateSourceFileOptions(fileName, moduleResolutionCache, host, options);
                const file = host.getSourceFile(fileName, sourceFileOptions, (hostErrorMessage) => addFilePreprocessingFileExplainingDiagnostic(
                /*file*/
                void 0, reason, Diagnostics.Cannot_read_file_0_Colon_1, [fileName, hostErrorMessage]), shouldCreateNewSourceFile);
                if (packageId) {
                    const packageIdKey = packageIdToString(packageId);
                    const fileFromPackageId = packageIdToSourceFile.get(packageIdKey);
                    if (fileFromPackageId) {
                        const dupFile = createRedirectedSourceFile(fileFromPackageId, file, fileName, path, toPath3(fileName), originalFileName, sourceFileOptions);
                        redirectTargetsMap.add(fileFromPackageId.path, fileName);
                        addFileToFilesByName(dupFile, path, fileName, redirectedPath);
                        addFileIncludeReason(dupFile, reason);
                        sourceFileToPackageName.set(path, packageIdToPackageName(packageId));
                        processingOtherFiles.push(dupFile);
                        return dupFile;
                    }
                    else if (file) {
                        packageIdToSourceFile.set(packageIdKey, file);
                        sourceFileToPackageName.set(path, packageIdToPackageName(packageId));
                    }
                }
                addFileToFilesByName(file, path, fileName, redirectedPath);
                if (file) {
                    sourceFilesFoundSearchingNodeModules.set(path, currentNodeModulesDepth > 0);
                    file.fileName = fileName;
                    file.path = path;
                    file.resolvedPath = toPath3(fileName);
                    file.originalFileName = originalFileName;
                    file.packageJsonLocations = ((_a2 = sourceFileOptions.packageJsonLocations) == null ? void 0 : _a2.length) ? sourceFileOptions.packageJsonLocations : void 0;
                    file.packageJsonScope = sourceFileOptions.packageJsonScope;
                    addFileIncludeReason(file, reason);
                    if (host.useCaseSensitiveFileNames()) {
                        const pathLowerCase = toFileNameLowerCase(path);
                        const existingFile = filesByNameIgnoreCase.get(pathLowerCase);
                        if (existingFile) {
                            reportFileNamesDifferOnlyInCasingError(fileName, existingFile, reason);
                        }
                        else {
                            filesByNameIgnoreCase.set(pathLowerCase, file);
                        }
                    }
                    skipDefaultLib = skipDefaultLib || file.hasNoDefaultLib && !ignoreNoDefaultLib;
                    if (!options.noResolve) {
                        processReferencedFiles(file, isDefaultLib);
                        processTypeReferenceDirectives(file);
                    }
                    if (!options.noLib) {
                        processLibReferenceDirectives(file);
                    }
                    processImportedModules(file);
                    if (isDefaultLib) {
                        processingDefaultLibFiles.push(file);
                    }
                    else {
                        processingOtherFiles.push(file);
                    }
                }
                return file;
            }
            function addFileIncludeReason(file, reason) {
                if (file)
                    fileReasons.add(file.path, reason);
            }
            function addFileToFilesByName(file, path, fileName, redirectedPath) {
                if (redirectedPath) {
                    updateFilesByNameMap(fileName, redirectedPath, file);
                    updateFilesByNameMap(fileName, path, file || false);
                }
                else {
                    updateFilesByNameMap(fileName, path, file);
                }
            }
            function updateFilesByNameMap(fileName, path, file) {
                filesByName.set(path, file);
                if (file !== void 0)
                    missingFileNames.delete(path);
                else
                    missingFileNames.set(path, fileName);
            }
            function getProjectReferenceRedirect(fileName) {
                const referencedProject = getProjectReferenceRedirectProject(fileName);
                return referencedProject && getProjectReferenceOutputName(referencedProject, fileName);
            }
            function getProjectReferenceRedirectProject(fileName) {
                if (!resolvedProjectReferences || !resolvedProjectReferences.length || isDeclarationFileName(fileName) || fileExtensionIs(fileName, ".json" /* Json */)) {
                    return void 0;
                }
                return getResolvedProjectReferenceToRedirect(fileName);
            }
            function getProjectReferenceOutputName(referencedProject, fileName) {
                const out = outFile(referencedProject.commandLine.options);
                return out ? changeExtension(out, ".d.ts" /* Dts */) : getOutputDeclarationFileName(fileName, referencedProject.commandLine, !host.useCaseSensitiveFileNames());
            }
            function getResolvedProjectReferenceToRedirect(fileName) {
                if (mapFromFileToProjectReferenceRedirects === void 0) {
                    mapFromFileToProjectReferenceRedirects = /* @__PURE__ */ new Map();
                    forEachResolvedProjectReference2((referencedProject) => {
                        if (toPath3(options.configFilePath) !== referencedProject.sourceFile.path) {
                            referencedProject.commandLine.fileNames.forEach((f) => mapFromFileToProjectReferenceRedirects.set(toPath3(f), referencedProject.sourceFile.path));
                        }
                    });
                }
                const referencedProjectPath = mapFromFileToProjectReferenceRedirects.get(toPath3(fileName));
                return referencedProjectPath && getResolvedProjectReferenceByPath(referencedProjectPath);
            }
            function forEachResolvedProjectReference2(cb) {
                return forEachResolvedProjectReference(resolvedProjectReferences, cb);
            }
            function getSourceOfProjectReferenceRedirect(path) {
                if (!isDeclarationFileName(path))
                    return void 0;
                if (mapFromToProjectReferenceRedirectSource === void 0) {
                    mapFromToProjectReferenceRedirectSource = /* @__PURE__ */ new Map();
                    forEachResolvedProjectReference2((resolvedRef) => {
                        const out = outFile(resolvedRef.commandLine.options);
                        if (out) {
                            const outputDts = changeExtension(out, ".d.ts" /* Dts */);
                            mapFromToProjectReferenceRedirectSource.set(toPath3(outputDts), true);
                        }
                        else {
                            const getCommonSourceDirectory3 = memoize(() => getCommonSourceDirectoryOfConfig(resolvedRef.commandLine, !host.useCaseSensitiveFileNames()));
                            forEach(resolvedRef.commandLine.fileNames, (fileName) => {
                                if (!isDeclarationFileName(fileName) && !fileExtensionIs(fileName, ".json" /* Json */)) {
                                    const outputDts = getOutputDeclarationFileName(fileName, resolvedRef.commandLine, !host.useCaseSensitiveFileNames(), getCommonSourceDirectory3);
                                    mapFromToProjectReferenceRedirectSource.set(toPath3(outputDts), fileName);
                                }
                            });
                        }
                    });
                }
                return mapFromToProjectReferenceRedirectSource.get(path);
            }
            function isSourceOfProjectReferenceRedirect(fileName) {
                return useSourceOfProjectReferenceRedirect && !!getResolvedProjectReferenceToRedirect(fileName);
            }
            function getResolvedProjectReferenceByPath(projectReferencePath) {
                if (!projectReferenceRedirects) {
                    return void 0;
                }
                return projectReferenceRedirects.get(projectReferencePath) || void 0;
            }
            function processReferencedFiles(file, isDefaultLib) {
                forEach(file.referencedFiles, (ref, index) => {
                    processSourceFile(resolveTripleslashReference(ref.fileName, file.fileName), isDefaultLib, 
                    /*ignoreNoDefaultLib*/
                    false, 
                    /*packageId*/
                    void 0, { kind: 4 /* ReferenceFile */, file: file.path, index });
                });
            }
            function processTypeReferenceDirectives(file) {
                const typeDirectives = file.typeReferenceDirectives;
                if (!typeDirectives.length)
                    return;
                const resolutions = (resolvedTypeReferenceDirectiveNamesProcessing == null ? void 0 : resolvedTypeReferenceDirectiveNamesProcessing.get(file.path)) || resolveTypeReferenceDirectiveNamesReusingOldState(typeDirectives, file);
                const resolutionsInFile = createModeAwareCache();
                (resolvedTypeReferenceDirectiveNames ?? (resolvedTypeReferenceDirectiveNames = /* @__PURE__ */ new Map())).set(file.path, resolutionsInFile);
                for (let index = 0; index < typeDirectives.length; index++) {
                    const ref = file.typeReferenceDirectives[index];
                    const resolvedTypeReferenceDirective = resolutions[index];
                    const fileName = toFileNameLowerCase(ref.fileName);
                    resolutionsInFile.set(fileName, getModeForFileReference(ref, file.impliedNodeFormat), resolvedTypeReferenceDirective);
                    const mode = ref.resolutionMode || file.impliedNodeFormat;
                    processTypeReferenceDirective(fileName, mode, resolvedTypeReferenceDirective, { kind: 5 /* TypeReferenceDirective */, file: file.path, index });
                }
            }
            function processTypeReferenceDirective(typeReferenceDirective, mode, resolution, reason) {
                var _a2, _b2;
                (_a2 = tracing) == null ? void 0 : _a2.push(tracing.Phase.Program, "processTypeReferenceDirective", { directive: typeReferenceDirective, hasResolved: !!resolution.resolvedTypeReferenceDirective, refKind: reason.kind, refPath: isReferencedFile(reason) ? reason.file : void 0 });
                processTypeReferenceDirectiveWorker(typeReferenceDirective, mode, resolution, reason);
                (_b2 = tracing) == null ? void 0 : _b2.pop();
            }
            function processTypeReferenceDirectiveWorker(typeReferenceDirective, mode, resolution, reason) {
                var _a2;
                addResolutionDiagnostics(resolution);
                const previousResolution = (_a2 = resolvedTypeReferenceDirectives.get(typeReferenceDirective, mode)) == null ? void 0 : _a2.resolvedTypeReferenceDirective;
                if (previousResolution && previousResolution.primary) {
                    return;
                }
                let saveResolution = true;
                const { resolvedTypeReferenceDirective } = resolution;
                if (resolvedTypeReferenceDirective) {
                    if (resolvedTypeReferenceDirective.isExternalLibraryImport)
                        currentNodeModulesDepth++;
                    if (resolvedTypeReferenceDirective.primary) {
                        processSourceFile(resolvedTypeReferenceDirective.resolvedFileName, 
                        /*isDefaultLib*/
                        false, 
                        /*ignoreNoDefaultLib*/
                        false, resolvedTypeReferenceDirective.packageId, reason);
                    }
                    else {
                        if (previousResolution) {
                            if (resolvedTypeReferenceDirective.resolvedFileName !== previousResolution.resolvedFileName) {
                                const otherFileText = host.readFile(resolvedTypeReferenceDirective.resolvedFileName);
                                const existingFile = getSourceFile(previousResolution.resolvedFileName);
                                if (otherFileText !== existingFile.text) {
                                    addFilePreprocessingFileExplainingDiagnostic(existingFile, reason, Diagnostics.Conflicting_definitions_for_0_found_at_1_and_2_Consider_installing_a_specific_version_of_this_library_to_resolve_the_conflict, [typeReferenceDirective, resolvedTypeReferenceDirective.resolvedFileName, previousResolution.resolvedFileName]);
                                }
                            }
                            saveResolution = false;
                        }
                        else {
                            processSourceFile(resolvedTypeReferenceDirective.resolvedFileName, 
                            /*isDefaultLib*/
                            false, 
                            /*ignoreNoDefaultLib*/
                            false, resolvedTypeReferenceDirective.packageId, reason);
                        }
                    }
                    if (resolvedTypeReferenceDirective.isExternalLibraryImport)
                        currentNodeModulesDepth--;
                }
                else {
                    addFilePreprocessingFileExplainingDiagnostic(
                    /*file*/
                    void 0, reason, Diagnostics.Cannot_find_type_definition_file_for_0, [typeReferenceDirective]);
                }
                if (saveResolution) {
                    resolvedTypeReferenceDirectives.set(typeReferenceDirective, mode, resolution);
                }
            }
            function pathForLibFile(libFileName) {
                const existing = resolvedLibReferences == null ? void 0 : resolvedLibReferences.get(libFileName);
                if (existing)
                    return existing.actual;
                const result = pathForLibFileWorker(libFileName);
                (resolvedLibReferences ?? (resolvedLibReferences = /* @__PURE__ */ new Map())).set(libFileName, result);
                return result.actual;
            }
            function pathForLibFileWorker(libFileName) {
                var _a2, _b2, _c2, _d2, _e2;
                const existing = resolvedLibProcessing == null ? void 0 : resolvedLibProcessing.get(libFileName);
                if (existing)
                    return existing;
                if (structureIsReused !== 0 /* Not */ && oldProgram && !hasInvalidatedLibResolutions(libFileName)) {
                    const oldResolution = (_a2 = oldProgram.resolvedLibReferences) == null ? void 0 : _a2.get(libFileName);
                    if (oldResolution) {
                        if (oldResolution.resolution && isTraceEnabled(options, host)) {
                            const libraryName2 = getLibraryNameFromLibFileName(libFileName);
                            const resolveFrom2 = getInferredLibraryNameResolveFrom(options, currentDirectory, libFileName);
                            trace(host, oldResolution.resolution.resolvedModule ? oldResolution.resolution.resolvedModule.packageId ? Diagnostics.Reusing_resolution_of_module_0_from_1_of_old_program_it_was_successfully_resolved_to_2_with_Package_ID_3 : Diagnostics.Reusing_resolution_of_module_0_from_1_of_old_program_it_was_successfully_resolved_to_2 : Diagnostics.Reusing_resolution_of_module_0_from_1_of_old_program_it_was_not_resolved, libraryName2, getNormalizedAbsolutePath(resolveFrom2, currentDirectory), (_b2 = oldResolution.resolution.resolvedModule) == null ? void 0 : _b2.resolvedFileName, ((_c2 = oldResolution.resolution.resolvedModule) == null ? void 0 : _c2.packageId) && packageIdToString(oldResolution.resolution.resolvedModule.packageId));
                        }
                        (resolvedLibProcessing ?? (resolvedLibProcessing = /* @__PURE__ */ new Map())).set(libFileName, oldResolution);
                        return oldResolution;
                    }
                }
                const libraryName = getLibraryNameFromLibFileName(libFileName);
                const resolveFrom = getInferredLibraryNameResolveFrom(options, currentDirectory, libFileName);
                (_d2 = tracing) == null ? void 0 : _d2.push(tracing.Phase.Program, "resolveLibrary", { resolveFrom });
                mark("beforeResolveLibrary");
                const resolution = actualResolveLibrary(libraryName, resolveFrom, options, libFileName);
                mark("afterResolveLibrary");
                measure("ResolveLibrary", "beforeResolveLibrary", "afterResolveLibrary");
                (_e2 = tracing) == null ? void 0 : _e2.pop();
                const result = {
                    resolution,
                    actual: resolution.resolvedModule ? resolution.resolvedModule.resolvedFileName : combinePaths(defaultLibraryPath, libFileName)
                };
                (resolvedLibProcessing ?? (resolvedLibProcessing = /* @__PURE__ */ new Map())).set(libFileName, result);
                return result;
            }
            function processLibReferenceDirectives(file) {
                forEach(file.libReferenceDirectives, (libReference, index) => {
                    const { libName, libFileName } = getLibFileNameFromLibReference(libReference);
                    if (libFileName) {
                        processRootFile(pathForLibFile(libFileName), 
                        /*isDefaultLib*/
                        true, 
                        /*ignoreNoDefaultLib*/
                        true, { kind: 7 /* LibReferenceDirective */, file: file.path, index });
                    }
                    else {
                        const unqualifiedLibName = removeSuffix(removePrefix(libName, "lib."), ".d.ts");
                        const suggestion = getSpellingSuggestion(unqualifiedLibName, libs, identity);
                        const diagnostic = suggestion ? Diagnostics.Cannot_find_lib_definition_for_0_Did_you_mean_1 : Diagnostics.Cannot_find_lib_definition_for_0;
                        const args = suggestion ? [libName, suggestion] : [libName];
                        (fileProcessingDiagnostics || (fileProcessingDiagnostics = [])).push({
                            kind: 0 /* FilePreprocessingReferencedDiagnostic */,
                            reason: { kind: 7 /* LibReferenceDirective */, file: file.path, index },
                            diagnostic,
                            args
                        });
                    }
                });
            }
            function getCanonicalFileName(fileName) {
                return host.getCanonicalFileName(fileName);
            }
            function processImportedModules(file) {
                var _a2;
                collectExternalModuleReferences(file);
                if (file.imports.length || file.moduleAugmentations.length) {
                    const moduleNames = getModuleNames(file);
                    const resolutions = (resolvedModulesProcessing == null ? void 0 : resolvedModulesProcessing.get(file.path)) || resolveModuleNamesReusingOldState(moduleNames, file);
                    Debug.assert(resolutions.length === moduleNames.length);
                    const optionsForFile = ((_a2 = getRedirectReferenceForResolution(file)) == null ? void 0 : _a2.commandLine.options) || options;
                    const resolutionsInFile = createModeAwareCache();
                    (resolvedModules ?? (resolvedModules = /* @__PURE__ */ new Map())).set(file.path, resolutionsInFile);
                    for (let index = 0; index < moduleNames.length; index++) {
                        const resolution = resolutions[index].resolvedModule;
                        const moduleName = moduleNames[index].text;
                        const mode = getModeForUsageLocationWorker(file, moduleNames[index], optionsForFile);
                        resolutionsInFile.set(moduleName, mode, resolutions[index]);
                        addResolutionDiagnosticsFromResolutionOrCache(file, moduleName, resolutions[index], mode);
                        if (!resolution) {
                            continue;
                        }
                        const isFromNodeModulesSearch = resolution.isExternalLibraryImport;
                        const isJsFile = !resolutionExtensionIsTSOrJson(resolution.extension);
                        const isJsFileFromNodeModules = isFromNodeModulesSearch && isJsFile && (!resolution.originalPath || pathContainsNodeModules(resolution.resolvedFileName));
                        const resolvedFileName = resolution.resolvedFileName;
                        if (isFromNodeModulesSearch) {
                            currentNodeModulesDepth++;
                        }
                        const elideImport = isJsFileFromNodeModules && currentNodeModulesDepth > maxNodeModuleJsDepth;
                        const shouldAddFile = resolvedFileName && !getResolutionDiagnostic(optionsForFile, resolution, file) && !optionsForFile.noResolve && index < file.imports.length && !elideImport && !(isJsFile && !getAllowJSCompilerOption(optionsForFile)) && (isInJSFile(file.imports[index]) || !(file.imports[index].flags & 16777216 /* JSDoc */));
                        if (elideImport) {
                            modulesWithElidedImports.set(file.path, true);
                        }
                        else if (shouldAddFile) {
                            findSourceFile(resolvedFileName, 
                            /*isDefaultLib*/
                            false, 
                            /*ignoreNoDefaultLib*/
                            false, { kind: 3 /* Import */, file: file.path, index }, resolution.packageId);
                        }
                        if (isFromNodeModulesSearch) {
                            currentNodeModulesDepth--;
                        }
                    }
                }
            }
            function checkSourceFilesBelongToPath(sourceFiles, rootDirectory) {
                let allFilesBelongToPath = true;
                const absoluteRootDirectoryPath = host.getCanonicalFileName(getNormalizedAbsolutePath(rootDirectory, currentDirectory));
                for (const sourceFile of sourceFiles) {
                    if (!sourceFile.isDeclarationFile) {
                        const absoluteSourceFilePath = host.getCanonicalFileName(getNormalizedAbsolutePath(sourceFile.fileName, currentDirectory));
                        if (absoluteSourceFilePath.indexOf(absoluteRootDirectoryPath) !== 0) {
                            addProgramDiagnosticExplainingFile(sourceFile, Diagnostics.File_0_is_not_under_rootDir_1_rootDir_is_expected_to_contain_all_source_files, [sourceFile.fileName, rootDirectory]);
                            allFilesBelongToPath = false;
                        }
                    }
                }
                return allFilesBelongToPath;
            }
            function parseProjectReferenceConfigFile(ref) {
                if (!projectReferenceRedirects) {
                    projectReferenceRedirects = /* @__PURE__ */ new Map();
                }
                const refPath = resolveProjectReferencePath(ref);
                const sourceFilePath = toPath3(refPath);
                const fromCache = projectReferenceRedirects.get(sourceFilePath);
                if (fromCache !== void 0) {
                    return fromCache || void 0;
                }
                let commandLine;
                let sourceFile;
                if (host.getParsedCommandLine) {
                    commandLine = host.getParsedCommandLine(refPath);
                    if (!commandLine) {
                        addFileToFilesByName(
                        /*file*/
                        void 0, sourceFilePath, refPath, 
                        /*redirectedPath*/
                        void 0);
                        projectReferenceRedirects.set(sourceFilePath, false);
                        return void 0;
                    }
                    sourceFile = Debug.checkDefined(commandLine.options.configFile);
                    Debug.assert(!sourceFile.path || sourceFile.path === sourceFilePath);
                    addFileToFilesByName(sourceFile, sourceFilePath, refPath, 
                    /*redirectedPath*/
                    void 0);
                }
                else {
                    const basePath = getNormalizedAbsolutePath(getDirectoryPath(refPath), currentDirectory);
                    sourceFile = host.getSourceFile(refPath, 100 /* JSON */);
                    addFileToFilesByName(sourceFile, sourceFilePath, refPath, 
                    /*redirectedPath*/
                    void 0);
                    if (sourceFile === void 0) {
                        projectReferenceRedirects.set(sourceFilePath, false);
                        return void 0;
                    }
                    commandLine = parseJsonSourceFileConfigFileContent(sourceFile, configParsingHost, basePath, 
                    /*existingOptions*/
                    void 0, refPath);
                }
                sourceFile.fileName = refPath;
                sourceFile.path = sourceFilePath;
                sourceFile.resolvedPath = sourceFilePath;
                sourceFile.originalFileName = refPath;
                const resolvedRef = { commandLine, sourceFile };
                projectReferenceRedirects.set(sourceFilePath, resolvedRef);
                if (commandLine.projectReferences) {
                    resolvedRef.references = commandLine.projectReferences.map(parseProjectReferenceConfigFile);
                }
                return resolvedRef;
            }
            function verifyCompilerOptions() {
                if (options.strictPropertyInitialization && !getStrictOptionValue(options, "strictNullChecks")) {
                    createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1, "strictPropertyInitialization", "strictNullChecks");
                }
                if (options.exactOptionalPropertyTypes && !getStrictOptionValue(options, "strictNullChecks")) {
                    createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1, "exactOptionalPropertyTypes", "strictNullChecks");
                }
                if (options.isolatedModules || options.verbatimModuleSyntax) {
                    if (options.out) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_with_option_1, "out", options.verbatimModuleSyntax ? "verbatimModuleSyntax" : "isolatedModules");
                    }
                    if (options.outFile) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_with_option_1, "outFile", options.verbatimModuleSyntax ? "verbatimModuleSyntax" : "isolatedModules");
                    }
                }
                if (options.inlineSourceMap) {
                    if (options.sourceMap) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_with_option_1, "sourceMap", "inlineSourceMap");
                    }
                    if (options.mapRoot) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_with_option_1, "mapRoot", "inlineSourceMap");
                    }
                }
                if (options.composite) {
                    if (options.declaration === false) {
                        createDiagnosticForOptionName(Diagnostics.Composite_projects_may_not_disable_declaration_emit, "declaration");
                    }
                    if (options.incremental === false) {
                        createDiagnosticForOptionName(Diagnostics.Composite_projects_may_not_disable_incremental_compilation, "declaration");
                    }
                }
                const outputFile = outFile(options);
                if (options.tsBuildInfoFile) {
                    if (!isIncrementalCompilation(options)) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1_or_option_2, "tsBuildInfoFile", "incremental", "composite");
                    }
                }
                else if (options.incremental && !outputFile && !options.configFilePath) {
                    programDiagnostics.add(createCompilerDiagnostic(Diagnostics.Option_incremental_can_only_be_specified_using_tsconfig_emitting_to_single_file_or_when_option_tsBuildInfoFile_is_specified));
                }
                verifyDeprecatedCompilerOptions();
                verifyProjectReferences();
                if (options.composite) {
                    const rootPaths = new Set(rootNames.map(toPath3));
                    for (const file of files) {
                        if (sourceFileMayBeEmitted(file, program) && !rootPaths.has(file.path)) {
                            addProgramDiagnosticExplainingFile(file, Diagnostics.File_0_is_not_listed_within_the_file_list_of_project_1_Projects_must_list_all_files_or_use_an_include_pattern, [file.fileName, options.configFilePath || ""]);
                        }
                    }
                }
                if (options.paths) {
                    for (const key in options.paths) {
                        if (!hasProperty(options.paths, key)) {
                            continue;
                        }
                        if (!hasZeroOrOneAsteriskCharacter(key)) {
                            createDiagnosticForOptionPaths(
                            /*onKey*/
                            true, key, Diagnostics.Pattern_0_can_have_at_most_one_Asterisk_character, key);
                        }
                        if (isArray(options.paths[key])) {
                            const len = options.paths[key].length;
                            if (len === 0) {
                                createDiagnosticForOptionPaths(
                                /*onKey*/
                                false, key, Diagnostics.Substitutions_for_pattern_0_shouldn_t_be_an_empty_array, key);
                            }
                            for (let i = 0; i < len; i++) {
                                const subst = options.paths[key][i];
                                const typeOfSubst = typeof subst;
                                if (typeOfSubst === "string") {
                                    if (!hasZeroOrOneAsteriskCharacter(subst)) {
                                        createDiagnosticForOptionPathKeyValue(key, i, Diagnostics.Substitution_0_in_pattern_1_can_have_at_most_one_Asterisk_character, subst, key);
                                    }
                                    if (!options.baseUrl && !pathIsRelative(subst) && !pathIsAbsolute(subst)) {
                                        createDiagnosticForOptionPathKeyValue(key, i, Diagnostics.Non_relative_paths_are_not_allowed_when_baseUrl_is_not_set_Did_you_forget_a_leading_Slash);
                                    }
                                }
                                else {
                                    createDiagnosticForOptionPathKeyValue(key, i, Diagnostics.Substitution_0_for_pattern_1_has_incorrect_type_expected_string_got_2, subst, key, typeOfSubst);
                                }
                            }
                        }
                        else {
                            createDiagnosticForOptionPaths(
                            /*onKey*/
                            false, key, Diagnostics.Substitutions_for_pattern_0_should_be_an_array, key);
                        }
                    }
                }
                if (!options.sourceMap && !options.inlineSourceMap) {
                    if (options.inlineSources) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_can_only_be_used_when_either_option_inlineSourceMap_or_option_sourceMap_is_provided, "inlineSources");
                    }
                    if (options.sourceRoot) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_can_only_be_used_when_either_option_inlineSourceMap_or_option_sourceMap_is_provided, "sourceRoot");
                    }
                }
                if (options.out && options.outFile) {
                    createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_with_option_1, "out", "outFile");
                }
                if (options.mapRoot && !(options.sourceMap || options.declarationMap)) {
                    createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1_or_option_2, "mapRoot", "sourceMap", "declarationMap");
                }
                if (options.declarationDir) {
                    if (!getEmitDeclarations(options)) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1_or_option_2, "declarationDir", "declaration", "composite");
                    }
                    if (outputFile) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_with_option_1, "declarationDir", options.out ? "out" : "outFile");
                    }
                }
                if (options.declarationMap && !getEmitDeclarations(options)) {
                    createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1_or_option_2, "declarationMap", "declaration", "composite");
                }
                if (options.lib && options.noLib) {
                    createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_with_option_1, "lib", "noLib");
                }
                if (options.noImplicitUseStrict && getStrictOptionValue(options, "alwaysStrict")) {
                    createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_with_option_1, "noImplicitUseStrict", "alwaysStrict");
                }
                const languageVersion = getEmitScriptTarget(options);
                const firstNonAmbientExternalModuleSourceFile = find(files, (f) => isExternalModule(f) && !f.isDeclarationFile);
                if (options.isolatedModules || options.verbatimModuleSyntax) {
                    if (options.module === 0 /* None */ && languageVersion < 2 /* ES2015 */ && options.isolatedModules) {
                        createDiagnosticForOptionName(Diagnostics.Option_isolatedModules_can_only_be_used_when_either_option_module_is_provided_or_option_target_is_ES2015_or_higher, "isolatedModules", "target");
                    }
                    if (options.preserveConstEnums === false) {
                        createDiagnosticForOptionName(Diagnostics.Option_preserveConstEnums_cannot_be_disabled_when_0_is_enabled, options.verbatimModuleSyntax ? "verbatimModuleSyntax" : "isolatedModules", "preserveConstEnums");
                    }
                }
                else if (firstNonAmbientExternalModuleSourceFile && languageVersion < 2 /* ES2015 */ && options.module === 0 /* None */) {
                    const span = getErrorSpanForNode(firstNonAmbientExternalModuleSourceFile, typeof firstNonAmbientExternalModuleSourceFile.externalModuleIndicator === "boolean" ? firstNonAmbientExternalModuleSourceFile : firstNonAmbientExternalModuleSourceFile.externalModuleIndicator);
                    programDiagnostics.add(createFileDiagnostic(firstNonAmbientExternalModuleSourceFile, span.start, span.length, Diagnostics.Cannot_use_imports_exports_or_module_augmentations_when_module_is_none));
                }
                if (outputFile && !options.emitDeclarationOnly) {
                    if (options.module && !(options.module === 2 /* AMD */ || options.module === 4 /* System */)) {
                        createDiagnosticForOptionName(Diagnostics.Only_amd_and_system_modules_are_supported_alongside_0, options.out ? "out" : "outFile", "module");
                    }
                    else if (options.module === void 0 && firstNonAmbientExternalModuleSourceFile) {
                        const span = getErrorSpanForNode(firstNonAmbientExternalModuleSourceFile, typeof firstNonAmbientExternalModuleSourceFile.externalModuleIndicator === "boolean" ? firstNonAmbientExternalModuleSourceFile : firstNonAmbientExternalModuleSourceFile.externalModuleIndicator);
                        programDiagnostics.add(createFileDiagnostic(firstNonAmbientExternalModuleSourceFile, span.start, span.length, Diagnostics.Cannot_compile_modules_using_option_0_unless_the_module_flag_is_amd_or_system, options.out ? "out" : "outFile"));
                    }
                }
                if (getResolveJsonModule(options)) {
                    if (getEmitModuleResolutionKind(options) === 1 /* Classic */) {
                        createDiagnosticForOptionName(Diagnostics.Option_resolveJsonModule_cannot_be_specified_when_moduleResolution_is_set_to_classic, "resolveJsonModule");
                    }
                    else if (!hasJsonModuleEmitEnabled(options)) {
                        createDiagnosticForOptionName(Diagnostics.Option_resolveJsonModule_cannot_be_specified_when_module_is_set_to_none_system_or_umd, "resolveJsonModule", "module");
                    }
                }
                if (options.outDir || // there is --outDir specified
                    options.rootDir || // there is --rootDir specified
                    options.sourceRoot || // there is --sourceRoot specified
                    options.mapRoot) {
                    const dir = getCommonSourceDirectory2();
                    if (options.outDir && dir === "" && files.some((file) => getRootLength(file.fileName) > 1)) {
                        createDiagnosticForOptionName(Diagnostics.Cannot_find_the_common_subdirectory_path_for_the_input_files, "outDir");
                    }
                }
                if (options.useDefineForClassFields && languageVersion === 0 /* ES3 */) {
                    createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_when_option_target_is_ES3, "useDefineForClassFields");
                }
                if (options.checkJs && !getAllowJSCompilerOption(options)) {
                    programDiagnostics.add(createCompilerDiagnostic(Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1, "checkJs", "allowJs"));
                }
                if (options.emitDeclarationOnly) {
                    if (!getEmitDeclarations(options)) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1_or_option_2, "emitDeclarationOnly", "declaration", "composite");
                    }
                    if (options.noEmit) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_with_option_1, "emitDeclarationOnly", "noEmit");
                    }
                }
                if (options.emitDecoratorMetadata && !options.experimentalDecorators) {
                    createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1, "emitDecoratorMetadata", "experimentalDecorators");
                }
                if (options.jsxFactory) {
                    if (options.reactNamespace) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_with_option_1, "reactNamespace", "jsxFactory");
                    }
                    if (options.jsx === 4 /* ReactJSX */ || options.jsx === 5 /* ReactJSXDev */) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_when_option_jsx_is_1, "jsxFactory", inverseJsxOptionMap.get("" + options.jsx));
                    }
                    if (!parseIsolatedEntityName(options.jsxFactory, languageVersion)) {
                        createOptionValueDiagnostic("jsxFactory", Diagnostics.Invalid_value_for_jsxFactory_0_is_not_a_valid_identifier_or_qualified_name, options.jsxFactory);
                    }
                }
                else if (options.reactNamespace && !isIdentifierText(options.reactNamespace, languageVersion)) {
                    createOptionValueDiagnostic("reactNamespace", Diagnostics.Invalid_value_for_reactNamespace_0_is_not_a_valid_identifier, options.reactNamespace);
                }
                if (options.jsxFragmentFactory) {
                    if (!options.jsxFactory) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1, "jsxFragmentFactory", "jsxFactory");
                    }
                    if (options.jsx === 4 /* ReactJSX */ || options.jsx === 5 /* ReactJSXDev */) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_when_option_jsx_is_1, "jsxFragmentFactory", inverseJsxOptionMap.get("" + options.jsx));
                    }
                    if (!parseIsolatedEntityName(options.jsxFragmentFactory, languageVersion)) {
                        createOptionValueDiagnostic("jsxFragmentFactory", Diagnostics.Invalid_value_for_jsxFragmentFactory_0_is_not_a_valid_identifier_or_qualified_name, options.jsxFragmentFactory);
                    }
                }
                if (options.reactNamespace) {
                    if (options.jsx === 4 /* ReactJSX */ || options.jsx === 5 /* ReactJSXDev */) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_when_option_jsx_is_1, "reactNamespace", inverseJsxOptionMap.get("" + options.jsx));
                    }
                }
                if (options.jsxImportSource) {
                    if (options.jsx === 2 /* React */) {
                        createDiagnosticForOptionName(Diagnostics.Option_0_cannot_be_specified_when_option_jsx_is_1, "jsxImportSource", inverseJsxOptionMap.get("" + options.jsx));
                    }
                }
                if (options.preserveValueImports && getEmitModuleKind(options) < 5 /* ES2015 */) {
                    createDiagnosticForOptionName(Diagnostics.Option_0_can_only_be_used_when_module_is_set_to_preserve_or_to_es2015_or_later, "preserveValueImports");
                }
                const moduleKind = getEmitModuleKind(options);
                if (options.verbatimModuleSyntax) {
                    if (moduleKind === 2 /* AMD */ || moduleKind === 3 /* UMD */ || moduleKind === 4 /* System */) {
                        createDiagnosticForOptionName(Diagnostics.Option_verbatimModuleSyntax_cannot_be_used_when_module_is_set_to_UMD_AMD_or_System, "verbatimModuleSyntax");
                    }
                    if (options.preserveValueImports) {
                        createRedundantOptionDiagnostic("preserveValueImports", "verbatimModuleSyntax");
                    }
                    if (options.importsNotUsedAsValues) {
                        createRedundantOptionDiagnostic("importsNotUsedAsValues", "verbatimModuleSyntax");
                    }
                }
                if (options.allowImportingTsExtensions && !(options.noEmit || options.emitDeclarationOnly)) {
                    createOptionValueDiagnostic("allowImportingTsExtensions", Diagnostics.Option_allowImportingTsExtensions_can_only_be_used_when_either_noEmit_or_emitDeclarationOnly_is_set);
                }
                const moduleResolution = getEmitModuleResolutionKind(options);
                if (options.resolvePackageJsonExports && !moduleResolutionSupportsPackageJsonExportsAndImports(moduleResolution)) {
                    createDiagnosticForOptionName(Diagnostics.Option_0_can_only_be_used_when_moduleResolution_is_set_to_node16_nodenext_or_bundler, "resolvePackageJsonExports");
                }
                if (options.resolvePackageJsonImports && !moduleResolutionSupportsPackageJsonExportsAndImports(moduleResolution)) {
                    createDiagnosticForOptionName(Diagnostics.Option_0_can_only_be_used_when_moduleResolution_is_set_to_node16_nodenext_or_bundler, "resolvePackageJsonImports");
                }
                if (options.customConditions && !moduleResolutionSupportsPackageJsonExportsAndImports(moduleResolution)) {
                    createDiagnosticForOptionName(Diagnostics.Option_0_can_only_be_used_when_moduleResolution_is_set_to_node16_nodenext_or_bundler, "customConditions");
                }
                if (moduleResolution === 100 /* Bundler */ && !emitModuleKindIsNonNodeESM(moduleKind) && moduleKind !== 200 /* Preserve */) {
                    createOptionValueDiagnostic("moduleResolution", Diagnostics.Option_0_can_only_be_used_when_module_is_set_to_preserve_or_to_es2015_or_later, "bundler");
                }
                if (ModuleKind[moduleKind] && (100 /* Node16 */ <= moduleKind && moduleKind <= 199 /* NodeNext */) && !(3 /* Node16 */ <= moduleResolution && moduleResolution <= 99 /* NodeNext */)) {
                    const moduleKindName = ModuleKind[moduleKind];
                    createOptionValueDiagnostic("moduleResolution", Diagnostics.Option_moduleResolution_must_be_set_to_0_or_left_unspecified_when_option_module_is_set_to_1, moduleKindName, moduleKindName);
                }
                else if (ModuleResolutionKind[moduleResolution] && (3 /* Node16 */ <= moduleResolution && moduleResolution <= 99 /* NodeNext */) && !(100 /* Node16 */ <= moduleKind && moduleKind <= 199 /* NodeNext */)) {
                    const moduleResolutionName = ModuleResolutionKind[moduleResolution];
                    createOptionValueDiagnostic("module", Diagnostics.Option_module_must_be_set_to_0_when_option_moduleResolution_is_set_to_1, moduleResolutionName, moduleResolutionName);
                }
                if (!options.noEmit && !options.suppressOutputPathCheck) {
                    const emitHost = getEmitHost();
                    const emitFilesSeen = /* @__PURE__ */ new Set();
                    forEachEmittedFile(emitHost, (emitFileNames) => {
                        if (!options.emitDeclarationOnly) {
                            verifyEmitFilePath(emitFileNames.jsFilePath, emitFilesSeen);
                        }
                        verifyEmitFilePath(emitFileNames.declarationFilePath, emitFilesSeen);
                    });
                }
                function verifyEmitFilePath(emitFileName, emitFilesSeen) {
                    if (emitFileName) {
                        const emitFilePath = toPath3(emitFileName);
                        if (filesByName.has(emitFilePath)) {
                            let chain;
                            if (!options.configFilePath) {
                                chain = chainDiagnosticMessages(
                                /*details*/
                                void 0, Diagnostics.Adding_a_tsconfig_json_file_will_help_organize_projects_that_contain_both_TypeScript_and_JavaScript_files_Learn_more_at_https_Colon_Slash_Slashaka_ms_Slashtsconfig);
                            }
                            chain = chainDiagnosticMessages(chain, Diagnostics.Cannot_write_file_0_because_it_would_overwrite_input_file, emitFileName);
                            blockEmittingOfFile(emitFileName, createCompilerDiagnosticFromMessageChain(chain));
                        }
                        const emitFileKey = !host.useCaseSensitiveFileNames() ? toFileNameLowerCase(emitFilePath) : emitFilePath;
                        if (emitFilesSeen.has(emitFileKey)) {
                            blockEmittingOfFile(emitFileName, createCompilerDiagnostic(Diagnostics.Cannot_write_file_0_because_it_would_be_overwritten_by_multiple_input_files, emitFileName));
                        }
                        else {
                            emitFilesSeen.add(emitFileKey);
                        }
                    }
                }
            }
            function getIgnoreDeprecationsVersion() {
                const ignoreDeprecations = options.ignoreDeprecations;
                if (ignoreDeprecations) {
                    if (ignoreDeprecations === "5.0") {
                        return new Version(ignoreDeprecations);
                    }
                    reportInvalidIgnoreDeprecations();
                }
                return Version.zero;
            }
            function checkDeprecations(deprecatedIn, removedIn, createDiagnostic, fn) {
                const deprecatedInVersion = new Version(deprecatedIn);
                const removedInVersion = new Version(removedIn);
                const typescriptVersion = new Version(typeScriptVersion3 || versionMajorMinor);
                const ignoreDeprecationsVersion = getIgnoreDeprecationsVersion();
                const mustBeRemoved = !(removedInVersion.compareTo(typescriptVersion) === 1 /* GreaterThan */);
                const canBeSilenced = !mustBeRemoved && ignoreDeprecationsVersion.compareTo(deprecatedInVersion) === -1 /* LessThan */;
                if (mustBeRemoved || canBeSilenced) {
                    fn((name, value, useInstead) => {
                        if (mustBeRemoved) {
                            if (value === void 0) {
                                createDiagnostic(name, value, useInstead, Diagnostics.Option_0_has_been_removed_Please_remove_it_from_your_configuration, name);
                            }
                            else {
                                createDiagnostic(name, value, useInstead, Diagnostics.Option_0_1_has_been_removed_Please_remove_it_from_your_configuration, name, value);
                            }
                        }
                        else {
                            if (value === void 0) {
                                createDiagnostic(name, value, useInstead, Diagnostics.Option_0_is_deprecated_and_will_stop_functioning_in_TypeScript_1_Specify_compilerOption_ignoreDeprecations_Colon_2_to_silence_this_error, name, removedIn, deprecatedIn);
                            }
                            else {
                                createDiagnostic(name, value, useInstead, Diagnostics.Option_0_1_is_deprecated_and_will_stop_functioning_in_TypeScript_2_Specify_compilerOption_ignoreDeprecations_Colon_3_to_silence_this_error, name, value, removedIn, deprecatedIn);
                            }
                        }
                    });
                }
            }
            function verifyDeprecatedCompilerOptions() {
                function createDiagnostic(name, value, useInstead, message, ...args) {
                    if (useInstead) {
                        const details = chainDiagnosticMessages(
                        /*details*/
                        void 0, Diagnostics.Use_0_instead, useInstead);
                        const chain = chainDiagnosticMessages(details, message, ...args);
                        createDiagnosticForOption(
                        /*onKey*/
                        !value, name, 
                        /*option2*/
                        void 0, chain);
                    }
                    else {
                        createDiagnosticForOption(
                        /*onKey*/
                        !value, name, 
                        /*option2*/
                        void 0, message, ...args);
                    }
                }
                checkDeprecations("5.0", "5.5", createDiagnostic, (createDeprecatedDiagnostic) => {
                    if (options.target === 0 /* ES3 */) {
                        createDeprecatedDiagnostic("target", "ES3");
                    }
                    if (options.noImplicitUseStrict) {
                        createDeprecatedDiagnostic("noImplicitUseStrict");
                    }
                    if (options.keyofStringsOnly) {
                        createDeprecatedDiagnostic("keyofStringsOnly");
                    }
                    if (options.suppressExcessPropertyErrors) {
                        createDeprecatedDiagnostic("suppressExcessPropertyErrors");
                    }
                    if (options.suppressImplicitAnyIndexErrors) {
                        createDeprecatedDiagnostic("suppressImplicitAnyIndexErrors");
                    }
                    if (options.noStrictGenericChecks) {
                        createDeprecatedDiagnostic("noStrictGenericChecks");
                    }
                    if (options.charset) {
                        createDeprecatedDiagnostic("charset");
                    }
                    if (options.out) {
                        createDeprecatedDiagnostic("out", 
                        /*value*/
                        void 0, "outFile");
                    }
                    if (options.importsNotUsedAsValues) {
                        createDeprecatedDiagnostic("importsNotUsedAsValues", 
                        /*value*/
                        void 0, "verbatimModuleSyntax");
                    }
                    if (options.preserveValueImports) {
                        createDeprecatedDiagnostic("preserveValueImports", 
                        /*value*/
                        void 0, "verbatimModuleSyntax");
                    }
                });
            }
            function verifyDeprecatedProjectReference(ref, parentFile, index) {
                function createDiagnostic(_name, _value, _useInstead, message, ...args) {
                    createDiagnosticForReference(parentFile, index, message, ...args);
                }
                checkDeprecations("5.0", "5.5", createDiagnostic, (createDeprecatedDiagnostic) => {
                    if (ref.prepend) {
                        createDeprecatedDiagnostic("prepend");
                    }
                });
            }
            function createDiagnosticExplainingFile(file, fileProcessingReason, diagnostic, args) {
                var _a2;
                let fileIncludeReasons;
                let relatedInfo;
                let locationReason = isReferencedFile(fileProcessingReason) ? fileProcessingReason : void 0;
                if (file)
                    (_a2 = fileReasons.get(file.path)) == null ? void 0 : _a2.forEach(processReason);
                if (fileProcessingReason)
                    processReason(fileProcessingReason);
                if (locationReason && (fileIncludeReasons == null ? void 0 : fileIncludeReasons.length) === 1)
                    fileIncludeReasons = void 0;
                const location = locationReason && getReferencedFileLocation(program, locationReason);
                const fileIncludeReasonDetails = fileIncludeReasons && chainDiagnosticMessages(fileIncludeReasons, Diagnostics.The_file_is_in_the_program_because_Colon);
                const redirectInfo = file && explainIfFileIsRedirectAndImpliedFormat(file);
                const chain = chainDiagnosticMessages(redirectInfo ? fileIncludeReasonDetails ? [fileIncludeReasonDetails, ...redirectInfo] : redirectInfo : fileIncludeReasonDetails, diagnostic, ...args || emptyArray);
                return location && isReferenceFileLocation(location) ? createFileDiagnosticFromMessageChain(location.file, location.pos, location.end - location.pos, chain, relatedInfo) : createCompilerDiagnosticFromMessageChain(chain, relatedInfo);
                function processReason(reason) {
                    (fileIncludeReasons || (fileIncludeReasons = [])).push(fileIncludeReasonToDiagnostics(program, reason));
                    if (!locationReason && isReferencedFile(reason)) {
                        locationReason = reason;
                    }
                    else if (locationReason !== reason) {
                        relatedInfo = append(relatedInfo, fileIncludeReasonToRelatedInformation(reason));
                    }
                    if (reason === fileProcessingReason)
                        fileProcessingReason = void 0;
                }
            }
            function addFilePreprocessingFileExplainingDiagnostic(file, fileProcessingReason, diagnostic, args) {
                (fileProcessingDiagnostics || (fileProcessingDiagnostics = [])).push({
                    kind: 1 /* FilePreprocessingFileExplainingDiagnostic */,
                    file: file && file.path,
                    fileProcessingReason,
                    diagnostic,
                    args
                });
            }
            function addProgramDiagnosticExplainingFile(file, diagnostic, args) {
                programDiagnostics.add(createDiagnosticExplainingFile(file, 
                /*fileProcessingReason*/
                void 0, diagnostic, args));
            }
            function fileIncludeReasonToRelatedInformation(reason) {
                if (isReferencedFile(reason)) {
                    const referenceLocation = getReferencedFileLocation(program, reason);
                    let message2;
                    switch (reason.kind) {
                        case 3 /* Import */:
                            message2 = Diagnostics.File_is_included_via_import_here;
                            break;
                        case 4 /* ReferenceFile */:
                            message2 = Diagnostics.File_is_included_via_reference_here;
                            break;
                        case 5 /* TypeReferenceDirective */:
                            message2 = Diagnostics.File_is_included_via_type_library_reference_here;
                            break;
                        case 7 /* LibReferenceDirective */:
                            message2 = Diagnostics.File_is_included_via_library_reference_here;
                            break;
                        default:
                            Debug.assertNever(reason);
                    }
                    return isReferenceFileLocation(referenceLocation) ? createFileDiagnostic(referenceLocation.file, referenceLocation.pos, referenceLocation.end - referenceLocation.pos, message2) : void 0;
                }
                if (!options.configFile)
                    return void 0;
                let configFileNode;
                let message;
                switch (reason.kind) {
                    case 0 /* RootFile */:
                        if (!options.configFile.configFileSpecs)
                            return void 0;
                        const fileName = getNormalizedAbsolutePath(rootNames[reason.index], currentDirectory);
                        const matchedByFiles = getMatchedFileSpec(program, fileName);
                        if (matchedByFiles) {
                            configFileNode = getTsConfigPropArrayElementValue(options.configFile, "files", matchedByFiles);
                            message = Diagnostics.File_is_matched_by_files_list_specified_here;
                            break;
                        }
                        const matchedByInclude = getMatchedIncludeSpec(program, fileName);
                        if (!matchedByInclude || !isString(matchedByInclude))
                            return void 0;
                        configFileNode = getTsConfigPropArrayElementValue(options.configFile, "include", matchedByInclude);
                        message = Diagnostics.File_is_matched_by_include_pattern_specified_here;
                        break;
                    case 1 /* SourceFromProjectReference */:
                    case 2 /* OutputFromProjectReference */:
                        const referencedResolvedRef = Debug.checkDefined(resolvedProjectReferences == null ? void 0 : resolvedProjectReferences[reason.index]);
                        const referenceInfo = forEachProjectReference(projectReferences, resolvedProjectReferences, (resolvedRef, parent2, index2) => resolvedRef === referencedResolvedRef ? { sourceFile: (parent2 == null ? void 0 : parent2.sourceFile) || options.configFile, index: index2 } : void 0);
                        if (!referenceInfo)
                            return void 0;
                        const { sourceFile, index } = referenceInfo;
                        const referencesSyntax = forEachTsConfigPropArray(sourceFile, "references", (property) => isArrayLiteralExpression(property.initializer) ? property.initializer : void 0);
                        return referencesSyntax && referencesSyntax.elements.length > index ? createDiagnosticForNodeInSourceFile(sourceFile, referencesSyntax.elements[index], reason.kind === 2 /* OutputFromProjectReference */ ? Diagnostics.File_is_output_from_referenced_project_specified_here : Diagnostics.File_is_source_from_referenced_project_specified_here) : void 0;
                    case 8 /* AutomaticTypeDirectiveFile */:
                        if (!options.types)
                            return void 0;
                        configFileNode = getOptionsSyntaxByArrayElementValue("types", reason.typeReference);
                        message = Diagnostics.File_is_entry_point_of_type_library_specified_here;
                        break;
                    case 6 /* LibFile */:
                        if (reason.index !== void 0) {
                            configFileNode = getOptionsSyntaxByArrayElementValue("lib", options.lib[reason.index]);
                            message = Diagnostics.File_is_library_specified_here;
                            break;
                        }
                        const target = forEachEntry(targetOptionDeclaration.type, (value, key) => value === getEmitScriptTarget(options) ? key : void 0);
                        configFileNode = target ? getOptionsSyntaxByValue("target", target) : void 0;
                        message = Diagnostics.File_is_default_library_for_target_specified_here;
                        break;
                    default:
                        Debug.assertNever(reason);
                }
                return configFileNode && createDiagnosticForNodeInSourceFile(options.configFile, configFileNode, message);
            }
            function verifyProjectReferences() {
                const buildInfoPath = !options.suppressOutputPathCheck ? getTsBuildInfoEmitOutputFilePath(options) : void 0;
                forEachProjectReference(projectReferences, resolvedProjectReferences, (resolvedRef, parent2, index) => {
                    const ref = (parent2 ? parent2.commandLine.projectReferences : projectReferences)[index];
                    const parentFile = parent2 && parent2.sourceFile;
                    verifyDeprecatedProjectReference(ref, parentFile, index);
                    if (!resolvedRef) {
                        createDiagnosticForReference(parentFile, index, Diagnostics.File_0_not_found, ref.path);
                        return;
                    }
                    const options2 = resolvedRef.commandLine.options;
                    if (!options2.composite || options2.noEmit) {
                        const inputs = parent2 ? parent2.commandLine.fileNames : rootNames;
                        if (inputs.length) {
                            if (!options2.composite)
                                createDiagnosticForReference(parentFile, index, Diagnostics.Referenced_project_0_must_have_setting_composite_Colon_true, ref.path);
                            if (options2.noEmit)
                                createDiagnosticForReference(parentFile, index, Diagnostics.Referenced_project_0_may_not_disable_emit, ref.path);
                        }
                    }
                    if (ref.prepend) {
                        const out = outFile(options2);
                        if (out) {
                            if (!host.fileExists(out)) {
                                createDiagnosticForReference(parentFile, index, Diagnostics.Output_file_0_from_project_1_does_not_exist, out, ref.path);
                            }
                        }
                        else {
                            createDiagnosticForReference(parentFile, index, Diagnostics.Cannot_prepend_project_0_because_it_does_not_have_outFile_set, ref.path);
                        }
                    }
                    if (!parent2 && buildInfoPath && buildInfoPath === getTsBuildInfoEmitOutputFilePath(options2)) {
                        createDiagnosticForReference(parentFile, index, Diagnostics.Cannot_write_file_0_because_it_will_overwrite_tsbuildinfo_file_generated_by_referenced_project_1, buildInfoPath, ref.path);
                        hasEmitBlockingDiagnostics.set(toPath3(buildInfoPath), true);
                    }
                });
            }
            function createDiagnosticForOptionPathKeyValue(key, valueIndex, message, ...args) {
                let needCompilerDiagnostic = true;
                forEachOptionPathsSyntax((pathProp) => {
                    if (isObjectLiteralExpression(pathProp.initializer)) {
                        forEachPropertyAssignment(pathProp.initializer, key, (keyProps) => {
                            const initializer = keyProps.initializer;
                            if (isArrayLiteralExpression(initializer) && initializer.elements.length > valueIndex) {
                                programDiagnostics.add(createDiagnosticForNodeInSourceFile(options.configFile, initializer.elements[valueIndex], message, ...args));
                                needCompilerDiagnostic = false;
                            }
                        });
                    }
                });
                if (needCompilerDiagnostic) {
                    programDiagnostics.add(createCompilerDiagnostic(message, ...args));
                }
            }
            function createDiagnosticForOptionPaths(onKey, key, message, ...args) {
                let needCompilerDiagnostic = true;
                forEachOptionPathsSyntax((pathProp) => {
                    if (isObjectLiteralExpression(pathProp.initializer) && createOptionDiagnosticInObjectLiteralSyntax(pathProp.initializer, onKey, key, 
                    /*key2*/
                    void 0, message, ...args)) {
                        needCompilerDiagnostic = false;
                    }
                });
                if (needCompilerDiagnostic) {
                    programDiagnostics.add(createCompilerDiagnostic(message, ...args));
                }
            }
            function forEachOptionsSyntaxByName(name, callback) {
                return forEachPropertyAssignment(getCompilerOptionsObjectLiteralSyntax(), name, callback);
            }
            function forEachOptionPathsSyntax(callback) {
                return forEachOptionsSyntaxByName("paths", callback);
            }
            function getOptionsSyntaxByValue(name, value) {
                return forEachOptionsSyntaxByName(name, (property) => isStringLiteral(property.initializer) && property.initializer.text === value ? property.initializer : void 0);
            }
            function getOptionsSyntaxByArrayElementValue(name, value) {
                const compilerOptionsObjectLiteralSyntax = getCompilerOptionsObjectLiteralSyntax();
                return compilerOptionsObjectLiteralSyntax && getPropertyArrayElementValue(compilerOptionsObjectLiteralSyntax, name, value);
            }
            function createDiagnosticForOptionName(message, option1, option2, option3) {
                createDiagnosticForOption(
                /*onKey*/
                true, option1, option2, message, option1, option2, option3);
            }
            function createOptionValueDiagnostic(option1, message, ...args) {
                createDiagnosticForOption(
                /*onKey*/
                false, option1, 
                /*option2*/
                void 0, message, ...args);
            }
            function createDiagnosticForReference(sourceFile, index, message, ...args) {
                const referencesSyntax = forEachTsConfigPropArray(sourceFile || options.configFile, "references", (property) => isArrayLiteralExpression(property.initializer) ? property.initializer : void 0);
                if (referencesSyntax && referencesSyntax.elements.length > index) {
                    programDiagnostics.add(createDiagnosticForNodeInSourceFile(sourceFile || options.configFile, referencesSyntax.elements[index], message, ...args));
                }
                else {
                    programDiagnostics.add(createCompilerDiagnostic(message, ...args));
                }
            }
            function createDiagnosticForOption(onKey, option1, option2, message, ...args) {
                const compilerOptionsObjectLiteralSyntax = getCompilerOptionsObjectLiteralSyntax();
                const needCompilerDiagnostic = !compilerOptionsObjectLiteralSyntax || !createOptionDiagnosticInObjectLiteralSyntax(compilerOptionsObjectLiteralSyntax, onKey, option1, option2, message, ...args);
                if (needCompilerDiagnostic) {
                    if ("messageText" in message) {
                        programDiagnostics.add(createCompilerDiagnosticFromMessageChain(message));
                    }
                    else {
                        programDiagnostics.add(createCompilerDiagnostic(message, ...args));
                    }
                }
            }
            function getCompilerOptionsObjectLiteralSyntax() {
                if (_compilerOptionsObjectLiteralSyntax === void 0) {
                    _compilerOptionsObjectLiteralSyntax = forEachPropertyAssignment(getTsConfigObjectLiteralExpression(options.configFile), "compilerOptions", (prop) => isObjectLiteralExpression(prop.initializer) ? prop.initializer : void 0) || false;
                }
                return _compilerOptionsObjectLiteralSyntax || void 0;
            }
            function createOptionDiagnosticInObjectLiteralSyntax(objectLiteral, onKey, key1, key2, message, ...args) {
                let needsCompilerDiagnostic = false;
                forEachPropertyAssignment(objectLiteral, key1, (prop) => {
                    if ("messageText" in message) {
                        programDiagnostics.add(createDiagnosticForNodeFromMessageChain(options.configFile, onKey ? prop.name : prop.initializer, message));
                    }
                    else {
                        programDiagnostics.add(createDiagnosticForNodeInSourceFile(options.configFile, onKey ? prop.name : prop.initializer, message, ...args));
                    }
                    needsCompilerDiagnostic = true;
                }, key2);
                return needsCompilerDiagnostic;
            }
            function createRedundantOptionDiagnostic(errorOnOption, redundantWithOption) {
                const compilerOptionsObjectLiteralSyntax = getCompilerOptionsObjectLiteralSyntax();
                if (compilerOptionsObjectLiteralSyntax) {
                    createOptionDiagnosticInObjectLiteralSyntax(compilerOptionsObjectLiteralSyntax, 
                    /*onKey*/
                    true, errorOnOption, 
                    /*key2*/
                    void 0, Diagnostics.Option_0_is_redundant_and_cannot_be_specified_with_option_1, errorOnOption, redundantWithOption);
                }
                else {
                    createDiagnosticForOptionName(Diagnostics.Option_0_is_redundant_and_cannot_be_specified_with_option_1, errorOnOption, redundantWithOption);
                }
            }
            function blockEmittingOfFile(emitFileName, diag2) {
                hasEmitBlockingDiagnostics.set(toPath3(emitFileName), true);
                programDiagnostics.add(diag2);
            }
            function isEmittedFile(file) {
                if (options.noEmit) {
                    return false;
                }
                const filePath = toPath3(file);
                if (getSourceFileByPath(filePath)) {
                    return false;
                }
                const out = outFile(options);
                if (out) {
                    return isSameFile(filePath, out) || isSameFile(filePath, removeFileExtension(out) + ".d.ts" /* Dts */);
                }
                if (options.declarationDir && containsPath(options.declarationDir, filePath, currentDirectory, !host.useCaseSensitiveFileNames())) {
                    return true;
                }
                if (options.outDir) {
                    return containsPath(options.outDir, filePath, currentDirectory, !host.useCaseSensitiveFileNames());
                }
                if (fileExtensionIsOneOf(filePath, supportedJSExtensionsFlat) || isDeclarationFileName(filePath)) {
                    const filePathWithoutExtension = removeFileExtension(filePath);
                    return !!getSourceFileByPath(filePathWithoutExtension + ".ts" /* Ts */) || !!getSourceFileByPath(filePathWithoutExtension + ".tsx" /* Tsx */);
                }
                return false;
            }
            function isSameFile(file1, file2) {
                return comparePaths(file1, file2, currentDirectory, !host.useCaseSensitiveFileNames()) === 0 /* EqualTo */;
            }
            function getSymlinkCache() {
                if (host.getSymlinkCache) {
                    return host.getSymlinkCache();
                }
                if (!symlinks) {
                    symlinks = createSymlinkCache(currentDirectory, getCanonicalFileName);
                }
                if (files && !symlinks.hasProcessedResolutions()) {
                    symlinks.setSymlinksFromResolutions(forEachResolvedModule, forEachResolvedTypeReferenceDirective, automaticTypeDirectiveResolutions);
                }
                return symlinks;
            }
            function getModeForUsageLocation2(file, usage) {
                var _a2;
                const optionsForFile = ((_a2 = getRedirectReferenceForResolution(file)) == null ? void 0 : _a2.commandLine.options) || options;
                return getModeForUsageLocationWorker(file, usage, optionsForFile);
            }
            function getModeForResolutionAtIndex2(file, index) {
                return getModeForUsageLocation2(file, getModuleNameStringLiteralAt(file, index));
            }
        }
        function updateHostForUseSourceOfProjectReferenceRedirect(host) {
            let setOfDeclarationDirectories;
            const originalFileExists = host.compilerHost.fileExists;
            const originalDirectoryExists = host.compilerHost.directoryExists;
            const originalGetDirectories = host.compilerHost.getDirectories;
            const originalRealpath = host.compilerHost.realpath;
            if (!host.useSourceOfProjectReferenceRedirect)
                return { onProgramCreateComplete: noop, fileExists };
            host.compilerHost.fileExists = fileExists;
            let directoryExists;
            if (originalDirectoryExists) {
                directoryExists = host.compilerHost.directoryExists = (path) => {
                    if (originalDirectoryExists.call(host.compilerHost, path)) {
                        handleDirectoryCouldBeSymlink(path);
                        return true;
                    }
                    if (!host.getResolvedProjectReferences())
                        return false;
                    if (!setOfDeclarationDirectories) {
                        setOfDeclarationDirectories = /* @__PURE__ */ new Set();
                        host.forEachResolvedProjectReference((ref) => {
                            const out = outFile(ref.commandLine.options);
                            if (out) {
                                setOfDeclarationDirectories.add(getDirectoryPath(host.toPath(out)));
                            }
                            else {
                                const declarationDir = ref.commandLine.options.declarationDir || ref.commandLine.options.outDir;
                                if (declarationDir) {
                                    setOfDeclarationDirectories.add(host.toPath(declarationDir));
                                }
                            }
                        });
                    }
                    return fileOrDirectoryExistsUsingSource(path, 
                    /*isFile*/
                    false);
                };
            }
            if (originalGetDirectories) {
                host.compilerHost.getDirectories = (path) => !host.getResolvedProjectReferences() || originalDirectoryExists && originalDirectoryExists.call(host.compilerHost, path) ? originalGetDirectories.call(host.compilerHost, path) : [];
            }
            if (originalRealpath) {
                host.compilerHost.realpath = (s) => {
                    var _a;
                    return ((_a = host.getSymlinkCache().getSymlinkedFiles()) == null ? void 0 : _a.get(host.toPath(s))) || originalRealpath.call(host.compilerHost, s);
                };
            }
            return { onProgramCreateComplete, fileExists, directoryExists };
            function onProgramCreateComplete() {
                host.compilerHost.fileExists = originalFileExists;
                host.compilerHost.directoryExists = originalDirectoryExists;
                host.compilerHost.getDirectories = originalGetDirectories;
            }
            function fileExists(file) {
                if (originalFileExists.call(host.compilerHost, file))
                    return true;
                if (!host.getResolvedProjectReferences())
                    return false;
                if (!isDeclarationFileName(file))
                    return false;
                return fileOrDirectoryExistsUsingSource(file, 
                /*isFile*/
                true);
            }
            function fileExistsIfProjectReferenceDts(file) {
                const source = host.getSourceOfProjectReferenceRedirect(host.toPath(file));
                return source !== void 0 ? isString(source) ? originalFileExists.call(host.compilerHost, source) : true : void 0;
            }
            function directoryExistsIfProjectReferenceDeclDir(dir) {
                const dirPath = host.toPath(dir);
                const dirPathWithTrailingDirectorySeparator = `${dirPath}${directorySeparator}`;
                return forEachKey(setOfDeclarationDirectories, (declDirPath) => dirPath === declDirPath || // Any parent directory of declaration dir
                    startsWith(declDirPath, dirPathWithTrailingDirectorySeparator) || // Any directory inside declaration dir
                    startsWith(dirPath, `${declDirPath}/`));
            }
            function handleDirectoryCouldBeSymlink(directory) {
                var _a;
                if (!host.getResolvedProjectReferences() || containsIgnoredPath(directory))
                    return;
                if (!originalRealpath || !directory.includes(nodeModulesPathPart))
                    return;
                const symlinkCache = host.getSymlinkCache();
                const directoryPath = ensureTrailingDirectorySeparator(host.toPath(directory));
                if ((_a = symlinkCache.getSymlinkedDirectories()) == null ? void 0 : _a.has(directoryPath))
                    return;
                const real = normalizePath(originalRealpath.call(host.compilerHost, directory));
                let realPath2;
                if (real === directory || (realPath2 = ensureTrailingDirectorySeparator(host.toPath(real))) === directoryPath) {
                    symlinkCache.setSymlinkedDirectory(directoryPath, false);
                    return;
                }
                symlinkCache.setSymlinkedDirectory(directory, {
                    real: ensureTrailingDirectorySeparator(real),
                    realPath: realPath2
                });
            }
            function fileOrDirectoryExistsUsingSource(fileOrDirectory, isFile) {
                var _a;
                const fileOrDirectoryExistsUsingSource2 = isFile ? (file) => fileExistsIfProjectReferenceDts(file) : (dir) => directoryExistsIfProjectReferenceDeclDir(dir);
                const result = fileOrDirectoryExistsUsingSource2(fileOrDirectory);
                if (result !== void 0)
                    return result;
                const symlinkCache = host.getSymlinkCache();
                const symlinkedDirectories = symlinkCache.getSymlinkedDirectories();
                if (!symlinkedDirectories)
                    return false;
                const fileOrDirectoryPath = host.toPath(fileOrDirectory);
                if (!fileOrDirectoryPath.includes(nodeModulesPathPart))
                    return false;
                if (isFile && ((_a = symlinkCache.getSymlinkedFiles()) == null ? void 0 : _a.has(fileOrDirectoryPath)))
                    return true;
                return firstDefinedIterator(symlinkedDirectories.entries(), ([directoryPath, symlinkedDirectory]) => {
                    if (!symlinkedDirectory || !startsWith(fileOrDirectoryPath, directoryPath))
                        return void 0;
                    const result2 = fileOrDirectoryExistsUsingSource2(fileOrDirectoryPath.replace(directoryPath, symlinkedDirectory.realPath));
                    if (isFile && result2) {
                        const absolutePath = getNormalizedAbsolutePath(fileOrDirectory, host.compilerHost.getCurrentDirectory());
                        symlinkCache.setSymlinkedFile(fileOrDirectoryPath, `${symlinkedDirectory.real}${absolutePath.replace(new RegExp(directoryPath, "i"), "")}`);
                    }
                    return result2;
                }) || false;
            }
        }
        function handleNoEmitOptions(program, sourceFile, writeFile2, cancellationToken) {
            const options = program.getCompilerOptions();
            if (options.noEmit) {
                program.getSemanticDiagnostics(sourceFile, cancellationToken);
                return sourceFile || outFile(options) ? emitSkippedWithNoDiagnostics : program.emitBuildInfo(writeFile2, cancellationToken);
            }
            if (!options.noEmitOnError)
                return void 0;
            let diagnostics = [
                ...program.getOptionsDiagnostics(cancellationToken),
                ...program.getSyntacticDiagnostics(sourceFile, cancellationToken),
                ...program.getGlobalDiagnostics(cancellationToken),
                ...program.getSemanticDiagnostics(sourceFile, cancellationToken)
            ];
            if (diagnostics.length === 0 && getEmitDeclarations(program.getCompilerOptions())) {
                diagnostics = program.getDeclarationDiagnostics(
                /*sourceFile*/
                void 0, cancellationToken);
            }
            if (!diagnostics.length)
                return void 0;
            let emittedFiles;
            if (!sourceFile && !outFile(options)) {
                const emitResult = program.emitBuildInfo(writeFile2, cancellationToken);
                if (emitResult.diagnostics)
                    diagnostics = [...diagnostics, ...emitResult.diagnostics];
                emittedFiles = emitResult.emittedFiles;
            }
            return { diagnostics, sourceMaps: void 0, emittedFiles, emitSkipped: true };
        }
        function filterSemanticDiagnostics(diagnostic, option) {
            return filter(diagnostic, (d) => !d.skippedOn || !option[d.skippedOn]);
        }
        function parseConfigHostFromCompilerHostLike(host, directoryStructureHost = host) {
            return {
                fileExists: (f) => directoryStructureHost.fileExists(f),
                readDirectory(root, extensions, excludes, includes, depth) {
                    Debug.assertIsDefined(directoryStructureHost.readDirectory, "'CompilerHost.readDirectory' must be implemented to correctly process 'projectReferences'");
                    return directoryStructureHost.readDirectory(root, extensions, excludes, includes, depth);
                },
                readFile: (f) => directoryStructureHost.readFile(f),
                directoryExists: maybeBind(directoryStructureHost, directoryStructureHost.directoryExists),
                getDirectories: maybeBind(directoryStructureHost, directoryStructureHost.getDirectories),
                realpath: maybeBind(directoryStructureHost, directoryStructureHost.realpath),
                useCaseSensitiveFileNames: host.useCaseSensitiveFileNames(),
                getCurrentDirectory: () => host.getCurrentDirectory(),
                onUnRecoverableConfigFileDiagnostic: host.onUnRecoverableConfigFileDiagnostic || returnUndefined,
                trace: host.trace ? (s) => host.trace(s) : void 0
            };
        }
        function createPrependNodes(projectReferences, getCommandLine, readFile, host) {
            if (!projectReferences)
                return emptyArray;
            let nodes;
            for (let i = 0; i < projectReferences.length; i++) {
                const ref = projectReferences[i];
                const resolvedRefOpts = getCommandLine(ref, i);
                if (ref.prepend && resolvedRefOpts && resolvedRefOpts.options) {
                    const out = outFile(resolvedRefOpts.options);
                    if (!out)
                        continue;
                    const { jsFilePath, sourceMapFilePath, declarationFilePath, declarationMapPath, buildInfoPath } = getOutputPathsForBundle(resolvedRefOpts.options, 
                    /*forceDtsPaths*/
                    true);
                    const node = createInputFilesWithFilePaths(readFile, jsFilePath, sourceMapFilePath, declarationFilePath, declarationMapPath, buildInfoPath, host, resolvedRefOpts.options);
                    (nodes || (nodes = [])).push(node);
                }
            }
            return nodes || emptyArray;
        }
        function resolveProjectReferencePath(ref) {
            return resolveConfigFileProjectName(ref.path);
        }
        function getResolutionDiagnostic(options, { extension }, { isDeclarationFile }) {
            switch (extension) {
                case ".ts" /* Ts */:
                case ".d.ts" /* Dts */:
                case ".mts" /* Mts */:
                case ".d.mts" /* Dmts */:
                case ".cts" /* Cts */:
                case ".d.cts" /* Dcts */:
                    return void 0;
                case ".tsx" /* Tsx */:
                    return needJsx();
                case ".jsx" /* Jsx */:
                    return needJsx() || needAllowJs();
                case ".js" /* Js */:
                case ".mjs" /* Mjs */:
                case ".cjs" /* Cjs */:
                    return needAllowJs();
                case ".json" /* Json */:
                    return needResolveJsonModule();
                default:
                    return needAllowArbitraryExtensions();
            }
            function needJsx() {
                return options.jsx ? void 0 : Diagnostics.Module_0_was_resolved_to_1_but_jsx_is_not_set;
            }
            function needAllowJs() {
                return getAllowJSCompilerOption(options) || !getStrictOptionValue(options, "noImplicitAny") ? void 0 : Diagnostics.Could_not_find_a_declaration_file_for_module_0_1_implicitly_has_an_any_type;
            }
            function needResolveJsonModule() {
                return getResolveJsonModule(options) ? void 0 : Diagnostics.Module_0_was_resolved_to_1_but_resolveJsonModule_is_not_used;
            }
            function needAllowArbitraryExtensions() {
                return isDeclarationFile || options.allowArbitraryExtensions ? void 0 : Diagnostics.Module_0_was_resolved_to_1_but_allowArbitraryExtensions_is_not_set;
            }
        }
        function getModuleNames({ imports, moduleAugmentations }) {
            const res = imports.map((i) => i);
            for (const aug of moduleAugmentations) {
                if (aug.kind === 11 /* StringLiteral */) {
                    res.push(aug);
                }
            }
            return res;
        }
        function getModuleNameStringLiteralAt({ imports, moduleAugmentations }, index) {
            if (index < imports.length)
                return imports[index];
            let augIndex = imports.length;
            for (const aug of moduleAugmentations) {
                if (aug.kind === 11 /* StringLiteral */) {
                    if (index === augIndex)
                        return aug;
                    augIndex++;
                }
            }
            Debug.fail("should never ask for module name at index higher than possible module name");
        }
        var ForegroundColorEscapeSequences, gutterStyleSequence, gutterSeparator, resetEscapeSequence, ellipsis, halfIndent, indent, emptyResolution, moduleResolutionNameAndModeGetter, typeReferenceResolutionNameAndModeGetter, inferredTypesContainingFile, plainJSErrors, emitSkippedWithNoDiagnostics;
        var init_program = __esm({
            "src/compiler/program.ts"() {
                "use strict";
                init_ts2();
                init_ts_performance();
                ForegroundColorEscapeSequences = /* @__PURE__ */ ((ForegroundColorEscapeSequences2) => {
                    ForegroundColorEscapeSequences2["Grey"] = "\x1B[90m";
                    ForegroundColorEscapeSequences2["Red"] = "\x1B[91m";
                    ForegroundColorEscapeSequences2["Yellow"] = "\x1B[93m";
                    ForegroundColorEscapeSequences2["Blue"] = "\x1B[94m";
                    ForegroundColorEscapeSequences2["Cyan"] = "\x1B[96m";
                    return ForegroundColorEscapeSequences2;
                })(ForegroundColorEscapeSequences || {});
                gutterStyleSequence = "\x1B[7m";
                gutterSeparator = " ";
                resetEscapeSequence = "\x1B[0m";
                ellipsis = "...";
                halfIndent = "  ";
                indent = "    ";
                emptyResolution = {
                    resolvedModule: void 0,
                    resolvedTypeReferenceDirective: void 0
                };
                moduleResolutionNameAndModeGetter = {
                    getName: getModuleResolutionName,
                    getMode: (entry, file, compilerOptions) => getModeForUsageLocation(file, entry, compilerOptions)
                };
                typeReferenceResolutionNameAndModeGetter = {
                    getName: getTypeReferenceResolutionName,
                    getMode: (entry, file) => getModeForFileReference(entry, file == null ? void 0 : file.impliedNodeFormat)
                };
                inferredTypesContainingFile = "__inferred type names__.ts";
                plainJSErrors = /* @__PURE__ */ new Set([
                    // binder errors
                    Diagnostics.Cannot_redeclare_block_scoped_variable_0.code,
                    Diagnostics.A_module_cannot_have_multiple_default_exports.code,
                    Diagnostics.Another_export_default_is_here.code,
                    Diagnostics.The_first_export_default_is_here.code,
                    Diagnostics.Identifier_expected_0_is_a_reserved_word_at_the_top_level_of_a_module.code,
                    Diagnostics.Identifier_expected_0_is_a_reserved_word_in_strict_mode_Modules_are_automatically_in_strict_mode.code,
                    Diagnostics.Identifier_expected_0_is_a_reserved_word_that_cannot_be_used_here.code,
                    Diagnostics.constructor_is_a_reserved_word.code,
                    Diagnostics.delete_cannot_be_called_on_an_identifier_in_strict_mode.code,
                    Diagnostics.Code_contained_in_a_class_is_evaluated_in_JavaScript_s_strict_mode_which_does_not_allow_this_use_of_0_For_more_information_see_https_Colon_Slash_Slashdeveloper_mozilla_org_Slashen_US_Slashdocs_SlashWeb_SlashJavaScript_SlashReference_SlashStrict_mode.code,
                    Diagnostics.Invalid_use_of_0_Modules_are_automatically_in_strict_mode.code,
                    Diagnostics.Invalid_use_of_0_in_strict_mode.code,
                    Diagnostics.A_label_is_not_allowed_here.code,
                    Diagnostics.with_statements_are_not_allowed_in_strict_mode.code,
                    // grammar errors
                    Diagnostics.A_break_statement_can_only_be_used_within_an_enclosing_iteration_or_switch_statement.code,
                    Diagnostics.A_break_statement_can_only_jump_to_a_label_of_an_enclosing_statement.code,
                    Diagnostics.A_class_declaration_without_the_default_modifier_must_have_a_name.code,
                    Diagnostics.A_class_member_cannot_have_the_0_keyword.code,
                    Diagnostics.A_comma_expression_is_not_allowed_in_a_computed_property_name.code,
                    Diagnostics.A_continue_statement_can_only_be_used_within_an_enclosing_iteration_statement.code,
                    Diagnostics.A_continue_statement_can_only_jump_to_a_label_of_an_enclosing_iteration_statement.code,
                    Diagnostics.A_continue_statement_can_only_jump_to_a_label_of_an_enclosing_iteration_statement.code,
                    Diagnostics.A_default_clause_cannot_appear_more_than_once_in_a_switch_statement.code,
                    Diagnostics.A_default_export_must_be_at_the_top_level_of_a_file_or_module_declaration.code,
                    Diagnostics.A_definite_assignment_assertion_is_not_permitted_in_this_context.code,
                    Diagnostics.A_destructuring_declaration_must_have_an_initializer.code,
                    Diagnostics.A_get_accessor_cannot_have_parameters.code,
                    Diagnostics.A_rest_element_cannot_contain_a_binding_pattern.code,
                    Diagnostics.A_rest_element_cannot_have_a_property_name.code,
                    Diagnostics.A_rest_element_cannot_have_an_initializer.code,
                    Diagnostics.A_rest_element_must_be_last_in_a_destructuring_pattern.code,
                    Diagnostics.A_rest_parameter_cannot_have_an_initializer.code,
                    Diagnostics.A_rest_parameter_must_be_last_in_a_parameter_list.code,
                    Diagnostics.A_rest_parameter_or_binding_pattern_may_not_have_a_trailing_comma.code,
                    Diagnostics.A_return_statement_cannot_be_used_inside_a_class_static_block.code,
                    Diagnostics.A_set_accessor_cannot_have_rest_parameter.code,
                    Diagnostics.A_set_accessor_must_have_exactly_one_parameter.code,
                    Diagnostics.An_export_declaration_can_only_be_used_at_the_top_level_of_a_module.code,
                    Diagnostics.An_export_declaration_cannot_have_modifiers.code,
                    Diagnostics.An_import_declaration_can_only_be_used_at_the_top_level_of_a_module.code,
                    Diagnostics.An_import_declaration_cannot_have_modifiers.code,
                    Diagnostics.An_object_member_cannot_be_declared_optional.code,
                    Diagnostics.Argument_of_dynamic_import_cannot_be_spread_element.code,
                    Diagnostics.Cannot_assign_to_private_method_0_Private_methods_are_not_writable.code,
                    Diagnostics.Cannot_redeclare_identifier_0_in_catch_clause.code,
                    Diagnostics.Catch_clause_variable_cannot_have_an_initializer.code,
                    Diagnostics.Class_decorators_can_t_be_used_with_static_private_identifier_Consider_removing_the_experimental_decorator.code,
                    Diagnostics.Classes_can_only_extend_a_single_class.code,
                    Diagnostics.Classes_may_not_have_a_field_named_constructor.code,
                    Diagnostics.Did_you_mean_to_use_a_Colon_An_can_only_follow_a_property_name_when_the_containing_object_literal_is_part_of_a_destructuring_pattern.code,
                    Diagnostics.Duplicate_label_0.code,
                    Diagnostics.Dynamic_imports_can_only_accept_a_module_specifier_and_an_optional_set_of_attributes_as_arguments.code,
                    Diagnostics.for_await_loops_cannot_be_used_inside_a_class_static_block.code,
                    Diagnostics.JSX_attributes_must_only_be_assigned_a_non_empty_expression.code,
                    Diagnostics.JSX_elements_cannot_have_multiple_attributes_with_the_same_name.code,
                    Diagnostics.JSX_expressions_may_not_use_the_comma_operator_Did_you_mean_to_write_an_array.code,
                    Diagnostics.JSX_property_access_expressions_cannot_include_JSX_namespace_names.code,
                    Diagnostics.Jump_target_cannot_cross_function_boundary.code,
                    Diagnostics.Line_terminator_not_permitted_before_arrow.code,
                    Diagnostics.Modifiers_cannot_appear_here.code,
                    Diagnostics.Only_a_single_variable_declaration_is_allowed_in_a_for_in_statement.code,
                    Diagnostics.Only_a_single_variable_declaration_is_allowed_in_a_for_of_statement.code,
                    Diagnostics.Private_identifiers_are_not_allowed_outside_class_bodies.code,
                    Diagnostics.Private_identifiers_are_only_allowed_in_class_bodies_and_may_only_be_used_as_part_of_a_class_member_declaration_property_access_or_on_the_left_hand_side_of_an_in_expression.code,
                    Diagnostics.Property_0_is_not_accessible_outside_class_1_because_it_has_a_private_identifier.code,
                    Diagnostics.Tagged_template_expressions_are_not_permitted_in_an_optional_chain.code,
                    Diagnostics.The_left_hand_side_of_a_for_of_statement_may_not_be_async.code,
                    Diagnostics.The_variable_declaration_of_a_for_in_statement_cannot_have_an_initializer.code,
                    Diagnostics.The_variable_declaration_of_a_for_of_statement_cannot_have_an_initializer.code,
                    Diagnostics.Trailing_comma_not_allowed.code,
                    Diagnostics.Variable_declaration_list_cannot_be_empty.code,
                    Diagnostics._0_and_1_operations_cannot_be_mixed_without_parentheses.code,
                    Diagnostics._0_expected.code,
                    Diagnostics._0_is_not_a_valid_meta_property_for_keyword_1_Did_you_mean_2.code,
                    Diagnostics._0_list_cannot_be_empty.code,
                    Diagnostics._0_modifier_already_seen.code,
                    Diagnostics._0_modifier_cannot_appear_on_a_constructor_declaration.code,
                    Diagnostics._0_modifier_cannot_appear_on_a_module_or_namespace_element.code,
                    Diagnostics._0_modifier_cannot_appear_on_a_parameter.code,
                    Diagnostics._0_modifier_cannot_appear_on_class_elements_of_this_kind.code,
                    Diagnostics._0_modifier_cannot_be_used_here.code,
                    Diagnostics._0_modifier_must_precede_1_modifier.code,
                    Diagnostics._0_declarations_can_only_be_declared_inside_a_block.code,
                    Diagnostics._0_declarations_must_be_initialized.code,
                    Diagnostics.extends_clause_already_seen.code,
                    Diagnostics.let_is_not_allowed_to_be_used_as_a_name_in_let_or_const_declarations.code,
                    Diagnostics.Class_constructor_may_not_be_a_generator.code,
                    Diagnostics.Class_constructor_may_not_be_an_accessor.code,
                    Diagnostics.await_expressions_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules.code,
                    Diagnostics.await_using_statements_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules.code,
                    Diagnostics.Private_field_0_must_be_declared_in_an_enclosing_class.code,
                    // Type errors
                    Diagnostics.This_condition_will_always_return_0_since_JavaScript_compares_objects_by_reference_not_value.code
                ]);
                emitSkippedWithNoDiagnostics = { diagnostics: emptyArray, sourceMaps: void 0, emittedFiles: void 0, emitSkipped: true };
            }
        });
        // src/compiler/builderStatePublic.ts
        var init_builderStatePublic = __esm({
            "src/compiler/builderStatePublic.ts"() {
                "use strict";
            }
        });
        // src/compiler/builderState.ts
        function getFileEmitOutput(program, sourceFile, emitOnlyDtsFiles, cancellationToken, customTransformers, forceDtsEmit) {
            const outputFiles = [];
            const { emitSkipped, diagnostics } = program.emit(sourceFile, writeFile2, cancellationToken, emitOnlyDtsFiles, customTransformers, forceDtsEmit);
            return { outputFiles, emitSkipped, diagnostics };
            function writeFile2(fileName, text, writeByteOrderMark) {
                outputFiles.push({ name: fileName, writeByteOrderMark, text });
            }
        }
        var BuilderState;
        var init_builderState = __esm({
            "src/compiler/builderState.ts"() {
                "use strict";
                init_ts2();
                ((BuilderState2) => {
                    function createManyToManyPathMap() {
                        function create2(forward, reverse, deleted) {
                            const map2 = {
                                getKeys: (v) => reverse.get(v),
                                getValues: (k) => forward.get(k),
                                keys: () => forward.keys(),
                                deleteKey: (k) => {
                                    (deleted || (deleted = /* @__PURE__ */ new Set())).add(k);
                                    const set = forward.get(k);
                                    if (!set) {
                                        return false;
                                    }
                                    set.forEach((v) => deleteFromMultimap(reverse, v, k));
                                    forward.delete(k);
                                    return true;
                                },
                                set: (k, vSet) => {
                                    deleted == null ? void 0 : deleted.delete(k);
                                    const existingVSet = forward.get(k);
                                    forward.set(k, vSet);
                                    existingVSet == null ? void 0 : existingVSet.forEach((v) => {
                                        if (!vSet.has(v)) {
                                            deleteFromMultimap(reverse, v, k);
                                        }
                                    });
                                    vSet.forEach((v) => {
                                        if (!(existingVSet == null ? void 0 : existingVSet.has(v))) {
                                            addToMultimap(reverse, v, k);
                                        }
                                    });
                                    return map2;
                                }
                            };
                            return map2;
                        }
                        return create2(
                        /* @__PURE__ */ new Map(), 
                        /* @__PURE__ */ new Map(), 
                        /*deleted*/
                        void 0);
                    }
                    BuilderState2.createManyToManyPathMap = createManyToManyPathMap;
                    function addToMultimap(map2, k, v) {
                        let set = map2.get(k);
                        if (!set) {
                            set = /* @__PURE__ */ new Set();
                            map2.set(k, set);
                        }
                        set.add(v);
                    }
                    function deleteFromMultimap(map2, k, v) {
                        const set = map2.get(k);
                        if (set == null ? void 0 : set.delete(v)) {
                            if (!set.size) {
                                map2.delete(k);
                            }
                            return true;
                        }
                        return false;
                    }
                    function getReferencedFilesFromImportedModuleSymbol(symbol) {
                        return mapDefined(symbol.declarations, (declaration) => {
                            var _a;
                            return (_a = getSourceFileOfNode(declaration)) == null ? void 0 : _a.resolvedPath;
                        });
                    }
                    function getReferencedFilesFromImportLiteral(checker, importName) {
                        const symbol = checker.getSymbolAtLocation(importName);
                        return symbol && getReferencedFilesFromImportedModuleSymbol(symbol);
                    }
                    function getReferencedFileFromFileName(program, fileName, sourceFileDirectory, getCanonicalFileName) {
                        return toPath(program.getProjectReferenceRedirect(fileName) || fileName, sourceFileDirectory, getCanonicalFileName);
                    }
                    function getReferencedFiles(program, sourceFile, getCanonicalFileName) {
                        let referencedFiles;
                        if (sourceFile.imports && sourceFile.imports.length > 0) {
                            const checker = program.getTypeChecker();
                            for (const importName of sourceFile.imports) {
                                const declarationSourceFilePaths = getReferencedFilesFromImportLiteral(checker, importName);
                                declarationSourceFilePaths == null ? void 0 : declarationSourceFilePaths.forEach(addReferencedFile);
                            }
                        }
                        const sourceFileDirectory = getDirectoryPath(sourceFile.resolvedPath);
                        if (sourceFile.referencedFiles && sourceFile.referencedFiles.length > 0) {
                            for (const referencedFile of sourceFile.referencedFiles) {
                                const referencedPath = getReferencedFileFromFileName(program, referencedFile.fileName, sourceFileDirectory, getCanonicalFileName);
                                addReferencedFile(referencedPath);
                            }
                        }
                        program.forEachResolvedTypeReferenceDirective(({ resolvedTypeReferenceDirective }) => {
                            if (!resolvedTypeReferenceDirective) {
                                return;
                            }
                            const fileName = resolvedTypeReferenceDirective.resolvedFileName;
                            const typeFilePath = getReferencedFileFromFileName(program, fileName, sourceFileDirectory, getCanonicalFileName);
                            addReferencedFile(typeFilePath);
                        }, sourceFile);
                        if (sourceFile.moduleAugmentations.length) {
                            const checker = program.getTypeChecker();
                            for (const moduleName of sourceFile.moduleAugmentations) {
                                if (!isStringLiteral(moduleName))
                                    continue;
                                const symbol = checker.getSymbolAtLocation(moduleName);
                                if (!symbol)
                                    continue;
                                addReferenceFromAmbientModule(symbol);
                            }
                        }
                        for (const ambientModule of program.getTypeChecker().getAmbientModules()) {
                            if (ambientModule.declarations && ambientModule.declarations.length > 1) {
                                addReferenceFromAmbientModule(ambientModule);
                            }
                        }
                        return referencedFiles;
                        function addReferenceFromAmbientModule(symbol) {
                            if (!symbol.declarations) {
                                return;
                            }
                            for (const declaration of symbol.declarations) {
                                const declarationSourceFile = getSourceFileOfNode(declaration);
                                if (declarationSourceFile && declarationSourceFile !== sourceFile) {
                                    addReferencedFile(declarationSourceFile.resolvedPath);
                                }
                            }
                        }
                        function addReferencedFile(referencedPath) {
                            (referencedFiles || (referencedFiles = /* @__PURE__ */ new Set())).add(referencedPath);
                        }
                    }
                    function canReuseOldState(newReferencedMap, oldState) {
                        return oldState && !oldState.referencedMap === !newReferencedMap;
                    }
                    BuilderState2.canReuseOldState = canReuseOldState;
                    function create(newProgram, oldState, disableUseFileVersionAsSignature) {
                        var _a, _b, _c;
                        const fileInfos = /* @__PURE__ */ new Map();
                        const options = newProgram.getCompilerOptions();
                        const isOutFile = outFile(options);
                        const referencedMap = options.module !== 0 /* None */ && !isOutFile ? createManyToManyPathMap() : void 0;
                        const exportedModulesMap = referencedMap ? createManyToManyPathMap() : void 0;
                        const useOldState = canReuseOldState(referencedMap, oldState);
                        newProgram.getTypeChecker();
                        for (const sourceFile of newProgram.getSourceFiles()) {
                            const version2 = Debug.checkDefined(sourceFile.version, "Program intended to be used with Builder should have source files with versions set");
                            const oldUncommittedSignature = useOldState ? (_a = oldState.oldSignatures) == null ? void 0 : _a.get(sourceFile.resolvedPath) : void 0;
                            const signature = oldUncommittedSignature === void 0 ? useOldState ? (_b = oldState.fileInfos.get(sourceFile.resolvedPath)) == null ? void 0 : _b.signature : void 0 : oldUncommittedSignature || void 0;
                            if (referencedMap) {
                                const newReferences = getReferencedFiles(newProgram, sourceFile, newProgram.getCanonicalFileName);
                                if (newReferences) {
                                    referencedMap.set(sourceFile.resolvedPath, newReferences);
                                }
                                if (useOldState) {
                                    const oldUncommittedExportedModules = (_c = oldState.oldExportedModulesMap) == null ? void 0 : _c.get(sourceFile.resolvedPath);
                                    const exportedModules = oldUncommittedExportedModules === void 0 ? oldState.exportedModulesMap.getValues(sourceFile.resolvedPath) : oldUncommittedExportedModules || void 0;
                                    if (exportedModules) {
                                        exportedModulesMap.set(sourceFile.resolvedPath, exportedModules);
                                    }
                                }
                            }
                            fileInfos.set(sourceFile.resolvedPath, {
                                version: version2,
                                signature,
                                // No need to calculate affectsGlobalScope with --out since its not used at all
                                affectsGlobalScope: !isOutFile ? isFileAffectingGlobalScope(sourceFile) || void 0 : void 0,
                                impliedFormat: sourceFile.impliedNodeFormat
                            });
                        }
                        return {
                            fileInfos,
                            referencedMap,
                            exportedModulesMap,
                            useFileVersionAsSignature: !disableUseFileVersionAsSignature && !useOldState
                        };
                    }
                    BuilderState2.create = create;
                    function releaseCache2(state) {
                        state.allFilesExcludingDefaultLibraryFile = void 0;
                        state.allFileNames = void 0;
                    }
                    BuilderState2.releaseCache = releaseCache2;
                    function getFilesAffectedBy(state, programOfThisState, path, cancellationToken, host) {
                        var _a, _b;
                        const result = getFilesAffectedByWithOldState(state, programOfThisState, path, cancellationToken, host);
                        (_a = state.oldSignatures) == null ? void 0 : _a.clear();
                        (_b = state.oldExportedModulesMap) == null ? void 0 : _b.clear();
                        return result;
                    }
                    BuilderState2.getFilesAffectedBy = getFilesAffectedBy;
                    function getFilesAffectedByWithOldState(state, programOfThisState, path, cancellationToken, host) {
                        const sourceFile = programOfThisState.getSourceFileByPath(path);
                        if (!sourceFile) {
                            return emptyArray;
                        }
                        if (!updateShapeSignature(state, programOfThisState, sourceFile, cancellationToken, host)) {
                            return [sourceFile];
                        }
                        return (state.referencedMap ? getFilesAffectedByUpdatedShapeWhenModuleEmit : getFilesAffectedByUpdatedShapeWhenNonModuleEmit)(state, programOfThisState, sourceFile, cancellationToken, host);
                    }
                    BuilderState2.getFilesAffectedByWithOldState = getFilesAffectedByWithOldState;
                    function updateSignatureOfFile(state, signature, path) {
                        state.fileInfos.get(path).signature = signature;
                        (state.hasCalledUpdateShapeSignature || (state.hasCalledUpdateShapeSignature = /* @__PURE__ */ new Set())).add(path);
                    }
                    BuilderState2.updateSignatureOfFile = updateSignatureOfFile;
                    function computeDtsSignature(programOfThisState, sourceFile, cancellationToken, host, onNewSignature) {
                        programOfThisState.emit(sourceFile, (fileName, text, _writeByteOrderMark, _onError, sourceFiles, data) => {
                            Debug.assert(isDeclarationFileName(fileName), `File extension for signature expected to be dts: Got:: ${fileName}`);
                            onNewSignature(computeSignatureWithDiagnostics(programOfThisState, sourceFile, text, host, data), sourceFiles);
                        }, cancellationToken, 
                        /*emitOnly*/
                        true, 
                        /*customTransformers*/
                        void 0, 
                        /*forceDtsEmit*/
                        true);
                    }
                    BuilderState2.computeDtsSignature = computeDtsSignature;
                    function updateShapeSignature(state, programOfThisState, sourceFile, cancellationToken, host, useFileVersionAsSignature = state.useFileVersionAsSignature) {
                        var _a;
                        if ((_a = state.hasCalledUpdateShapeSignature) == null ? void 0 : _a.has(sourceFile.resolvedPath))
                            return false;
                        const info = state.fileInfos.get(sourceFile.resolvedPath);
                        const prevSignature = info.signature;
                        let latestSignature;
                        if (!sourceFile.isDeclarationFile && !useFileVersionAsSignature) {
                            computeDtsSignature(programOfThisState, sourceFile, cancellationToken, host, (signature, sourceFiles) => {
                                latestSignature = signature;
                                if (latestSignature !== prevSignature) {
                                    updateExportedModules(state, sourceFile, sourceFiles[0].exportedModulesFromDeclarationEmit);
                                }
                            });
                        }
                        if (latestSignature === void 0) {
                            latestSignature = sourceFile.version;
                            if (state.exportedModulesMap && latestSignature !== prevSignature) {
                                (state.oldExportedModulesMap || (state.oldExportedModulesMap = /* @__PURE__ */ new Map())).set(sourceFile.resolvedPath, state.exportedModulesMap.getValues(sourceFile.resolvedPath) || false);
                                const references = state.referencedMap ? state.referencedMap.getValues(sourceFile.resolvedPath) : void 0;
                                if (references) {
                                    state.exportedModulesMap.set(sourceFile.resolvedPath, references);
                                }
                                else {
                                    state.exportedModulesMap.deleteKey(sourceFile.resolvedPath);
                                }
                            }
                        }
                        (state.oldSignatures || (state.oldSignatures = /* @__PURE__ */ new Map())).set(sourceFile.resolvedPath, prevSignature || false);
                        (state.hasCalledUpdateShapeSignature || (state.hasCalledUpdateShapeSignature = /* @__PURE__ */ new Set())).add(sourceFile.resolvedPath);
                        info.signature = latestSignature;
                        return latestSignature !== prevSignature;
                    }
                    BuilderState2.updateShapeSignature = updateShapeSignature;
                    function updateExportedModules(state, sourceFile, exportedModulesFromDeclarationEmit) {
                        if (!state.exportedModulesMap)
                            return;
                        (state.oldExportedModulesMap || (state.oldExportedModulesMap = /* @__PURE__ */ new Map())).set(sourceFile.resolvedPath, state.exportedModulesMap.getValues(sourceFile.resolvedPath) || false);
                        const exportedModules = getExportedModules(exportedModulesFromDeclarationEmit);
                        if (exportedModules) {
                            state.exportedModulesMap.set(sourceFile.resolvedPath, exportedModules);
                        }
                        else {
                            state.exportedModulesMap.deleteKey(sourceFile.resolvedPath);
                        }
                    }
                    BuilderState2.updateExportedModules = updateExportedModules;
                    function getExportedModules(exportedModulesFromDeclarationEmit) {
                        let exportedModules;
                        exportedModulesFromDeclarationEmit == null ? void 0 : exportedModulesFromDeclarationEmit.forEach((symbol) => getReferencedFilesFromImportedModuleSymbol(symbol).forEach((path) => (exportedModules ?? (exportedModules = /* @__PURE__ */ new Set())).add(path)));
                        return exportedModules;
                    }
                    BuilderState2.getExportedModules = getExportedModules;
                    function getAllDependencies(state, programOfThisState, sourceFile) {
                        const compilerOptions = programOfThisState.getCompilerOptions();
                        if (outFile(compilerOptions)) {
                            return getAllFileNames(state, programOfThisState);
                        }
                        if (!state.referencedMap || isFileAffectingGlobalScope(sourceFile)) {
                            return getAllFileNames(state, programOfThisState);
                        }
                        const seenMap = /* @__PURE__ */ new Set();
                        const queue = [sourceFile.resolvedPath];
                        while (queue.length) {
                            const path = queue.pop();
                            if (!seenMap.has(path)) {
                                seenMap.add(path);
                                const references = state.referencedMap.getValues(path);
                                if (references) {
                                    for (const key of references.keys()) {
                                        queue.push(key);
                                    }
                                }
                            }
                        }
                        return arrayFrom(mapDefinedIterator(seenMap.keys(), (path) => {
                            var _a;
                            return ((_a = programOfThisState.getSourceFileByPath(path)) == null ? void 0 : _a.fileName) ?? path;
                        }));
                    }
                    BuilderState2.getAllDependencies = getAllDependencies;
                    function getAllFileNames(state, programOfThisState) {
                        if (!state.allFileNames) {
                            const sourceFiles = programOfThisState.getSourceFiles();
                            state.allFileNames = sourceFiles === emptyArray ? emptyArray : sourceFiles.map((file) => file.fileName);
                        }
                        return state.allFileNames;
                    }
                    function getReferencedByPaths(state, referencedFilePath) {
                        const keys = state.referencedMap.getKeys(referencedFilePath);
                        return keys ? arrayFrom(keys.keys()) : [];
                    }
                    BuilderState2.getReferencedByPaths = getReferencedByPaths;
                    function containsOnlyAmbientModules(sourceFile) {
                        for (const statement of sourceFile.statements) {
                            if (!isModuleWithStringLiteralName(statement)) {
                                return false;
                            }
                        }
                        return true;
                    }
                    function containsGlobalScopeAugmentation(sourceFile) {
                        return some(sourceFile.moduleAugmentations, (augmentation) => isGlobalScopeAugmentation(augmentation.parent));
                    }
                    function isFileAffectingGlobalScope(sourceFile) {
                        return containsGlobalScopeAugmentation(sourceFile) || !isExternalOrCommonJsModule(sourceFile) && !isJsonSourceFile(sourceFile) && !containsOnlyAmbientModules(sourceFile);
                    }
                    function getAllFilesExcludingDefaultLibraryFile(state, programOfThisState, firstSourceFile) {
                        if (state.allFilesExcludingDefaultLibraryFile) {
                            return state.allFilesExcludingDefaultLibraryFile;
                        }
                        let result;
                        if (firstSourceFile)
                            addSourceFile(firstSourceFile);
                        for (const sourceFile of programOfThisState.getSourceFiles()) {
                            if (sourceFile !== firstSourceFile) {
                                addSourceFile(sourceFile);
                            }
                        }
                        state.allFilesExcludingDefaultLibraryFile = result || emptyArray;
                        return state.allFilesExcludingDefaultLibraryFile;
                        function addSourceFile(sourceFile) {
                            if (!programOfThisState.isSourceFileDefaultLibrary(sourceFile)) {
                                (result || (result = [])).push(sourceFile);
                            }
                        }
                    }
                    BuilderState2.getAllFilesExcludingDefaultLibraryFile = getAllFilesExcludingDefaultLibraryFile;
                    function getFilesAffectedByUpdatedShapeWhenNonModuleEmit(state, programOfThisState, sourceFileWithUpdatedShape) {
                        const compilerOptions = programOfThisState.getCompilerOptions();
                        if (compilerOptions && outFile(compilerOptions)) {
                            return [sourceFileWithUpdatedShape];
                        }
                        return getAllFilesExcludingDefaultLibraryFile(state, programOfThisState, sourceFileWithUpdatedShape);
                    }
                    function getFilesAffectedByUpdatedShapeWhenModuleEmit(state, programOfThisState, sourceFileWithUpdatedShape, cancellationToken, host) {
                        if (isFileAffectingGlobalScope(sourceFileWithUpdatedShape)) {
                            return getAllFilesExcludingDefaultLibraryFile(state, programOfThisState, sourceFileWithUpdatedShape);
                        }
                        const compilerOptions = programOfThisState.getCompilerOptions();
                        if (compilerOptions && (getIsolatedModules(compilerOptions) || outFile(compilerOptions))) {
                            return [sourceFileWithUpdatedShape];
                        }
                        const seenFileNamesMap = /* @__PURE__ */ new Map();
                        seenFileNamesMap.set(sourceFileWithUpdatedShape.resolvedPath, sourceFileWithUpdatedShape);
                        const queue = getReferencedByPaths(state, sourceFileWithUpdatedShape.resolvedPath);
                        while (queue.length > 0) {
                            const currentPath = queue.pop();
                            if (!seenFileNamesMap.has(currentPath)) {
                                const currentSourceFile = programOfThisState.getSourceFileByPath(currentPath);
                                seenFileNamesMap.set(currentPath, currentSourceFile);
                                if (currentSourceFile && updateShapeSignature(state, programOfThisState, currentSourceFile, cancellationToken, host)) {
                                    queue.push(...getReferencedByPaths(state, currentSourceFile.resolvedPath));
                                }
                            }
                        }
                        return arrayFrom(mapDefinedIterator(seenFileNamesMap.values(), (value) => value));
                    }
                })(BuilderState || (BuilderState = {}));
            }
        });
        // src/compiler/builder.ts
        function getBuilderFileEmit(options) {
            let result = 1 /* Js */;
            if (options.sourceMap)
                result = result | 2 /* JsMap */;
            if (options.inlineSourceMap)
                result = result | 4 /* JsInlineMap */;
            if (getEmitDeclarations(options))
                result = result | 8 /* Dts */;
            if (options.declarationMap)
                result = result | 16 /* DtsMap */;
            if (options.emitDeclarationOnly)
                result = result & 24 /* AllDts */;
            return result;
        }
        function getPendingEmitKind(optionsOrEmitKind, oldOptionsOrEmitKind) {
            const oldEmitKind = oldOptionsOrEmitKind && (isNumber(oldOptionsOrEmitKind) ? oldOptionsOrEmitKind : getBuilderFileEmit(oldOptionsOrEmitKind));
            const emitKind = isNumber(optionsOrEmitKind) ? optionsOrEmitKind : getBuilderFileEmit(optionsOrEmitKind);
            if (oldEmitKind === emitKind)
                return 0 /* None */;
            if (!oldEmitKind || !emitKind)
                return emitKind;
            const diff = oldEmitKind ^ emitKind;
            let result = 0 /* None */;
            if (diff & 7 /* AllJs */)
                result = emitKind & 7 /* AllJs */;
            if (diff & 24 /* AllDts */)
                result = result | emitKind & 24 /* AllDts */;
            return result;
        }
        function hasSameKeys(map1, map2) {
            return map1 === map2 || map1 !== void 0 && map2 !== void 0 && map1.size === map2.size && !forEachKey(map1, (key) => !map2.has(key));
        }
        function createBuilderProgramState(newProgram, oldState) {
            var _a, _b;
            const state = BuilderState.create(newProgram, oldState, 
            /*disableUseFileVersionAsSignature*/
            false);
            state.program = newProgram;
            const compilerOptions = newProgram.getCompilerOptions();
            state.compilerOptions = compilerOptions;
            const outFilePath = outFile(compilerOptions);
            if (!outFilePath) {
                state.semanticDiagnosticsPerFile = /* @__PURE__ */ new Map();
            }
            else if (compilerOptions.composite && (oldState == null ? void 0 : oldState.outSignature) && outFilePath === outFile(oldState == null ? void 0 : oldState.compilerOptions)) {
                state.outSignature = oldState.outSignature && getEmitSignatureFromOldSignature(compilerOptions, oldState.compilerOptions, oldState.outSignature);
            }
            state.changedFilesSet = /* @__PURE__ */ new Set();
            state.latestChangedDtsFile = compilerOptions.composite ? oldState == null ? void 0 : oldState.latestChangedDtsFile : void 0;
            const useOldState = BuilderState.canReuseOldState(state.referencedMap, oldState);
            const oldCompilerOptions = useOldState ? oldState.compilerOptions : void 0;
            const canCopySemanticDiagnostics = useOldState && oldState.semanticDiagnosticsPerFile && !!state.semanticDiagnosticsPerFile && !compilerOptionsAffectSemanticDiagnostics(compilerOptions, oldCompilerOptions);
            const canCopyEmitSignatures = compilerOptions.composite && (oldState == null ? void 0 : oldState.emitSignatures) && !outFilePath && !compilerOptionsAffectDeclarationPath(compilerOptions, oldState.compilerOptions);
            if (useOldState) {
                (_a = oldState.changedFilesSet) == null ? void 0 : _a.forEach((value) => state.changedFilesSet.add(value));
                if (!outFilePath && ((_b = oldState.affectedFilesPendingEmit) == null ? void 0 : _b.size)) {
                    state.affectedFilesPendingEmit = new Map(oldState.affectedFilesPendingEmit);
                    state.seenAffectedFiles = /* @__PURE__ */ new Set();
                }
                state.programEmitPending = oldState.programEmitPending;
            }
            else {
                state.buildInfoEmitPending = true;
            }
            const referencedMap = state.referencedMap;
            const oldReferencedMap = useOldState ? oldState.referencedMap : void 0;
            const copyDeclarationFileDiagnostics = canCopySemanticDiagnostics && !compilerOptions.skipLibCheck === !oldCompilerOptions.skipLibCheck;
            const copyLibFileDiagnostics = copyDeclarationFileDiagnostics && !compilerOptions.skipDefaultLibCheck === !oldCompilerOptions.skipDefaultLibCheck;
            state.fileInfos.forEach((info, sourceFilePath) => {
                var _a2;
                let oldInfo;
                let newReferences;
                if (!useOldState || // File wasn't present in old state
                    !(oldInfo = oldState.fileInfos.get(sourceFilePath)) || // versions dont match
                    oldInfo.version !== info.version || // Implied formats dont match
                    oldInfo.impliedFormat !== info.impliedFormat || // Referenced files changed
                    !hasSameKeys(newReferences = referencedMap && referencedMap.getValues(sourceFilePath), oldReferencedMap && oldReferencedMap.getValues(sourceFilePath)) || // Referenced file was deleted in the new program
                    newReferences && forEachKey(newReferences, (path) => !state.fileInfos.has(path) && oldState.fileInfos.has(path))) {
                    addFileToChangeSet(state, sourceFilePath);
                }
                else {
                    const sourceFile = newProgram.getSourceFileByPath(sourceFilePath);
                    const emitDiagnostics = (_a2 = oldState.emitDiagnosticsPerFile) == null ? void 0 : _a2.get(sourceFilePath);
                    if (emitDiagnostics) {
                        (state.emitDiagnosticsPerFile ?? (state.emitDiagnosticsPerFile = /* @__PURE__ */ new Map())).set(sourceFilePath, oldState.hasReusableDiagnostic ? convertToDiagnostics(emitDiagnostics, newProgram) : repopulateDiagnostics(emitDiagnostics, newProgram));
                    }
                    if (canCopySemanticDiagnostics) {
                        if (sourceFile.isDeclarationFile && !copyDeclarationFileDiagnostics)
                            return;
                        if (sourceFile.hasNoDefaultLib && !copyLibFileDiagnostics)
                            return;
                        const diagnostics = oldState.semanticDiagnosticsPerFile.get(sourceFilePath);
                        if (diagnostics) {
                            state.semanticDiagnosticsPerFile.set(sourceFilePath, oldState.hasReusableDiagnostic ? convertToDiagnostics(diagnostics, newProgram) : repopulateDiagnostics(diagnostics, newProgram));
                            (state.semanticDiagnosticsFromOldState ?? (state.semanticDiagnosticsFromOldState = /* @__PURE__ */ new Set())).add(sourceFilePath);
                        }
                    }
                }
                if (canCopyEmitSignatures) {
                    const oldEmitSignature = oldState.emitSignatures.get(sourceFilePath);
                    if (oldEmitSignature) {
                        (state.emitSignatures ?? (state.emitSignatures = /* @__PURE__ */ new Map())).set(sourceFilePath, getEmitSignatureFromOldSignature(compilerOptions, oldState.compilerOptions, oldEmitSignature));
                    }
                }
            });
            if (useOldState && forEachEntry(oldState.fileInfos, (info, sourceFilePath) => {
                if (state.fileInfos.has(sourceFilePath))
                    return false;
                if (outFilePath || info.affectsGlobalScope)
                    return true;
                state.buildInfoEmitPending = true;
                return false;
            })) {
                BuilderState.getAllFilesExcludingDefaultLibraryFile(state, newProgram, 
                /*firstSourceFile*/
                void 0).forEach((file) => addFileToChangeSet(state, file.resolvedPath));
            }
            else if (oldCompilerOptions) {
                const pendingEmitKind = compilerOptionsAffectEmit(compilerOptions, oldCompilerOptions) ? getBuilderFileEmit(compilerOptions) : getPendingEmitKind(compilerOptions, oldCompilerOptions);
                if (pendingEmitKind !== 0 /* None */) {
                    if (!outFilePath) {
                        newProgram.getSourceFiles().forEach((f) => {
                            if (!state.changedFilesSet.has(f.resolvedPath)) {
                                addToAffectedFilesPendingEmit(state, f.resolvedPath, pendingEmitKind);
                            }
                        });
                        Debug.assert(!state.seenAffectedFiles || !state.seenAffectedFiles.size);
                        state.seenAffectedFiles = state.seenAffectedFiles || /* @__PURE__ */ new Set();
                        state.buildInfoEmitPending = true;
                    }
                    else {
                        state.programEmitPending = state.programEmitPending ? state.programEmitPending | pendingEmitKind : pendingEmitKind;
                    }
                }
            }
            if (outFilePath && !state.changedFilesSet.size) {
                if (useOldState)
                    state.bundle = oldState.bundle;
                if (some(newProgram.getProjectReferences(), (ref) => !!ref.prepend))
                    state.programEmitPending = getBuilderFileEmit(compilerOptions);
            }
            return state;
        }
        function addFileToChangeSet(state, path) {
            state.changedFilesSet.add(path);
            state.buildInfoEmitPending = true;
            state.programEmitPending = void 0;
        }
        function getEmitSignatureFromOldSignature(options, oldOptions, oldEmitSignature) {
            return !!options.declarationMap === !!oldOptions.declarationMap ? (
            // Use same format of signature
            oldEmitSignature) : (
            // Convert to different format
            isString(oldEmitSignature) ? [oldEmitSignature] : oldEmitSignature[0]);
        }
        function repopulateDiagnostics(diagnostics, newProgram) {
            if (!diagnostics.length)
                return diagnostics;
            return sameMap(diagnostics, (diag2) => {
                if (isString(diag2.messageText))
                    return diag2;
                const repopulatedChain = convertOrRepopulateDiagnosticMessageChain(diag2.messageText, diag2.file, newProgram, (chain) => {
                    var _a;
                    return (_a = chain.repopulateInfo) == null ? void 0 : _a.call(chain);
                });
                return repopulatedChain === diag2.messageText ? diag2 : { ...diag2, messageText: repopulatedChain };
            });
        }
        function convertOrRepopulateDiagnosticMessageChain(chain, sourceFile, newProgram, repopulateInfo) {
            const info = repopulateInfo(chain);
            if (info) {
                return {
                    ...createModuleNotFoundChain(sourceFile, newProgram, info.moduleReference, info.mode, info.packageName || info.moduleReference),
                    next: convertOrRepopulateDiagnosticMessageChainArray(chain.next, sourceFile, newProgram, repopulateInfo)
                };
            }
            const next = convertOrRepopulateDiagnosticMessageChainArray(chain.next, sourceFile, newProgram, repopulateInfo);
            return next === chain.next ? chain : { ...chain, next };
        }
        function convertOrRepopulateDiagnosticMessageChainArray(array, sourceFile, newProgram, repopulateInfo) {
            return sameMap(array, (chain) => convertOrRepopulateDiagnosticMessageChain(chain, sourceFile, newProgram, repopulateInfo));
        }
        function convertToDiagnostics(diagnostics, newProgram) {
            if (!diagnostics.length)
                return emptyArray;
            let buildInfoDirectory;
            return diagnostics.map((diagnostic) => {
                const result = convertToDiagnosticRelatedInformation(diagnostic, newProgram, toPathInBuildInfoDirectory);
                result.reportsUnnecessary = diagnostic.reportsUnnecessary;
                result.reportsDeprecated = diagnostic.reportDeprecated;
                result.source = diagnostic.source;
                result.skippedOn = diagnostic.skippedOn;
                const { relatedInformation } = diagnostic;
                result.relatedInformation = relatedInformation ? relatedInformation.length ? relatedInformation.map((r) => convertToDiagnosticRelatedInformation(r, newProgram, toPathInBuildInfoDirectory)) : [] : void 0;
                return result;
            });
            function toPathInBuildInfoDirectory(path) {
                buildInfoDirectory ?? (buildInfoDirectory = getDirectoryPath(getNormalizedAbsolutePath(getTsBuildInfoEmitOutputFilePath(newProgram.getCompilerOptions()), newProgram.getCurrentDirectory())));
                return toPath(path, buildInfoDirectory, newProgram.getCanonicalFileName);
            }
        }
        function convertToDiagnosticRelatedInformation(diagnostic, newProgram, toPath3) {
            const { file } = diagnostic;
            const sourceFile = file ? newProgram.getSourceFileByPath(toPath3(file)) : void 0;
            return {
                ...diagnostic,
                file: sourceFile,
                messageText: isString(diagnostic.messageText) ? diagnostic.messageText : convertOrRepopulateDiagnosticMessageChain(diagnostic.messageText, sourceFile, newProgram, (chain) => chain.info)
            };
        }
        function releaseCache(state) {
            BuilderState.releaseCache(state);
            state.program = void 0;
        }
        function backupBuilderProgramEmitState(state) {
            const outFilePath = outFile(state.compilerOptions);
            Debug.assert(!state.changedFilesSet.size || outFilePath);
            return {
                affectedFilesPendingEmit: state.affectedFilesPendingEmit && new Map(state.affectedFilesPendingEmit),
                seenEmittedFiles: state.seenEmittedFiles && new Map(state.seenEmittedFiles),
                programEmitPending: state.programEmitPending,
                emitSignatures: state.emitSignatures && new Map(state.emitSignatures),
                outSignature: state.outSignature,
                latestChangedDtsFile: state.latestChangedDtsFile,
                hasChangedEmitSignature: state.hasChangedEmitSignature,
                changedFilesSet: outFilePath ? new Set(state.changedFilesSet) : void 0,
                buildInfoEmitPending: state.buildInfoEmitPending,
                emitDiagnosticsPerFile: state.emitDiagnosticsPerFile && new Map(state.emitDiagnosticsPerFile)
            };
        }
        function restoreBuilderProgramEmitState(state, savedEmitState) {
            state.affectedFilesPendingEmit = savedEmitState.affectedFilesPendingEmit;
            state.seenEmittedFiles = savedEmitState.seenEmittedFiles;
            state.programEmitPending = savedEmitState.programEmitPending;
            state.emitSignatures = savedEmitState.emitSignatures;
            state.outSignature = savedEmitState.outSignature;
            state.latestChangedDtsFile = savedEmitState.latestChangedDtsFile;
            state.hasChangedEmitSignature = savedEmitState.hasChangedEmitSignature;
            state.buildInfoEmitPending = savedEmitState.buildInfoEmitPending;
            state.emitDiagnosticsPerFile = savedEmitState.emitDiagnosticsPerFile;
            if (savedEmitState.changedFilesSet)
                state.changedFilesSet = savedEmitState.changedFilesSet;
        }
        function assertSourceFileOkWithoutNextAffectedCall(state, sourceFile) {
            Debug.assert(!sourceFile || !state.affectedFiles || state.affectedFiles[state.affectedFilesIndex - 1] !== sourceFile || !state.semanticDiagnosticsPerFile.has(sourceFile.resolvedPath));
        }
        function getNextAffectedFile(state, cancellationToken, host) {
            var _a, _b;
            while (true) {
                const { affectedFiles } = state;
                if (affectedFiles) {
                    const seenAffectedFiles = state.seenAffectedFiles;
                    let affectedFilesIndex = state.affectedFilesIndex;
                    while (affectedFilesIndex < affectedFiles.length) {
                        const affectedFile = affectedFiles[affectedFilesIndex];
                        if (!seenAffectedFiles.has(affectedFile.resolvedPath)) {
                            state.affectedFilesIndex = affectedFilesIndex;
                            addToAffectedFilesPendingEmit(state, affectedFile.resolvedPath, getBuilderFileEmit(state.compilerOptions));
                            handleDtsMayChangeOfAffectedFile(state, affectedFile, cancellationToken, host);
                            return affectedFile;
                        }
                        affectedFilesIndex++;
                    }
                    state.changedFilesSet.delete(state.currentChangedFilePath);
                    state.currentChangedFilePath = void 0;
                    (_a = state.oldSignatures) == null ? void 0 : _a.clear();
                    (_b = state.oldExportedModulesMap) == null ? void 0 : _b.clear();
                    state.affectedFiles = void 0;
                }
                const nextKey = state.changedFilesSet.keys().next();
                if (nextKey.done) {
                    return void 0;
                }
                const program = Debug.checkDefined(state.program);
                const compilerOptions = program.getCompilerOptions();
                if (outFile(compilerOptions)) {
                    Debug.assert(!state.semanticDiagnosticsPerFile);
                    return program;
                }
                state.affectedFiles = BuilderState.getFilesAffectedByWithOldState(state, program, nextKey.value, cancellationToken, host);
                state.currentChangedFilePath = nextKey.value;
                state.affectedFilesIndex = 0;
                if (!state.seenAffectedFiles)
                    state.seenAffectedFiles = /* @__PURE__ */ new Set();
            }
        }
        function clearAffectedFilesPendingEmit(state, emitOnlyDtsFiles) {
            var _a;
            if (!((_a = state.affectedFilesPendingEmit) == null ? void 0 : _a.size))
                return;
            if (!emitOnlyDtsFiles)
                return state.affectedFilesPendingEmit = void 0;
            state.affectedFilesPendingEmit.forEach((emitKind, path) => {
                const pending = emitKind & 7 /* AllJs */;
                if (!pending)
                    state.affectedFilesPendingEmit.delete(path);
                else
                    state.affectedFilesPendingEmit.set(path, pending);
            });
        }
        function getNextAffectedFilePendingEmit(state, emitOnlyDtsFiles) {
            var _a;
            if (!((_a = state.affectedFilesPendingEmit) == null ? void 0 : _a.size))
                return void 0;
            return forEachEntry(state.affectedFilesPendingEmit, (emitKind, path) => {
                var _a2;
                const affectedFile = state.program.getSourceFileByPath(path);
                if (!affectedFile || !sourceFileMayBeEmitted(affectedFile, state.program)) {
                    state.affectedFilesPendingEmit.delete(path);
                    return void 0;
                }
                const seenKind = (_a2 = state.seenEmittedFiles) == null ? void 0 : _a2.get(affectedFile.resolvedPath);
                let pendingKind = getPendingEmitKind(emitKind, seenKind);
                if (emitOnlyDtsFiles)
                    pendingKind = pendingKind & 24 /* AllDts */;
                if (pendingKind)
                    return { affectedFile, emitKind: pendingKind };
            });
        }
        function getNextPendingEmitDiagnosticsFile(state) {
            var _a;
            if (!((_a = state.emitDiagnosticsPerFile) == null ? void 0 : _a.size))
                return void 0;
            return forEachEntry(state.emitDiagnosticsPerFile, (diagnostics, path) => {
                var _a2;
                const affectedFile = state.program.getSourceFileByPath(path);
                if (!affectedFile || !sourceFileMayBeEmitted(affectedFile, state.program)) {
                    state.emitDiagnosticsPerFile.delete(path);
                    return void 0;
                }
                const seenKind = ((_a2 = state.seenEmittedFiles) == null ? void 0 : _a2.get(affectedFile.resolvedPath)) || 0 /* None */;
                if (!(seenKind & 24 /* AllDts */))
                    return { affectedFile, diagnostics, seenKind };
            });
        }
        function removeDiagnosticsOfLibraryFiles(state) {
            if (!state.cleanedDiagnosticsOfLibFiles) {
                state.cleanedDiagnosticsOfLibFiles = true;
                const program = Debug.checkDefined(state.program);
                const options = program.getCompilerOptions();
                forEach(program.getSourceFiles(), (f) => program.isSourceFileDefaultLibrary(f) && !skipTypeChecking(f, options, program) && removeSemanticDiagnosticsOf(state, f.resolvedPath));
            }
        }
        function handleDtsMayChangeOfAffectedFile(state, affectedFile, cancellationToken, host) {
            removeSemanticDiagnosticsOf(state, affectedFile.resolvedPath);
            if (state.allFilesExcludingDefaultLibraryFile === state.affectedFiles) {
                removeDiagnosticsOfLibraryFiles(state);
                BuilderState.updateShapeSignature(state, Debug.checkDefined(state.program), affectedFile, cancellationToken, host);
                return;
            }
            if (state.compilerOptions.assumeChangesOnlyAffectDirectDependencies)
                return;
            handleDtsMayChangeOfReferencingExportOfAffectedFile(state, affectedFile, cancellationToken, host);
        }
        function handleDtsMayChangeOf(state, path, cancellationToken, host) {
            removeSemanticDiagnosticsOf(state, path);
            if (!state.changedFilesSet.has(path)) {
                const program = Debug.checkDefined(state.program);
                const sourceFile = program.getSourceFileByPath(path);
                if (sourceFile) {
                    BuilderState.updateShapeSignature(state, program, sourceFile, cancellationToken, host, 
                    /*useFileVersionAsSignature*/
                    true);
                    if (getEmitDeclarations(state.compilerOptions)) {
                        addToAffectedFilesPendingEmit(state, path, state.compilerOptions.declarationMap ? 24 /* AllDts */ : 8 /* Dts */);
                    }
                }
            }
        }
        function removeSemanticDiagnosticsOf(state, path) {
            if (!state.semanticDiagnosticsFromOldState) {
                return true;
            }
            state.semanticDiagnosticsFromOldState.delete(path);
            state.semanticDiagnosticsPerFile.delete(path);
            return !state.semanticDiagnosticsFromOldState.size;
        }
        function isChangedSignature(state, path) {
            const oldSignature = Debug.checkDefined(state.oldSignatures).get(path) || void 0;
            const newSignature = Debug.checkDefined(state.fileInfos.get(path)).signature;
            return newSignature !== oldSignature;
        }
        function handleDtsMayChangeOfGlobalScope(state, filePath, cancellationToken, host) {
            var _a;
            if (!((_a = state.fileInfos.get(filePath)) == null ? void 0 : _a.affectsGlobalScope))
                return false;
            BuilderState.getAllFilesExcludingDefaultLibraryFile(state, state.program, 
            /*firstSourceFile*/
            void 0).forEach((file) => handleDtsMayChangeOf(state, file.resolvedPath, cancellationToken, host));
            removeDiagnosticsOfLibraryFiles(state);
            return true;
        }
        function handleDtsMayChangeOfReferencingExportOfAffectedFile(state, affectedFile, cancellationToken, host) {
            var _a;
            if (!state.exportedModulesMap || !state.changedFilesSet.has(affectedFile.resolvedPath))
                return;
            if (!isChangedSignature(state, affectedFile.resolvedPath))
                return;
            if (getIsolatedModules(state.compilerOptions)) {
                const seenFileNamesMap = /* @__PURE__ */ new Map();
                seenFileNamesMap.set(affectedFile.resolvedPath, true);
                const queue = BuilderState.getReferencedByPaths(state, affectedFile.resolvedPath);
                while (queue.length > 0) {
                    const currentPath = queue.pop();
                    if (!seenFileNamesMap.has(currentPath)) {
                        seenFileNamesMap.set(currentPath, true);
                        if (handleDtsMayChangeOfGlobalScope(state, currentPath, cancellationToken, host))
                            return;
                        handleDtsMayChangeOf(state, currentPath, cancellationToken, host);
                        if (isChangedSignature(state, currentPath)) {
                            const currentSourceFile = Debug.checkDefined(state.program).getSourceFileByPath(currentPath);
                            queue.push(...BuilderState.getReferencedByPaths(state, currentSourceFile.resolvedPath));
                        }
                    }
                }
            }
            const seenFileAndExportsOfFile = /* @__PURE__ */ new Set();
            (_a = state.exportedModulesMap.getKeys(affectedFile.resolvedPath)) == null ? void 0 : _a.forEach((exportedFromPath) => {
                if (handleDtsMayChangeOfGlobalScope(state, exportedFromPath, cancellationToken, host))
                    return true;
                const references = state.referencedMap.getKeys(exportedFromPath);
                return references && forEachKey(references, (filePath) => handleDtsMayChangeOfFileAndExportsOfFile(state, filePath, seenFileAndExportsOfFile, cancellationToken, host));
            });
        }
        function handleDtsMayChangeOfFileAndExportsOfFile(state, filePath, seenFileAndExportsOfFile, cancellationToken, host) {
            var _a, _b;
            if (!tryAddToSet(seenFileAndExportsOfFile, filePath))
                return void 0;
            if (handleDtsMayChangeOfGlobalScope(state, filePath, cancellationToken, host))
                return true;
            handleDtsMayChangeOf(state, filePath, cancellationToken, host);
            (_a = state.exportedModulesMap.getKeys(filePath)) == null ? void 0 : _a.forEach((exportedFromPath) => handleDtsMayChangeOfFileAndExportsOfFile(state, exportedFromPath, seenFileAndExportsOfFile, cancellationToken, host));
            (_b = state.referencedMap.getKeys(filePath)) == null ? void 0 : _b.forEach((referencingFilePath) => !seenFileAndExportsOfFile.has(referencingFilePath) && // Not already removed diagnostic file
                handleDtsMayChangeOf(
                // Dont add to seen since this is not yet done with the export removal
                state, referencingFilePath, cancellationToken, host));
            return void 0;
        }
        function getSemanticDiagnosticsOfFile(state, sourceFile, cancellationToken) {
            return concatenate(getBinderAndCheckerDiagnosticsOfFile(state, sourceFile, cancellationToken), Debug.checkDefined(state.program).getProgramDiagnostics(sourceFile));
        }
        function getBinderAndCheckerDiagnosticsOfFile(state, sourceFile, cancellationToken) {
            const path = sourceFile.resolvedPath;
            if (state.semanticDiagnosticsPerFile) {
                const cachedDiagnostics = state.semanticDiagnosticsPerFile.get(path);
                if (cachedDiagnostics) {
                    return filterSemanticDiagnostics(cachedDiagnostics, state.compilerOptions);
                }
            }
            const diagnostics = Debug.checkDefined(state.program).getBindAndCheckDiagnostics(sourceFile, cancellationToken);
            if (state.semanticDiagnosticsPerFile) {
                state.semanticDiagnosticsPerFile.set(path, diagnostics);
            }
            return filterSemanticDiagnostics(diagnostics, state.compilerOptions);
        }
        function isProgramBundleEmitBuildInfo(info) {
            return !!outFile(info.options || {});
        }
        function getBuildInfo2(state, bundle) {
            var _a, _b, _c;
            const currentDirectory = Debug.checkDefined(state.program).getCurrentDirectory();
            const buildInfoDirectory = getDirectoryPath(getNormalizedAbsolutePath(getTsBuildInfoEmitOutputFilePath(state.compilerOptions), currentDirectory));
            const latestChangedDtsFile = state.latestChangedDtsFile ? relativeToBuildInfoEnsuringAbsolutePath(state.latestChangedDtsFile) : void 0;
            const fileNames = [];
            const fileNameToFileId = /* @__PURE__ */ new Map();
            const root = [];
            if (outFile(state.compilerOptions)) {
                const fileInfos2 = arrayFrom(state.fileInfos.entries(), ([key, value]) => {
                    const fileId = toFileId(key);
                    tryAddRoot(key, fileId);
                    return value.impliedFormat ? { version: value.version, impliedFormat: value.impliedFormat, signature: void 0, affectsGlobalScope: void 0 } : value.version;
                });
                const program2 = {
                    fileNames,
                    fileInfos: fileInfos2,
                    root,
                    options: convertToProgramBuildInfoCompilerOptions(state.compilerOptions),
                    outSignature: state.outSignature,
                    latestChangedDtsFile,
                    pendingEmit: !state.programEmitPending ? void 0 : (
                    // Pending is undefined or None is encoded as undefined
                    state.programEmitPending === getBuilderFileEmit(state.compilerOptions) ? false : (
                    // Pending emit is same as deteremined by compilerOptions
                    state.programEmitPending))
                    // Actual value
                };
                const { js, dts, commonSourceDirectory, sourceFiles } = bundle;
                state.bundle = bundle = {
                    commonSourceDirectory,
                    sourceFiles,
                    js: js || (!state.compilerOptions.emitDeclarationOnly ? (_a = state.bundle) == null ? void 0 : _a.js : void 0),
                    dts: dts || (getEmitDeclarations(state.compilerOptions) ? (_b = state.bundle) == null ? void 0 : _b.dts : void 0)
                };
                return createBuildInfo(program2, bundle);
            }
            let fileIdsList;
            let fileNamesToFileIdListId;
            let emitSignatures;
            const fileInfos = arrayFrom(state.fileInfos.entries(), ([key, value]) => {
                var _a2, _b2;
                const fileId = toFileId(key);
                tryAddRoot(key, fileId);
                Debug.assert(fileNames[fileId - 1] === relativeToBuildInfo(key));
                const oldSignature = (_a2 = state.oldSignatures) == null ? void 0 : _a2.get(key);
                const actualSignature = oldSignature !== void 0 ? oldSignature || void 0 : value.signature;
                if (state.compilerOptions.composite) {
                    const file = state.program.getSourceFileByPath(key);
                    if (!isJsonSourceFile(file) && sourceFileMayBeEmitted(file, state.program)) {
                        const emitSignature = (_b2 = state.emitSignatures) == null ? void 0 : _b2.get(key);
                        if (emitSignature !== actualSignature) {
                            (emitSignatures || (emitSignatures = [])).push(emitSignature === void 0 ? fileId : (
                            // There is no emit, encode as false
                            // fileId, signature: emptyArray if signature only differs in dtsMap option than our own compilerOptions otherwise EmitSignature
                            [fileId, !isString(emitSignature) && emitSignature[0] === actualSignature ? emptyArray : emitSignature]));
                        }
                    }
                }
                return value.version === actualSignature ? value.affectsGlobalScope || value.impliedFormat ? (
                // If file version is same as signature, dont serialize signature
                { version: value.version, signature: void 0, affectsGlobalScope: value.affectsGlobalScope, impliedFormat: value.impliedFormat }) : (
                // If file info only contains version and signature and both are same we can just write string
                value.version) : actualSignature !== void 0 ? (
                // If signature is not same as version, encode signature in the fileInfo
                oldSignature === void 0 ? (
                // If we havent computed signature, use fileInfo as is
                value) : (
                // Serialize fileInfo with new updated signature
                { version: value.version, signature: actualSignature, affectsGlobalScope: value.affectsGlobalScope, impliedFormat: value.impliedFormat })) : (
                // Signature of the FileInfo is undefined, serialize it as false
                { version: value.version, signature: false, affectsGlobalScope: value.affectsGlobalScope, impliedFormat: value.impliedFormat });
            });
            let referencedMap;
            if (state.referencedMap) {
                referencedMap = arrayFrom(state.referencedMap.keys()).sort(compareStringsCaseSensitive).map((key) => [
                    toFileId(key),
                    toFileIdListId(state.referencedMap.getValues(key))
                ]);
            }
            let exportedModulesMap;
            if (state.exportedModulesMap) {
                exportedModulesMap = mapDefined(arrayFrom(state.exportedModulesMap.keys()).sort(compareStringsCaseSensitive), (key) => {
                    var _a2;
                    const oldValue = (_a2 = state.oldExportedModulesMap) == null ? void 0 : _a2.get(key);
                    if (oldValue === void 0)
                        return [toFileId(key), toFileIdListId(state.exportedModulesMap.getValues(key))];
                    if (oldValue)
                        return [toFileId(key), toFileIdListId(oldValue)];
                    return void 0;
                });
            }
            const semanticDiagnosticsPerFile = convertToProgramBuildInfoDiagnostics(state.semanticDiagnosticsPerFile);
            let affectedFilesPendingEmit;
            if ((_c = state.affectedFilesPendingEmit) == null ? void 0 : _c.size) {
                const fullEmitForOptions = getBuilderFileEmit(state.compilerOptions);
                const seenFiles = /* @__PURE__ */ new Set();
                for (const path of arrayFrom(state.affectedFilesPendingEmit.keys()).sort(compareStringsCaseSensitive)) {
                    if (tryAddToSet(seenFiles, path)) {
                        const file = state.program.getSourceFileByPath(path);
                        if (!file || !sourceFileMayBeEmitted(file, state.program))
                            continue;
                        const fileId = toFileId(path), pendingEmit = state.affectedFilesPendingEmit.get(path);
                        (affectedFilesPendingEmit || (affectedFilesPendingEmit = [])).push(pendingEmit === fullEmitForOptions ? fileId : (
                        // Pending full emit per options
                        pendingEmit === 8 /* Dts */ ? [fileId] : (
                        // Pending on Dts only
                        [fileId, pendingEmit]))
                        // Anything else
                        );
                    }
                }
            }
            let changeFileSet;
            if (state.changedFilesSet.size) {
                for (const path of arrayFrom(state.changedFilesSet.keys()).sort(compareStringsCaseSensitive)) {
                    (changeFileSet || (changeFileSet = [])).push(toFileId(path));
                }
            }
            const emitDiagnosticsPerFile = convertToProgramBuildInfoDiagnostics(state.emitDiagnosticsPerFile);
            const program = {
                fileNames,
                fileInfos,
                root,
                options: convertToProgramBuildInfoCompilerOptions(state.compilerOptions),
                fileIdsList,
                referencedMap,
                exportedModulesMap,
                semanticDiagnosticsPerFile,
                emitDiagnosticsPerFile,
                affectedFilesPendingEmit,
                changeFileSet,
                emitSignatures,
                latestChangedDtsFile
            };
            return createBuildInfo(program, bundle);
            function relativeToBuildInfoEnsuringAbsolutePath(path) {
                return relativeToBuildInfo(getNormalizedAbsolutePath(path, currentDirectory));
            }
            function relativeToBuildInfo(path) {
                return ensurePathIsNonModuleName(getRelativePathFromDirectory(buildInfoDirectory, path, state.program.getCanonicalFileName));
            }
            function toFileId(path) {
                let fileId = fileNameToFileId.get(path);
                if (fileId === void 0) {
                    fileNames.push(relativeToBuildInfo(path));
                    fileNameToFileId.set(path, fileId = fileNames.length);
                }
                return fileId;
            }
            function toFileIdListId(set) {
                const fileIds = arrayFrom(set.keys(), toFileId).sort(compareValues);
                const key = fileIds.join();
                let fileIdListId = fileNamesToFileIdListId == null ? void 0 : fileNamesToFileIdListId.get(key);
                if (fileIdListId === void 0) {
                    (fileIdsList || (fileIdsList = [])).push(fileIds);
                    (fileNamesToFileIdListId || (fileNamesToFileIdListId = /* @__PURE__ */ new Map())).set(key, fileIdListId = fileIdsList.length);
                }
                return fileIdListId;
            }
            function tryAddRoot(path, fileId) {
                const file = state.program.getSourceFile(path);
                if (!state.program.getFileIncludeReasons().get(file.path).some((r) => r.kind === 0 /* RootFile */))
                    return;
                if (!root.length)
                    return root.push(fileId);
                const last2 = root[root.length - 1];
                const isLastStartEnd = isArray(last2);
                if (isLastStartEnd && last2[1] === fileId - 1)
                    return last2[1] = fileId;
                if (isLastStartEnd || root.length === 1 || last2 !== fileId - 1)
                    return root.push(fileId);
                const lastButOne = root[root.length - 2];
                if (!isNumber(lastButOne) || lastButOne !== last2 - 1)
                    return root.push(fileId);
                root[root.length - 2] = [lastButOne, fileId];
                return root.length = root.length - 1;
            }
            function convertToProgramBuildInfoCompilerOptions(options) {
                let result;
                const { optionsNameMap } = getOptionsNameMap();
                for (const name of getOwnKeys(options).sort(compareStringsCaseSensitive)) {
                    const optionInfo = optionsNameMap.get(name.toLowerCase());
                    if (optionInfo == null ? void 0 : optionInfo.affectsBuildInfo) {
                        (result || (result = {}))[name] = convertToReusableCompilerOptionValue(optionInfo, options[name]);
                    }
                }
                return result;
            }
            function convertToReusableCompilerOptionValue(option, value) {
                if (option) {
                    Debug.assert(option.type !== "listOrElement");
                    if (option.type === "list") {
                        const values = value;
                        if (option.element.isFilePath && values.length) {
                            return values.map(relativeToBuildInfoEnsuringAbsolutePath);
                        }
                    }
                    else if (option.isFilePath) {
                        return relativeToBuildInfoEnsuringAbsolutePath(value);
                    }
                }
                return value;
            }
            function convertToProgramBuildInfoDiagnostics(diagnostics) {
                let result;
                if (diagnostics) {
                    for (const key of arrayFrom(diagnostics.keys()).sort(compareStringsCaseSensitive)) {
                        const value = diagnostics.get(key);
                        (result || (result = [])).push(value.length ? [
                            toFileId(key),
                            convertToReusableDiagnostics(value)
                        ] : toFileId(key));
                    }
                }
                return result;
            }
            function convertToReusableDiagnostics(diagnostics) {
                Debug.assert(!!diagnostics.length);
                return diagnostics.map((diagnostic) => {
                    const result = convertToReusableDiagnosticRelatedInformation(diagnostic);
                    result.reportsUnnecessary = diagnostic.reportsUnnecessary;
                    result.reportDeprecated = diagnostic.reportsDeprecated;
                    result.source = diagnostic.source;
                    result.skippedOn = diagnostic.skippedOn;
                    const { relatedInformation } = diagnostic;
                    result.relatedInformation = relatedInformation ? relatedInformation.length ? relatedInformation.map((r) => convertToReusableDiagnosticRelatedInformation(r)) : [] : void 0;
                    return result;
                });
            }
            function convertToReusableDiagnosticRelatedInformation(diagnostic) {
                const { file } = diagnostic;
                return {
                    ...diagnostic,
                    file: file ? relativeToBuildInfo(file.resolvedPath) : void 0,
                    messageText: isString(diagnostic.messageText) ? diagnostic.messageText : convertToReusableDiagnosticMessageChain(diagnostic.messageText)
                };
            }
            function convertToReusableDiagnosticMessageChain(chain) {
                if (chain.repopulateInfo) {
                    return {
                        info: chain.repopulateInfo(),
                        next: convertToReusableDiagnosticMessageChainArray(chain.next)
                    };
                }
                const next = convertToReusableDiagnosticMessageChainArray(chain.next);
                return next === chain.next ? chain : { ...chain, next };
            }
            function convertToReusableDiagnosticMessageChainArray(array) {
                if (!array)
                    return array;
                return forEach(array, (chain, index) => {
                    const reusable = convertToReusableDiagnosticMessageChain(chain);
                    if (chain === reusable)
                        return void 0;
                    const result = index > 0 ? array.slice(0, index - 1) : [];
                    result.push(reusable);
                    for (let i = index + 1; i < array.length; i++) {
                        result.push(convertToReusableDiagnosticMessageChain(array[i]));
                    }
                    return result;
                }) || array;
            }
        }
        function getBuilderCreationParameters(newProgramOrRootNames, hostOrOptions, oldProgramOrHost, configFileParsingDiagnosticsOrOldProgram, configFileParsingDiagnostics, projectReferences) {
            let host;
            let newProgram;
            let oldProgram;
            if (newProgramOrRootNames === void 0) {
                Debug.assert(hostOrOptions === void 0);
                host = oldProgramOrHost;
                oldProgram = configFileParsingDiagnosticsOrOldProgram;
                Debug.assert(!!oldProgram);
                newProgram = oldProgram.getProgram();
            }
            else if (isArray(newProgramOrRootNames)) {
                oldProgram = configFileParsingDiagnosticsOrOldProgram;
                newProgram = createProgram({
                    rootNames: newProgramOrRootNames,
                    options: hostOrOptions,
                    host: oldProgramOrHost,
                    oldProgram: oldProgram && oldProgram.getProgramOrUndefined(),
                    configFileParsingDiagnostics,
                    projectReferences
                });
                host = oldProgramOrHost;
            }
            else {
                newProgram = newProgramOrRootNames;
                host = hostOrOptions;
                oldProgram = oldProgramOrHost;
                configFileParsingDiagnostics = configFileParsingDiagnosticsOrOldProgram;
            }
            return { host, newProgram, oldProgram, configFileParsingDiagnostics: configFileParsingDiagnostics || emptyArray };
        }
        function getTextHandlingSourceMapForSignature(text, data) {
            return (data == null ? void 0 : data.sourceMapUrlPos) !== void 0 ? text.substring(0, data.sourceMapUrlPos) : text;
        }
        function computeSignatureWithDiagnostics(program, sourceFile, text, host, data) {
            var _a;
            text = getTextHandlingSourceMapForSignature(text, data);
            let sourceFileDirectory;
            if ((_a = data == null ? void 0 : data.diagnostics) == null ? void 0 : _a.length) {
                text += data.diagnostics.map((diagnostic) => `${locationInfo(diagnostic)}${DiagnosticCategory[diagnostic.category]}${diagnostic.code}: ${flattenDiagnosticMessageText2(diagnostic.messageText)}`).join("\n");
            }
            return (host.createHash ?? generateDjb2Hash)(text);
            function flattenDiagnosticMessageText2(diagnostic) {
                return isString(diagnostic) ? diagnostic : diagnostic === void 0 ? "" : !diagnostic.next ? diagnostic.messageText : diagnostic.messageText + diagnostic.next.map(flattenDiagnosticMessageText2).join("\n");
            }
            function locationInfo(diagnostic) {
                if (diagnostic.file.resolvedPath === sourceFile.resolvedPath)
                    return `(${diagnostic.start},${diagnostic.length})`;
                if (sourceFileDirectory === void 0)
                    sourceFileDirectory = getDirectoryPath(sourceFile.resolvedPath);
                return `${ensurePathIsNonModuleName(getRelativePathFromDirectory(sourceFileDirectory, diagnostic.file.resolvedPath, program.getCanonicalFileName))}(${diagnostic.start},${diagnostic.length})`;
            }
        }
        function computeSignature(text, host, data) {
            return (host.createHash ?? generateDjb2Hash)(getTextHandlingSourceMapForSignature(text, data));
        }
        function createBuilderProgram(kind, { newProgram, host, oldProgram, configFileParsingDiagnostics }) {
            let oldState = oldProgram && oldProgram.getState();
            if (oldState && newProgram === oldState.program && configFileParsingDiagnostics === newProgram.getConfigFileParsingDiagnostics()) {
                newProgram = void 0;
                oldState = void 0;
                return oldProgram;
            }
            const state = createBuilderProgramState(newProgram, oldState);
            newProgram.getBuildInfo = (bundle) => getBuildInfo2(state, bundle);
            newProgram = void 0;
            oldProgram = void 0;
            oldState = void 0;
            const getState = () => state;
            const builderProgram = createRedirectedBuilderProgram(getState, configFileParsingDiagnostics);
            builderProgram.getState = getState;
            builderProgram.saveEmitState = () => backupBuilderProgramEmitState(state);
            builderProgram.restoreEmitState = (saved) => restoreBuilderProgramEmitState(state, saved);
            builderProgram.hasChangedEmitSignature = () => !!state.hasChangedEmitSignature;
            builderProgram.getAllDependencies = (sourceFile) => BuilderState.getAllDependencies(state, Debug.checkDefined(state.program), sourceFile);
            builderProgram.getSemanticDiagnostics = getSemanticDiagnostics;
            builderProgram.emit = emit;
            builderProgram.releaseProgram = () => releaseCache(state);
            if (kind === 0 /* SemanticDiagnosticsBuilderProgram */) {
                builderProgram.getSemanticDiagnosticsOfNextAffectedFile = getSemanticDiagnosticsOfNextAffectedFile;
            }
            else if (kind === 1 /* EmitAndSemanticDiagnosticsBuilderProgram */) {
                builderProgram.getSemanticDiagnosticsOfNextAffectedFile = getSemanticDiagnosticsOfNextAffectedFile;
                builderProgram.emitNextAffectedFile = emitNextAffectedFile;
                builderProgram.emitBuildInfo = emitBuildInfo;
            }
            else {
                notImplemented();
            }
            return builderProgram;
            function emitBuildInfo(writeFile2, cancellationToken) {
                if (state.buildInfoEmitPending) {
                    const result = Debug.checkDefined(state.program).emitBuildInfo(writeFile2 || maybeBind(host, host.writeFile), cancellationToken);
                    state.buildInfoEmitPending = false;
                    return result;
                }
                return emitSkippedWithNoDiagnostics;
            }
            function emitNextAffectedFile(writeFile2, cancellationToken, emitOnlyDtsFiles, customTransformers) {
                var _a, _b, _c;
                let affected = getNextAffectedFile(state, cancellationToken, host);
                const programEmitKind = getBuilderFileEmit(state.compilerOptions);
                let emitKind = emitOnlyDtsFiles ? programEmitKind & 24 /* AllDts */ : programEmitKind;
                if (!affected) {
                    if (!outFile(state.compilerOptions)) {
                        const pendingAffectedFile = getNextAffectedFilePendingEmit(state, emitOnlyDtsFiles);
                        if (!pendingAffectedFile) {
                            const pendingForDiagnostics = getNextPendingEmitDiagnosticsFile(state);
                            if (pendingForDiagnostics) {
                                (state.seenEmittedFiles ?? (state.seenEmittedFiles = /* @__PURE__ */ new Map())).set(pendingForDiagnostics.affectedFile.resolvedPath, pendingForDiagnostics.seenKind | 24 /* AllDts */);
                                return {
                                    result: { emitSkipped: true, diagnostics: pendingForDiagnostics.diagnostics },
                                    affected: pendingForDiagnostics.affectedFile
                                };
                            }
                            if (!state.buildInfoEmitPending)
                                return void 0;
                            const affected2 = state.program;
                            const result2 = affected2.emitBuildInfo(writeFile2 || maybeBind(host, host.writeFile), cancellationToken);
                            state.buildInfoEmitPending = false;
                            return { result: result2, affected: affected2 };
                        }
                        ({ affectedFile: affected, emitKind } = pendingAffectedFile);
                    }
                    else {
                        if (!state.programEmitPending)
                            return void 0;
                        emitKind = state.programEmitPending;
                        if (emitOnlyDtsFiles)
                            emitKind = emitKind & 24 /* AllDts */;
                        if (!emitKind)
                            return void 0;
                        affected = state.program;
                    }
                }
                let emitOnly;
                if (emitKind & 7 /* AllJs */)
                    emitOnly = 0 /* Js */;
                if (emitKind & 24 /* AllDts */)
                    emitOnly = emitOnly === void 0 ? 1 /* Dts */ : void 0;
                if (affected === state.program) {
                    state.programEmitPending = state.changedFilesSet.size ? getPendingEmitKind(programEmitKind, emitKind) : state.programEmitPending ? getPendingEmitKind(state.programEmitPending, emitKind) : void 0;
                }
                const result = state.program.emit(affected === state.program ? void 0 : affected, getWriteFileCallback(writeFile2, customTransformers), cancellationToken, emitOnly, customTransformers);
                if (affected !== state.program) {
                    const affectedSourceFile = affected;
                    state.seenAffectedFiles.add(affectedSourceFile.resolvedPath);
                    if (state.affectedFilesIndex !== void 0)
                        state.affectedFilesIndex++;
                    state.buildInfoEmitPending = true;
                    const existing = ((_a = state.seenEmittedFiles) == null ? void 0 : _a.get(affectedSourceFile.resolvedPath)) || 0 /* None */;
                    (state.seenEmittedFiles ?? (state.seenEmittedFiles = /* @__PURE__ */ new Map())).set(affectedSourceFile.resolvedPath, emitKind | existing);
                    const existingPending = ((_b = state.affectedFilesPendingEmit) == null ? void 0 : _b.get(affectedSourceFile.resolvedPath)) || programEmitKind;
                    const pendingKind = getPendingEmitKind(existingPending, emitKind | existing);
                    if (pendingKind)
                        (state.affectedFilesPendingEmit ?? (state.affectedFilesPendingEmit = /* @__PURE__ */ new Map())).set(affectedSourceFile.resolvedPath, pendingKind);
                    else
                        (_c = state.affectedFilesPendingEmit) == null ? void 0 : _c.delete(affectedSourceFile.resolvedPath);
                    if (result.diagnostics.length)
                        (state.emitDiagnosticsPerFile ?? (state.emitDiagnosticsPerFile = /* @__PURE__ */ new Map())).set(affectedSourceFile.resolvedPath, result.diagnostics);
                }
                else {
                    state.changedFilesSet.clear();
                }
                return { result, affected };
            }
            function getWriteFileCallback(writeFile2, customTransformers) {
                if (!getEmitDeclarations(state.compilerOptions))
                    return writeFile2 || maybeBind(host, host.writeFile);
                return (fileName, text, writeByteOrderMark, onError, sourceFiles, data) => {
                    var _a, _b, _c, _d;
                    if (isDeclarationFileName(fileName)) {
                        if (!outFile(state.compilerOptions)) {
                            Debug.assert((sourceFiles == null ? void 0 : sourceFiles.length) === 1);
                            let emitSignature;
                            if (!customTransformers) {
                                const file = sourceFiles[0];
                                const info = state.fileInfos.get(file.resolvedPath);
                                if (info.signature === file.version) {
                                    const signature = computeSignatureWithDiagnostics(state.program, file, text, host, data);
                                    if (!((_a = data == null ? void 0 : data.diagnostics) == null ? void 0 : _a.length))
                                        emitSignature = signature;
                                    if (signature !== file.version) {
                                        if (host.storeFilesChangingSignatureDuringEmit)
                                            (state.filesChangingSignature ?? (state.filesChangingSignature = /* @__PURE__ */ new Set())).add(file.resolvedPath);
                                        if (state.exportedModulesMap)
                                            BuilderState.updateExportedModules(state, file, file.exportedModulesFromDeclarationEmit);
                                        if (state.affectedFiles) {
                                            const existing = (_b = state.oldSignatures) == null ? void 0 : _b.get(file.resolvedPath);
                                            if (existing === void 0)
                                                (state.oldSignatures ?? (state.oldSignatures = /* @__PURE__ */ new Map())).set(file.resolvedPath, info.signature || false);
                                            info.signature = signature;
                                        }
                                        else {
                                            info.signature = signature;
                                            (_c = state.oldExportedModulesMap) == null ? void 0 : _c.clear();
                                        }
                                    }
                                }
                            }
                            if (state.compilerOptions.composite) {
                                const filePath = sourceFiles[0].resolvedPath;
                                emitSignature = handleNewSignature((_d = state.emitSignatures) == null ? void 0 : _d.get(filePath), emitSignature);
                                if (!emitSignature)
                                    return;
                                (state.emitSignatures ?? (state.emitSignatures = /* @__PURE__ */ new Map())).set(filePath, emitSignature);
                            }
                        }
                        else if (state.compilerOptions.composite) {
                            const newSignature = handleNewSignature(state.outSignature, 
                            /*newSignature*/
                            void 0);
                            if (!newSignature)
                                return;
                            state.outSignature = newSignature;
                        }
                    }
                    if (writeFile2)
                        writeFile2(fileName, text, writeByteOrderMark, onError, sourceFiles, data);
                    else if (host.writeFile)
                        host.writeFile(fileName, text, writeByteOrderMark, onError, sourceFiles, data);
                    else
                        state.program.writeFile(fileName, text, writeByteOrderMark, onError, sourceFiles, data);
                    function handleNewSignature(oldSignatureFormat, newSignature) {
                        const oldSignature = !oldSignatureFormat || isString(oldSignatureFormat) ? oldSignatureFormat : oldSignatureFormat[0];
                        newSignature ?? (newSignature = computeSignature(text, host, data));
                        if (newSignature === oldSignature) {
                            if (oldSignatureFormat === oldSignature)
                                return void 0;
                            else if (data)
                                data.differsOnlyInMap = true;
                            else
                                data = { differsOnlyInMap: true };
                        }
                        else {
                            state.hasChangedEmitSignature = true;
                            state.latestChangedDtsFile = fileName;
                        }
                        return newSignature;
                    }
                };
            }
            function emit(targetSourceFile, writeFile2, cancellationToken, emitOnlyDtsFiles, customTransformers) {
                if (kind === 1 /* EmitAndSemanticDiagnosticsBuilderProgram */) {
                    assertSourceFileOkWithoutNextAffectedCall(state, targetSourceFile);
                }
                const result = handleNoEmitOptions(builderProgram, targetSourceFile, writeFile2, cancellationToken);
                if (result)
                    return result;
                if (!targetSourceFile) {
                    if (kind === 1 /* EmitAndSemanticDiagnosticsBuilderProgram */) {
                        let sourceMaps = [];
                        let emitSkipped = false;
                        let diagnostics;
                        let emittedFiles = [];
                        let affectedEmitResult;
                        while (affectedEmitResult = emitNextAffectedFile(writeFile2, cancellationToken, emitOnlyDtsFiles, customTransformers)) {
                            emitSkipped = emitSkipped || affectedEmitResult.result.emitSkipped;
                            diagnostics = addRange(diagnostics, affectedEmitResult.result.diagnostics);
                            emittedFiles = addRange(emittedFiles, affectedEmitResult.result.emittedFiles);
                            sourceMaps = addRange(sourceMaps, affectedEmitResult.result.sourceMaps);
                        }
                        return {
                            emitSkipped,
                            diagnostics: diagnostics || emptyArray,
                            emittedFiles,
                            sourceMaps
                        };
                    }
                    else {
                        clearAffectedFilesPendingEmit(state, emitOnlyDtsFiles);
                    }
                }
                return Debug.checkDefined(state.program).emit(targetSourceFile, getWriteFileCallback(writeFile2, customTransformers), cancellationToken, emitOnlyDtsFiles, customTransformers);
            }
            function getSemanticDiagnosticsOfNextAffectedFile(cancellationToken, ignoreSourceFile) {
                while (true) {
                    const affected = getNextAffectedFile(state, cancellationToken, host);
                    let result;
                    if (!affected)
                        return void 0;
                    else if (affected !== state.program) {
                        const affectedSourceFile = affected;
                        if (!ignoreSourceFile || !ignoreSourceFile(affectedSourceFile)) {
                            result = getSemanticDiagnosticsOfFile(state, affectedSourceFile, cancellationToken);
                        }
                        state.seenAffectedFiles.add(affectedSourceFile.resolvedPath);
                        state.affectedFilesIndex++;
                        state.buildInfoEmitPending = true;
                        if (!result)
                            continue;
                    }
                    else {
                        result = state.program.getSemanticDiagnostics(
                        /*sourceFile*/
                        void 0, cancellationToken);
                        state.changedFilesSet.clear();
                        state.programEmitPending = getBuilderFileEmit(state.compilerOptions);
                    }
                    return { result, affected };
                }
            }
            function getSemanticDiagnostics(sourceFile, cancellationToken) {
                assertSourceFileOkWithoutNextAffectedCall(state, sourceFile);
                const compilerOptions = Debug.checkDefined(state.program).getCompilerOptions();
                if (outFile(compilerOptions)) {
                    Debug.assert(!state.semanticDiagnosticsPerFile);
                    return Debug.checkDefined(state.program).getSemanticDiagnostics(sourceFile, cancellationToken);
                }
                if (sourceFile) {
                    return getSemanticDiagnosticsOfFile(state, sourceFile, cancellationToken);
                }
                while (getSemanticDiagnosticsOfNextAffectedFile(cancellationToken)) {
                }
                let diagnostics;
                for (const sourceFile2 of Debug.checkDefined(state.program).getSourceFiles()) {
                    diagnostics = addRange(diagnostics, getSemanticDiagnosticsOfFile(state, sourceFile2, cancellationToken));
                }
                return diagnostics || emptyArray;
            }
        }
        function addToAffectedFilesPendingEmit(state, affectedFilePendingEmit, kind) {
            var _a, _b;
            const existingKind = ((_a = state.affectedFilesPendingEmit) == null ? void 0 : _a.get(affectedFilePendingEmit)) || 0 /* None */;
            (state.affectedFilesPendingEmit ?? (state.affectedFilesPendingEmit = /* @__PURE__ */ new Map())).set(affectedFilePendingEmit, existingKind | kind);
            (_b = state.emitDiagnosticsPerFile) == null ? void 0 : _b.delete(affectedFilePendingEmit);
        }
        function toBuilderStateFileInfoForMultiEmit(fileInfo) {
            return isString(fileInfo) ? { version: fileInfo, signature: fileInfo, affectsGlobalScope: void 0, impliedFormat: void 0 } : isString(fileInfo.signature) ? fileInfo : { version: fileInfo.version, signature: fileInfo.signature === false ? void 0 : fileInfo.version, affectsGlobalScope: fileInfo.affectsGlobalScope, impliedFormat: fileInfo.impliedFormat };
        }
        function toBuilderFileEmit(value, fullEmitForOptions) {
            return isNumber(value) ? fullEmitForOptions : value[1] || 8 /* Dts */;
        }
        function toProgramEmitPending(value, options) {
            return !value ? getBuilderFileEmit(options || {}) : value;
        }
        function createBuilderProgramUsingProgramBuildInfo(buildInfo, buildInfoPath, host) {
            var _a, _b, _c, _d;
            const program = buildInfo.program;
            const buildInfoDirectory = getDirectoryPath(getNormalizedAbsolutePath(buildInfoPath, host.getCurrentDirectory()));
            const getCanonicalFileName = createGetCanonicalFileName(host.useCaseSensitiveFileNames());
            let state;
            const filePaths = (_a = program.fileNames) == null ? void 0 : _a.map(toPathInBuildInfoDirectory);
            let filePathsSetList;
            const latestChangedDtsFile = program.latestChangedDtsFile ? toAbsolutePath(program.latestChangedDtsFile) : void 0;
            if (isProgramBundleEmitBuildInfo(program)) {
                const fileInfos = /* @__PURE__ */ new Map();
                program.fileInfos.forEach((fileInfo, index) => {
                    const path = toFilePath(index + 1);
                    fileInfos.set(path, isString(fileInfo) ? { version: fileInfo, signature: void 0, affectsGlobalScope: void 0, impliedFormat: void 0 } : fileInfo);
                });
                state = {
                    fileInfos,
                    compilerOptions: program.options ? convertToOptionsWithAbsolutePaths(program.options, toAbsolutePath) : {},
                    latestChangedDtsFile,
                    outSignature: program.outSignature,
                    programEmitPending: program.pendingEmit === void 0 ? void 0 : toProgramEmitPending(program.pendingEmit, program.options),
                    bundle: buildInfo.bundle
                };
            }
            else {
                filePathsSetList = (_b = program.fileIdsList) == null ? void 0 : _b.map((fileIds) => new Set(fileIds.map(toFilePath)));
                const fileInfos = /* @__PURE__ */ new Map();
                const emitSignatures = ((_c = program.options) == null ? void 0 : _c.composite) && !outFile(program.options) ? /* @__PURE__ */ new Map() : void 0;
                program.fileInfos.forEach((fileInfo, index) => {
                    const path = toFilePath(index + 1);
                    const stateFileInfo = toBuilderStateFileInfoForMultiEmit(fileInfo);
                    fileInfos.set(path, stateFileInfo);
                    if (emitSignatures && stateFileInfo.signature)
                        emitSignatures.set(path, stateFileInfo.signature);
                });
                (_d = program.emitSignatures) == null ? void 0 : _d.forEach((value) => {
                    if (isNumber(value))
                        emitSignatures.delete(toFilePath(value));
                    else {
                        const key = toFilePath(value[0]);
                        emitSignatures.set(key, !isString(value[1]) && !value[1].length ? (
                        // File signature is emit signature but differs in map
                        [emitSignatures.get(key)]) : value[1]);
                    }
                });
                const fullEmitForOptions = program.affectedFilesPendingEmit ? getBuilderFileEmit(program.options || {}) : void 0;
                state = {
                    fileInfos,
                    compilerOptions: program.options ? convertToOptionsWithAbsolutePaths(program.options, toAbsolutePath) : {},
                    referencedMap: toManyToManyPathMap(program.referencedMap),
                    exportedModulesMap: toManyToManyPathMap(program.exportedModulesMap),
                    semanticDiagnosticsPerFile: toPerFileDiagnostics(program.semanticDiagnosticsPerFile),
                    emitDiagnosticsPerFile: toPerFileDiagnostics(program.emitDiagnosticsPerFile),
                    hasReusableDiagnostic: true,
                    affectedFilesPendingEmit: program.affectedFilesPendingEmit && arrayToMap(program.affectedFilesPendingEmit, (value) => toFilePath(isNumber(value) ? value : value[0]), (value) => toBuilderFileEmit(value, fullEmitForOptions)),
                    changedFilesSet: new Set(map(program.changeFileSet, toFilePath)),
                    latestChangedDtsFile,
                    emitSignatures: (emitSignatures == null ? void 0 : emitSignatures.size) ? emitSignatures : void 0
                };
            }
            return {
                getState: () => state,
                saveEmitState: noop,
                restoreEmitState: noop,
                getProgram: notImplemented,
                getProgramOrUndefined: returnUndefined,
                releaseProgram: noop,
                getCompilerOptions: () => state.compilerOptions,
                getSourceFile: notImplemented,
                getSourceFiles: notImplemented,
                getOptionsDiagnostics: notImplemented,
                getGlobalDiagnostics: notImplemented,
                getConfigFileParsingDiagnostics: notImplemented,
                getSyntacticDiagnostics: notImplemented,
                getDeclarationDiagnostics: notImplemented,
                getSemanticDiagnostics: notImplemented,
                emit: notImplemented,
                getAllDependencies: notImplemented,
                getCurrentDirectory: notImplemented,
                emitNextAffectedFile: notImplemented,
                getSemanticDiagnosticsOfNextAffectedFile: notImplemented,
                emitBuildInfo: notImplemented,
                close: noop,
                hasChangedEmitSignature: returnFalse
            };
            function toPathInBuildInfoDirectory(path) {
                return toPath(path, buildInfoDirectory, getCanonicalFileName);
            }
            function toAbsolutePath(path) {
                return getNormalizedAbsolutePath(path, buildInfoDirectory);
            }
            function toFilePath(fileId) {
                return filePaths[fileId - 1];
            }
            function toFilePathsSet(fileIdsListId) {
                return filePathsSetList[fileIdsListId - 1];
            }
            function toManyToManyPathMap(referenceMap) {
                if (!referenceMap) {
                    return void 0;
                }
                const map2 = BuilderState.createManyToManyPathMap();
                referenceMap.forEach(([fileId, fileIdListId]) => map2.set(toFilePath(fileId), toFilePathsSet(fileIdListId)));
                return map2;
            }
            function toPerFileDiagnostics(diagnostics) {
                return diagnostics && arrayToMap(diagnostics, (value) => toFilePath(isNumber(value) ? value : value[0]), (value) => isNumber(value) ? emptyArray : value[1]);
            }
        }
        function getBuildInfoFileVersionMap(program, buildInfoPath, host) {
            const buildInfoDirectory = getDirectoryPath(getNormalizedAbsolutePath(buildInfoPath, host.getCurrentDirectory()));
            const getCanonicalFileName = createGetCanonicalFileName(host.useCaseSensitiveFileNames());
            const fileInfos = /* @__PURE__ */ new Map();
            let rootIndex = 0;
            const roots = [];
            program.fileInfos.forEach((fileInfo, index) => {
                const path = toPath(program.fileNames[index], buildInfoDirectory, getCanonicalFileName);
                const version2 = isString(fileInfo) ? fileInfo : fileInfo.version;
                fileInfos.set(path, version2);
                if (rootIndex < program.root.length) {
                    const current = program.root[rootIndex];
                    const fileId = index + 1;
                    if (isArray(current)) {
                        if (current[0] <= fileId && fileId <= current[1]) {
                            roots.push(path);
                            if (current[1] === fileId)
                                rootIndex++;
                        }
                    }
                    else if (current === fileId) {
                        roots.push(path);
                        rootIndex++;
                    }
                }
            });
            return { fileInfos, roots };
        }
        function createRedirectedBuilderProgram(getState, configFileParsingDiagnostics) {
            return {
                getState: notImplemented,
                saveEmitState: noop,
                restoreEmitState: noop,
                getProgram,
                getProgramOrUndefined: () => getState().program,
                releaseProgram: () => getState().program = void 0,
                getCompilerOptions: () => getState().compilerOptions,
                getSourceFile: (fileName) => getProgram().getSourceFile(fileName),
                getSourceFiles: () => getProgram().getSourceFiles(),
                getOptionsDiagnostics: (cancellationToken) => getProgram().getOptionsDiagnostics(cancellationToken),
                getGlobalDiagnostics: (cancellationToken) => getProgram().getGlobalDiagnostics(cancellationToken),
                getConfigFileParsingDiagnostics: () => configFileParsingDiagnostics,
                getSyntacticDiagnostics: (sourceFile, cancellationToken) => getProgram().getSyntacticDiagnostics(sourceFile, cancellationToken),
                getDeclarationDiagnostics: (sourceFile, cancellationToken) => getProgram().getDeclarationDiagnostics(sourceFile, cancellationToken),
                getSemanticDiagnostics: (sourceFile, cancellationToken) => getProgram().getSemanticDiagnostics(sourceFile, cancellationToken),
                emit: (sourceFile, writeFile2, cancellationToken, emitOnlyDts, customTransformers) => getProgram().emit(sourceFile, writeFile2, cancellationToken, emitOnlyDts, customTransformers),
                emitBuildInfo: (writeFile2, cancellationToken) => getProgram().emitBuildInfo(writeFile2, cancellationToken),
                getAllDependencies: notImplemented,
                getCurrentDirectory: () => getProgram().getCurrentDirectory(),
                close: noop
            };
            function getProgram() {
                return Debug.checkDefined(getState().program);
            }
        }
        var BuilderFileEmit, BuilderProgramKind;
        var init_builder = __esm({
            "src/compiler/builder.ts"() {
                "use strict";
                init_ts2();
                BuilderFileEmit = /* @__PURE__ */ ((BuilderFileEmit2) => {
                    BuilderFileEmit2[BuilderFileEmit2["None"] = 0] = "None";
                    BuilderFileEmit2[BuilderFileEmit2["Js"] = 1] = "Js";
                    BuilderFileEmit2[BuilderFileEmit2["JsMap"] = 2] = "JsMap";
                    BuilderFileEmit2[BuilderFileEmit2["JsInlineMap"] = 4] = "JsInlineMap";
                    BuilderFileEmit2[BuilderFileEmit2["Dts"] = 8] = "Dts";
                    BuilderFileEmit2[BuilderFileEmit2["DtsMap"] = 16] = "DtsMap";
                    BuilderFileEmit2[BuilderFileEmit2["AllJs"] = 7] = "AllJs";
                    BuilderFileEmit2[BuilderFileEmit2["AllDts"] = 24] = "AllDts";
                    BuilderFileEmit2[BuilderFileEmit2["All"] = 31] = "All";
                    return BuilderFileEmit2;
                })(BuilderFileEmit || {});
                BuilderProgramKind = /* @__PURE__ */ ((BuilderProgramKind2) => {
                    BuilderProgramKind2[BuilderProgramKind2["SemanticDiagnosticsBuilderProgram"] = 0] = "SemanticDiagnosticsBuilderProgram";
                    BuilderProgramKind2[BuilderProgramKind2["EmitAndSemanticDiagnosticsBuilderProgram"] = 1] = "EmitAndSemanticDiagnosticsBuilderProgram";
                    return BuilderProgramKind2;
                })(BuilderProgramKind || {});
            }
        });
        // src/compiler/builderPublic.ts
        function createSemanticDiagnosticsBuilderProgram(newProgramOrRootNames, hostOrOptions, oldProgramOrHost, configFileParsingDiagnosticsOrOldProgram, configFileParsingDiagnostics, projectReferences) {
            return createBuilderProgram(0 /* SemanticDiagnosticsBuilderProgram */, getBuilderCreationParameters(newProgramOrRootNames, hostOrOptions, oldProgramOrHost, configFileParsingDiagnosticsOrOldProgram, configFileParsingDiagnostics, projectReferences));
        }
        function createEmitAndSemanticDiagnosticsBuilderProgram(newProgramOrRootNames, hostOrOptions, oldProgramOrHost, configFileParsingDiagnosticsOrOldProgram, configFileParsingDiagnostics, projectReferences) {
            return createBuilderProgram(1 /* EmitAndSemanticDiagnosticsBuilderProgram */, getBuilderCreationParameters(newProgramOrRootNames, hostOrOptions, oldProgramOrHost, configFileParsingDiagnosticsOrOldProgram, configFileParsingDiagnostics, projectReferences));
        }
        function createAbstractBuilder(newProgramOrRootNames, hostOrOptions, oldProgramOrHost, configFileParsingDiagnosticsOrOldProgram, configFileParsingDiagnostics, projectReferences) {
            const { newProgram, configFileParsingDiagnostics: newConfigFileParsingDiagnostics } = getBuilderCreationParameters(newProgramOrRootNames, hostOrOptions, oldProgramOrHost, configFileParsingDiagnosticsOrOldProgram, configFileParsingDiagnostics, projectReferences);
            return createRedirectedBuilderProgram(() => ({ program: newProgram, compilerOptions: newProgram.getCompilerOptions() }), newConfigFileParsingDiagnostics);
        }
        var init_builderPublic = __esm({
            "src/compiler/builderPublic.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/resolutionCache.ts
        function removeIgnoredPath(path) {
            if (endsWith(path, "/node_modules/.staging")) {
                return removeSuffix(path, "/.staging");
            }
            return some(ignoredPaths, (searchPath) => path.includes(searchPath)) ? void 0 : path;
        }
        function perceivedOsRootLengthForWatching(pathComponents2, length2) {
            if (length2 <= 1)
                return 1;
            let indexAfterOsRoot = 1;
            let isDosStyle = pathComponents2[0].search(/[a-zA-Z]:/) === 0;
            if (pathComponents2[0] !== directorySeparator && !isDosStyle && // Non dos style paths
                pathComponents2[1].search(/[a-zA-Z]\$$/) === 0) {
                if (length2 === 2)
                    return 2;
                indexAfterOsRoot = 2;
                isDosStyle = true;
            }
            if (isDosStyle && !pathComponents2[indexAfterOsRoot].match(/^users$/i)) {
                return indexAfterOsRoot;
            }
            if (pathComponents2[indexAfterOsRoot].match(/^workspaces$/i)) {
                return indexAfterOsRoot + 1;
            }
            return indexAfterOsRoot + 2;
        }
        function canWatchDirectoryOrFile(pathComponents2, length2) {
            if (length2 === void 0)
                length2 = pathComponents2.length;
            if (length2 <= 2)
                return false;
            const perceivedOsRootLength = perceivedOsRootLengthForWatching(pathComponents2, length2);
            return length2 > perceivedOsRootLength + 1;
        }
        function canWatchAtTypes(atTypes) {
            return canWatchAffectedPackageJsonOrNodeModulesOfAtTypes(getDirectoryPath(atTypes));
        }
        function isInDirectoryPath(dirComponents, fileOrDirComponents) {
            if (fileOrDirComponents.length < fileOrDirComponents.length)
                return false;
            for (let i = 0; i < dirComponents.length; i++) {
                if (fileOrDirComponents[i] !== dirComponents[i])
                    return false;
            }
            return true;
        }
        function canWatchAffectedPackageJsonOrNodeModulesOfAtTypes(fileOrDirPath) {
            return canWatchDirectoryOrFile(getPathComponents(fileOrDirPath));
        }
        function canWatchAffectingLocation(filePath) {
            return canWatchAffectedPackageJsonOrNodeModulesOfAtTypes(filePath);
        }
        function getDirectoryToWatchFailedLookupLocation(failedLookupLocation, failedLookupLocationPath, rootDir, rootPath, rootPathComponents, getCurrentDirectory) {
            const failedLookupPathComponents = getPathComponents(failedLookupLocationPath);
            failedLookupLocation = isRootedDiskPath(failedLookupLocation) ? normalizePath(failedLookupLocation) : getNormalizedAbsolutePath(failedLookupLocation, getCurrentDirectory());
            const failedLookupComponents = getPathComponents(failedLookupLocation);
            const perceivedOsRootLength = perceivedOsRootLengthForWatching(failedLookupPathComponents, failedLookupPathComponents.length);
            if (failedLookupPathComponents.length <= perceivedOsRootLength + 1)
                return void 0;
            const nodeModulesIndex = failedLookupPathComponents.indexOf("node_modules");
            if (nodeModulesIndex !== -1 && nodeModulesIndex + 1 <= perceivedOsRootLength + 1)
                return void 0;
            if (isInDirectoryPath(rootPathComponents, failedLookupPathComponents)) {
                if (failedLookupPathComponents.length > rootPathComponents.length + 1) {
                    return getDirectoryOfFailedLookupWatch(failedLookupComponents, failedLookupPathComponents, Math.max(rootPathComponents.length + 1, perceivedOsRootLength + 1));
                }
                else {
                    return {
                        dir: rootDir,
                        dirPath: rootPath,
                        nonRecursive: true
                    };
                }
            }
            return getDirectoryToWatchFromFailedLookupLocationDirectory(failedLookupComponents, failedLookupPathComponents, failedLookupPathComponents.length - 1, perceivedOsRootLength, nodeModulesIndex, rootPathComponents);
        }
        function getDirectoryToWatchFromFailedLookupLocationDirectory(dirComponents, dirPathComponents, dirPathComponentsLength, perceivedOsRootLength, nodeModulesIndex, rootPathComponents) {
            if (nodeModulesIndex !== -1) {
                return getDirectoryOfFailedLookupWatch(dirComponents, dirPathComponents, nodeModulesIndex + 1);
            }
            let nonRecursive = true;
            let length2 = dirPathComponentsLength;
            for (let i = 0; i < dirPathComponentsLength; i++) {
                if (dirPathComponents[i] !== rootPathComponents[i]) {
                    nonRecursive = false;
                    length2 = Math.max(i + 1, perceivedOsRootLength + 1);
                    break;
                }
            }
            return getDirectoryOfFailedLookupWatch(dirComponents, dirPathComponents, length2, nonRecursive);
        }
        function getDirectoryOfFailedLookupWatch(dirComponents, dirPathComponents, length2, nonRecursive) {
            return {
                dir: getPathFromPathComponents(dirComponents, length2),
                dirPath: getPathFromPathComponents(dirPathComponents, length2),
                nonRecursive
            };
        }
        function getDirectoryToWatchFailedLookupLocationFromTypeRoot(typeRoot, typeRootPath, rootPath, rootPathComponents, getCurrentDirectory, filterCustomPath) {
            const typeRootPathComponents = getPathComponents(typeRootPath);
            if (isInDirectoryPath(rootPathComponents, typeRootPathComponents)) {
                return rootPath;
            }
            typeRoot = isRootedDiskPath(typeRoot) ? normalizePath(typeRoot) : getNormalizedAbsolutePath(typeRoot, getCurrentDirectory());
            const toWatch = getDirectoryToWatchFromFailedLookupLocationDirectory(getPathComponents(typeRoot), typeRootPathComponents, typeRootPathComponents.length, perceivedOsRootLengthForWatching(typeRootPathComponents, typeRootPathComponents.length), typeRootPathComponents.indexOf("node_modules"), rootPathComponents);
            return toWatch && filterCustomPath(toWatch.dirPath) ? toWatch.dirPath : void 0;
        }
        function getRootDirectoryOfResolutionCache(rootDirForResolution, getCurrentDirectory) {
            const normalized = getNormalizedAbsolutePath(rootDirForResolution, getCurrentDirectory());
            return !isDiskPathRoot(normalized) ? removeTrailingDirectorySeparator(normalized) : normalized;
        }
        function getRootPathSplitLength(rootPath) {
            return rootPath.split(directorySeparator).length - (hasTrailingDirectorySeparator(rootPath) ? 1 : 0);
        }
        function getModuleResolutionHost(resolutionHost) {
            var _a;
            return ((_a = resolutionHost.getCompilerHost) == null ? void 0 : _a.call(resolutionHost)) || resolutionHost;
        }
        function createModuleResolutionLoaderUsingGlobalCache(containingFile, redirectedReference, options, resolutionHost, moduleResolutionCache) {
            return {
                nameAndMode: moduleResolutionNameAndModeGetter,
                resolve: (moduleName, resoluionMode) => resolveModuleNameUsingGlobalCache(resolutionHost, moduleResolutionCache, moduleName, containingFile, options, redirectedReference, resoluionMode)
            };
        }
        function resolveModuleNameUsingGlobalCache(resolutionHost, moduleResolutionCache, moduleName, containingFile, compilerOptions, redirectedReference, mode) {
            const host = getModuleResolutionHost(resolutionHost);
            const primaryResult = resolveModuleName(moduleName, containingFile, compilerOptions, host, moduleResolutionCache, redirectedReference, mode);
            if (!resolutionHost.getGlobalCache) {
                return primaryResult;
            }
            const globalCache = resolutionHost.getGlobalCache();
            if (globalCache !== void 0 && !isExternalModuleNameRelative(moduleName) && !(primaryResult.resolvedModule && extensionIsTS(primaryResult.resolvedModule.extension))) {
                const { resolvedModule, failedLookupLocations, affectingLocations, resolutionDiagnostics } = loadModuleFromGlobalCache(Debug.checkDefined(resolutionHost.globalCacheResolutionModuleName)(moduleName), resolutionHost.projectName, compilerOptions, host, globalCache, moduleResolutionCache);
                if (resolvedModule) {
                    primaryResult.resolvedModule = resolvedModule;
                    primaryResult.failedLookupLocations = updateResolutionField(primaryResult.failedLookupLocations, failedLookupLocations);
                    primaryResult.affectingLocations = updateResolutionField(primaryResult.affectingLocations, affectingLocations);
                    primaryResult.resolutionDiagnostics = updateResolutionField(primaryResult.resolutionDiagnostics, resolutionDiagnostics);
                    return primaryResult;
                }
            }
            return primaryResult;
        }
        function createResolutionCache(resolutionHost, rootDirForResolution, logChangesWhenResolvingModule) {
            let filesWithChangedSetOfUnresolvedImports;
            let filesWithInvalidatedResolutions;
            let filesWithInvalidatedNonRelativeUnresolvedImports;
            const nonRelativeExternalModuleResolutions = createMultiMap();
            const resolutionsWithFailedLookups = /* @__PURE__ */ new Set();
            const resolutionsWithOnlyAffectingLocations = /* @__PURE__ */ new Set();
            const resolvedFileToResolution = /* @__PURE__ */ new Map();
            const impliedFormatPackageJsons = /* @__PURE__ */ new Map();
            let hasChangedAutomaticTypeDirectiveNames = false;
            let affectingPathChecksForFile;
            let affectingPathChecks;
            let failedLookupChecks;
            let startsWithPathChecks;
            let isInDirectoryChecks;
            let allModuleAndTypeResolutionsAreInvalidated = false;
            const getCurrentDirectory = memoize(() => resolutionHost.getCurrentDirectory());
            const cachedDirectoryStructureHost = resolutionHost.getCachedDirectoryStructureHost();
            const resolvedModuleNames = /* @__PURE__ */ new Map();
            const moduleResolutionCache = createModuleResolutionCache(getCurrentDirectory(), resolutionHost.getCanonicalFileName, resolutionHost.getCompilationSettings());
            const resolvedTypeReferenceDirectives = /* @__PURE__ */ new Map();
            const typeReferenceDirectiveResolutionCache = createTypeReferenceDirectiveResolutionCache(getCurrentDirectory(), resolutionHost.getCanonicalFileName, resolutionHost.getCompilationSettings(), moduleResolutionCache.getPackageJsonInfoCache(), moduleResolutionCache.optionsToRedirectsKey);
            const resolvedLibraries = /* @__PURE__ */ new Map();
            const libraryResolutionCache = createModuleResolutionCache(getCurrentDirectory(), resolutionHost.getCanonicalFileName, getOptionsForLibraryResolution(resolutionHost.getCompilationSettings()), moduleResolutionCache.getPackageJsonInfoCache());
            const directoryWatchesOfFailedLookups = /* @__PURE__ */ new Map();
            const fileWatchesOfAffectingLocations = /* @__PURE__ */ new Map();
            const rootDir = getRootDirectoryOfResolutionCache(rootDirForResolution, getCurrentDirectory);
            const rootPath = resolutionHost.toPath(rootDir);
            const rootPathComponents = getPathComponents(rootPath);
            const typeRootsWatches = /* @__PURE__ */ new Map();
            return {
                rootDirForResolution,
                resolvedModuleNames,
                resolvedTypeReferenceDirectives,
                resolvedLibraries,
                resolvedFileToResolution,
                resolutionsWithFailedLookups,
                resolutionsWithOnlyAffectingLocations,
                directoryWatchesOfFailedLookups,
                fileWatchesOfAffectingLocations,
                watchFailedLookupLocationsOfExternalModuleResolutions,
                getModuleResolutionCache: () => moduleResolutionCache,
                startRecordingFilesWithChangedResolutions,
                finishRecordingFilesWithChangedResolutions,
                // perDirectoryResolvedModuleNames and perDirectoryResolvedTypeReferenceDirectives could be non empty if there was exception during program update
                // (between startCachingPerDirectoryResolution and finishCachingPerDirectoryResolution)
                startCachingPerDirectoryResolution,
                finishCachingPerDirectoryResolution,
                resolveModuleNameLiterals,
                resolveTypeReferenceDirectiveReferences,
                resolveLibrary: resolveLibrary2,
                resolveSingleModuleNameWithoutWatching,
                removeResolutionsFromProjectReferenceRedirects,
                removeResolutionsOfFile,
                hasChangedAutomaticTypeDirectiveNames: () => hasChangedAutomaticTypeDirectiveNames,
                invalidateResolutionOfFile,
                invalidateResolutionsOfFailedLookupLocations,
                setFilesWithInvalidatedNonRelativeUnresolvedImports,
                createHasInvalidatedResolutions,
                isFileWithInvalidatedNonRelativeUnresolvedImports,
                updateTypeRootsWatch,
                closeTypeRootsWatch,
                clear: clear2,
                onChangesAffectModuleResolution
            };
            function getResolvedModule(resolution) {
                return resolution.resolvedModule;
            }
            function getResolvedTypeReferenceDirective(resolution) {
                return resolution.resolvedTypeReferenceDirective;
            }
            function clear2() {
                clearMap(directoryWatchesOfFailedLookups, closeFileWatcherOf);
                clearMap(fileWatchesOfAffectingLocations, closeFileWatcherOf);
                nonRelativeExternalModuleResolutions.clear();
                closeTypeRootsWatch();
                resolvedModuleNames.clear();
                resolvedTypeReferenceDirectives.clear();
                resolvedFileToResolution.clear();
                resolutionsWithFailedLookups.clear();
                resolutionsWithOnlyAffectingLocations.clear();
                failedLookupChecks = void 0;
                startsWithPathChecks = void 0;
                isInDirectoryChecks = void 0;
                affectingPathChecks = void 0;
                affectingPathChecksForFile = void 0;
                allModuleAndTypeResolutionsAreInvalidated = false;
                moduleResolutionCache.clear();
                typeReferenceDirectiveResolutionCache.clear();
                moduleResolutionCache.update(resolutionHost.getCompilationSettings());
                typeReferenceDirectiveResolutionCache.update(resolutionHost.getCompilationSettings());
                libraryResolutionCache.clear();
                impliedFormatPackageJsons.clear();
                resolvedLibraries.clear();
                hasChangedAutomaticTypeDirectiveNames = false;
            }
            function onChangesAffectModuleResolution() {
                allModuleAndTypeResolutionsAreInvalidated = true;
                moduleResolutionCache.clearAllExceptPackageJsonInfoCache();
                typeReferenceDirectiveResolutionCache.clearAllExceptPackageJsonInfoCache();
                moduleResolutionCache.update(resolutionHost.getCompilationSettings());
                typeReferenceDirectiveResolutionCache.update(resolutionHost.getCompilationSettings());
            }
            function startRecordingFilesWithChangedResolutions() {
                filesWithChangedSetOfUnresolvedImports = [];
            }
            function finishRecordingFilesWithChangedResolutions() {
                const collected = filesWithChangedSetOfUnresolvedImports;
                filesWithChangedSetOfUnresolvedImports = void 0;
                return collected;
            }
            function isFileWithInvalidatedNonRelativeUnresolvedImports(path) {
                if (!filesWithInvalidatedNonRelativeUnresolvedImports) {
                    return false;
                }
                const value = filesWithInvalidatedNonRelativeUnresolvedImports.get(path);
                return !!value && !!value.length;
            }
            function createHasInvalidatedResolutions(customHasInvalidatedResolutions, customHasInvalidatedLibResolutions) {
                invalidateResolutionsOfFailedLookupLocations();
                const collected = filesWithInvalidatedResolutions;
                filesWithInvalidatedResolutions = void 0;
                return {
                    hasInvalidatedResolutions: (path) => customHasInvalidatedResolutions(path) || allModuleAndTypeResolutionsAreInvalidated || !!(collected == null ? void 0 : collected.has(path)) || isFileWithInvalidatedNonRelativeUnresolvedImports(path),
                    hasInvalidatedLibResolutions: (libFileName) => {
                        var _a;
                        return customHasInvalidatedLibResolutions(libFileName) || !!((_a = resolvedLibraries == null ? void 0 : resolvedLibraries.get(libFileName)) == null ? void 0 : _a.isInvalidated);
                    }
                };
            }
            function startCachingPerDirectoryResolution() {
                moduleResolutionCache.isReadonly = void 0;
                typeReferenceDirectiveResolutionCache.isReadonly = void 0;
                libraryResolutionCache.isReadonly = void 0;
                moduleResolutionCache.getPackageJsonInfoCache().isReadonly = void 0;
                moduleResolutionCache.clearAllExceptPackageJsonInfoCache();
                typeReferenceDirectiveResolutionCache.clearAllExceptPackageJsonInfoCache();
                libraryResolutionCache.clearAllExceptPackageJsonInfoCache();
                nonRelativeExternalModuleResolutions.forEach(watchFailedLookupLocationOfNonRelativeModuleResolutions);
                nonRelativeExternalModuleResolutions.clear();
            }
            function cleanupLibResolutionWatching(newProgram) {
                resolvedLibraries.forEach((resolution, libFileName) => {
                    var _a;
                    if (!((_a = newProgram == null ? void 0 : newProgram.resolvedLibReferences) == null ? void 0 : _a.has(libFileName))) {
                        stopWatchFailedLookupLocationOfResolution(resolution, resolutionHost.toPath(getInferredLibraryNameResolveFrom(resolutionHost.getCompilationSettings(), getCurrentDirectory(), libFileName)), getResolvedModule);
                        resolvedLibraries.delete(libFileName);
                    }
                });
            }
            function finishCachingPerDirectoryResolution(newProgram, oldProgram) {
                filesWithInvalidatedNonRelativeUnresolvedImports = void 0;
                allModuleAndTypeResolutionsAreInvalidated = false;
                nonRelativeExternalModuleResolutions.forEach(watchFailedLookupLocationOfNonRelativeModuleResolutions);
                nonRelativeExternalModuleResolutions.clear();
                if (newProgram !== oldProgram) {
                    cleanupLibResolutionWatching(newProgram);
                    newProgram == null ? void 0 : newProgram.getSourceFiles().forEach((newFile) => {
                        var _a;
                        const expected = isExternalOrCommonJsModule(newFile) ? ((_a = newFile.packageJsonLocations) == null ? void 0 : _a.length) ?? 0 : 0;
                        const existing = impliedFormatPackageJsons.get(newFile.path) ?? emptyArray;
                        for (let i = existing.length; i < expected; i++) {
                            createFileWatcherOfAffectingLocation(newFile.packageJsonLocations[i], 
                            /*forResolution*/
                            false);
                        }
                        if (existing.length > expected) {
                            for (let i = expected; i < existing.length; i++) {
                                fileWatchesOfAffectingLocations.get(existing[i]).files--;
                            }
                        }
                        if (expected)
                            impliedFormatPackageJsons.set(newFile.path, newFile.packageJsonLocations);
                        else
                            impliedFormatPackageJsons.delete(newFile.path);
                    });
                    impliedFormatPackageJsons.forEach((existing, path) => {
                        if (!(newProgram == null ? void 0 : newProgram.getSourceFileByPath(path))) {
                            existing.forEach((location) => fileWatchesOfAffectingLocations.get(location).files--);
                            impliedFormatPackageJsons.delete(path);
                        }
                    });
                }
                directoryWatchesOfFailedLookups.forEach(closeDirectoryWatchesOfFailedLookup);
                fileWatchesOfAffectingLocations.forEach(closeFileWatcherOfAffectingLocation);
                hasChangedAutomaticTypeDirectiveNames = false;
                moduleResolutionCache.isReadonly = true;
                typeReferenceDirectiveResolutionCache.isReadonly = true;
                libraryResolutionCache.isReadonly = true;
                moduleResolutionCache.getPackageJsonInfoCache().isReadonly = true;
            }
            function closeDirectoryWatchesOfFailedLookup(watcher, path) {
                if (watcher.refCount === 0) {
                    directoryWatchesOfFailedLookups.delete(path);
                    watcher.watcher.close();
                }
            }
            function closeFileWatcherOfAffectingLocation(watcher, path) {
                var _a;
                if (watcher.files === 0 && watcher.resolutions === 0 && !((_a = watcher.symlinks) == null ? void 0 : _a.size)) {
                    fileWatchesOfAffectingLocations.delete(path);
                    watcher.watcher.close();
                }
            }
            function resolveNamesWithLocalCache({ entries, containingFile, containingSourceFile, redirectedReference, options, perFileCache, reusedNames, loader, getResolutionWithResolvedFileName, deferWatchingNonRelativeResolution, shouldRetryResolution, logChanges }) {
                const path = resolutionHost.toPath(containingFile);
                const resolutionsInFile = perFileCache.get(path) || perFileCache.set(path, createModeAwareCache()).get(path);
                const resolvedModules = [];
                const hasInvalidatedNonRelativeUnresolvedImport = logChanges && isFileWithInvalidatedNonRelativeUnresolvedImports(path);
                const program = resolutionHost.getCurrentProgram();
                const oldRedirect = program && program.getResolvedProjectReferenceToRedirect(containingFile);
                const unmatchedRedirects = oldRedirect ? !redirectedReference || redirectedReference.sourceFile.path !== oldRedirect.sourceFile.path : !!redirectedReference;
                const seenNamesInFile = createModeAwareCache();
                for (const entry of entries) {
                    const name = loader.nameAndMode.getName(entry);
                    const mode = loader.nameAndMode.getMode(entry, containingSourceFile, (redirectedReference == null ? void 0 : redirectedReference.commandLine.options) || options);
                    let resolution = resolutionsInFile.get(name, mode);
                    if (!seenNamesInFile.has(name, mode) && (allModuleAndTypeResolutionsAreInvalidated || unmatchedRedirects || !resolution || resolution.isInvalidated || // If the name is unresolved import that was invalidated, recalculate
                        hasInvalidatedNonRelativeUnresolvedImport && !isExternalModuleNameRelative(name) && shouldRetryResolution(resolution))) {
                        const existingResolution = resolution;
                        resolution = loader.resolve(name, mode);
                        if (resolutionHost.onDiscoveredSymlink && resolutionIsSymlink(resolution)) {
                            resolutionHost.onDiscoveredSymlink();
                        }
                        resolutionsInFile.set(name, mode, resolution);
                        if (resolution !== existingResolution) {
                            watchFailedLookupLocationsOfExternalModuleResolutions(name, resolution, path, getResolutionWithResolvedFileName, deferWatchingNonRelativeResolution);
                            if (existingResolution) {
                                stopWatchFailedLookupLocationOfResolution(existingResolution, path, getResolutionWithResolvedFileName);
                            }
                        }
                        if (logChanges && filesWithChangedSetOfUnresolvedImports && !resolutionIsEqualTo(existingResolution, resolution)) {
                            filesWithChangedSetOfUnresolvedImports.push(path);
                            logChanges = false;
                        }
                    }
                    else {
                        const host = getModuleResolutionHost(resolutionHost);
                        if (isTraceEnabled(options, host) && !seenNamesInFile.has(name, mode)) {
                            const resolved = getResolutionWithResolvedFileName(resolution);
                            trace(host, perFileCache === resolvedModuleNames ? (resolved == null ? void 0 : resolved.resolvedFileName) ? resolved.packageId ? Diagnostics.Reusing_resolution_of_module_0_from_1_of_old_program_it_was_successfully_resolved_to_2_with_Package_ID_3 : Diagnostics.Reusing_resolution_of_module_0_from_1_of_old_program_it_was_successfully_resolved_to_2 : Diagnostics.Reusing_resolution_of_module_0_from_1_of_old_program_it_was_not_resolved : (resolved == null ? void 0 : resolved.resolvedFileName) ? resolved.packageId ? Diagnostics.Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_successfully_resolved_to_2_with_Package_ID_3 : Diagnostics.Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_successfully_resolved_to_2 : Diagnostics.Reusing_resolution_of_type_reference_directive_0_from_1_of_old_program_it_was_not_resolved, name, containingFile, resolved == null ? void 0 : resolved.resolvedFileName, (resolved == null ? void 0 : resolved.packageId) && packageIdToString(resolved.packageId));
                        }
                    }
                    Debug.assert(resolution !== void 0 && !resolution.isInvalidated);
                    seenNamesInFile.set(name, mode, true);
                    resolvedModules.push(resolution);
                }
                reusedNames == null ? void 0 : reusedNames.forEach((entry) => seenNamesInFile.set(loader.nameAndMode.getName(entry), loader.nameAndMode.getMode(entry, containingSourceFile, (redirectedReference == null ? void 0 : redirectedReference.commandLine.options) || options), true));
                if (resolutionsInFile.size() !== seenNamesInFile.size()) {
                    resolutionsInFile.forEach((resolution, name, mode) => {
                        if (!seenNamesInFile.has(name, mode)) {
                            stopWatchFailedLookupLocationOfResolution(resolution, path, getResolutionWithResolvedFileName);
                            resolutionsInFile.delete(name, mode);
                        }
                    });
                }
                return resolvedModules;
                function resolutionIsEqualTo(oldResolution, newResolution) {
                    if (oldResolution === newResolution) {
                        return true;
                    }
                    if (!oldResolution || !newResolution) {
                        return false;
                    }
                    const oldResult = getResolutionWithResolvedFileName(oldResolution);
                    const newResult = getResolutionWithResolvedFileName(newResolution);
                    if (oldResult === newResult) {
                        return true;
                    }
                    if (!oldResult || !newResult) {
                        return false;
                    }
                    return oldResult.resolvedFileName === newResult.resolvedFileName;
                }
            }
            function resolveTypeReferenceDirectiveReferences(typeDirectiveReferences, containingFile, redirectedReference, options, containingSourceFile, reusedNames) {
                return resolveNamesWithLocalCache({
                    entries: typeDirectiveReferences,
                    containingFile,
                    containingSourceFile,
                    redirectedReference,
                    options,
                    reusedNames,
                    perFileCache: resolvedTypeReferenceDirectives,
                    loader: createTypeReferenceResolutionLoader(containingFile, redirectedReference, options, getModuleResolutionHost(resolutionHost), typeReferenceDirectiveResolutionCache),
                    getResolutionWithResolvedFileName: getResolvedTypeReferenceDirective,
                    shouldRetryResolution: (resolution) => resolution.resolvedTypeReferenceDirective === void 0,
                    deferWatchingNonRelativeResolution: false
                });
            }
            function resolveModuleNameLiterals(moduleLiterals, containingFile, redirectedReference, options, containingSourceFile, reusedNames) {
                return resolveNamesWithLocalCache({
                    entries: moduleLiterals,
                    containingFile,
                    containingSourceFile,
                    redirectedReference,
                    options,
                    reusedNames,
                    perFileCache: resolvedModuleNames,
                    loader: createModuleResolutionLoaderUsingGlobalCache(containingFile, redirectedReference, options, resolutionHost, moduleResolutionCache),
                    getResolutionWithResolvedFileName: getResolvedModule,
                    shouldRetryResolution: (resolution) => !resolution.resolvedModule || !resolutionExtensionIsTSOrJson(resolution.resolvedModule.extension),
                    logChanges: logChangesWhenResolvingModule,
                    deferWatchingNonRelativeResolution: true
                    // Defer non relative resolution watch because we could be using ambient modules
                });
            }
            function resolveLibrary2(libraryName, resolveFrom, options, libFileName) {
                const host = getModuleResolutionHost(resolutionHost);
                let resolution = resolvedLibraries == null ? void 0 : resolvedLibraries.get(libFileName);
                if (!resolution || resolution.isInvalidated) {
                    const existingResolution = resolution;
                    resolution = resolveLibrary(libraryName, resolveFrom, options, host, libraryResolutionCache);
                    const path = resolutionHost.toPath(resolveFrom);
                    watchFailedLookupLocationsOfExternalModuleResolutions(libraryName, resolution, path, getResolvedModule, 
                    /*deferWatchingNonRelativeResolution*/
                    false);
                    resolvedLibraries.set(libFileName, resolution);
                    if (existingResolution) {
                        stopWatchFailedLookupLocationOfResolution(existingResolution, path, getResolvedModule);
                    }
                }
                else {
                    if (isTraceEnabled(options, host)) {
                        const resolved = getResolvedModule(resolution);
                        trace(host, (resolved == null ? void 0 : resolved.resolvedFileName) ? resolved.packageId ? Diagnostics.Reusing_resolution_of_module_0_from_1_of_old_program_it_was_successfully_resolved_to_2_with_Package_ID_3 : Diagnostics.Reusing_resolution_of_module_0_from_1_of_old_program_it_was_successfully_resolved_to_2 : Diagnostics.Reusing_resolution_of_module_0_from_1_of_old_program_it_was_not_resolved, libraryName, resolveFrom, resolved == null ? void 0 : resolved.resolvedFileName, (resolved == null ? void 0 : resolved.packageId) && packageIdToString(resolved.packageId));
                    }
                }
                return resolution;
            }
            function resolveSingleModuleNameWithoutWatching(moduleName, containingFile) {
                var _a, _b;
                const path = resolutionHost.toPath(containingFile);
                const resolutionsInFile = resolvedModuleNames.get(path);
                const resolution = resolutionsInFile == null ? void 0 : resolutionsInFile.get(moduleName, 
                /*mode*/
                void 0);
                if (resolution && !resolution.isInvalidated)
                    return resolution;
                const data = (_a = resolutionHost.beforeResolveSingleModuleNameWithoutWatching) == null ? void 0 : _a.call(resolutionHost, moduleResolutionCache);
                const host = getModuleResolutionHost(resolutionHost);
                const result = resolveModuleName(moduleName, containingFile, resolutionHost.getCompilationSettings(), host, moduleResolutionCache);
                (_b = resolutionHost.afterResolveSingleModuleNameWithoutWatching) == null ? void 0 : _b.call(resolutionHost, moduleResolutionCache, moduleName, containingFile, result, data);
                return result;
            }
            function isNodeModulesAtTypesDirectory(dirPath) {
                return endsWith(dirPath, "/node_modules/@types");
            }
            function watchFailedLookupLocationsOfExternalModuleResolutions(name, resolution, filePath, getResolutionWithResolvedFileName, deferWatchingNonRelativeResolution) {
                var _a;
                if (resolution.refCount) {
                    resolution.refCount++;
                    Debug.assertIsDefined(resolution.files);
                }
                else {
                    resolution.refCount = 1;
                    Debug.assert(!((_a = resolution.files) == null ? void 0 : _a.size));
                    if (!deferWatchingNonRelativeResolution || isExternalModuleNameRelative(name)) {
                        watchFailedLookupLocationOfResolution(resolution);
                    }
                    else {
                        nonRelativeExternalModuleResolutions.add(name, resolution);
                    }
                    const resolved = getResolutionWithResolvedFileName(resolution);
                    if (resolved && resolved.resolvedFileName) {
                        const key = resolutionHost.toPath(resolved.resolvedFileName);
                        let resolutions = resolvedFileToResolution.get(key);
                        if (!resolutions)
                            resolvedFileToResolution.set(key, resolutions = /* @__PURE__ */ new Set());
                        resolutions.add(resolution);
                    }
                }
                (resolution.files ?? (resolution.files = /* @__PURE__ */ new Set())).add(filePath);
            }
            function watchFailedLookupLocation(failedLookupLocation, setAtRoot) {
                const failedLookupLocationPath = resolutionHost.toPath(failedLookupLocation);
                const toWatch = getDirectoryToWatchFailedLookupLocation(failedLookupLocation, failedLookupLocationPath, rootDir, rootPath, rootPathComponents, getCurrentDirectory);
                if (toWatch) {
                    const { dir, dirPath, nonRecursive } = toWatch;
                    if (dirPath === rootPath) {
                        Debug.assert(nonRecursive);
                        setAtRoot = true;
                    }
                    else {
                        setDirectoryWatcher(dir, dirPath, nonRecursive);
                    }
                }
                return setAtRoot;
            }
            function watchFailedLookupLocationOfResolution(resolution) {
                Debug.assert(!!resolution.refCount);
                const { failedLookupLocations, affectingLocations, alternateResult } = resolution;
                if (!(failedLookupLocations == null ? void 0 : failedLookupLocations.length) && !(affectingLocations == null ? void 0 : affectingLocations.length) && !alternateResult)
                    return;
                if ((failedLookupLocations == null ? void 0 : failedLookupLocations.length) || alternateResult)
                    resolutionsWithFailedLookups.add(resolution);
                let setAtRoot = false;
                if (failedLookupLocations) {
                    for (const failedLookupLocation of failedLookupLocations) {
                        setAtRoot = watchFailedLookupLocation(failedLookupLocation, setAtRoot);
                    }
                }
                if (alternateResult)
                    setAtRoot = watchFailedLookupLocation(alternateResult, setAtRoot);
                if (setAtRoot) {
                    setDirectoryWatcher(rootDir, rootPath, 
                    /*nonRecursive*/
                    true);
                }
                watchAffectingLocationsOfResolution(resolution, !(failedLookupLocations == null ? void 0 : failedLookupLocations.length) && !alternateResult);
            }
            function watchAffectingLocationsOfResolution(resolution, addToResolutionsWithOnlyAffectingLocations) {
                Debug.assert(!!resolution.refCount);
                const { affectingLocations } = resolution;
                if (!(affectingLocations == null ? void 0 : affectingLocations.length))
                    return;
                if (addToResolutionsWithOnlyAffectingLocations)
                    resolutionsWithOnlyAffectingLocations.add(resolution);
                for (const affectingLocation of affectingLocations) {
                    createFileWatcherOfAffectingLocation(affectingLocation, 
                    /*forResolution*/
                    true);
                }
            }
            function createFileWatcherOfAffectingLocation(affectingLocation, forResolution) {
                const fileWatcher = fileWatchesOfAffectingLocations.get(affectingLocation);
                if (fileWatcher) {
                    if (forResolution)
                        fileWatcher.resolutions++;
                    else
                        fileWatcher.files++;
                    return;
                }
                let locationToWatch = affectingLocation;
                let isSymlink = false;
                let symlinkWatcher;
                if (resolutionHost.realpath) {
                    locationToWatch = resolutionHost.realpath(affectingLocation);
                    if (affectingLocation !== locationToWatch) {
                        isSymlink = true;
                        symlinkWatcher = fileWatchesOfAffectingLocations.get(locationToWatch);
                    }
                }
                const resolutions = forResolution ? 1 : 0;
                const files = forResolution ? 0 : 1;
                if (!isSymlink || !symlinkWatcher) {
                    const watcher = {
                        watcher: canWatchAffectingLocation(resolutionHost.toPath(locationToWatch)) ? resolutionHost.watchAffectingFileLocation(locationToWatch, (fileName, eventKind) => {
                            cachedDirectoryStructureHost == null ? void 0 : cachedDirectoryStructureHost.addOrDeleteFile(fileName, resolutionHost.toPath(locationToWatch), eventKind);
                            invalidateAffectingFileWatcher(locationToWatch, moduleResolutionCache.getPackageJsonInfoCache().getInternalMap());
                            resolutionHost.scheduleInvalidateResolutionsOfFailedLookupLocations();
                        }) : noopFileWatcher,
                        resolutions: isSymlink ? 0 : resolutions,
                        files: isSymlink ? 0 : files,
                        symlinks: void 0
                    };
                    fileWatchesOfAffectingLocations.set(locationToWatch, watcher);
                    if (isSymlink)
                        symlinkWatcher = watcher;
                }
                if (isSymlink) {
                    Debug.assert(!!symlinkWatcher);
                    const watcher = {
                        watcher: {
                            close: () => {
                                var _a;
                                const symlinkWatcher2 = fileWatchesOfAffectingLocations.get(locationToWatch);
                                if (((_a = symlinkWatcher2 == null ? void 0 : symlinkWatcher2.symlinks) == null ? void 0 : _a.delete(affectingLocation)) && !symlinkWatcher2.symlinks.size && !symlinkWatcher2.resolutions && !symlinkWatcher2.files) {
                                    fileWatchesOfAffectingLocations.delete(locationToWatch);
                                    symlinkWatcher2.watcher.close();
                                }
                            }
                        },
                        resolutions,
                        files,
                        symlinks: void 0
                    };
                    fileWatchesOfAffectingLocations.set(affectingLocation, watcher);
                    (symlinkWatcher.symlinks ?? (symlinkWatcher.symlinks = /* @__PURE__ */ new Set())).add(affectingLocation);
                }
            }
            function invalidateAffectingFileWatcher(path, packageJsonMap) {
                var _a;
                const watcher = fileWatchesOfAffectingLocations.get(path);
                if (watcher == null ? void 0 : watcher.resolutions)
                    (affectingPathChecks ?? (affectingPathChecks = /* @__PURE__ */ new Set())).add(path);
                if (watcher == null ? void 0 : watcher.files)
                    (affectingPathChecksForFile ?? (affectingPathChecksForFile = /* @__PURE__ */ new Set())).add(path);
                (_a = watcher == null ? void 0 : watcher.symlinks) == null ? void 0 : _a.forEach((path2) => invalidateAffectingFileWatcher(path2, packageJsonMap));
                packageJsonMap == null ? void 0 : packageJsonMap.delete(resolutionHost.toPath(path));
            }
            function watchFailedLookupLocationOfNonRelativeModuleResolutions(resolutions, name) {
                const program = resolutionHost.getCurrentProgram();
                if (!program || !program.getTypeChecker().tryFindAmbientModuleWithoutAugmentations(name)) {
                    resolutions.forEach(watchFailedLookupLocationOfResolution);
                }
                else {
                    resolutions.forEach((resolution) => watchAffectingLocationsOfResolution(resolution, 
                    /*addToResolutionsWithOnlyAffectingLocations*/
                    true));
                }
            }
            function setDirectoryWatcher(dir, dirPath, nonRecursive) {
                const dirWatcher = directoryWatchesOfFailedLookups.get(dirPath);
                if (dirWatcher) {
                    Debug.assert(!!nonRecursive === !!dirWatcher.nonRecursive);
                    dirWatcher.refCount++;
                }
                else {
                    directoryWatchesOfFailedLookups.set(dirPath, { watcher: createDirectoryWatcher(dir, dirPath, nonRecursive), refCount: 1, nonRecursive });
                }
            }
            function stopWatchFailedLookupLocation(failedLookupLocation, removeAtRoot, syncDirWatcherRemove) {
                const failedLookupLocationPath = resolutionHost.toPath(failedLookupLocation);
                const toWatch = getDirectoryToWatchFailedLookupLocation(failedLookupLocation, failedLookupLocationPath, rootDir, rootPath, rootPathComponents, getCurrentDirectory);
                if (toWatch) {
                    const { dirPath } = toWatch;
                    if (dirPath === rootPath) {
                        removeAtRoot = true;
                    }
                    else {
                        removeDirectoryWatcher(dirPath, syncDirWatcherRemove);
                    }
                }
                return removeAtRoot;
            }
            function stopWatchFailedLookupLocationOfResolution(resolution, filePath, getResolutionWithResolvedFileName, syncDirWatcherRemove) {
                Debug.checkDefined(resolution.files).delete(filePath);
                resolution.refCount--;
                if (resolution.refCount) {
                    return;
                }
                const resolved = getResolutionWithResolvedFileName(resolution);
                if (resolved && resolved.resolvedFileName) {
                    const key = resolutionHost.toPath(resolved.resolvedFileName);
                    const resolutions = resolvedFileToResolution.get(key);
                    if ((resolutions == null ? void 0 : resolutions.delete(resolution)) && !resolutions.size)
                        resolvedFileToResolution.delete(key);
                }
                const { failedLookupLocations, affectingLocations, alternateResult } = resolution;
                if (resolutionsWithFailedLookups.delete(resolution)) {
                    let removeAtRoot = false;
                    if (failedLookupLocations) {
                        for (const failedLookupLocation of failedLookupLocations) {
                            removeAtRoot = stopWatchFailedLookupLocation(failedLookupLocation, removeAtRoot, syncDirWatcherRemove);
                        }
                    }
                    if (alternateResult)
                        removeAtRoot = stopWatchFailedLookupLocation(alternateResult, removeAtRoot, syncDirWatcherRemove);
                    if (removeAtRoot)
                        removeDirectoryWatcher(rootPath, syncDirWatcherRemove);
                }
                else if (affectingLocations == null ? void 0 : affectingLocations.length) {
                    resolutionsWithOnlyAffectingLocations.delete(resolution);
                }
                if (affectingLocations) {
                    for (const affectingLocation of affectingLocations) {
                        const watcher = fileWatchesOfAffectingLocations.get(affectingLocation);
                        watcher.resolutions--;
                        if (syncDirWatcherRemove)
                            closeFileWatcherOfAffectingLocation(watcher, affectingLocation);
                    }
                }
            }
            function removeDirectoryWatcher(dirPath, syncDirWatcherRemove) {
                const dirWatcher = directoryWatchesOfFailedLookups.get(dirPath);
                dirWatcher.refCount--;
                if (syncDirWatcherRemove)
                    closeDirectoryWatchesOfFailedLookup(dirWatcher, dirPath);
            }
            function createDirectoryWatcher(directory, dirPath, nonRecursive) {
                return resolutionHost.watchDirectoryOfFailedLookupLocation(directory, (fileOrDirectory) => {
                    const fileOrDirectoryPath = resolutionHost.toPath(fileOrDirectory);
                    if (cachedDirectoryStructureHost) {
                        cachedDirectoryStructureHost.addOrDeleteFileOrDirectory(fileOrDirectory, fileOrDirectoryPath);
                    }
                    scheduleInvalidateResolutionOfFailedLookupLocation(fileOrDirectoryPath, dirPath === fileOrDirectoryPath);
                }, nonRecursive ? 0 /* None */ : 1 /* Recursive */);
            }
            function removeResolutionsOfFileFromCache(cache, filePath, getResolutionWithResolvedFileName, syncDirWatcherRemove) {
                const resolutions = cache.get(filePath);
                if (resolutions) {
                    resolutions.forEach((resolution) => stopWatchFailedLookupLocationOfResolution(resolution, filePath, getResolutionWithResolvedFileName, syncDirWatcherRemove));
                    cache.delete(filePath);
                }
            }
            function removeResolutionsFromProjectReferenceRedirects(filePath) {
                if (!fileExtensionIs(filePath, ".json" /* Json */))
                    return;
                const program = resolutionHost.getCurrentProgram();
                if (!program)
                    return;
                const resolvedProjectReference = program.getResolvedProjectReferenceByPath(filePath);
                if (!resolvedProjectReference)
                    return;
                resolvedProjectReference.commandLine.fileNames.forEach((f) => removeResolutionsOfFile(resolutionHost.toPath(f)));
            }
            function removeResolutionsOfFile(filePath, syncDirWatcherRemove) {
                removeResolutionsOfFileFromCache(resolvedModuleNames, filePath, getResolvedModule, syncDirWatcherRemove);
                removeResolutionsOfFileFromCache(resolvedTypeReferenceDirectives, filePath, getResolvedTypeReferenceDirective, syncDirWatcherRemove);
            }
            function invalidateResolutions(resolutions, canInvalidate) {
                if (!resolutions)
                    return false;
                let invalidated = false;
                resolutions.forEach((resolution) => {
                    if (resolution.isInvalidated || !canInvalidate(resolution))
                        return;
                    resolution.isInvalidated = invalidated = true;
                    for (const containingFilePath of Debug.checkDefined(resolution.files)) {
                        (filesWithInvalidatedResolutions ?? (filesWithInvalidatedResolutions = /* @__PURE__ */ new Set())).add(containingFilePath);
                        hasChangedAutomaticTypeDirectiveNames = hasChangedAutomaticTypeDirectiveNames || endsWith(containingFilePath, inferredTypesContainingFile);
                    }
                });
                return invalidated;
            }
            function invalidateResolutionOfFile(filePath) {
                removeResolutionsOfFile(filePath);
                const prevHasChangedAutomaticTypeDirectiveNames = hasChangedAutomaticTypeDirectiveNames;
                if (invalidateResolutions(resolvedFileToResolution.get(filePath), returnTrue) && hasChangedAutomaticTypeDirectiveNames && !prevHasChangedAutomaticTypeDirectiveNames) {
                    resolutionHost.onChangedAutomaticTypeDirectiveNames();
                }
            }
            function setFilesWithInvalidatedNonRelativeUnresolvedImports(filesMap) {
                Debug.assert(filesWithInvalidatedNonRelativeUnresolvedImports === filesMap || filesWithInvalidatedNonRelativeUnresolvedImports === void 0);
                filesWithInvalidatedNonRelativeUnresolvedImports = filesMap;
            }
            function scheduleInvalidateResolutionOfFailedLookupLocation(fileOrDirectoryPath, isCreatingWatchedDirectory) {
                if (isCreatingWatchedDirectory) {
                    (isInDirectoryChecks || (isInDirectoryChecks = /* @__PURE__ */ new Set())).add(fileOrDirectoryPath);
                }
                else {
                    const updatedPath = removeIgnoredPath(fileOrDirectoryPath);
                    if (!updatedPath)
                        return false;
                    fileOrDirectoryPath = updatedPath;
                    if (resolutionHost.fileIsOpen(fileOrDirectoryPath)) {
                        return false;
                    }
                    const dirOfFileOrDirectory = getDirectoryPath(fileOrDirectoryPath);
                    if (isNodeModulesAtTypesDirectory(fileOrDirectoryPath) || isNodeModulesDirectory(fileOrDirectoryPath) || isNodeModulesAtTypesDirectory(dirOfFileOrDirectory) || isNodeModulesDirectory(dirOfFileOrDirectory)) {
                        (failedLookupChecks || (failedLookupChecks = /* @__PURE__ */ new Set())).add(fileOrDirectoryPath);
                        (startsWithPathChecks || (startsWithPathChecks = /* @__PURE__ */ new Set())).add(fileOrDirectoryPath);
                    }
                    else {
                        if (isEmittedFileOfProgram(resolutionHost.getCurrentProgram(), fileOrDirectoryPath)) {
                            return false;
                        }
                        if (fileExtensionIs(fileOrDirectoryPath, ".map")) {
                            return false;
                        }
                        (failedLookupChecks || (failedLookupChecks = /* @__PURE__ */ new Set())).add(fileOrDirectoryPath);
                        const packagePath = parseNodeModuleFromPath(fileOrDirectoryPath, 
                        /*isFolder*/
                        true);
                        if (packagePath)
                            (startsWithPathChecks || (startsWithPathChecks = /* @__PURE__ */ new Set())).add(packagePath);
                    }
                }
                resolutionHost.scheduleInvalidateResolutionsOfFailedLookupLocations();
            }
            function invalidatePackageJsonMap() {
                const packageJsonMap = moduleResolutionCache.getPackageJsonInfoCache().getInternalMap();
                if (packageJsonMap && (failedLookupChecks || startsWithPathChecks || isInDirectoryChecks)) {
                    packageJsonMap.forEach((_value, path) => isInvalidatedFailedLookup(path) ? packageJsonMap.delete(path) : void 0);
                }
            }
            function invalidateResolutionsOfFailedLookupLocations() {
                var _a;
                if (allModuleAndTypeResolutionsAreInvalidated) {
                    affectingPathChecksForFile = void 0;
                    invalidatePackageJsonMap();
                    if (failedLookupChecks || startsWithPathChecks || isInDirectoryChecks || affectingPathChecks) {
                        invalidateResolutions(resolvedLibraries, canInvalidateFailedLookupResolution);
                    }
                    failedLookupChecks = void 0;
                    startsWithPathChecks = void 0;
                    isInDirectoryChecks = void 0;
                    affectingPathChecks = void 0;
                    return true;
                }
                let invalidated = false;
                if (affectingPathChecksForFile) {
                    (_a = resolutionHost.getCurrentProgram()) == null ? void 0 : _a.getSourceFiles().forEach((f) => {
                        if (some(f.packageJsonLocations, (location) => affectingPathChecksForFile.has(location))) {
                            (filesWithInvalidatedResolutions ?? (filesWithInvalidatedResolutions = /* @__PURE__ */ new Set())).add(f.path);
                            invalidated = true;
                        }
                    });
                    affectingPathChecksForFile = void 0;
                }
                if (!failedLookupChecks && !startsWithPathChecks && !isInDirectoryChecks && !affectingPathChecks) {
                    return invalidated;
                }
                invalidated = invalidateResolutions(resolutionsWithFailedLookups, canInvalidateFailedLookupResolution) || invalidated;
                invalidatePackageJsonMap();
                failedLookupChecks = void 0;
                startsWithPathChecks = void 0;
                isInDirectoryChecks = void 0;
                invalidated = invalidateResolutions(resolutionsWithOnlyAffectingLocations, canInvalidatedFailedLookupResolutionWithAffectingLocation) || invalidated;
                affectingPathChecks = void 0;
                return invalidated;
            }
            function canInvalidateFailedLookupResolution(resolution) {
                var _a;
                if (canInvalidatedFailedLookupResolutionWithAffectingLocation(resolution))
                    return true;
                if (!failedLookupChecks && !startsWithPathChecks && !isInDirectoryChecks)
                    return false;
                return ((_a = resolution.failedLookupLocations) == null ? void 0 : _a.some((location) => isInvalidatedFailedLookup(resolutionHost.toPath(location)))) || !!resolution.alternateResult && isInvalidatedFailedLookup(resolutionHost.toPath(resolution.alternateResult));
            }
            function isInvalidatedFailedLookup(locationPath) {
                return (failedLookupChecks == null ? void 0 : failedLookupChecks.has(locationPath)) || firstDefinedIterator((startsWithPathChecks == null ? void 0 : startsWithPathChecks.keys()) || [], (fileOrDirectoryPath) => startsWith(locationPath, fileOrDirectoryPath) ? true : void 0) || firstDefinedIterator((isInDirectoryChecks == null ? void 0 : isInDirectoryChecks.keys()) || [], (dirPath) => locationPath.length > dirPath.length && startsWith(locationPath, dirPath) && (isDiskPathRoot(dirPath) || locationPath[dirPath.length] === directorySeparator) ? true : void 0);
            }
            function canInvalidatedFailedLookupResolutionWithAffectingLocation(resolution) {
                var _a;
                return !!affectingPathChecks && ((_a = resolution.affectingLocations) == null ? void 0 : _a.some((location) => affectingPathChecks.has(location)));
            }
            function closeTypeRootsWatch() {
                clearMap(typeRootsWatches, closeFileWatcher);
            }
            function createTypeRootsWatch(typeRoot) {
                return canWatchTypeRootPath(typeRoot) ? resolutionHost.watchTypeRootsDirectory(typeRoot, (fileOrDirectory) => {
                    const fileOrDirectoryPath = resolutionHost.toPath(fileOrDirectory);
                    if (cachedDirectoryStructureHost) {
                        cachedDirectoryStructureHost.addOrDeleteFileOrDirectory(fileOrDirectory, fileOrDirectoryPath);
                    }
                    hasChangedAutomaticTypeDirectiveNames = true;
                    resolutionHost.onChangedAutomaticTypeDirectiveNames();
                    const dirPath = getDirectoryToWatchFailedLookupLocationFromTypeRoot(typeRoot, resolutionHost.toPath(typeRoot), rootPath, rootPathComponents, getCurrentDirectory, (dirPath2) => directoryWatchesOfFailedLookups.has(dirPath2));
                    if (dirPath) {
                        scheduleInvalidateResolutionOfFailedLookupLocation(fileOrDirectoryPath, dirPath === fileOrDirectoryPath);
                    }
                }, 1 /* Recursive */) : noopFileWatcher;
            }
            function updateTypeRootsWatch() {
                const options = resolutionHost.getCompilationSettings();
                if (options.types) {
                    closeTypeRootsWatch();
                    return;
                }
                const typeRoots = getEffectiveTypeRoots(options, { getCurrentDirectory });
                if (typeRoots) {
                    mutateMap(typeRootsWatches, new Set(typeRoots), {
                        createNewValue: createTypeRootsWatch,
                        onDeleteValue: closeFileWatcher
                    });
                }
                else {
                    closeTypeRootsWatch();
                }
            }
            function canWatchTypeRootPath(typeRoot) {
                if (resolutionHost.getCompilationSettings().typeRoots)
                    return true;
                return canWatchAtTypes(resolutionHost.toPath(typeRoot));
            }
        }
        function resolutionIsSymlink(resolution) {
            var _a, _b;
            return !!(((_a = resolution.resolvedModule) == null ? void 0 : _a.originalPath) || ((_b = resolution.resolvedTypeReferenceDirective) == null ? void 0 : _b.originalPath));
        }
        var init_resolutionCache = __esm({
            "src/compiler/resolutionCache.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/watch.ts
        function createDiagnosticReporter(system, pretty) {
            const host = system === sys && sysFormatDiagnosticsHost ? sysFormatDiagnosticsHost : {
                getCurrentDirectory: () => system.getCurrentDirectory(),
                getNewLine: () => system.newLine,
                getCanonicalFileName: createGetCanonicalFileName(system.useCaseSensitiveFileNames)
            };
            if (!pretty) {
                return (diagnostic) => system.write(formatDiagnostic(diagnostic, host));
            }
            const diagnostics = new Array(1);
            return (diagnostic) => {
                diagnostics[0] = diagnostic;
                system.write(formatDiagnosticsWithColorAndContext(diagnostics, host) + host.getNewLine());
                diagnostics[0] = void 0;
            };
        }
        function clearScreenIfNotWatchingForFileChanges(system, diagnostic, options) {
            if (system.clearScreen && !options.preserveWatchOutput && !options.extendedDiagnostics && !options.diagnostics && contains(screenStartingMessageCodes, diagnostic.code)) {
                system.clearScreen();
                return true;
            }
            return false;
        }
        function getPlainDiagnosticFollowingNewLines(diagnostic, newLine) {
            return contains(screenStartingMessageCodes, diagnostic.code) ? newLine + newLine : newLine;
        }
        function getLocaleTimeString(system) {
            return !system.now ? ( /* @__PURE__ */new Date()).toLocaleTimeString() : (
            // On some systems / builds of Node, there's a non-breaking space between the time and AM/PM.
            // This branch is solely for testing, so just switch it to a normal space for baseline stability.
            // See:
            //     - https://github.com/nodejs/node/issues/45171
            //     - https://github.com/nodejs/node/issues/45753
            system.now().toLocaleTimeString("en-US", { timeZone: "UTC" }).replace("\u202F", " "));
        }
        function createWatchStatusReporter(system, pretty) {
            return pretty ? (diagnostic, newLine, options) => {
                clearScreenIfNotWatchingForFileChanges(system, diagnostic, options);
                let output = `[${formatColorAndReset(getLocaleTimeString(system), "\x1B[90m" /* Grey */)}] `;
                output += `${flattenDiagnosticMessageText(diagnostic.messageText, system.newLine)}${newLine + newLine}`;
                system.write(output);
            } : (diagnostic, newLine, options) => {
                let output = "";
                if (!clearScreenIfNotWatchingForFileChanges(system, diagnostic, options)) {
                    output += newLine;
                }
                output += `${getLocaleTimeString(system)} - `;
                output += `${flattenDiagnosticMessageText(diagnostic.messageText, system.newLine)}${getPlainDiagnosticFollowingNewLines(diagnostic, newLine)}`;
                system.write(output);
            };
        }
        function parseConfigFileWithSystem(configFileName, optionsToExtend, extendedConfigCache, watchOptionsToExtend, system, reportDiagnostic) {
            const host = system;
            host.onUnRecoverableConfigFileDiagnostic = (diagnostic) => reportUnrecoverableDiagnostic(system, reportDiagnostic, diagnostic);
            const result = getParsedCommandLineOfConfigFile(configFileName, optionsToExtend, host, extendedConfigCache, watchOptionsToExtend);
            host.onUnRecoverableConfigFileDiagnostic = void 0;
            return result;
        }
        function getErrorCountForSummary(diagnostics) {
            return countWhere(diagnostics, (diagnostic) => diagnostic.category === 1 /* Error */);
        }
        function getFilesInErrorForSummary(diagnostics) {
            const filesInError = filter(diagnostics, (diagnostic) => diagnostic.category === 1 /* Error */).map((errorDiagnostic) => {
                if (errorDiagnostic.file === void 0)
                    return;
                return `${errorDiagnostic.file.fileName}`;
            });
            return filesInError.map((fileName) => {
                if (fileName === void 0) {
                    return void 0;
                }
                const diagnosticForFileName = find(diagnostics, (diagnostic) => diagnostic.file !== void 0 && diagnostic.file.fileName === fileName);
                if (diagnosticForFileName !== void 0) {
                    const { line } = getLineAndCharacterOfPosition(diagnosticForFileName.file, diagnosticForFileName.start);
                    return {
                        fileName,
                        line: line + 1
                    };
                }
            });
        }
        function getWatchErrorSummaryDiagnosticMessage(errorCount) {
            return errorCount === 1 ? Diagnostics.Found_1_error_Watching_for_file_changes : Diagnostics.Found_0_errors_Watching_for_file_changes;
        }
        function prettyPathForFileError(error2, cwd) {
            const line = formatColorAndReset(":" + error2.line, "\x1B[90m" /* Grey */);
            if (pathIsAbsolute(error2.fileName) && pathIsAbsolute(cwd)) {
                return getRelativePathFromDirectory(cwd, error2.fileName, 
                /*ignoreCase*/
                false) + line;
            }
            return error2.fileName + line;
        }
        function getErrorSummaryText(errorCount, filesInError, newLine, host) {
            if (errorCount === 0)
                return "";
            const nonNilFiles = filesInError.filter((fileInError) => fileInError !== void 0);
            const distinctFileNamesWithLines = nonNilFiles.map((fileInError) => `${fileInError.fileName}:${fileInError.line}`).filter((value, index, self) => self.indexOf(value) === index);
            const firstFileReference = nonNilFiles[0] && prettyPathForFileError(nonNilFiles[0], host.getCurrentDirectory());
            let messageAndArgs;
            if (errorCount === 1) {
                messageAndArgs = filesInError[0] !== void 0 ? [Diagnostics.Found_1_error_in_0, firstFileReference] : [Diagnostics.Found_1_error];
            }
            else {
                messageAndArgs = distinctFileNamesWithLines.length === 0 ? [Diagnostics.Found_0_errors, errorCount] : distinctFileNamesWithLines.length === 1 ? [Diagnostics.Found_0_errors_in_the_same_file_starting_at_Colon_1, errorCount, firstFileReference] : [Diagnostics.Found_0_errors_in_1_files, errorCount, distinctFileNamesWithLines.length];
            }
            const d = createCompilerDiagnostic(...messageAndArgs);
            const suffix = distinctFileNamesWithLines.length > 1 ? createTabularErrorsDisplay(nonNilFiles, host) : "";
            return `${newLine}${flattenDiagnosticMessageText(d.messageText, newLine)}${newLine}${newLine}${suffix}`;
        }
        function createTabularErrorsDisplay(filesInError, host) {
            const distinctFiles = filesInError.filter((value, index, self) => index === self.findIndex((file) => (file == null ? void 0 : file.fileName) === (value == null ? void 0 : value.fileName)));
            if (distinctFiles.length === 0)
                return "";
            const numberLength = (num) => Math.log(num) * Math.LOG10E + 1;
            const fileToErrorCount = distinctFiles.map((file) => [file, countWhere(filesInError, (fileInError) => fileInError.fileName === file.fileName)]);
            const maxErrors = fileToErrorCount.reduce((acc, value) => Math.max(acc, value[1] || 0), 0);
            const headerRow = Diagnostics.Errors_Files.message;
            const leftColumnHeadingLength = headerRow.split(" ")[0].length;
            const leftPaddingGoal = Math.max(leftColumnHeadingLength, numberLength(maxErrors));
            const headerPadding = Math.max(numberLength(maxErrors) - leftColumnHeadingLength, 0);
            let tabularData = "";
            tabularData += " ".repeat(headerPadding) + headerRow + "\n";
            fileToErrorCount.forEach((row) => {
                const [file, errorCount] = row;
                const errorCountDigitsLength = Math.log(errorCount) * Math.LOG10E + 1 | 0;
                const leftPadding = errorCountDigitsLength < leftPaddingGoal ? " ".repeat(leftPaddingGoal - errorCountDigitsLength) : "";
                const fileRef = prettyPathForFileError(file, host.getCurrentDirectory());
                tabularData += `${leftPadding}${errorCount}  ${fileRef}
`;
            });
            return tabularData;
        }
        function isBuilderProgram2(program) {
            return !!program.getState;
        }
        function listFiles(program, write) {
            const options = program.getCompilerOptions();
            if (options.explainFiles) {
                explainFiles(isBuilderProgram2(program) ? program.getProgram() : program, write);
            }
            else if (options.listFiles || options.listFilesOnly) {
                forEach(program.getSourceFiles(), (file) => {
                    write(file.fileName);
                });
            }
        }
        function explainFiles(program, write) {
            var _a, _b;
            const reasons = program.getFileIncludeReasons();
            const relativeFileName = (fileName) => convertToRelativePath(fileName, program.getCurrentDirectory(), program.getCanonicalFileName);
            for (const file of program.getSourceFiles()) {
                write(`${toFileName(file, relativeFileName)}`);
                (_a = reasons.get(file.path)) == null ? void 0 : _a.forEach((reason) => write(`  ${fileIncludeReasonToDiagnostics(program, reason, relativeFileName).messageText}`));
                (_b = explainIfFileIsRedirectAndImpliedFormat(file, relativeFileName)) == null ? void 0 : _b.forEach((d) => write(`  ${d.messageText}`));
            }
        }
        function explainIfFileIsRedirectAndImpliedFormat(file, fileNameConvertor) {
            var _a;
            let result;
            if (file.path !== file.resolvedPath) {
                (result ?? (result = [])).push(chainDiagnosticMessages(
                /*details*/
                void 0, Diagnostics.File_is_output_of_project_reference_source_0, toFileName(file.originalFileName, fileNameConvertor)));
            }
            if (file.redirectInfo) {
                (result ?? (result = [])).push(chainDiagnosticMessages(
                /*details*/
                void 0, Diagnostics.File_redirects_to_file_0, toFileName(file.redirectInfo.redirectTarget, fileNameConvertor)));
            }
            if (isExternalOrCommonJsModule(file)) {
                switch (file.impliedNodeFormat) {
                    case 99 /* ESNext */:
                        if (file.packageJsonScope) {
                            (result ?? (result = [])).push(chainDiagnosticMessages(
                            /*details*/
                            void 0, Diagnostics.File_is_ECMAScript_module_because_0_has_field_type_with_value_module, toFileName(last(file.packageJsonLocations), fileNameConvertor)));
                        }
                        break;
                    case 1 /* CommonJS */:
                        if (file.packageJsonScope) {
                            (result ?? (result = [])).push(chainDiagnosticMessages(
                            /*details*/
                            void 0, file.packageJsonScope.contents.packageJsonContent.type ? Diagnostics.File_is_CommonJS_module_because_0_has_field_type_whose_value_is_not_module : Diagnostics.File_is_CommonJS_module_because_0_does_not_have_field_type, toFileName(last(file.packageJsonLocations), fileNameConvertor)));
                        }
                        else if ((_a = file.packageJsonLocations) == null ? void 0 : _a.length) {
                            (result ?? (result = [])).push(chainDiagnosticMessages(
                            /*details*/
                            void 0, Diagnostics.File_is_CommonJS_module_because_package_json_was_not_found));
                        }
                        break;
                }
            }
            return result;
        }
        function getMatchedFileSpec(program, fileName) {
            var _a;
            const configFile = program.getCompilerOptions().configFile;
            if (!((_a = configFile == null ? void 0 : configFile.configFileSpecs) == null ? void 0 : _a.validatedFilesSpec))
                return void 0;
            const filePath = program.getCanonicalFileName(fileName);
            const basePath = getDirectoryPath(getNormalizedAbsolutePath(configFile.fileName, program.getCurrentDirectory()));
            return find(configFile.configFileSpecs.validatedFilesSpec, (fileSpec) => program.getCanonicalFileName(getNormalizedAbsolutePath(fileSpec, basePath)) === filePath);
        }
        function getMatchedIncludeSpec(program, fileName) {
            var _a, _b;
            const configFile = program.getCompilerOptions().configFile;
            if (!((_a = configFile == null ? void 0 : configFile.configFileSpecs) == null ? void 0 : _a.validatedIncludeSpecs))
                return void 0;
            if (configFile.configFileSpecs.isDefaultIncludeSpec)
                return true;
            const isJsonFile = fileExtensionIs(fileName, ".json" /* Json */);
            const basePath = getDirectoryPath(getNormalizedAbsolutePath(configFile.fileName, program.getCurrentDirectory()));
            const useCaseSensitiveFileNames2 = program.useCaseSensitiveFileNames();
            return find((_b = configFile == null ? void 0 : configFile.configFileSpecs) == null ? void 0 : _b.validatedIncludeSpecs, (includeSpec) => {
                if (isJsonFile && !endsWith(includeSpec, ".json" /* Json */))
                    return false;
                const pattern = getPatternFromSpec(includeSpec, basePath, "files");
                return !!pattern && getRegexFromPattern(`(${pattern})$`, useCaseSensitiveFileNames2).test(fileName);
            });
        }
        function fileIncludeReasonToDiagnostics(program, reason, fileNameConvertor) {
            var _a, _b;
            const options = program.getCompilerOptions();
            if (isReferencedFile(reason)) {
                const referenceLocation = getReferencedFileLocation(program, reason);
                const referenceText = isReferenceFileLocation(referenceLocation) ? referenceLocation.file.text.substring(referenceLocation.pos, referenceLocation.end) : `"${referenceLocation.text}"`;
                let message;
                Debug.assert(isReferenceFileLocation(referenceLocation) || reason.kind === 3 /* Import */, "Only synthetic references are imports");
                switch (reason.kind) {
                    case 3 /* Import */:
                        if (isReferenceFileLocation(referenceLocation)) {
                            message = referenceLocation.packageId ? Diagnostics.Imported_via_0_from_file_1_with_packageId_2 : Diagnostics.Imported_via_0_from_file_1;
                        }
                        else if (referenceLocation.text === externalHelpersModuleNameText) {
                            message = referenceLocation.packageId ? Diagnostics.Imported_via_0_from_file_1_with_packageId_2_to_import_importHelpers_as_specified_in_compilerOptions : Diagnostics.Imported_via_0_from_file_1_to_import_importHelpers_as_specified_in_compilerOptions;
                        }
                        else {
                            message = referenceLocation.packageId ? Diagnostics.Imported_via_0_from_file_1_with_packageId_2_to_import_jsx_and_jsxs_factory_functions : Diagnostics.Imported_via_0_from_file_1_to_import_jsx_and_jsxs_factory_functions;
                        }
                        break;
                    case 4 /* ReferenceFile */:
                        Debug.assert(!referenceLocation.packageId);
                        message = Diagnostics.Referenced_via_0_from_file_1;
                        break;
                    case 5 /* TypeReferenceDirective */:
                        message = referenceLocation.packageId ? Diagnostics.Type_library_referenced_via_0_from_file_1_with_packageId_2 : Diagnostics.Type_library_referenced_via_0_from_file_1;
                        break;
                    case 7 /* LibReferenceDirective */:
                        Debug.assert(!referenceLocation.packageId);
                        message = Diagnostics.Library_referenced_via_0_from_file_1;
                        break;
                    default:
                        Debug.assertNever(reason);
                }
                return chainDiagnosticMessages(
                /*details*/
                void 0, message, referenceText, toFileName(referenceLocation.file, fileNameConvertor), referenceLocation.packageId && packageIdToString(referenceLocation.packageId));
            }
            switch (reason.kind) {
                case 0 /* RootFile */:
                    if (!((_a = options.configFile) == null ? void 0 : _a.configFileSpecs))
                        return chainDiagnosticMessages(
                        /*details*/
                        void 0, Diagnostics.Root_file_specified_for_compilation);
                    const fileName = getNormalizedAbsolutePath(program.getRootFileNames()[reason.index], program.getCurrentDirectory());
                    const matchedByFiles = getMatchedFileSpec(program, fileName);
                    if (matchedByFiles)
                        return chainDiagnosticMessages(
                        /*details*/
                        void 0, Diagnostics.Part_of_files_list_in_tsconfig_json);
                    const matchedByInclude = getMatchedIncludeSpec(program, fileName);
                    return isString(matchedByInclude) ? chainDiagnosticMessages(
                    /*details*/
                    void 0, Diagnostics.Matched_by_include_pattern_0_in_1, matchedByInclude, toFileName(options.configFile, fileNameConvertor)) : (
                    // Could be additional files specified as roots or matched by default include
                    chainDiagnosticMessages(
                    /*details*/
                    void 0, matchedByInclude ? Diagnostics.Matched_by_default_include_pattern_Asterisk_Asterisk_Slash_Asterisk : Diagnostics.Root_file_specified_for_compilation));
                case 1 /* SourceFromProjectReference */:
                case 2 /* OutputFromProjectReference */:
                    const isOutput = reason.kind === 2 /* OutputFromProjectReference */;
                    const referencedResolvedRef = Debug.checkDefined((_b = program.getResolvedProjectReferences()) == null ? void 0 : _b[reason.index]);
                    return chainDiagnosticMessages(
                    /*details*/
                    void 0, outFile(options) ? isOutput ? Diagnostics.Output_from_referenced_project_0_included_because_1_specified : Diagnostics.Source_from_referenced_project_0_included_because_1_specified : isOutput ? Diagnostics.Output_from_referenced_project_0_included_because_module_is_specified_as_none : Diagnostics.Source_from_referenced_project_0_included_because_module_is_specified_as_none, toFileName(referencedResolvedRef.sourceFile.fileName, fileNameConvertor), options.outFile ? "--outFile" : "--out");
                case 8 /* AutomaticTypeDirectiveFile */: {
                    const messageAndArgs = options.types ? reason.packageId ? [Diagnostics.Entry_point_of_type_library_0_specified_in_compilerOptions_with_packageId_1, reason.typeReference, packageIdToString(reason.packageId)] : [Diagnostics.Entry_point_of_type_library_0_specified_in_compilerOptions, reason.typeReference] : reason.packageId ? [Diagnostics.Entry_point_for_implicit_type_library_0_with_packageId_1, reason.typeReference, packageIdToString(reason.packageId)] : [Diagnostics.Entry_point_for_implicit_type_library_0, reason.typeReference];
                    return chainDiagnosticMessages(
                    /*details*/
                    void 0, ...messageAndArgs);
                }
                case 6 /* LibFile */: {
                    if (reason.index !== void 0)
                        return chainDiagnosticMessages(
                        /*details*/
                        void 0, Diagnostics.Library_0_specified_in_compilerOptions, options.lib[reason.index]);
                    const target = forEachEntry(targetOptionDeclaration.type, (value, key) => value === getEmitScriptTarget(options) ? key : void 0);
                    const messageAndArgs = target ? [Diagnostics.Default_library_for_target_0, target] : [Diagnostics.Default_library];
                    return chainDiagnosticMessages(
                    /*details*/
                    void 0, ...messageAndArgs);
                }
                default:
                    Debug.assertNever(reason);
            }
        }
        function toFileName(file, fileNameConvertor) {
            const fileName = isString(file) ? file : file.fileName;
            return fileNameConvertor ? fileNameConvertor(fileName) : fileName;
        }
        function emitFilesAndReportErrors(program, reportDiagnostic, write, reportSummary, writeFile2, cancellationToken, emitOnlyDtsFiles, customTransformers) {
            const isListFilesOnly = !!program.getCompilerOptions().listFilesOnly;
            const allDiagnostics = program.getConfigFileParsingDiagnostics().slice();
            const configFileParsingDiagnosticsLength = allDiagnostics.length;
            addRange(allDiagnostics, program.getSyntacticDiagnostics(
            /*sourceFile*/
            void 0, cancellationToken));
            if (allDiagnostics.length === configFileParsingDiagnosticsLength) {
                addRange(allDiagnostics, program.getOptionsDiagnostics(cancellationToken));
                if (!isListFilesOnly) {
                    addRange(allDiagnostics, program.getGlobalDiagnostics(cancellationToken));
                    if (allDiagnostics.length === configFileParsingDiagnosticsLength) {
                        addRange(allDiagnostics, program.getSemanticDiagnostics(
                        /*sourceFile*/
                        void 0, cancellationToken));
                    }
                }
            }
            const emitResult = isListFilesOnly ? { emitSkipped: true, diagnostics: emptyArray } : program.emit(
            /*targetSourceFile*/
            void 0, writeFile2, cancellationToken, emitOnlyDtsFiles, customTransformers);
            const { emittedFiles, diagnostics: emitDiagnostics } = emitResult;
            addRange(allDiagnostics, emitDiagnostics);
            const diagnostics = sortAndDeduplicateDiagnostics(allDiagnostics);
            diagnostics.forEach(reportDiagnostic);
            if (write) {
                const currentDir = program.getCurrentDirectory();
                forEach(emittedFiles, (file) => {
                    const filepath = getNormalizedAbsolutePath(file, currentDir);
                    write(`TSFILE: ${filepath}`);
                });
                listFiles(program, write);
            }
            if (reportSummary) {
                reportSummary(getErrorCountForSummary(diagnostics), getFilesInErrorForSummary(diagnostics));
            }
            return {
                emitResult,
                diagnostics
            };
        }
        function emitFilesAndReportErrorsAndGetExitStatus(program, reportDiagnostic, write, reportSummary, writeFile2, cancellationToken, emitOnlyDtsFiles, customTransformers) {
            const { emitResult, diagnostics } = emitFilesAndReportErrors(program, reportDiagnostic, write, reportSummary, writeFile2, cancellationToken, emitOnlyDtsFiles, customTransformers);
            if (emitResult.emitSkipped && diagnostics.length > 0) {
                return 1 /* DiagnosticsPresent_OutputsSkipped */;
            }
            else if (diagnostics.length > 0) {
                return 2 /* DiagnosticsPresent_OutputsGenerated */;
            }
            return 0 /* Success */;
        }
        function createWatchHost(system = sys, reportWatchStatus2) {
            const onWatchStatusChange = reportWatchStatus2 || createWatchStatusReporter(system);
            return {
                onWatchStatusChange,
                watchFile: maybeBind(system, system.watchFile) || returnNoopFileWatcher,
                watchDirectory: maybeBind(system, system.watchDirectory) || returnNoopFileWatcher,
                setTimeout: maybeBind(system, system.setTimeout) || noop,
                clearTimeout: maybeBind(system, system.clearTimeout) || noop
            };
        }
        function createWatchFactory(host, options) {
            const watchLogLevel = host.trace ? options.extendedDiagnostics ? 2 /* Verbose */ : options.diagnostics ? 1 /* TriggerOnly */ : 0 /* None */ : 0 /* None */;
            const writeLog = watchLogLevel !== 0 /* None */ ? (s) => host.trace(s) : noop;
            const result = getWatchFactory(host, watchLogLevel, writeLog);
            result.writeLog = writeLog;
            return result;
        }
        function createCompilerHostFromProgramHost(host, getCompilerOptions, directoryStructureHost = host) {
            const useCaseSensitiveFileNames2 = host.useCaseSensitiveFileNames();
            const compilerHost = {
                getSourceFile: createGetSourceFile((fileName, encoding) => !encoding ? compilerHost.readFile(fileName) : host.readFile(fileName, encoding), getCompilerOptions, 
                /*setParentNodes*/
                void 0),
                getDefaultLibLocation: maybeBind(host, host.getDefaultLibLocation),
                getDefaultLibFileName: (options) => host.getDefaultLibFileName(options),
                writeFile: createWriteFileMeasuringIO((path, data, writeByteOrderMark) => host.writeFile(path, data, writeByteOrderMark), (path) => host.createDirectory(path), (path) => host.directoryExists(path)),
                getCurrentDirectory: memoize(() => host.getCurrentDirectory()),
                useCaseSensitiveFileNames: () => useCaseSensitiveFileNames2,
                getCanonicalFileName: createGetCanonicalFileName(useCaseSensitiveFileNames2),
                getNewLine: () => getNewLineCharacter(getCompilerOptions()),
                fileExists: (f) => host.fileExists(f),
                readFile: (f) => host.readFile(f),
                trace: maybeBind(host, host.trace),
                directoryExists: maybeBind(directoryStructureHost, directoryStructureHost.directoryExists),
                getDirectories: maybeBind(directoryStructureHost, directoryStructureHost.getDirectories),
                realpath: maybeBind(host, host.realpath),
                getEnvironmentVariable: maybeBind(host, host.getEnvironmentVariable) || (() => ""),
                createHash: maybeBind(host, host.createHash),
                readDirectory: maybeBind(host, host.readDirectory),
                storeFilesChangingSignatureDuringEmit: host.storeFilesChangingSignatureDuringEmit,
                jsDocParsingMode: host.jsDocParsingMode
            };
            return compilerHost;
        }
        function getSourceFileVersionAsHashFromText(host, text) {
            if (text.match(sourceMapCommentRegExpDontCareLineStart)) {
                let lineEnd = text.length;
                let lineStart = lineEnd;
                for (let pos = lineEnd - 1; pos >= 0; pos--) {
                    const ch = text.charCodeAt(pos);
                    switch (ch) {
                        case 10 /* lineFeed */:
                            if (pos && text.charCodeAt(pos - 1) === 13 /* carriageReturn */) {
                                pos--;
                            }
                        case 13 /* carriageReturn */:
                            break;
                        default:
                            if (ch < 127 /* maxAsciiCharacter */ || !isLineBreak(ch)) {
                                lineStart = pos;
                                continue;
                            }
                            break;
                    }
                    const line = text.substring(lineStart, lineEnd);
                    if (line.match(sourceMapCommentRegExp)) {
                        text = text.substring(0, lineStart);
                        break;
                    }
                    else if (!line.match(whitespaceOrMapCommentRegExp)) {
                        break;
                    }
                    lineEnd = lineStart;
                }
            }
            return (host.createHash || generateDjb2Hash)(text);
        }
        function setGetSourceFileAsHashVersioned(compilerHost) {
            const originalGetSourceFile = compilerHost.getSourceFile;
            compilerHost.getSourceFile = (...args) => {
                const result = originalGetSourceFile.call(compilerHost, ...args);
                if (result) {
                    result.version = getSourceFileVersionAsHashFromText(compilerHost, result.text);
                }
                return result;
            };
        }
        function createProgramHost(system, createProgram2) {
            const getDefaultLibLocation = memoize(() => getDirectoryPath(normalizePath(system.getExecutingFilePath())));
            return {
                useCaseSensitiveFileNames: () => system.useCaseSensitiveFileNames,
                getNewLine: () => system.newLine,
                getCurrentDirectory: memoize(() => system.getCurrentDirectory()),
                getDefaultLibLocation,
                getDefaultLibFileName: (options) => combinePaths(getDefaultLibLocation(), getDefaultLibFileName(options)),
                fileExists: (path) => system.fileExists(path),
                readFile: (path, encoding) => system.readFile(path, encoding),
                directoryExists: (path) => system.directoryExists(path),
                getDirectories: (path) => system.getDirectories(path),
                readDirectory: (path, extensions, exclude, include, depth) => system.readDirectory(path, extensions, exclude, include, depth),
                realpath: maybeBind(system, system.realpath),
                getEnvironmentVariable: maybeBind(system, system.getEnvironmentVariable),
                trace: (s) => system.write(s + system.newLine),
                createDirectory: (path) => system.createDirectory(path),
                writeFile: (path, data, writeByteOrderMark) => system.writeFile(path, data, writeByteOrderMark),
                createHash: maybeBind(system, system.createHash),
                createProgram: createProgram2 || createEmitAndSemanticDiagnosticsBuilderProgram,
                storeFilesChangingSignatureDuringEmit: system.storeFilesChangingSignatureDuringEmit,
                now: maybeBind(system, system.now)
            };
        }
        function createWatchCompilerHost(system = sys, createProgram2, reportDiagnostic, reportWatchStatus2) {
            const write = (s) => system.write(s + system.newLine);
            const result = createProgramHost(system, createProgram2);
            copyProperties(result, createWatchHost(system, reportWatchStatus2));
            result.afterProgramCreate = (builderProgram) => {
                const compilerOptions = builderProgram.getCompilerOptions();
                const newLine = getNewLineCharacter(compilerOptions);
                emitFilesAndReportErrors(builderProgram, reportDiagnostic, write, (errorCount) => result.onWatchStatusChange(createCompilerDiagnostic(getWatchErrorSummaryDiagnosticMessage(errorCount), errorCount), newLine, compilerOptions, errorCount));
            };
            return result;
        }
        function reportUnrecoverableDiagnostic(system, reportDiagnostic, diagnostic) {
            reportDiagnostic(diagnostic);
            system.exit(1 /* DiagnosticsPresent_OutputsSkipped */);
        }
        function createWatchCompilerHostOfConfigFile({ configFileName, optionsToExtend, watchOptionsToExtend, extraFileExtensions, system, createProgram: createProgram2, reportDiagnostic, reportWatchStatus: reportWatchStatus2 }) {
            const diagnosticReporter = reportDiagnostic || createDiagnosticReporter(system);
            const host = createWatchCompilerHost(system, createProgram2, diagnosticReporter, reportWatchStatus2);
            host.onUnRecoverableConfigFileDiagnostic = (diagnostic) => reportUnrecoverableDiagnostic(system, diagnosticReporter, diagnostic);
            host.configFileName = configFileName;
            host.optionsToExtend = optionsToExtend;
            host.watchOptionsToExtend = watchOptionsToExtend;
            host.extraFileExtensions = extraFileExtensions;
            return host;
        }
        function createWatchCompilerHostOfFilesAndCompilerOptions({ rootFiles, options, watchOptions, projectReferences, system, createProgram: createProgram2, reportDiagnostic, reportWatchStatus: reportWatchStatus2 }) {
            const host = createWatchCompilerHost(system, createProgram2, reportDiagnostic || createDiagnosticReporter(system), reportWatchStatus2);
            host.rootFiles = rootFiles;
            host.options = options;
            host.watchOptions = watchOptions;
            host.projectReferences = projectReferences;
            return host;
        }
        function performIncrementalCompilation(input) {
            const system = input.system || sys;
            const host = input.host || (input.host = createIncrementalCompilerHost(input.options, system));
            const builderProgram = createIncrementalProgram(input);
            const exitStatus = emitFilesAndReportErrorsAndGetExitStatus(builderProgram, input.reportDiagnostic || createDiagnosticReporter(system), (s) => host.trace && host.trace(s), input.reportErrorSummary || input.options.pretty ? (errorCount, filesInError) => system.write(getErrorSummaryText(errorCount, filesInError, system.newLine, host)) : void 0);
            if (input.afterProgramEmitAndDiagnostics)
                input.afterProgramEmitAndDiagnostics(builderProgram);
            return exitStatus;
        }
        var sysFormatDiagnosticsHost, screenStartingMessageCodes, noopFileWatcher, returnNoopFileWatcher, WatchType;
        var init_watch = __esm({
            "src/compiler/watch.ts"() {
                "use strict";
                init_ts2();
                sysFormatDiagnosticsHost = sys ? {
                    getCurrentDirectory: () => sys.getCurrentDirectory(),
                    getNewLine: () => sys.newLine,
                    getCanonicalFileName: createGetCanonicalFileName(sys.useCaseSensitiveFileNames)
                } : void 0;
                screenStartingMessageCodes = [
                    Diagnostics.Starting_compilation_in_watch_mode.code,
                    Diagnostics.File_change_detected_Starting_incremental_compilation.code
                ];
                noopFileWatcher = { close: noop };
                returnNoopFileWatcher = () => noopFileWatcher;
                WatchType = {
                    ConfigFile: "Config file",
                    ExtendedConfigFile: "Extended config file",
                    SourceFile: "Source file",
                    MissingFile: "Missing file",
                    WildcardDirectory: "Wild card directory",
                    FailedLookupLocations: "Failed Lookup Locations",
                    AffectingFileLocation: "File location affecting resolution",
                    TypeRoots: "Type roots",
                    ConfigFileOfReferencedProject: "Config file of referened project",
                    ExtendedConfigOfReferencedProject: "Extended config file of referenced project",
                    WildcardDirectoryOfReferencedProject: "Wild card directory of referenced project",
                    PackageJson: "package.json file",
                    ClosedScriptInfo: "Closed Script info",
                    ConfigFileForInferredRoot: "Config file for the inferred project root",
                    NodeModules: "node_modules for closed script infos and package.jsons affecting module specifier cache",
                    MissingSourceMapFile: "Missing source map file",
                    NoopConfigFileForInferredRoot: "Noop Config file for the inferred project root",
                    MissingGeneratedFile: "Missing generated file",
                    NodeModulesForModuleSpecifierCache: "node_modules for module specifier cache invalidation",
                    TypingInstallerLocationFile: "File location for typing installer",
                    TypingInstallerLocationDirectory: "Directory location for typing installer"
                };
            }
        });
        // src/compiler/watchPublic.ts
        function readBuilderProgram(compilerOptions, host) {
            const buildInfoPath = getTsBuildInfoEmitOutputFilePath(compilerOptions);
            if (!buildInfoPath)
                return void 0;
            let buildInfo;
            if (host.getBuildInfo) {
                buildInfo = host.getBuildInfo(buildInfoPath, compilerOptions.configFilePath);
            }
            else {
                const content = host.readFile(buildInfoPath);
                if (!content)
                    return void 0;
                buildInfo = getBuildInfo(buildInfoPath, content);
            }
            if (!buildInfo || buildInfo.version !== version || !buildInfo.program)
                return void 0;
            return createBuilderProgramUsingProgramBuildInfo(buildInfo, buildInfoPath, host);
        }
        function createIncrementalCompilerHost(options, system = sys) {
            const host = createCompilerHostWorker(options, 
            /*setParentNodes*/
            void 0, system);
            host.createHash = maybeBind(system, system.createHash);
            host.storeFilesChangingSignatureDuringEmit = system.storeFilesChangingSignatureDuringEmit;
            setGetSourceFileAsHashVersioned(host);
            changeCompilerHostLikeToUseCache(host, (fileName) => toPath(fileName, host.getCurrentDirectory(), host.getCanonicalFileName));
            return host;
        }
        function createIncrementalProgram({ rootNames, options, configFileParsingDiagnostics, projectReferences, host, createProgram: createProgram2 }) {
            host = host || createIncrementalCompilerHost(options);
            createProgram2 = createProgram2 || createEmitAndSemanticDiagnosticsBuilderProgram;
            const oldProgram = readBuilderProgram(options, host);
            return createProgram2(rootNames, options, host, oldProgram, configFileParsingDiagnostics, projectReferences);
        }
        function createWatchCompilerHost2(rootFilesOrConfigFileName, options, system, createProgram2, reportDiagnostic, reportWatchStatus2, projectReferencesOrWatchOptionsToExtend, watchOptionsOrExtraFileExtensions) {
            if (isArray(rootFilesOrConfigFileName)) {
                return createWatchCompilerHostOfFilesAndCompilerOptions({
                    rootFiles: rootFilesOrConfigFileName,
                    options,
                    watchOptions: watchOptionsOrExtraFileExtensions,
                    projectReferences: projectReferencesOrWatchOptionsToExtend,
                    system,
                    createProgram: createProgram2,
                    reportDiagnostic,
                    reportWatchStatus: reportWatchStatus2
                });
            }
            else {
                return createWatchCompilerHostOfConfigFile({
                    configFileName: rootFilesOrConfigFileName,
                    optionsToExtend: options,
                    watchOptionsToExtend: projectReferencesOrWatchOptionsToExtend,
                    extraFileExtensions: watchOptionsOrExtraFileExtensions,
                    system,
                    createProgram: createProgram2,
                    reportDiagnostic,
                    reportWatchStatus: reportWatchStatus2
                });
            }
        }
        function createWatchProgram(host) {
            let builderProgram;
            let updateLevel;
            let missingFilesMap;
            let watchedWildcardDirectories;
            let timerToUpdateProgram;
            let timerToInvalidateFailedLookupResolutions;
            let parsedConfigs;
            let sharedExtendedConfigFileWatchers;
            let extendedConfigCache = host.extendedConfigCache;
            let reportFileChangeDetectedOnCreateProgram = false;
            const sourceFilesCache = /* @__PURE__ */ new Map();
            let missingFilePathsRequestedForRelease;
            let hasChangedCompilerOptions = false;
            const useCaseSensitiveFileNames2 = host.useCaseSensitiveFileNames();
            const currentDirectory = host.getCurrentDirectory();
            const { configFileName, optionsToExtend: optionsToExtendForConfigFile = {}, watchOptionsToExtend, extraFileExtensions, createProgram: createProgram2 } = host;
            let { rootFiles: rootFileNames, options: compilerOptions, watchOptions, projectReferences } = host;
            let wildcardDirectories;
            let configFileParsingDiagnostics;
            let canConfigFileJsonReportNoInputFiles = false;
            let hasChangedConfigFileParsingErrors = false;
            const cachedDirectoryStructureHost = configFileName === void 0 ? void 0 : createCachedDirectoryStructureHost(host, currentDirectory, useCaseSensitiveFileNames2);
            const directoryStructureHost = cachedDirectoryStructureHost || host;
            const parseConfigFileHost = parseConfigHostFromCompilerHostLike(host, directoryStructureHost);
            let newLine = updateNewLine();
            if (configFileName && host.configFileParsingResult) {
                setConfigFileParsingResult(host.configFileParsingResult);
                newLine = updateNewLine();
            }
            reportWatchDiagnostic(Diagnostics.Starting_compilation_in_watch_mode);
            if (configFileName && !host.configFileParsingResult) {
                newLine = getNewLineCharacter(optionsToExtendForConfigFile);
                Debug.assert(!rootFileNames);
                parseConfigFile2();
                newLine = updateNewLine();
            }
            Debug.assert(compilerOptions);
            Debug.assert(rootFileNames);
            const { watchFile: watchFile2, watchDirectory, writeLog } = createWatchFactory(host, compilerOptions);
            const getCanonicalFileName = createGetCanonicalFileName(useCaseSensitiveFileNames2);
            writeLog(`Current directory: ${currentDirectory} CaseSensitiveFileNames: ${useCaseSensitiveFileNames2}`);
            let configFileWatcher;
            if (configFileName) {
                configFileWatcher = watchFile2(configFileName, scheduleProgramReload, 2e3 /* High */, watchOptions, WatchType.ConfigFile);
            }
            const compilerHost = createCompilerHostFromProgramHost(host, () => compilerOptions, directoryStructureHost);
            setGetSourceFileAsHashVersioned(compilerHost);
            const getNewSourceFile = compilerHost.getSourceFile;
            compilerHost.getSourceFile = (fileName, ...args) => getVersionedSourceFileByPath(fileName, toPath3(fileName), ...args);
            compilerHost.getSourceFileByPath = getVersionedSourceFileByPath;
            compilerHost.getNewLine = () => newLine;
            compilerHost.fileExists = fileExists;
            compilerHost.onReleaseOldSourceFile = onReleaseOldSourceFile;
            compilerHost.onReleaseParsedCommandLine = onReleaseParsedCommandLine;
            compilerHost.toPath = toPath3;
            compilerHost.getCompilationSettings = () => compilerOptions;
            compilerHost.useSourceOfProjectReferenceRedirect = maybeBind(host, host.useSourceOfProjectReferenceRedirect);
            compilerHost.watchDirectoryOfFailedLookupLocation = (dir, cb, flags) => watchDirectory(dir, cb, flags, watchOptions, WatchType.FailedLookupLocations);
            compilerHost.watchAffectingFileLocation = (file, cb) => watchFile2(file, cb, 2e3 /* High */, watchOptions, WatchType.AffectingFileLocation);
            compilerHost.watchTypeRootsDirectory = (dir, cb, flags) => watchDirectory(dir, cb, flags, watchOptions, WatchType.TypeRoots);
            compilerHost.getCachedDirectoryStructureHost = () => cachedDirectoryStructureHost;
            compilerHost.scheduleInvalidateResolutionsOfFailedLookupLocations = scheduleInvalidateResolutionsOfFailedLookupLocations;
            compilerHost.onInvalidatedResolution = scheduleProgramUpdate;
            compilerHost.onChangedAutomaticTypeDirectiveNames = scheduleProgramUpdate;
            compilerHost.fileIsOpen = returnFalse;
            compilerHost.getCurrentProgram = getCurrentProgram;
            compilerHost.writeLog = writeLog;
            compilerHost.getParsedCommandLine = getParsedCommandLine;
            const resolutionCache = createResolutionCache(compilerHost, configFileName ? getDirectoryPath(getNormalizedAbsolutePath(configFileName, currentDirectory)) : currentDirectory, 
            /*logChangesWhenResolvingModule*/
            false);
            compilerHost.resolveModuleNameLiterals = maybeBind(host, host.resolveModuleNameLiterals);
            compilerHost.resolveModuleNames = maybeBind(host, host.resolveModuleNames);
            if (!compilerHost.resolveModuleNameLiterals && !compilerHost.resolveModuleNames) {
                compilerHost.resolveModuleNameLiterals = resolutionCache.resolveModuleNameLiterals.bind(resolutionCache);
            }
            compilerHost.resolveTypeReferenceDirectiveReferences = maybeBind(host, host.resolveTypeReferenceDirectiveReferences);
            compilerHost.resolveTypeReferenceDirectives = maybeBind(host, host.resolveTypeReferenceDirectives);
            if (!compilerHost.resolveTypeReferenceDirectiveReferences && !compilerHost.resolveTypeReferenceDirectives) {
                compilerHost.resolveTypeReferenceDirectiveReferences = resolutionCache.resolveTypeReferenceDirectiveReferences.bind(resolutionCache);
            }
            compilerHost.resolveLibrary = !host.resolveLibrary ? resolutionCache.resolveLibrary.bind(resolutionCache) : host.resolveLibrary.bind(host);
            compilerHost.getModuleResolutionCache = host.resolveModuleNameLiterals || host.resolveModuleNames ? maybeBind(host, host.getModuleResolutionCache) : () => resolutionCache.getModuleResolutionCache();
            const userProvidedResolution = !!host.resolveModuleNameLiterals || !!host.resolveTypeReferenceDirectiveReferences || !!host.resolveModuleNames || !!host.resolveTypeReferenceDirectives;
            const customHasInvalidatedResolutions = userProvidedResolution ? maybeBind(host, host.hasInvalidatedResolutions) || returnTrue : returnFalse;
            const customHasInvalidLibResolutions = host.resolveLibrary ? maybeBind(host, host.hasInvalidatedLibResolutions) || returnTrue : returnFalse;
            builderProgram = readBuilderProgram(compilerOptions, compilerHost);
            synchronizeProgram();
            watchConfigFileWildCardDirectories();
            if (configFileName)
                updateExtendedConfigFilesWatches(toPath3(configFileName), compilerOptions, watchOptions, WatchType.ExtendedConfigFile);
            return configFileName ? { getCurrentProgram: getCurrentBuilderProgram, getProgram: updateProgram, close, getResolutionCache } : { getCurrentProgram: getCurrentBuilderProgram, getProgram: updateProgram, updateRootFileNames, close, getResolutionCache };
            function close() {
                clearInvalidateResolutionsOfFailedLookupLocations();
                resolutionCache.clear();
                clearMap(sourceFilesCache, (value) => {
                    if (value && value.fileWatcher) {
                        value.fileWatcher.close();
                        value.fileWatcher = void 0;
                    }
                });
                if (configFileWatcher) {
                    configFileWatcher.close();
                    configFileWatcher = void 0;
                }
                extendedConfigCache == null ? void 0 : extendedConfigCache.clear();
                extendedConfigCache = void 0;
                if (sharedExtendedConfigFileWatchers) {
                    clearMap(sharedExtendedConfigFileWatchers, closeFileWatcherOf);
                    sharedExtendedConfigFileWatchers = void 0;
                }
                if (watchedWildcardDirectories) {
                    clearMap(watchedWildcardDirectories, closeFileWatcherOf);
                    watchedWildcardDirectories = void 0;
                }
                if (missingFilesMap) {
                    clearMap(missingFilesMap, closeFileWatcher);
                    missingFilesMap = void 0;
                }
                if (parsedConfigs) {
                    clearMap(parsedConfigs, (config) => {
                        var _a;
                        (_a = config.watcher) == null ? void 0 : _a.close();
                        config.watcher = void 0;
                        if (config.watchedDirectories)
                            clearMap(config.watchedDirectories, closeFileWatcherOf);
                        config.watchedDirectories = void 0;
                    });
                    parsedConfigs = void 0;
                }
            }
            function getResolutionCache() {
                return resolutionCache;
            }
            function getCurrentBuilderProgram() {
                return builderProgram;
            }
            function getCurrentProgram() {
                return builderProgram && builderProgram.getProgramOrUndefined();
            }
            function synchronizeProgram() {
                writeLog(`Synchronizing program`);
                Debug.assert(compilerOptions);
                Debug.assert(rootFileNames);
                clearInvalidateResolutionsOfFailedLookupLocations();
                const program = getCurrentBuilderProgram();
                if (hasChangedCompilerOptions) {
                    newLine = updateNewLine();
                    if (program && changesAffectModuleResolution(program.getCompilerOptions(), compilerOptions)) {
                        resolutionCache.onChangesAffectModuleResolution();
                    }
                }
                const { hasInvalidatedResolutions, hasInvalidatedLibResolutions } = resolutionCache.createHasInvalidatedResolutions(customHasInvalidatedResolutions, customHasInvalidLibResolutions);
                const { originalReadFile, originalFileExists, originalDirectoryExists, originalCreateDirectory, originalWriteFile, readFileWithCache } = changeCompilerHostLikeToUseCache(compilerHost, toPath3);
                if (isProgramUptoDate(getCurrentProgram(), rootFileNames, compilerOptions, (path) => getSourceVersion(path, readFileWithCache), (fileName) => compilerHost.fileExists(fileName), hasInvalidatedResolutions, hasInvalidatedLibResolutions, hasChangedAutomaticTypeDirectiveNames, getParsedCommandLine, projectReferences)) {
                    if (hasChangedConfigFileParsingErrors) {
                        if (reportFileChangeDetectedOnCreateProgram) {
                            reportWatchDiagnostic(Diagnostics.File_change_detected_Starting_incremental_compilation);
                        }
                        builderProgram = createProgram2(
                        /*rootNames*/
                        void 0, 
                        /*options*/
                        void 0, compilerHost, builderProgram, configFileParsingDiagnostics, projectReferences);
                        hasChangedConfigFileParsingErrors = false;
                    }
                }
                else {
                    if (reportFileChangeDetectedOnCreateProgram) {
                        reportWatchDiagnostic(Diagnostics.File_change_detected_Starting_incremental_compilation);
                    }
                    createNewProgram(hasInvalidatedResolutions, hasInvalidatedLibResolutions);
                }
                reportFileChangeDetectedOnCreateProgram = false;
                if (host.afterProgramCreate && program !== builderProgram) {
                    host.afterProgramCreate(builderProgram);
                }
                compilerHost.readFile = originalReadFile;
                compilerHost.fileExists = originalFileExists;
                compilerHost.directoryExists = originalDirectoryExists;
                compilerHost.createDirectory = originalCreateDirectory;
                compilerHost.writeFile = originalWriteFile;
                return builderProgram;
            }
            function createNewProgram(hasInvalidatedResolutions, hasInvalidatedLibResolutions) {
                writeLog("CreatingProgramWith::");
                writeLog(`  roots: ${JSON.stringify(rootFileNames)}`);
                writeLog(`  options: ${JSON.stringify(compilerOptions)}`);
                if (projectReferences)
                    writeLog(`  projectReferences: ${JSON.stringify(projectReferences)}`);
                const needsUpdateInTypeRootWatch = hasChangedCompilerOptions || !getCurrentProgram();
                hasChangedCompilerOptions = false;
                hasChangedConfigFileParsingErrors = false;
                resolutionCache.startCachingPerDirectoryResolution();
                compilerHost.hasInvalidatedResolutions = hasInvalidatedResolutions;
                compilerHost.hasInvalidatedLibResolutions = hasInvalidatedLibResolutions;
                compilerHost.hasChangedAutomaticTypeDirectiveNames = hasChangedAutomaticTypeDirectiveNames;
                const oldProgram = getCurrentProgram();
                builderProgram = createProgram2(rootFileNames, compilerOptions, compilerHost, builderProgram, configFileParsingDiagnostics, projectReferences);
                resolutionCache.finishCachingPerDirectoryResolution(builderProgram.getProgram(), oldProgram);
                updateMissingFilePathsWatch(builderProgram.getProgram(), missingFilesMap || (missingFilesMap = /* @__PURE__ */ new Map()), watchMissingFilePath);
                if (needsUpdateInTypeRootWatch) {
                    resolutionCache.updateTypeRootsWatch();
                }
                if (missingFilePathsRequestedForRelease) {
                    for (const missingFilePath of missingFilePathsRequestedForRelease) {
                        if (!missingFilesMap.has(missingFilePath)) {
                            sourceFilesCache.delete(missingFilePath);
                        }
                    }
                    missingFilePathsRequestedForRelease = void 0;
                }
            }
            function updateRootFileNames(files) {
                Debug.assert(!configFileName, "Cannot update root file names with config file watch mode");
                rootFileNames = files;
                scheduleProgramUpdate();
            }
            function updateNewLine() {
                return getNewLineCharacter(compilerOptions || optionsToExtendForConfigFile);
            }
            function toPath3(fileName) {
                return toPath(fileName, currentDirectory, getCanonicalFileName);
            }
            function isFileMissingOnHost(hostSourceFile) {
                return typeof hostSourceFile === "boolean";
            }
            function isFilePresenceUnknownOnHost(hostSourceFile) {
                return typeof hostSourceFile.version === "boolean";
            }
            function fileExists(fileName) {
                const path = toPath3(fileName);
                if (isFileMissingOnHost(sourceFilesCache.get(path))) {
                    return false;
                }
                return directoryStructureHost.fileExists(fileName);
            }
            function getVersionedSourceFileByPath(fileName, path, languageVersionOrOptions, onError, shouldCreateNewSourceFile) {
                const hostSourceFile = sourceFilesCache.get(path);
                if (isFileMissingOnHost(hostSourceFile)) {
                    return void 0;
                }
                const impliedNodeFormat = typeof languageVersionOrOptions === "object" ? languageVersionOrOptions.impliedNodeFormat : void 0;
                if (hostSourceFile === void 0 || shouldCreateNewSourceFile || isFilePresenceUnknownOnHost(hostSourceFile) || hostSourceFile.sourceFile.impliedNodeFormat !== impliedNodeFormat) {
                    const sourceFile = getNewSourceFile(fileName, languageVersionOrOptions, onError);
                    if (hostSourceFile) {
                        if (sourceFile) {
                            hostSourceFile.sourceFile = sourceFile;
                            hostSourceFile.version = sourceFile.version;
                            if (!hostSourceFile.fileWatcher) {
                                hostSourceFile.fileWatcher = watchFilePath(path, fileName, onSourceFileChange, 250 /* Low */, watchOptions, WatchType.SourceFile);
                            }
                        }
                        else {
                            if (hostSourceFile.fileWatcher) {
                                hostSourceFile.fileWatcher.close();
                            }
                            sourceFilesCache.set(path, false);
                        }
                    }
                    else {
                        if (sourceFile) {
                            const fileWatcher = watchFilePath(path, fileName, onSourceFileChange, 250 /* Low */, watchOptions, WatchType.SourceFile);
                            sourceFilesCache.set(path, { sourceFile, version: sourceFile.version, fileWatcher });
                        }
                        else {
                            sourceFilesCache.set(path, false);
                        }
                    }
                    return sourceFile;
                }
                return hostSourceFile.sourceFile;
            }
            function nextSourceFileVersion(path) {
                const hostSourceFile = sourceFilesCache.get(path);
                if (hostSourceFile !== void 0) {
                    if (isFileMissingOnHost(hostSourceFile)) {
                        sourceFilesCache.set(path, { version: false });
                    }
                    else {
                        hostSourceFile.version = false;
                    }
                }
            }
            function getSourceVersion(path, readFileWithCache) {
                const hostSourceFile = sourceFilesCache.get(path);
                if (!hostSourceFile)
                    return void 0;
                if (hostSourceFile.version)
                    return hostSourceFile.version;
                const text = readFileWithCache(path);
                return text !== void 0 ? getSourceFileVersionAsHashFromText(compilerHost, text) : void 0;
            }
            function onReleaseOldSourceFile(oldSourceFile, _oldOptions, hasSourceFileByPath) {
                const hostSourceFileInfo = sourceFilesCache.get(oldSourceFile.resolvedPath);
                if (hostSourceFileInfo !== void 0) {
                    if (isFileMissingOnHost(hostSourceFileInfo)) {
                        (missingFilePathsRequestedForRelease || (missingFilePathsRequestedForRelease = [])).push(oldSourceFile.path);
                    }
                    else if (hostSourceFileInfo.sourceFile === oldSourceFile) {
                        if (hostSourceFileInfo.fileWatcher) {
                            hostSourceFileInfo.fileWatcher.close();
                        }
                        sourceFilesCache.delete(oldSourceFile.resolvedPath);
                        if (!hasSourceFileByPath) {
                            resolutionCache.removeResolutionsOfFile(oldSourceFile.path);
                        }
                    }
                }
            }
            function reportWatchDiagnostic(message) {
                if (host.onWatchStatusChange) {
                    host.onWatchStatusChange(createCompilerDiagnostic(message), newLine, compilerOptions || optionsToExtendForConfigFile);
                }
            }
            function hasChangedAutomaticTypeDirectiveNames() {
                return resolutionCache.hasChangedAutomaticTypeDirectiveNames();
            }
            function clearInvalidateResolutionsOfFailedLookupLocations() {
                if (!timerToInvalidateFailedLookupResolutions)
                    return false;
                host.clearTimeout(timerToInvalidateFailedLookupResolutions);
                timerToInvalidateFailedLookupResolutions = void 0;
                return true;
            }
            function scheduleInvalidateResolutionsOfFailedLookupLocations() {
                if (!host.setTimeout || !host.clearTimeout) {
                    return resolutionCache.invalidateResolutionsOfFailedLookupLocations();
                }
                const pending = clearInvalidateResolutionsOfFailedLookupLocations();
                writeLog(`Scheduling invalidateFailedLookup${pending ? ", Cancelled earlier one" : ""}`);
                timerToInvalidateFailedLookupResolutions = host.setTimeout(invalidateResolutionsOfFailedLookup, 250, "timerToInvalidateFailedLookupResolutions");
            }
            function invalidateResolutionsOfFailedLookup() {
                timerToInvalidateFailedLookupResolutions = void 0;
                if (resolutionCache.invalidateResolutionsOfFailedLookupLocations()) {
                    scheduleProgramUpdate();
                }
            }
            function scheduleProgramUpdate() {
                if (!host.setTimeout || !host.clearTimeout) {
                    return;
                }
                if (timerToUpdateProgram) {
                    host.clearTimeout(timerToUpdateProgram);
                }
                writeLog("Scheduling update");
                timerToUpdateProgram = host.setTimeout(updateProgramWithWatchStatus, 250, "timerToUpdateProgram");
            }
            function scheduleProgramReload() {
                Debug.assert(!!configFileName);
                updateLevel = 2 /* Full */;
                scheduleProgramUpdate();
            }
            function updateProgramWithWatchStatus() {
                timerToUpdateProgram = void 0;
                reportFileChangeDetectedOnCreateProgram = true;
                updateProgram();
            }
            function updateProgram() {
                var _a, _b, _c, _d;
                switch (updateLevel) {
                    case 1 /* RootNamesAndUpdate */:
                        (_a = perfLogger) == null ? void 0 : _a.logStartUpdateProgram("PartialConfigReload");
                        reloadFileNamesFromConfigFile();
                        break;
                    case 2 /* Full */:
                        (_b = perfLogger) == null ? void 0 : _b.logStartUpdateProgram("FullConfigReload");
                        reloadConfigFile();
                        break;
                    default:
                        (_c = perfLogger) == null ? void 0 : _c.logStartUpdateProgram("SynchronizeProgram");
                        synchronizeProgram();
                        break;
                }
                (_d = perfLogger) == null ? void 0 : _d.logStopUpdateProgram("Done");
                return getCurrentBuilderProgram();
            }
            function reloadFileNamesFromConfigFile() {
                writeLog("Reloading new file names and options");
                Debug.assert(compilerOptions);
                Debug.assert(configFileName);
                updateLevel = 0 /* Update */;
                rootFileNames = getFileNamesFromConfigSpecs(compilerOptions.configFile.configFileSpecs, getNormalizedAbsolutePath(getDirectoryPath(configFileName), currentDirectory), compilerOptions, parseConfigFileHost, extraFileExtensions);
                if (updateErrorForNoInputFiles(rootFileNames, getNormalizedAbsolutePath(configFileName, currentDirectory), compilerOptions.configFile.configFileSpecs, configFileParsingDiagnostics, canConfigFileJsonReportNoInputFiles)) {
                    hasChangedConfigFileParsingErrors = true;
                }
                synchronizeProgram();
            }
            function reloadConfigFile() {
                Debug.assert(configFileName);
                writeLog(`Reloading config file: ${configFileName}`);
                updateLevel = 0 /* Update */;
                if (cachedDirectoryStructureHost) {
                    cachedDirectoryStructureHost.clearCache();
                }
                parseConfigFile2();
                hasChangedCompilerOptions = true;
                synchronizeProgram();
                watchConfigFileWildCardDirectories();
                updateExtendedConfigFilesWatches(toPath3(configFileName), compilerOptions, watchOptions, WatchType.ExtendedConfigFile);
            }
            function parseConfigFile2() {
                Debug.assert(configFileName);
                setConfigFileParsingResult(getParsedCommandLineOfConfigFile(configFileName, optionsToExtendForConfigFile, parseConfigFileHost, extendedConfigCache || (extendedConfigCache = /* @__PURE__ */ new Map()), watchOptionsToExtend, extraFileExtensions));
            }
            function setConfigFileParsingResult(configFileParseResult) {
                rootFileNames = configFileParseResult.fileNames;
                compilerOptions = configFileParseResult.options;
                watchOptions = configFileParseResult.watchOptions;
                projectReferences = configFileParseResult.projectReferences;
                wildcardDirectories = configFileParseResult.wildcardDirectories;
                configFileParsingDiagnostics = getConfigFileParsingDiagnostics(configFileParseResult).slice();
                canConfigFileJsonReportNoInputFiles = canJsonReportNoInputFiles(configFileParseResult.raw);
                hasChangedConfigFileParsingErrors = true;
            }
            function getParsedCommandLine(configFileName2) {
                const configPath = toPath3(configFileName2);
                let config = parsedConfigs == null ? void 0 : parsedConfigs.get(configPath);
                if (config) {
                    if (!config.updateLevel)
                        return config.parsedCommandLine;
                    if (config.parsedCommandLine && config.updateLevel === 1 /* RootNamesAndUpdate */ && !host.getParsedCommandLine) {
                        writeLog("Reloading new file names and options");
                        Debug.assert(compilerOptions);
                        const fileNames = getFileNamesFromConfigSpecs(config.parsedCommandLine.options.configFile.configFileSpecs, getNormalizedAbsolutePath(getDirectoryPath(configFileName2), currentDirectory), compilerOptions, parseConfigFileHost);
                        config.parsedCommandLine = { ...config.parsedCommandLine, fileNames };
                        config.updateLevel = void 0;
                        return config.parsedCommandLine;
                    }
                }
                writeLog(`Loading config file: ${configFileName2}`);
                const parsedCommandLine = host.getParsedCommandLine ? host.getParsedCommandLine(configFileName2) : getParsedCommandLineFromConfigFileHost(configFileName2);
                if (config) {
                    config.parsedCommandLine = parsedCommandLine;
                    config.updateLevel = void 0;
                }
                else {
                    (parsedConfigs || (parsedConfigs = /* @__PURE__ */ new Map())).set(configPath, config = { parsedCommandLine });
                }
                watchReferencedProject(configFileName2, configPath, config);
                return parsedCommandLine;
            }
            function getParsedCommandLineFromConfigFileHost(configFileName2) {
                const onUnRecoverableConfigFileDiagnostic = parseConfigFileHost.onUnRecoverableConfigFileDiagnostic;
                parseConfigFileHost.onUnRecoverableConfigFileDiagnostic = noop;
                const parsedCommandLine = getParsedCommandLineOfConfigFile(configFileName2, 
                /*optionsToExtend*/
                void 0, parseConfigFileHost, extendedConfigCache || (extendedConfigCache = /* @__PURE__ */ new Map()), watchOptionsToExtend);
                parseConfigFileHost.onUnRecoverableConfigFileDiagnostic = onUnRecoverableConfigFileDiagnostic;
                return parsedCommandLine;
            }
            function onReleaseParsedCommandLine(fileName) {
                var _a;
                const path = toPath3(fileName);
                const config = parsedConfigs == null ? void 0 : parsedConfigs.get(path);
                if (!config)
                    return;
                parsedConfigs.delete(path);
                if (config.watchedDirectories)
                    clearMap(config.watchedDirectories, closeFileWatcherOf);
                (_a = config.watcher) == null ? void 0 : _a.close();
                clearSharedExtendedConfigFileWatcher(path, sharedExtendedConfigFileWatchers);
            }
            function watchFilePath(path, file, callback, pollingInterval, options, watchType) {
                return watchFile2(file, (fileName, eventKind) => callback(fileName, eventKind, path), pollingInterval, options, watchType);
            }
            function onSourceFileChange(fileName, eventKind, path) {
                updateCachedSystemWithFile(fileName, path, eventKind);
                if (eventKind === 2 /* Deleted */ && sourceFilesCache.has(path)) {
                    resolutionCache.invalidateResolutionOfFile(path);
                }
                nextSourceFileVersion(path);
                scheduleProgramUpdate();
            }
            function updateCachedSystemWithFile(fileName, path, eventKind) {
                if (cachedDirectoryStructureHost) {
                    cachedDirectoryStructureHost.addOrDeleteFile(fileName, path, eventKind);
                }
            }
            function watchMissingFilePath(missingFilePath, missingFileName) {
                return (parsedConfigs == null ? void 0 : parsedConfigs.has(missingFilePath)) ? noopFileWatcher : watchFilePath(missingFilePath, missingFileName, onMissingFileChange, 500 /* Medium */, watchOptions, WatchType.MissingFile);
            }
            function onMissingFileChange(fileName, eventKind, missingFilePath) {
                updateCachedSystemWithFile(fileName, missingFilePath, eventKind);
                if (eventKind === 0 /* Created */ && missingFilesMap.has(missingFilePath)) {
                    missingFilesMap.get(missingFilePath).close();
                    missingFilesMap.delete(missingFilePath);
                    nextSourceFileVersion(missingFilePath);
                    scheduleProgramUpdate();
                }
            }
            function watchConfigFileWildCardDirectories() {
                updateWatchingWildcardDirectories(watchedWildcardDirectories || (watchedWildcardDirectories = /* @__PURE__ */ new Map()), wildcardDirectories, watchWildcardDirectory);
            }
            function watchWildcardDirectory(directory, flags) {
                return watchDirectory(directory, (fileOrDirectory) => {
                    Debug.assert(configFileName);
                    Debug.assert(compilerOptions);
                    const fileOrDirectoryPath = toPath3(fileOrDirectory);
                    if (cachedDirectoryStructureHost) {
                        cachedDirectoryStructureHost.addOrDeleteFileOrDirectory(fileOrDirectory, fileOrDirectoryPath);
                    }
                    nextSourceFileVersion(fileOrDirectoryPath);
                    if (isIgnoredFileFromWildCardWatching({
                        watchedDirPath: toPath3(directory),
                        fileOrDirectory,
                        fileOrDirectoryPath,
                        configFileName,
                        extraFileExtensions,
                        options: compilerOptions,
                        program: getCurrentBuilderProgram() || rootFileNames,
                        currentDirectory,
                        useCaseSensitiveFileNames: useCaseSensitiveFileNames2,
                        writeLog,
                        toPath: toPath3
                    }))
                        return;
                    if (updateLevel !== 2 /* Full */) {
                        updateLevel = 1 /* RootNamesAndUpdate */;
                        scheduleProgramUpdate();
                    }
                }, flags, watchOptions, WatchType.WildcardDirectory);
            }
            function updateExtendedConfigFilesWatches(forProjectPath, options, watchOptions2, watchType) {
                updateSharedExtendedConfigFileWatcher(forProjectPath, options, sharedExtendedConfigFileWatchers || (sharedExtendedConfigFileWatchers = /* @__PURE__ */ new Map()), (extendedConfigFileName, extendedConfigFilePath) => watchFile2(extendedConfigFileName, (_fileName, eventKind) => {
                    var _a;
                    updateCachedSystemWithFile(extendedConfigFileName, extendedConfigFilePath, eventKind);
                    if (extendedConfigCache)
                        cleanExtendedConfigCache(extendedConfigCache, extendedConfigFilePath, toPath3);
                    const projects = (_a = sharedExtendedConfigFileWatchers.get(extendedConfigFilePath)) == null ? void 0 : _a.projects;
                    if (!(projects == null ? void 0 : projects.size))
                        return;
                    projects.forEach((projectPath) => {
                        if (configFileName && toPath3(configFileName) === projectPath) {
                            updateLevel = 2 /* Full */;
                        }
                        else {
                            const config = parsedConfigs == null ? void 0 : parsedConfigs.get(projectPath);
                            if (config)
                                config.updateLevel = 2 /* Full */;
                            resolutionCache.removeResolutionsFromProjectReferenceRedirects(projectPath);
                        }
                        scheduleProgramUpdate();
                    });
                }, 2e3 /* High */, watchOptions2, watchType), toPath3);
            }
            function watchReferencedProject(configFileName2, configPath, commandLine) {
                var _a, _b, _c, _d;
                commandLine.watcher || (commandLine.watcher = watchFile2(configFileName2, (_fileName, eventKind) => {
                    updateCachedSystemWithFile(configFileName2, configPath, eventKind);
                    const config = parsedConfigs == null ? void 0 : parsedConfigs.get(configPath);
                    if (config)
                        config.updateLevel = 2 /* Full */;
                    resolutionCache.removeResolutionsFromProjectReferenceRedirects(configPath);
                    scheduleProgramUpdate();
                }, 2e3 /* High */, ((_a = commandLine.parsedCommandLine) == null ? void 0 : _a.watchOptions) || watchOptions, WatchType.ConfigFileOfReferencedProject));
                updateWatchingWildcardDirectories(commandLine.watchedDirectories || (commandLine.watchedDirectories = /* @__PURE__ */ new Map()), (_b = commandLine.parsedCommandLine) == null ? void 0 : _b.wildcardDirectories, (directory, flags) => {
                    var _a2;
                    return watchDirectory(directory, (fileOrDirectory) => {
                        const fileOrDirectoryPath = toPath3(fileOrDirectory);
                        if (cachedDirectoryStructureHost) {
                            cachedDirectoryStructureHost.addOrDeleteFileOrDirectory(fileOrDirectory, fileOrDirectoryPath);
                        }
                        nextSourceFileVersion(fileOrDirectoryPath);
                        const config = parsedConfigs == null ? void 0 : parsedConfigs.get(configPath);
                        if (!(config == null ? void 0 : config.parsedCommandLine))
                            return;
                        if (isIgnoredFileFromWildCardWatching({
                            watchedDirPath: toPath3(directory),
                            fileOrDirectory,
                            fileOrDirectoryPath,
                            configFileName: configFileName2,
                            options: config.parsedCommandLine.options,
                            program: config.parsedCommandLine.fileNames,
                            currentDirectory,
                            useCaseSensitiveFileNames: useCaseSensitiveFileNames2,
                            writeLog,
                            toPath: toPath3
                        }))
                            return;
                        if (config.updateLevel !== 2 /* Full */) {
                            config.updateLevel = 1 /* RootNamesAndUpdate */;
                            scheduleProgramUpdate();
                        }
                    }, flags, ((_a2 = commandLine.parsedCommandLine) == null ? void 0 : _a2.watchOptions) || watchOptions, WatchType.WildcardDirectoryOfReferencedProject);
                });
                updateExtendedConfigFilesWatches(configPath, (_c = commandLine.parsedCommandLine) == null ? void 0 : _c.options, ((_d = commandLine.parsedCommandLine) == null ? void 0 : _d.watchOptions) || watchOptions, WatchType.ExtendedConfigOfReferencedProject);
            }
        }
        var init_watchPublic = __esm({
            "src/compiler/watchPublic.ts"() {
                "use strict";
                init_ts2();
            }
        });
        // src/compiler/tsbuild.ts
        function resolveConfigFileProjectName(project) {
            if (fileExtensionIs(project, ".json" /* Json */)) {
                return project;
            }
            return combinePaths(project, "tsconfig.json");
        }
        var UpToDateStatusType;
        var init_tsbuild = __esm({
            "src/compiler/tsbuild.ts"() {
                "use strict";
                init_ts2();
                UpToDateStatusType = /* @__PURE__ */ ((UpToDateStatusType2) => {
                    UpToDateStatusType2[UpToDateStatusType2["Unbuildable"] = 0] = "Unbuildable";
                    UpToDateStatusType2[UpToDateStatusType2["UpToDate"] = 1] = "UpToDate";
                    UpToDateStatusType2[UpToDateStatusType2["UpToDateWithUpstreamTypes"] = 2] = "UpToDateWithUpstreamTypes";
                    UpToDateStatusType2[UpToDateStatusType2["OutOfDateWithPrepend"] = 3] = "OutOfDateWithPrepend";
                    UpToDateStatusType2[UpToDateStatusType2["OutputMissing"] = 4] = "OutputMissing";
                    UpToDateStatusType2[UpToDateStatusType2["ErrorReadingFile"] = 5] = "ErrorReadingFile";
                    UpToDateStatusType2[UpToDateStatusType2["OutOfDateWithSelf"] = 6] = "OutOfDateWithSelf";
                    UpToDateStatusType2[UpToDateStatusType2["OutOfDateWithUpstream"] = 7] = "OutOfDateWithUpstream";
                    UpToDateStatusType2[UpToDateStatusType2["OutOfDateBuildInfo"] = 8] = "OutOfDateBuildInfo";
                    UpToDateStatusType2[UpToDateStatusType2["OutOfDateOptions"] = 9] = "OutOfDateOptions";
                    UpToDateStatusType2[UpToDateStatusType2["OutOfDateRoots"] = 10] = "OutOfDateRoots";
                    UpToDateStatusType2[UpToDateStatusType2["UpstreamOutOfDate"] = 11] = "UpstreamOutOfDate";
                    UpToDateStatusType2[UpToDateStatusType2["UpstreamBlocked"] = 12] = "UpstreamBlocked";
                    UpToDateStatusType2[UpToDateStatusType2["ComputingUpstream"] = 13] = "ComputingUpstream";
                    UpToDateStatusType2[UpToDateStatusType2["TsVersionOutputOfDate"] = 14] = "TsVersionOutputOfDate";
                    UpToDateStatusType2[UpToDateStatusType2["UpToDateWithInputFileText"] = 15] = "UpToDateWithInputFileText";
                    UpToDateStatusType2[UpToDateStatusType2["ContainerOnly"] = 16] = "ContainerOnly";
                    UpToDateStatusType2[UpToDateStatusType2["ForceBuild"] = 17] = "ForceBuild";
                    return UpToDateStatusType2;
                })(UpToDateStatusType || {});
            }
        });
        // src/compiler/tsbuildPublic.ts
        function getOrCreateValueFromConfigFileMap(configFileMap, resolved, createT) {
            const existingValue = configFileMap.get(resolved);
            let newValue;
            if (!existingValue) {
                newValue = createT();
                configFileMap.set(resolved, newValue);
            }
            return existingValue || newValue;
        }
        function getOrCreateValueMapFromConfigFileMap(configFileMap, resolved) {
            return getOrCreateValueFromConfigFileMap(configFileMap, resolved, () => /* @__PURE__ */ new Map());
        }
        function getCurrentTime(host) {
            return host.now ? host.now() : /* @__PURE__ */ new Date();
        }
        function isCircularBuildOrder(buildOrder) {
            return !!buildOrder && !!buildOrder.buildOrder;
        }
        function getBuildOrderFromAnyBuildOrder(anyBuildOrder) {
            return isCircularBuildOrder(anyBuildOrder) ? anyBuildOrder.buildOrder : anyBuildOrder;
        }
        function createBuilderStatusReporter(system, pretty) {
            return (diagnostic) => {
                let output = pretty ? `[${formatColorAndReset(getLocaleTimeString(system), "\x1B[90m" /* Grey */)}] ` : `${getLocaleTimeString(system)} - `;
                output += `${flattenDiagnosticMessageText(diagnostic.messageText, system.newLine)}${system.newLine + system.newLine}`;
                system.write(output);
            };
        }
        function createSolutionBuilderHostBase(system, createProgram2, reportDiagnostic, reportSolutionBuilderStatus) {
            const host = createProgramHost(system, createProgram2);
            host.getModifiedTime = system.getModifiedTime ? (path) => system.getModifiedTime(path) : returnUndefined;
            host.setModifiedTime = system.setModifiedTime ? (path, date) => system.setModifiedTime(path, date) : noop;
            host.deleteFile = system.deleteFile ? (path) => system.deleteFile(path) : noop;
            host.reportDiagnostic = reportDiagnostic || createDiagnosticReporter(system);
            host.reportSolutionBuilderStatus = reportSolutionBuilderStatus || createBuilderStatusReporter(system);
            host.now = maybeBind(system, system.now);
            return host;
        }
        function createSolutionBuilderHost(system = sys, createProgram2, reportDiagnostic, reportSolutionBuilderStatus, reportErrorSummary2) {
            const host = createSolutionBuilderHostBase(system, createProgram2, reportDiagnostic, reportSolutionBuilderStatus);
            host.reportErrorSummary = reportErrorSummary2;
            return host;
        }
        function createSolutionBuilderWithWatchHost(system = sys, createProgram2, reportDiagnostic, reportSolutionBuilderStatus, reportWatchStatus2) {
            const host = createSolutionBuilderHostBase(system, createProgram2, reportDiagnostic, reportSolutionBuilderStatus);
            const watchHost = createWatchHost(system, reportWatchStatus2);
            copyProperties(host, watchHost);
            return host;
        }
        function getCompilerOptionsOfBuildOptions(buildOptions) {
            const result = {};
            commonOptionsWithBuild.forEach((option) => {
                if (hasProperty(buildOptions, option.name))
                    result[option.name] = buildOptions[option.name];
            });
            return result;
        }
        function createSolutionBuilder(host, rootNames, defaultOptions) {
            return createSolutionBuilderWorker(
            /*watch*/
            false, host, rootNames, defaultOptions);
        }
        function createSolutionBuilderWithWatch(host, rootNames, defaultOptions, baseWatchOptions) {
            return createSolutionBuilderWorker(
            /*watch*/
            true, host, rootNames, defaultOptions, baseWatchOptions);
        }
        function createSolutionBuilderState(watch, hostOrHostWithWatch, rootNames, options, baseWatchOptions) {
            const host = hostOrHostWithWatch;
            const hostWithWatch = hostOrHostWithWatch;
            const baseCompilerOptions = getCompilerOptionsOfBuildOptions(options);
            const compilerHost = createCompilerHostFromProgramHost(host, () => state.projectCompilerOptions);
            setGetSourceFileAsHashVersioned(compilerHost);
            compilerHost.getParsedCommandLine = (fileName) => parseConfigFile(state, fileName, toResolvedConfigFilePath(state, fileName));
            compilerHost.resolveModuleNameLiterals = maybeBind(host, host.resolveModuleNameLiterals);
            compilerHost.resolveTypeReferenceDirectiveReferences = maybeBind(host, host.resolveTypeReferenceDirectiveReferences);
            compilerHost.resolveLibrary = maybeBind(host, host.resolveLibrary);
            compilerHost.resolveModuleNames = maybeBind(host, host.resolveModuleNames);
            compilerHost.resolveTypeReferenceDirectives = maybeBind(host, host.resolveTypeReferenceDirectives);
            compilerHost.getModuleResolutionCache = maybeBind(host, host.getModuleResolutionCache);
            let moduleResolutionCache, typeReferenceDirectiveResolutionCache;
            if (!compilerHost.resolveModuleNameLiterals && !compilerHost.resolveModuleNames) {
                moduleResolutionCache = createModuleResolutionCache(compilerHost.getCurrentDirectory(), compilerHost.getCanonicalFileName);
                compilerHost.resolveModuleNameLiterals = (moduleNames, containingFile, redirectedReference, options2, containingSourceFile) => loadWithModeAwareCache(moduleNames, containingFile, redirectedReference, options2, containingSourceFile, host, moduleResolutionCache, createModuleResolutionLoader);
                compilerHost.getModuleResolutionCache = () => moduleResolutionCache;
            }
            if (!compilerHost.resolveTypeReferenceDirectiveReferences && !compilerHost.resolveTypeReferenceDirectives) {
                typeReferenceDirectiveResolutionCache = createTypeReferenceDirectiveResolutionCache(compilerHost.getCurrentDirectory(), compilerHost.getCanonicalFileName, 
                /*options*/
                void 0, moduleResolutionCache == null ? void 0 : moduleResolutionCache.getPackageJsonInfoCache(), moduleResolutionCache == null ? void 0 : moduleResolutionCache.optionsToRedirectsKey);
                compilerHost.resolveTypeReferenceDirectiveReferences = (typeDirectiveNames, containingFile, redirectedReference, options2, containingSourceFile) => loadWithModeAwareCache(typeDirectiveNames, containingFile, redirectedReference, options2, containingSourceFile, host, typeReferenceDirectiveResolutionCache, createTypeReferenceResolutionLoader);
            }
            let libraryResolutionCache;
            if (!compilerHost.resolveLibrary) {
                libraryResolutionCache = createModuleResolutionCache(compilerHost.getCurrentDirectory(), compilerHost.getCanonicalFileName, 
                /*options*/
                void 0, moduleResolutionCache == null ? void 0 : moduleResolutionCache.getPackageJsonInfoCache());
                compilerHost.resolveLibrary = (libraryName, resolveFrom, options2) => resolveLibrary(libraryName, resolveFrom, options2, host, libraryResolutionCache);
            }
            compilerHost.getBuildInfo = (fileName, configFilePath) => getBuildInfo3(state, fileName, toResolvedConfigFilePath(state, configFilePath), 
            /*modifiedTime*/
            void 0);
            const { watchFile: watchFile2, watchDirectory, writeLog } = createWatchFactory(hostWithWatch, options);
            const state = {
                host,
                hostWithWatch,
                parseConfigFileHost: parseConfigHostFromCompilerHostLike(host),
                write: maybeBind(host, host.trace),
                // State of solution
                options,
                baseCompilerOptions,
                rootNames,
                baseWatchOptions,
                resolvedConfigFilePaths: /* @__PURE__ */ new Map(),
                configFileCache: /* @__PURE__ */ new Map(),
                projectStatus: /* @__PURE__ */ new Map(),
                extendedConfigCache: /* @__PURE__ */ new Map(),
                buildInfoCache: /* @__PURE__ */ new Map(),
                outputTimeStamps: /* @__PURE__ */ new Map(),
                builderPrograms: /* @__PURE__ */ new Map(),
                diagnostics: /* @__PURE__ */ new Map(),
                projectPendingBuild: /* @__PURE__ */ new Map(),
                projectErrorsReported: /* @__PURE__ */ new Map(),
                compilerHost,
                moduleResolutionCache,
                typeReferenceDirectiveResolutionCache,
                libraryResolutionCache,
                // Mutable state
                buildOrder: void 0,
                readFileWithCache: (f) => host.readFile(f),
                projectCompilerOptions: baseCompilerOptions,
                cache: void 0,
                allProjectBuildPending: true,
                needsSummary: true,
                watchAllProjectsPending: watch,
                // Watch state
                watch,
                allWatchedWildcardDirectories: /* @__PURE__ */ new Map(),
                allWatchedInputFiles: /* @__PURE__ */ new Map(),
                allWatchedConfigFiles: /* @__PURE__ */ new Map(),
                allWatchedExtendedConfigFiles: /* @__PURE__ */ new Map(),
                allWatchedPackageJsonFiles: /* @__PURE__ */ new Map(),
                filesWatched: /* @__PURE__ */ new Map(),
                lastCachedPackageJsonLookups: /* @__PURE__ */ new Map(),
                timerToBuildInvalidatedProject: void 0,
                reportFileChangeDetected: false,
                watchFile: watchFile2,
                watchDirectory,
                writeLog
            };
            return state;
        }
        function toPath2(state, fileName) {
            return toPath(fileName, state.compilerHost.getCurrentDirectory(), state.compilerHost.getCanonicalFileName);
        }
        function toResolvedConfigFilePath(state, fileName) {
            const { resolvedConfigFilePaths } = state;
            const path = resolvedConfigFilePaths.get(fileName);
            if (path !== void 0)
                return path;
            const resolvedPath = toPath2(state, fileName);
            resolvedConfigFilePaths.set(fileName, resolvedPath);
            return resolvedPath;
        }
        function isParsedCommandLine(entry) {
            return !!entry.options;
        }
        function getCachedParsedConfigFile(state, configFilePath) {
            const value = state.configFileCache.get(configFilePath);
            return value && isParsedCommandLine(value) ? value : void 0;
        }
        function parseConfigFile(state, configFileName, configFilePath) {
            const { configFileCache } = state;
            const value = configFileCache.get(configFilePath);
            if (value) {
                return isParsedCommandLine(value) ? value : void 0;
            }
            mark("SolutionBuilder::beforeConfigFileParsing");
            let diagnostic;
            const { parseConfigFileHost, baseCompilerOptions, baseWatchOptions, extendedConfigCache, host } = state;
            let parsed;
            if (host.getParsedCommandLine) {
                parsed = host.getParsedCommandLine(configFileName);
                if (!parsed)
                    diagnostic = createCompilerDiagnostic(Diagnostics.File_0_not_found, configFileName);
            }
            else {
                parseConfigFileHost.onUnRecoverableConfigFileDiagnostic = (d) => diagnostic = d;
                parsed = getParsedCommandLineOfConfigFile(configFileName, baseCompilerOptions, parseConfigFileHost, extendedConfigCache, baseWatchOptions);
                parseConfigFileHost.onUnRecoverableConfigFileDiagnostic = noop;
            }
            configFileCache.set(configFilePath, parsed || diagnostic);
            mark("SolutionBuilder::afterConfigFileParsing");
            measure("SolutionBuilder::Config file parsing", "SolutionBuilder::beforeConfigFileParsing", "SolutionBuilder::afterConfigFileParsing");
            return parsed;
        }
        function resolveProjectName(state, name) {
            return resolveConfigFileProjectName(resolvePath(state.compilerHost.getCurrentDirectory(), name));
        }
        function createBuildOrder(state, roots) {
            const temporaryMarks = /* @__PURE__ */ new Map();
            const permanentMarks = /* @__PURE__ */ new Map();
            const circularityReportStack = [];
            let buildOrder;
            let circularDiagnostics;
            for (const root of roots) {
                visit(root);
            }
            return circularDiagnostics ? { buildOrder: buildOrder || emptyArray, circularDiagnostics } : buildOrder || emptyArray;
            function visit(configFileName, inCircularContext) {
                const projPath = toResolvedConfigFilePath(state, configFileName);
                if (permanentMarks.has(projPath))
                    return;
                if (temporaryMarks.has(projPath)) {
                    if (!inCircularContext) {
                        (circularDiagnostics || (circularDiagnostics = [])).push(createCompilerDiagnostic(Diagnostics.Project_references_may_not_form_a_circular_graph_Cycle_detected_Colon_0, circularityReportStack.join("\r\n")));
                    }
                    return;
                }
                temporaryMarks.set(projPath, true);
                circularityReportStack.push(configFileName);
                const parsed = parseConfigFile(state, configFileName, projPath);
                if (parsed && parsed.projectReferences) {
                    for (const ref of parsed.projectReferences) {
                        const resolvedRefPath = resolveProjectName(state, ref.path);
                        visit(resolvedRefPath, inCircularContext || ref.circular);
                    }
                }
                circularityReportStack.pop();
                permanentMarks.set(projPath, true);
                (buildOrder || (buildOrder = [])).push(configFileName);
            }
        }
        function getBuildOrder(state) {
            return state.buildOrder || createStateBuildOrder(state);
        }
        function createStateBuildOrder(state) {
            const buildOrder = createBuildOrder(state, state.rootNames.map((f) => resolveProjectName(state, f)));
            state.resolvedConfigFilePaths.clear();
            const currentProjects = new Set(getBuildOrderFromAnyBuildOrder(buildOrder).map((resolved) => toResolvedConfigFilePath(state, resolved)));
            const noopOnDelete = { onDeleteValue: noop };
            mutateMapSkippingNewValues(state.configFileCache, currentProjects, noopOnDelete);
            mutateMapSkippingNewValues(state.projectStatus, currentProjects, noopOnDelete);
            mutateMapSkippingNewValues(state.builderPrograms, currentProjects, noopOnDelete);
            mutateMapSkippingNewValues(state.diagnostics, currentProjects, noopOnDelete);
            mutateMapSkippingNewValues(state.projectPendingBuild, currentProjects, noopOnDelete);
            mutateMapSkippingNewValues(state.projectErrorsReported, currentProjects, noopOnDelete);
            mutateMapSkippingNewValues(state.buildInfoCache, currentProjects, noopOnDelete);
            mutateMapSkippingNewValues(state.outputTimeStamps, currentProjects, noopOnDelete);
            mutateMapSkippingNewValues(state.lastCachedPackageJsonLookups, currentProjects, noopOnDelete);
            if (state.watch) {
                mutateMapSkippingNewValues(state.allWatchedConfigFiles, currentProjects, { onDeleteValue: closeFileWatcher });
                state.allWatchedExtendedConfigFiles.forEach((watcher) => {
                    watcher.projects.forEach((project) => {
                        if (!currentProjects.has(project)) {
                            watcher.projects.delete(project);
                        }
                    });
                    watcher.close();
                });
                mutateMapSkippingNewValues(state.allWatchedWildcardDirectories, currentProjects, { onDeleteValue: (existingMap) => existingMap.forEach(closeFileWatcherOf) });
                mutateMapSkippingNewValues(state.allWatchedInputFiles, currentProjects, { onDeleteValue: (existingMap) => existingMap.forEach(closeFileWatcher) });
                mutateMapSkippingNewValues(state.allWatchedPackageJsonFiles, currentProjects, { onDeleteValue: (existingMap) => existingMap.forEach(closeFileWatcher) });
            }
            return state.buildOrder = buildOrder;
        }
        function getBuildOrderFor(state, project, onlyReferences) {
            const resolvedProject = project && resolveProjectName(state, project);
            const buildOrderFromState = getBuildOrder(state);
            if (isCircularBuildOrder(buildOrderFromState))
                return buildOrderFromState;
            if (resolvedProject) {
                const projectPath = toResolvedConfigFilePath(state, resolvedProject);
                const projectIndex = findIndex(buildOrderFromState, (configFileName) => toResolvedConfigFilePath(state, configFileName) === projectPath);
                if (projectIndex === -1)
                    return void 0;
            }
            const buildOrder = resolvedProject ? createBuildOrder(state, [resolvedProject]) : buildOrderFromState;
            Debug.assert(!isCircularBuildOrder(buildOrder));
            Debug.assert(!onlyReferences || resolvedProject !== void 0);
            Debug.assert(!onlyReferences || buildOrder[buildOrder.length - 1] === resolvedProject);
            return onlyReferences ? buildOrder.slice(0, buildOrder.length - 1) : buildOrder;
        }
        function enableCache(state) {
            if (state.cache) {
                disableCache(state);
            }
            const { compilerHost, host } = state;
            const originalReadFileWithCache = state.readFileWithCache;
            const originalGetSourceFile = compilerHost.getSourceFile;
            const { originalReadFile, originalFileExists, originalDirectoryExists, originalCreateDirectory, originalWriteFile, getSourceFileWithCache, readFileWithCache } = changeCompilerHostLikeToUseCache(host, (fileName) => toPath2(state, fileName), (...args) => originalGetSourceFile.call(compilerHost, ...args));
            state.readFileWithCache = readFileWithCache;
            compilerHost.getSourceFile = getSourceFileWithCache;
            state.cache = {
                originalReadFile,
                originalFileExists,
                originalDirectoryExists,
                originalCreateDirectory,
                originalWriteFile,
                originalReadFileWithCache,
                originalGetSourceFile
            };
        }
        function disableCache(state) {
            if (!state.cache)
                return;
            const { cache, host, compilerHost, extendedConfigCache, moduleResolutionCache, typeReferenceDirectiveResolutionCache, libraryResolutionCache } = state;
            host.readFile = cache.originalReadFile;
            host.fileExists = cache.originalFileExists;
            host.directoryExists = cache.originalDirectoryExists;
            host.createDirectory = cache.originalCreateDirectory;
            host.writeFile = cache.originalWriteFile;
            compilerHost.getSourceFile = cache.originalGetSourceFile;
            state.readFileWithCache = cache.originalReadFileWithCache;
            extendedConfigCache.clear();
            moduleResolutionCache == null ? void 0 : moduleResolutionCache.clear();
            typeReferenceDirectiveResolutionCache == null ? void 0 : typeReferenceDirectiveResolutionCache.clear();
            libraryResolutionCache == null ? void 0 : libraryResolutionCache.clear();
            state.cache = void 0;
        }
        function clearProjectStatus(state, resolved) {
            state.projectStatus.delete(resolved);
            state.diagnostics.delete(resolved);
        }
        function addProjToQueue({ projectPendingBuild }, proj, updateLevel) {
            const value = projectPendingBuild.get(proj);
            if (value === void 0) {
                projectPendingBuild.set(proj, updateLevel);
            }
            else if (value < updateLevel) {
                projectPendingBuild.set(proj, updateLevel);
            }
        }
        function setupInitialBuild(state, cancellationToken) {
            if (!state.allProjectBuildPending)
                return;
            state.allProjectBuildPending = false;
            if (state.options.watch)
                reportWatchStatus(state, Diagnostics.Starting_compilation_in_watch_mode);
            enableCache(state);
            const buildOrder = getBuildOrderFromAnyBuildOrder(getBuildOrder(state));
            buildOrder.forEach((configFileName) => state.projectPendingBuild.set(toResolvedConfigFilePath(state, configFileName), 0 /* Update */));
            if (cancellationToken) {
                cancellationToken.throwIfCancellationRequested();
            }
        }
        function doneInvalidatedProject(state, projectPath) {
            state.projectPendingBuild.delete(projectPath);
            return state.diagnostics.has(projectPath) ? 1 /* DiagnosticsPresent_OutputsSkipped */ : 0 /* Success */;
        }
        function createUpdateOutputFileStampsProject(state, project, projectPath, config, buildOrder) {
            let updateOutputFileStampsPending = true;
            return {
                kind: 2 /* UpdateOutputFileStamps */,
                project,
                projectPath,
                buildOrder,
                getCompilerOptions: () => config.options,
                getCurrentDirectory: () => state.compilerHost.getCurrentDirectory(),
                updateOutputFileStatmps: () => {
                    updateOutputTimestamps(state, config, projectPath);
                    updateOutputFileStampsPending = false;
                },
                done: () => {
                    if (updateOutputFileStampsPending) {
                        updateOutputTimestamps(state, config, projectPath);
                    }
                    mark("SolutionBuilder::Timestamps only updates");
                    return doneInvalidatedProject(state, projectPath);
                }
            };
        }
        function createBuildOrUpdateInvalidedProject(kind, state, project, projectPath, projectIndex, config, buildOrder) {
            let step = kind === 0 /* Build */ ? 0 /* CreateProgram */ : 4 /* EmitBundle */;
            let program;
            let buildResult;
            let invalidatedProjectOfBundle;
            return kind === 0 /* Build */ ? {
                kind,
                project,
                projectPath,
                buildOrder,
                getCompilerOptions: () => config.options,
                getCurrentDirectory: () => state.compilerHost.getCurrentDirectory(),
                getBuilderProgram: () => withProgramOrUndefined(identity),
                getProgram: () => withProgramOrUndefined((program2) => program2.getProgramOrUndefined()),
                getSourceFile: (fileName) => withProgramOrUndefined((program2) => program2.getSourceFile(fileName)),
                getSourceFiles: () => withProgramOrEmptyArray((program2) => program2.getSourceFiles()),
                getOptionsDiagnostics: (cancellationToken) => withProgramOrEmptyArray((program2) => program2.getOptionsDiagnostics(cancellationToken)),
                getGlobalDiagnostics: (cancellationToken) => withProgramOrEmptyArray((program2) => program2.getGlobalDiagnostics(cancellationToken)),
                getConfigFileParsingDiagnostics: () => withProgramOrEmptyArray((program2) => program2.getConfigFileParsingDiagnostics()),
                getSyntacticDiagnostics: (sourceFile, cancellationToken) => withProgramOrEmptyArray((program2) => program2.getSyntacticDiagnostics(sourceFile, cancellationToken)),
                getAllDependencies: (sourceFile) => withProgramOrEmptyArray((program2) => program2.getAllDependencies(sourceFile)),
                getSemanticDiagnostics: (sourceFile, cancellationToken) => withProgramOrEmptyArray((program2) => program2.getSemanticDiagnostics(sourceFile, cancellationToken)),
                getSemanticDiagnosticsOfNextAffectedFile: (cancellationToken, ignoreSourceFile) => withProgramOrUndefined((program2) => program2.getSemanticDiagnosticsOfNextAffectedFile && program2.getSemanticDiagnosticsOfNextAffectedFile(cancellationToken, ignoreSourceFile)),
                emit: (targetSourceFile, writeFile2, cancellationToken, emitOnlyDtsFiles, customTransformers) => {
                    if (targetSourceFile || emitOnlyDtsFiles) {
                        return withProgramOrUndefined((program2) => {
                            var _a, _b;
                            return program2.emit(targetSourceFile, writeFile2, cancellationToken, emitOnlyDtsFiles, customTransformers || ((_b = (_a = state.host).getCustomTransformers) == null ? void 0 : _b.call(_a, project)));
                        });
                    }
                    executeSteps(2 /* SemanticDiagnostics */, cancellationToken);
                    if (step === 5 /* EmitBuildInfo */) {
                        return emitBuildInfo(writeFile2, cancellationToken);
                    }
                    if (step !== 3 /* Emit */)
                        return void 0;
                    return emit(writeFile2, cancellationToken, customTransformers);
                },
                done
            } : {
                kind,
                project,
                projectPath,
                buildOrder,
                getCompilerOptions: () => config.options,
                getCurrentDirectory: () => state.compilerHost.getCurrentDirectory(),
                emit: (writeFile2, customTransformers) => {
                    if (step !== 4 /* EmitBundle */)
                        return invalidatedProjectOfBundle;
                    return emitBundle(writeFile2, customTransformers);
                },
                done
            };
            function done(cancellationToken, writeFile2, customTransformers) {
                executeSteps(8 /* Done */, cancellationToken, writeFile2, customTransformers);
                if (kind === 0 /* Build */)
                    mark("SolutionBuilder::Projects built");
                else
                    mark("SolutionBuilder::Bundles updated");
                return doneInvalidatedProject(state, projectPath);
            }
            function withProgramOrUndefined(action) {
                executeSteps(0 /* CreateProgram */);
                return program && action(program);
            }
            function withProgramOrEmptyArray(action) {
                return withProgramOrUndefined(action) || emptyArray;
            }
            function createProgram2() {
                var _a, _b, _c;
                Debug.assert(program === void 0);
                if (state.options.dry) {
                    reportStatus(state, Diagnostics.A_non_dry_build_would_build_project_0, project);
                    buildResult = 1 /* Success */;
                    step = 7 /* QueueReferencingProjects */;
                    return;
                }
                if (state.options.verbose)
                    reportStatus(state, Diagnostics.Building_project_0, project);
                if (config.fileNames.length === 0) {
                    reportAndStoreErrors(state, projectPath, getConfigFileParsingDiagnostics(config));
                    buildResult = 0 /* None */;
                    step = 7 /* QueueReferencingProjects */;
                    return;
                }
                const { host, compilerHost } = state;
                state.projectCompilerOptions = config.options;
                (_a = state.moduleResolutionCache) == null ? void 0 : _a.update(config.options);
                (_b = state.typeReferenceDirectiveResolutionCache) == null ? void 0 : _b.update(config.options);
                program = host.createProgram(config.fileNames, config.options, compilerHost, getOldProgram(state, projectPath, config), getConfigFileParsingDiagnostics(config), config.projectReferences);
                if (state.watch) {
                    const internalMap = (_c = state.moduleResolutionCache) == null ? void 0 : _c.getPackageJsonInfoCache().getInternalMap();
                    state.lastCachedPackageJsonLookups.set(projectPath, internalMap && new Set(arrayFrom(internalMap.values(), (data) => state.host.realpath && (isPackageJsonInfo(data) || data.directoryExists) ? state.host.realpath(combinePaths(data.packageDirectory, "package.json")) : combinePaths(data.packageDirectory, "package.json"))));
                    state.builderPrograms.set(projectPath, program);
                }
                step++;
            }
            function handleDiagnostics(diagnostics, errorFlags, errorType) {
                if (diagnostics.length) {
                    ({ buildResult, step } = buildErrors(state, projectPath, program, config, diagnostics, errorFlags, errorType));
                }
                else {
                    step++;
                }
            }
            function getSyntaxDiagnostics(cancellationToken) {
                Debug.assertIsDefined(program);
                handleDiagnostics([
                    ...program.getConfigFileParsingDiagnostics(),
                    ...program.getOptionsDiagnostics(cancellationToken),
                    ...program.getGlobalDiagnostics(cancellationToken),
                    ...program.getSyntacticDiagnostics(
                    /*sourceFile*/
                    void 0, cancellationToken)
                ], 8 /* SyntaxErrors */, "Syntactic");
            }
            function getSemanticDiagnostics(cancellationToken) {
                handleDiagnostics(Debug.checkDefined(program).getSemanticDiagnostics(
                /*sourceFile*/
                void 0, cancellationToken), 16 /* TypeErrors */, "Semantic");
            }
            function emit(writeFileCallback, cancellationToken, customTransformers) {
                var _a, _b, _c;
                Debug.assertIsDefined(program);
                Debug.assert(step === 3 /* Emit */);
                const saved = program.saveEmitState();
                let declDiagnostics;
                const reportDeclarationDiagnostics = (d) => (declDiagnostics || (declDiagnostics = [])).push(d);
                const outputFiles = [];
                const { emitResult } = emitFilesAndReportErrors(program, reportDeclarationDiagnostics, 
                /*write*/
                void 0, 
                /*reportSummary*/
                void 0, (name, text, writeByteOrderMark, _onError, _sourceFiles, data) => outputFiles.push({ name, text, writeByteOrderMark, data }), cancellationToken, 
                /*emitOnlyDtsFiles*/
                false, customTransformers || ((_b = (_a = state.host).getCustomTransformers) == null ? void 0 : _b.call(_a, project)));
                if (declDiagnostics) {
                    program.restoreEmitState(saved);
                    ({ buildResult, step } = buildErrors(state, projectPath, program, config, declDiagnostics, 32 /* DeclarationEmitErrors */, "Declaration file"));
                    return {
                        emitSkipped: true,
                        diagnostics: emitResult.diagnostics
                    };
                }
                const { host, compilerHost } = state;
                const resultFlags = ((_c = program.hasChangedEmitSignature) == null ? void 0 : _c.call(program)) ? 0 /* None */ : 2 /* DeclarationOutputUnchanged */;
                const emitterDiagnostics = createDiagnosticCollection();
                const emittedOutputs = /* @__PURE__ */ new Map();
                const options = program.getCompilerOptions();
                const isIncremental = isIncrementalCompilation(options);
                let outputTimeStampMap;
                let now;
                outputFiles.forEach(({ name, text, writeByteOrderMark, data }) => {
                    const path = toPath2(state, name);
                    emittedOutputs.set(toPath2(state, name), name);
                    if (data == null ? void 0 : data.buildInfo)
                        setBuildInfo(state, data.buildInfo, projectPath, options, resultFlags);
                    const modifiedTime = (data == null ? void 0 : data.differsOnlyInMap) ? getModifiedTime(state.host, name) : void 0;
                    writeFile(writeFileCallback ? { writeFile: writeFileCallback } : compilerHost, emitterDiagnostics, name, text, writeByteOrderMark);
                    if (data == null ? void 0 : data.differsOnlyInMap)
                        state.host.setModifiedTime(name, modifiedTime);
                    else if (!isIncremental && state.watch) {
                        (outputTimeStampMap || (outputTimeStampMap = getOutputTimeStampMap(state, projectPath))).set(path, now || (now = getCurrentTime(state.host)));
                    }
                });
                finishEmit(emitterDiagnostics, emittedOutputs, outputFiles.length ? outputFiles[0].name : getFirstProjectOutput(config, !host.useCaseSensitiveFileNames()), resultFlags);
                return emitResult;
            }
            function emitBuildInfo(writeFileCallback, cancellationToken) {
                Debug.assertIsDefined(program);
                Debug.assert(step === 5 /* EmitBuildInfo */);
                const emitResult = program.emitBuildInfo((name, text, writeByteOrderMark, onError, sourceFiles, data) => {
                    if (data == null ? void 0 : data.buildInfo)
                        setBuildInfo(state, data.buildInfo, projectPath, program.getCompilerOptions(), 2 /* DeclarationOutputUnchanged */);
                    if (writeFileCallback)
                        writeFileCallback(name, text, writeByteOrderMark, onError, sourceFiles, data);
                    else
                        state.compilerHost.writeFile(name, text, writeByteOrderMark, onError, sourceFiles, data);
                }, cancellationToken);
                if (emitResult.diagnostics.length) {
                    reportErrors(state, emitResult.diagnostics);
                    state.diagnostics.set(projectPath, [...state.diagnostics.get(projectPath), ...emitResult.diagnostics]);
                    buildResult = 64 /* EmitErrors */ & buildResult;
                }
                if (emitResult.emittedFiles && state.write) {
                    emitResult.emittedFiles.forEach((name) => listEmittedFile(state, config, name));
                }
                afterProgramDone(state, program, config);
                step = 7 /* QueueReferencingProjects */;
                return emitResult;
            }
            function finishEmit(emitterDiagnostics, emittedOutputs, oldestOutputFileName, resultFlags) {
                const emitDiagnostics = emitterDiagnostics.getDiagnostics();
                if (emitDiagnostics.length) {
                    ({ buildResult, step } = buildErrors(state, projectPath, program, config, emitDiagnostics, 64 /* EmitErrors */, "Emit"));
                    return emitDiagnostics;
                }
                if (state.write) {
                    emittedOutputs.forEach((name) => listEmittedFile(state, config, name));
                }
                updateOutputTimestampsWorker(state, config, projectPath, Diagnostics.Updating_unchanged_output_timestamps_of_project_0, emittedOutputs);
                state.diagnostics.delete(projectPath);
                state.projectStatus.set(projectPath, {
                    type: 1 /* UpToDate */,
                    oldestOutputFileName
                });
                afterProgramDone(state, program, config);
                step = 7 /* QueueReferencingProjects */;
                buildResult = resultFlags;
                return emitDiagnostics;
            }
            function emitBundle(writeFileCallback, customTransformers) {
                var _a, _b, _c, _d;
                Debug.assert(kind === 1 /* UpdateBundle */);
                if (state.options.dry) {
                    reportStatus(state, Diagnostics.A_non_dry_build_would_update_output_of_project_0, project);
                    buildResult = 1 /* Success */;
                    step = 7 /* QueueReferencingProjects */;
                    return void 0;
                }
                if (state.options.verbose)
                    reportStatus(state, Diagnostics.Updating_output_of_project_0, project);
                const { compilerHost } = state;
                state.projectCompilerOptions = config.options;
                (_b = (_a = state.host).beforeEmitBundle) == null ? void 0 : _b.call(_a, config);
                const outputFiles = emitUsingBuildInfo(config, compilerHost, (ref) => {
                    const refName = resolveProjectName(state, ref.path);
                    return parseConfigFile(state, refName, toResolvedConfigFilePath(state, refName));
                }, customTransformers || ((_d = (_c = state.host).getCustomTransformers) == null ? void 0 : _d.call(_c, project)));
                if (isString(outputFiles)) {
                    reportStatus(state, Diagnostics.Cannot_update_output_of_project_0_because_there_was_error_reading_file_1, project, relName(state, outputFiles));
                    step = 6 /* BuildInvalidatedProjectOfBundle */;
                    return invalidatedProjectOfBundle = createBuildOrUpdateInvalidedProject(0 /* Build */, state, project, projectPath, projectIndex, config, buildOrder);
                }
                Debug.assert(!!outputFiles.length);
                const emitterDiagnostics = createDiagnosticCollection();
                const emittedOutputs = /* @__PURE__ */ new Map();
                let resultFlags = 2 /* DeclarationOutputUnchanged */;
                const existingBuildInfo = state.buildInfoCache.get(projectPath).buildInfo || void 0;
                outputFiles.forEach(({ name, text, writeByteOrderMark, data }) => {
                    var _a2, _b2;
                    emittedOutputs.set(toPath2(state, name), name);
                    if (data == null ? void 0 : data.buildInfo) {
                        if (((_a2 = data.buildInfo.program) == null ? void 0 : _a2.outSignature) !== ((_b2 = existingBuildInfo == null ? void 0 : existingBuildInfo.program) == null ? void 0 : _b2.outSignature)) {
                            resultFlags &= ~2 /* DeclarationOutputUnchanged */;
                        }
                        setBuildInfo(state, data.buildInfo, projectPath, config.options, resultFlags);
                    }
                    writeFile(writeFileCallback ? { writeFile: writeFileCallback } : compilerHost, emitterDiagnostics, name, text, writeByteOrderMark);
                });
                const emitDiagnostics = finishEmit(emitterDiagnostics, emittedOutputs, outputFiles[0].name, resultFlags);
                return { emitSkipped: false, diagnostics: emitDiagnostics };
            }
            function executeSteps(till, cancellationToken, writeFile2, customTransformers) {
                while (step <= till && step < 8 /* Done */) {
                    const currentStep = step;
                    switch (step) {
                        case 0 /* CreateProgram */:
                            createProgram2();
                            break;
                        case 1 /* SyntaxDiagnostics */:
                            getSyntaxDiagnostics(cancellationToken);
                            break;
                        case 2 /* SemanticDiagnostics */:
                            getSemanticDiagnostics(cancellationToken);
                            break;
                        case 3 /* Emit */:
                            emit(writeFile2, cancellationToken, customTransformers);
                            break;
                        case 5 /* EmitBuildInfo */:
                            emitBuildInfo(writeFile2, cancellationToken);
                            break;
                        case 4 /* EmitBundle */:
                            emitBundle(writeFile2, customTransformers);
                            break;
                        case 6 /* BuildInvalidatedProjectOfBundle */:
                            Debug.checkDefined(invalidatedProjectOfBundle).done(cancellationToken, writeFile2, customTransformers);
                            step = 8 /* Done */;
                            break;
                        case 7 /* QueueReferencingProjects */:
                            queueReferencingProjects(state, project, projectPath, projectIndex, config, buildOrder, Debug.checkDefined(buildResult));
                            step++;
                            break;
                        case 8 /* Done */:
                        default:
                            assertType(step);
                    }
                    Debug.assert(step > currentStep);
                }
            }
        }
        function needsBuild({ options }, status, config) {
            if (status.type !== 3 /* OutOfDateWithPrepend */ || options.force)
                return true;
            return config.fileNames.length === 0 || !!getConfigFileParsingDiagnostics(config).length || !isIncrementalCompilation(config.options);
        }
        function getNextInvalidatedProjectCreateInfo(state, buildOrder, reportQueue) {
            if (!state.projectPendingBuild.size)
                return void 0;
            if (isCircularBuildOrder(buildOrder))
                return void 0;
            const { options, projectPendingBuild } = state;
            for (let projectIndex = 0; projectIndex < buildOrder.length; projectIndex++) {
                const project = buildOrder[projectIndex];
                const projectPath = toResolvedConfigFilePath(state, project);
                const updateLevel = state.projectPendingBuild.get(projectPath);
                if (updateLevel === void 0)
                    continue;
                if (reportQueue) {
                    reportQueue = false;
                    reportBuildQueue(state, buildOrder);
                }
                const config = parseConfigFile(state, project, projectPath);
                if (!config) {
                    reportParseConfigFileDiagnostic(state, projectPath);
                    projectPendingBuild.delete(projectPath);
                    continue;
                }
                if (updateLevel === 2 /* Full */) {
                    watchConfigFile(state, project, projectPath, config);
                    watchExtendedConfigFiles(state, projectPath, config);
                    watchWildCardDirectories(state, project, projectPath, config);
                    watchInputFiles(state, project, projectPath, config);
                    watchPackageJsonFiles(state, project, projectPath, config);
                }
                else if (updateLevel === 1 /* RootNamesAndUpdate */) {
                    config.fileNames = getFileNamesFromConfigSpecs(config.options.configFile.configFileSpecs, getDirectoryPath(project), config.options, state.parseConfigFileHost);
                    updateErrorForNoInputFiles(config.fileNames, project, config.options.configFile.configFileSpecs, config.errors, canJsonReportNoInputFiles(config.raw));
                    watchInputFiles(state, project, projectPath, config);
                    watchPackageJsonFiles(state, project, projectPath, config);
                }
                const status = getUpToDateStatus(state, config, projectPath);
                if (!options.force) {
                    if (status.type === 1 /* UpToDate */) {
                        verboseReportProjectStatus(state, project, status);
                        reportAndStoreErrors(state, projectPath, getConfigFileParsingDiagnostics(config));
                        projectPendingBuild.delete(projectPath);
                        if (options.dry) {
                            reportStatus(state, Diagnostics.Project_0_is_up_to_date, project);
                        }
                        continue;
                    }
                    if (status.type === 2 /* UpToDateWithUpstreamTypes */ || status.type === 15 /* UpToDateWithInputFileText */) {
                        reportAndStoreErrors(state, projectPath, getConfigFileParsingDiagnostics(config));
                        return {
                            kind: 2 /* UpdateOutputFileStamps */,
                            status,
                            project,
                            projectPath,
                            projectIndex,
                            config
                        };
                    }
                }
                if (status.type === 12 /* UpstreamBlocked */) {
                    verboseReportProjectStatus(state, project, status);
                    reportAndStoreErrors(state, projectPath, getConfigFileParsingDiagnostics(config));
                    projectPendingBuild.delete(projectPath);
                    if (options.verbose) {
                        reportStatus(state, status.upstreamProjectBlocked ? Diagnostics.Skipping_build_of_project_0_because_its_dependency_1_was_not_built : Diagnostics.Skipping_build_of_project_0_because_its_dependency_1_has_errors, project, status.upstreamProjectName);
                    }
                    continue;
                }
                if (status.type === 16 /* ContainerOnly */) {
                    verboseReportProjectStatus(state, project, status);
                    reportAndStoreErrors(state, projectPath, getConfigFileParsingDiagnostics(config));
                    projectPendingBuild.delete(projectPath);
                    continue;
                }
                return {
                    kind: needsBuild(state, status, config) ? 0 /* Build */ : 1 /* UpdateBundle */,
                    status,
                    project,
                    projectPath,
                    projectIndex,
                    config
                };
            }
            return void 0;
        }
        function createInvalidatedProjectWithInfo(state, info, buildOrder) {
            verboseReportProjectStatus(state, info.project, info.status);
            return info.kind !== 2 /* UpdateOutputFileStamps */ ? createBuildOrUpdateInvalidedProject(info.kind, state, info.project, info.projectPath, info.projectIndex, info.config, buildOrder) : createUpdateOutputFileStampsProject(state, info.project, info.projectPath, info.config, buildOrder);
        }
        function getNextInvalidatedProject(state, buildOrder, reportQueue) {
            const info = getNextInvalidatedProjectCreateInfo(state, buildOrder, reportQueue);
            if (!info)
                return info;
            return createInvalidatedProjectWithInfo(state, info, buildOrder);
        }
        function listEmittedFile({ write }, proj, file) {
            if (write && proj.options.listEmittedFiles) {
                write(`TSFILE: ${file}`);
            }
        }
        function getOldProgram({ options, builderPrograms, compilerHost }, proj, parsed) {
            if (options.force)
                return void 0;
            const value = builderPrograms.get(proj);
            if (value)
                return value;
            return readBuilderProgram(parsed.options, compilerHost);
        }
        function afterProgramDone(state, program, config) {
            if (program) {
                if (state.write)
                    listFiles(program, state.write);
                if (state.host.afterProgramEmitAndDiagnostics) {
                    state.host.afterProgramEmitAndDiagnostics(program);
                }
                program.releaseProgram();
            }
            else if (state.host.afterEmitBundle) {
                state.host.afterEmitBundle(config);
            }
            state.projectCompilerOptions = state.baseCompilerOptions;
        }
        function buildErrors(state, resolvedPath, program, config, diagnostics, buildResult, errorType) {
            const canEmitBuildInfo = program && !outFile(program.getCompilerOptions());
            reportAndStoreErrors(state, resolvedPath, diagnostics);
            state.projectStatus.set(resolvedPath, { type: 0 /* Unbuildable */, reason: `${errorType} errors` });
            if (canEmitBuildInfo)
                return { buildResult, step: 5 /* EmitBuildInfo */ };
            afterProgramDone(state, program, config);
            return { buildResult, step: 7 /* QueueReferencingProjects */ };
        }
        function isFileWatcherWithModifiedTime(value) {
            return !!value.watcher;
        }
        function getModifiedTime2(state, fileName) {
            const path = toPath2(state, fileName);
            const existing = state.filesWatched.get(path);
            if (state.watch && !!existing) {
                if (!isFileWatcherWithModifiedTime(existing))
                    return existing;
                if (existing.modifiedTime)
                    return existing.modifiedTime;
            }
            const result = getModifiedTime(state.host, fileName);
            if (state.watch) {
                if (existing)
                    existing.modifiedTime = result;
                else
                    state.filesWatched.set(path, result);
            }
            return result;
        }
        function watchFile(state, file, callback, pollingInterval, options, watchType, project) {
            const path = toPath2(state, file);
            const existing = state.filesWatched.get(path);
            if (existing && isFileWatcherWithModifiedTime(existing)) {
                existing.callbacks.push(callback);
            }
            else {
                const watcher = state.watchFile(file, (fileName, eventKind, modifiedTime) => {
                    const existing2 = Debug.checkDefined(state.filesWatched.get(path));
                    Debug.assert(isFileWatcherWithModifiedTime(existing2));
                    existing2.modifiedTime = modifiedTime;
                    existing2.callbacks.forEach((cb) => cb(fileName, eventKind, modifiedTime));
                }, pollingInterval, options, watchType, project);
                state.filesWatched.set(path, { callbacks: [callback], watcher, modifiedTime: existing });
            }
            return {
                close: () => {
                    const existing2 = Debug.checkDefined(state.filesWatched.get(path));
                    Debug.assert(isFileWatcherWithModifiedTime(existing2));
                    if (existing2.callbacks.length === 1) {
                        state.filesWatched.delete(path);
                        closeFileWatcherOf(existing2);
                    }
                    else {
                        unorderedRemoveItem(existing2.callbacks, callback);
                    }
                }
            };
        }
        function getOutputTimeStampMap(state, resolvedConfigFilePath) {
            if (!state.watch)
                return void 0;
            let result = state.outputTimeStamps.get(resolvedConfigFilePath);
            if (!result)
                state.outputTimeStamps.set(resolvedConfigFilePath, result = /* @__PURE__ */ new Map());
            return result;
        }
        function setBuildInfo(state, buildInfo, resolvedConfigPath, options, resultFlags) {
            const buildInfoPath = getTsBuildInfoEmitOutputFilePath(options);
            const existing = getBuildInfoCacheEntry(state, buildInfoPath, resolvedConfigPath);
            const modifiedTime = getCurrentTime(state.host);
            if (existing) {
                existing.buildInfo = buildInfo;
                existing.modifiedTime = modifiedTime;
                if (!(resultFlags & 2 /* DeclarationOutputUnchanged */))
                    existing.latestChangedDtsTime = modifiedTime;
            }
            else {
                state.buildInfoCache.set(resolvedConfigPath, {
                    path: toPath2(state, buildInfoPath),
                    buildInfo,
                    modifiedTime,
                    latestChangedDtsTime: resultFlags & 2 /* DeclarationOutputUnchanged */ ? void 0 : modifiedTime
                });
            }
        }
        function getBuildInfoCacheEntry(state, buildInfoPath, resolvedConfigPath) {
            const path = toPath2(state, buildInfoPath);
            const existing = state.buildInfoCache.get(resolvedConfigPath);
            return (existing == null ? void 0 : existing.path) === path ? existing : void 0;
        }
        function getBuildInfo3(state, buildInfoPath, resolvedConfigPath, modifiedTime) {
            const path = toPath2(state, buildInfoPath);
            const existing = state.buildInfoCache.get(resolvedConfigPath);
            if (existing !== void 0 && existing.path === path) {
                return existing.buildInfo || void 0;
            }
            const value = state.readFileWithCache(buildInfoPath);
            const buildInfo = value ? getBuildInfo(buildInfoPath, value) : void 0;
            state.buildInfoCache.set(resolvedConfigPath, { path, buildInfo: buildInfo || false, modifiedTime: modifiedTime || missingFileModifiedTime });
            return buildInfo;
        }
        function checkConfigFileUpToDateStatus(state, configFile, oldestOutputFileTime, oldestOutputFileName) {
            const tsconfigTime = getModifiedTime2(state, configFile);
            if (oldestOutputFileTime < tsconfigTime) {
                return {
                    type: 6 /* OutOfDateWithSelf */,
                    outOfDateOutputFileName: oldestOutputFileName,
                    newerInputFileName: configFile
                };
            }
        }
        function getUpToDateStatusWorker(state, project, resolvedPath) {
            var _a, _b, _c;
            if (!project.fileNames.length && !canJsonReportNoInputFiles(project.raw)) {
                return {
                    type: 16 /* ContainerOnly */
                };
            }
            let referenceStatuses;
            const force = !!state.options.force;
            if (project.projectReferences) {
                state.projectStatus.set(resolvedPath, { type: 13 /* ComputingUpstream */ });
                for (const ref of project.projectReferences) {
                    const resolvedRef = resolveProjectReferencePath(ref);
                    const resolvedRefPath = toResolvedConfigFilePath(state, resolvedRef);
                    const resolvedConfig = parseConfigFile(state, resolvedRef, resolvedRefPath);
                    const refStatus = getUpToDateStatus(state, resolvedConfig, resolvedRefPath);
                    if (refStatus.type === 13 /* ComputingUpstream */ || refStatus.type === 16 /* ContainerOnly */) {
                        continue;
                    }
                    if (refStatus.type === 0 /* Unbuildable */ || refStatus.type === 12 /* UpstreamBlocked */) {
                        return {
                            type: 12 /* UpstreamBlocked */,
                            upstreamProjectName: ref.path,
                            upstreamProjectBlocked: refStatus.type === 12 /* UpstreamBlocked */
                        };
                    }
                    if (refStatus.type !== 1 /* UpToDate */) {
                        return {
                            type: 11 /* UpstreamOutOfDate */,
                            upstreamProjectName: ref.path
                        };
                    }
                    if (!force)
                        (referenceStatuses || (referenceStatuses = [])).push({ ref, refStatus, resolvedRefPath, resolvedConfig });
                }
            }
            if (force)
                return { type: 17 /* ForceBuild */ };
            const { host } = state;
            const buildInfoPath = getTsBuildInfoEmitOutputFilePath(project.options);
            let oldestOutputFileName;
            let oldestOutputFileTime = maximumDate;
            let buildInfoTime;
            let buildInfoProgram;
            let buildInfoVersionMap;
            if (buildInfoPath) {
                const buildInfoCacheEntry2 = getBuildInfoCacheEntry(state, buildInfoPath, resolvedPath);
                buildInfoTime = (buildInfoCacheEntry2 == null ? void 0 : buildInfoCacheEntry2.modifiedTime) || getModifiedTime(host, buildInfoPath);
                if (buildInfoTime === missingFileModifiedTime) {
                    if (!buildInfoCacheEntry2) {
                        state.buildInfoCache.set(resolvedPath, {
                            path: toPath2(state, buildInfoPath),
                            buildInfo: false,
                            modifiedTime: buildInfoTime
                        });
                    }
                    return {
                        type: 4 /* OutputMissing */,
                        missingOutputFileName: buildInfoPath
                    };
                }
                const buildInfo = getBuildInfo3(state, buildInfoPath, resolvedPath, buildInfoTime);
                if (!buildInfo) {
                    return {
                        type: 5 /* ErrorReadingFile */,
                        fileName: buildInfoPath
                    };
                }
                if ((buildInfo.bundle || buildInfo.program) && buildInfo.version !== version) {
                    return {
                        type: 14 /* TsVersionOutputOfDate */,
                        version: buildInfo.version
                    };
                }
                if (buildInfo.program) {
                    if (((_a = buildInfo.program.changeFileSet) == null ? void 0 : _a.length) || (!project.options.noEmit ? ((_b = buildInfo.program.affectedFilesPendingEmit) == null ? void 0 : _b.length) || ((_c = buildInfo.program.emitDiagnosticsPerFile) == null ? void 0 : _c.length) : some(buildInfo.program.semanticDiagnosticsPerFile, isArray))) {
                        return {
                            type: 8 /* OutOfDateBuildInfo */,
                            buildInfoFile: buildInfoPath
                        };
                    }
                    if (!project.options.noEmit && getPendingEmitKind(project.options, buildInfo.program.options || {})) {
                        return {
                            type: 9 /* OutOfDateOptions */,
                            buildInfoFile: buildInfoPath
                        };
                    }
                    buildInfoProgram = buildInfo.program;
                }
                oldestOutputFileTime = buildInfoTime;
                oldestOutputFileName = buildInfoPath;
            }
            let newestInputFileName = void 0;
            let newestInputFileTime = minimumDate;
            let pseudoInputUpToDate = false;
            const seenRoots = /* @__PURE__ */ new Set();
            for (const inputFile of project.fileNames) {
                const inputTime = getModifiedTime2(state, inputFile);
                if (inputTime === missingFileModifiedTime) {
                    return {
                        type: 0 /* Unbuildable */,
                        reason: `${inputFile} does not exist`
                    };
                }
                if (buildInfoTime && buildInfoTime < inputTime) {
                    let version2;
                    let currentVersion;
                    if (buildInfoProgram) {
                        if (!buildInfoVersionMap)
                            buildInfoVersionMap = getBuildInfoFileVersionMap(buildInfoProgram, buildInfoPath, host);
                        version2 = buildInfoVersionMap.fileInfos.get(toPath2(state, inputFile));
                        const text = version2 ? state.readFileWithCache(inputFile) : void 0;
                        currentVersion = text !== void 0 ? getSourceFileVersionAsHashFromText(host, text) : void 0;
                        if (version2 && version2 === currentVersion)
                            pseudoInputUpToDate = true;
                    }
                    if (!version2 || version2 !== currentVersion) {
                        return {
                            type: 6 /* OutOfDateWithSelf */,
                            outOfDateOutputFileName: buildInfoPath,
                            newerInputFileName: inputFile
                        };
                    }
                }
                if (inputTime > newestInputFileTime) {
                    newestInputFileName = inputFile;
                    newestInputFileTime = inputTime;
                }
                if (buildInfoProgram)
                    seenRoots.add(toPath2(state, inputFile));
            }
            if (buildInfoProgram) {
                if (!buildInfoVersionMap)
                    buildInfoVersionMap = getBuildInfoFileVersionMap(buildInfoProgram, buildInfoPath, host);
                for (const existingRoot of buildInfoVersionMap.roots) {
                    if (!seenRoots.has(existingRoot)) {
                        return {
                            type: 10 /* OutOfDateRoots */,
                            buildInfoFile: buildInfoPath,
                            inputFile: existingRoot
                        };
                    }
                }
            }
            if (!buildInfoPath) {
                const outputs = getAllProjectOutputs(project, !host.useCaseSensitiveFileNames());
                const outputTimeStampMap = getOutputTimeStampMap(state, resolvedPath);
                for (const output of outputs) {
                    const path = toPath2(state, output);
                    let outputTime = outputTimeStampMap == null ? void 0 : outputTimeStampMap.get(path);
                    if (!outputTime) {
                        outputTime = getModifiedTime(state.host, output);
                        outputTimeStampMap == null ? void 0 : outputTimeStampMap.set(path, outputTime);
                    }
                    if (outputTime === missingFileModifiedTime) {
                        return {
                            type: 4 /* OutputMissing */,
                            missingOutputFileName: output
                        };
                    }
                    if (outputTime < newestInputFileTime) {
                        return {
                            type: 6 /* OutOfDateWithSelf */,
                            outOfDateOutputFileName: output,
                            newerInputFileName: newestInputFileName
                        };
                    }
                    if (outputTime < oldestOutputFileTime) {
                        oldestOutputFileTime = outputTime;
                        oldestOutputFileName = output;
                    }
                }
            }
            const buildInfoCacheEntry = state.buildInfoCache.get(resolvedPath);
            let pseudoUpToDate = false;
            let usesPrepend = false;
            let upstreamChangedProject;
            if (referenceStatuses) {
                for (const { ref, refStatus, resolvedConfig, resolvedRefPath } of referenceStatuses) {
                    usesPrepend = usesPrepend || !!ref.prepend;
                    if (refStatus.newestInputFileTime && refStatus.newestInputFileTime <= oldestOutputFileTime) {
                        continue;
                    }
                    if (buildInfoCacheEntry && hasSameBuildInfo(state, buildInfoCacheEntry, resolvedRefPath)) {
                        return {
                            type: 7 /* OutOfDateWithUpstream */,
                            outOfDateOutputFileName: buildInfoPath,
                            newerProjectName: ref.path
                        };
                    }
                    const newestDeclarationFileContentChangedTime = getLatestChangedDtsTime(state, resolvedConfig.options, resolvedRefPath);
                    if (newestDeclarationFileContentChangedTime && newestDeclarationFileContentChangedTime <= oldestOutputFileTime) {
                        pseudoUpToDate = true;
                        upstreamChangedProject = ref.path;
                        continue;
                    }
                    Debug.assert(oldestOutputFileName !== void 0, "Should have an oldest output filename here");
                    return {
                        type: 7 /* OutOfDateWithUpstream */,
                        outOfDateOutputFileName: oldestOutputFileName,
                        newerProjectName: ref.path
                    };
                }
            }
            const configStatus = checkConfigFileUpToDateStatus(state, project.options.configFilePath, oldestOutputFileTime, oldestOutputFileName);
            if (configStatus)
                return configStatus;
            const extendedConfigStatus = forEach(project.options.configFile.extendedSourceFiles || emptyArray, (configFile) => checkConfigFileUpToDateStatus(state, configFile, oldestOutputFileTime, oldestOutputFileName));
            if (extendedConfigStatus)
                return extendedConfigStatus;
            const packageJsonLookups = state.lastCachedPackageJsonLookups.get(resolvedPath);
            const dependentPackageFileStatus = packageJsonLookups && forEachKey(packageJsonLookups, (path) => checkConfigFileUpToDateStatus(state, path, oldestOutputFileTime, oldestOutputFileName));
            if (dependentPackageFileStatus)
                return dependentPackageFileStatus;
            if (usesPrepend && pseudoUpToDate) {
                return {
                    type: 3 /* OutOfDateWithPrepend */,
                    outOfDateOutputFileName: oldestOutputFileName,
                    newerProjectName: upstreamChangedProject
                };
            }
            return {
                type: pseudoUpToDate ? 2 /* UpToDateWithUpstreamTypes */ : pseudoInputUpToDate ? 15 /* UpToDateWithInputFileText */ : 1 /* UpToDate */,
                newestInputFileTime,
                newestInputFileName,
                oldestOutputFileName
            };
        }
        function hasSameBuildInfo(state, buildInfoCacheEntry, resolvedRefPath) {
            const refBuildInfo = state.buildInfoCache.get(resolvedRefPath);
            return refBuildInfo.path === buildInfoCacheEntry.path;
        }
        function getUpToDateStatus(state, project, resolvedPath) {
            if (project === void 0) {
                return { type: 0 /* Unbuildable */, reason: "File deleted mid-build" };
            }
            const prior = state.projectStatus.get(resolvedPath);
            if (prior !== void 0) {
                return prior;
            }
            mark("SolutionBuilder::beforeUpToDateCheck");
            const actual = getUpToDateStatusWorker(state, project, resolvedPath);
            mark("SolutionBuilder::afterUpToDateCheck");
            measure("SolutionBuilder::Up-to-date check", "SolutionBuilder::beforeUpToDateCheck", "SolutionBuilder::afterUpToDateCheck");
            state.projectStatus.set(resolvedPath, actual);
            return actual;
        }
        function updateOutputTimestampsWorker(state, proj, projectPath, verboseMessage, skipOutputs) {
            if (proj.options.noEmit)
                return;
            let now;
            const buildInfoPath = getTsBuildInfoEmitOutputFilePath(proj.options);
            if (buildInfoPath) {
                if (!(skipOutputs == null ? void 0 : skipOutputs.has(toPath2(state, buildInfoPath)))) {
                    if (!!state.options.verbose)
                        reportStatus(state, verboseMessage, proj.options.configFilePath);
                    state.host.setModifiedTime(buildInfoPath, now = getCurrentTime(state.host));
                    getBuildInfoCacheEntry(state, buildInfoPath, projectPath).modifiedTime = now;
                }
                state.outputTimeStamps.delete(projectPath);
                return;
            }
            const { host } = state;
            const outputs = getAllProjectOutputs(proj, !host.useCaseSensitiveFileNames());
            const outputTimeStampMap = getOutputTimeStampMap(state, projectPath);
            const modifiedOutputs = outputTimeStampMap ? /* @__PURE__ */ new Set() : void 0;
            if (!skipOutputs || outputs.length !== skipOutputs.size) {
                let reportVerbose = !!state.options.verbose;
                for (const file of outputs) {
                    const path = toPath2(state, file);
                    if (skipOutputs == null ? void 0 : skipOutputs.has(path))
                        continue;
                    if (reportVerbose) {
                        reportVerbose = false;
                        reportStatus(state, verboseMessage, proj.options.configFilePath);
                    }
                    host.setModifiedTime(file, now || (now = getCurrentTime(state.host)));
                    if (outputTimeStampMap) {
                        outputTimeStampMap.set(path, now);
                        modifiedOutputs.add(path);
                    }
                }
            }
            outputTimeStampMap == null ? void 0 : outputTimeStampMap.forEach((_value, key) => {
                if (!(skipOutputs == null ? void 0 : skipOutputs.has(key)) && !modifiedOutputs.has(key))
                    outputTimeStampMap.delete(key);
            });
        }
        function getLatestChangedDtsTime(state, options, resolvedConfigPath) {
            if (!options.composite)
                return void 0;
            const entry = Debug.checkDefined(state.buildInfoCache.get(resolvedConfigPath));
            if (entry.latestChangedDtsTime !== void 0)
                return entry.latestChangedDtsTime || void 0;
            const latestChangedDtsTime = entry.buildInfo && entry.buildInfo.program && entry.buildInfo.program.latestChangedDtsFile ? state.host.getModifiedTime(getNormalizedAbsolutePath(entry.buildInfo.program.latestChangedDtsFile, getDirectoryPath(entry.path))) : void 0;
            entry.latestChangedDtsTime = latestChangedDtsTime || false;
            return latestChangedDtsTime;
        }
        function updateOutputTimestamps(state, proj, resolvedPath) {
            if (state.options.dry) {
                return reportStatus(state, Diagnostics.A_non_dry_build_would_update_timestamps_for_output_of_project_0, proj.options.configFilePath);
            }
            updateOutputTimestampsWorker(state, proj, resolvedPath, Diagnostics.Updating_output_timestamps_of_project_0);
            state.projectStatus.set(resolvedPath, {
                type: 1 /* UpToDate */,
                oldestOutputFileName: getFirstProjectOutput(proj, !state.host.useCaseSensitiveFileNames())
            });
        }
        function queueReferencingProjects(state, project, projectPath, projectIndex, config, buildOrder, buildResult) {
            if (buildResult & 124 /* AnyErrors */)
                return;
            if (!config.options.composite)
                return;
            for (let index = projectIndex + 1; index < buildOrder.length; index++) {
                const nextProject = buildOrder[index];
                const nextProjectPath = toResolvedConfigFilePath(state, nextProject);
                if (state.projectPendingBuild.has(nextProjectPath))
                    continue;
                const nextProjectConfig = parseConfigFile(state, nextProject, nextProjectPath);
                if (!nextProjectConfig || !nextProjectConfig.projectReferences)
                    continue;
                for (const ref of nextProjectConfig.projectReferences) {
                    const resolvedRefPath = resolveProjectName(state, ref.path);
                    if (toResolvedConfigFilePath(state, resolvedRefPath) !== projectPath)
                        continue;
                    const status = state.projectStatus.get(nextProjectPath);
                    if (status) {
                        switch (status.type) {
                            case 1 /* UpToDate */:
                                if (buildResult & 2 /* DeclarationOutputUnchanged */) {
                                    if (ref.prepend) {
                                        state.projectStatus.set(nextProjectPath, {
                                            type: 3 /* OutOfDateWithPrepend */,
                                            outOfDateOutputFileName: status.oldestOutputFileName,
                                            newerProjectName: project
                                        });
                                    }
                                    else {
                                        status.type = 2 /* UpToDateWithUpstreamTypes */;
                                    }
                                    break;
                                }
                            case 15 /* UpToDateWithInputFileText */:
                            case 2 /* UpToDateWithUpstreamTypes */:
                            case 3 /* OutOfDateWithPrepend */:
                                if (!(buildResult & 2 /* DeclarationOutputUnchanged */)) {
                                    state.projectStatus.set(nextProjectPath, {
                                        type: 7 /* OutOfDateWithUpstream */,
                                        outOfDateOutputFileName: status.type === 3 /* OutOfDateWithPrepend */ ? status.outOfDateOutputFileName : status.oldestOutputFileName,
                                        newerProjectName: project
                                    });
                                }
                                break;
                            case 12 /* UpstreamBlocked */:
                                if (toResolvedConfigFilePath(state, resolveProjectName(state, status.upstreamProjectName)) === projectPath) {
                                    clearProjectStatus(state, nextProjectPath);
                                }
                                break;
                        }
                    }
                    addProjToQueue(state, nextProjectPath, 0 /* Update */);
                    break;
                }
            }
        }
        function build(state, project, cancellationToken, writeFile2, getCustomTransformers, onlyReferences) {
            mark("SolutionBuilder::beforeBuild");
            const result = buildWorker(state, project, cancellationToken, writeFile2, getCustomTransformers, onlyReferences);
            mark("SolutionBuilder::afterBuild");
            measure("SolutionBuilder::Build", "SolutionBuilder::beforeBuild", "SolutionBuilder::afterBuild");
            return result;
        }
        function buildWorker(state, project, cancellationToken, writeFile2, getCustomTransformers, onlyReferences) {
            const buildOrder = getBuildOrderFor(state, project, onlyReferences);
            if (!buildOrder)
                return 3 /* InvalidProject_OutputsSkipped */;
            setupInitialBuild(state, cancellationToken);
            let reportQueue = true;
            let successfulProjects = 0;
            while (true) {
                const invalidatedProject = getNextInvalidatedProject(state, buildOrder, reportQueue);
                if (!invalidatedProject)
                    break;
                reportQueue = false;
                invalidatedProject.done(cancellationToken, writeFile2, getCustomTransformers == null ? void 0 : getCustomTransformers(invalidatedProject.project));
                if (!state.diagnostics.has(invalidatedProject.projectPath))
                    successfulProjects++;
            }
            disableCache(state);
            reportErrorSummary(state, buildOrder);
            startWatching(state, buildOrder);
            return isCircularBuildOrder(buildOrder) ? 4 /* ProjectReferenceCycle_OutputsSkipped */ : !buildOrder.some((p) => state.diagnostics.has(toResolvedConfigFilePath(state, p))) ? 0 /* Success */ : successfulProjects ? 2 /* DiagnosticsPresent_OutputsGenerated */ : 1 /* DiagnosticsPresent_OutputsSkipped */;
        }
        function clean(state, project, onlyReferences) {
            mark("SolutionBuilder::beforeClean");
            const result = cleanWorker(state, project, onlyReferences);
            mark("SolutionBuilder::afterClean");
            measure("SolutionBuilder::Clean", "SolutionBuilder::beforeClean", "SolutionBuilder::afterClean");
            return result;
        }
        function cleanWorker(state, project, onlyReferences) {
            const buildOrder = getBuildOrderFor(state, project, onlyReferences);
            if (!buildOrder)
                return 3 /* InvalidProject_OutputsSkipped */;
            if (isCircularBuildOrder(buildOrder)) {
                reportErrors(state, buildOrder.circularDiagnostics);
                return 4 /* ProjectReferenceCycle_OutputsSkipped */;
            }
            const { options, host } = state;
            const filesToDelete = options.dry ? [] : void 0;
            for (const proj of buildOrder) {
                const resolvedPath = toResolvedConfigFilePath(state, proj);
                const parsed = parseConfigFile(state, proj, resolvedPath);
                if (parsed === void 0) {
                    reportParseConfigFileDiagnostic(state, resolvedPath);
                    continue;
                }
                const outputs = getAllProjectOutputs(parsed, !host.useCaseSensitiveFileNames());
                if (!outputs.length)
                    continue;
                const inputFileNames = new Set(parsed.fileNames.map((f) => toPath2(state, f)));
                for (const output of outputs) {
                    if (inputFileNames.has(toPath2(state, output)))
                        continue;
                    if (host.fileExists(output)) {
                        if (filesToDelete) {
                            filesToDelete.push(output);
                        }
                        else {
                            host.deleteFile(output);
                            invalidateProject(state, resolvedPath, 0 /* Update */);
                        }
                    }
                }
            }
            if (filesToDelete) {
                reportStatus(state, Diagnostics.A_non_dry_build_would_delete_the_following_files_Colon_0, filesToDelete.map((f) => `\r
 * ${f}`).join(""));
            }
            return 0 /* Success */;
        }
        function invalidateProject(state, resolved, updateLevel) {
            if (state.host.getParsedCommandLine && updateLevel === 1 /* RootNamesAndUpdate */) {
                updateLevel = 2 /* Full */;
            }
            if (updateLevel === 2 /* Full */) {
                state.configFileCache.delete(resolved);
                state.buildOrder = void 0;
            }
            state.needsSummary = true;
            clearProjectStatus(state, resolved);
            addProjToQueue(state, resolved, updateLevel);
            enableCache(state);
        }
        function invalidateProjectAndScheduleBuilds(state, resolvedPath, updateLevel) {
            state.reportFileChangeDetected = true;
            invalidateProject(state, resolvedPath, updateLevel);
            scheduleBuildInvalidatedProject(state, 250, 
            /*changeDetected*/
            true);
        }
        function scheduleBuildInvalidatedProject(state, time, changeDetected) {
            const { hostWithWatch } = state;
            if (!hostWithWatch.setTimeout || !hostWithWatch.clearTimeout) {
                return;
            }
            if (state.timerToBuildInvalidatedProject) {
                hostWithWatch.clearTimeout(state.timerToBuildInvalidatedProject);
            }
            state.timerToBuildInvalidatedProject = hostWithWatch.setTimeout(buildNextInvalidatedProject, time, "timerToBuildInvalidatedProject", state, changeDetected);
        }
        function buildNextInvalidatedProject(_timeoutType, state, changeDetected) {
            mark("SolutionBuilder::beforeBuild");
            const buildOrder = buildNextInvalidatedProjectWorker(state, changeDetected);
            mark("SolutionBuilder::afterBuild");
            measure("SolutionBuilder::Build", "SolutionBuilder::beforeBuild", "SolutionBuilder::afterBuild");
            if (buildOrder)
                reportErrorSummary(state, buildOrder);
        }
        function buildNextInvalidatedProjectWorker(state, changeDetected) {
            state.timerToBuildInvalidatedProject = void 0;
            if (state.reportFileChangeDetected) {
                state.reportFileChangeDetected = false;
                state.projectErrorsReported.clear();
                reportWatchStatus(state, Diagnostics.File_change_detected_Starting_incremental_compilation);
            }
            let projectsBuilt = 0;
            const buildOrder = getBuildOrder(state);
            const invalidatedProject = getNextInvalidatedProject(state, buildOrder, 
            /*reportQueue*/
            false);
            if (invalidatedProject) {
                invalidatedProject.done();
                projectsBuilt++;
                while (state.projectPendingBuild.size) {
                    if (state.timerToBuildInvalidatedProject)
                        return;
                    const info = getNextInvalidatedProjectCreateInfo(state, buildOrder, 
                    /*reportQueue*/
                    false);
                    if (!info)
                        break;
                    if (info.kind !== 2 /* UpdateOutputFileStamps */ && (changeDetected || projectsBuilt === 5)) {
                        scheduleBuildInvalidatedProject(state, 100, 
                        /*changeDetected*/
                        false);
                        return;
                    }
                    const project = createInvalidatedProjectWithInfo(state, info, buildOrder);
                    project.done();
                    if (info.kind !== 2 /* UpdateOutputFileStamps */)
                        projectsBuilt++;
                }
            }
            disableCache(state);
            return buildOrder;
        }
        function watchConfigFile(state, resolved, resolvedPath, parsed) {
            if (!state.watch || state.allWatchedConfigFiles.has(resolvedPath))
                return;
            state.allWatchedConfigFiles.set(resolvedPath, watchFile(state, resolved, () => invalidateProjectAndScheduleBuilds(state, resolvedPath, 2 /* Full */), 2e3 /* High */, parsed == null ? void 0 : parsed.watchOptions, WatchType.ConfigFile, resolved));
        }
        function watchExtendedConfigFiles(state, resolvedPath, parsed) {
            updateSharedExtendedConfigFileWatcher(resolvedPath, parsed == null ? void 0 : parsed.options, state.allWatchedExtendedConfigFiles, (extendedConfigFileName, extendedConfigFilePath) => watchFile(state, extendedConfigFileName, () => {
                var _a;
                return (_a = state.allWatchedExtendedConfigFiles.get(extendedConfigFilePath)) == null ? void 0 : _a.projects.forEach((projectConfigFilePath) => invalidateProjectAndScheduleBuilds(state, projectConfigFilePath, 2 /* Full */));
            }, 2e3 /* High */, parsed == null ? void 0 : parsed.watchOptions, WatchType.ExtendedConfigFile), (fileName) => toPath2(state, fileName));
        }
        function watchWildCardDirectories(state, resolved, resolvedPath, parsed) {
            if (!state.watch)
                return;
            updateWatchingWildcardDirectories(getOrCreateValueMapFromConfigFileMap(state.allWatchedWildcardDirectories, resolvedPath), parsed.wildcardDirectories, (dir, flags) => state.watchDirectory(dir, (fileOrDirectory) => {
                var _a;
                if (isIgnoredFileFromWildCardWatching({
                    watchedDirPath: toPath2(state, dir),
                    fileOrDirectory,
                    fileOrDirectoryPath: toPath2(state, fileOrDirectory),
                    configFileName: resolved,
                    currentDirectory: state.compilerHost.getCurrentDirectory(),
                    options: parsed.options,
                    program: state.builderPrograms.get(resolvedPath) || ((_a = getCachedParsedConfigFile(state, resolvedPath)) == null ? void 0 : _a.fileNames),
                    useCaseSensitiveFileNames: state.parseConfigFileHost.useCaseSensitiveFileNames,
                    writeLog: (s) => state.writeLog(s),
                    toPath: (fileName) => toPath2(state, fileName)
                }))
                    return;
                invalidateProjectAndScheduleBuilds(state, resolvedPath, 1 /* RootNamesAndUpdate */);
            }, flags, parsed == null ? void 0 : parsed.watchOptions, WatchType.WildcardDirectory, resolved));
        }
        function watchInputFiles(state, resolved, resolvedPath, parsed) {
            if (!state.watch)
                return;
            mutateMap(getOrCreateValueMapFromConfigFileMap(state.allWatchedInputFiles, resolvedPath), new Set(parsed.fileNames), {
                createNewValue: (input) => watchFile(state, input, () => invalidateProjectAndScheduleBuilds(state, resolvedPath, 0 /* Update */), 250 /* Low */, parsed == null ? void 0 : parsed.watchOptions, WatchType.SourceFile, resolved),
                onDeleteValue: closeFileWatcher
            });
        }
        function watchPackageJsonFiles(state, resolved, resolvedPath, parsed) {
            if (!state.watch || !state.lastCachedPackageJsonLookups)
                return;
            mutateMap(getOrCreateValueMapFromConfigFileMap(state.allWatchedPackageJsonFiles, resolvedPath), state.lastCachedPackageJsonLookups.get(resolvedPath), {
                createNewValue: (input) => watchFile(state, input, () => invalidateProjectAndScheduleBuilds(state, resolvedPath, 0 /* Update */), 2e3 /* High */, parsed == null ? void 0 : parsed.watchOptions, WatchType.PackageJson, resolved),
                onDeleteValue: closeFileWatcher
            });
        }
        function startWatching(state, buildOrder) {
            if (!state.watchAllProjectsPending)
                return;
            mark("SolutionBuilder::beforeWatcherCreation");
            state.watchAllProjectsPending = false;
            for (const resolved of getBuildOrderFromAnyBuildOrder(buildOrder)) {
                const resolvedPath = toResolvedConfigFilePath(state, resolved);
                const cfg = parseConfigFile(state, resolved, resolvedPath);
                watchConfigFile(state, resolved, resolvedPath, cfg);
                watchExtendedConfigFiles(state, resolvedPath, cfg);
                if (cfg) {
                    watchWildCardDirectories(state, resolved, resolvedPath, cfg);
                    watchInputFiles(state, resolved, resolvedPath, cfg);
                    watchPackageJsonFiles(state, resolved, resolvedPath, cfg);
                }
            }
            mark("SolutionBuilder::afterWatcherCreation");
            measure("SolutionBuilder::Watcher creation", "SolutionBuilder::beforeWatcherCreation", "SolutionBuilder::afterWatcherCreation");
        }
        function stopWatching(state) {
            clearMap(state.allWatchedConfigFiles, closeFileWatcher);
            clearMap(state.allWatchedExtendedConfigFiles, closeFileWatcherOf);
            clearMap(state.allWatchedWildcardDirectories, (watchedWildcardDirectories) => clearMap(watchedWildcardDirectories, closeFileWatcherOf));
            clearMap(state.allWatchedInputFiles, (watchedWildcardDirectories) => clearMap(watchedWildcardDirectories, closeFileWatcher));
            clearMap(state.allWatchedPackageJsonFiles, (watchedPacageJsonFiles) => clearMap(watchedPacageJsonFiles, closeFileWatcher));
        }
        function createSolutionBuilderWorker(watch, hostOrHostWithWatch, rootNames, options, baseWatchOptions) {
            const state = createSolutionBuilderState(watch, hostOrHostWithWatch, rootNames, options, baseWatchOptions);
            return {
                build: (project, cancellationToken, writeFile2, getCustomTransformers) => build(state, project, cancellationToken, writeFile2, getCustomTransformers),
                clean: (project) => clean(state, project),
                buildReferences: (project, cancellationToken, writeFile2, getCustomTransformers) => build(state, project, cancellationToken, writeFile2, getCustomTransformers, 
                /*onlyReferences*/
                true),
                cleanReferences: (project) => clean(state, project, 
                /*onlyReferences*/
                true),
                getNextInvalidatedProject: (cancellationToken) => {
                    setupInitialBuild(state, cancellationToken);
                    return getNextInvalidatedProject(state, getBuildOrder(state), 
                    /*reportQueue*/
                    false);
                },
                getBuildOrder: () => getBuildOrder(state),
                getUpToDateStatusOfProject: (project) => {
                    const configFileName = resolveProjectName(state, project);
                    const configFilePath = toResolvedConfigFilePath(state, configFileName);
                    return getUpToDateStatus(state, parseConfigFile(state, configFileName, configFilePath), configFilePath);
                },
                invalidateProject: (configFilePath, updateLevel) => invalidateProject(state, configFilePath, updateLevel || 0 /* Update */),
                close: () => stopWatching(state)
            };
        }
        function relName(state, path) {
            return convertToRelativePath(path, state.compilerHost.getCurrentDirectory(), state.compilerHost.getCanonicalFileName);
        }
        function reportStatus(state, message, ...args) {
            state.host.reportSolutionBuilderStatus(createCompilerDiagnostic(message, ...args));
        }
        function reportWatchStatus(state, message, ...args) {
            var _a, _b;
            (_b = (_a = state.hostWithWatch).onWatchStatusChange) == null ? void 0 : _b.call(_a, createCompilerDiagnostic(message, ...args), state.host.getNewLine(), state.baseCompilerOptions);
        }
        function reportErrors({ host }, errors) {
            errors.forEach((err) => host.reportDiagnostic(err));
        }
        function reportAndStoreErrors(state, proj, errors) {
            reportErrors(state, errors);
            state.projectErrorsReported.set(proj, true);
            if (errors.length) {
                state.diagnostics.set(proj, errors);
            }
        }
        function reportParseConfigFileDiagnostic(state, proj) {
            reportAndStoreErrors(state, proj, [state.configFileCache.get(proj)]);
        }
        function reportErrorSummary(state, buildOrder) {
            if (!state.needsSummary)
                return;
            state.needsSummary = false;
            const canReportSummary = state.watch || !!state.host.reportErrorSummary;
            const { diagnostics } = state;
            let totalErrors = 0;
            let filesInError = [];
            if (isCircularBuildOrder(buildOrder)) {
                reportBuildQueue(state, buildOrder.buildOrder);
                reportErrors(state, buildOrder.circularDiagnostics);
                if (canReportSummary)
                    totalErrors += getErrorCountForSummary(buildOrder.circularDiagnostics);
                if (canReportSummary)
                    filesInError = [...filesInError, ...getFilesInErrorForSummary(buildOrder.circularDiagnostics)];
            }
            else {
                buildOrder.forEach((project) => {
                    const projectPath = toResolvedConfigFilePath(state, project);
                    if (!state.projectErrorsReported.has(projectPath)) {
                        reportErrors(state, diagnostics.get(projectPath) || emptyArray);
                    }
                });
                if (canReportSummary)
                    diagnostics.forEach((singleProjectErrors) => totalErrors += getErrorCountForSummary(singleProjectErrors));
                if (canReportSummary)
                    diagnostics.forEach((singleProjectErrors) => [...filesInError, ...getFilesInErrorForSummary(singleProjectErrors)]);
            }
            if (state.watch) {
                reportWatchStatus(state, getWatchErrorSummaryDiagnosticMessage(totalErrors), totalErrors);
            }
            else if (state.host.reportErrorSummary) {
                state.host.reportErrorSummary(totalErrors, filesInError);
            }
        }
        function reportBuildQueue(state, buildQueue) {
            if (state.options.verbose) {
                reportStatus(state, Diagnostics.Projects_in_this_build_Colon_0, buildQueue.map((s) => "\r\n    * " + relName(state, s)).join(""));
            }
        }
        function reportUpToDateStatus(state, configFileName, status) {
            switch (status.type) {
                case 6 /* OutOfDateWithSelf */:
                    return reportStatus(state, Diagnostics.Project_0_is_out_of_date_because_output_1_is_older_than_input_2, relName(state, configFileName), relName(state, status.outOfDateOutputFileName), relName(state, status.newerInputFileName));
                case 7 /* OutOfDateWithUpstream */:
                    return reportStatus(state, Diagnostics.Project_0_is_out_of_date_because_output_1_is_older_than_input_2, relName(state, configFileName), relName(state, status.outOfDateOutputFileName), relName(state, status.newerProjectName));
                case 4 /* OutputMissing */:
                    return reportStatus(state, Diagnostics.Project_0_is_out_of_date_because_output_file_1_does_not_exist, relName(state, configFileName), relName(state, status.missingOutputFileName));
                case 5 /* ErrorReadingFile */:
                    return reportStatus(state, Diagnostics.Project_0_is_out_of_date_because_there_was_error_reading_file_1, relName(state, configFileName), relName(state, status.fileName));
                case 8 /* OutOfDateBuildInfo */:
                    return reportStatus(state, Diagnostics.Project_0_is_out_of_date_because_buildinfo_file_1_indicates_that_some_of_the_changes_were_not_emitted, relName(state, configFileName), relName(state, status.buildInfoFile));
                case 9 /* OutOfDateOptions */:
                    return reportStatus(state, Diagnostics.Project_0_is_out_of_date_because_buildinfo_file_1_indicates_there_is_change_in_compilerOptions, relName(state, configFileName), relName(state, status.buildInfoFile));
                case 10 /* OutOfDateRoots */:
                    return reportStatus(state, Diagnostics.Project_0_is_out_of_date_because_buildinfo_file_1_indicates_that_file_2_was_root_file_of_compilation_but_not_any_more, relName(state, configFileName), relName(state, status.buildInfoFile), relName(state, status.inputFile));
                case 1 /* UpToDate */:
                    if (status.newestInputFileTime !== void 0) {
                        return reportStatus(state, Diagnostics.Project_0_is_up_to_date_because_newest_input_1_is_older_than_output_2, relName(state, configFileName), relName(state, status.newestInputFileName || ""), relName(state, status.oldestOutputFileName || ""));
                    }
                    break;
                case 3 /* OutOfDateWithPrepend */:
                    return reportStatus(state, Diagnostics.Project_0_is_out_of_date_because_output_of_its_dependency_1_has_changed, relName(state, configFileName), relName(state, status.newerProjectName));
                case 2 /* UpToDateWithUpstreamTypes */:
                    return reportStatus(state, Diagnostics.Project_0_is_up_to_date_with_d_ts_files_from_its_dependencies, relName(state, configFileName));
                case 15 /* UpToDateWithInputFileText */:
                    return reportStatus(state, Diagnostics.Project_0_is_up_to_date_but_needs_to_update_timestamps_of_output_files_that_are_older_than_input_files, relName(state, configFileName));
                case 11 /* UpstreamOutOfDate */:
                    return reportStatus(state, Diagnostics.Project_0_is_out_of_date_because_its_dependency_1_is_out_of_date, relName(state, configFileName), relName(state, status.upstreamProjectName));
                case 12 /* UpstreamBlocked */:
                    return reportStatus(state, status.upstreamProjectBlocked ? Diagnostics.Project_0_can_t_be_built_because_its_dependency_1_was_not_built : Diagnostics.Project_0_can_t_be_built_because_its_dependency_1_has_errors, relName(state, configFileName), relName(state, status.upstreamProjectName));
                case 0 /* Unbuildable */:
                    return reportStatus(state, Diagnostics.Failed_to_parse_file_0_Colon_1, relName(state, configFileName), status.reason);
                case 14 /* TsVersionOutputOfDate */:
                    return reportStatus(state, Diagnostics.Project_0_is_out_of_date_because_output_for_it_was_generated_with_version_1_that_differs_with_current_version_2, relName(state, configFileName), status.version, version);
                case 17 /* ForceBuild */:
                    return reportStatus(state, Diagnostics.Project_0_is_being_forcibly_rebuilt, relName(state, configFileName));
                case 16 /* ContainerOnly */:
                case 13 /* ComputingUpstream */:
                    break;
                default:
                    assertType(status);
            }
        }
        function verboseReportProjectStatus(state, configFileName, status) {
            if (state.options.verbose) {
                reportUpToDateStatus(state, configFileName, status);
            }
        }
        var minimumDate, maximumDate, InvalidatedProjectKind;
        var init_tsbuildPublic = __esm({
            "src/compiler/tsbuildPublic.ts"() {
                "use strict";
                init_ts2();
                init_ts_performance();
                minimumDate = /* @__PURE__ */ new Date(-864e13);
                maximumDate = /* @__PURE__ */ new Date(864e13);
                InvalidatedProjectKind = /* @__PURE__ */ ((InvalidatedProjectKind2) => {
                    InvalidatedProjectKind2[InvalidatedProjectKind2["Build"] = 0] = "Build";
                    InvalidatedProjectKind2[InvalidatedProjectKind2["UpdateBundle"] = 1] = "UpdateBundle";
                    InvalidatedProjectKind2[InvalidatedProjectKind2["UpdateOutputFileStamps"] = 2] = "UpdateOutputFileStamps";
                    return InvalidatedProjectKind2;
                })(InvalidatedProjectKind || {});
            }
        });
        // src/compiler/_namespaces/ts.ts
        var init_ts2 = __esm({
            "src/compiler/_namespaces/ts.ts"() {
                "use strict";
                init_corePublic();
                init_core();
                init_debug();
                init_semver();
                init_performanceCore();
                init_perfLogger();
                init_tracing();
                init_types();
                init_sys();
                init_path();
                init_diagnosticInformationMap_generated();
                init_scanner();
                init_utilitiesPublic();
                init_utilities();
                init_baseNodeFactory();
                init_parenthesizerRules();
                init_nodeConverters();
                init_nodeFactory();
                init_emitNode();
                init_emitHelpers();
                init_nodeTests();
                init_utilities2();
                init_utilitiesPublic2();
                init_parser();
                init_commandLineParser();
                init_moduleNameResolver();
                init_binder();
                init_symbolWalker();
                init_checker();
                init_visitorPublic();
                init_sourcemap();
                init_utilities3();
                init_destructuring();
                init_classThis();
                init_namedEvaluation();
                init_taggedTemplate();
                init_ts();
                init_classFields();
                init_typeSerializer();
                init_legacyDecorators();
                init_esDecorators();
                init_es2017();
                init_es2018();
                init_es2019();
                init_es2020();
                init_es2021();
                init_esnext();
                init_jsx();
                init_es2016();
                init_es2015();
                init_es5();
                init_generators();
                init_module();
                init_system();
                init_esnextAnd2015();
                init_node();
                init_diagnostics();
                init_declarations();
                init_transformer();
                init_emitter();
                init_watchUtilities();
                init_program();
                init_builderStatePublic();
                init_builderState();
                init_builder();
                init_builderPublic();
                init_resolutionCache();
                init_watch();
                init_watchPublic();
                init_tsbuild();
                init_tsbuildPublic();
                init_ts_moduleSpecifiers();
                init_ts_performance();
            }
        });
        // src/jsTyping/shared.ts
        function hasArgument(argumentName) {
            return sys.args.includes(argumentName);
        }
        function findArgument(argumentName) {
            const index = sys.args.indexOf(argumentName);
            return index >= 0 && index < sys.args.length - 1 ? sys.args[index + 1] : void 0;
        }
        function nowString() {
            const d = /* @__PURE__ */ new Date();
            return `${d.getHours().toString().padStart(2, "0")}:${d.getMinutes().toString().padStart(2, "0")}:${d.getSeconds().toString().padStart(2, "0")}.${d.getMilliseconds().toString().padStart(3, "0")}`;
        }
        function indent2(str) {
            return indentStr + str.replace(/\n/g, indentStr);
        }
        function stringifyIndented(json) {
            return indent2(JSON.stringify(json, void 0, 2));
        }
        var ActionSet, ActionInvalidate, ActionPackageInstalled, EventTypesRegistry, EventBeginInstallTypes, EventEndInstallTypes, EventInitializationFailed, ActionWatchTypingLocations, Arguments, indentStr;
        var init_shared = __esm({
            "src/jsTyping/shared.ts"() {
                "use strict";
                init_ts3();
                ActionSet = "action::set";
                ActionInvalidate = "action::invalidate";
                ActionPackageInstalled = "action::packageInstalled";
                EventTypesRegistry = "event::typesRegistry";
                EventBeginInstallTypes = "event::beginInstallTypes";
                EventEndInstallTypes = "event::endInstallTypes";
                EventInitializationFailed = "event::initializationFailed";
                ActionWatchTypingLocations = "action::watchTypingLocations";
                ((Arguments2) => {
                    Arguments2.GlobalCacheLocation = "--globalTypingsCacheLocation";
                    Arguments2.LogFile = "--logFile";
                    Arguments2.EnableTelemetry = "--enableTelemetry";
                    Arguments2.TypingSafeListLocation = "--typingSafeListLocation";
                    Arguments2.TypesMapLocation = "--typesMapLocation";
                    Arguments2.NpmLocation = "--npmLocation";
                    Arguments2.ValidateDefaultNpmLocation = "--validateDefaultNpmLocation";
                })(Arguments || (Arguments = {}));
                indentStr = "\n    ";
            }
        });
        // src/jsTyping/types.ts
        var init_types2 = __esm({
            "src/jsTyping/types.ts"() {
                "use strict";
            }
        });
        // src/jsTyping/_namespaces/ts.server.ts
        var init_ts_server = __esm({
            "src/jsTyping/_namespaces/ts.server.ts"() {
                "use strict";
                init_shared();
                init_types2();
            }
        });
        // src/jsTyping/jsTyping.ts
        function isTypingUpToDate(cachedTyping, availableTypingVersions) {
            const availableVersion = new Version(getProperty(availableTypingVersions, `ts${versionMajorMinor}`) || getProperty(availableTypingVersions, "latest"));
            return availableVersion.compareTo(cachedTyping.version) <= 0;
        }
        function nonRelativeModuleNameForTypingCache(moduleName) {
            return nodeCoreModules.has(moduleName) ? "node" : moduleName;
        }
        function loadSafeList(host, safeListPath) {
            const result = readConfigFile(safeListPath, (path) => host.readFile(path));
            return new Map(Object.entries(result.config));
        }
        function loadTypesMap(host, typesMapPath) {
            var _a;
            const result = readConfigFile(typesMapPath, (path) => host.readFile(path));
            if ((_a = result.config) == null ? void 0 : _a.simpleMap) {
                return new Map(Object.entries(result.config.simpleMap));
            }
            return void 0;
        }
        function discoverTypings(host, log, fileNames, projectRootPath, safeList, packageNameToTypingLocation, typeAcquisition, unresolvedImports, typesRegistry, compilerOptions) {
            if (!typeAcquisition || !typeAcquisition.enable) {
                return { cachedTypingPaths: [], newTypingNames: [], filesToWatch: [] };
            }
            const inferredTypings = /* @__PURE__ */ new Map();
            fileNames = mapDefined(fileNames, (fileName) => {
                const path = normalizePath(fileName);
                if (hasJSFileExtension(path)) {
                    return path;
                }
            });
            const filesToWatch = [];
            if (typeAcquisition.include)
                addInferredTypings(typeAcquisition.include, "Explicitly included types");
            const exclude = typeAcquisition.exclude || [];
            if (!compilerOptions.types) {
                const possibleSearchDirs = new Set(fileNames.map(getDirectoryPath));
                possibleSearchDirs.add(projectRootPath);
                possibleSearchDirs.forEach((searchDir) => {
                    getTypingNames(searchDir, "bower.json", "bower_components", filesToWatch);
                    getTypingNames(searchDir, "package.json", "node_modules", filesToWatch);
                });
            }
            if (!typeAcquisition.disableFilenameBasedTypeAcquisition) {
                getTypingNamesFromSourceFileNames(fileNames);
            }
            if (unresolvedImports) {
                const module2 = deduplicate(unresolvedImports.map(nonRelativeModuleNameForTypingCache), equateStringsCaseSensitive, compareStringsCaseSensitive);
                addInferredTypings(module2, "Inferred typings from unresolved imports");
            }
            for (const excludeTypingName of exclude) {
                const didDelete = inferredTypings.delete(excludeTypingName);
                if (didDelete && log)
                    log(`Typing for ${excludeTypingName} is in exclude list, will be ignored.`);
            }
            packageNameToTypingLocation.forEach((typing, name) => {
                const registryEntry = typesRegistry.get(name);
                if (inferredTypings.get(name) === false && registryEntry !== void 0 && isTypingUpToDate(typing, registryEntry)) {
                    inferredTypings.set(name, typing.typingLocation);
                }
            });
            const newTypingNames = [];
            const cachedTypingPaths = [];
            inferredTypings.forEach((inferred, typing) => {
                if (inferred) {
                    cachedTypingPaths.push(inferred);
                }
                else {
                    newTypingNames.push(typing);
                }
            });
            const result = { cachedTypingPaths, newTypingNames, filesToWatch };
            if (log)
                log(`Finished typings discovery:${stringifyIndented(result)}`);
            return result;
            function addInferredTyping(typingName) {
                if (!inferredTypings.has(typingName)) {
                    inferredTypings.set(typingName, false);
                }
            }
            function addInferredTypings(typingNames, message) {
                if (log)
                    log(`${message}: ${JSON.stringify(typingNames)}`);
                forEach(typingNames, addInferredTyping);
            }
            function getTypingNames(projectRootPath2, manifestName, modulesDirName, filesToWatch2) {
                const manifestPath = combinePaths(projectRootPath2, manifestName);
                let manifest;
                let manifestTypingNames;
                if (host.fileExists(manifestPath)) {
                    filesToWatch2.push(manifestPath);
                    manifest = readConfigFile(manifestPath, (path) => host.readFile(path)).config;
                    manifestTypingNames = flatMap([manifest.dependencies, manifest.devDependencies, manifest.optionalDependencies, manifest.peerDependencies], getOwnKeys);
                    addInferredTypings(manifestTypingNames, `Typing names in '${manifestPath}' dependencies`);
                }
                const packagesFolderPath = combinePaths(projectRootPath2, modulesDirName);
                filesToWatch2.push(packagesFolderPath);
                if (!host.directoryExists(packagesFolderPath)) {
                    return;
                }
                const packageNames = [];
                const dependencyManifestNames = manifestTypingNames ? manifestTypingNames.map((typingName) => combinePaths(packagesFolderPath, typingName, manifestName)) : host.readDirectory(packagesFolderPath, [".json" /* Json */], 
                /*excludes*/
                void 0, 
                /*includes*/
                void 0, 
                /*depth*/
                3).filter((manifestPath2) => {
                    if (getBaseFileName(manifestPath2) !== manifestName) {
                        return false;
                    }
                    const pathComponents2 = getPathComponents(normalizePath(manifestPath2));
                    const isScoped = pathComponents2[pathComponents2.length - 3][0] === "@";
                    return isScoped && toFileNameLowerCase(pathComponents2[pathComponents2.length - 4]) === modulesDirName || // `node_modules/@foo/bar`
                        !isScoped && toFileNameLowerCase(pathComponents2[pathComponents2.length - 3]) === modulesDirName;
                });
                if (log)
                    log(`Searching for typing names in ${packagesFolderPath}; all files: ${JSON.stringify(dependencyManifestNames)}`);
                for (const manifestPath2 of dependencyManifestNames) {
                    const normalizedFileName = normalizePath(manifestPath2);
                    const result2 = readConfigFile(normalizedFileName, (path) => host.readFile(path));
                    const manifest2 = result2.config;
                    if (!manifest2.name) {
                        continue;
                    }
                    const ownTypes = manifest2.types || manifest2.typings;
                    if (ownTypes) {
                        const absolutePath = getNormalizedAbsolutePath(ownTypes, getDirectoryPath(normalizedFileName));
                        if (host.fileExists(absolutePath)) {
                            if (log)
                                log(`    Package '${manifest2.name}' provides its own types.`);
                            inferredTypings.set(manifest2.name, absolutePath);
                        }
                        else {
                            if (log)
                                log(`    Package '${manifest2.name}' provides its own types but they are missing.`);
                        }
                    }
                    else {
                        packageNames.push(manifest2.name);
                    }
                }
                addInferredTypings(packageNames, "    Found package names");
            }
            function getTypingNamesFromSourceFileNames(fileNames2) {
                const fromFileNames = mapDefined(fileNames2, (j) => {
                    if (!hasJSFileExtension(j))
                        return void 0;
                    const inferredTypingName = removeFileExtension(toFileNameLowerCase(getBaseFileName(j)));
                    const cleanedTypingName = removeMinAndVersionNumbers(inferredTypingName);
                    return safeList.get(cleanedTypingName);
                });
                if (fromFileNames.length) {
                    addInferredTypings(fromFileNames, "Inferred typings from file names");
                }
                const hasJsxFile = some(fileNames2, (f) => fileExtensionIs(f, ".jsx" /* Jsx */));
                if (hasJsxFile) {
                    if (log)
                        log(`Inferred 'react' typings due to presence of '.jsx' extension`);
                    addInferredTyping("react");
                }
            }
        }
        function validatePackageName(packageName) {
            return validatePackageNameWorker(packageName, 
            /*supportScopedPackage*/
            true);
        }
        function validatePackageNameWorker(packageName, supportScopedPackage) {
            if (!packageName) {
                return 1 /* EmptyName */;
            }
            if (packageName.length > maxPackageNameLength) {
                return 2 /* NameTooLong */;
            }
            if (packageName.charCodeAt(0) === 46 /* dot */) {
                return 3 /* NameStartsWithDot */;
            }
            if (packageName.charCodeAt(0) === 95 /* _ */) {
                return 4 /* NameStartsWithUnderscore */;
            }
            if (supportScopedPackage) {
                const matches = /^@([^/]+)\/([^/]+)$/.exec(packageName);
                if (matches) {
                    const scopeResult = validatePackageNameWorker(matches[1], 
                    /*supportScopedPackage*/
                    false);
                    if (scopeResult !== 0 /* Ok */) {
                        return { name: matches[1], isScopeName: true, result: scopeResult };
                    }
                    const packageResult = validatePackageNameWorker(matches[2], 
                    /*supportScopedPackage*/
                    false);
                    if (packageResult !== 0 /* Ok */) {
                        return { name: matches[2], isScopeName: false, result: packageResult };
                    }
                    return 0 /* Ok */;
                }
            }
            if (encodeURIComponent(packageName) !== packageName) {
                return 5 /* NameContainsNonURISafeCharacters */;
            }
            return 0 /* Ok */;
        }
        function renderPackageNameValidationFailure(result, typing) {
            return typeof result === "object" ? renderPackageNameValidationFailureWorker(typing, result.result, result.name, result.isScopeName) : renderPackageNameValidationFailureWorker(typing, result, typing, 
            /*isScopeName*/
            false);
        }
        function renderPackageNameValidationFailureWorker(typing, result, name, isScopeName) {
            const kind = isScopeName ? "Scope" : "Package";
            switch (result) {
                case 1 /* EmptyName */:
                    return `'${typing}':: ${kind} name '${name}' cannot be empty`;
                case 2 /* NameTooLong */:
                    return `'${typing}':: ${kind} name '${name}' should be less than ${maxPackageNameLength} characters`;
                case 3 /* NameStartsWithDot */:
                    return `'${typing}':: ${kind} name '${name}' cannot start with '.'`;
                case 4 /* NameStartsWithUnderscore */:
                    return `'${typing}':: ${kind} name '${name}' cannot start with '_'`;
                case 5 /* NameContainsNonURISafeCharacters */:
                    return `'${typing}':: ${kind} name '${name}' contains non URI safe characters`;
                case 0 /* Ok */:
                    return Debug.fail();
                default:
                    Debug.assertNever(result);
            }
        }
        var unprefixedNodeCoreModuleList, prefixedNodeCoreModuleList, nodeCoreModuleList, nodeCoreModules, NameValidationResult, maxPackageNameLength;
        var init_jsTyping = __esm({
            "src/jsTyping/jsTyping.ts"() {
                "use strict";
                init_ts3();
                init_ts_server();
                unprefixedNodeCoreModuleList = [
                    "assert",
                    "assert/strict",
                    "async_hooks",
                    "buffer",
                    "child_process",
                    "cluster",
                    "console",
                    "constants",
                    "crypto",
                    "dgram",
                    "diagnostics_channel",
                    "dns",
                    "dns/promises",
                    "domain",
                    "events",
                    "fs",
                    "fs/promises",
                    "http",
                    "https",
                    "http2",
                    "inspector",
                    "module",
                    "net",
                    "os",
                    "path",
                    "perf_hooks",
                    "process",
                    "punycode",
                    "querystring",
                    "readline",
                    "repl",
                    "stream",
                    "stream/promises",
                    "string_decoder",
                    "timers",
                    "timers/promises",
                    "tls",
                    "trace_events",
                    "tty",
                    "url",
                    "util",
                    "util/types",
                    "v8",
                    "vm",
                    "wasi",
                    "worker_threads",
                    "zlib"
                ];
                prefixedNodeCoreModuleList = unprefixedNodeCoreModuleList.map((name) => `node:${name}`);
                nodeCoreModuleList = [...unprefixedNodeCoreModuleList, ...prefixedNodeCoreModuleList];
                nodeCoreModules = new Set(nodeCoreModuleList);
                NameValidationResult = /* @__PURE__ */ ((NameValidationResult2) => {
                    NameValidationResult2[NameValidationResult2["Ok"] = 0] = "Ok";
                    NameValidationResult2[NameValidationResult2["EmptyName"] = 1] = "EmptyName";
                    NameValidationResult2[NameValidationResult2["NameTooLong"] = 2] = "NameTooLong";
                    NameValidationResult2[NameValidationResult2["NameStartsWithDot"] = 3] = "NameStartsWithDot";
                    NameValidationResult2[NameValidationResult2["NameStartsWithUnderscore"] = 4] = "NameStartsWithUnderscore";
                    NameValidationResult2[NameValidationResult2["NameContainsNonURISafeCharacters"] = 5] = "NameContainsNonURISafeCharacters";
                    return NameValidationResult2;
                })(NameValidationResult || {});
                maxPackageNameLength = 214;
            }
        });
        // src/jsTyping/_namespaces/ts.JsTyping.ts
        var ts_JsTyping_exports = {};
        __export(ts_JsTyping_exports, {
            NameValidationResult: () => NameValidationResult,
            discoverTypings: () => discoverTypings,
            isTypingUpToDate: () => isTypingUpToDate,
            loadSafeList: () => loadSafeList,
            loadTypesMap: () => loadTypesMap,
            nodeCoreModuleList: () => nodeCoreModuleList,
            nodeCoreModules: () => nodeCoreModules,
            nonRelativeModuleNameForTypingCache: () => nonRelativeModuleNameForTypingCache,
            prefixedNodeCoreModuleList: () => prefixedNodeCoreModuleList,
            renderPackageNameValidationFailure: () => renderPackageNameValidationFailure,
            validatePackageName: () => validatePackageName
        });
        var init_ts_JsTyping = __esm({
            "src/jsTyping/_namespaces/ts.JsTyping.ts"() {
                "use strict";
                init_jsTyping();
            }
        });
        // src/jsTyping/_namespaces/ts.ts
        var init_ts3 = __esm({
            "src/jsTyping/_namespaces/ts.ts"() {
                "use strict";
                init_ts2();
                init_ts_JsTyping();
                init_ts_server();
            }
        });
        // src/services/types.ts
        function getDefaultFormatCodeSettings(newLineCharacter) {
            return {
                indentSize: 4,
                tabSize: 4,
                newLineCharacter: newLineCharacter || "\n",
                convertTabsToSpaces: true,
                indentStyle: 2 /* Smart */,
                insertSpaceAfterConstructor: false,
                insertSpaceAfterCommaDelimiter: true,
                insertSpaceAfterSemicolonInForStatements: true,
                insertSpaceBeforeAndAfterBinaryOperators: true,
                insertSpaceAfterKeywordsInControlFlowStatements: true,
                insertSpaceAfterFunctionKeywordForAnonymousFunctions: false,
                insertSpaceAfterOpeningAndBeforeClosingNonemptyParenthesis: false,
                insertSpaceAfterOpeningAndBeforeClosingNonemptyBrackets: false,
                insertSpaceAfterOpeningAndBeforeClosingNonemptyBraces: true,
                insertSpaceAfterOpeningAndBeforeClosingTemplateStringBraces: false,
                insertSpaceAfterOpeningAndBeforeClosingJsxExpressionBraces: false,
                insertSpaceBeforeFunctionParenthesis: false,
                placeOpenBraceOnNewLineForFunctions: false,
                placeOpenBraceOnNewLineForControlBlocks: false,
                semicolons: "ignore" /* Ignore */,
                trimTrailingWhitespace: true,
                indentSwitchCase: true
            };
        }
        var ScriptSnapshot, PackageJsonDependencyGroup, PackageJsonAutoImportPreference, LanguageServiceMode, emptyOptions, SemanticClassificationFormat, OrganizeImportsMode, CompletionTriggerKind, InlayHintKind, HighlightSpanKind, IndentStyle, SemicolonPreference, testFormatSettings, SymbolDisplayPartKind, CompletionInfoFlags, OutliningSpanKind, OutputFileType, EndOfLineState, TokenClass, ScriptElementKind, ScriptElementKindModifier, ClassificationTypeNames, ClassificationType;
        var init_types3 = __esm({
            "src/services/types.ts"() {
                "use strict";
                ((ScriptSnapshot2) => {
                    class StringScriptSnapshot {
                        constructor(text) {
                            this.text = text;
                        }
                        getText(start, end) {
                            return start === 0 && end === this.text.length ? this.text : this.text.substring(start, end);
                        }
                        getLength() {
                            return this.text.length;
                        }
                        getChangeRange() {
                            return void 0;
                        }
                    }
                    function fromString(text) {
                        return new StringScriptSnapshot(text);
                    }
                    ScriptSnapshot2.fromString = fromString;
                })(ScriptSnapshot || (ScriptSnapshot = {}));
                PackageJsonDependencyGroup = /* @__PURE__ */ ((PackageJsonDependencyGroup2) => {
                    PackageJsonDependencyGroup2[PackageJsonDependencyGroup2["Dependencies"] = 1] = "Dependencies";
                    PackageJsonDependencyGroup2[PackageJsonDependencyGroup2["DevDependencies"] = 2] = "DevDependencies";
                    PackageJsonDependencyGroup2[PackageJsonDependencyGroup2["PeerDependencies"] = 4] = "PeerDependencies";
                    PackageJsonDependencyGroup2[PackageJsonDependencyGroup2["OptionalDependencies"] = 8] = "OptionalDependencies";
                    PackageJsonDependencyGroup2[PackageJsonDependencyGroup2["All"] = 15] = "All";
                    return PackageJsonDependencyGroup2;
                })(PackageJsonDependencyGroup || {});
                PackageJsonAutoImportPreference = /* @__PURE__ */ ((PackageJsonAutoImportPreference2) => {
                    PackageJsonAutoImportPreference2[PackageJsonAutoImportPreference2["Off"] = 0] = "Off";
                    PackageJsonAutoImportPreference2[PackageJsonAutoImportPreference2["On"] = 1] = "On";
                    PackageJsonAutoImportPreference2[PackageJsonAutoImportPreference2["Auto"] = 2] = "Auto";
                    return PackageJsonAutoImportPreference2;
                })(PackageJsonAutoImportPreference || {});
                LanguageServiceMode = /* @__PURE__ */ ((LanguageServiceMode2) => {
                    LanguageServiceMode2[LanguageServiceMode2["Semantic"] = 0] = "Semantic";
                    LanguageServiceMode2[LanguageServiceMode2["PartialSemantic"] = 1] = "PartialSemantic";
                    LanguageServiceMode2[LanguageServiceMode2["Syntactic"] = 2] = "Syntactic";
                    return LanguageServiceMode2;
                })(LanguageServiceMode || {});
                emptyOptions = {};
                SemanticClassificationFormat = /* @__PURE__ */ ((SemanticClassificationFormat2) => {
                    SemanticClassificationFormat2["Original"] = "original";
                    SemanticClassificationFormat2["TwentyTwenty"] = "2020";
                    return SemanticClassificationFormat2;
                })(SemanticClassificationFormat || {});
                OrganizeImportsMode = /* @__PURE__ */ ((OrganizeImportsMode3) => {
                    OrganizeImportsMode3["All"] = "All";
                    OrganizeImportsMode3["SortAndCombine"] = "SortAndCombine";
                    OrganizeImportsMode3["RemoveUnused"] = "RemoveUnused";
                    return OrganizeImportsMode3;
                })(OrganizeImportsMode || {});
                CompletionTriggerKind = /* @__PURE__ */ ((CompletionTriggerKind4) => {
                    CompletionTriggerKind4[CompletionTriggerKind4["Invoked"] = 1] = "Invoked";
                    CompletionTriggerKind4[CompletionTriggerKind4["TriggerCharacter"] = 2] = "TriggerCharacter";
                    CompletionTriggerKind4[CompletionTriggerKind4["TriggerForIncompleteCompletions"] = 3] = "TriggerForIncompleteCompletions";
                    return CompletionTriggerKind4;
                })(CompletionTriggerKind || {});
                InlayHintKind = /* @__PURE__ */ ((InlayHintKind2) => {
                    InlayHintKind2["Type"] = "Type";
                    InlayHintKind2["Parameter"] = "Parameter";
                    InlayHintKind2["Enum"] = "Enum";
                    return InlayHintKind2;
                })(InlayHintKind || {});
                HighlightSpanKind = /* @__PURE__ */ ((HighlightSpanKind2) => {
                    HighlightSpanKind2["none"] = "none";
                    HighlightSpanKind2["definition"] = "definition";
                    HighlightSpanKind2["reference"] = "reference";
                    HighlightSpanKind2["writtenReference"] = "writtenReference";
                    return HighlightSpanKind2;
                })(HighlightSpanKind || {});
                IndentStyle = /* @__PURE__ */ ((IndentStyle3) => {
                    IndentStyle3[IndentStyle3["None"] = 0] = "None";
                    IndentStyle3[IndentStyle3["Block"] = 1] = "Block";
                    IndentStyle3[IndentStyle3["Smart"] = 2] = "Smart";
                    return IndentStyle3;
                })(IndentStyle || {});
                SemicolonPreference = /* @__PURE__ */ ((SemicolonPreference3) => {
                    SemicolonPreference3["Ignore"] = "ignore";
                    SemicolonPreference3["Insert"] = "insert";
                    SemicolonPreference3["Remove"] = "remove";
                    return SemicolonPreference3;
                })(SemicolonPreference || {});
                testFormatSettings = getDefaultFormatCodeSettings("\n");
                SymbolDisplayPartKind = /* @__PURE__ */ ((SymbolDisplayPartKind2) => {
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["aliasName"] = 0] = "aliasName";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["className"] = 1] = "className";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["enumName"] = 2] = "enumName";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["fieldName"] = 3] = "fieldName";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["interfaceName"] = 4] = "interfaceName";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["keyword"] = 5] = "keyword";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["lineBreak"] = 6] = "lineBreak";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["numericLiteral"] = 7] = "numericLiteral";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["stringLiteral"] = 8] = "stringLiteral";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["localName"] = 9] = "localName";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["methodName"] = 10] = "methodName";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["moduleName"] = 11] = "moduleName";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["operator"] = 12] = "operator";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["parameterName"] = 13] = "parameterName";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["propertyName"] = 14] = "propertyName";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["punctuation"] = 15] = "punctuation";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["space"] = 16] = "space";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["text"] = 17] = "text";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["typeParameterName"] = 18] = "typeParameterName";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["enumMemberName"] = 19] = "enumMemberName";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["functionName"] = 20] = "functionName";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["regularExpressionLiteral"] = 21] = "regularExpressionLiteral";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["link"] = 22] = "link";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["linkName"] = 23] = "linkName";
                    SymbolDisplayPartKind2[SymbolDisplayPartKind2["linkText"] = 24] = "linkText";
                    return SymbolDisplayPartKind2;
                })(SymbolDisplayPartKind || {});
                CompletionInfoFlags = /* @__PURE__ */ ((CompletionInfoFlags2) => {
                    CompletionInfoFlags2[CompletionInfoFlags2["None"] = 0] = "None";
                    CompletionInfoFlags2[CompletionInfoFlags2["MayIncludeAutoImports"] = 1] = "MayIncludeAutoImports";
                    CompletionInfoFlags2[CompletionInfoFlags2["IsImportStatementCompletion"] = 2] = "IsImportStatementCompletion";
                    CompletionInfoFlags2[CompletionInfoFlags2["IsContinuation"] = 4] = "IsContinuation";
                    CompletionInfoFlags2[CompletionInfoFlags2["ResolvedModuleSpecifiers"] = 8] = "ResolvedModuleSpecifiers";
                    CompletionInfoFlags2[CompletionInfoFlags2["ResolvedModuleSpecifiersBeyondLimit"] = 16] = "ResolvedModuleSpecifiersBeyondLimit";
                    CompletionInfoFlags2[CompletionInfoFlags2["MayIncludeMethodSnippets"] = 32] = "MayIncludeMethodSnippets";
                    return CompletionInfoFlags2;
                })(CompletionInfoFlags || {});
                OutliningSpanKind = /* @__PURE__ */ ((OutliningSpanKind2) => {
                    OutliningSpanKind2["Comment"] = "comment";
                    OutliningSpanKind2["Region"] = "region";
                    OutliningSpanKind2["Code"] = "code";
                    OutliningSpanKind2["Imports"] = "imports";
                    return OutliningSpanKind2;
                })(OutliningSpanKind || {});
                OutputFileType = /* @__PURE__ */ ((OutputFileType2) => {
                    OutputFileType2[OutputFileType2["JavaScript"] = 0] = "JavaScript";
                    OutputFileType2[OutputFileType2["SourceMap"] = 1] = "SourceMap";
                    OutputFileType2[OutputFileType2["Declaration"] = 2] = "Declaration";
                    return OutputFileType2;
                })(OutputFileType || {});
                EndOfLineState = /* @__PURE__ */ ((EndOfLineState2) => {
                    EndOfLineState2[EndOfLineState2["None"] = 0] = "None";
                    EndOfLineState2[EndOfLineState2["InMultiLineCommentTrivia"] = 1] = "InMultiLineCommentTrivia";
                    EndOfLineState2[EndOfLineState2["InSingleQuoteStringLiteral"] = 2] = "InSingleQuoteStringLiteral";
                    EndOfLineState2[EndOfLineState2["InDoubleQuoteStringLiteral"] = 3] = "InDoubleQuoteStringLiteral";
                    EndOfLineState2[EndOfLineState2["InTemplateHeadOrNoSubstitutionTemplate"] = 4] = "InTemplateHeadOrNoSubstitutionTemplate";
                    EndOfLineState2[EndOfLineState2["InTemplateMiddleOrTail"] = 5] = "InTemplateMiddleOrTail";
                    EndOfLineState2[EndOfLineState2["InTemplateSubstitutionPosition"] = 6] = "InTemplateSubstitutionPosition";
                    return EndOfLineState2;
                })(EndOfLineState || {});
                TokenClass = /* @__PURE__ */ ((TokenClass2) => {
                    TokenClass2[TokenClass2["Punctuation"] = 0] = "Punctuation";
                    TokenClass2[TokenClass2["Keyword"] = 1] = "Keyword";
                    TokenClass2[TokenClass2["Operator"] = 2] = "Operator";
                    TokenClass2[TokenClass2["Comment"] = 3] = "Comment";
                    TokenClass2[TokenClass2["Whitespace"] = 4] = "Whitespace";
                    TokenClass2[TokenClass2["Identifier"] = 5] = "Identifier";
                    TokenClass2[TokenClass2["NumberLiteral"] = 6] = "NumberLiteral";
                    TokenClass2[TokenClass2["BigIntLiteral"] = 7] = "BigIntLiteral";
                    TokenClass2[TokenClass2["StringLiteral"] = 8] = "StringLiteral";
                    TokenClass2[TokenClass2["RegExpLiteral"] = 9] = "RegExpLiteral";
                    return TokenClass2;
                })(TokenClass || {});
                ScriptElementKind = /* @__PURE__ */ ((ScriptElementKind2) => {
                    ScriptElementKind2["unknown"] = "";
                    ScriptElementKind2["warning"] = "warning";
                    ScriptElementKind2["keyword"] = "keyword";
                    ScriptElementKind2["scriptElement"] = "script";
                    ScriptElementKind2["moduleElement"] = "module";
                    ScriptElementKind2["classElement"] = "class";
                    ScriptElementKind2["localClassElement"] = "local class";
                    ScriptElementKind2["interfaceElement"] = "interface";
                    ScriptElementKind2["typeElement"] = "type";
                    ScriptElementKind2["enumElement"] = "enum";
                    ScriptElementKind2["enumMemberElement"] = "enum member";
                    ScriptElementKind2["variableElement"] = "var";
                    ScriptElementKind2["localVariableElement"] = "local var";
                    ScriptElementKind2["variableUsingElement"] = "using";
                    ScriptElementKind2["variableAwaitUsingElement"] = "await using";
                    ScriptElementKind2["functionElement"] = "function";
                    ScriptElementKind2["localFunctionElement"] = "local function";
                    ScriptElementKind2["memberFunctionElement"] = "method";
                    ScriptElementKind2["memberGetAccessorElement"] = "getter";
                    ScriptElementKind2["memberSetAccessorElement"] = "setter";
                    ScriptElementKind2["memberVariableElement"] = "property";
                    ScriptElementKind2["memberAccessorVariableElement"] = "accessor";
                    ScriptElementKind2["constructorImplementationElement"] = "constructor";
                    ScriptElementKind2["callSignatureElement"] = "call";
                    ScriptElementKind2["indexSignatureElement"] = "index";
                    ScriptElementKind2["constructSignatureElement"] = "construct";
                    ScriptElementKind2["parameterElement"] = "parameter";
                    ScriptElementKind2["typeParameterElement"] = "type parameter";
                    ScriptElementKind2["primitiveType"] = "primitive type";
                    ScriptElementKind2["label"] = "label";
                    ScriptElementKind2["alias"] = "alias";
                    ScriptElementKind2["constElement"] = "const";
                    ScriptElementKind2["letElement"] = "let";
                    ScriptElementKind2["directory"] = "directory";
                    ScriptElementKind2["externalModuleName"] = "external module name";
                    ScriptElementKind2["jsxAttribute"] = "JSX attribute";
                    ScriptElementKind2["string"] = "string";
                    ScriptElementKind2["link"] = "link";
                    ScriptElementKind2["linkName"] = "link name";
                    ScriptElementKind2["linkText"] = "link text";
                    return ScriptElementKind2;
                })(ScriptElementKind || {});
                ScriptElementKindModifier = /* @__PURE__ */ ((ScriptElementKindModifier2) => {
                    ScriptElementKindModifier2["none"] = "";
                    ScriptElementKindModifier2["publicMemberModifier"] = "public";
                    ScriptElementKindModifier2["privateMemberModifier"] = "private";
                    ScriptElementKindModifier2["protectedMemberModifier"] = "protected";
                    ScriptElementKindModifier2["exportedModifier"] = "export";
                    ScriptElementKindModifier2["ambientModifier"] = "declare";
                    ScriptElementKindModifier2["staticModifier"] = "static";
                    ScriptElementKindModifier2["abstractModifier"] = "abstract";
                    ScriptElementKindModifier2["optionalModifier"] = "optional";
                    ScriptElementKindModifier2["deprecatedModifier"] = "deprecated";
                    ScriptElementKindModifier2["dtsModifier"] = ".d.ts";
                    ScriptElementKindModifier2["tsModifier"] = ".ts";
                    ScriptElementKindModifier2["tsxModifier"] = ".tsx";
                    ScriptElementKindModifier2["jsModifier"] = ".js";
                    ScriptElementKindModifier2["jsxModifier"] = ".jsx";
                    ScriptElementKindModifier2["jsonModifier"] = ".json";
                    ScriptElementKindModifier2["dmtsModifier"] = ".d.mts";
                    ScriptElementKindModifier2["mtsModifier"] = ".mts";
                    ScriptElementKindModifier2["mjsModifier"] = ".mjs";
                    ScriptElementKindModifier2["dctsModifier"] = ".d.cts";
                    ScriptElementKindModifier2["ctsModifier"] = ".cts";
                    ScriptElementKindModifier2["cjsModifier"] = ".cjs";
                    return ScriptElementKindModifier2;
                })(ScriptElementKindModifier || {});
                ClassificationTypeNames = /* @__PURE__ */ ((ClassificationTypeNames2) => {
                    ClassificationTypeNames2["comment"] = "comment";
                    ClassificationTypeNames2["identifier"] = "identifier";
                    ClassificationTypeNames2["keyword"] = "keyword";
                    ClassificationTypeNames2["numericLiteral"] = "number";
                    ClassificationTypeNames2["bigintLiteral"] = "bigint";
                    ClassificationTypeNames2["operator"] = "operator";
                    ClassificationTypeNames2["stringLiteral"] = "string";
                    ClassificationTypeNames2["whiteSpace"] = "whitespace";
                    ClassificationTypeNames2["text"] = "text";
                    ClassificationTypeNames2["punctuation"] = "punctuation";
                    ClassificationTypeNames2["className"] = "class name";
                    ClassificationTypeNames2["enumName"] = "enum name";
                    ClassificationTypeNames2["interfaceName"] = "interface name";
                    ClassificationTypeNames2["moduleName"] = "module name";
                    ClassificationTypeNames2["typeParameterName"] = "type parameter name";
                    ClassificationTypeNames2["typeAliasName"] = "type alias name";
                    ClassificationTypeNames2["parameterName"] = "parameter name";
                    ClassificationTypeNames2["docCommentTagName"] = "doc comment tag name";
                    ClassificationTypeNames2["jsxOpenTagName"] = "jsx open tag name";
                    ClassificationTypeNames2["jsxCloseTagName"] = "jsx close tag name";
                    ClassificationTypeNames2["jsxSelfClosingTagName"] = "jsx self closing tag name";
                    ClassificationTypeNames2["jsxAttribute"] = "jsx attribute";
                    ClassificationTypeNames2["jsxText"] = "jsx text";
                    ClassificationTypeNames2["jsxAttributeStringLiteralValue"] = "jsx attribute string literal value";
                    return ClassificationTypeNames2;
                })(ClassificationTypeNames || {});
                ClassificationType = /* @__PURE__ */ ((ClassificationType3) => {
                    ClassificationType3[ClassificationType3["comment"] = 1] = "comment";
                    ClassificationType3[ClassificationType3["identifier"] = 2] = "identifier";
                    ClassificationType3[ClassificationType3["keyword"] = 3] = "keyword";
                    ClassificationType3[ClassificationType3["numericLiteral"] = 4] = "numericLiteral";
                    ClassificationType3[ClassificationType3["operator"] = 5] = "operator";
                    ClassificationType3[ClassificationType3["stringLiteral"] = 6] = "stringLiteral";
                    ClassificationType3[ClassificationType3["regularExpressionLiteral"] = 7] = "regularExpressionLiteral";
                    ClassificationType3[ClassificationType3["whiteSpace"] = 8] = "whiteSpace";
                    ClassificationType3[ClassificationType3["text"] = 9] = "text";
                    ClassificationType3[ClassificationType3["punctuation"] = 10] = "punctuation";
                    ClassificationType3[ClassificationType3["className"] = 11] = "className";
                    ClassificationType3[ClassificationType3["enumName"] = 12] = "enumName";
                    ClassificationType3[ClassificationType3["interfaceName"] = 13] = "interfaceName";
                    ClassificationType3[ClassificationType3["moduleName"] = 14] = "moduleName";
                    ClassificationType3[ClassificationType3["typeParameterName"] = 15] = "typeParameterName";
                    ClassificationType3[ClassificationType3["typeAliasName"] = 16] = "typeAliasName";
                    ClassificationType3[ClassificationType3["parameterName"] = 17] = "parameterName";
                    ClassificationType3[ClassificationType3["docCommentTagName"] = 18] = "docCommentTagName";
                    ClassificationType3[ClassificationType3["jsxOpenTagName"] = 19] = "jsxOpenTagName";
                    ClassificationType3[ClassificationType3["jsxCloseTagName"] = 20] = "jsxCloseTagName";
                    ClassificationType3[ClassificationType3["jsxSelfClosingTagName"] = 21] = "jsxSelfClosingTagName";
                    ClassificationType3[ClassificationType3["jsxAttribute"] = 22] = "jsxAttribute";
                    ClassificationType3[ClassificationType3["jsxText"] = 23] = "jsxText";
                    ClassificationType3[ClassificationType3["jsxAttributeStringLiteralValue"] = 24] = "jsxAttributeStringLiteralValue";
                    ClassificationType3[ClassificationType3["bigintLiteral"] = 25] = "bigintLiteral";
                    return ClassificationType3;
                })(ClassificationType || {});
            }
        });
        // src/services/utilities.ts
        function getMeaningFromDeclaration(node) {
            switch (node.kind) {
                case 260 /* VariableDeclaration */:
                    return isInJSFile(node) && getJSDocEnumTag(node) ? 7 /* All */ : 1 /* Value */;
                case 169 /* Parameter */:
                case 208 /* BindingElement */:
                case 172 /* PropertyDeclaration */:
                case 171 /* PropertySignature */:
                case 303 /* PropertyAssignment */:
                case 304 /* ShorthandPropertyAssignment */:
                case 174 /* MethodDeclaration */:
                case 173 /* MethodSignature */:
                case 176 /* Constructor */:
                case 177 /* GetAccessor */:
                case 178 /* SetAccessor */:
                case 262 /* FunctionDeclaration */:
                case 218 /* FunctionExpression */:
                case 219 /* ArrowFunction */:
                case 299 /* CatchClause */:
                case 291 /* JsxAttribute */:
                    return 1 /* Value */;
                case 168 /* TypeParameter */:
                case 264 /* InterfaceDeclaration */:
                case 265 /* TypeAliasDeclaration */:
                case 187 /* TypeLiteral */:
                    return 2 /* Type */;
                case 353 /* JSDocTypedefTag */:
                    return node.name === void 0 ? 1 /* Value */ | 2 /* Type */ : 2 /* Type */;
                case 306 /* EnumMember */:
                case 263 /* ClassDeclaration */:
                    return 1 /* Value */ | 2 /* Type */;
                case 267 /* ModuleDeclaration */:
                    if (isAmbientModule(node)) {
                        return 4 /* Namespace */ | 1 /* Value */;
                    }
                    else if (getModuleInstanceState(node) === 1 /* Instantiated */) {
                        return 4 /* Namespace */ | 1 /* Value */;
                    }
                    else {
                        return 4 /* Namespace */;
                    }
                case 266 /* EnumDeclaration */:
                case 275 /* NamedImports */:
                case 276 /* ImportSpecifier */:
                case 271 /* ImportEqualsDeclaration */:
                case 272 /* ImportDeclaration */:
                case 277 /* ExportAssignment */:
                case 278 /* ExportDeclaration */:
                    return 7 /* All */;
                case 312 /* SourceFile */:
                    return 4 /* Namespace */ | 1 /* Value */;
            }
            return 7 /* All */;
        }
        function getMeaningFromLocation(node) {
            node = getAdjustedReferenceLocation(node);
            const parent2 = node.parent;
            if (node.kind === 312 /* SourceFile */) {
                return 1 /* Value */;
            }
            else if (isExportAssignment(parent2) || isExportSpecifier(parent2) || isExternalModuleReference(parent2) || isImportSpecifier(parent2) || isImportClause(parent2) || isImportEqualsDeclaration(parent2) && node === parent2.name) {
                return 7 /* All */;
            }
            else if (isInRightSideOfInternalImportEqualsDeclaration(node)) {
                return getMeaningFromRightHandSideOfImportEquals(node);
            }
            else if (isDeclarationName(node)) {
                return getMeaningFromDeclaration(parent2);
            }
            else if (isEntityName(node) && findAncestor(node, or(isJSDocNameReference, isJSDocLinkLike, isJSDocMemberName))) {
                return 7 /* All */;
            }
            else if (isTypeReference(node)) {
                return 2 /* Type */;
            }
            else if (isNamespaceReference(node)) {
                return 4 /* Namespace */;
            }
            else if (isTypeParameterDeclaration(parent2)) {
                Debug.assert(isJSDocTemplateTag(parent2.parent));
                return 2 /* Type */;
            }
            else if (isLiteralTypeNode(parent2)) {
                return 2 /* Type */ | 1 /* Value */;
            }
            else {
                return 1 /* Value */;
            }
        }
        function getMeaningFromRightHandSideOfImportEquals(node) {
            const name = node.kind === 166 /* QualifiedName */ ? node : isQualifiedName(node.parent) && node.parent.right === node ? node.parent : void 0;
            return name && name.parent.kind === 271 /* ImportEqualsDeclaration */ ? 7 /* All */ : 4 /* Namespace */;
        }
        function isInRightSideOfInternalImportEqualsDeclaration(node) {
            while (node.parent.kind === 166 /* QualifiedName */) {
                node = node.parent;
            }
            return isInternalModuleImportEqualsDeclaration(node.parent) && node.parent.moduleReference === node;
        }
        function isNamespaceReference(node) {
            return isQualifiedNameNamespaceReference(node) || isPropertyAccessNamespaceReference(node);
        }
        function isQualifiedNameNamespaceReference(node) {
            let root = node;
            let isLastClause = true;
            if (root.parent.kind === 166 /* QualifiedName */) {
                while (root.parent && root.parent.kind === 166 /* QualifiedName */) {
                    root = root.parent;
                }
                isLastClause = root.right === node;
            }
            return root.parent.kind === 183 /* TypeReference */ && !isLastClause;
        }
        function isPropertyAccessNamespaceReference(node) {
            let root = node;
            let isLastClause = true;
            if (root.parent.kind === 211 /* PropertyAccessExpression */) {
                while (root.parent && root.parent.kind === 211 /* PropertyAccessExpression */) {
                    root = root.parent;
                }
                isLastClause = root.name === node;
            }
            if (!isLastClause && root.parent.kind === 233 /* ExpressionWithTypeArguments */ && root.parent.parent.kind === 298 /* HeritageClause */) {
                const decl = root.parent.parent.parent;
                return decl.kind === 263 /* ClassDeclaration */ && root.parent.parent.token === 119 /* ImplementsKeyword */ || decl.kind === 264 /* InterfaceDeclaration */ && root.parent.parent.token === 96 /* ExtendsKeyword */;
            }
            return false;
        }
        function isTypeReference(node) {
            if (isRightSideOfQualifiedNameOrPropertyAccess(node)) {
                node = node.parent;
            }
            switch (node.kind) {
                case 110 /* ThisKeyword */:
                    return !isExpressionNode(node);
                case 197 /* ThisType */:
                    return true;
            }
            switch (node.parent.kind) {
                case 183 /* TypeReference */:
                    return true;
                case 205 /* ImportType */:
                    return !node.parent.isTypeOf;
                case 233 /* ExpressionWithTypeArguments */:
                    return isPartOfTypeNode(node.parent);
            }
            return false;
        }
        function isCallExpressionTarget(node, includeElementAccess = false, skipPastOuterExpressions = false) {
            return isCalleeWorker(node, isCallExpression, selectExpressionOfCallOrNewExpressionOrDecorator, includeElementAccess, skipPastOuterExpressions);
        }
        function isNewExpressionTarget(node, includeElementAccess = false, skipPastOuterExpressions = false) {
            return isCalleeWorker(node, isNewExpression, selectExpressionOfCallOrNewExpressionOrDecorator, includeElementAccess, skipPastOuterExpressions);
        }
        function isCallOrNewExpressionTarget(node, includeElementAccess = false, skipPastOuterExpressions = false) {
            return isCalleeWorker(node, isCallOrNewExpression, selectExpressionOfCallOrNewExpressionOrDecorator, includeElementAccess, skipPastOuterExpressions);
        }
        function isTaggedTemplateTag(node, includeElementAccess = false, skipPastOuterExpressions = false) {
            return isCalleeWorker(node, isTaggedTemplateExpression, selectTagOfTaggedTemplateExpression, includeElementAccess, skipPastOuterExpressions);
        }
        function isDecoratorTarget(node, includeElementAccess = false, skipPastOuterExpressions = false) {
            return isCalleeWorker(node, isDecorator, selectExpressionOfCallOrNewExpressionOrDecorator, includeElementAccess, skipPastOuterExpressions);
        }
        function isJsxOpeningLikeElementTagName(node, includeElementAccess = false, skipPastOuterExpressions = false) {
            return isCalleeWorker(node, isJsxOpeningLikeElement, selectTagNameOfJsxOpeningLikeElement, includeElementAccess, skipPastOuterExpressions);
        }
        function selectExpressionOfCallOrNewExpressionOrDecorator(node) {
            return node.expression;
        }
        function selectTagOfTaggedTemplateExpression(node) {
            return node.tag;
        }
        function selectTagNameOfJsxOpeningLikeElement(node) {
            return node.tagName;
        }
        function isCalleeWorker(node, pred, calleeSelector, includeElementAccess, skipPastOuterExpressions) {
            let target = includeElementAccess ? climbPastPropertyOrElementAccess(node) : climbPastPropertyAccess(node);
            if (skipPastOuterExpressions) {
                target = skipOuterExpressions(target);
            }
            return !!target && !!target.parent && pred(target.parent) && calleeSelector(target.parent) === target;
        }
        function climbPastPropertyAccess(node) {
            return isRightSideOfPropertyAccess(node) ? node.parent : node;
        }
        function climbPastPropertyOrElementAccess(node) {
            return isRightSideOfPropertyAccess(node) || isArgumentExpressionOfElementAccess(node) ? node.parent : node;
        }
        function getTargetLabel(referenceNode, labelName) {
            while (referenceNode) {
                if (referenceNode.kind === 256 /* LabeledStatement */ && referenceNode.label.escapedText === labelName) {
                    return referenceNode.label;
                }
                referenceNode = referenceNode.parent;
            }
            return void 0;
        }
        function hasPropertyAccessExpressionWithName(node, funcName) {
            if (!isPropertyAccessExpression(node.expression)) {
                return false;
            }
            return node.expression.name.text === funcName;
        }
        function isJumpStatementTarget(node) {
            var _a;
            return isIdentifier(node) && ((_a = tryCast(node.parent, isBreakOrContinueStatement)) == null ? void 0 : _a.label) === node;
        }
        function isLabelOfLabeledStatement(node) {
            var _a;
            return isIdentifier(node) && ((_a = tryCast(node.parent, isLabeledStatement)) == null ? void 0 : _a.label) === node;
        }
        function isLabelName(node) {
            return isLabelOfLabeledStatement(node) || isJumpStatementTarget(node);
        }
        function isTagName(node) {
            var _a;
            return ((_a = tryCast(node.parent, isJSDocTag)) == null ? void 0 : _a.tagName) === node;
        }
        function isRightSideOfQualifiedName(node) {
            var _a;
            return ((_a = tryCast(node.parent, isQualifiedName)) == null ? void 0 : _a.right) === node;
        }
        function isRightSideOfPropertyAccess(node) {
            var _a;
            return ((_a = tryCast(node.parent, isPropertyAccessExpression)) == null ? void 0 : _a.name) === node;
        }
        function isArgumentExpressionOfElementAccess(node) {
            var _a;
            return ((_a = tryCast(node.parent, isElementAccessExpression)) == null ? void 0 : _a.argumentExpression) === node;
        }
        function isNameOfModuleDeclaration(node) {
            var _a;
            return ((_a = tryCast(node.parent, isModuleDeclaration)) == null ? void 0 : _a.name) === node;
        }
        function isNameOfFunctionDeclaration(node) {
            var _a;
            return isIdentifier(node) && ((_a = tryCast(node.parent, isFunctionLike)) == null ? void 0 : _a.name) === node;
        }
        function isLiteralNameOfPropertyDeclarationOrIndexAccess(node) {
            switch (node.parent.kind) {
                case 172 /* PropertyDeclaration */:
                case 171 /* PropertySignature */:
                case 303 /* PropertyAssignment */:
                case 306 /* EnumMember */:
                case 174 /* MethodDeclaration */:
                case 173 /* MethodSignature */:
                case 177 /* GetAccessor */:
                case 178 /* SetAccessor */:
                case 267 /* ModuleDeclaration */:
                    return getNameOfDeclaration(node.parent) === node;
                case 212 /* ElementAccessExpression */:
                    return node.parent.argumentExpression === node;
                case 167 /* ComputedPropertyName */:
                    return true;
                case 201 /* LiteralType */:
                    return node.parent.parent.kind === 199 /* IndexedAccessType */;
                default:
                    return false;
            }
        }
        function isExpressionOfExternalModuleImportEqualsDeclaration(node) {
            return isExternalModuleImportEqualsDeclaration(node.parent.parent) && getExternalModuleImportEqualsDeclarationExpression(node.parent.parent) === node;
        }
        function getContainerNode(node) {
            if (isJSDocTypeAlias(node)) {
                node = node.parent.parent;
            }
            while (true) {
                node = node.parent;
                if (!node) {
                    return void 0;
                }
                switch (node.kind) {
                    case 312 /* SourceFile */:
                    case 174 /* MethodDeclaration */:
                    case 173 /* MethodSignature */:
                    case 262 /* FunctionDeclaration */:
                    case 218 /* FunctionExpression */:
                    case 177 /* GetAccessor */:
                    case 178 /* SetAccessor */:
                    case 263 /* ClassDeclaration */:
                    case 264 /* InterfaceDeclaration */:
                    case 266 /* EnumDeclaration */:
                    case 267 /* ModuleDeclaration */:
                        return node;
                }
            }
        }
        function getNodeKind(node) {
            switch (node.kind) {
                case 312 /* SourceFile */:
                    return isExternalModule(node) ? "module" /* moduleElement */ : "script" /* scriptElement */;
                case 267 /* ModuleDeclaration */:
                    return "module" /* moduleElement */;
                case 263 /* ClassDeclaration */:
                case 231 /* ClassExpression */:
                    return "class" /* classElement */;
                case 264 /* InterfaceDeclaration */:
                    return "interface" /* interfaceElement */;
                case 265 /* TypeAliasDeclaration */:
                case 345 /* JSDocCallbackTag */:
                case 353 /* JSDocTypedefTag */:
                    return "type" /* typeElement */;
                case 266 /* EnumDeclaration */:
                    return "enum" /* enumElement */;
                case 260 /* VariableDeclaration */:
                    return getKindOfVariableDeclaration(node);
                case 208 /* BindingElement */:
                    return getKindOfVariableDeclaration(getRootDeclaration(node));
                case 219 /* ArrowFunction */:
                case 262 /* FunctionDeclaration */:
                case 218 /* FunctionExpression */:
                    return "function" /* functionElement */;
                case 177 /* GetAccessor */:
                    return "getter" /* memberGetAccessorElement */;
                case 178 /* SetAccessor */:
                    return "setter" /* memberSetAccessorElement */;
                case 174 /* MethodDeclaration */:
                case 173 /* MethodSignature */:
                    return "method" /* memberFunctionElement */;
                case 303 /* PropertyAssignment */:
                    const { initializer } = node;
                    return isFunctionLike(initializer) ? "method" /* memberFunctionElement */ : "property" /* memberVariableElement */;
                case 172 /* PropertyDeclaration */:
                case 171 /* PropertySignature */:
                case 304 /* ShorthandPropertyAssignment */:
                case 305 /* SpreadAssignment */:
                    return "property" /* memberVariableElement */;
                case 181 /* IndexSignature */:
                    return "index" /* indexSignatureElement */;
                case 180 /* ConstructSignature */:
                    return "construct" /* constructSignatureElement */;
                case 179 /* CallSignature */:
                    return "call" /* callSignatureElement */;
                case 176 /* Constructor */:
                case 175 /* ClassStaticBlockDeclaration */:
                    return "constructor" /* constructorImplementationElement */;
                case 168 /* TypeParameter */:
                    return "type parameter" /* typeParameterElement */;
                case 306 /* EnumMember */:
                    return "enum member" /* enumMemberElement */;
                case 169 /* Parameter */:
                    return hasSyntacticModifier(node, 31 /* ParameterPropertyModifier */) ? "property" /* memberVariableElement */ : "parameter" /* parameterElement */;
                case 271 /* ImportEqualsDeclaration */:
                case 276 /* ImportSpecifier */:
                case 281 /* ExportSpecifier */:
                case 274 /* NamespaceImport */:
                case 280 /* NamespaceExport */:
                    return "alias" /* alias */;
                case 226 /* BinaryExpression */:
                    const kind = getAssignmentDeclarationKind(node);
                    const { right } = node;
                    switch (kind) {
                        case 7 /* ObjectDefinePropertyValue */:
                        case 8 /* ObjectDefinePropertyExports */:
                        case 9 /* ObjectDefinePrototypeProperty */:
                        case 0 /* None */:
                            return "" /* unknown */;
                        case 1 /* ExportsProperty */:
                        case 2 /* ModuleExports */:
                            const rightKind = getNodeKind(right);
                            return rightKind === "" /* unknown */ ? "const" /* constElement */ : rightKind;
                        case 3 /* PrototypeProperty */:
                            return isFunctionExpression(right) ? "method" /* memberFunctionElement */ : "property" /* memberVariableElement */;
                        case 4 /* ThisProperty */:
                            return "property" /* memberVariableElement */;
                        case 5 /* Property */:
                            return isFunctionExpression(right) ? "method" /* memberFunctionElement */ : "property" /* memberVariableElement */;
                        case 6 /* Prototype */:
                            return "local class" /* localClassElement */;
                        default: {
                            assertType(kind);
                            return "" /* unknown */;
                        }
                    }
                case 80 /* Identifier */:
                    return isImportClause(node.parent) ? "alias" /* alias */ : "" /* unknown */;
                case 277 /* ExportAssignment */:
                    const scriptKind = getNodeKind(node.expression);
                    return scriptKind === "" /* unknown */ ? "const" /* constElement */ : scriptKind;
                default:
                    return "" /* unknown */;
            }
            function getKindOfVariableDeclaration(v) {
                return isVarConst(v) ? "const" /* constElement */ : isLet(v) ? "let" /* letElement */ : "var" /* variableElement */;
            }
        }
        function isThis(node) {
            switch (node.kind) {
                case 110 /* ThisKeyword */:
                    return true;
                case 80 /* Identifier */:
                    return identifierIsThisKeyword(node) && node.parent.kind === 169 /* Parameter */;
                default:
                    return false;
            }
        }
        function getLineStartPositionForPosition(position, sourceFile) {
            const lineStarts = getLineStarts(sourceFile);
            const line = sourceFile.getLineAndCharacterOfPosition(position).line;
            return lineStarts[line];
        }
        function rangeContainsRange(r1, r2) {
            return startEndContainsRange(r1.pos, r1.end, r2);
        }
        function rangeContainsRangeExclusive(r1, r2) {
            return rangeContainsPositionExclusive(r1, r2.pos) && rangeContainsPositionExclusive(r1, r2.end);
        }
        function rangeContainsPosition(r, pos) {
            return r.pos <= pos && pos <= r.end;
        }
        function rangeContainsPositionExclusive(r, pos) {
            return r.pos < pos && pos < r.end;
        }
        function startEndContainsRange(start, end, range) {
            return start <= range.pos && end >= range.end;
        }
        function rangeContainsStartEnd(range, start, end) {
            return range.pos <= start && range.end >= end;
        }
        function rangeOverlapsWithStartEnd(r1, start, end) {
            return startEndOverlapsWithStartEnd(r1.pos, r1.end, start, end);
        }
        function nodeOverlapsWithStartEnd(node, sourceFile, start, end) {
            return startEndOverlapsWithStartEnd(node.getStart(sourceFile), node.end, start, end);
        }
        function startEndOverlapsWithStartEnd(start1, end1, start2, end2) {
            const start = Math.max(start1, start2);
            const end = Math.min(end1, end2);
            return start < end;
        }
        function positionBelongsToNode(candidate, position, sourceFile) {
            Debug.assert(candidate.pos <= position);
            return position < candidate.end || !isCompletedNode(candidate, sourceFile);
        }
        function isCompletedNode(n, sourceFile) {
            if (n === void 0 || nodeIsMissing(n)) {
                return false;
            }
            switch (n.kind) {
                case 263 /* ClassDeclaration */:
                case 264 /* InterfaceDeclaration */:
                case 266 /* EnumDeclaration */:
                case 210 /* ObjectLiteralExpression */:
                case 206 /* ObjectBindingPattern */:
                case 187 /* TypeLiteral */:
                case 241 /* Block */:
                case 268 /* ModuleBlock */:
                case 269 /* CaseBlock */:
                case 275 /* NamedImports */:
                case 279 /* NamedExports */:
                    return nodeEndsWith(n, 20 /* CloseBraceToken */, sourceFile);
                case 299 /* CatchClause */:
                    return isCompletedNode(n.block, sourceFile);
                case 214 /* NewExpression */:
                    if (!n.arguments) {
                        return true;
                    }
                case 213 /* CallExpression */:
                case 217 /* ParenthesizedExpression */:
                case 196 /* ParenthesizedType */:
                    return nodeEndsWith(n, 22 /* CloseParenToken */, sourceFile);
                case 184 /* FunctionType */:
                case 185 /* ConstructorType */:
                    return isCompletedNode(n.type, sourceFile);
                case 176 /* Constructor */:
                case 177 /* GetAccessor */:
                case 178 /* SetAccessor */:
                case 262 /* FunctionDeclaration */:
                case 218 /* FunctionExpression */:
                case 174 /* MethodDeclaration */:
                case 173 /* MethodSignature */:
                case 180 /* ConstructSignature */:
                case 179 /* CallSignature */:
                case 219 /* ArrowFunction */:
                    if (n.body) {
                        return isCompletedNode(n.body, sourceFile);
                    }
                    if (n.type) {
                        return isCompletedNode(n.type, sourceFile);
                    }
                    return hasChildOfKind(n, 22 /* CloseParenToken */, sourceFile);
                case 267 /* ModuleDeclaration */:
                    return !!n.body && isCompletedNode(n.body, sourceFile);
                case 245 /* IfStatement */:
                    if (n.elseStatement) {
                        return isCompletedNode(n.elseStatement, sourceFile);
                    }
                    return isCompletedNode(n.thenStatement, sourceFile);
                case 244 /* ExpressionStatement */:
                    return isCompletedNode(n.expression, sourceFile) || hasChildOfKind(n, 27 /* SemicolonToken */, sourceFile);
                case 209 /* ArrayLiteralExpression */:
                case 207 /* ArrayBindingPattern */:
                case 212 /* ElementAccessExpression */:
                case 167 /* ComputedPropertyName */:
                case 189 /* TupleType */:
                    return nodeEndsWith(n, 24 /* CloseBracketToken */, sourceFile);
                case 181 /* IndexSignature */:
                    if (n.type) {
                        return isCompletedNode(n.type, sourceFile);
                    }
                    return hasChildOfKind(n, 24 /* CloseBracketToken */, sourceFile);
                case 296 /* CaseClause */:
                case 297 /* DefaultClause */:
                    return false;
                case 248 /* ForStatement */:
                case 249 /* ForInStatement */:
                case 250 /* ForOfStatement */:
                case 247 /* WhileStatement */:
                    return isCompletedNode(n.statement, sourceFile);
                case 246 /* DoStatement */:
                    return hasChildOfKind(n, 117 /* WhileKeyword */, sourceFile) ? nodeEndsWith(n, 22 /* CloseParenToken */, sourceFile) : isCompletedNode(n.statement, sourceFile);
                case 186 /* TypeQuery */:
                    return isCompletedNode(n.exprName, sourceFile);
                case 221 /* TypeOfExpression */:
                case 220 /* DeleteExpression */:
                case 222 /* VoidExpression */:
                case 229 /* YieldExpression */:
                case 230 /* SpreadElement */:
                    const unaryWordExpression = n;
                    return isCompletedNode(unaryWordExpression.expression, sourceFile);
                case 215 /* TaggedTemplateExpression */:
                    return isCompletedNode(n.template, sourceFile);
                case 228 /* TemplateExpression */:
                    const lastSpan = lastOrUndefined(n.templateSpans);
                    return isCompletedNode(lastSpan, sourceFile);
                case 239 /* TemplateSpan */:
                    return nodeIsPresent(n.literal);
                case 278 /* ExportDeclaration */:
                case 272 /* ImportDeclaration */:
                    return nodeIsPresent(n.moduleSpecifier);
                case 224 /* PrefixUnaryExpression */:
                    return isCompletedNode(n.operand, sourceFile);
                case 226 /* BinaryExpression */:
                    return isCompletedNode(n.right, sourceFile);
                case 227 /* ConditionalExpression */:
                    return isCompletedNode(n.whenFalse, sourceFile);
                default:
                    return true;
            }
        }
        function nodeEndsWith(n, expectedLastToken, sourceFile) {
            const children = n.getChildren(sourceFile);
            if (children.length) {
                const lastChild = last(children);
                if (lastChild.kind === expectedLastToken) {
                    return true;
                }
                else if (lastChild.kind === 27 /* SemicolonToken */ && children.length !== 1) {
                    return children[children.length - 2].kind === expectedLastToken;
                }
            }
            return false;
        }
        function findListItemInfo(node) {
            const list = findContainingList(node);
            if (!list) {
                return void 0;
            }
            const children = list.getChildren();
            const listItemIndex = indexOfNode(children, node);
            return {
                listItemIndex,
                list
            };
        }
        function hasChildOfKind(n, kind, sourceFile) {
            return !!findChildOfKind(n, kind, sourceFile);
        }
        function findChildOfKind(n, kind, sourceFile) {
            return find(n.getChildren(sourceFile), (c) => c.kind === kind);
        }
        function findContainingList(node) {
            const syntaxList = find(node.parent.getChildren(), (c) => isSyntaxList(c) && rangeContainsRange(c, node));
            Debug.assert(!syntaxList || contains(syntaxList.getChildren(), node));
            return syntaxList;
        }
        function isDefaultModifier2(node) {
            return node.kind === 90 /* DefaultKeyword */;
        }
        function isClassKeyword(node) {
            return node.kind === 86 /* ClassKeyword */;
        }
        function isFunctionKeyword(node) {
            return node.kind === 100 /* FunctionKeyword */;
        }
        function getAdjustedLocationForClass(node) {
            if (isNamedDeclaration(node)) {
                return node.name;
            }
            if (isClassDeclaration(node)) {
                const defaultModifier = node.modifiers && find(node.modifiers, isDefaultModifier2);
                if (defaultModifier)
                    return defaultModifier;
            }
            if (isClassExpression(node)) {
                const classKeyword = find(node.getChildren(), isClassKeyword);
                if (classKeyword)
                    return classKeyword;
            }
        }
        function getAdjustedLocationForFunction(node) {
            if (isNamedDeclaration(node)) {
                return node.name;
            }
            if (isFunctionDeclaration(node)) {
                const defaultModifier = find(node.modifiers, isDefaultModifier2);
                if (defaultModifier)
                    return defaultModifier;
            }
            if (isFunctionExpression(node)) {
                const functionKeyword = find(node.getChildren(), isFunctionKeyword);
                if (functionKeyword)
                    return functionKeyword;
            }
        }
        function getAncestorTypeNode(node) {
            let lastTypeNode;
            findAncestor(node, (a) => {
                if (isTypeNode(a)) {
                    lastTypeNode = a;
                }
                return !isQualifiedName(a.parent) && !isTypeNode(a.parent) && !isTypeElement(a.parent);
            });
            return lastTypeNode;
        }
        function getContextualTypeFromParentOrAncestorTypeNode(node, checker) {
            if (node.flags & (16777216 /* JSDoc */ & ~524288 /* JavaScriptFile */))
                return void 0;
            const contextualType = getContextualTypeFromParent(node, checker);
            if (contextualType)
                return contextualType;
            const ancestorTypeNode = getAncestorTypeNode(node);
            return ancestorTypeNode && checker.getTypeAtLocation(ancestorTypeNode);
        }
        function getAdjustedLocationForDeclaration(node, forRename) {
            if (!forRename) {
                switch (node.kind) {
                    case 263 /* ClassDeclaration */:
                    case 231 /* ClassExpression */:
                        return getAdjustedLocationForClass(node);
                    case 262 /* FunctionDeclaration */:
                    case 218 /* FunctionExpression */:
                        return getAdjustedLocationForFunction(node);
                    case 176 /* Constructor */:
                        return node;
                }
            }
            if (isNamedDeclaration(node)) {
                return node.name;
            }
        }
        function getAdjustedLocationForImportDeclaration(node, forRename) {
            if (node.importClause) {
                if (node.importClause.name && node.importClause.namedBindings) {
                    return;
                }
                if (node.importClause.name) {
                    return node.importClause.name;
                }
                if (node.importClause.namedBindings) {
                    if (isNamedImports(node.importClause.namedBindings)) {
                        const onlyBinding = singleOrUndefined(node.importClause.namedBindings.elements);
                        if (!onlyBinding) {
                            return;
                        }
                        return onlyBinding.name;
                    }
                    else if (isNamespaceImport(node.importClause.namedBindings)) {
                        return node.importClause.namedBindings.name;
                    }
                }
            }
            if (!forRename) {
                return node.moduleSpecifier;
            }
        }
        function getAdjustedLocationForExportDeclaration(node, forRename) {
            if (node.exportClause) {
                if (isNamedExports(node.exportClause)) {
                    const onlyBinding = singleOrUndefined(node.exportClause.elements);
                    if (!onlyBinding) {
                        return;
                    }
                    return node.exportClause.elements[0].name;
                }
                else if (isNamespaceExport(node.exportClause)) {
                    return node.exportClause.name;
                }
            }
            if (!forRename) {
                return node.moduleSpecifier;
            }
        }
        function getAdjustedLocationForHeritageClause(node) {
            if (node.types.length === 1) {
                return node.types[0].expression;
            }
        }
        function getAdjustedLocation(node, forRename) {
            const { parent: parent2 } = node;
            if (isModifier(node) && (forRename || node.kind !== 90 /* DefaultKeyword */) ? canHaveModifiers(parent2) && contains(parent2.modifiers, node) : node.kind === 86 /* ClassKeyword */ ? isClassDeclaration(parent2) || isClassExpression(node) : node.kind === 100 /* FunctionKeyword */ ? isFunctionDeclaration(parent2) || isFunctionExpression(node) : node.kind === 120 /* InterfaceKeyword */ ? isInterfaceDeclaration(parent2) : node.kind === 94 /* EnumKeyword */ ? isEnumDeclaration(parent2) : node.kind === 156 /* TypeKeyword */ ? isTypeAliasDeclaration(parent2) : node.kind === 145 /* NamespaceKeyword */ || node.kind === 144 /* ModuleKeyword */ ? isModuleDeclaration(parent2) : node.kind === 102 /* ImportKeyword */ ? isImportEqualsDeclaration(parent2) : node.kind === 139 /* GetKeyword */ ? isGetAccessorDeclaration(parent2) : node.kind === 153 /* SetKeyword */ && isSetAccessorDeclaration(parent2)) {
                const location = getAdjustedLocationForDeclaration(parent2, forRename);
                if (location) {
                    return location;
                }
            }
            if ((node.kind === 115 /* VarKeyword */ || node.kind === 87 /* ConstKeyword */ || node.kind === 121 /* LetKeyword */) && isVariableDeclarationList(parent2) && parent2.declarations.length === 1) {
                const decl = parent2.declarations[0];
                if (isIdentifier(decl.name)) {
                    return decl.name;
                }
            }
            if (node.kind === 156 /* TypeKeyword */) {
                if (isImportClause(parent2) && parent2.isTypeOnly) {
                    const location = getAdjustedLocationForImportDeclaration(parent2.parent, forRename);
                    if (location) {
                        return location;
                    }
                }
                if (isExportDeclaration(parent2) && parent2.isTypeOnly) {
                    const location = getAdjustedLocationForExportDeclaration(parent2, forRename);
                    if (location) {
                        return location;
                    }
                }
            }
            if (node.kind === 130 /* AsKeyword */) {
                if (isImportSpecifier(parent2) && parent2.propertyName || isExportSpecifier(parent2) && parent2.propertyName || isNamespaceImport(parent2) || isNamespaceExport(parent2)) {
                    return parent2.name;
                }
                if (isExportDeclaration(parent2) && parent2.exportClause && isNamespaceExport(parent2.exportClause)) {
                    return parent2.exportClause.name;
                }
            }
            if (node.kind === 102 /* ImportKeyword */ && isImportDeclaration(parent2)) {
                const location = getAdjustedLocationForImportDeclaration(parent2, forRename);
                if (location) {
                    return location;
                }
            }
            if (node.kind === 95 /* ExportKeyword */) {
                if (isExportDeclaration(parent2)) {
                    const location = getAdjustedLocationForExportDeclaration(parent2, forRename);
                    if (location) {
                        return location;
                    }
                }
                if (isExportAssignment(parent2)) {
                    return skipOuterExpressions(parent2.expression);
                }
            }
            if (node.kind === 149 /* RequireKeyword */ && isExternalModuleReference(parent2)) {
                return parent2.expression;
            }
            if (node.kind === 161 /* FromKeyword */ && (isImportDeclaration(parent2) || isExportDeclaration(parent2)) && parent2.moduleSpecifier) {
                return parent2.moduleSpecifier;
            }
            if ((node.kind === 96 /* ExtendsKeyword */ || node.kind === 119 /* ImplementsKeyword */) && isHeritageClause(parent2) && parent2.token === node.kind) {
                const location = getAdjustedLocationForHeritageClause(parent2);
                if (location) {
                    return location;
                }
            }
            if (node.kind === 96 /* ExtendsKeyword */) {
                if (isTypeParameterDeclaration(parent2) && parent2.constraint && isTypeReferenceNode(parent2.constraint)) {
                    return parent2.constraint.typeName;
                }
                if (isConditionalTypeNode(parent2) && isTypeReferenceNode(parent2.extendsType)) {
                    return parent2.extendsType.typeName;
                }
            }
            if (node.kind === 140 /* InferKeyword */ && isInferTypeNode(parent2)) {
                return parent2.typeParameter.name;
            }
            if (node.kind === 103 /* InKeyword */ && isTypeParameterDeclaration(parent2) && isMappedTypeNode(parent2.parent)) {
                return parent2.name;
            }
            if (node.kind === 143 /* KeyOfKeyword */ && isTypeOperatorNode(parent2) && parent2.operator === 143 /* KeyOfKeyword */ && isTypeReferenceNode(parent2.type)) {
                return parent2.type.typeName;
            }
            if (node.kind === 148 /* ReadonlyKeyword */ && isTypeOperatorNode(parent2) && parent2.operator === 148 /* ReadonlyKeyword */ && isArrayTypeNode(parent2.type) && isTypeReferenceNode(parent2.type.elementType)) {
                return parent2.type.elementType.typeName;
            }
            if (!forRename) {
                if (node.kind === 105 /* NewKeyword */ && isNewExpression(parent2) || node.kind === 116 /* VoidKeyword */ && isVoidExpression(parent2) || node.kind === 114 /* TypeOfKeyword */ && isTypeOfExpression(parent2) || node.kind === 135 /* AwaitKeyword */ && isAwaitExpression(parent2) || node.kind === 127 /* YieldKeyword */ && isYieldExpression(parent2) || node.kind === 91 /* DeleteKeyword */ && isDeleteExpression(parent2)) {
                    if (parent2.expression) {
                        return skipOuterExpressions(parent2.expression);
                    }
                }
                if ((node.kind === 103 /* InKeyword */ || node.kind === 104 /* InstanceOfKeyword */) && isBinaryExpression(parent2) && parent2.operatorToken === node) {
                    return skipOuterExpressions(parent2.right);
                }
                if (node.kind === 130 /* AsKeyword */ && isAsExpression(parent2) && isTypeReferenceNode(parent2.type)) {
                    return parent2.type.typeName;
                }
                if (node.kind === 103 /* InKeyword */ && isForInStatement(parent2) || node.kind === 165 /* OfKeyword */ && isForOfStatement(parent2)) {
                    return skipOuterExpressions(parent2.expression);
                }
            }
            return node;
        }
        function getAdjustedReferenceLocation(node) {
            return getAdjustedLocation(node, 
            /*forRename*/
            false);
        }
        function getAdjustedRenameLocation(node) {
            return getAdjustedLocation(node, 
            /*forRename*/
            true);
        }
        function getTouchingPropertyName(sourceFile, position) {
            return getTouchingToken(sourceFile, position, (n) => isPropertyNameLiteral(n) || isKeyword(n.kind) || isPrivateIdentifier(n));
        }
        function getTouchingToken(sourceFile, position, includePrecedingTokenAtEndPosition) {
            return getTokenAtPositionWorker(sourceFile, position, 
            /*allowPositionInLeadingTrivia*/
            false, includePrecedingTokenAtEndPosition, 
            /*includeEndPosition*/
            false);
        }
        function getTokenAtPosition(sourceFile, position) {
            return getTokenAtPositionWorker(sourceFile, position, 
            /*allowPositionInLeadingTrivia*/
            true, 
            /*includePrecedingTokenAtEndPosition*/
            void 0, 
            /*includeEndPosition*/
            false);
        }
        function getTokenAtPositionWorker(sourceFile, position, allowPositionInLeadingTrivia, includePrecedingTokenAtEndPosition, includeEndPosition) {
            let current = sourceFile;
            let foundToken;
            outer: while (true) {
                const children = current.getChildren(sourceFile);
                const i = binarySearchKey(children, position, (_, i2) => i2, (middle, _) => {
                    const end = children[middle].getEnd();
                    if (end < position) {
                        return -1 /* LessThan */;
                    }
                    const start = allowPositionInLeadingTrivia ? children[middle].getFullStart() : children[middle].getStart(sourceFile, 
                    /*includeJsDocComment*/
                    true);
                    if (start > position) {
                        return 1 /* GreaterThan */;
                    }
                    if (nodeContainsPosition(children[middle], start, end)) {
                        if (children[middle - 1]) {
                            if (nodeContainsPosition(children[middle - 1])) {
                                return 1 /* GreaterThan */;
                            }
                        }
                        return 0 /* EqualTo */;
                    }
                    if (includePrecedingTokenAtEndPosition && start === position && children[middle - 1] && children[middle - 1].getEnd() === position && nodeContainsPosition(children[middle - 1])) {
                        return 1 /* GreaterThan */;
                    }
                    return -1 /* LessThan */;
                });
                if (foundToken) {
                    return foundToken;
                }
                if (i >= 0 && children[i]) {
                    current = children[i];
                    continue outer;
                }
                return current;
            }
            function nodeContainsPosition(node, start, end) {
                end ?? (end = node.getEnd());
                if (end < position) {
                    return false;
                }
                start ?? (start = allowPositionInLeadingTrivia ? node.getFullStart() : node.getStart(sourceFile, 
                /*includeJsDocComment*/
                true));
                if (start > position) {
                    return false;
                }
                if (position < end || position === end && (node.kind === 1 /* EndOfFileToken */ || includeEndPosition)) {
                    return true;
                }
                else if (includePrecedingTokenAtEndPosition && end === position) {
                    const previousToken = findPrecedingToken(position, sourceFile, node);
                    if (previousToken && includePrecedingTokenAtEndPosition(previousToken)) {
                        foundToken = previousToken;
                        return true;
                    }
                }
                return false;
            }
        }
        function findFirstNonJsxWhitespaceToken(sourceFile, position) {
            let tokenAtPosition = getTokenAtPosition(sourceFile, position);
            while (isWhiteSpaceOnlyJsxText(tokenAtPosition)) {
                const nextToken = findNextToken(tokenAtPosition, tokenAtPosition.parent, sourceFile);
                if (!nextToken)
                    return;
                tokenAtPosition = nextToken;
            }
            return tokenAtPosition;
        }
        function findTokenOnLeftOfPosition(file, position) {
            const tokenAtPosition = getTokenAtPosition(file, position);
            if (isToken(tokenAtPosition) && position > tokenAtPosition.getStart(file) && position < tokenAtPosition.getEnd()) {
                return tokenAtPosition;
            }
            return findPrecedingToken(position, file);
        }
        function findNextToken(previousToken, parent2, sourceFile) {
            return find2(parent2);
            function find2(n) {
                if (isToken(n) && n.pos === previousToken.end) {
                    return n;
                }
                return firstDefined(n.getChildren(sourceFile), (child) => {
                    const shouldDiveInChildNode = (
                    // previous token is enclosed somewhere in the child
                    child.pos <= previousToken.pos && child.end > previousToken.end || // previous token ends exactly at the beginning of child
                        child.pos === previousToken.end);
                    return shouldDiveInChildNode && nodeHasTokens(child, sourceFile) ? find2(child) : void 0;
                });
            }
        }
        function findPrecedingToken(position, sourceFile, startNode2, excludeJsdoc) {
            const result = find2(startNode2 || sourceFile);
            Debug.assert(!(result && isWhiteSpaceOnlyJsxText(result)));
            return result;
            function find2(n) {
                if (isNonWhitespaceToken(n) && n.kind !== 1 /* EndOfFileToken */) {
                    return n;
                }
                const children = n.getChildren(sourceFile);
                const i = binarySearchKey(children, position, (_, i2) => i2, (middle, _) => {
                    if (position < children[middle].end) {
                        if (!children[middle - 1] || position >= children[middle - 1].end) {
                            return 0 /* EqualTo */;
                        }
                        return 1 /* GreaterThan */;
                    }
                    return -1 /* LessThan */;
                });
                if (i >= 0 && children[i]) {
                    const child = children[i];
                    if (position < child.end) {
                        const start = child.getStart(sourceFile, 
                        /*includeJsDoc*/
                        !excludeJsdoc);
                        const lookInPreviousChild = start >= position || // cursor in the leading trivia
                            !nodeHasTokens(child, sourceFile) || isWhiteSpaceOnlyJsxText(child);
                        if (lookInPreviousChild) {
                            const candidate2 = findRightmostChildNodeWithTokens(children, 
                            /*exclusiveStartPosition*/
                            i, sourceFile, n.kind);
                            if (candidate2) {
                                if (!excludeJsdoc && isJSDocCommentContainingNode(candidate2) && candidate2.getChildren(sourceFile).length) {
                                    return find2(candidate2);
                                }
                                return findRightmostToken(candidate2, sourceFile);
                            }
                            return void 0;
                        }
                        else {
                            return find2(child);
                        }
                    }
                }
                Debug.assert(startNode2 !== void 0 || n.kind === 312 /* SourceFile */ || n.kind === 1 /* EndOfFileToken */ || isJSDocCommentContainingNode(n));
                const candidate = findRightmostChildNodeWithTokens(children, 
                /*exclusiveStartPosition*/
                children.length, sourceFile, n.kind);
                return candidate && findRightmostToken(candidate, sourceFile);
            }
        }
        function isNonWhitespaceToken(n) {
            return isToken(n) && !isWhiteSpaceOnlyJsxText(n);
        }
        function findRightmostToken(n, sourceFile) {
            if (isNonWhitespaceToken(n)) {
                return n;
            }
            const children = n.getChildren(sourceFile);
            if (children.length === 0) {
                return n;
            }
            const candidate = findRightmostChildNodeWithTokens(children, 
            /*exclusiveStartPosition*/
            children.length, sourceFile, n.kind);
            return candidate && findRightmostToken(candidate, sourceFile);
        }
        function findRightmostChildNodeWithTokens(children, exclusiveStartPosition, sourceFile, parentKind) {
            for (let i = exclusiveStartPosition - 1; i >= 0; i--) {
                const child = children[i];
                if (isWhiteSpaceOnlyJsxText(child)) {
                    if (i === 0 && (parentKind === 12 /* JsxText */ || parentKind === 285 /* JsxSelfClosingElement */)) {
                        Debug.fail("`JsxText` tokens should not be the first child of `JsxElement | JsxSelfClosingElement`");
                    }
                }
                else if (nodeHasTokens(children[i], sourceFile)) {
                    return children[i];
                }
            }
        }
        function isInString(sourceFile, position, previousToken = findPrecedingToken(position, sourceFile)) {
            if (previousToken && isStringTextContainingNode(previousToken)) {
                const start = previousToken.getStart(sourceFile);
                const end = previousToken.getEnd();
                if (start < position && position < end) {
                    return true;
                }
                if (position === end) {
                    return !!previousToken.isUnterminated;
                }
            }
            return false;
        }
        function isInsideJsxElementOrAttribute(sourceFile, position) {
            const token = getTokenAtPosition(sourceFile, position);
            if (!token) {
                return false;
            }
            if (token.kind === 12 /* JsxText */) {
                return true;
            }
            if (token.kind === 30 /* LessThanToken */ && token.parent.kind === 12 /* JsxText */) {
                return true;
            }
            if (token.kind === 30 /* LessThanToken */ && token.parent.kind === 294 /* JsxExpression */) {
                return true;
            }
            if (token && token.kind === 20 /* CloseBraceToken */ && token.parent.kind === 294 /* JsxExpression */) {
                return true;
            }
            if (token.kind === 30 /* LessThanToken */ && token.parent.kind === 287 /* JsxClosingElement */) {
                return true;
            }
            return false;
        }
        function isWhiteSpaceOnlyJsxText(node) {
            return isJsxText(node) && node.containsOnlyTriviaWhiteSpaces;
        }
        function isInTemplateString(sourceFile, position) {
            const token = getTokenAtPosition(sourceFile, position);
            return isTemplateLiteralKind(token.kind) && position > token.getStart(sourceFile);
        }
        function isInJSXText(sourceFile, position) {
            const token = getTokenAtPosition(sourceFile, position);
            if (isJsxText(token)) {
                return true;
            }
            if (token.kind === 19 /* OpenBraceToken */ && isJsxExpression(token.parent) && isJsxElement(token.parent.parent)) {
                return true;
            }
            if (token.kind === 30 /* LessThanToken */ && isJsxOpeningLikeElement(token.parent) && isJsxElement(token.parent.parent)) {
                return true;
            }
            return false;
        }
        function isInsideJsxElement(sourceFile, position) {
            function isInsideJsxElementTraversal(node) {
                while (node) {
                    if (node.kind >= 285 /* JsxSelfClosingElement */ && node.kind <= 294 /* JsxExpression */ || node.kind === 12 /* JsxText */ || node.kind === 30 /* LessThanToken */ || node.kind === 32 /* GreaterThanToken */ || node.kind === 80 /* Identifier */ || node.kind === 20 /* CloseBraceToken */ || node.kind === 19 /* OpenBraceToken */ || node.kind === 44 /* SlashToken */) {
                        node = node.parent;
                    }
                    else if (node.kind === 284 /* JsxElement */) {
                        if (position > node.getStart(sourceFile))
                            return true;
                        node = node.parent;
                    }
                    else {
                        return false;
                    }
                }
                return false;
            }
            return isInsideJsxElementTraversal(getTokenAtPosition(sourceFile, position));
        }
        function findPrecedingMatchingToken(token, matchingTokenKind, sourceFile) {
            const closeTokenText = tokenToString(token.kind);
            const matchingTokenText = tokenToString(matchingTokenKind);
            const tokenFullStart = token.getFullStart();
            const bestGuessIndex = sourceFile.text.lastIndexOf(matchingTokenText, tokenFullStart);
            if (bestGuessIndex === -1) {
                return void 0;
            }
            if (sourceFile.text.lastIndexOf(closeTokenText, tokenFullStart - 1) < bestGuessIndex) {
                const nodeAtGuess = findPrecedingToken(bestGuessIndex + 1, sourceFile);
                if (nodeAtGuess && nodeAtGuess.kind === matchingTokenKind) {
                    return nodeAtGuess;
                }
            }
            const tokenKind = token.kind;
            let remainingMatchingTokens = 0;
            while (true) {
                const preceding = findPrecedingToken(token.getFullStart(), sourceFile);
                if (!preceding) {
                    return void 0;
                }
                token = preceding;
                if (token.kind === matchingTokenKind) {
                    if (remainingMatchingTokens === 0) {
                        return token;
                    }
                    remainingMatchingTokens--;
                }
                else if (token.kind === tokenKind) {
                    remainingMatchingTokens++;
                }
            }
        }
        function removeOptionality(type, isOptionalExpression, isOptionalChain2) {
            return isOptionalExpression ? type.getNonNullableType() : isOptionalChain2 ? type.getNonOptionalType() : type;
        }
        function isPossiblyTypeArgumentPosition(token, sourceFile, checker) {
            const info = getPossibleTypeArgumentsInfo(token, sourceFile);
            return info !== void 0 && (isPartOfTypeNode(info.called) || getPossibleGenericSignatures(info.called, info.nTypeArguments, checker).length !== 0 || isPossiblyTypeArgumentPosition(info.called, sourceFile, checker));
        }
        function getPossibleGenericSignatures(called, typeArgumentCount, checker) {
            let type = checker.getTypeAtLocation(called);
            if (isOptionalChain(called.parent)) {
                type = removeOptionality(type, isOptionalChainRoot(called.parent), 
                /*isOptionalChain*/
                true);
            }
            const signatures = isNewExpression(called.parent) ? type.getConstructSignatures() : type.getCallSignatures();
            return signatures.filter((candidate) => !!candidate.typeParameters && candidate.typeParameters.length >= typeArgumentCount);
        }
        function getPossibleTypeArgumentsInfo(tokenIn, sourceFile) {
            if (sourceFile.text.lastIndexOf("<", tokenIn ? tokenIn.pos : sourceFile.text.length) === -1) {
                return void 0;
            }
            let token = tokenIn;
            let remainingLessThanTokens = 0;
            let nTypeArguments = 0;
            while (token) {
                switch (token.kind) {
                    case 30 /* LessThanToken */:
                        token = findPrecedingToken(token.getFullStart(), sourceFile);
                        if (token && token.kind === 29 /* QuestionDotToken */) {
                            token = findPrecedingToken(token.getFullStart(), sourceFile);
                        }
                        if (!token || !isIdentifier(token))
                            return void 0;
                        if (!remainingLessThanTokens) {
                            return isDeclarationName(token) ? void 0 : { called: token, nTypeArguments };
                        }
                        remainingLessThanTokens--;
                        break;
                    case 50 /* GreaterThanGreaterThanGreaterThanToken */:
                        remainingLessThanTokens = 3;
                        break;
                    case 49 /* GreaterThanGreaterThanToken */:
                        remainingLessThanTokens = 2;
                        break;
                    case 32 /* GreaterThanToken */:
                        remainingLessThanTokens++;
                        break;
                    case 20 /* CloseBraceToken */:
                        token = findPrecedingMatchingToken(token, 19 /* OpenBraceToken */, sourceFile);
                        if (!token)
                            return void 0;
                        break;
                    case 22 /* CloseParenToken */:
                        token = findPrecedingMatchingToken(token, 21 /* OpenParenToken */, sourceFile);
                        if (!token)
                            return void 0;
                        break;
                    case 24 /* CloseBracketToken */:
                        token = findPrecedingMatchingToken(token, 23 /* OpenBracketToken */, sourceFile);
                        if (!token)
                            return void 0;
                        break;
                    case 28 /* CommaToken */:
                        nTypeArguments++;
                        break;
                    case 39 /* EqualsGreaterThanToken */:
                    case 80 /* Identifier */:
                    case 11 /* StringLiteral */:
                    case 9 /* NumericLiteral */:
                    case 10 /* BigIntLiteral */:
                    case 112 /* TrueKeyword */:
                    case 97 /* FalseKeyword */:
                    case 114 /* TypeOfKeyword */:
                    case 96 /* ExtendsKeyword */:
                    case 143 /* KeyOfKeyword */:
                    case 25 /* DotToken */:
                    case 52 /* BarToken */:
                    case 58 /* QuestionToken */:
                    case 59 /* ColonToken */:
                        break;
                    default:
                        if (isTypeNode(token)) {
                            break;
                        }
                        return void 0;
                }
                token = findPrecedingToken(token.getFullStart(), sourceFile);
            }
            return void 0;
        }
        function isInComment(sourceFile, position, tokenAtPosition) {
            return ts_formatting_exports.getRangeOfEnclosingComment(sourceFile, position, 
            /*precedingToken*/
            void 0, tokenAtPosition);
        }
        function hasDocComment(sourceFile, position) {
            const token = getTokenAtPosition(sourceFile, position);
            return !!findAncestor(token, isJSDoc);
        }
        function nodeHasTokens(n, sourceFile) {
            return n.kind === 1 /* EndOfFileToken */ ? !!n.jsDoc : n.getWidth(sourceFile) !== 0;
        }
        function getNodeModifiers(node, excludeFlags = 0 /* None */) {
            const result = [];
            const flags = isDeclaration(node) ? getCombinedNodeFlagsAlwaysIncludeJSDoc(node) & ~excludeFlags : 0 /* None */;
            if (flags & 2 /* Private */)
                result.push("private" /* privateMemberModifier */);
            if (flags & 4 /* Protected */)
                result.push("protected" /* protectedMemberModifier */);
            if (flags & 1 /* Public */)
                result.push("public" /* publicMemberModifier */);
            if (flags & 256 /* Static */ || isClassStaticBlockDeclaration(node))
                result.push("static" /* staticModifier */);
            if (flags & 64 /* Abstract */)
                result.push("abstract" /* abstractModifier */);
            if (flags & 32 /* Export */)
                result.push("export" /* exportedModifier */);
            if (flags & 65536 /* Deprecated */)
                result.push("deprecated" /* deprecatedModifier */);
            if (node.flags & 33554432 /* Ambient */)
                result.push("declare" /* ambientModifier */);
            if (node.kind === 277 /* ExportAssignment */)
                result.push("export" /* exportedModifier */);
            return result.length > 0 ? result.join(",") : "" /* none */;
        }
        function getTypeArgumentOrTypeParameterList(node) {
            if (node.kind === 183 /* TypeReference */ || node.kind === 213 /* CallExpression */) {
                return node.typeArguments;
            }
            if (isFunctionLike(node) || node.kind === 263 /* ClassDeclaration */ || node.kind === 264 /* InterfaceDeclaration */) {
                return node.typeParameters;
            }
            return void 0;
        }
        function isComment(kind) {
            return kind === 2 /* SingleLineCommentTrivia */ || kind === 3 /* MultiLineCommentTrivia */;
        }
        function isStringOrRegularExpressionOrTemplateLiteral(kind) {
            if (kind === 11 /* StringLiteral */ || kind === 14 /* RegularExpressionLiteral */ || isTemplateLiteralKind(kind)) {
                return true;
            }
            return false;
        }
        function areIntersectedTypesAvoidingStringReduction(checker, t1, t2) {
            return !!(t1.flags & 4 /* String */) && checker.isEmptyAnonymousObjectType(t2);
        }
        function isStringAndEmptyAnonymousObjectIntersection(type) {
            if (!type.isIntersection()) {
                return false;
            }
            const { types, checker } = type;
            return types.length === 2 && (areIntersectedTypesAvoidingStringReduction(checker, types[0], types[1]) || areIntersectedTypesAvoidingStringReduction(checker, types[1], types[0]));
        }
        function isInsideTemplateLiteral(node, position, sourceFile) {
            return isTemplateLiteralKind(node.kind) && (node.getStart(sourceFile) < position && position < node.end) || !!node.isUnterminated && position === node.end;
        }
        function isAccessibilityModifier(kind) {
            switch (kind) {
                case 125 /* PublicKeyword */:
                case 123 /* PrivateKeyword */:
                case 124 /* ProtectedKeyword */:
                    return true;
            }
            return false;
        }
        function cloneCompilerOptions(options) {
            const result = clone(options);
            setConfigFileInOptions(result, options && options.configFile);
            return result;
        }
        function isArrayLiteralOrObjectLiteralDestructuringPattern(node) {
            if (node.kind === 209 /* ArrayLiteralExpression */ || node.kind === 210 /* ObjectLiteralExpression */) {
                if (node.parent.kind === 226 /* BinaryExpression */ && node.parent.left === node && node.parent.operatorToken.kind === 64 /* EqualsToken */) {
                    return true;
                }
                if (node.parent.kind === 250 /* ForOfStatement */ && node.parent.initializer === node) {
                    return true;
                }
                if (isArrayLiteralOrObjectLiteralDestructuringPattern(node.parent.kind === 303 /* PropertyAssignment */ ? node.parent.parent : node.parent)) {
                    return true;
                }
            }
            return false;
        }
        function isInReferenceComment(sourceFile, position) {
            return isInReferenceCommentWorker(sourceFile, position, 
            /*shouldBeReference*/
            true);
        }
        function isInNonReferenceComment(sourceFile, position) {
            return isInReferenceCommentWorker(sourceFile, position, 
            /*shouldBeReference*/
            false);
        }
        function isInReferenceCommentWorker(sourceFile, position, shouldBeReference) {
            const range = isInComment(sourceFile, position, 
            /*tokenAtPosition*/
            void 0);
            return !!range && shouldBeReference === tripleSlashDirectivePrefixRegex.test(sourceFile.text.substring(range.pos, range.end));
        }
        function getReplacementSpanForContextToken(contextToken) {
            if (!contextToken)
                return void 0;
            switch (contextToken.kind) {
                case 11 /* StringLiteral */:
                case 15 /* NoSubstitutionTemplateLiteral */:
                    return createTextSpanFromStringLiteralLikeContent(contextToken);
                default:
                    return createTextSpanFromNode(contextToken);
            }
        }
        function createTextSpanFromNode(node, sourceFile, endNode2) {
            return createTextSpanFromBounds(node.getStart(sourceFile), (endNode2 || node).getEnd());
        }
        function createTextSpanFromStringLiteralLikeContent(node) {
            if (node.isUnterminated)
                return void 0;
            return createTextSpanFromBounds(node.getStart() + 1, node.getEnd() - 1);
        }
        function createTextRangeFromNode(node, sourceFile) {
            return createRange(node.getStart(sourceFile), node.end);
        }
        function createTextSpanFromRange(range) {
            return createTextSpanFromBounds(range.pos, range.end);
        }
        function createTextRangeFromSpan(span) {
            return createRange(span.start, span.start + span.length);
        }
        function createTextChangeFromStartLength(start, length2, newText) {
            return createTextChange(createTextSpan(start, length2), newText);
        }
        function createTextChange(span, newText) {
            return { span, newText };
        }
        function isTypeKeyword(kind) {
            return contains(typeKeywords, kind);
        }
        function isTypeKeywordToken(node) {
            return node.kind === 156 /* TypeKeyword */;
        }
        function isTypeKeywordTokenOrIdentifier(node) {
            return isTypeKeywordToken(node) || isIdentifier(node) && node.text === "type";
        }
        function isExternalModuleSymbol(moduleSymbol) {
            return !!(moduleSymbol.flags & 1536 /* Module */) && moduleSymbol.name.charCodeAt(0) === 34 /* doubleQuote */;
        }
        function nodeSeenTracker() {
            const seen = [];
            return (node) => {
                const id = getNodeId(node);
                return !seen[id] && (seen[id] = true);
            };
        }
        function getSnapshotText(snap) {
            return snap.getText(0, snap.getLength());
        }
        function repeatString(str, count) {
            let result = "";
            for (let i = 0; i < count; i++) {
                result += str;
            }
            return result;
        }
        function skipConstraint(type) {
            return type.isTypeParameter() ? type.getConstraint() || type : type;
        }
        function getNameFromPropertyName(name) {
            return name.kind === 167 /* ComputedPropertyName */ ? isStringOrNumericLiteralLike(name.expression) ? name.expression.text : void 0 : isPrivateIdentifier(name) ? idText(name) : getTextOfIdentifierOrLiteral(name);
        }
        function programContainsModules(program) {
            return program.getSourceFiles().some((s) => !s.isDeclarationFile && !program.isSourceFileFromExternalLibrary(s) && !!(s.externalModuleIndicator || s.commonJsModuleIndicator));
        }
        function programContainsEsModules(program) {
            return program.getSourceFiles().some((s) => !s.isDeclarationFile && !program.isSourceFileFromExternalLibrary(s) && !!s.externalModuleIndicator);
        }
        function compilerOptionsIndicateEsModules(compilerOptions) {
            return !!compilerOptions.module || getEmitScriptTarget(compilerOptions) >= 2 /* ES2015 */ || !!compilerOptions.noEmit;
        }
        function createModuleSpecifierResolutionHost(program, host) {
            return {
                fileExists: (fileName) => program.fileExists(fileName),
                getCurrentDirectory: () => host.getCurrentDirectory(),
                readFile: maybeBind(host, host.readFile),
                useCaseSensitiveFileNames: maybeBind(host, host.useCaseSensitiveFileNames),
                getSymlinkCache: maybeBind(host, host.getSymlinkCache) || program.getSymlinkCache,
                getModuleSpecifierCache: maybeBind(host, host.getModuleSpecifierCache),
                getPackageJsonInfoCache: () => {
                    var _a;
                    return (_a = program.getModuleResolutionCache()) == null ? void 0 : _a.getPackageJsonInfoCache();
                },
                getGlobalTypingsCacheLocation: maybeBind(host, host.getGlobalTypingsCacheLocation),
                redirectTargetsMap: program.redirectTargetsMap,
                getProjectReferenceRedirect: (fileName) => program.getProjectReferenceRedirect(fileName),
                isSourceOfProjectReferenceRedirect: (fileName) => program.isSourceOfProjectReferenceRedirect(fileName),
                getNearestAncestorDirectoryWithPackageJson: maybeBind(host, host.getNearestAncestorDirectoryWithPackageJson),
                getFileIncludeReasons: () => program.getFileIncludeReasons(),
                getCommonSourceDirectory: () => program.getCommonSourceDirectory()
            };
        }
        function getModuleSpecifierResolverHost(program, host) {
            return {
                ...createModuleSpecifierResolutionHost(program, host),
                getCommonSourceDirectory: () => program.getCommonSourceDirectory()
            };
        }
        function moduleResolutionUsesNodeModules(moduleResolution) {
            return moduleResolution === 2 /* Node10 */ || moduleResolution >= 3 /* Node16 */ && moduleResolution <= 99 /* NodeNext */ || moduleResolution === 100 /* Bundler */;
        }
        function makeImportIfNecessary(defaultImport, namedImports, moduleSpecifier, quotePreference) {
            return defaultImport || namedImports && namedImports.length ? makeImport(defaultImport, namedImports, moduleSpecifier, quotePreference) : void 0;
        }
        function makeImport(defaultImport, namedImports, moduleSpecifier, quotePreference, isTypeOnly) {
            return factory.createImportDeclaration(
            /*modifiers*/
            void 0, defaultImport || namedImports ? factory.createImportClause(!!isTypeOnly, defaultImport, namedImports && namedImports.length ? factory.createNamedImports(namedImports) : void 0) : void 0, typeof moduleSpecifier === "string" ? makeStringLiteral(moduleSpecifier, quotePreference) : moduleSpecifier, 
            /*attributes*/
            void 0);
        }
        function makeStringLiteral(text, quotePreference) {
            return factory.createStringLiteral(text, quotePreference === 0 /* Single */);
        }
        function quotePreferenceFromString(str, sourceFile) {
            return isStringDoubleQuoted(str, sourceFile) ? 1 /* Double */ : 0 /* Single */;
        }
        function getQuotePreference(sourceFile, preferences) {
            if (preferences.quotePreference && preferences.quotePreference !== "auto") {
                return preferences.quotePreference === "single" ? 0 /* Single */ : 1 /* Double */;
            }
            else {
                const firstModuleSpecifier = sourceFile.imports && find(sourceFile.imports, (n) => isStringLiteral(n) && !nodeIsSynthesized(n.parent));
                return firstModuleSpecifier ? quotePreferenceFromString(firstModuleSpecifier, sourceFile) : 1 /* Double */;
            }
        }
        function getQuoteFromPreference(qp) {
            switch (qp) {
                case 0 /* Single */:
                    return "'";
                case 1 /* Double */:
                    return '"';
                default:
                    return Debug.assertNever(qp);
            }
        }
        function symbolNameNoDefault(symbol) {
            const escaped = symbolEscapedNameNoDefault(symbol);
            return escaped === void 0 ? void 0 : unescapeLeadingUnderscores(escaped);
        }
        function symbolEscapedNameNoDefault(symbol) {
            if (symbol.escapedName !== "default" /* Default */) {
                return symbol.escapedName;
            }
            return firstDefined(symbol.declarations, (decl) => {
                const name = getNameOfDeclaration(decl);
                return name && name.kind === 80 /* Identifier */ ? name.escapedText : void 0;
            });
        }
        function isModuleSpecifierLike(node) {
            return isStringLiteralLike(node) && (isExternalModuleReference(node.parent) || isImportDeclaration(node.parent) || isRequireCall(node.parent, 
            /*requireStringLiteralLikeArgument*/
            false) && node.parent.arguments[0] === node || isImportCall(node.parent) && node.parent.arguments[0] === node);
        }
        function isObjectBindingElementWithoutPropertyName(bindingElement) {
            return isBindingElement(bindingElement) && isObjectBindingPattern(bindingElement.parent) && isIdentifier(bindingElement.name) && !bindingElement.propertyName;
        }
        function getPropertySymbolFromBindingElement(checker, bindingElement) {
            const typeOfPattern = checker.getTypeAtLocation(bindingElement.parent);
            return typeOfPattern && checker.getPropertyOfType(typeOfPattern, bindingElement.name.text);
        }
        function getParentNodeInSpan(node, file, span) {
            if (!node)
                return void 0;
            while (node.parent) {
                if (isSourceFile(node.parent) || !spanContainsNode(span, node.parent, file)) {
                    return node;
                }
                node = node.parent;
            }
        }
        function spanContainsNode(span, node, file) {
            return textSpanContainsPosition(span, node.getStart(file)) && node.getEnd() <= textSpanEnd(span);
        }
        function findModifier(node, kind) {
            return canHaveModifiers(node) ? find(node.modifiers, (m) => m.kind === kind) : void 0;
        }
        function insertImports(changes, sourceFile, imports, blankLineBetween, preferences) {
            const decl = isArray(imports) ? imports[0] : imports;
            const importKindPredicate = decl.kind === 243 /* VariableStatement */ ? isRequireVariableStatement : isAnyImportSyntax;
            const existingImportStatements = filter(sourceFile.statements, importKindPredicate);
            let sortKind = isArray(imports) ? ts_OrganizeImports_exports.detectImportDeclarationSorting(imports, preferences) : 3 /* Both */;
            const comparer = ts_OrganizeImports_exports.getOrganizeImportsComparer(preferences, sortKind === 2 /* CaseInsensitive */);
            const sortedNewImports = isArray(imports) ? stableSort(imports, (a, b) => ts_OrganizeImports_exports.compareImportsOrRequireStatements(a, b, comparer)) : [imports];
            if (!existingImportStatements.length) {
                changes.insertNodesAtTopOfFile(sourceFile, sortedNewImports, blankLineBetween);
            }
            else if (existingImportStatements && (sortKind = ts_OrganizeImports_exports.detectImportDeclarationSorting(existingImportStatements, preferences))) {
                const comparer2 = ts_OrganizeImports_exports.getOrganizeImportsComparer(preferences, sortKind === 2 /* CaseInsensitive */);
                for (const newImport of sortedNewImports) {
                    const insertionIndex = ts_OrganizeImports_exports.getImportDeclarationInsertionIndex(existingImportStatements, newImport, comparer2);
                    if (insertionIndex === 0) {
                        const options = existingImportStatements[0] === sourceFile.statements[0] ? { leadingTriviaOption: ts_textChanges_exports.LeadingTriviaOption.Exclude } : {};
                        changes.insertNodeBefore(sourceFile, existingImportStatements[0], newImport, 
                        /*blankLineBetween*/
                        false, options);
                    }
                    else {
                        const prevImport = existingImportStatements[insertionIndex - 1];
                        changes.insertNodeAfter(sourceFile, prevImport, newImport);
                    }
                }
            }
            else {
                const lastExistingImport = lastOrUndefined(existingImportStatements);
                if (lastExistingImport) {
                    changes.insertNodesAfter(sourceFile, lastExistingImport, sortedNewImports);
                }
                else {
                    changes.insertNodesAtTopOfFile(sourceFile, sortedNewImports, blankLineBetween);
                }
            }
        }
        function getTypeKeywordOfTypeOnlyImport(importClause, sourceFile) {
            Debug.assert(importClause.isTypeOnly);
            return cast(importClause.getChildAt(0, sourceFile), isTypeKeywordToken);
        }
        function textSpansEqual(a, b) {
            return !!a && !!b && a.start === b.start && a.length === b.length;
        }
        function documentSpansEqual(a, b, useCaseSensitiveFileNames2) {
            return (useCaseSensitiveFileNames2 ? equateStringsCaseSensitive : equateStringsCaseInsensitive)(a.fileName, b.fileName) && textSpansEqual(a.textSpan, b.textSpan);
        }
        function getDocumentSpansEqualityComparer(useCaseSensitiveFileNames2) {
            return (a, b) => documentSpansEqual(a, b, useCaseSensitiveFileNames2);
        }
        function forEachUnique(array, callback) {
            if (array) {
                for (let i = 0; i < array.length; i++) {
                    if (array.indexOf(array[i]) === i) {
                        const result = callback(array[i], i);
                        if (result) {
                            return result;
                        }
                    }
                }
            }
            return void 0;
        }
        function isTextWhiteSpaceLike(text, startPos, endPos) {
            for (let i = startPos; i < endPos; i++) {
                if (!isWhiteSpaceLike(text.charCodeAt(i))) {
                    return false;
                }
            }
            return true;
        }
        function getMappedLocation(location, sourceMapper, fileExists) {
            const mapsTo = sourceMapper.tryGetSourcePosition(location);
            return mapsTo && (!fileExists || fileExists(normalizePath(mapsTo.fileName)) ? mapsTo : void 0);
        }
        function getMappedDocumentSpan(documentSpan, sourceMapper, fileExists) {
            const { fileName, textSpan } = documentSpan;
            const newPosition = getMappedLocation({ fileName, pos: textSpan.start }, sourceMapper, fileExists);
            if (!newPosition)
                return void 0;
            const newEndPosition = getMappedLocation({ fileName, pos: textSpan.start + textSpan.length }, sourceMapper, fileExists);
            const newLength = newEndPosition ? newEndPosition.pos - newPosition.pos : textSpan.length;
            return {
                fileName: newPosition.fileName,
                textSpan: {
                    start: newPosition.pos,
                    length: newLength
                },
                originalFileName: documentSpan.fileName,
                originalTextSpan: documentSpan.textSpan,
                contextSpan: getMappedContextSpan(documentSpan, sourceMapper, fileExists),
                originalContextSpan: documentSpan.contextSpan
            };
        }
        function getMappedContextSpan(documentSpan, sourceMapper, fileExists) {
            const contextSpanStart = documentSpan.contextSpan && getMappedLocation({ fileName: documentSpan.fileName, pos: documentSpan.contextSpan.start }, sourceMapper, fileExists);
            const contextSpanEnd = documentSpan.contextSpan && getMappedLocation({ fileName: documentSpan.fileName, pos: documentSpan.contextSpan.start + documentSpan.contextSpan.length }, sourceMapper, fileExists);
            return contextSpanStart && contextSpanEnd ? { start: contextSpanStart.pos, length: contextSpanEnd.pos - contextSpanStart.pos } : void 0;
        }
        function isFirstDeclarationOfSymbolParameter(symbol) {
            const declaration = symbol.declarations ? firstOrUndefined(symbol.declarations) : void 0;
            return !!findAncestor(declaration, (n) => isParameter(n) ? true : isBindingElement(n) || isObjectBindingPattern(n) || isArrayBindingPattern(n) ? false : "quit");
        }
        function getDisplayPartWriter() {
            const absoluteMaximumLength = defaultMaximumTruncationLength * 10;
            let displayParts;
            let lineStart;
            let indent3;
            let length2;
            resetWriter();
            const unknownWrite = (text) => writeKind(text, 17 /* text */);
            return {
                displayParts: () => {
                    const finalText = displayParts.length && displayParts[displayParts.length - 1].text;
                    if (length2 > absoluteMaximumLength && finalText && finalText !== "...") {
                        if (!isWhiteSpaceLike(finalText.charCodeAt(finalText.length - 1))) {
                            displayParts.push(displayPart(" ", 16 /* space */));
                        }
                        displayParts.push(displayPart("...", 15 /* punctuation */));
                    }
                    return displayParts;
                },
                writeKeyword: (text) => writeKind(text, 5 /* keyword */),
                writeOperator: (text) => writeKind(text, 12 /* operator */),
                writePunctuation: (text) => writeKind(text, 15 /* punctuation */),
                writeTrailingSemicolon: (text) => writeKind(text, 15 /* punctuation */),
                writeSpace: (text) => writeKind(text, 16 /* space */),
                writeStringLiteral: (text) => writeKind(text, 8 /* stringLiteral */),
                writeParameter: (text) => writeKind(text, 13 /* parameterName */),
                writeProperty: (text) => writeKind(text, 14 /* propertyName */),
                writeLiteral: (text) => writeKind(text, 8 /* stringLiteral */),
                writeSymbol,
                writeLine,
                write: unknownWrite,
                writeComment: unknownWrite,
                getText: () => "",
                getTextPos: () => 0,
                getColumn: () => 0,
                getLine: () => 0,
                isAtStartOfLine: () => false,
                hasTrailingWhitespace: () => false,
                hasTrailingComment: () => false,
                rawWrite: notImplemented,
                getIndent: () => indent3,
                increaseIndent: () => {
                    indent3++;
                },
                decreaseIndent: () => {
                    indent3--;
                },
                clear: resetWriter
            };
            function writeIndent() {
                if (length2 > absoluteMaximumLength)
                    return;
                if (lineStart) {
                    const indentString = getIndentString(indent3);
                    if (indentString) {
                        length2 += indentString.length;
                        displayParts.push(displayPart(indentString, 16 /* space */));
                    }
                    lineStart = false;
                }
            }
            function writeKind(text, kind) {
                if (length2 > absoluteMaximumLength)
                    return;
                writeIndent();
                length2 += text.length;
                displayParts.push(displayPart(text, kind));
            }
            function writeSymbol(text, symbol) {
                if (length2 > absoluteMaximumLength)
                    return;
                writeIndent();
                length2 += text.length;
                displayParts.push(symbolPart(text, symbol));
            }
            function writeLine() {
                if (length2 > absoluteMaximumLength)
                    return;
                length2 += 1;
                displayParts.push(lineBreakPart());
                lineStart = true;
            }
            function resetWriter() {
                displayParts = [];
                lineStart = true;
                indent3 = 0;
                length2 = 0;
            }
        }
        function symbolPart(text, symbol) {
            return displayPart(text, displayPartKind(symbol));
            function displayPartKind(symbol2) {
                const flags = symbol2.flags;
                if (flags & 3 /* Variable */) {
                    return isFirstDeclarationOfSymbolParameter(symbol2) ? 13 /* parameterName */ : 9 /* localName */;
                }
                if (flags & 4 /* Property */)
                    return 14 /* propertyName */;
                if (flags & 32768 /* GetAccessor */)
                    return 14 /* propertyName */;
                if (flags & 65536 /* SetAccessor */)
                    return 14 /* propertyName */;
                if (flags & 8 /* EnumMember */)
                    return 19 /* enumMemberName */;
                if (flags & 16 /* Function */)
                    return 20 /* functionName */;
                if (flags & 32 /* Class */)
                    return 1 /* className */;
                if (flags & 64 /* Interface */)
                    return 4 /* interfaceName */;
                if (flags & 384 /* Enum */)
                    return 2 /* enumName */;
                if (flags & 1536 /* Module */)
                    return 11 /* moduleName */;
                if (flags & 8192 /* Method */)
                    return 10 /* methodName */;
                if (flags & 262144 /* TypeParameter */)
                    return 18 /* typeParameterName */;
                if (flags & 524288 /* TypeAlias */)
                    return 0 /* aliasName */;
                if (flags & 2097152 /* Alias */)
                    return 0 /* aliasName */;
                return 17 /* text */;
            }
        }
        function displayPart(text, kind) {
            return { text, kind: SymbolDisplayPartKind[kind] };
        }
        function spacePart() {
            return displayPart(" ", 16 /* space */);
        }
        function keywordPart(kind) {
            return displayPart(tokenToString(kind), 5 /* keyword */);
        }
        function punctuationPart(kind) {
            return displayPart(tokenToString(kind), 15 /* punctuation */);
        }
        function operatorPart(kind) {
            return displayPart(tokenToString(kind), 12 /* operator */);
        }
        function parameterNamePart(text) {
            return displayPart(text, 13 /* parameterName */);
        }
        function propertyNamePart(text) {
            return displayPart(text, 14 /* propertyName */);
        }
        function textOrKeywordPart(text) {
            const kind = stringToToken(text);
            return kind === void 0 ? textPart(text) : keywordPart(kind);
        }
        function textPart(text) {
            return displayPart(text, 17 /* text */);
        }
        function typeAliasNamePart(text) {
            return displayPart(text, 0 /* aliasName */);
        }
        function typeParameterNamePart(text) {
            return displayPart(text, 18 /* typeParameterName */);
        }
        function linkTextPart(text) {
            return displayPart(text, 24 /* linkText */);
        }
        function linkNamePart(text, target) {
            return {
                text,
                kind: SymbolDisplayPartKind[23 /* linkName */],
                target: {
                    fileName: getSourceFileOfNode(target).fileName,
                    textSpan: createTextSpanFromNode(target)
                }
            };
        }
        function linkPart(text) {
            return displayPart(text, 22 /* link */);
        }
        function buildLinkParts(link, checker) {
            var _a;
            const prefix = isJSDocLink(link) ? "link" : isJSDocLinkCode(link) ? "linkcode" : "linkplain";
            const parts = [linkPart(`{@${prefix} `)];
            if (!link.name) {
                if (link.text) {
                    parts.push(linkTextPart(link.text));
                }
            }
            else {
                const symbol = checker == null ? void 0 : checker.getSymbolAtLocation(link.name);
                const targetSymbol = symbol && checker ? getSymbolTarget(symbol, checker) : void 0;
                const suffix = findLinkNameEnd(link.text);
                const name = getTextOfNode(link.name) + link.text.slice(0, suffix);
                const text = skipSeparatorFromLinkText(link.text.slice(suffix));
                const decl = (targetSymbol == null ? void 0 : targetSymbol.valueDeclaration) || ((_a = targetSymbol == null ? void 0 : targetSymbol.declarations) == null ? void 0 : _a[0]);
                if (decl) {
                    parts.push(linkNamePart(name, decl));
                    if (text)
                        parts.push(linkTextPart(text));
                }
                else {
                    const separator = suffix === 0 || link.text.charCodeAt(suffix) === 124 /* bar */ && name.charCodeAt(name.length - 1) !== 32 /* space */ ? " " : "";
                    parts.push(linkTextPart(name + separator + text));
                }
            }
            parts.push(linkPart("}"));
            return parts;
        }
        function skipSeparatorFromLinkText(text) {
            let pos = 0;
            if (text.charCodeAt(pos++) === 124 /* bar */) {
                while (pos < text.length && text.charCodeAt(pos) === 32 /* space */)
                    pos++;
                return text.slice(pos);
            }
            return text;
        }
        function findLinkNameEnd(text) {
            let pos = text.indexOf("://");
            if (pos === 0) {
                while (pos < text.length && text.charCodeAt(pos) !== 124 /* bar */)
                    pos++;
                return pos;
            }
            if (text.indexOf("()") === 0)
                return 2;
            if (text.charAt(0) === "<") {
                let brackets2 = 0;
                let i = 0;
                while (i < text.length) {
                    if (text[i] === "<")
                        brackets2++;
                    if (text[i] === ">")
                        brackets2--;
                    i++;
                    if (!brackets2)
                        return i;
                }
            }
            return 0;
        }
        function getNewLineOrDefaultFromHost(host, formatSettings) {
            var _a;
            return (formatSettings == null ? void 0 : formatSettings.newLineCharacter) || ((_a = host.getNewLine) == null ? void 0 : _a.call(host)) || lineFeed2;
        }
        function lineBreakPart() {
            return displayPart("\n", 6 /* lineBreak */);
        }
        function mapToDisplayParts(writeDisplayParts) {
            try {
                writeDisplayParts(displayPartWriter);
                return displayPartWriter.displayParts();
            }
            finally {
                displayPartWriter.clear();
            }
        }
        function typeToDisplayParts(typechecker, type, enclosingDeclaration, flags = 0 /* None */) {
            return mapToDisplayParts((writer) => {
                typechecker.writeType(type, enclosingDeclaration, flags | 1024 /* MultilineObjectLiterals */ | 16384 /* UseAliasDefinedOutsideCurrentScope */, writer);
            });
        }
        function symbolToDisplayParts(typeChecker, symbol, enclosingDeclaration, meaning, flags = 0 /* None */) {
            return mapToDisplayParts((writer) => {
                typeChecker.writeSymbol(symbol, enclosingDeclaration, meaning, flags | 8 /* UseAliasDefinedOutsideCurrentScope */, writer);
            });
        }
        function signatureToDisplayParts(typechecker, signature, enclosingDeclaration, flags = 0 /* None */) {
            flags |= 16384 /* UseAliasDefinedOutsideCurrentScope */ | 1024 /* MultilineObjectLiterals */ | 32 /* WriteTypeArgumentsOfSignature */ | 8192 /* OmitParameterModifiers */;
            return mapToDisplayParts((writer) => {
                typechecker.writeSignature(signature, enclosingDeclaration, flags, 
                /*kind*/
                void 0, writer);
            });
        }
        function nodeToDisplayParts(node, enclosingDeclaration) {
            const file = enclosingDeclaration.getSourceFile();
            return mapToDisplayParts((writer) => {
                const printer = createPrinterWithRemoveCommentsOmitTrailingSemicolon();
                printer.writeNode(4 /* Unspecified */, node, file, writer);
            });
        }
        function isImportOrExportSpecifierName(location) {
            return !!location.parent && isImportOrExportSpecifier(location.parent) && location.parent.propertyName === location;
        }
        function getScriptKind(fileName, host) {
            return ensureScriptKind(fileName, host.getScriptKind && host.getScriptKind(fileName));
        }
        function getSymbolTarget(symbol, checker) {
            let next = symbol;
            while (isAliasSymbol(next) || isTransientSymbol(next) && next.links.target) {
                if (isTransientSymbol(next) && next.links.target) {
                    next = next.links.target;
                }
                else {
                    next = skipAlias(next, checker);
                }
            }
            return next;
        }
        function isAliasSymbol(symbol) {
            return (symbol.flags & 2097152 /* Alias */) !== 0;
        }
        function getUniqueSymbolId(symbol, checker) {
            return getSymbolId(skipAlias(symbol, checker));
        }
        function getFirstNonSpaceCharacterPosition(text, position) {
            while (isWhiteSpaceLike(text.charCodeAt(position))) {
                position += 1;
            }
            return position;
        }
        function getPrecedingNonSpaceCharacterPosition(text, position) {
            while (position > -1 && isWhiteSpaceSingleLine(text.charCodeAt(position))) {
                position -= 1;
            }
            return position + 1;
        }
        function getSynthesizedDeepClone(node, includeTrivia = true) {
            const clone2 = node && getSynthesizedDeepCloneWorker(node);
            if (clone2 && !includeTrivia)
                suppressLeadingAndTrailingTrivia(clone2);
            return clone2;
        }
        function getSynthesizedDeepCloneWithReplacements(node, includeTrivia, replaceNode) {
            let clone2 = replaceNode(node);
            if (clone2) {
                setOriginalNode(clone2, node);
            }
            else {
                clone2 = getSynthesizedDeepCloneWorker(node, replaceNode);
            }
            if (clone2 && !includeTrivia)
                suppressLeadingAndTrailingTrivia(clone2);
            return clone2;
        }
        function getSynthesizedDeepCloneWorker(node, replaceNode) {
            const nodeClone = replaceNode ? (n) => getSynthesizedDeepCloneWithReplacements(n, 
            /*includeTrivia*/
            true, replaceNode) : getSynthesizedDeepClone;
            const nodesClone = replaceNode ? (ns) => ns && getSynthesizedDeepClonesWithReplacements(ns, 
            /*includeTrivia*/
            true, replaceNode) : (ns) => ns && getSynthesizedDeepClones(ns);
            const visited = visitEachChild(node, nodeClone, 
            /*context*/
            void 0, nodesClone, nodeClone);
            if (visited === node) {
                const clone2 = isStringLiteral(node) ? setOriginalNode(factory.createStringLiteralFromNode(node), node) : isNumericLiteral(node) ? setOriginalNode(factory.createNumericLiteral(node.text, node.numericLiteralFlags), node) : factory.cloneNode(node);
                return setTextRange(clone2, node);
            }
            visited.parent = void 0;
            return visited;
        }
        function getSynthesizedDeepClones(nodes, includeTrivia = true) {
            if (nodes) {
                const cloned = factory.createNodeArray(nodes.map((n) => getSynthesizedDeepClone(n, includeTrivia)), nodes.hasTrailingComma);
                setTextRange(cloned, nodes);
                return cloned;
            }
            return nodes;
        }
        function getSynthesizedDeepClonesWithReplacements(nodes, includeTrivia, replaceNode) {
            return factory.createNodeArray(nodes.map((n) => getSynthesizedDeepCloneWithReplacements(n, includeTrivia, replaceNode)), nodes.hasTrailingComma);
        }
        function suppressLeadingAndTrailingTrivia(node) {
            suppressLeadingTrivia(node);
            suppressTrailingTrivia(node);
        }
        function suppressLeadingTrivia(node) {
            addEmitFlagsRecursively(node, 1024 /* NoLeadingComments */, getFirstChild);
        }
        function suppressTrailingTrivia(node) {
            addEmitFlagsRecursively(node, 2048 /* NoTrailingComments */, getLastChild);
        }
        function copyComments(sourceNode, targetNode) {
            const sourceFile = sourceNode.getSourceFile();
            const text = sourceFile.text;
            if (hasLeadingLineBreak(sourceNode, text)) {
                copyLeadingComments(sourceNode, targetNode, sourceFile);
            }
            else {
                copyTrailingAsLeadingComments(sourceNode, targetNode, sourceFile);
            }
            copyTrailingComments(sourceNode, targetNode, sourceFile);
        }
        function hasLeadingLineBreak(node, text) {
            const start = node.getFullStart();
            const end = node.getStart();
            for (let i = start; i < end; i++) {
                if (text.charCodeAt(i) === 10 /* lineFeed */)
                    return true;
            }
            return false;
        }
        function addEmitFlagsRecursively(node, flag, getChild) {
            addEmitFlags(node, flag);
            const child = getChild(node);
            if (child)
                addEmitFlagsRecursively(child, flag, getChild);
        }
        function getFirstChild(node) {
            return node.forEachChild((child) => child);
        }
        function getUniqueName(baseName, sourceFile) {
            let nameText = baseName;
            for (let i = 1; !isFileLevelUniqueName(sourceFile, nameText); i++) {
                nameText = `${baseName}_${i}`;
            }
            return nameText;
        }
        function getRenameLocation(edits, renameFilename, name, preferLastLocation) {
            let delta = 0;
            let lastPos = -1;
            for (const { fileName, textChanges: textChanges2 } of edits) {
                Debug.assert(fileName === renameFilename);
                for (const change of textChanges2) {
                    const { span, newText } = change;
                    const index = indexInTextChange(newText, escapeString(name));
                    if (index !== -1) {
                        lastPos = span.start + delta + index;
                        if (!preferLastLocation) {
                            return lastPos;
                        }
                    }
                    delta += newText.length - span.length;
                }
            }
            Debug.assert(preferLastLocation);
            Debug.assert(lastPos >= 0);
            return lastPos;
        }
        function copyLeadingComments(sourceNode, targetNode, sourceFile, commentKind, hasTrailingNewLine) {
            forEachLeadingCommentRange(sourceFile.text, sourceNode.pos, getAddCommentsFunction(targetNode, sourceFile, commentKind, hasTrailingNewLine, addSyntheticLeadingComment));
        }
        function copyTrailingComments(sourceNode, targetNode, sourceFile, commentKind, hasTrailingNewLine) {
            forEachTrailingCommentRange(sourceFile.text, sourceNode.end, getAddCommentsFunction(targetNode, sourceFile, commentKind, hasTrailingNewLine, addSyntheticTrailingComment));
        }
        function copyTrailingAsLeadingComments(sourceNode, targetNode, sourceFile, commentKind, hasTrailingNewLine) {
            forEachTrailingCommentRange(sourceFile.text, sourceNode.pos, getAddCommentsFunction(targetNode, sourceFile, commentKind, hasTrailingNewLine, addSyntheticLeadingComment));
        }
        function getAddCommentsFunction(targetNode, sourceFile, commentKind, hasTrailingNewLine, cb) {
            return (pos, end, kind, htnl) => {
                if (kind === 3 /* MultiLineCommentTrivia */) {
                    pos += 2;
                    end -= 2;
                }
                else {
                    pos += 2;
                }
                cb(targetNode, commentKind || kind, sourceFile.text.slice(pos, end), hasTrailingNewLine !== void 0 ? hasTrailingNewLine : htnl);
            };
        }
        function indexInTextChange(change, name) {
            if (startsWith(change, name))
                return 0;
            let idx = change.indexOf(" " + name);
            if (idx === -1)
                idx = change.indexOf("." + name);
            if (idx === -1)
                idx = change.indexOf('"' + name);
            return idx === -1 ? -1 : idx + 1;
        }
        function needsParentheses(expression) {
            return isBinaryExpression(expression) && expression.operatorToken.kind === 28 /* CommaToken */ || isObjectLiteralExpression(expression) || (isAsExpression(expression) || isSatisfiesExpression(expression)) && isObjectLiteralExpression(expression.expression);
        }
        function getContextualTypeFromParent(node, checker, contextFlags) {
            const parent2 = walkUpParenthesizedExpressions(node.parent);
            switch (parent2.kind) {
                case 214 /* NewExpression */:
                    return checker.getContextualType(parent2, contextFlags);
                case 226 /* BinaryExpression */: {
                    const { left, operatorToken, right } = parent2;
                    return isEqualityOperatorKind(operatorToken.kind) ? checker.getTypeAtLocation(node === right ? left : right) : checker.getContextualType(node, contextFlags);
                }
                case 296 /* CaseClause */:
                    return getSwitchedType(parent2, checker);
                default:
                    return checker.getContextualType(node, contextFlags);
            }
        }
        function quote(sourceFile, preferences, text) {
            const quotePreference = getQuotePreference(sourceFile, preferences);
            const quoted = JSON.stringify(text);
            return quotePreference === 0 /* Single */ ? `'${stripQuotes(quoted).replace(/'/g, () => "\\'").replace(/\\"/g, '"')}'` : quoted;
        }
        function isEqualityOperatorKind(kind) {
            switch (kind) {
                case 37 /* EqualsEqualsEqualsToken */:
                case 35 /* EqualsEqualsToken */:
                case 38 /* ExclamationEqualsEqualsToken */:
                case 36 /* ExclamationEqualsToken */:
                    return true;
                default:
                    return false;
            }
        }
        function isStringLiteralOrTemplate(node) {
            switch (node.kind) {
                case 11 /* StringLiteral */:
                case 15 /* NoSubstitutionTemplateLiteral */:
                case 228 /* TemplateExpression */:
                case 215 /* TaggedTemplateExpression */:
                    return true;
                default:
                    return false;
            }
        }
        function hasIndexSignature(type) {
            return !!type.getStringIndexType() || !!type.getNumberIndexType();
        }
        function getSwitchedType(caseClause, checker) {
            return checker.getTypeAtLocation(caseClause.parent.parent.expression);
        }
        function getTypeNodeIfAccessible(type, enclosingScope, program, host) {
            const checker = program.getTypeChecker();
            let typeIsAccessible = true;
            const notAccessible = () => typeIsAccessible = false;
            const res = checker.typeToTypeNode(type, enclosingScope, 1 /* NoTruncation */, {
                trackSymbol: (symbol, declaration, meaning) => {
                    typeIsAccessible = typeIsAccessible && checker.isSymbolAccessible(symbol, declaration, meaning, 
                    /*shouldComputeAliasToMarkVisible*/
                    false).accessibility === 0 /* Accessible */;
                    return !typeIsAccessible;
                },
                reportInaccessibleThisError: notAccessible,
                reportPrivateInBaseOfClassExpression: notAccessible,
                reportInaccessibleUniqueSymbolError: notAccessible,
                moduleResolverHost: getModuleSpecifierResolverHost(program, host)
            });
            return typeIsAccessible ? res : void 0;
        }
        function syntaxRequiresTrailingCommaOrSemicolonOrASI(kind) {
            return kind === 179 /* CallSignature */ || kind === 180 /* ConstructSignature */ || kind === 181 /* IndexSignature */ || kind === 171 /* PropertySignature */ || kind === 173 /* MethodSignature */;
        }
        function syntaxRequiresTrailingFunctionBlockOrSemicolonOrASI(kind) {
            return kind === 262 /* FunctionDeclaration */ || kind === 176 /* Constructor */ || kind === 174 /* MethodDeclaration */ || kind === 177 /* GetAccessor */ || kind === 178 /* SetAccessor */;
        }
        function syntaxRequiresTrailingModuleBlockOrSemicolonOrASI(kind) {
            return kind === 267 /* ModuleDeclaration */;
        }
        function syntaxRequiresTrailingSemicolonOrASI(kind) {
            return kind === 243 /* VariableStatement */ || kind === 244 /* ExpressionStatement */ || kind === 246 /* DoStatement */ || kind === 251 /* ContinueStatement */ || kind === 252 /* BreakStatement */ || kind === 253 /* ReturnStatement */ || kind === 257 /* ThrowStatement */ || kind === 259 /* DebuggerStatement */ || kind === 172 /* PropertyDeclaration */ || kind === 265 /* TypeAliasDeclaration */ || kind === 272 /* ImportDeclaration */ || kind === 271 /* ImportEqualsDeclaration */ || kind === 278 /* ExportDeclaration */ || kind === 270 /* NamespaceExportDeclaration */ || kind === 277 /* ExportAssignment */;
        }
        function nodeIsASICandidate(node, sourceFile) {
            const lastToken = node.getLastToken(sourceFile);
            if (lastToken && lastToken.kind === 27 /* SemicolonToken */) {
                return false;
            }
            if (syntaxRequiresTrailingCommaOrSemicolonOrASI(node.kind)) {
                if (lastToken && lastToken.kind === 28 /* CommaToken */) {
                    return false;
                }
            }
            else if (syntaxRequiresTrailingModuleBlockOrSemicolonOrASI(node.kind)) {
                const lastChild = last(node.getChildren(sourceFile));
                if (lastChild && isModuleBlock(lastChild)) {
                    return false;
                }
            }
            else if (syntaxRequiresTrailingFunctionBlockOrSemicolonOrASI(node.kind)) {
                const lastChild = last(node.getChildren(sourceFile));
                if (lastChild && isFunctionBlock(lastChild)) {
                    return false;
                }
            }
            else if (!syntaxRequiresTrailingSemicolonOrASI(node.kind)) {
                return false;
            }
            if (node.kind === 246 /* DoStatement */) {
                return true;
            }
            const topNode = findAncestor(node, (ancestor) => !ancestor.parent);
            const nextToken = findNextToken(node, topNode, sourceFile);
            if (!nextToken || nextToken.kind === 20 /* CloseBraceToken */) {
                return true;
            }
            const startLine = sourceFile.getLineAndCharacterOfPosition(node.getEnd()).line;
            const endLine = sourceFile.getLineAndCharacterOfPosition(nextToken.getStart(sourceFile)).line;
            return startLine !== endLine;
        }
        function positionIsASICandidate(pos, context, sourceFile) {
            const contextAncestor = findAncestor(context, (ancestor) => {
                if (ancestor.end !== pos) {
                    return "quit";
                }
                return syntaxMayBeASICandidate(ancestor.kind);
            });
            return !!contextAncestor && nodeIsASICandidate(contextAncestor, sourceFile);
        }
        function probablyUsesSemicolons(sourceFile) {
            let withSemicolon = 0;
            let withoutSemicolon = 0;
            const nStatementsToObserve = 5;
            forEachChild(sourceFile, function visit(node) {
                if (syntaxRequiresTrailingSemicolonOrASI(node.kind)) {
                    const lastToken = node.getLastToken(sourceFile);
                    if ((lastToken == null ? void 0 : lastToken.kind) === 27 /* SemicolonToken */) {
                        withSemicolon++;
                    }
                    else {
                        withoutSemicolon++;
                    }
                }
                else if (syntaxRequiresTrailingCommaOrSemicolonOrASI(node.kind)) {
                    const lastToken = node.getLastToken(sourceFile);
                    if ((lastToken == null ? void 0 : lastToken.kind) === 27 /* SemicolonToken */) {
                        withSemicolon++;
                    }
                    else if (lastToken && lastToken.kind !== 28 /* CommaToken */) {
                        const lastTokenLine = getLineAndCharacterOfPosition(sourceFile, lastToken.getStart(sourceFile)).line;
                        const nextTokenLine = getLineAndCharacterOfPosition(sourceFile, getSpanOfTokenAtPosition(sourceFile, lastToken.end).start).line;
                        if (lastTokenLine !== nextTokenLine) {
                            withoutSemicolon++;
                        }
                    }
                }
                if (withSemicolon + withoutSemicolon >= nStatementsToObserve) {
                    return true;
                }
                return forEachChild(node, visit);
            });
            if (withSemicolon === 0 && withoutSemicolon <= 1) {
                return true;
            }
            return withSemicolon / withoutSemicolon > 1 / nStatementsToObserve;
        }
        function tryGetDirectories(host, directoryName) {
            return tryIOAndConsumeErrors(host, host.getDirectories, directoryName) || [];
        }
        function tryReadDirectory(host, path, extensions, exclude, include) {
            return tryIOAndConsumeErrors(host, host.readDirectory, path, extensions, exclude, include) || emptyArray;
        }
        function tryFileExists(host, path) {
            return tryIOAndConsumeErrors(host, host.fileExists, path);
        }
        function tryDirectoryExists(host, path) {
            return tryAndIgnoreErrors(() => directoryProbablyExists(path, host)) || false;
        }
        function tryAndIgnoreErrors(cb) {
            try {
                return cb();
            }
            catch {
                return void 0;
            }
        }
        function tryIOAndConsumeErrors(host, toApply, ...args) {
            return tryAndIgnoreErrors(() => toApply && toApply.apply(host, args));
        }
        function findPackageJsons(startDirectory, host, stopDirectory) {
            const paths = [];
            forEachAncestorDirectory(startDirectory, (ancestor) => {
                if (ancestor === stopDirectory) {
                    return true;
                }
                const currentConfigPath = combinePaths(ancestor, "package.json");
                if (tryFileExists(host, currentConfigPath)) {
                    paths.push(currentConfigPath);
                }
            });
            return paths;
        }
        function findPackageJson(directory, host) {
            let packageJson;
            forEachAncestorDirectory(directory, (ancestor) => {
                if (ancestor === "node_modules")
                    return true;
                packageJson = findConfigFile(ancestor, (f) => tryFileExists(host, f), "package.json");
                if (packageJson) {
                    return true;
                }
            });
            return packageJson;
        }
        function getPackageJsonsVisibleToFile(fileName, host) {
            if (!host.fileExists) {
                return [];
            }
            const packageJsons = [];
            forEachAncestorDirectory(getDirectoryPath(fileName), (ancestor) => {
                const packageJsonFileName = combinePaths(ancestor, "package.json");
                if (host.fileExists(packageJsonFileName)) {
                    const info = createPackageJsonInfo(packageJsonFileName, host);
                    if (info) {
                        packageJsons.push(info);
                    }
                }
            });
            return packageJsons;
        }
        function createPackageJsonInfo(fileName, host) {
            if (!host.readFile) {
                return void 0;
            }
            const dependencyKeys = ["dependencies", "devDependencies", "optionalDependencies", "peerDependencies"];
            const stringContent = host.readFile(fileName) || "";
            const content = tryParseJson(stringContent);
            const info = {};
            if (content) {
                for (const key of dependencyKeys) {
                    const dependencies = content[key];
                    if (!dependencies) {
                        continue;
                    }
                    const dependencyMap = /* @__PURE__ */ new Map();
                    for (const packageName in dependencies) {
                        dependencyMap.set(packageName, dependencies[packageName]);
                    }
                    info[key] = dependencyMap;
                }
            }
            const dependencyGroups = [
                [1 /* Dependencies */, info.dependencies],
                [2 /* DevDependencies */, info.devDependencies],
                [8 /* OptionalDependencies */, info.optionalDependencies],
                [4 /* PeerDependencies */, info.peerDependencies]
            ];
            return {
                ...info,
                parseable: !!content,
                fileName,
                get,
                has(dependencyName, inGroups) {
                    return !!get(dependencyName, inGroups);
                }
            };
            function get(dependencyName, inGroups = 15 /* All */) {
                for (const [group2, deps] of dependencyGroups) {
                    if (deps && inGroups & group2) {
                        const dep = deps.get(dependencyName);
                        if (dep !== void 0) {
                            return dep;
                        }
                    }
                }
            }
        }
        function createPackageJsonImportFilter(fromFile, preferences, host) {
            const packageJsons = (host.getPackageJsonsVisibleToFile && host.getPackageJsonsVisibleToFile(fromFile.fileName) || getPackageJsonsVisibleToFile(fromFile.fileName, host)).filter((p) => p.parseable);
            let usesNodeCoreModules;
            let ambientModuleCache;
            let sourceFileCache;
            return {
                allowsImportingAmbientModule,
                allowsImportingSourceFile,
                allowsImportingSpecifier
            };
            function moduleSpecifierIsCoveredByPackageJson(specifier) {
                const packageName = getNodeModuleRootSpecifier(specifier);
                for (const packageJson of packageJsons) {
                    if (packageJson.has(packageName) || packageJson.has(getTypesPackageName(packageName))) {
                        return true;
                    }
                }
                return false;
            }
            function allowsImportingAmbientModule(moduleSymbol, moduleSpecifierResolutionHost) {
                if (!packageJsons.length || !moduleSymbol.valueDeclaration) {
                    return true;
                }
                if (!ambientModuleCache) {
                    ambientModuleCache = /* @__PURE__ */ new Map();
                }
                else {
                    const cached = ambientModuleCache.get(moduleSymbol);
                    if (cached !== void 0) {
                        return cached;
                    }
                }
                const declaredModuleSpecifier = stripQuotes(moduleSymbol.getName());
                if (isAllowedCoreNodeModulesImport(declaredModuleSpecifier)) {
                    ambientModuleCache.set(moduleSymbol, true);
                    return true;
                }
                const declaringSourceFile = moduleSymbol.valueDeclaration.getSourceFile();
                const declaringNodeModuleName = getNodeModulesPackageNameFromFileName(declaringSourceFile.fileName, moduleSpecifierResolutionHost);
                if (typeof declaringNodeModuleName === "undefined") {
                    ambientModuleCache.set(moduleSymbol, true);
                    return true;
                }
                const result = moduleSpecifierIsCoveredByPackageJson(declaringNodeModuleName) || moduleSpecifierIsCoveredByPackageJson(declaredModuleSpecifier);
                ambientModuleCache.set(moduleSymbol, result);
                return result;
            }
            function allowsImportingSourceFile(sourceFile, moduleSpecifierResolutionHost) {
                if (!packageJsons.length) {
                    return true;
                }
                if (!sourceFileCache) {
                    sourceFileCache = /* @__PURE__ */ new Map();
                }
                else {
                    const cached = sourceFileCache.get(sourceFile);
                    if (cached !== void 0) {
                        return cached;
                    }
                }
                const moduleSpecifier = getNodeModulesPackageNameFromFileName(sourceFile.fileName, moduleSpecifierResolutionHost);
                if (!moduleSpecifier) {
                    sourceFileCache.set(sourceFile, true);
                    return true;
                }
                const result = moduleSpecifierIsCoveredByPackageJson(moduleSpecifier);
                sourceFileCache.set(sourceFile, result);
                return result;
            }
            function allowsImportingSpecifier(moduleSpecifier) {
                if (!packageJsons.length || isAllowedCoreNodeModulesImport(moduleSpecifier)) {
                    return true;
                }
                if (pathIsRelative(moduleSpecifier) || isRootedDiskPath(moduleSpecifier)) {
                    return true;
                }
                return moduleSpecifierIsCoveredByPackageJson(moduleSpecifier);
            }
            function isAllowedCoreNodeModulesImport(moduleSpecifier) {
                if (isSourceFileJS(fromFile) && ts_JsTyping_exports.nodeCoreModules.has(moduleSpecifier)) {
                    if (usesNodeCoreModules === void 0) {
                        usesNodeCoreModules = consumesNodeCoreModules(fromFile);
                    }
                    if (usesNodeCoreModules) {
                        return true;
                    }
                }
                return false;
            }
            function getNodeModulesPackageNameFromFileName(importedFileName, moduleSpecifierResolutionHost) {
                if (!importedFileName.includes("node_modules")) {
                    return void 0;
                }
                const specifier = ts_moduleSpecifiers_exports.getNodeModulesPackageName(host.getCompilationSettings(), fromFile, importedFileName, moduleSpecifierResolutionHost, preferences);
                if (!specifier) {
                    return void 0;
                }
                if (!pathIsRelative(specifier) && !isRootedDiskPath(specifier)) {
                    return getNodeModuleRootSpecifier(specifier);
                }
            }
            function getNodeModuleRootSpecifier(fullSpecifier) {
                const components = getPathComponents(getPackageNameFromTypesPackageName(fullSpecifier)).slice(1);
                if (startsWith(components[0], "@")) {
                    return `${components[0]}/${components[1]}`;
                }
                return components[0];
            }
        }
        function consumesNodeCoreModules(sourceFile) {
            return some(sourceFile.imports, ({ text }) => ts_JsTyping_exports.nodeCoreModules.has(text));
        }
        function isInsideNodeModules(fileOrDirectory) {
            return contains(getPathComponents(fileOrDirectory), "node_modules");
        }
        function isDiagnosticWithLocation(diagnostic) {
            return diagnostic.file !== void 0 && diagnostic.start !== void 0 && diagnostic.length !== void 0;
        }
        function findDiagnosticForNode(node, sortedFileDiagnostics) {
            const span = createTextSpanFromNode(node);
            const index = binarySearchKey(sortedFileDiagnostics, span, identity, compareTextSpans);
            if (index >= 0) {
                const diagnostic = sortedFileDiagnostics[index];
                Debug.assertEqual(diagnostic.file, node.getSourceFile(), "Diagnostics proided to 'findDiagnosticForNode' must be from a single SourceFile");
                return cast(diagnostic, isDiagnosticWithLocation);
            }
        }
        function getDiagnosticsWithinSpan(span, sortedFileDiagnostics) {
            var _a;
            let index = binarySearchKey(sortedFileDiagnostics, span.start, (diag2) => diag2.start, compareValues);
            if (index < 0) {
                index = ~index;
            }
            while (((_a = sortedFileDiagnostics[index - 1]) == null ? void 0 : _a.start) === span.start) {
                index--;
            }
            const result = [];
            const end = textSpanEnd(span);
            while (true) {
                const diagnostic = tryCast(sortedFileDiagnostics[index], isDiagnosticWithLocation);
                if (!diagnostic || diagnostic.start > end) {
                    break;
                }
                if (textSpanContainsTextSpan(span, diagnostic)) {
                    result.push(diagnostic);
                }
                index++;
            }
            return result;
        }
        function getRefactorContextSpan({ startPosition, endPosition }) {
            return createTextSpanFromBounds(startPosition, endPosition === void 0 ? startPosition : endPosition);
        }
        function getFixableErrorSpanExpression(sourceFile, span) {
            const token = getTokenAtPosition(sourceFile, span.start);
            const expression = findAncestor(token, (node) => {
                if (node.getStart(sourceFile) < span.start || node.getEnd() > textSpanEnd(span)) {
                    return "quit";
                }
                return isExpression(node) && textSpansEqual(span, createTextSpanFromNode(node, sourceFile));
            });
            return expression;
        }
        function mapOneOrMany(valueOrArray, f, resultSelector = identity) {
            return valueOrArray ? isArray(valueOrArray) ? resultSelector(map(valueOrArray, f)) : f(valueOrArray, 0) : void 0;
        }
        function firstOrOnly(valueOrArray) {
            return isArray(valueOrArray) ? first(valueOrArray) : valueOrArray;
        }
        function getNamesForExportedSymbol(symbol, scriptTarget) {
            if (needsNameFromDeclaration(symbol)) {
                const fromDeclaration = getDefaultLikeExportNameFromDeclaration(symbol);
                if (fromDeclaration)
                    return fromDeclaration;
                const fileNameCase = ts_codefix_exports.moduleSymbolToValidIdentifier(getSymbolParentOrFail(symbol), scriptTarget, 
                /*forceCapitalize*/
                false);
                const capitalized = ts_codefix_exports.moduleSymbolToValidIdentifier(getSymbolParentOrFail(symbol), scriptTarget, 
                /*forceCapitalize*/
                true);
                if (fileNameCase === capitalized)
                    return fileNameCase;
                return [fileNameCase, capitalized];
            }
            return symbol.name;
        }
        function getNameForExportedSymbol(symbol, scriptTarget, preferCapitalized) {
            if (needsNameFromDeclaration(symbol)) {
                return getDefaultLikeExportNameFromDeclaration(symbol) || ts_codefix_exports.moduleSymbolToValidIdentifier(getSymbolParentOrFail(symbol), scriptTarget, !!preferCapitalized);
            }
            return symbol.name;
        }
        function needsNameFromDeclaration(symbol) {
            return !(symbol.flags & 33554432 /* Transient */) && (symbol.escapedName === "export=" /* ExportEquals */ || symbol.escapedName === "default" /* Default */);
        }
        function getDefaultLikeExportNameFromDeclaration(symbol) {
            return firstDefined(symbol.declarations, (d) => {
                var _a, _b, _c;
                if (isExportAssignment(d)) {
                    return (_a = tryCast(skipOuterExpressions(d.expression), isIdentifier)) == null ? void 0 : _a.text;
                }
                if (isExportSpecifier(d) && d.symbol.flags === 2097152 /* Alias */) {
                    return (_b = tryCast(d.propertyName, isIdentifier)) == null ? void 0 : _b.text;
                }
                return (_c = tryCast(getNameOfDeclaration(d), isIdentifier)) == null ? void 0 : _c.text;
            });
        }
        function getSymbolParentOrFail(symbol) {
            var _a;
            return Debug.checkDefined(symbol.parent, `Symbol parent was undefined. Flags: ${Debug.formatSymbolFlags(symbol.flags)}. Declarations: ${(_a = symbol.declarations) == null ? void 0 : _a.map((d) => {
                const kind = Debug.formatSyntaxKind(d.kind);
                const inJS = isInJSFile(d);
                const { expression } = d;
                return (inJS ? "[JS]" : "") + kind + (expression ? ` (expression: ${Debug.formatSyntaxKind(expression.kind)})` : "");
            }).join(", ")}.`);
        }
        function stringContainsAt(haystack, needle, startIndex) {
            const needleLength = needle.length;
            if (needleLength + startIndex > haystack.length) {
                return false;
            }
            for (let i = 0; i < needleLength; i++) {
                if (needle.charCodeAt(i) !== haystack.charCodeAt(i + startIndex))
                    return false;
            }
            return true;
        }
        function startsWithUnderscore(name) {
            return name.charCodeAt(0) === 95 /* _ */;
        }
        function isGlobalDeclaration(declaration) {
            return !isNonGlobalDeclaration(declaration);
        }
        function isNonGlobalDeclaration(declaration) {
            const sourceFile = declaration.getSourceFile();
            if (!sourceFile.externalModuleIndicator && !sourceFile.commonJsModuleIndicator) {
                return false;
            }
            return isInJSFile(declaration) || !findAncestor(declaration, (d) => isModuleDeclaration(d) && isGlobalScopeAugmentation(d));
        }
        function isDeprecatedDeclaration(decl) {
            return !!(getCombinedNodeFlagsAlwaysIncludeJSDoc(decl) & 65536 /* Deprecated */);
        }
        function shouldUseUriStyleNodeCoreModules(file, program) {
            const decisionFromFile = firstDefined(file.imports, (node) => {
                if (ts_JsTyping_exports.nodeCoreModules.has(node.text)) {
                    return startsWith(node.text, "node:");
                }
            });
            return decisionFromFile ?? program.usesUriStyleNodeCoreModules;
        }
        function getNewLineKind(newLineCharacter) {
            return newLineCharacter === "\n" ? 1 /* LineFeed */ : 0 /* CarriageReturnLineFeed */;
        }
        function diagnosticToString(diag2) {
            return isArray(diag2) ? formatStringFromArgs(getLocaleSpecificMessage(diag2[0]), diag2.slice(1)) : getLocaleSpecificMessage(diag2);
        }
        function getFormatCodeSettingsForWriting({ options }, sourceFile) {
            const shouldAutoDetectSemicolonPreference = !options.semicolons || options.semicolons === "ignore" /* Ignore */;
            const shouldRemoveSemicolons = options.semicolons === "remove" /* Remove */ || shouldAutoDetectSemicolonPreference && !probablyUsesSemicolons(sourceFile);
            return {
                ...options,
                semicolons: shouldRemoveSemicolons ? "remove" /* Remove */ : "ignore" /* Ignore */
            };
        }
        function jsxModeNeedsExplicitImport(jsx) {
            return jsx === 2 /* React */ || jsx === 3 /* ReactNative */;
        }
        function isSourceFileFromLibrary(program, node) {
            return program.isSourceFileFromExternalLibrary(node) || program.isSourceFileDefaultLibrary(node);
        }
        function newCaseClauseTracker(checker, clauses) {
            const existingStrings = /* @__PURE__ */ new Set();
            const existingNumbers = /* @__PURE__ */ new Set();
            const existingBigInts = /* @__PURE__ */ new Set();
            for (const clause of clauses) {
                if (!isDefaultClause(clause)) {
                    const expression = skipParentheses(clause.expression);
                    if (isLiteralExpression(expression)) {
                        switch (expression.kind) {
                            case 15 /* NoSubstitutionTemplateLiteral */:
                            case 11 /* StringLiteral */:
                                existingStrings.add(expression.text);
                                break;
                            case 9 /* NumericLiteral */:
                                existingNumbers.add(parseInt(expression.text));
                                break;
                            case 10 /* BigIntLiteral */:
                                const parsedBigInt = parseBigInt(endsWith(expression.text, "n") ? expression.text.slice(0, -1) : expression.text);
                                if (parsedBigInt) {
                                    existingBigInts.add(pseudoBigIntToString(parsedBigInt));
                                }
                                break;
                        }
                    }
                    else {
                        const symbol = checker.getSymbolAtLocation(clause.expression);
                        if (symbol && symbol.valueDeclaration && isEnumMember(symbol.valueDeclaration)) {
                            const enumValue = checker.getConstantValue(symbol.valueDeclaration);
                            if (enumValue !== void 0) {
                                addValue(enumValue);
                            }
                        }
                    }
                }
            }
            return {
                addValue,
                hasValue
            };
            function addValue(value) {
                switch (typeof value) {
                    case "string":
                        existingStrings.add(value);
                        break;
                    case "number":
                        existingNumbers.add(value);
                }
            }
            function hasValue(value) {
                switch (typeof value) {
                    case "string":
                        return existingStrings.has(value);
                    case "number":
                        return existingNumbers.has(value);
                    case "object":
                        return existingBigInts.has(pseudoBigIntToString(value));
                }
            }
        }
        function fileShouldUseJavaScriptRequire(file, program, host, preferRequire) {
            var _a;
            const fileName = typeof file === "string" ? file : file.fileName;
            if (!hasJSFileExtension(fileName)) {
                return false;
            }
            const compilerOptions = program.getCompilerOptions();
            const moduleKind = getEmitModuleKind(compilerOptions);
            const impliedNodeFormat = typeof file === "string" ? getImpliedNodeFormatForFile(toPath(file, host.getCurrentDirectory(), hostGetCanonicalFileName(host)), (_a = program.getPackageJsonInfoCache) == null ? void 0 : _a.call(program), host, compilerOptions) : file.impliedNodeFormat;
            if (impliedNodeFormat === 99 /* ESNext */) {
                return false;
            }
            if (impliedNodeFormat === 1 /* CommonJS */) {
                return true;
            }
            if (compilerOptions.verbatimModuleSyntax && moduleKind === 1 /* CommonJS */) {
                return true;
            }
            if (compilerOptions.verbatimModuleSyntax && emitModuleKindIsNonNodeESM(moduleKind)) {
                return false;
            }
            if (typeof file === "object") {
                if (file.commonJsModuleIndicator) {
                    return true;
                }
                if (file.externalModuleIndicator) {
                    return false;
                }
            }
            return preferRequire;
        }
        var scanner, SemanticMeaning, tripleSlashDirectivePrefixRegex, typeKeywords, QuotePreference, displayPartWriter, lineFeed2, ANONYMOUS, syntaxMayBeASICandidate;
        var init_utilities4 = __esm({
            "src/services/utilities.ts"() {
                "use strict";
                init_ts4();
                scanner = createScanner(99 /* Latest */, 
                /*skipTrivia*/
                true);
                SemanticMeaning = /* @__PURE__ */ ((SemanticMeaning3) => {
                    SemanticMeaning3[SemanticMeaning3["None"] = 0] = "None";
                    SemanticMeaning3[SemanticMeaning3["Value"] = 1] = "Value";
                    SemanticMeaning3[SemanticMeaning3["Type"] = 2] = "Type";
                    SemanticMeaning3[SemanticMeaning3["Namespace"] = 4] = "Namespace";
                    SemanticMeaning3[SemanticMeaning3["All"] = 7] = "All";
                    return SemanticMeaning3;
                })(SemanticMeaning || {});
                tripleSlashDirectivePrefixRegex = /^\/\/\/\s*</;
                typeKeywords = [
                    133 /* AnyKeyword */,
                    131 /* AssertsKeyword */,
                    163 /* BigIntKeyword */,
                    136 /* BooleanKeyword */,
                    97 /* FalseKeyword */,
                    140 /* InferKeyword */,
                    143 /* KeyOfKeyword */,
                    146 /* NeverKeyword */,
                    106 /* NullKeyword */,
                    150 /* NumberKeyword */,
                    151 /* ObjectKeyword */,
                    148 /* ReadonlyKeyword */,
                    154 /* StringKeyword */,
                    155 /* SymbolKeyword */,
                    114 /* TypeOfKeyword */,
                    112 /* TrueKeyword */,
                    116 /* VoidKeyword */,
                    157 /* UndefinedKeyword */,
                    158 /* UniqueKeyword */,
                    159 /* UnknownKeyword */
                ];
                QuotePreference = /* @__PURE__ */ ((QuotePreference7) => {
                    QuotePreference7[QuotePreference7["Single"] = 0] = "Single";
                    QuotePreference7[QuotePreference7["Double"] = 1] = "Double";
                    return QuotePreference7;
                })(QuotePreference || {});
                displayPartWriter = getDisplayPartWriter();
                lineFeed2 = "\n";
                ANONYMOUS = "anonymous function";
                syntaxMayBeASICandidate = or(syntaxRequiresTrailingCommaOrSemicolonOrASI, syntaxRequiresTrailingFunctionBlockOrSemicolonOrASI, syntaxRequiresTrailingModuleBlockOrSemicolonOrASI, syntaxRequiresTrailingSemicolonOrASI);
            }
        });
        // src/services/exportInfoMap.ts
        function createCacheableExportInfoMap(host) {
            let exportInfoId = 1;
            const exportInfo = createMultiMap();
            const symbols = /* @__PURE__ */ new Map();
            const packages = /* @__PURE__ */ new Map();
            let usableByFileName;
            const cache = {
                isUsableByFile: (importingFile) => importingFile === usableByFileName,
                isEmpty: () => !exportInfo.size,
                clear: () => {
                    exportInfo.clear();
                    symbols.clear();
                    usableByFileName = void 0;
                },
                add: (importingFile, symbol, symbolTableKey, moduleSymbol, moduleFile, exportKind, isFromPackageJson, checker) => {
                    if (importingFile !== usableByFileName) {
                        cache.clear();
                        usableByFileName = importingFile;
                    }
                    let packageName;
                    if (moduleFile) {
                        const nodeModulesPathParts = getNodeModulePathParts(moduleFile.fileName);
                        if (nodeModulesPathParts) {
                            const { topLevelNodeModulesIndex, topLevelPackageNameIndex, packageRootIndex } = nodeModulesPathParts;
                            packageName = unmangleScopedPackageName(getPackageNameFromTypesPackageName(moduleFile.fileName.substring(topLevelPackageNameIndex + 1, packageRootIndex)));
                            if (startsWith(importingFile, moduleFile.path.substring(0, topLevelNodeModulesIndex))) {
                                const prevDeepestNodeModulesPath = packages.get(packageName);
                                const nodeModulesPath = moduleFile.fileName.substring(0, topLevelPackageNameIndex + 1);
                                if (prevDeepestNodeModulesPath) {
                                    const prevDeepestNodeModulesIndex = prevDeepestNodeModulesPath.indexOf(nodeModulesPathPart);
                                    if (topLevelNodeModulesIndex > prevDeepestNodeModulesIndex) {
                                        packages.set(packageName, nodeModulesPath);
                                    }
                                }
                                else {
                                    packages.set(packageName, nodeModulesPath);
                                }
                            }
                        }
                    }
                    const isDefault = exportKind === 1 /* Default */;
                    const namedSymbol = isDefault && getLocalSymbolForExportDefault(symbol) || symbol;
                    const names = exportKind === 0 /* Named */ || isExternalModuleSymbol(namedSymbol) ? unescapeLeadingUnderscores(symbolTableKey) : getNamesForExportedSymbol(namedSymbol, 
                    /*scriptTarget*/
                    void 0);
                    const symbolName2 = typeof names === "string" ? names : names[0];
                    const capitalizedSymbolName = typeof names === "string" ? void 0 : names[1];
                    const moduleName = stripQuotes(moduleSymbol.name);
                    const id = exportInfoId++;
                    const target = skipAlias(symbol, checker);
                    const storedSymbol = symbol.flags & 33554432 /* Transient */ ? void 0 : symbol;
                    const storedModuleSymbol = moduleSymbol.flags & 33554432 /* Transient */ ? void 0 : moduleSymbol;
                    if (!storedSymbol || !storedModuleSymbol)
                        symbols.set(id, [symbol, moduleSymbol]);
                    exportInfo.add(key(symbolName2, symbol, isExternalModuleNameRelative(moduleName) ? void 0 : moduleName, checker), {
                        id,
                        symbolTableKey,
                        symbolName: symbolName2,
                        capitalizedSymbolName,
                        moduleName,
                        moduleFile,
                        moduleFileName: moduleFile == null ? void 0 : moduleFile.fileName,
                        packageName,
                        exportKind,
                        targetFlags: target.flags,
                        isFromPackageJson,
                        symbol: storedSymbol,
                        moduleSymbol: storedModuleSymbol
                    });
                },
                get: (importingFile, key2) => {
                    if (importingFile !== usableByFileName)
                        return;
                    const result = exportInfo.get(key2);
                    return result == null ? void 0 : result.map(rehydrateCachedInfo);
                },
                search: (importingFile, preferCapitalized, matches, action) => {
                    if (importingFile !== usableByFileName)
                        return;
                    return forEachEntry(exportInfo, (info, key2) => {
                        const { symbolName: symbolName2, ambientModuleName } = parseKey(key2);
                        const name = preferCapitalized && info[0].capitalizedSymbolName || symbolName2;
                        if (matches(name, info[0].targetFlags)) {
                            const rehydrated = info.map(rehydrateCachedInfo);
                            const filtered = rehydrated.filter((r, i) => isNotShadowedByDeeperNodeModulesPackage(r, info[i].packageName));
                            if (filtered.length) {
                                const res = action(filtered, name, !!ambientModuleName, key2);
                                if (res !== void 0)
                                    return res;
                            }
                        }
                    });
                },
                releaseSymbols: () => {
                    symbols.clear();
                },
                onFileChanged: (oldSourceFile, newSourceFile, typeAcquisitionEnabled) => {
                    if (fileIsGlobalOnly(oldSourceFile) && fileIsGlobalOnly(newSourceFile)) {
                        return false;
                    }
                    if (usableByFileName && usableByFileName !== newSourceFile.path || // If ATA is enabled, auto-imports uses existing imports to guess whether you want auto-imports from node.
                        // Adding or removing imports from node could change the outcome of that guess, so could change the suggestions list.
                        typeAcquisitionEnabled && consumesNodeCoreModules(oldSourceFile) !== consumesNodeCoreModules(newSourceFile) || // Module agumentation and ambient module changes can add or remove exports available to be auto-imported.
                        // Changes elsewhere in the file can change the *type* of an export in a module augmentation,
                        // but type info is gathered in getCompletionEntryDetails, which doesn't use the cache.
                        !arrayIsEqualTo(oldSourceFile.moduleAugmentations, newSourceFile.moduleAugmentations) || !ambientModuleDeclarationsAreEqual(oldSourceFile, newSourceFile)) {
                        cache.clear();
                        return true;
                    }
                    usableByFileName = newSourceFile.path;
                    return false;
                }
            };
            if (Debug.isDebugging) {
                Object.defineProperty(cache, "__cache", { value: exportInfo });
            }
            return cache;
            function rehydrateCachedInfo(info) {
                if (info.symbol && info.moduleSymbol)
                    return info;
                const { id, exportKind, targetFlags, isFromPackageJson, moduleFileName } = info;
                const [cachedSymbol, cachedModuleSymbol] = symbols.get(id) || emptyArray;
                if (cachedSymbol && cachedModuleSymbol) {
                    return {
                        symbol: cachedSymbol,
                        moduleSymbol: cachedModuleSymbol,
                        moduleFileName,
                        exportKind,
                        targetFlags,
                        isFromPackageJson
                    };
                }
                const checker = (isFromPackageJson ? host.getPackageJsonAutoImportProvider() : host.getCurrentProgram()).getTypeChecker();
                const moduleSymbol = info.moduleSymbol || cachedModuleSymbol || Debug.checkDefined(info.moduleFile ? checker.getMergedSymbol(info.moduleFile.symbol) : checker.tryFindAmbientModule(info.moduleName));
                const symbol = info.symbol || cachedSymbol || Debug.checkDefined(exportKind === 2 /* ExportEquals */ ? checker.resolveExternalModuleSymbol(moduleSymbol) : checker.tryGetMemberInModuleExportsAndProperties(unescapeLeadingUnderscores(info.symbolTableKey), moduleSymbol), `Could not find symbol '${info.symbolName}' by key '${info.symbolTableKey}' in module ${moduleSymbol.name}`);
                symbols.set(id, [symbol, moduleSymbol]);
                return {
                    symbol,
                    moduleSymbol,
                    moduleFileName,
                    exportKind,
                    targetFlags,
                    isFromPackageJson
                };
            }
            function key(importedName, symbol, ambientModuleName, checker) {
                const moduleKey = ambientModuleName || "";
                return `${importedName.length} ${getSymbolId(skipAlias(symbol, checker))} ${importedName} ${moduleKey}`;
            }
            function parseKey(key2) {
                const firstSpace = key2.indexOf(" ");
                const secondSpace = key2.indexOf(" ", firstSpace + 1);
                const symbolNameLength = parseInt(key2.substring(0, firstSpace), 10);
                const data = key2.substring(secondSpace + 1);
                const symbolName2 = data.substring(0, symbolNameLength);
                const moduleKey = data.substring(symbolNameLength + 1);
                const ambientModuleName = moduleKey === "" ? void 0 : moduleKey;
                return { symbolName: symbolName2, ambientModuleName };
            }
            function fileIsGlobalOnly(file) {
                return !file.commonJsModuleIndicator && !file.externalModuleIndicator && !file.moduleAugmentations && !file.ambientModuleNames;
            }
            function ambientModuleDeclarationsAreEqual(oldSourceFile, newSourceFile) {
                if (!arrayIsEqualTo(oldSourceFile.ambientModuleNames, newSourceFile.ambientModuleNames)) {
                    return false;
                }
                let oldFileStatementIndex = -1;
                let newFileStatementIndex = -1;
                for (const ambientModuleName of newSourceFile.ambientModuleNames) {
                    const isMatchingModuleDeclaration = (node) => isNonGlobalAmbientModule(node) && node.name.text === ambientModuleName;
                    oldFileStatementIndex = findIndex(oldSourceFile.statements, isMatchingModuleDeclaration, oldFileStatementIndex + 1);
                    newFileStatementIndex = findIndex(newSourceFile.statements, isMatchingModuleDeclaration, newFileStatementIndex + 1);
                    if (oldSourceFile.statements[oldFileStatementIndex] !== newSourceFile.statements[newFileStatementIndex]) {
                        return false;
                    }
                }
                return true;
            }
            function isNotShadowedByDeeperNodeModulesPackage(info, packageName) {
                if (!packageName || !info.moduleFileName)
                    return true;
                const typingsCacheLocation = host.getGlobalTypingsCacheLocation();
                if (typingsCacheLocation && startsWith(info.moduleFileName, typingsCacheLocation))
                    return true;
                const packageDeepestNodeModulesPath = packages.get(packageName);
                return !packageDeepestNodeModulesPath || startsWith(info.moduleFileName, packageDeepestNodeModulesPath);
            }
        }
        function isImportableFile(program, from, to, preferences, packageJsonFilter, moduleSpecifierResolutionHost, moduleSpecifierCache) {
            var _a;
            if (from === to)
                return false;
            const cachedResult = moduleSpecifierCache == null ? void 0 : moduleSpecifierCache.get(from.path, to.path, preferences, {});
            if ((cachedResult == null ? void 0 : cachedResult.isBlockedByPackageJsonDependencies) !== void 0) {
                return !cachedResult.isBlockedByPackageJsonDependencies;
            }
            const getCanonicalFileName = hostGetCanonicalFileName(moduleSpecifierResolutionHost);
            const globalTypingsCache = (_a = moduleSpecifierResolutionHost.getGlobalTypingsCacheLocation) == null ? void 0 : _a.call(moduleSpecifierResolutionHost);
            const hasImportablePath = !!ts_moduleSpecifiers_exports.forEachFileNameOfModule(from.fileName, to.fileName, moduleSpecifierResolutionHost, 
            /*preferSymlinks*/
            false, (toPath3) => {
                const toFile = program.getSourceFile(toPath3);
                return (toFile === to || !toFile) && isImportablePath(from.fileName, toPath3, getCanonicalFileName, globalTypingsCache);
            });
            if (packageJsonFilter) {
                const isAutoImportable = hasImportablePath && packageJsonFilter.allowsImportingSourceFile(to, moduleSpecifierResolutionHost);
                moduleSpecifierCache == null ? void 0 : moduleSpecifierCache.setBlockedByPackageJsonDependencies(from.path, to.path, preferences, {}, !isAutoImportable);
                return isAutoImportable;
            }
            return hasImportablePath;
        }
        function isImportablePath(fromPath, toPath3, getCanonicalFileName, globalCachePath) {
            const toNodeModules = forEachAncestorDirectory(toPath3, (ancestor) => getBaseFileName(ancestor) === "node_modules" ? ancestor : void 0);
            const toNodeModulesParent = toNodeModules && getDirectoryPath(getCanonicalFileName(toNodeModules));
            return toNodeModulesParent === void 0 || startsWith(getCanonicalFileName(fromPath), toNodeModulesParent) || !!globalCachePath && startsWith(getCanonicalFileName(globalCachePath), toNodeModulesParent);
        }
        function forEachExternalModuleToImportFrom(program, host, preferences, useAutoImportProvider, cb) {
            var _a, _b;
            const useCaseSensitiveFileNames2 = hostUsesCaseSensitiveFileNames(host);
            const excludePatterns = preferences.autoImportFileExcludePatterns && mapDefined(preferences.autoImportFileExcludePatterns, (spec) => {
                const pattern = getSubPatternFromSpec(spec, "", "exclude");
                return pattern ? getRegexFromPattern(pattern, useCaseSensitiveFileNames2) : void 0;
            });
            forEachExternalModule(program.getTypeChecker(), program.getSourceFiles(), excludePatterns, host, (module2, file) => cb(module2, file, program, 
            /*isFromPackageJson*/
            false));
            const autoImportProvider = useAutoImportProvider && ((_a = host.getPackageJsonAutoImportProvider) == null ? void 0 : _a.call(host));
            if (autoImportProvider) {
                const start = timestamp();
                const checker = program.getTypeChecker();
                forEachExternalModule(autoImportProvider.getTypeChecker(), autoImportProvider.getSourceFiles(), excludePatterns, host, (module2, file) => {
                    if (file && !program.getSourceFile(file.fileName) || !file && !checker.resolveName(module2.name, 
                    /*location*/
                    void 0, 1536 /* Module */, 
                    /*excludeGlobals*/
                    false)) {
                        cb(module2, file, autoImportProvider, 
                        /*isFromPackageJson*/
                        true);
                    }
                });
                (_b = host.log) == null ? void 0 : _b.call(host, `forEachExternalModuleToImportFrom autoImportProvider: ${timestamp() - start}`);
            }
        }
        function forEachExternalModule(checker, allSourceFiles, excludePatterns, host, cb) {
            var _a, _b;
            const realpathsWithSymlinks = (_a = host.getSymlinkCache) == null ? void 0 : _a.call(host).getSymlinkedDirectoriesByRealpath();
            const isExcluded = excludePatterns && (({ fileName, path }) => {
                if (excludePatterns.some((p) => p.test(fileName)))
                    return true;
                if ((realpathsWithSymlinks == null ? void 0 : realpathsWithSymlinks.size) && pathContainsNodeModules(fileName)) {
                    let dir = getDirectoryPath(fileName);
                    return forEachAncestorDirectory(getDirectoryPath(path), (dirPath) => {
                        const symlinks = realpathsWithSymlinks.get(ensureTrailingDirectorySeparator(dirPath));
                        if (symlinks) {
                            return symlinks.some((s) => excludePatterns.some((p) => p.test(fileName.replace(dir, s))));
                        }
                        dir = getDirectoryPath(dir);
                    }) ?? false;
                }
                return false;
            });
            for (const ambient of checker.getAmbientModules()) {
                if (!ambient.name.includes("*") && !(excludePatterns && ((_b = ambient.declarations) == null ? void 0 : _b.every((d) => isExcluded(d.getSourceFile()))))) {
                    cb(ambient, 
                    /*sourceFile*/
                    void 0);
                }
            }
            for (const sourceFile of allSourceFiles) {
                if (isExternalOrCommonJsModule(sourceFile) && !(isExcluded == null ? void 0 : isExcluded(sourceFile))) {
                    cb(checker.getMergedSymbol(sourceFile.symbol), sourceFile);
                }
            }
        }
        function getExportInfoMap(importingFile, host, program, preferences, cancellationToken) {
            var _a, _b, _c, _d, _e;
            const start = timestamp();
            (_a = host.getPackageJsonAutoImportProvider) == null ? void 0 : _a.call(host);
            const cache = ((_b = host.getCachedExportInfoMap) == null ? void 0 : _b.call(host)) || createCacheableExportInfoMap({
                getCurrentProgram: () => program,
                getPackageJsonAutoImportProvider: () => {
                    var _a2;
                    return (_a2 = host.getPackageJsonAutoImportProvider) == null ? void 0 : _a2.call(host);
                },
                getGlobalTypingsCacheLocation: () => {
                    var _a2;
                    return (_a2 = host.getGlobalTypingsCacheLocation) == null ? void 0 : _a2.call(host);
                }
            });
            if (cache.isUsableByFile(importingFile.path)) {
                (_c = host.log) == null ? void 0 : _c.call(host, "getExportInfoMap: cache hit");
                return cache;
            }
            (_d = host.log) == null ? void 0 : _d.call(host, "getExportInfoMap: cache miss or empty; calculating new results");
            const compilerOptions = program.getCompilerOptions();
            let moduleCount = 0;
            try {
                forEachExternalModuleToImportFrom(program, host, preferences, 
                /*useAutoImportProvider*/
                true, (moduleSymbol, moduleFile, program2, isFromPackageJson) => {
                    if (++moduleCount % 100 === 0)
                        cancellationToken == null ? void 0 : cancellationToken.throwIfCancellationRequested();
                    const seenExports = /* @__PURE__ */ new Map();
                    const checker = program2.getTypeChecker();
                    const defaultInfo = getDefaultLikeExportInfo(moduleSymbol, checker, compilerOptions);
                    if (defaultInfo && isImportableSymbol(defaultInfo.symbol, checker)) {
                        cache.add(importingFile.path, defaultInfo.symbol, defaultInfo.exportKind === 1 /* Default */ ? "default" /* Default */ : "export=" /* ExportEquals */, moduleSymbol, moduleFile, defaultInfo.exportKind, isFromPackageJson, checker);
                    }
                    checker.forEachExportAndPropertyOfModule(moduleSymbol, (exported, key) => {
                        if (exported !== (defaultInfo == null ? void 0 : defaultInfo.symbol) && isImportableSymbol(exported, checker) && addToSeen(seenExports, key)) {
                            cache.add(importingFile.path, exported, key, moduleSymbol, moduleFile, 0 /* Named */, isFromPackageJson, checker);
                        }
                    });
                });
            }
            catch (err) {
                cache.clear();
                throw err;
            }
            (_e = host.log) == null ? void 0 : _e.call(host, `getExportInfoMap: done in ${timestamp() - start} ms`);
            return cache;
        }
        function getDefaultLikeExportInfo(moduleSymbol, checker, compilerOptions) {
            const exported = getDefaultLikeExportWorker(moduleSymbol, checker);
            if (!exported)
                return void 0;
            const { symbol, exportKind } = exported;
            const info = getDefaultExportInfoWorker(symbol, checker, compilerOptions);
            return info && { symbol, exportKind, ...info };
        }
        function isImportableSymbol(symbol, checker) {
            return !checker.isUndefinedSymbol(symbol) && !checker.isUnknownSymbol(symbol) && !isKnownSymbol(symbol) && !isPrivateIdentifierSymbol(symbol);
        }
        function getDefaultLikeExportWorker(moduleSymbol, checker) {
            const exportEquals = checker.resolveExternalModuleSymbol(moduleSymbol);
            if (exportEquals !== moduleSymbol)
                return { symbol: exportEquals, exportKind: 2 /* ExportEquals */ };
            const defaultExport = checker.tryGetMemberInModuleExports("default" /* Default */, moduleSymbol);
            if (defaultExport)
                return { symbol: defaultExport, exportKind: 1 /* Default */ };
        }
        function getDefaultExportInfoWorker(defaultExport, checker, compilerOptions) {
            const localSymbol = getLocalSymbolForExportDefault(defaultExport);
            if (localSymbol)
                return { resolvedSymbol: localSymbol, name: localSymbol.name };
            const name = getNameForExportDefault(defaultExport);
            if (name !== void 0)
                return { resolvedSymbol: defaultExport, name };
            if (defaultExport.flags & 2097152 /* Alias */) {
                const aliased = checker.getImmediateAliasedSymbol(defaultExport);
                if (aliased && aliased.parent) {
                    return getDefaultExportInfoWorker(aliased, checker, compilerOptions);
                }
            }
            if (defaultExport.escapedName !== "default" /* Default */ && defaultExport.escapedName !== "export=" /* ExportEquals */) {
                return { resolvedSymbol: defaultExport, name: defaultExport.getName() };
            }
            return { resolvedSymbol: defaultExport, name: getNameForExportedSymbol(defaultExport, compilerOptions.target) };
        }
        function getNameForExportDefault(symbol) {
            return symbol.declarations && firstDefined(symbol.declarations, (declaration) => {
                var _a;
                if (isExportAssignment(declaration)) {
                    return (_a = tryCast(skipOuterExpressions(declaration.expression), isIdentifier)) == null ? void 0 : _a.text;
                }
                else if (isExportSpecifier(declaration)) {
                    Debug.assert(declaration.name.text === "default" /* Default */, "Expected the specifier to be a default export");
                    return declaration.propertyName && declaration.propertyName.text;
                }
            });
        }
        var ImportKind, ExportKind;
        var init_exportInfoMap = __esm({
            "src/services/exportInfoMap.ts"() {
                "use strict";
                init_ts4();
                ImportKind = /* @__PURE__ */ ((ImportKind2) => {
                    ImportKind2[ImportKind2["Named"] = 0] = "Named";
                    ImportKind2[ImportKind2["Default"] = 1] = "Default";
                    ImportKind2[ImportKind2["Namespace"] = 2] = "Namespace";
                    ImportKind2[ImportKind2["CommonJS"] = 3] = "CommonJS";
                    return ImportKind2;
                })(ImportKind || {});
                ExportKind = /* @__PURE__ */ ((ExportKind3) => {
                    ExportKind3[ExportKind3["Named"] = 0] = "Named";
                    ExportKind3[ExportKind3["Default"] = 1] = "Default";
                    ExportKind3[ExportKind3["ExportEquals"] = 2] = "ExportEquals";
                    ExportKind3[ExportKind3["UMD"] = 3] = "UMD";
                    return ExportKind3;
                })(ExportKind || {});
            }
        });
        // src/services/classifier.ts
        function createClassifier() {
            const scanner2 = createScanner(99 /* Latest */, 
            /*skipTrivia*/
            false);
            function getClassificationsForLine(text, lexState, syntacticClassifierAbsent) {
                return convertClassificationsToResult(getEncodedLexicalClassifications(text, lexState, syntacticClassifierAbsent), text);
            }
            function getEncodedLexicalClassifications(text, lexState, syntacticClassifierAbsent) {
                let token = 0 /* Unknown */;
                let lastNonTriviaToken = 0 /* Unknown */;
                const templateStack = [];
                const { prefix, pushTemplate } = getPrefixFromLexState(lexState);
                text = prefix + text;
                const offset = prefix.length;
                if (pushTemplate) {
                    templateStack.push(16 /* TemplateHead */);
                }
                scanner2.setText(text);
                let endOfLineState = 0 /* None */;
                const spans = [];
                let angleBracketStack = 0;
                do {
                    token = scanner2.scan();
                    if (!isTrivia(token)) {
                        handleToken();
                        lastNonTriviaToken = token;
                    }
                    const end = scanner2.getTokenEnd();
                    pushEncodedClassification(scanner2.getTokenStart(), end, offset, classFromKind(token), spans);
                    if (end >= text.length) {
                        const end2 = getNewEndOfLineState(scanner2, token, lastOrUndefined(templateStack));
                        if (end2 !== void 0) {
                            endOfLineState = end2;
                        }
                    }
                } while (token !== 1 /* EndOfFileToken */);
                function handleToken() {
                    switch (token) {
                        case 44 /* SlashToken */:
                        case 69 /* SlashEqualsToken */:
                            if (!noRegexTable[lastNonTriviaToken] && scanner2.reScanSlashToken() === 14 /* RegularExpressionLiteral */) {
                                token = 14 /* RegularExpressionLiteral */;
                            }
                            break;
                        case 30 /* LessThanToken */:
                            if (lastNonTriviaToken === 80 /* Identifier */) {
                                angleBracketStack++;
                            }
                            break;
                        case 32 /* GreaterThanToken */:
                            if (angleBracketStack > 0) {
                                angleBracketStack--;
                            }
                            break;
                        case 133 /* AnyKeyword */:
                        case 154 /* StringKeyword */:
                        case 150 /* NumberKeyword */:
                        case 136 /* BooleanKeyword */:
                        case 155 /* SymbolKeyword */:
                            if (angleBracketStack > 0 && !syntacticClassifierAbsent) {
                                token = 80 /* Identifier */;
                            }
                            break;
                        case 16 /* TemplateHead */:
                            templateStack.push(token);
                            break;
                        case 19 /* OpenBraceToken */:
                            if (templateStack.length > 0) {
                                templateStack.push(token);
                            }
                            break;
                        case 20 /* CloseBraceToken */:
                            if (templateStack.length > 0) {
                                const lastTemplateStackToken = lastOrUndefined(templateStack);
                                if (lastTemplateStackToken === 16 /* TemplateHead */) {
                                    token = scanner2.reScanTemplateToken(
                                    /*isTaggedTemplate*/
                                    false);
                                    if (token === 18 /* TemplateTail */) {
                                        templateStack.pop();
                                    }
                                    else {
                                        Debug.assertEqual(token, 17 /* TemplateMiddle */, "Should have been a template middle.");
                                    }
                                }
                                else {
                                    Debug.assertEqual(lastTemplateStackToken, 19 /* OpenBraceToken */, "Should have been an open brace");
                                    templateStack.pop();
                                }
                            }
                            break;
                        default:
                            if (!isKeyword(token)) {
                                break;
                            }
                            if (lastNonTriviaToken === 25 /* DotToken */) {
                                token = 80 /* Identifier */;
                            }
                            else if (isKeyword(lastNonTriviaToken) && isKeyword(token) && !canFollow(lastNonTriviaToken, token)) {
                                token = 80 /* Identifier */;
                            }
                    }
                }
                return { endOfLineState, spans };
            }
            return { getClassificationsForLine, getEncodedLexicalClassifications };
        }
        function getNewEndOfLineState(scanner2, token, lastOnTemplateStack) {
            switch (token) {
                case 11 /* StringLiteral */: {
                    if (!scanner2.isUnterminated())
                        return void 0;
                    const tokenText = scanner2.getTokenText();
                    const lastCharIndex = tokenText.length - 1;
                    let numBackslashes = 0;
                    while (tokenText.charCodeAt(lastCharIndex - numBackslashes) === 92 /* backslash */) {
                        numBackslashes++;
                    }
                    if ((numBackslashes & 1) === 0)
                        return void 0;
                    return tokenText.charCodeAt(0) === 34 /* doubleQuote */ ? 3 /* InDoubleQuoteStringLiteral */ : 2 /* InSingleQuoteStringLiteral */;
                }
                case 3 /* MultiLineCommentTrivia */:
                    return scanner2.isUnterminated() ? 1 /* InMultiLineCommentTrivia */ : void 0;
                default:
                    if (isTemplateLiteralKind(token)) {
                        if (!scanner2.isUnterminated()) {
                            return void 0;
                        }
                        switch (token) {
                            case 18 /* TemplateTail */:
                                return 5 /* InTemplateMiddleOrTail */;
                            case 15 /* NoSubstitutionTemplateLiteral */:
                                return 4 /* InTemplateHeadOrNoSubstitutionTemplate */;
                            default:
                                return Debug.fail("Only 'NoSubstitutionTemplateLiteral's and 'TemplateTail's can be unterminated; got SyntaxKind #" + token);
                        }
                    }
                    return lastOnTemplateStack === 16 /* TemplateHead */ ? 6 /* InTemplateSubstitutionPosition */ : void 0;
            }
        }
        function pushEncodedClassification(start, end, offset, classification, result) {
            if (classification === 8 /* whiteSpace */) {
                return;
            }
            if (start === 0 && offset > 0) {
                start += offset;
            }
            const length2 = end - start;
            if (length2 > 0) {
                result.push(start - offset, length2, classification);
            }
        }
        function convertClassificationsToResult(classifications, text) {
            const entries = [];
            const dense = classifications.spans;
            let lastEnd = 0;
            for (let i = 0; i < dense.length; i += 3) {
                const start = dense[i];
                const length2 = dense[i + 1];
                const type = dense[i + 2];
                if (lastEnd >= 0) {
                    const whitespaceLength2 = start - lastEnd;
                    if (whitespaceLength2 > 0) {
                        entries.push({ length: whitespaceLength2, classification: 4 /* Whitespace */ });
                    }
                }
                entries.push({ length: length2, classification: convertClassification(type) });
                lastEnd = start + length2;
            }
            const whitespaceLength = text.length - lastEnd;
            if (whitespaceLength > 0) {
                entries.push({ length: whitespaceLength, classification: 4 /* Whitespace */ });
            }
            return { entries, finalLexState: classifications.endOfLineState };
        }
        function convertClassification(type) {
            switch (type) {
                case 1 /* comment */:
                    return 3 /* Comment */;
                case 3 /* keyword */:
                    return 1 /* Keyword */;
                case 4 /* numericLiteral */:
                    return 6 /* NumberLiteral */;
                case 25 /* bigintLiteral */:
                    return 7 /* BigIntLiteral */;
                case 5 /* operator */:
                    return 2 /* Operator */;
                case 6 /* stringLiteral */:
                    return 8 /* StringLiteral */;
                case 8 /* whiteSpace */:
                    return 4 /* Whitespace */;
                case 10 /* punctuation */:
                    return 0 /* Punctuation */;
                case 2 /* identifier */:
                case 11 /* className */:
                case 12 /* enumName */:
                case 13 /* interfaceName */:
                case 14 /* moduleName */:
                case 15 /* typeParameterName */:
                case 16 /* typeAliasName */:
                case 9 /* text */:
                case 17 /* parameterName */:
                    return 5 /* Identifier */;
                default:
                    return void 0;
            }
        }
        function canFollow(keyword1, keyword2) {
            if (!isAccessibilityModifier(keyword1)) {
                return true;
            }
            switch (keyword2) {
                case 139 /* GetKeyword */:
                case 153 /* SetKeyword */:
                case 137 /* ConstructorKeyword */:
                case 126 /* StaticKeyword */:
                case 129 /* AccessorKeyword */:
                    return true;
                default:
                    return false;
            }
        }
        function getPrefixFromLexState(lexState) {
            switch (lexState) {
                case 3 /* InDoubleQuoteStringLiteral */:
                    return { prefix: '"\\\n' };
                case 2 /* InSingleQuoteStringLiteral */:
                    return { prefix: "'\\\n" };
                case 1 /* InMultiLineCommentTrivia */:
                    return { prefix: "/*\n" };
                case 4 /* InTemplateHeadOrNoSubstitutionTemplate */:
                    return { prefix: "`\n" };
                case 5 /* InTemplateMiddleOrTail */:
                    return { prefix: "}\n", pushTemplate: true };
                case 6 /* InTemplateSubstitutionPosition */:
                    return { prefix: "", pushTemplate: true };
                case 0 /* None */:
                    return { prefix: "" };
                default:
                    return Debug.assertNever(lexState);
            }
        }
        function isBinaryExpressionOperatorToken(token) {
            switch (token) {
                case 42 /* AsteriskToken */:
                case 44 /* SlashToken */:
                case 45 /* PercentToken */:
                case 40 /* PlusToken */:
                case 41 /* MinusToken */:
                case 48 /* LessThanLessThanToken */:
                case 49 /* GreaterThanGreaterThanToken */:
                case 50 /* GreaterThanGreaterThanGreaterThanToken */:
                case 30 /* LessThanToken */:
                case 32 /* GreaterThanToken */:
                case 33 /* LessThanEqualsToken */:
                case 34 /* GreaterThanEqualsToken */:
                case 104 /* InstanceOfKeyword */:
                case 103 /* InKeyword */:
                case 130 /* AsKeyword */:
                case 152 /* SatisfiesKeyword */:
                case 35 /* EqualsEqualsToken */:
                case 36 /* ExclamationEqualsToken */:
                case 37 /* EqualsEqualsEqualsToken */:
                case 38 /* ExclamationEqualsEqualsToken */:
                case 51 /* AmpersandToken */:
                case 53 /* CaretToken */:
                case 52 /* BarToken */:
                case 56 /* AmpersandAmpersandToken */:
                case 57 /* BarBarToken */:
                case 75 /* BarEqualsToken */:
                case 74 /* AmpersandEqualsToken */:
                case 79 /* CaretEqualsToken */:
                case 71 /* LessThanLessThanEqualsToken */:
                case 72 /* GreaterThanGreaterThanEqualsToken */:
                case 73 /* GreaterThanGreaterThanGreaterThanEqualsToken */:
                case 65 /* PlusEqualsToken */:
                case 66 /* MinusEqualsToken */:
                case 67 /* AsteriskEqualsToken */:
                case 69 /* SlashEqualsToken */:
                case 70 /* PercentEqualsToken */:
                case 64 /* EqualsToken */:
                case 28 /* CommaToken */:
                case 61 /* QuestionQuestionToken */:
                case 76 /* BarBarEqualsToken */:
                case 77 /* AmpersandAmpersandEqualsToken */:
                case 78 /* QuestionQuestionEqualsToken */:
                    return true;
                default:
                    return false;
            }
        }
        function isPrefixUnaryExpressionOperatorToken(token) {
            switch (token) {
                case 40 /* PlusToken */:
                case 41 /* MinusToken */:
                case 55 /* TildeToken */:
                case 54 /* ExclamationToken */:
                case 46 /* PlusPlusToken */:
                case 47 /* MinusMinusToken */:
                    return true;
                default:
                    return false;
            }
        }
        function classFromKind(token) {
            if (isKeyword(token)) {
                return 3 /* keyword */;
            }
            else if (isBinaryExpressionOperatorToken(token) || isPrefixUnaryExpressionOperatorToken(token)) {
                return 5 /* operator */;
            }
            else if (token >= 19 /* FirstPunctuation */ && token <= 79 /* LastPunctuation */) {
                return 10 /* punctuation */;
            }
            switch (token) {
                case 9 /* NumericLiteral */:
                    return 4 /* numericLiteral */;
                case 10 /* BigIntLiteral */:
                    return 25 /* bigintLiteral */;
                case 11 /* StringLiteral */:
                    return 6 /* stringLiteral */;
                case 14 /* RegularExpressionLiteral */:
                    return 7 /* regularExpressionLiteral */;
                case 7 /* ConflictMarkerTrivia */:
                case 3 /* MultiLineCommentTrivia */:
                case 2 /* SingleLineCommentTrivia */:
                    return 1 /* comment */;
                case 5 /* WhitespaceTrivia */:
                case 4 /* NewLineTrivia */:
                    return 8 /* whiteSpace */;
                case 80 /* Identifier */:
                default:
                    if (isTemplateLiteralKind(token)) {
                        return 6 /* stringLiteral */;
                    }
                    return 2 /* identifier */;
            }
        }
        function getSemanticClassifications(typeChecker, cancellationToken, sourceFile, classifiableNames, span) {
            return convertClassificationsToSpans(getEncodedSemanticClassifications(typeChecker, cancellationToken, sourceFile, classifiableNames, span));
        }
        function checkForClassificationCancellation(cancellationToken, kind) {
            switch (kind) {
                case 267 /* ModuleDeclaration */:
                case 263 /* ClassDeclaration */:
                case 264 /* InterfaceDeclaration */:
                case 262 /* FunctionDeclaration */:
                case 231 /* ClassExpression */:
                case 218 /* FunctionExpression */:
                case 219 /* ArrowFunction */:
                    cancellationToken.throwIfCancellationRequested();
            }
        }
        function getEncodedSemanticClassifications(typeChecker, cancellationToken, sourceFile, classifiableNames, span) {
            const spans = [];
            sourceFile.forEachChild(function cb(node) {
                if (!node || !textSpanIntersectsWith(span, node.pos, node.getFullWidth())) {
                    return;
                }
                checkForClassificationCancellation(cancellationToken, node.kind);
                if (isIdentifier(node) && !nodeIsMissing(node) && classifiableNames.has(node.escapedText)) {
                    const symbol = typeChecker.getSymbolAtLocation(node);
                    const type = symbol && classifySymbol(symbol, getMeaningFromLocation(node), typeChecker);
                    if (type) {
                        pushClassification(node.getStart(sourceFile), node.getEnd(), type);
                    }
                }
                node.forEachChild(cb);
            });
            return { spans, endOfLineState: 0 /* None */ };
            function pushClassification(start, end, type) {
                const length2 = end - start;
                Debug.assert(length2 > 0, `Classification had non-positive length of ${length2}`);
                spans.push(start);
                spans.push(length2);
                spans.push(type);
            }
        }
        function classifySymbol(symbol, meaningAtPosition, checker) {
            const flags = symbol.getFlags();
            if ((flags & 2885600 /* Classifiable */) === 0 /* None */) {
                return void 0;
            }
            else if (flags & 32 /* Class */) {
                return 11 /* className */;
            }
            else if (flags & 384 /* Enum */) {
                return 12 /* enumName */;
            }
            else if (flags & 524288 /* TypeAlias */) {
                return 16 /* typeAliasName */;
            }
            else if (flags & 1536 /* Module */) {
                return meaningAtPosition & 4 /* Namespace */ || meaningAtPosition & 1 /* Value */ && hasValueSideModule(symbol) ? 14 /* moduleName */ : void 0;
            }
            else if (flags & 2097152 /* Alias */) {
                return classifySymbol(checker.getAliasedSymbol(symbol), meaningAtPosition, checker);
            }
            else if (meaningAtPosition & 2 /* Type */) {
                return flags & 64 /* Interface */ ? 13 /* interfaceName */ : flags & 262144 /* TypeParameter */ ? 15 /* typeParameterName */ : void 0;
            }
            else {
                return void 0;
            }
        }
        function hasValueSideModule(symbol) {
            return some(symbol.declarations, (declaration) => isModuleDeclaration(declaration) && getModuleInstanceState(declaration) === 1 /* Instantiated */);
        }
        function getClassificationTypeName(type) {
            switch (type) {
                case 1 /* comment */:
                    return "comment" /* comment */;
                case 2 /* identifier */:
                    return "identifier" /* identifier */;
                case 3 /* keyword */:
                    return "keyword" /* keyword */;
                case 4 /* numericLiteral */:
                    return "number" /* numericLiteral */;
                case 25 /* bigintLiteral */:
                    return "bigint" /* bigintLiteral */;
                case 5 /* operator */:
                    return "operator" /* operator */;
                case 6 /* stringLiteral */:
                    return "string" /* stringLiteral */;
                case 8 /* whiteSpace */:
                    return "whitespace" /* whiteSpace */;
                case 9 /* text */:
                    return "text" /* text */;
                case 10 /* punctuation */:
                    return "punctuation" /* punctuation */;
                case 11 /* className */:
                    return "class name" /* className */;
                case 12 /* enumName */:
                    return "enum name" /* enumName */;
                case 13 /* interfaceName */:
                    return "interface name" /* interfaceName */;
                case 14 /* moduleName */:
                    return "module name" /* moduleName */;
                case 15 /* typeParameterName */:
                    return "type parameter name" /* typeParameterName */;
                case 16 /* typeAliasName */:
                    return "type alias name" /* typeAliasName */;
                case 17 /* parameterName */:
                    return "parameter name" /* parameterName */;
                case 18 /* docCommentTagName */:
                    return "doc comment tag name" /* docCommentTagName */;
                case 19 /* jsxOpenTagName */:
                    return "jsx open tag name" /* jsxOpenTagName */;
                case 20 /* jsxCloseTagName */:
                    return "jsx close tag name" /* jsxCloseTagName */;
                case 21 /* jsxSelfClosingTagName */:
                    return "jsx self closing tag name" /* jsxSelfClosingTagName */;
                case 22 /* jsxAttribute */:
                    return "jsx attribute" /* jsxAttribute */;
                case 23 /* jsxText */:
                    return "jsx text" /* jsxText */;
                case 24 /* jsxAttributeStringLiteralValue */:
                    return "jsx attribute string literal value" /* jsxAttributeStringLiteralValue */;
                default:
                    return void 0;
            }
        }
        function convertClassificationsToSpans(classifications) {
            Debug.assert(classifications.spans.length % 3 === 0);
            const dense = classifications.spans;
            const result = [];
            for (let i = 0; i < dense.length; i += 3) {
                result.push({
                    textSpan: createTextSpan(dense[i], dense[i + 1]),
                    classificationType: getClassificationTypeName(dense[i + 2])
                });
            }
            return result;
        }
        function getSyntacticClassifications(cancellationToken, sourceFile, span) {
            return convertClassificationsToSpans(getEncodedSyntacticClassifications(cancellationToken, sourceFile, span));
        }
        function getEncodedSyntacticClassifications(cancellationToken, sourceFile, span) {
            const spanStart = span.start;
            const spanLength = span.length;
            const triviaScanner = createScanner(99 /* Latest */, 
            /*skipTrivia*/
            false, sourceFile.languageVariant, sourceFile.text);
            const mergeConflictScanner = createScanner(99 /* Latest */, 
            /*skipTrivia*/
            false, sourceFile.languageVariant, sourceFile.text);
            const result = [];
            processElement(sourceFile);
            return { spans: result, endOfLineState: 0 /* None */ };
            function pushClassification(start, length2, type) {
                result.push(start);
                result.push(length2);
                result.push(type);
            }
            function classifyLeadingTriviaAndGetTokenStart(token) {
                triviaScanner.resetTokenState(token.pos);
                while (true) {
                    const start = triviaScanner.getTokenEnd();
                    if (!couldStartTrivia(sourceFile.text, start)) {
                        return start;
                    }
                    const kind = triviaScanner.scan();
                    const end = triviaScanner.getTokenEnd();
                    const width = end - start;
                    if (!isTrivia(kind)) {
                        return start;
                    }
                    switch (kind) {
                        case 4 /* NewLineTrivia */:
                        case 5 /* WhitespaceTrivia */:
                            continue;
                        case 2 /* SingleLineCommentTrivia */:
                        case 3 /* MultiLineCommentTrivia */:
                            classifyComment(token, kind, start, width);
                            triviaScanner.resetTokenState(end);
                            continue;
                        case 7 /* ConflictMarkerTrivia */:
                            const text = sourceFile.text;
                            const ch = text.charCodeAt(start);
                            if (ch === 60 /* lessThan */ || ch === 62 /* greaterThan */) {
                                pushClassification(start, width, 1 /* comment */);
                                continue;
                            }
                            Debug.assert(ch === 124 /* bar */ || ch === 61 /* equals */);
                            classifyDisabledMergeCode(text, start, end);
                            break;
                        case 6 /* ShebangTrivia */:
                            break;
                        default:
                            Debug.assertNever(kind);
                    }
                }
            }
            function classifyComment(token, kind, start, width) {
                if (kind === 3 /* MultiLineCommentTrivia */) {
                    const docCommentAndDiagnostics = parseIsolatedJSDocComment(sourceFile.text, start, width);
                    if (docCommentAndDiagnostics && docCommentAndDiagnostics.jsDoc) {
                        setParent(docCommentAndDiagnostics.jsDoc, token);
                        classifyJSDocComment(docCommentAndDiagnostics.jsDoc);
                        return;
                    }
                }
                else if (kind === 2 /* SingleLineCommentTrivia */) {
                    if (tryClassifyTripleSlashComment(start, width)) {
                        return;
                    }
                }
                pushCommentRange(start, width);
            }
            function pushCommentRange(start, width) {
                pushClassification(start, width, 1 /* comment */);
            }
            function classifyJSDocComment(docComment) {
                var _a, _b, _c, _d, _e, _f, _g, _h;
                let pos = docComment.pos;
                if (docComment.tags) {
                    for (const tag of docComment.tags) {
                        if (tag.pos !== pos) {
                            pushCommentRange(pos, tag.pos - pos);
                        }
                        pushClassification(tag.pos, 1, 10 /* punctuation */);
                        pushClassification(tag.tagName.pos, tag.tagName.end - tag.tagName.pos, 18 /* docCommentTagName */);
                        pos = tag.tagName.end;
                        let commentStart = tag.tagName.end;
                        switch (tag.kind) {
                            case 348 /* JSDocParameterTag */:
                                const param = tag;
                                processJSDocParameterTag(param);
                                commentStart = param.isNameFirst && ((_a = param.typeExpression) == null ? void 0 : _a.end) || param.name.end;
                                break;
                            case 355 /* JSDocPropertyTag */:
                                const prop = tag;
                                commentStart = prop.isNameFirst && ((_b = prop.typeExpression) == null ? void 0 : _b.end) || prop.name.end;
                                break;
                            case 352 /* JSDocTemplateTag */:
                                processJSDocTemplateTag(tag);
                                pos = tag.end;
                                commentStart = tag.typeParameters.end;
                                break;
                            case 353 /* JSDocTypedefTag */:
                                const type = tag;
                                commentStart = ((_c = type.typeExpression) == null ? void 0 : _c.kind) === 316 /* JSDocTypeExpression */ && ((_d = type.fullName) == null ? void 0 : _d.end) || ((_e = type.typeExpression) == null ? void 0 : _e.end) || commentStart;
                                break;
                            case 345 /* JSDocCallbackTag */:
                                commentStart = tag.typeExpression.end;
                                break;
                            case 351 /* JSDocTypeTag */:
                                processElement(tag.typeExpression);
                                pos = tag.end;
                                commentStart = tag.typeExpression.end;
                                break;
                            case 350 /* JSDocThisTag */:
                            case 347 /* JSDocEnumTag */:
                                commentStart = tag.typeExpression.end;
                                break;
                            case 349 /* JSDocReturnTag */:
                                processElement(tag.typeExpression);
                                pos = tag.end;
                                commentStart = ((_f = tag.typeExpression) == null ? void 0 : _f.end) || commentStart;
                                break;
                            case 354 /* JSDocSeeTag */:
                                commentStart = ((_g = tag.name) == null ? void 0 : _g.end) || commentStart;
                                break;
                            case 335 /* JSDocAugmentsTag */:
                            case 336 /* JSDocImplementsTag */:
                                commentStart = tag.class.end;
                                break;
                            case 356 /* JSDocThrowsTag */:
                                processElement(tag.typeExpression);
                                pos = tag.end;
                                commentStart = ((_h = tag.typeExpression) == null ? void 0 : _h.end) || commentStart;
                                break;
                        }
                        if (typeof tag.comment === "object") {
                            pushCommentRange(tag.comment.pos, tag.comment.end - tag.comment.pos);
                        }
                        else if (typeof tag.comment === "string") {
                            pushCommentRange(commentStart, tag.end - commentStart);
                        }
                    }
                }
                if (pos !== docComment.end) {
                    pushCommentRange(pos, docComment.end - pos);
                }
                return;
                function processJSDocParameterTag(tag) {
                    if (tag.isNameFirst) {
                        pushCommentRange(pos, tag.name.pos - pos);
                        pushClassification(tag.name.pos, tag.name.end - tag.name.pos, 17 /* parameterName */);
                        pos = tag.name.end;
                    }
                    if (tag.typeExpression) {
                        pushCommentRange(pos, tag.typeExpression.pos - pos);
                        processElement(tag.typeExpression);
                        pos = tag.typeExpression.end;
                    }
                    if (!tag.isNameFirst) {
                        pushCommentRange(pos, tag.name.pos - pos);
                        pushClassification(tag.name.pos, tag.name.end - tag.name.pos, 17 /* parameterName */);
                        pos = tag.name.end;
                    }
                }
            }
            function tryClassifyTripleSlashComment(start, width) {
                const tripleSlashXMLCommentRegEx = /^(\/\/\/\s*)(<)(?:(\S+)((?:[^/]|\/[^>])*)(\/>)?)?/im;
                const attributeRegex = /(\s)(\S+)(\s*)(=)(\s*)('[^']+'|"[^"]+")/img;
                const text = sourceFile.text.substr(start, width);
                const match = tripleSlashXMLCommentRegEx.exec(text);
                if (!match) {
                    return false;
                }
                if (!match[3] || !(match[3] in commentPragmas)) {
                    return false;
                }
                let pos = start;
                pushCommentRange(pos, match[1].length);
                pos += match[1].length;
                pushClassification(pos, match[2].length, 10 /* punctuation */);
                pos += match[2].length;
                pushClassification(pos, match[3].length, 21 /* jsxSelfClosingTagName */);
                pos += match[3].length;
                const attrText = match[4];
                let attrPos = pos;
                while (true) {
                    const attrMatch = attributeRegex.exec(attrText);
                    if (!attrMatch) {
                        break;
                    }
                    const newAttrPos = pos + attrMatch.index + attrMatch[1].length;
                    if (newAttrPos > attrPos) {
                        pushCommentRange(attrPos, newAttrPos - attrPos);
                        attrPos = newAttrPos;
                    }
                    pushClassification(attrPos, attrMatch[2].length, 22 /* jsxAttribute */);
                    attrPos += attrMatch[2].length;
                    if (attrMatch[3].length) {
                        pushCommentRange(attrPos, attrMatch[3].length);
                        attrPos += attrMatch[3].length;
                    }
                    pushClassification(attrPos, attrMatch[4].length, 5 /* operator */);
                    attrPos += attrMatch[4].length;
                    if (attrMatch[5].length) {
                        pushCommentRange(attrPos, attrMatch[5].length);
                        attrPos += attrMatch[5].length;
                    }
                    pushClassification(attrPos, attrMatch[6].length, 24 /* jsxAttributeStringLiteralValue */);
                    attrPos += attrMatch[6].length;
                }
                pos += match[4].length;
                if (pos > attrPos) {
                    pushCommentRange(attrPos, pos - attrPos);
                }
                if (match[5]) {
                    pushClassification(pos, match[5].length, 10 /* punctuation */);
                    pos += match[5].length;
                }
                const end = start + width;
                if (pos < end) {
                    pushCommentRange(pos, end - pos);
                }
                return true;
            }
            function processJSDocTemplateTag(tag) {
                for (const child of tag.getChildren()) {
                    processElement(child);
                }
            }
            function classifyDisabledMergeCode(text, start, end) {
                let i;
                for (i = start; i < end; i++) {
                    if (isLineBreak(text.charCodeAt(i))) {
                        break;
                    }
                }
                pushClassification(start, i - start, 1 /* comment */);
                mergeConflictScanner.resetTokenState(i);
                while (mergeConflictScanner.getTokenEnd() < end) {
                    classifyDisabledCodeToken();
                }
            }
            function classifyDisabledCodeToken() {
                const start = mergeConflictScanner.getTokenEnd();
                const tokenKind = mergeConflictScanner.scan();
                const end = mergeConflictScanner.getTokenEnd();
                const type = classifyTokenType(tokenKind);
                if (type) {
                    pushClassification(start, end - start, type);
                }
            }
            function tryClassifyNode(node) {
                if (isJSDoc(node)) {
                    return true;
                }
                if (nodeIsMissing(node)) {
                    return true;
                }
                const classifiedElementName = tryClassifyJsxElementName(node);
                if (!isToken(node) && node.kind !== 12 /* JsxText */ && classifiedElementName === void 0) {
                    return false;
                }
                const tokenStart = node.kind === 12 /* JsxText */ ? node.pos : classifyLeadingTriviaAndGetTokenStart(node);
                const tokenWidth = node.end - tokenStart;
                Debug.assert(tokenWidth >= 0);
                if (tokenWidth > 0) {
                    const type = classifiedElementName || classifyTokenType(node.kind, node);
                    if (type) {
                        pushClassification(tokenStart, tokenWidth, type);
                    }
                }
                return true;
            }
            function tryClassifyJsxElementName(token) {
                switch (token.parent && token.parent.kind) {
                    case 286 /* JsxOpeningElement */:
                        if (token.parent.tagName === token) {
                            return 19 /* jsxOpenTagName */;
                        }
                        break;
                    case 287 /* JsxClosingElement */:
                        if (token.parent.tagName === token) {
                            return 20 /* jsxCloseTagName */;
                        }
                        break;
                    case 285 /* JsxSelfClosingElement */:
                        if (token.parent.tagName === token) {
                            return 21 /* jsxSelfClosingTagName */;
                        }
                        break;
                    case 291 /* JsxAttribute */:
                        if (token.parent.name === token) {
                            return 22 /* jsxAttribute */;
                        }
                        break;
                }
                return void 0;
            }
            function classifyTokenType(tokenKind, token) {
                if (isKeyword(tokenKind)) {
                    return 3 /* keyword */;
                }
                if (tokenKind === 30 /* LessThanToken */ || tokenKind === 32 /* GreaterThanToken */) {
                    if (token && getTypeArgumentOrTypeParameterList(token.parent)) {
                        return 10 /* punctuation */;
                    }
                }
                if (isPunctuation(tokenKind)) {
                    if (token) {
                        const parent2 = token.parent;
                        if (tokenKind === 64 /* EqualsToken */) {
                            if (parent2.kind === 260 /* VariableDeclaration */ || parent2.kind === 172 /* PropertyDeclaration */ || parent2.kind === 169 /* Parameter */ || parent2.kind === 291 /* JsxAttribute */) {
                                return 5 /* operator */;
                            }
                        }
                        if (parent2.kind === 226 /* BinaryExpression */ || parent2.kind === 224 /* PrefixUnaryExpression */ || parent2.kind === 225 /* PostfixUnaryExpression */ || parent2.kind === 227 /* ConditionalExpression */) {
                            return 5 /* operator */;
                        }
                    }
                    return 10 /* punctuation */;
                }
                else if (tokenKind === 9 /* NumericLiteral */) {
                    return 4 /* numericLiteral */;
                }
                else if (tokenKind === 10 /* BigIntLiteral */) {
                    return 25 /* bigintLiteral */;
                }
                else if (tokenKind === 11 /* StringLiteral */) {
                    return token && token.parent.kind === 291 /* JsxAttribute */ ? 24 /* jsxAttributeStringLiteralValue */ : 6 /* stringLiteral */;
                }
                else if (tokenKind === 14 /* RegularExpressionLiteral */) {
                    return 6 /* stringLiteral */;
                }
                else if (isTemplateLiteralKind(tokenKind)) {
                    return 6 /* stringLiteral */;
                }
                else if (tokenKind === 12 /* JsxText */) {
                    return 23 /* jsxText */;
                }
                else if (tokenKind === 80 /* Identifier */) {
                    if (token) {
                        switch (token.parent.kind) {
                            case 263 /* ClassDeclaration */:
                                if (token.parent.name === token) {
                                    return 11 /* className */;
                                }
                                return;
                            case 168 /* TypeParameter */:
                                if (token.parent.name === token) {
                                    return 15 /* typeParameterName */;
                                }
                                return;
                            case 264 /* InterfaceDeclaration */:
                                if (token.parent.name === token) {
                                    return 13 /* interfaceName */;
                                }
                                return;
                            case 266 /* EnumDeclaration */:
                                if (token.parent.name === token) {
                                    return 12 /* enumName */;
                                }
                                return;
                            case 267 /* ModuleDeclaration */:
                                if (token.parent.name === token) {
                                    return 14 /* moduleName */;
                                }
                                return;
                            case 169 /* Parameter */:
                                if (token.parent.name === token) {
                                    return isThisIdentifier(token) ? 3 /* keyword */ : 17 /* parameterName */;
                                }
                                return;
                        }
                        if (isConstTypeReference(token.parent)) {
                            return 3 /* keyword */;
                        }
                    }
                    return 2 /* identifier */;
                }
            }
            function processElement(element) {
                if (!element) {
                    return;
                }
                if (decodedTextSpanIntersectsWith(spanStart, spanLength, element.pos, element.getFullWidth())) {
                    checkForClassificationCancellation(cancellationToken, element.kind);
                    for (const child of element.getChildren(sourceFile)) {
                        if (!tryClassifyNode(child)) {
                            processElement(child);
                        }
                    }
                }
            }
        }
        var noRegexTable;
        var init_classifier = __esm({
            "src/services/classifier.ts"() {
                "use strict";
                init_ts4();
                noRegexTable = arrayToNumericMap([
                    80 /* Identifier */,
                    11 /* StringLiteral */,
                    9 /* NumericLiteral */,
                    10 /* BigIntLiteral */,
                    14 /* RegularExpressionLiteral */,
                    110 /* ThisKeyword */,
                    46 /* PlusPlusToken */,
                    47 /* MinusMinusToken */,
                    22 /* CloseParenToken */,
                    24 /* CloseBracketToken */,
                    20 /* CloseBraceToken */,
                    112 /* TrueKeyword */,
                    97 /* FalseKeyword */
                ], (token) => token, () => true);
            }
        });
        // src/services/documentHighlights.ts
        var DocumentHighlights;
        var init_documentHighlights = __esm({
            "src/services/documentHighlights.ts"() {
                "use strict";
                init_ts4();
                ((DocumentHighlights3) => {
                    function getDocumentHighlights(program, cancellationToken, sourceFile, position, sourceFilesToSearch) {
                        const node = getTouchingPropertyName(sourceFile, position);
                        if (node.parent && (isJsxOpeningElement(node.parent) && node.parent.tagName === node || isJsxClosingElement(node.parent))) {
                            const { openingElement, closingElement } = node.parent.parent;
                            const highlightSpans = [openingElement, closingElement].map(({ tagName }) => getHighlightSpanForNode(tagName, sourceFile));
                            return [{ fileName: sourceFile.fileName, highlightSpans }];
                        }
                        return getSemanticDocumentHighlights(position, node, program, cancellationToken, sourceFilesToSearch) || getSyntacticDocumentHighlights(node, sourceFile);
                    }
                    DocumentHighlights3.getDocumentHighlights = getDocumentHighlights;
                    function getHighlightSpanForNode(node, sourceFile) {
                        return {
                            fileName: sourceFile.fileName,
                            textSpan: createTextSpanFromNode(node, sourceFile),
                            kind: "none" /* none */
                        };
                    }
                    function getSemanticDocumentHighlights(position, node, program, cancellationToken, sourceFilesToSearch) {
                        const sourceFilesSet = new Set(sourceFilesToSearch.map((f) => f.fileName));
                        const referenceEntries = ts_FindAllReferences_exports.getReferenceEntriesForNode(position, node, program, sourceFilesToSearch, cancellationToken, 
                        /*options*/
                        void 0, sourceFilesSet);
                        if (!referenceEntries)
                            return void 0;
                        const map2 = arrayToMultiMap(referenceEntries.map(ts_FindAllReferences_exports.toHighlightSpan), (e) => e.fileName, (e) => e.span);
                        const getCanonicalFileName = createGetCanonicalFileName(program.useCaseSensitiveFileNames());
                        return arrayFrom(mapDefinedIterator(map2.entries(), ([fileName, highlightSpans]) => {
                            if (!sourceFilesSet.has(fileName)) {
                                if (!program.redirectTargetsMap.has(toPath(fileName, program.getCurrentDirectory(), getCanonicalFileName))) {
                                    return void 0;
                                }
                                const redirectTarget = program.getSourceFile(fileName);
                                const redirect = find(sourceFilesToSearch, (f) => !!f.redirectInfo && f.redirectInfo.redirectTarget === redirectTarget);
                                fileName = redirect.fileName;
                                Debug.assert(sourceFilesSet.has(fileName));
                            }
                            return { fileName, highlightSpans };
                        }));
                    }
                    function getSyntacticDocumentHighlights(node, sourceFile) {
                        const highlightSpans = getHighlightSpans(node, sourceFile);
                        return highlightSpans && [{ fileName: sourceFile.fileName, highlightSpans }];
                    }
                    function getHighlightSpans(node, sourceFile) {
                        switch (node.kind) {
                            case 101 /* IfKeyword */:
                            case 93 /* ElseKeyword */:
                                return isIfStatement(node.parent) ? getIfElseOccurrences(node.parent, sourceFile) : void 0;
                            case 107 /* ReturnKeyword */:
                                return useParent(node.parent, isReturnStatement, getReturnOccurrences);
                            case 111 /* ThrowKeyword */:
                                return useParent(node.parent, isThrowStatement, getThrowOccurrences);
                            case 113 /* TryKeyword */:
                            case 85 /* CatchKeyword */:
                            case 98 /* FinallyKeyword */:
                                const tryStatement = node.kind === 85 /* CatchKeyword */ ? node.parent.parent : node.parent;
                                return useParent(tryStatement, isTryStatement, getTryCatchFinallyOccurrences);
                            case 109 /* SwitchKeyword */:
                                return useParent(node.parent, isSwitchStatement, getSwitchCaseDefaultOccurrences);
                            case 84 /* CaseKeyword */:
                            case 90 /* DefaultKeyword */: {
                                if (isDefaultClause(node.parent) || isCaseClause(node.parent)) {
                                    return useParent(node.parent.parent.parent, isSwitchStatement, getSwitchCaseDefaultOccurrences);
                                }
                                return void 0;
                            }
                            case 83 /* BreakKeyword */:
                            case 88 /* ContinueKeyword */:
                                return useParent(node.parent, isBreakOrContinueStatement, getBreakOrContinueStatementOccurrences);
                            case 99 /* ForKeyword */:
                            case 117 /* WhileKeyword */:
                            case 92 /* DoKeyword */:
                                return useParent(node.parent, (n) => isIterationStatement(n, 
                                /*lookInLabeledStatements*/
                                true), getLoopBreakContinueOccurrences);
                            case 137 /* ConstructorKeyword */:
                                return getFromAllDeclarations(isConstructorDeclaration, [137 /* ConstructorKeyword */]);
                            case 139 /* GetKeyword */:
                            case 153 /* SetKeyword */:
                                return getFromAllDeclarations(isAccessor, [139 /* GetKeyword */, 153 /* SetKeyword */]);
                            case 135 /* AwaitKeyword */:
                                return useParent(node.parent, isAwaitExpression, getAsyncAndAwaitOccurrences);
                            case 134 /* AsyncKeyword */:
                                return highlightSpans(getAsyncAndAwaitOccurrences(node));
                            case 127 /* YieldKeyword */:
                                return highlightSpans(getYieldOccurrences(node));
                            case 103 /* InKeyword */:
                            case 147 /* OutKeyword */:
                                return void 0;
                            default:
                                return isModifierKind(node.kind) && (isDeclaration(node.parent) || isVariableStatement(node.parent)) ? highlightSpans(getModifierOccurrences(node.kind, node.parent)) : void 0;
                        }
                        function getFromAllDeclarations(nodeTest, keywords) {
                            return useParent(node.parent, nodeTest, (decl) => {
                                var _a;
                                return mapDefined((_a = tryCast(decl, canHaveSymbol)) == null ? void 0 : _a.symbol.declarations, (d) => nodeTest(d) ? find(d.getChildren(sourceFile), (c) => contains(keywords, c.kind)) : void 0);
                            });
                        }
                        function useParent(node2, nodeTest, getNodes4) {
                            return nodeTest(node2) ? highlightSpans(getNodes4(node2, sourceFile)) : void 0;
                        }
                        function highlightSpans(nodes) {
                            return nodes && nodes.map((node2) => getHighlightSpanForNode(node2, sourceFile));
                        }
                    }
                    function aggregateOwnedThrowStatements(node) {
                        if (isThrowStatement(node)) {
                            return [node];
                        }
                        else if (isTryStatement(node)) {
                            return concatenate(node.catchClause ? aggregateOwnedThrowStatements(node.catchClause) : node.tryBlock && aggregateOwnedThrowStatements(node.tryBlock), node.finallyBlock && aggregateOwnedThrowStatements(node.finallyBlock));
                        }
                        return isFunctionLike(node) ? void 0 : flatMapChildren(node, aggregateOwnedThrowStatements);
                    }
                    function getThrowStatementOwner(throwStatement) {
                        let child = throwStatement;
                        while (child.parent) {
                            const parent2 = child.parent;
                            if (isFunctionBlock(parent2) || parent2.kind === 312 /* SourceFile */) {
                                return parent2;
                            }
                            if (isTryStatement(parent2) && parent2.tryBlock === child && parent2.catchClause) {
                                return child;
                            }
                            child = parent2;
                        }
                        return void 0;
                    }
                    function aggregateAllBreakAndContinueStatements(node) {
                        return isBreakOrContinueStatement(node) ? [node] : isFunctionLike(node) ? void 0 : flatMapChildren(node, aggregateAllBreakAndContinueStatements);
                    }
                    function flatMapChildren(node, cb) {
                        const result = [];
                        node.forEachChild((child) => {
                            const value = cb(child);
                            if (value !== void 0) {
                                result.push(...toArray(value));
                            }
                        });
                        return result;
                    }
                    function ownsBreakOrContinueStatement(owner, statement) {
                        const actualOwner = getBreakOrContinueOwner(statement);
                        return !!actualOwner && actualOwner === owner;
                    }
                    function getBreakOrContinueOwner(statement) {
                        return findAncestor(statement, (node) => {
                            switch (node.kind) {
                                case 255 /* SwitchStatement */:
                                    if (statement.kind === 251 /* ContinueStatement */) {
                                        return false;
                                    }
                                case 248 /* ForStatement */:
                                case 249 /* ForInStatement */:
                                case 250 /* ForOfStatement */:
                                case 247 /* WhileStatement */:
                                case 246 /* DoStatement */:
                                    return !statement.label || isLabeledBy(node, statement.label.escapedText);
                                default:
                                    return isFunctionLike(node) && "quit";
                            }
                        });
                    }
                    function getModifierOccurrences(modifier, declaration) {
                        return mapDefined(getNodesToSearchForModifier(declaration, modifierToFlag(modifier)), (node) => findModifier(node, modifier));
                    }
                    function getNodesToSearchForModifier(declaration, modifierFlag) {
                        const container = declaration.parent;
                        switch (container.kind) {
                            case 268 /* ModuleBlock */:
                            case 312 /* SourceFile */:
                            case 241 /* Block */:
                            case 296 /* CaseClause */:
                            case 297 /* DefaultClause */:
                                if (modifierFlag & 64 /* Abstract */ && isClassDeclaration(declaration)) {
                                    return [...declaration.members, declaration];
                                }
                                else {
                                    return container.statements;
                                }
                            case 176 /* Constructor */:
                            case 174 /* MethodDeclaration */:
                            case 262 /* FunctionDeclaration */:
                                return [...container.parameters, ...isClassLike(container.parent) ? container.parent.members : []];
                            case 263 /* ClassDeclaration */:
                            case 231 /* ClassExpression */:
                            case 264 /* InterfaceDeclaration */:
                            case 187 /* TypeLiteral */:
                                const nodes = container.members;
                                if (modifierFlag & (7 /* AccessibilityModifier */ | 8 /* Readonly */)) {
                                    const constructor = find(container.members, isConstructorDeclaration);
                                    if (constructor) {
                                        return [...nodes, ...constructor.parameters];
                                    }
                                }
                                else if (modifierFlag & 64 /* Abstract */) {
                                    return [...nodes, container];
                                }
                                return nodes;
                            case 210 /* ObjectLiteralExpression */:
                                return void 0;
                            default:
                                Debug.assertNever(container, "Invalid container kind.");
                        }
                    }
                    function pushKeywordIf(keywordList, token, ...expected) {
                        if (token && contains(expected, token.kind)) {
                            keywordList.push(token);
                            return true;
                        }
                        return false;
                    }
                    function getLoopBreakContinueOccurrences(loopNode) {
                        const keywords = [];
                        if (pushKeywordIf(keywords, loopNode.getFirstToken(), 99 /* ForKeyword */, 117 /* WhileKeyword */, 92 /* DoKeyword */)) {
                            if (loopNode.kind === 246 /* DoStatement */) {
                                const loopTokens = loopNode.getChildren();
                                for (let i = loopTokens.length - 1; i >= 0; i--) {
                                    if (pushKeywordIf(keywords, loopTokens[i], 117 /* WhileKeyword */)) {
                                        break;
                                    }
                                }
                            }
                        }
                        forEach(aggregateAllBreakAndContinueStatements(loopNode.statement), (statement) => {
                            if (ownsBreakOrContinueStatement(loopNode, statement)) {
                                pushKeywordIf(keywords, statement.getFirstToken(), 83 /* BreakKeyword */, 88 /* ContinueKeyword */);
                            }
                        });
                        return keywords;
                    }
                    function getBreakOrContinueStatementOccurrences(breakOrContinueStatement) {
                        const owner = getBreakOrContinueOwner(breakOrContinueStatement);
                        if (owner) {
                            switch (owner.kind) {
                                case 248 /* ForStatement */:
                                case 249 /* ForInStatement */:
                                case 250 /* ForOfStatement */:
                                case 246 /* DoStatement */:
                                case 247 /* WhileStatement */:
                                    return getLoopBreakContinueOccurrences(owner);
                                case 255 /* SwitchStatement */:
                                    return getSwitchCaseDefaultOccurrences(owner);
                            }
                        }
                        return void 0;
                    }
                    function getSwitchCaseDefaultOccurrences(switchStatement) {
                        const keywords = [];
                        pushKeywordIf(keywords, switchStatement.getFirstToken(), 109 /* SwitchKeyword */);
                        forEach(switchStatement.caseBlock.clauses, (clause) => {
                            pushKeywordIf(keywords, clause.getFirstToken(), 84 /* CaseKeyword */, 90 /* DefaultKeyword */);
                            forEach(aggregateAllBreakAndContinueStatements(clause), (statement) => {
                                if (ownsBreakOrContinueStatement(switchStatement, statement)) {
                                    pushKeywordIf(keywords, statement.getFirstToken(), 83 /* BreakKeyword */);
                                }
                            });
                        });
                        return keywords;
                    }
                    function getTryCatchFinallyOccurrences(tryStatement, sourceFile) {
                        const keywords = [];
                        pushKeywordIf(keywords, tryStatement.getFirstToken(), 113 /* TryKeyword */);
                        if (tryStatement.catchClause) {
                            pushKeywordIf(keywords, tryStatement.catchClause.getFirstToken(), 85 /* CatchKeyword */);
                        }
                        if (tryStatement.finallyBlock) {
                            const finallyKeyword = findChildOfKind(tryStatement, 98 /* FinallyKeyword */, sourceFile);
                            pushKeywordIf(keywords, finallyKeyword, 98 /* FinallyKeyword */);
                        }
                        return keywords;
                    }
                    function getThrowOccurrences(throwStatement, sourceFile) {
                        const owner = getThrowStatementOwner(throwStatement);
                        if (!owner) {
                            return void 0;
                        }
                        const keywords = [];
                        forEach(aggregateOwnedThrowStatements(owner), (throwStatement2) => {
                            keywords.push(findChildOfKind(throwStatement2, 111 /* ThrowKeyword */, sourceFile));
                        });
                        if (isFunctionBlock(owner)) {
                            forEachReturnStatement(owner, (returnStatement) => {
                                keywords.push(findChildOfKind(returnStatement, 107 /* ReturnKeyword */, sourceFile));
                            });
                        }
                        return keywords;
                    }
                    function getReturnOccurrences(returnStatement, sourceFile) {
                        const func = getContainingFunction(returnStatement);
                        if (!func) {
                            return void 0;
                        }
                        const keywords = [];
                        forEachReturnStatement(cast(func.body, isBlock), (returnStatement2) => {
                            keywords.push(findChildOfKind(returnStatement2, 107 /* ReturnKeyword */, sourceFile));
                        });
                        forEach(aggregateOwnedThrowStatements(func.body), (throwStatement) => {
                            keywords.push(findChildOfKind(throwStatement, 111 /* ThrowKeyword */, sourceFile));
                        });
                        return keywords;
                    }
                    function getAsyncAndAwaitOccurrences(node) {
                        const func = getContainingFunction(node);
                        if (!func) {
                            return void 0;
                        }
                        const keywords = [];
                        if (func.modifiers) {
                            func.modifiers.forEach((modifier) => {
                                pushKeywordIf(keywords, modifier, 134 /* AsyncKeyword */);
                            });
                        }
                        forEachChild(func, (child) => {
                            traverseWithoutCrossingFunction(child, (node2) => {
                                if (isAwaitExpression(node2)) {
                                    pushKeywordIf(keywords, node2.getFirstToken(), 135 /* AwaitKeyword */);
                                }
                            });
                        });
                        return keywords;
                    }
                    function getYieldOccurrences(node) {
                        const func = getContainingFunction(node);
                        if (!func) {
                            return void 0;
                        }
                        const keywords = [];
                        forEachChild(func, (child) => {
                            traverseWithoutCrossingFunction(child, (node2) => {
                                if (isYieldExpression(node2)) {
                                    pushKeywordIf(keywords, node2.getFirstToken(), 127 /* YieldKeyword */);
                                }
                            });
                        });
                        return keywords;
                    }
                    function traverseWithoutCrossingFunction(node, cb) {
                        cb(node);
                        if (!isFunctionLike(node) && !isClassLike(node) && !isInterfaceDeclaration(node) && !isModuleDeclaration(node) && !isTypeAliasDeclaration(node) && !isTypeNode(node)) {
                            forEachChild(node, (child) => traverseWithoutCrossingFunction(child, cb));
                        }
                    }
                    function getIfElseOccurrences(ifStatement, sourceFile) {
                        const keywords = getIfElseKeywords(ifStatement, sourceFile);
                        const result = [];
                        for (let i = 0; i < keywords.length; i++) {
                            if (keywords[i].kind === 93 /* ElseKeyword */ && i < keywords.length - 1) {
                                const elseKeyword = keywords[i];
                                const ifKeyword = keywords[i + 1];
                                let shouldCombineElseAndIf = true;
                                for (let j = ifKeyword.getStart(sourceFile) - 1; j >= elseKeyword.end; j--) {
                                    if (!isWhiteSpaceSingleLine(sourceFile.text.charCodeAt(j))) {
                                        shouldCombineElseAndIf = false;
                                        break;
                                    }
                                }
                                if (shouldCombineElseAndIf) {
                                    result.push({
                                        fileName: sourceFile.fileName,
                                        textSpan: createTextSpanFromBounds(elseKeyword.getStart(), ifKeyword.end),
                                        kind: "reference" /* reference */
                                    });
                                    i++;
                                    continue;
                                }
                            }
                            result.push(getHighlightSpanForNode(keywords[i], sourceFile));
                        }
                        return result;
                    }
                    function getIfElseKeywords(ifStatement, sourceFile) {
                        const keywords = [];
                        while (isIfStatement(ifStatement.parent) && ifStatement.parent.elseStatement === ifStatement) {
                            ifStatement = ifStatement.parent;
                        }
                        while (true) {
                            const children = ifStatement.getChildren(sourceFile);
                            pushKeywordIf(keywords, children[0], 101 /* IfKeyword */);
                            for (let i = children.length - 1; i >= 0; i--) {
                                if (pushKeywordIf(keywords, children[i], 93 /* ElseKeyword */)) {
                                    break;
                                }
                            }
                            if (!ifStatement.elseStatement || !isIfStatement(ifStatement.elseStatement)) {
                                break;
                            }
                            ifStatement = ifStatement.elseStatement;
                        }
                        return keywords;
                    }
                    function isLabeledBy(node, labelName) {
                        return !!findAncestor(node.parent, (owner) => !isLabeledStatement(owner) ? "quit" : owner.label.escapedText === labelName);
                    }
                })(DocumentHighlights || (DocumentHighlights = {}));
            }
        });
        // src/services/documentRegistry.ts
        function isDocumentRegistryEntry(entry) {
            return !!entry.sourceFile;
        }
        function createDocumentRegistry(useCaseSensitiveFileNames2, currentDirectory, jsDocParsingMode) {
            return createDocumentRegistryInternal(useCaseSensitiveFileNames2, currentDirectory, jsDocParsingMode);
        }
        function createDocumentRegistryInternal(useCaseSensitiveFileNames2, currentDirectory = "", jsDocParsingMode, externalCache) {
            const buckets = /* @__PURE__ */ new Map();
            const getCanonicalFileName = createGetCanonicalFileName(!!useCaseSensitiveFileNames2);
            function reportStats() {
                const bucketInfoArray = arrayFrom(buckets.keys()).filter((name) => name && name.charAt(0) === "_").map((name) => {
                    const entries = buckets.get(name);
                    const sourceFiles = [];
                    entries.forEach((entry, name2) => {
                        if (isDocumentRegistryEntry(entry)) {
                            sourceFiles.push({
                                name: name2,
                                scriptKind: entry.sourceFile.scriptKind,
                                refCount: entry.languageServiceRefCount
                            });
                        }
                        else {
                            entry.forEach((value, scriptKind) => sourceFiles.push({ name: name2, scriptKind, refCount: value.languageServiceRefCount }));
                        }
                    });
                    sourceFiles.sort((x, y) => y.refCount - x.refCount);
                    return {
                        bucket: name,
                        sourceFiles
                    };
                });
                return JSON.stringify(bucketInfoArray, void 0, 2);
            }
            function getCompilationSettings(settingsOrHost) {
                if (typeof settingsOrHost.getCompilationSettings === "function") {
                    return settingsOrHost.getCompilationSettings();
                }
                return settingsOrHost;
            }
            function acquireDocument(fileName, compilationSettings, scriptSnapshot, version2, scriptKind, languageVersionOrOptions) {
                const path = toPath(fileName, currentDirectory, getCanonicalFileName);
                const key = getKeyForCompilationSettings(getCompilationSettings(compilationSettings));
                return acquireDocumentWithKey(fileName, path, compilationSettings, key, scriptSnapshot, version2, scriptKind, languageVersionOrOptions);
            }
            function acquireDocumentWithKey(fileName, path, compilationSettings, key, scriptSnapshot, version2, scriptKind, languageVersionOrOptions) {
                return acquireOrUpdateDocument(fileName, path, compilationSettings, key, scriptSnapshot, version2, 
                /*acquiring*/
                true, scriptKind, languageVersionOrOptions);
            }
            function updateDocument(fileName, compilationSettings, scriptSnapshot, version2, scriptKind, languageVersionOrOptions) {
                const path = toPath(fileName, currentDirectory, getCanonicalFileName);
                const key = getKeyForCompilationSettings(getCompilationSettings(compilationSettings));
                return updateDocumentWithKey(fileName, path, compilationSettings, key, scriptSnapshot, version2, scriptKind, languageVersionOrOptions);
            }
            function updateDocumentWithKey(fileName, path, compilationSettings, key, scriptSnapshot, version2, scriptKind, languageVersionOrOptions) {
                return acquireOrUpdateDocument(fileName, path, getCompilationSettings(compilationSettings), key, scriptSnapshot, version2, 
                /*acquiring*/
                false, scriptKind, languageVersionOrOptions);
            }
            function getDocumentRegistryEntry(bucketEntry, scriptKind) {
                const entry = isDocumentRegistryEntry(bucketEntry) ? bucketEntry : bucketEntry.get(Debug.checkDefined(scriptKind, "If there are more than one scriptKind's for same document the scriptKind should be provided"));
                Debug.assert(scriptKind === void 0 || !entry || entry.sourceFile.scriptKind === scriptKind, `Script kind should match provided ScriptKind:${scriptKind} and sourceFile.scriptKind: ${entry == null ? void 0 : entry.sourceFile.scriptKind}, !entry: ${!entry}`);
                return entry;
            }
            function acquireOrUpdateDocument(fileName, path, compilationSettingsOrHost, key, scriptSnapshot, version2, acquiring, scriptKind, languageVersionOrOptions) {
                var _a, _b, _c, _d;
                scriptKind = ensureScriptKind(fileName, scriptKind);
                const compilationSettings = getCompilationSettings(compilationSettingsOrHost);
                const host = compilationSettingsOrHost === compilationSettings ? void 0 : compilationSettingsOrHost;
                const scriptTarget = scriptKind === 6 /* JSON */ ? 100 /* JSON */ : getEmitScriptTarget(compilationSettings);
                const sourceFileOptions = typeof languageVersionOrOptions === "object" ? languageVersionOrOptions : {
                    languageVersion: scriptTarget,
                    impliedNodeFormat: host && getImpliedNodeFormatForFile(path, (_d = (_c = (_b = (_a = host.getCompilerHost) == null ? void 0 : _a.call(host)) == null ? void 0 : _b.getModuleResolutionCache) == null ? void 0 : _c.call(_b)) == null ? void 0 : _d.getPackageJsonInfoCache(), host, compilationSettings),
                    setExternalModuleIndicator: getSetExternalModuleIndicator(compilationSettings),
                    jsDocParsingMode
                };
                sourceFileOptions.languageVersion = scriptTarget;
                Debug.assertEqual(jsDocParsingMode, sourceFileOptions.jsDocParsingMode);
                const oldBucketCount = buckets.size;
                const keyWithMode = getDocumentRegistryBucketKeyWithMode(key, sourceFileOptions.impliedNodeFormat);
                const bucket = getOrUpdate(buckets, keyWithMode, () => /* @__PURE__ */ new Map());
                if (tracing) {
                    if (buckets.size > oldBucketCount) {
                        tracing.instant(tracing.Phase.Session, "createdDocumentRegistryBucket", { configFilePath: compilationSettings.configFilePath, key: keyWithMode });
                    }
                    const otherBucketKey = !isDeclarationFileName(path) && forEachEntry(buckets, (bucket2, bucketKey) => bucketKey !== keyWithMode && bucket2.has(path) && bucketKey);
                    if (otherBucketKey) {
                        tracing.instant(tracing.Phase.Session, "documentRegistryBucketOverlap", { path, key1: otherBucketKey, key2: keyWithMode });
                    }
                }
                const bucketEntry = bucket.get(path);
                let entry = bucketEntry && getDocumentRegistryEntry(bucketEntry, scriptKind);
                if (!entry && externalCache) {
                    const sourceFile = externalCache.getDocument(keyWithMode, path);
                    if (sourceFile) {
                        Debug.assert(acquiring);
                        entry = {
                            sourceFile,
                            languageServiceRefCount: 0
                        };
                        setBucketEntry();
                    }
                }
                if (!entry) {
                    const sourceFile = createLanguageServiceSourceFile(fileName, scriptSnapshot, sourceFileOptions, version2, 
                    /*setNodeParents*/
                    false, scriptKind);
                    if (externalCache) {
                        externalCache.setDocument(keyWithMode, path, sourceFile);
                    }
                    entry = {
                        sourceFile,
                        languageServiceRefCount: 1
                    };
                    setBucketEntry();
                }
                else {
                    if (entry.sourceFile.version !== version2) {
                        entry.sourceFile = updateLanguageServiceSourceFile(entry.sourceFile, scriptSnapshot, version2, scriptSnapshot.getChangeRange(entry.sourceFile.scriptSnapshot));
                        if (externalCache) {
                            externalCache.setDocument(keyWithMode, path, entry.sourceFile);
                        }
                    }
                    if (acquiring) {
                        entry.languageServiceRefCount++;
                    }
                }
                Debug.assert(entry.languageServiceRefCount !== 0);
                return entry.sourceFile;
                function setBucketEntry() {
                    if (!bucketEntry) {
                        bucket.set(path, entry);
                    }
                    else if (isDocumentRegistryEntry(bucketEntry)) {
                        const scriptKindMap = /* @__PURE__ */ new Map();
                        scriptKindMap.set(bucketEntry.sourceFile.scriptKind, bucketEntry);
                        scriptKindMap.set(scriptKind, entry);
                        bucket.set(path, scriptKindMap);
                    }
                    else {
                        bucketEntry.set(scriptKind, entry);
                    }
                }
            }
            function releaseDocument(fileName, compilationSettings, scriptKind, impliedNodeFormat) {
                const path = toPath(fileName, currentDirectory, getCanonicalFileName);
                const key = getKeyForCompilationSettings(compilationSettings);
                return releaseDocumentWithKey(path, key, scriptKind, impliedNodeFormat);
            }
            function releaseDocumentWithKey(path, key, scriptKind, impliedNodeFormat) {
                const bucket = Debug.checkDefined(buckets.get(getDocumentRegistryBucketKeyWithMode(key, impliedNodeFormat)));
                const bucketEntry = bucket.get(path);
                const entry = getDocumentRegistryEntry(bucketEntry, scriptKind);
                entry.languageServiceRefCount--;
                Debug.assert(entry.languageServiceRefCount >= 0);
                if (entry.languageServiceRefCount === 0) {
                    if (isDocumentRegistryEntry(bucketEntry)) {
                        bucket.delete(path);
                    }
                    else {
                        bucketEntry.delete(scriptKind);
                        if (bucketEntry.size === 1) {
                            bucket.set(path, firstDefinedIterator(bucketEntry.values(), identity));
                        }
                    }
                }
            }
            return {
                acquireDocument,
                acquireDocumentWithKey,
                updateDocument,
                updateDocumentWithKey,
                releaseDocument,
                releaseDocumentWithKey,
                getKeyForCompilationSettings,
                getDocumentRegistryBucketKeyWithMode,
                reportStats,
                getBuckets: () => buckets
            };
        }
        function getKeyForCompilationSettings(settings) {
            return getKeyForCompilerOptions(settings, sourceFileAffectingCompilerOptions);
        }
        function getDocumentRegistryBucketKeyWithMode(key, mode) {
            return mode ? `${key}|${mode}` : key;
        }
        var init_documentRegistry = __esm({
            "src/services/documentRegistry.ts"() {
                "use strict";
                init_ts4();
            }
        });
        // src/services/getEditsForFileRename.ts
        function getEditsForFileRename(program, oldFileOrDirPath, newFileOrDirPath, host, formatContext, preferences, sourceMapper) {
            const useCaseSensitiveFileNames2 = hostUsesCaseSensitiveFileNames(host);
            const getCanonicalFileName = createGetCanonicalFileName(useCaseSensitiveFileNames2);
            const oldToNew = getPathUpdater(oldFileOrDirPath, newFileOrDirPath, getCanonicalFileName, sourceMapper);
            const newToOld = getPathUpdater(newFileOrDirPath, oldFileOrDirPath, getCanonicalFileName, sourceMapper);
            return ts_textChanges_exports.ChangeTracker.with({ host, formatContext, preferences }, (changeTracker) => {
                updateTsconfigFiles(program, changeTracker, oldToNew, oldFileOrDirPath, newFileOrDirPath, host.getCurrentDirectory(), useCaseSensitiveFileNames2);
                updateImports(program, changeTracker, oldToNew, newToOld, host, getCanonicalFileName);
            });
        }
        function getPathUpdater(oldFileOrDirPath, newFileOrDirPath, getCanonicalFileName, sourceMapper) {
            const canonicalOldPath = getCanonicalFileName(oldFileOrDirPath);
            return (path) => {
                const originalPath = sourceMapper && sourceMapper.tryGetSourcePosition({ fileName: path, pos: 0 });
                const updatedPath = getUpdatedPath(originalPath ? originalPath.fileName : path);
                return originalPath ? updatedPath === void 0 ? void 0 : makeCorrespondingRelativeChange(originalPath.fileName, updatedPath, path, getCanonicalFileName) : updatedPath;
            };
            function getUpdatedPath(pathToUpdate) {
                if (getCanonicalFileName(pathToUpdate) === canonicalOldPath)
                    return newFileOrDirPath;
                const suffix = tryRemoveDirectoryPrefix(pathToUpdate, canonicalOldPath, getCanonicalFileName);
                return suffix === void 0 ? void 0 : newFileOrDirPath + "/" + suffix;
            }
        }
        function makeCorrespondingRelativeChange(a0, b0, a1, getCanonicalFileName) {
            const rel = getRelativePathFromFile(a0, b0, getCanonicalFileName);
            return combinePathsSafe(getDirectoryPath(a1), rel);
        }
        function updateTsconfigFiles(program, changeTracker, oldToNew, oldFileOrDirPath, newFileOrDirPath, currentDirectory, useCaseSensitiveFileNames2) {
            const { configFile } = program.getCompilerOptions();
            if (!configFile)
                return;
            const configDir = getDirectoryPath(configFile.fileName);
            const jsonObjectLiteral = getTsConfigObjectLiteralExpression(configFile);
            if (!jsonObjectLiteral)
                return;
            forEachProperty(jsonObjectLiteral, (property, propertyName) => {
                switch (propertyName) {
                    case "files":
                    case "include":
                    case "exclude": {
                        const foundExactMatch = updatePaths(property);
                        if (foundExactMatch || propertyName !== "include" || !isArrayLiteralExpression(property.initializer))
                            return;
                        const includes = mapDefined(property.initializer.elements, (e) => isStringLiteral(e) ? e.text : void 0);
                        if (includes.length === 0)
                            return;
                        const matchers = getFileMatcherPatterns(configDir, 
                        /*excludes*/
                        [], includes, useCaseSensitiveFileNames2, currentDirectory);
                        if (getRegexFromPattern(Debug.checkDefined(matchers.includeFilePattern), useCaseSensitiveFileNames2).test(oldFileOrDirPath) && !getRegexFromPattern(Debug.checkDefined(matchers.includeFilePattern), useCaseSensitiveFileNames2).test(newFileOrDirPath)) {
                            changeTracker.insertNodeAfter(configFile, last(property.initializer.elements), factory.createStringLiteral(relativePath(newFileOrDirPath)));
                        }
                        return;
                    }
                    case "compilerOptions":
                        forEachProperty(property.initializer, (property2, propertyName2) => {
                            const option = getOptionFromName(propertyName2);
                            Debug.assert((option == null ? void 0 : option.type) !== "listOrElement");
                            if (option && (option.isFilePath || option.type === "list" && option.element.isFilePath)) {
                                updatePaths(property2);
                            }
                            else if (propertyName2 === "paths") {
                                forEachProperty(property2.initializer, (pathsProperty) => {
                                    if (!isArrayLiteralExpression(pathsProperty.initializer))
                                        return;
                                    for (const e of pathsProperty.initializer.elements) {
                                        tryUpdateString(e);
                                    }
                                });
                            }
                        });
                        return;
                }
            });
            function updatePaths(property) {
                const elements = isArrayLiteralExpression(property.initializer) ? property.initializer.elements : [property.initializer];
                let foundExactMatch = false;
                for (const element of elements) {
                    foundExactMatch = tryUpdateString(element) || foundExactMatch;
                }
                return foundExactMatch;
            }
            function tryUpdateString(element) {
                if (!isStringLiteral(element))
                    return false;
                const elementFileName = combinePathsSafe(configDir, element.text);
                const updated = oldToNew(elementFileName);
                if (updated !== void 0) {
                    changeTracker.replaceRangeWithText(configFile, createStringRange(element, configFile), relativePath(updated));
                    return true;
                }
                return false;
            }
            function relativePath(path) {
                return getRelativePathFromDirectory(configDir, path, 
                /*ignoreCase*/
                !useCaseSensitiveFileNames2);
            }
        }
        function updateImports(program, changeTracker, oldToNew, newToOld, host, getCanonicalFileName) {
            const allFiles = program.getSourceFiles();
            for (const sourceFile of allFiles) {
                const newFromOld = oldToNew(sourceFile.fileName);
                const newImportFromPath = newFromOld ?? sourceFile.fileName;
                const newImportFromDirectory = getDirectoryPath(newImportFromPath);
                const oldFromNew = newToOld(sourceFile.fileName);
                const oldImportFromPath = oldFromNew || sourceFile.fileName;
                const oldImportFromDirectory = getDirectoryPath(oldImportFromPath);
                const importingSourceFileMoved = newFromOld !== void 0 || oldFromNew !== void 0;
                updateImportsWorker(sourceFile, changeTracker, (referenceText) => {
                    if (!pathIsRelative(referenceText))
                        return void 0;
                    const oldAbsolute = combinePathsSafe(oldImportFromDirectory, referenceText);
                    const newAbsolute = oldToNew(oldAbsolute);
                    return newAbsolute === void 0 ? void 0 : ensurePathIsNonModuleName(getRelativePathFromDirectory(newImportFromDirectory, newAbsolute, getCanonicalFileName));
                }, (importLiteral) => {
                    const importedModuleSymbol = program.getTypeChecker().getSymbolAtLocation(importLiteral);
                    if ((importedModuleSymbol == null ? void 0 : importedModuleSymbol.declarations) && importedModuleSymbol.declarations.some((d) => isAmbientModule(d)))
                        return void 0;
                    const toImport = oldFromNew !== void 0 ? getSourceFileToImportFromResolved(importLiteral, resolveModuleName(importLiteral.text, oldImportFromPath, program.getCompilerOptions(), host), oldToNew, allFiles) : getSourceFileToImport(importedModuleSymbol, importLiteral, sourceFile, program, host, oldToNew);
                    return toImport !== void 0 && (toImport.updated || importingSourceFileMoved && pathIsRelative(importLiteral.text)) ? ts_moduleSpecifiers_exports.updateModuleSpecifier(program.getCompilerOptions(), sourceFile, newImportFromPath, toImport.newFileName, createModuleSpecifierResolutionHost(program, host), importLiteral.text) : void 0;
                });
            }
        }
        function combineNormal(pathA, pathB) {
            return normalizePath(combinePaths(pathA, pathB));
        }
        function combinePathsSafe(pathA, pathB) {
            return ensurePathIsNonModuleName(combineNormal(pathA, pathB));
        }
        function getSourceFileToImport(importedModuleSymbol, importLiteral, importingSourceFile, program, host, oldToNew) {
            if (importedModuleSymbol) {
                const oldFileName = find(importedModuleSymbol.declarations, isSourceFile).fileName;
                const newFileName = oldToNew(oldFileName);
                return newFileName === void 0 ? { newFileName: oldFileName, updated: false } : { newFileName, updated: true };
            }
            else {
                const mode = program.getModeForUsageLocation(importingSourceFile, importLiteral);
                const resolved = host.resolveModuleNameLiterals || !host.resolveModuleNames ? program.getResolvedModuleFromModuleSpecifier(importLiteral) : host.getResolvedModuleWithFailedLookupLocationsFromCache && host.getResolvedModuleWithFailedLookupLocationsFromCache(importLiteral.text, importingSourceFile.fileName, mode);
                return getSourceFileToImportFromResolved(importLiteral, resolved, oldToNew, program.getSourceFiles());
            }
        }
        function getSourceFileToImportFromResolved(importLiteral, resolved, oldToNew, sourceFiles) {
            if (!resolved)
                return void 0;
            if (resolved.resolvedModule) {
                const result2 = tryChange(resolved.resolvedModule.resolvedFileName);
                if (result2)
                    return result2;
            }
            const result = forEach(resolved.failedLookupLocations, tryChangeWithIgnoringPackageJsonExisting) || pathIsRelative(importLiteral.text) && forEach(resolved.failedLookupLocations, tryChangeWithIgnoringPackageJson);
            if (result)
                return result;
            return resolved.resolvedModule && { newFileName: resolved.resolvedModule.resolvedFileName, updated: false };
            function tryChangeWithIgnoringPackageJsonExisting(oldFileName) {
                const newFileName = oldToNew(oldFileName);
                return newFileName && find(sourceFiles, (src) => src.fileName === newFileName) ? tryChangeWithIgnoringPackageJson(oldFileName) : void 0;
            }
            function tryChangeWithIgnoringPackageJson(oldFileName) {
                return !endsWith(oldFileName, "/package.json") ? tryChange(oldFileName) : void 0;
            }
            function tryChange(oldFileName) {
                const newFileName = oldToNew(oldFileName);
                return newFileName && { newFileName, updated: true };
            }
        }
        function updateImportsWorker(sourceFile, changeTracker, updateRef, updateImport2) {
            for (const ref of sourceFile.referencedFiles || emptyArray) {
                const updated = updateRef(ref.fileName);
                if (updated !== void 0 && updated !== sourceFile.text.slice(ref.pos, ref.end))
                    changeTracker.replaceRangeWithText(sourceFile, ref, updated);
            }
            for (const importStringLiteral of sourceFile.imports) {
                const updated = updateImport2(importStringLiteral);
                if (updated !== void 0 && updated !== importStringLiteral.text)
                    changeTracker.replaceRangeWithText(sourceFile, createStringRange(importStringLiteral, sourceFile), updated);
            }
        }
        function createStringRange(node, sourceFile) {
            return createRange(node.getStart(sourceFile) + 1, node.end - 1);
        }
        function forEachProperty(objectLiteral, cb) {
            if (!isObjectLiteralExpression(objectLiteral))
                return;
            for (const property of objectLiteral.properties) {
                if (isPropertyAssignment(property) && isStringLiteral(property.name)) {
                    cb(property, property.name.text);
                }
            }
        }
        var init_getEditsForFileRename = __esm({
            "src/services/getEditsForFileRename.ts"() {
                "use strict";
                init_ts4();
            }
        });
        // src/services/patternMatcher.ts
        function createPatternMatch(kind, isCaseSensitive) {
            return {
                kind,
                isCaseSensitive
            };
        }
        function createPatternMatcher(pattern) {
            const stringToWordSpans = /* @__PURE__ */ new Map();
            const dotSeparatedSegments = pattern.trim().split(".").map((p) => createSegment(p.trim()));
            if (dotSeparatedSegments.length === 1 && dotSeparatedSegments[0].totalTextChunk.text === "") {
                return {
                    getMatchForLastSegmentOfPattern: () => createPatternMatch(2 /* substring */, 
                    /*isCaseSensitive*/
                    true),
                    getFullMatch: () => createPatternMatch(2 /* substring */, 
                    /*isCaseSensitive*/
                    true),
                    patternContainsDots: false
                };
            }
            if (dotSeparatedSegments.some((segment) => !segment.subWordTextChunks.length))
                return void 0;
            return {
                getFullMatch: (containers, candidate) => getFullMatch(containers, candidate, dotSeparatedSegments, stringToWordSpans),
                getMatchForLastSegmentOfPattern: (candidate) => matchSegment(candidate, last(dotSeparatedSegments), stringToWordSpans),
                patternContainsDots: dotSeparatedSegments.length > 1
            };
        }
        function getFullMatch(candidateContainers, candidate, dotSeparatedSegments, stringToWordSpans) {
            const candidateMatch = matchSegment(candidate, last(dotSeparatedSegments), stringToWordSpans);
            if (!candidateMatch) {
                return void 0;
            }
            if (dotSeparatedSegments.length - 1 > candidateContainers.length) {
                return void 0;
            }
            let bestMatch;
            for (let i = dotSeparatedSegments.length - 2, j = candidateContainers.length - 1; i >= 0; i -= 1, j -= 1) {
                bestMatch = betterMatch(bestMatch, matchSegment(candidateContainers[j], dotSeparatedSegments[i], stringToWordSpans));
            }
            return bestMatch;
        }
        function getWordSpans(word, stringToWordSpans) {
            let spans = stringToWordSpans.get(word);
            if (!spans) {
                stringToWordSpans.set(word, spans = breakIntoWordSpans(word));
            }
            return spans;
        }
        function matchTextChunk(candidate, chunk, stringToWordSpans) {
            const index = indexOfIgnoringCase(candidate, chunk.textLowerCase);
            if (index === 0) {
                return createPatternMatch(chunk.text.length === candidate.length ? 0 /* exact */ : 1 /* prefix */, 
                /*isCaseSensitive:*/
                startsWith(candidate, chunk.text));
            }
            if (chunk.isLowerCase) {
                if (index === -1)
                    return void 0;
                const wordSpans = getWordSpans(candidate, stringToWordSpans);
                for (const span of wordSpans) {
                    if (partStartsWith(candidate, span, chunk.text, 
                    /*ignoreCase*/
                    true)) {
                        return createPatternMatch(2 /* substring */, 
                        /*isCaseSensitive:*/
                        partStartsWith(candidate, span, chunk.text, 
                        /*ignoreCase*/
                        false));
                    }
                }
                if (chunk.text.length < candidate.length && isUpperCaseLetter(candidate.charCodeAt(index))) {
                    return createPatternMatch(2 /* substring */, 
                    /*isCaseSensitive*/
                    false);
                }
            }
            else {
                if (candidate.indexOf(chunk.text) > 0) {
                    return createPatternMatch(2 /* substring */, 
                    /*isCaseSensitive*/
                    true);
                }
                if (chunk.characterSpans.length > 0) {
                    const candidateParts = getWordSpans(candidate, stringToWordSpans);
                    const isCaseSensitive = tryCamelCaseMatch(candidate, candidateParts, chunk, 
                    /*ignoreCase*/
                    false) ? true : tryCamelCaseMatch(candidate, candidateParts, chunk, 
                    /*ignoreCase*/
                    true) ? false : void 0;
                    if (isCaseSensitive !== void 0) {
                        return createPatternMatch(3 /* camelCase */, isCaseSensitive);
                    }
                }
            }
        }
        function matchSegment(candidate, segment, stringToWordSpans) {
            if (every2(segment.totalTextChunk.text, (ch) => ch !== 32 /* space */ && ch !== 42 /* asterisk */)) {
                const match = matchTextChunk(candidate, segment.totalTextChunk, stringToWordSpans);
                if (match)
                    return match;
            }
            const subWordTextChunks = segment.subWordTextChunks;
            let bestMatch;
            for (const subWordTextChunk of subWordTextChunks) {
                bestMatch = betterMatch(bestMatch, matchTextChunk(candidate, subWordTextChunk, stringToWordSpans));
            }
            return bestMatch;
        }
        function betterMatch(a, b) {
            return min([a, b], compareMatches);
        }
        function compareMatches(a, b) {
            return a === void 0 ? 1 /* GreaterThan */ : b === void 0 ? -1 /* LessThan */ : compareValues(a.kind, b.kind) || compareBooleans(!a.isCaseSensitive, !b.isCaseSensitive);
        }
        function partStartsWith(candidate, candidateSpan, pattern, ignoreCase, patternSpan = { start: 0, length: pattern.length }) {
            return patternSpan.length <= candidateSpan.length && everyInRange(0, patternSpan.length, (i) => equalChars(pattern.charCodeAt(patternSpan.start + i), candidate.charCodeAt(candidateSpan.start + i), ignoreCase));
        }
        function equalChars(ch1, ch2, ignoreCase) {
            return ignoreCase ? toLowerCase2(ch1) === toLowerCase2(ch2) : ch1 === ch2;
        }
        function tryCamelCaseMatch(candidate, candidateParts, chunk, ignoreCase) {
            const chunkCharacterSpans = chunk.characterSpans;
            let currentCandidate = 0;
            let currentChunkSpan = 0;
            let firstMatch;
            let contiguous;
            while (true) {
                if (currentChunkSpan === chunkCharacterSpans.length) {
                    return true;
                }
                else if (currentCandidate === candidateParts.length) {
                    return false;
                }
                let candidatePart = candidateParts[currentCandidate];
                let gotOneMatchThisCandidate = false;
                for (; currentChunkSpan < chunkCharacterSpans.length; currentChunkSpan++) {
                    const chunkCharacterSpan = chunkCharacterSpans[currentChunkSpan];
                    if (gotOneMatchThisCandidate) {
                        if (!isUpperCaseLetter(chunk.text.charCodeAt(chunkCharacterSpans[currentChunkSpan - 1].start)) || !isUpperCaseLetter(chunk.text.charCodeAt(chunkCharacterSpans[currentChunkSpan].start))) {
                            break;
                        }
                    }
                    if (!partStartsWith(candidate, candidatePart, chunk.text, ignoreCase, chunkCharacterSpan)) {
                        break;
                    }
                    gotOneMatchThisCandidate = true;
                    firstMatch = firstMatch === void 0 ? currentCandidate : firstMatch;
                    contiguous = contiguous === void 0 ? true : contiguous;
                    candidatePart = createTextSpan(candidatePart.start + chunkCharacterSpan.length, candidatePart.length - chunkCharacterSpan.length);
                }
                if (!gotOneMatchThisCandidate && contiguous !== void 0) {
                    contiguous = false;
                }
                currentCandidate++;
            }
        }
        function createSegment(text) {
            return {
                totalTextChunk: createTextChunk(text),
                subWordTextChunks: breakPatternIntoTextChunks(text)
            };
        }
        function isUpperCaseLetter(ch) {
            if (ch >= 65 /* A */ && ch <= 90 /* Z */) {
                return true;
            }
            if (ch < 127 /* maxAsciiCharacter */ || !isUnicodeIdentifierStart(ch, 99 /* Latest */)) {
                return false;
            }
            const str = String.fromCharCode(ch);
            return str === str.toUpperCase();
        }
        function isLowerCaseLetter(ch) {
            if (ch >= 97 /* a */ && ch <= 122 /* z */) {
                return true;
            }
            if (ch < 127 /* maxAsciiCharacter */ || !isUnicodeIdentifierStart(ch, 99 /* Latest */)) {
                return false;
            }
            const str = String.fromCharCode(ch);
            return str === str.toLowerCase();
        }
        function indexOfIgnoringCase(str, value) {
            const n = str.length - value.length;
            for (let start = 0; start <= n; start++) {
                if (every2(value, (valueChar, i) => toLowerCase2(str.charCodeAt(i + start)) === valueChar)) {
                    return start;
                }
            }
            return -1;
        }
        function toLowerCase2(ch) {
            if (ch >= 65 /* A */ && ch <= 90 /* Z */) {
                return 97 /* a */ + (ch - 65 /* A */);
            }
            if (ch < 127 /* maxAsciiCharacter */) {
                return ch;
            }
            return String.fromCharCode(ch).toLowerCase().charCodeAt(0);
        }
        function isDigit2(ch) {
            return ch >= 48 /* _0 */ && ch <= 57 /* _9 */;
        }
        function isWordChar(ch) {
            return isUpperCaseLetter(ch) || isLowerCaseLetter(ch) || isDigit2(ch) || ch === 95 /* _ */ || ch === 36 /* $ */;
        }
        function breakPatternIntoTextChunks(pattern) {
            const result = [];
            let wordStart = 0;
            let wordLength = 0;
            for (let i = 0; i < pattern.length; i++) {
                const ch = pattern.charCodeAt(i);
                if (isWordChar(ch)) {
                    if (wordLength === 0) {
                        wordStart = i;
                    }
                    wordLength++;
                }
                else {
                    if (wordLength > 0) {
                        result.push(createTextChunk(pattern.substr(wordStart, wordLength)));
                        wordLength = 0;
                    }
                }
            }
            if (wordLength > 0) {
                result.push(createTextChunk(pattern.substr(wordStart, wordLength)));
            }
            return result;
        }
        function createTextChunk(text) {
            const textLowerCase = text.toLowerCase();
            return {
                text,
                textLowerCase,
                isLowerCase: text === textLowerCase,
                characterSpans: breakIntoCharacterSpans(text)
            };
        }
        function breakIntoCharacterSpans(identifier) {
            return breakIntoSpans(identifier, 
            /*word*/
            false);
        }
        function breakIntoWordSpans(identifier) {
            return breakIntoSpans(identifier, 
            /*word*/
            true);
        }
        function breakIntoSpans(identifier, word) {
            const result = [];
            let wordStart = 0;
            for (let i = 1; i < identifier.length; i++) {
                const lastIsDigit = isDigit2(identifier.charCodeAt(i - 1));
                const currentIsDigit = isDigit2(identifier.charCodeAt(i));
                const hasTransitionFromLowerToUpper = transitionFromLowerToUpper(identifier, word, i);
                const hasTransitionFromUpperToLower = word && transitionFromUpperToLower(identifier, i, wordStart);
                if (charIsPunctuation(identifier.charCodeAt(i - 1)) || charIsPunctuation(identifier.charCodeAt(i)) || lastIsDigit !== currentIsDigit || hasTransitionFromLowerToUpper || hasTransitionFromUpperToLower) {
                    if (!isAllPunctuation(identifier, wordStart, i)) {
                        result.push(createTextSpan(wordStart, i - wordStart));
                    }
                    wordStart = i;
                }
            }
            if (!isAllPunctuation(identifier, wordStart, identifier.length)) {
                result.push(createTextSpan(wordStart, identifier.length - wordStart));
            }
            return result;
        }
        function charIsPunctuation(ch) {
            switch (ch) {
                case 33 /* exclamation */:
                case 34 /* doubleQuote */:
                case 35 /* hash */:
                case 37 /* percent */:
                case 38 /* ampersand */:
                case 39 /* singleQuote */:
                case 40 /* openParen */:
                case 41 /* closeParen */:
                case 42 /* asterisk */:
                case 44 /* comma */:
                case 45 /* minus */:
                case 46 /* dot */:
                case 47 /* slash */:
                case 58 /* colon */:
                case 59 /* semicolon */:
                case 63 /* question */:
                case 64 /* at */:
                case 91 /* openBracket */:
                case 92 /* backslash */:
                case 93 /* closeBracket */:
                case 95 /* _ */:
                case 123 /* openBrace */:
                case 125 /* closeBrace */:
                    return true;
            }
            return false;
        }
        function isAllPunctuation(identifier, start, end) {
            return every2(identifier, (ch) => charIsPunctuation(ch) && ch !== 95 /* _ */, start, end);
        }
        function transitionFromUpperToLower(identifier, index, wordStart) {
            return index !== wordStart && index + 1 < identifier.length && isUpperCaseLetter(identifier.charCodeAt(index)) && isLowerCaseLetter(identifier.charCodeAt(index + 1)) && every2(identifier, isUpperCaseLetter, wordStart, index);
        }
        function transitionFromLowerToUpper(identifier, word, index) {
            const lastIsUpper = isUpperCaseLetter(identifier.charCodeAt(index - 1));
            const currentIsUpper = isUpperCaseLetter(identifier.charCodeAt(index));
            return currentIsUpper && (!word || !lastIsUpper);
        }
        function everyInRange(start, end, pred) {
            for (let i = start; i < end; i++) {
                if (!pred(i)) {
                    return false;
                }
            }
            return true;
        }
        function every2(s, pred, start = 0, end = s.length) {
            return everyInRange(start, end, (i) => pred(s.charCodeAt(i), i));
        }
        var PatternMatchKind;
        var init_patternMatcher = __esm({
            "src/services/patternMatcher.ts"() {
                "use strict";
                init_ts4();
                PatternMatchKind = /* @__PURE__ */ ((PatternMatchKind2) => {
                    PatternMatchKind2[PatternMatchKind2["exact"] = 0] = "exact";
                    PatternMatchKind2[PatternMatchKind2["prefix"] = 1] = "prefix";
                    PatternMatchKind2[PatternMatchKind2["substring"] = 2] = "substring";
                    PatternMatchKind2[PatternMatchKind2["camelCase"] = 3] = "camelCase";
                    return PatternMatchKind2;
                })(PatternMatchKind || {});
            }
        });
        // src/services/preProcess.ts
        function preProcessFile(sourceText, readImportFiles = true, detectJavaScriptImports = false) {
            const pragmaContext = {
                languageVersion: 1 /* ES5 */,
                // controls whether the token scanner considers unicode identifiers or not - shouldn't matter, since we're only using it for trivia
                pragmas: void 0,
                checkJsDirective: void 0,
                referencedFiles: [],
                typeReferenceDirectives: [],
                libReferenceDirectives: [],
                amdDependencies: [],
                hasNoDefaultLib: void 0,
                moduleName: void 0
            };
            const importedFiles = [];
            let ambientExternalModules;
            let lastToken;
            let currentToken;
            let braceNesting = 0;
            let externalModule = false;
            function nextToken() {
                lastToken = currentToken;
                currentToken = scanner.scan();
                if (currentToken === 19 /* OpenBraceToken */) {
                    braceNesting++;
                }
                else if (currentToken === 20 /* CloseBraceToken */) {
                    braceNesting--;
                }
                return currentToken;
            }
            function getFileReference() {
                const fileName = scanner.getTokenValue();
                const pos = scanner.getTokenStart();
                return { fileName, pos, end: pos + fileName.length };
            }
            function recordAmbientExternalModule() {
                if (!ambientExternalModules) {
                    ambientExternalModules = [];
                }
                ambientExternalModules.push({ ref: getFileReference(), depth: braceNesting });
            }
            function recordModuleName() {
                importedFiles.push(getFileReference());
                markAsExternalModuleIfTopLevel();
            }
            function markAsExternalModuleIfTopLevel() {
                if (braceNesting === 0) {
                    externalModule = true;
                }
            }
            function tryConsumeDeclare() {
                let token = scanner.getToken();
                if (token === 138 /* DeclareKeyword */) {
                    token = nextToken();
                    if (token === 144 /* ModuleKeyword */) {
                        token = nextToken();
                        if (token === 11 /* StringLiteral */) {
                            recordAmbientExternalModule();
                        }
                    }
                    return true;
                }
                return false;
            }
            function tryConsumeImport() {
                if (lastToken === 25 /* DotToken */) {
                    return false;
                }
                let token = scanner.getToken();
                if (token === 102 /* ImportKeyword */) {
                    token = nextToken();
                    if (token === 21 /* OpenParenToken */) {
                        token = nextToken();
                        if (token === 11 /* StringLiteral */ || token === 15 /* NoSubstitutionTemplateLiteral */) {
                            recordModuleName();
                            return true;
                        }
                    }
                    else if (token === 11 /* StringLiteral */) {
                        recordModuleName();
                        return true;
                    }
                    else {
                        if (token === 156 /* TypeKeyword */) {
                            const skipTypeKeyword = scanner.lookAhead(() => {
                                const token2 = scanner.scan();
                                return token2 !== 161 /* FromKeyword */ && (token2 === 42 /* AsteriskToken */ || token2 === 19 /* OpenBraceToken */ || token2 === 80 /* Identifier */ || isKeyword(token2));
                            });
                            if (skipTypeKeyword) {
                                token = nextToken();
                            }
                        }
                        if (token === 80 /* Identifier */ || isKeyword(token)) {
                            token = nextToken();
                            if (token === 161 /* FromKeyword */) {
                                token = nextToken();
                                if (token === 11 /* StringLiteral */) {
                                    recordModuleName();
                                    return true;
                                }
                            }
                            else if (token === 64 /* EqualsToken */) {
                                if (tryConsumeRequireCall(
                                /*skipCurrentToken*/
                                true)) {
                                    return true;
                                }
                            }
                            else if (token === 28 /* CommaToken */) {
                                token = nextToken();
                            }
                            else {
                                return true;
                            }
                        }
                        if (token === 19 /* OpenBraceToken */) {
                            token = nextToken();
                            while (token !== 20 /* CloseBraceToken */ && token !== 1 /* EndOfFileToken */) {
                                token = nextToken();
                            }
                            if (token === 20 /* CloseBraceToken */) {
                                token = nextToken();
                                if (token === 161 /* FromKeyword */) {
                                    token = nextToken();
                                    if (token === 11 /* StringLiteral */) {
                                        recordModuleName();
                                    }
                                }
                            }
                        }
                        else if (token === 42 /* AsteriskToken */) {
                            token = nextToken();
                            if (token === 130 /* AsKeyword */) {
                                token = nextToken();
                                if (token === 80 /* Identifier */ || isKeyword(token)) {
                                    token = nextToken();
                                    if (token === 161 /* FromKeyword */) {
                                        token = nextToken();
                                        if (token === 11 /* StringLiteral */) {
                                            recordModuleName();
                                        }
                                    }
                                }
                            }
                        }
                    }
                    return true;
                }
                return false;
            }
            function tryConsumeExport() {
                let token = scanner.getToken();
                if (token === 95 /* ExportKeyword */) {
                    markAsExternalModuleIfTopLevel();
                    token = nextToken();
                    if (token === 156 /* TypeKeyword */) {
                        const skipTypeKeyword = scanner.lookAhead(() => {
                            const token2 = scanner.scan();
                            return token2 === 42 /* AsteriskToken */ || token2 === 19 /* OpenBraceToken */;
                        });
                        if (skipTypeKeyword) {
                            token = nextToken();
                        }
                    }
                    if (token === 19 /* OpenBraceToken */) {
                        token = nextToken();
                        while (token !== 20 /* CloseBraceToken */ && token !== 1 /* EndOfFileToken */) {
                            token = nextToken();
                        }
                        if (token === 20 /* CloseBraceToken */) {
                            token = nextToken();
                            if (token === 161 /* FromKeyword */) {
                                token = nextToken();
                                if (token === 11 /* StringLiteral */) {
                                    recordModuleName();
                                }
                            }
                        }
                    }
                    else if (token === 42 /* AsteriskToken */) {
                        token = nextToken();
                        if (token === 161 /* FromKeyword */) {
                            token = nextToken();
                            if (token === 11 /* StringLiteral */) {
                                recordModuleName();
                            }
                        }
                    }
                    else if (token === 102 /* ImportKeyword */) {
                        token = nextToken();
                        if (token === 156 /* TypeKeyword */) {
                            const skipTypeKeyword = scanner.lookAhead(() => {
                                const token2 = scanner.scan();
                                return token2 === 80 /* Identifier */ || isKeyword(token2);
                            });
                            if (skipTypeKeyword) {
                                token = nextToken();
                            }
                        }
                        if (token === 80 /* Identifier */ || isKeyword(token)) {
                            token = nextToken();
                            if (token === 64 /* EqualsToken */) {
                                if (tryConsumeRequireCall(
                                /*skipCurrentToken*/
                                true)) {
                                    return true;
                                }
                            }
                        }
                    }
                    return true;
                }
                return false;
            }
            function tryConsumeRequireCall(skipCurrentToken, allowTemplateLiterals = false) {
                let token = skipCurrentToken ? nextToken() : scanner.getToken();
                if (token === 149 /* RequireKeyword */) {
                    token = nextToken();
                    if (token === 21 /* OpenParenToken */) {
                        token = nextToken();
                        if (token === 11 /* StringLiteral */ || allowTemplateLiterals && token === 15 /* NoSubstitutionTemplateLiteral */) {
                            recordModuleName();
                        }
                    }
                    return true;
                }
                return false;
            }
            function tryConsumeDefine() {
                let token = scanner.getToken();
                if (token === 80 /* Identifier */ && scanner.getTokenValue() === "define") {
                    token = nextToken();
                    if (token !== 21 /* OpenParenToken */) {
                        return true;
                    }
                    token = nextToken();
                    if (token === 11 /* StringLiteral */ || token === 15 /* NoSubstitutionTemplateLiteral */) {
                        token = nextToken();
                        if (token === 28 /* CommaToken */) {
                            token = nextToken();
                        }
                        else {
                            return true;
                        }
                    }
                    if (token !== 23 /* OpenBracketToken */) {
                        return true;
                    }
                    token = nextToken();
                    while (token !== 24 /* CloseBracketToken */ && token !== 1 /* EndOfFileToken */) {
                        if (token === 11 /* StringLiteral */ || token === 15 /* NoSubstitutionTemplateLiteral */) {
                            recordModuleName();
                        }
                        token = nextToken();
                    }
                    return true;
                }
                return false;
            }
            function processImports() {
                scanner.setText(sourceText);
                nextToken();
                while (true) {
                    if (scanner.getToken() === 1 /* EndOfFileToken */) {
                        break;
                    }
                    if (scanner.getToken() === 16 /* TemplateHead */) {
                        const stack = [scanner.getToken()];
                        loop: while (length(stack)) {
                            const token = scanner.scan();
                            switch (token) {
                                case 1 /* EndOfFileToken */:
                                    break loop;
                                case 102 /* ImportKeyword */:
                                    tryConsumeImport();
                                    break;
                                case 16 /* TemplateHead */:
                                    stack.push(token);
                                    break;
                                case 19 /* OpenBraceToken */:
                                    if (length(stack)) {
                                        stack.push(token);
                                    }
                                    break;
                                case 20 /* CloseBraceToken */:
                                    if (length(stack)) {
                                        if (lastOrUndefined(stack) === 16 /* TemplateHead */) {
                                            if (scanner.reScanTemplateToken(
                                            /*isTaggedTemplate*/
                                            false) === 18 /* TemplateTail */) {
                                                stack.pop();
                                            }
                                        }
                                        else {
                                            stack.pop();
                                        }
                                    }
                                    break;
                            }
                        }
                        nextToken();
                    }
                    if (tryConsumeDeclare() || tryConsumeImport() || tryConsumeExport() || detectJavaScriptImports && (tryConsumeRequireCall(
                    /*skipCurrentToken*/
                    false, 
                    /*allowTemplateLiterals*/
                    true) || tryConsumeDefine())) {
                        continue;
                    }
                    else {
                        nextToken();
                    }
                }
                scanner.setText(void 0);
            }
            if (readImportFiles) {
                processImports();
            }
            processCommentPragmas(pragmaContext, sourceText);
            processPragmasIntoFields(pragmaContext, noop);
            if (externalModule) {
                if (ambientExternalModules) {
                    for (const decl of ambientExternalModules) {
                        importedFiles.push(decl.ref);
                    }
                }
                return { referencedFiles: pragmaContext.referencedFiles, typeReferenceDirectives: pragmaContext.typeReferenceDirectives, libReferenceDirectives: pragmaContext.libReferenceDirectives, importedFiles, isLibFile: !!pragmaContext.hasNoDefaultLib, ambientExternalModules: void 0 };
            }
            else {
                let ambientModuleNames;
                if (ambientExternalModules) {
                    for (const decl of ambientExternalModules) {
                        if (decl.depth === 0) {
                            if (!ambientModuleNames) {
                                ambientModuleNames = [];
                            }
                            ambientModuleNames.push(decl.ref.fileName);
                        }
                        else {
                            importedFiles.push(decl.ref);
                        }
                    }
                }
                return { referencedFiles: pragmaContext.referencedFiles, typeReferenceDirectives: pragmaContext.typeReferenceDirectives, libReferenceDirectives: pragmaContext.libReferenceDirectives, importedFiles, isLibFile: !!pragmaContext.hasNoDefaultLib, ambientExternalModules: ambientModuleNames };
            }
        }
        var init_preProcess = __esm({
            "src/services/preProcess.ts"() {
                "use strict";
                init_ts4();
            }
        });
        // src/services/sourcemaps.ts
        function getSourceMapper(host) {
            const getCanonicalFileName = createGetCanonicalFileName(host.useCaseSensitiveFileNames());
            const currentDirectory = host.getCurrentDirectory();
            const sourceFileLike = /* @__PURE__ */ new Map();
            const documentPositionMappers = /* @__PURE__ */ new Map();
            return { tryGetSourcePosition, tryGetGeneratedPosition, toLineColumnOffset, clearCache };
            function toPath3(fileName) {
                return toPath(fileName, currentDirectory, getCanonicalFileName);
            }
            function getDocumentPositionMapper2(generatedFileName, sourceFileName) {
                const path = toPath3(generatedFileName);
                const value = documentPositionMappers.get(path);
                if (value)
                    return value;
                let mapper;
                if (host.getDocumentPositionMapper) {
                    mapper = host.getDocumentPositionMapper(generatedFileName, sourceFileName);
                }
                else if (host.readFile) {
                    const file = getSourceFileLike(generatedFileName);
                    mapper = file && getDocumentPositionMapper({ getSourceFileLike, getCanonicalFileName, log: (s) => host.log(s) }, generatedFileName, getLineInfo(file.text, getLineStarts(file)), (f) => !host.fileExists || host.fileExists(f) ? host.readFile(f) : void 0);
                }
                documentPositionMappers.set(path, mapper || identitySourceMapConsumer);
                return mapper || identitySourceMapConsumer;
            }
            function tryGetSourcePosition(info) {
                if (!isDeclarationFileName(info.fileName))
                    return void 0;
                const file = getSourceFile(info.fileName);
                if (!file)
                    return void 0;
                const newLoc = getDocumentPositionMapper2(info.fileName).getSourcePosition(info);
                return !newLoc || newLoc === info ? void 0 : tryGetSourcePosition(newLoc) || newLoc;
            }
            function tryGetGeneratedPosition(info) {
                if (isDeclarationFileName(info.fileName))
                    return void 0;
                const sourceFile = getSourceFile(info.fileName);
                if (!sourceFile)
                    return void 0;
                const program = host.getProgram();
                if (program.isSourceOfProjectReferenceRedirect(sourceFile.fileName)) {
                    return void 0;
                }
                const options = program.getCompilerOptions();
                const outPath = outFile(options);
                const declarationPath = outPath ? removeFileExtension(outPath) + ".d.ts" /* Dts */ : getDeclarationEmitOutputFilePathWorker(info.fileName, program.getCompilerOptions(), currentDirectory, program.getCommonSourceDirectory(), getCanonicalFileName);
                if (declarationPath === void 0)
                    return void 0;
                const newLoc = getDocumentPositionMapper2(declarationPath, info.fileName).getGeneratedPosition(info);
                return newLoc === info ? void 0 : newLoc;
            }
            function getSourceFile(fileName) {
                const program = host.getProgram();
                if (!program)
                    return void 0;
                const path = toPath3(fileName);
                const file = program.getSourceFileByPath(path);
                return file && file.resolvedPath === path ? file : void 0;
            }
            function getOrCreateSourceFileLike(fileName) {
                const path = toPath3(fileName);
                const fileFromCache = sourceFileLike.get(path);
                if (fileFromCache !== void 0)
                    return fileFromCache ? fileFromCache : void 0;
                if (!host.readFile || host.fileExists && !host.fileExists(fileName)) {
                    sourceFileLike.set(path, false);
                    return void 0;
                }
                const text = host.readFile(fileName);
                const file = text ? createSourceFileLike(text) : false;
                sourceFileLike.set(path, file);
                return file ? file : void 0;
            }
            function getSourceFileLike(fileName) {
                return !host.getSourceFileLike ? getSourceFile(fileName) || getOrCreateSourceFileLike(fileName) : host.getSourceFileLike(fileName);
            }
            function toLineColumnOffset(fileName, position) {
                const file = getSourceFileLike(fileName);
                return file.getLineAndCharacterOfPosition(position);
            }
            function clearCache() {
                sourceFileLike.clear();
                documentPositionMappers.clear();
            }
        }
        function getDocumentPositionMapper(host, generatedFileName, generatedFileLineInfo, readMapFile) {
            let mapFileName = tryGetSourceMappingURL(generatedFileLineInfo);
            if (mapFileName) {
                const match = base64UrlRegExp.exec(mapFileName);
                if (match) {
                    if (match[1]) {
                        const base64Object = match[1];
                        return convertDocumentToSourceMapper(host, base64decode(sys, base64Object), generatedFileName);
                    }
                    mapFileName = void 0;
                }
            }
            const possibleMapLocations = [];
            if (mapFileName) {
                possibleMapLocations.push(mapFileName);
            }
            possibleMapLocations.push(generatedFileName + ".map");
            const originalMapFileName = mapFileName && getNormalizedAbsolutePath(mapFileName, getDirectoryPath(generatedFileName));
            for (const location of possibleMapLocations) {
                const mapFileName2 = getNormalizedAbsolutePath(location, getDirectoryPath(generatedFileName));
                const mapFileContents = readMapFile(mapFileName2, originalMapFileName);
                if (isString(mapFileContents)) {
                    return convertDocumentToSourceMapper(host, mapFileContents, mapFileName2);
                }
                if (mapFileContents !== void 0) {
                    return mapFileContents || void 0;
                }
            }
            return void 0;
        }
        function convertDocumentToSourceMapper(host, contents, mapFileName) {
            const map2 = tryParseRawSourceMap(contents);
            if (!map2 || !map2.sources || !map2.file || !map2.mappings) {
                return void 0;
            }
            if (map2.sourcesContent && map2.sourcesContent.some(isString))
                return void 0;
            return createDocumentPositionMapper(host, map2, mapFileName);
        }
        function createSourceFileLike(text, lineMap) {
            return {
                text,
                lineMap,
                getLineAndCharacterOfPosition(pos) {
                    return computeLineAndCharacterOfPosition(getLineStarts(this), pos);
                }
            };
        }
        var base64UrlRegExp;
        var init_sourcemaps = __esm({
            "src/services/sourcemaps.ts"() {
                "use strict";
                init_ts4();
                base64UrlRegExp = /^data:(?:application\/json(?:;charset=[uU][tT][fF]-8);base64,([A-Za-z0-9+/=]+)$)?/;
            }
        });
        // src/services/suggestionDiagnostics.ts
        function computeSuggestionDiagnostics(sourceFile, program, cancellationToken) {
            var _a;
            program.getSemanticDiagnostics(sourceFile, cancellationToken);
            const diags = [];
            const checker = program.getTypeChecker();
            const isCommonJSFile = sourceFile.impliedNodeFormat === 1 /* CommonJS */ || fileExtensionIsOneOf(sourceFile.fileName, [".cts" /* Cts */, ".cjs" /* Cjs */]);
            if (!isCommonJSFile && sourceFile.commonJsModuleIndicator && (programContainsEsModules(program) || compilerOptionsIndicateEsModules(program.getCompilerOptions())) && containsTopLevelCommonjs(sourceFile)) {
                diags.push(createDiagnosticForNode(getErrorNodeFromCommonJsIndicator(sourceFile.commonJsModuleIndicator), Diagnostics.File_is_a_CommonJS_module_it_may_be_converted_to_an_ES_module));
            }
            const isJsFile = isSourceFileJS(sourceFile);
            visitedNestedConvertibleFunctions.clear();
            check(sourceFile);
            if (getAllowSyntheticDefaultImports(program.getCompilerOptions())) {
                for (const moduleSpecifier of sourceFile.imports) {
                    const importNode = importFromModuleSpecifier(moduleSpecifier);
                    const name = importNameForConvertToDefaultImport(importNode);
                    if (!name)
                        continue;
                    const module2 = (_a = program.getResolvedModuleFromModuleSpecifier(moduleSpecifier)) == null ? void 0 : _a.resolvedModule;
                    const resolvedFile = module2 && program.getSourceFile(module2.resolvedFileName);
                    if (resolvedFile && resolvedFile.externalModuleIndicator && resolvedFile.externalModuleIndicator !== true && isExportAssignment(resolvedFile.externalModuleIndicator) && resolvedFile.externalModuleIndicator.isExportEquals) {
                        diags.push(createDiagnosticForNode(name, Diagnostics.Import_may_be_converted_to_a_default_import));
                    }
                }
            }
            addRange(diags, sourceFile.bindSuggestionDiagnostics);
            addRange(diags, program.getSuggestionDiagnostics(sourceFile, cancellationToken));
            return diags.sort((d1, d2) => d1.start - d2.start);
            function check(node) {
                if (isJsFile) {
                    if (canBeConvertedToClass(node, checker)) {
                        diags.push(createDiagnosticForNode(isVariableDeclaration(node.parent) ? node.parent.name : node, Diagnostics.This_constructor_function_may_be_converted_to_a_class_declaration));
                    }
                }
                else {
                    if (isVariableStatement(node) && node.parent === sourceFile && node.declarationList.flags & 2 /* Const */ && node.declarationList.declarations.length === 1) {
                        const init = node.declarationList.declarations[0].initializer;
                        if (init && isRequireCall(init, 
                        /*requireStringLiteralLikeArgument*/
                        true)) {
                            diags.push(createDiagnosticForNode(init, Diagnostics.require_call_may_be_converted_to_an_import));
                        }
                    }
                    const jsdocTypedefNodes = ts_codefix_exports.getJSDocTypedefNodes(node);
                    for (const jsdocTypedefNode of jsdocTypedefNodes) {
                        diags.push(createDiagnosticForNode(jsdocTypedefNode, Diagnostics.JSDoc_typedef_may_be_converted_to_TypeScript_type));
                    }
                    if (ts_codefix_exports.parameterShouldGetTypeFromJSDoc(node)) {
                        diags.push(createDiagnosticForNode(node.name || node, Diagnostics.JSDoc_types_may_be_moved_to_TypeScript_types));
                    }
                }
                if (canBeConvertedToAsync(node)) {
                    addConvertToAsyncFunctionDiagnostics(node, checker, diags);
                }
                node.forEachChild(check);
            }
        }
        function containsTopLevelCommonjs(sourceFile) {
            return sourceFile.statements.some((statement) => {
                switch (statement.kind) {
                    case 243 /* VariableStatement */:
                        return statement.declarationList.declarations.some((decl) => !!decl.initializer && isRequireCall(propertyAccessLeftHandSide(decl.initializer), 
                        /*requireStringLiteralLikeArgument*/
                        true));
                    case 244 /* ExpressionStatement */: {
                        const { expression } = statement;
                        if (!isBinaryExpression(expression))
                            return isRequireCall(expression, 
                            /*requireStringLiteralLikeArgument*/
                            true);
                        const kind = getAssignmentDeclarationKind(expression);
                        return kind === 1 /* ExportsProperty */ || kind === 2 /* ModuleExports */;
                    }
                    default:
                        return false;
                }
            });
        }
        function propertyAccessLeftHandSide(node) {
            return isPropertyAccessExpression(node) ? propertyAccessLeftHandSide(node.expression) : node;
        }
        function importNameForConvertToDefaultImport(node) {
            switch (node.kind) {
                case 272 /* ImportDeclaration */:
                    const { importClause, moduleSpecifier } = node;
                    return importClause && !importClause.name && importClause.namedBindings && importClause.namedBindings.kind === 274 /* NamespaceImport */ && isStringLiteral(moduleSpecifier) ? importClause.namedBindings.name : void 0;
                case 271 /* ImportEqualsDeclaration */:
                    return node.name;
                default:
                    return void 0;
            }
        }
        function addConvertToAsyncFunctionDiagnostics(node, checker, diags) {
            if (isConvertibleFunction(node, checker) && !visitedNestedConvertibleFunctions.has(getKeyFromNode(node))) {
                diags.push(createDiagnosticForNode(!node.name && isVariableDeclaration(node.parent) && isIdentifier(node.parent.name) ? node.parent.name : node, Diagnostics.This_may_be_converted_to_an_async_function));
            }
        }
        function isConvertibleFunction(node, checker) {
            return !isAsyncFunction(node) && node.body && isBlock(node.body) && hasReturnStatementWithPromiseHandler(node.body, checker) && returnsPromise(node, checker);
        }
        function returnsPromise(node, checker) {
            const signature = checker.getSignatureFromDeclaration(node);
            const returnType = signature ? checker.getReturnTypeOfSignature(signature) : void 0;
            return !!returnType && !!checker.getPromisedTypeOfPromise(returnType);
        }
        function getErrorNodeFromCommonJsIndicator(commonJsModuleIndicator) {
            return isBinaryExpression(commonJsModuleIndicator) ? commonJsModuleIndicator.left : commonJsModuleIndicator;
        }
        function hasReturnStatementWithPromiseHandler(body, checker) {
            return !!forEachReturnStatement(body, (statement) => isReturnStatementWithFixablePromiseHandler(statement, checker));
        }
        function isReturnStatementWithFixablePromiseHandler(node, checker) {
            return isReturnStatement(node) && !!node.expression && isFixablePromiseHandler(node.expression, checker);
        }
        function isFixablePromiseHandler(node, checker) {
            if (!isPromiseHandler(node) || !hasSupportedNumberOfArguments(node) || !node.arguments.every((arg) => isFixablePromiseArgument(arg, checker))) {
                return false;
            }
            let currentNode = node.expression.expression;
            while (isPromiseHandler(currentNode) || isPropertyAccessExpression(currentNode)) {
                if (isCallExpression(currentNode)) {
                    if (!hasSupportedNumberOfArguments(currentNode) || !currentNode.arguments.every((arg) => isFixablePromiseArgument(arg, checker))) {
                        return false;
                    }
                    currentNode = currentNode.expression.expression;
                }
                else {
                    currentNode = currentNode.expression;
                }
            }
            return true;
        }
        function isPromiseHandler(node) {
            return isCallExpression(node) && (hasPropertyAccessExpressionWithName(node, "then") || hasPropertyAccessExpressionWithName(node, "catch") || hasPropertyAccessExpressionWithName(node, "finally"));
        }
        function hasSupportedNumberOfArguments(node) {
            const name = node.expression.name.text;
            const maxArguments = name === "then" ? 2 : name === "catch" ? 1 : name === "finally" ? 1 : 0;
            if (node.arguments.length > maxArguments)
                return false;
            if (node.arguments.length < maxArguments)
                return true;
            return maxArguments === 1 || some(node.arguments, (arg) => {
                return arg.kind === 106 /* NullKeyword */ || isIdentifier(arg) && arg.text === "undefined";
            });
        }
        function isFixablePromiseArgument(arg, checker) {
            switch (arg.kind) {
                case 262 /* FunctionDeclaration */:
                case 218 /* FunctionExpression */:
                    const functionFlags = getFunctionFlags(arg);
                    if (functionFlags & 1 /* Generator */) {
                        return false;
                    }
                case 219 /* ArrowFunction */:
                    visitedNestedConvertibleFunctions.set(getKeyFromNode(arg), true);
                case 106 /* NullKeyword */:
                    return true;
                case 80 /* Identifier */:
                case 211 /* PropertyAccessExpression */: {
                    const symbol = checker.getSymbolAtLocation(arg);
                    if (!symbol) {
                        return false;
                    }
                    return checker.isUndefinedSymbol(symbol) || some(skipAlias(symbol, checker).declarations, (d) => isFunctionLike(d) || hasInitializer(d) && !!d.initializer && isFunctionLike(d.initializer));
                }
                default:
                    return false;
            }
        }
        function getKeyFromNode(exp) {
            return `${exp.pos.toString()}:${exp.end.toString()}`;
        }
        function canBeConvertedToClass(node, checker) {
            var _a, _b, _c, _d;
            if (isFunctionExpression(node)) {
                if (isVariableDeclaration(node.parent) && ((_a = node.symbol.members) == null ? void 0 : _a.size)) {
                    return true;
                }
                const symbol = checker.getSymbolOfExpando(node, 
                /*allowDeclaration*/
                false);
                return !!(symbol && (((_b = symbol.exports) == null ? void 0 : _b.size) || ((_c = symbol.members) == null ? void 0 : _c.size)));
            }
            if (isFunctionDeclaration(node)) {
                return !!((_d = node.symbol.members) == null ? void 0 : _d.size);
            }
            return false;
        }
        function canBeConvertedToAsync(node) {
            switch (node.kind) {
                case 262 /* FunctionDeclaration */:
                case 174 /* MethodDeclaration */:
                case 218 /* FunctionExpression */:
                case 219 /* ArrowFunction */:
                    return true;
                default:
                    return false;
            }
        }
        var visitedNestedConvertibleFunctions;
        var init_suggestionDiagnostics = __esm({
            "src/services/suggestionDiagnostics.ts"() {
                "use strict";
                init_ts4();
                visitedNestedConvertibleFunctions = /* @__PURE__ */ new Map();
            }
        });
        // src/services/transpile.ts
        function transpileModule(input, transpileOptions) {
            const diagnostics = [];
            const options = transpileOptions.compilerOptions ? fixupCompilerOptions(transpileOptions.compilerOptions, diagnostics) : {};
            const defaultOptions = getDefaultCompilerOptions2();
            for (const key in defaultOptions) {
                if (hasProperty(defaultOptions, key) && options[key] === void 0) {
                    options[key] = defaultOptions[key];
                }
            }
            for (const option of transpileOptionValueCompilerOptions) {
                if (options.verbatimModuleSyntax && optionsRedundantWithVerbatimModuleSyntax.has(option.name)) {
                    continue;
                }
                options[option.name] = option.transpileOptionValue;
            }
            options.suppressOutputPathCheck = true;
            options.allowNonTsExtensions = true;
            const newLine = getNewLineCharacter(options);
            const compilerHost = {
                getSourceFile: (fileName) => fileName === normalizePath(inputFileName) ? sourceFile : void 0,
                writeFile: (name, text) => {
                    if (fileExtensionIs(name, ".map")) {
                        Debug.assertEqual(sourceMapText, void 0, "Unexpected multiple source map outputs, file:", name);
                        sourceMapText = text;
                    }
                    else {
                        Debug.assertEqual(outputText, void 0, "Unexpected multiple outputs, file:", name);
                        outputText = text;
                    }
                },
                getDefaultLibFileName: () => "lib.d.ts",
                useCaseSensitiveFileNames: () => false,
                getCanonicalFileName: (fileName) => fileName,
                getCurrentDirectory: () => "",
                getNewLine: () => newLine,
                fileExists: (fileName) => fileName === inputFileName,
                readFile: () => "",
                directoryExists: () => true,
                getDirectories: () => []
            };
            const inputFileName = transpileOptions.fileName || (transpileOptions.compilerOptions && transpileOptions.compilerOptions.jsx ? "module.tsx" : "module.ts");
            const sourceFile = createSourceFile(inputFileName, input, {
                languageVersion: getEmitScriptTarget(options),
                impliedNodeFormat: getImpliedNodeFormatForFile(toPath(inputFileName, "", compilerHost.getCanonicalFileName), 
                /*packageJsonInfoCache*/
                void 0, compilerHost, options),
                setExternalModuleIndicator: getSetExternalModuleIndicator(options),
                jsDocParsingMode: transpileOptions.jsDocParsingMode ?? 0 /* ParseAll */
            });
            if (transpileOptions.moduleName) {
                sourceFile.moduleName = transpileOptions.moduleName;
            }
            if (transpileOptions.renamedDependencies) {
                sourceFile.renamedDependencies = new Map(Object.entries(transpileOptions.renamedDependencies));
            }
            let outputText;
            let sourceMapText;
            const program = createProgram([inputFileName], options, compilerHost);
            if (transpileOptions.reportDiagnostics) {
                addRange(
                /*to*/
                diagnostics, 
                /*from*/
                program.getSyntacticDiagnostics(sourceFile));
                addRange(
                /*to*/
                diagnostics, 
                /*from*/
                program.getOptionsDiagnostics());
            }
            program.emit(
            /*targetSourceFile*/
            void 0, 
            /*writeFile*/
            void 0, 
            /*cancellationToken*/
            void 0, 
            /*emitOnlyDtsFiles*/
            void 0, transpileOptions.transformers);
            if (outputText === void 0)
                return Debug.fail("Output generation failed");
            return { outputText, diagnostics, sourceMapText };
        }
        function transpile(input, compilerOptions, fileName, diagnostics, moduleName) {
            const output = transpileModule(input, { compilerOptions, fileName, reportDiagnostics: !!diagnostics, moduleName });
            addRange(diagnostics, output.diagnostics);
            return output.outputText;
        }
        function fixupCompilerOptions(options, diagnostics) {
            commandLineOptionsStringToEnum = commandLineOptionsStringToEnum || filter(optionDeclarations, (o) => typeof o.type === "object" && !forEachEntry(o.type, (v) => typeof v !== "number"));
            options = cloneCompilerOptions(options);
            for (const opt of commandLineOptionsStringToEnum) {
                if (!hasProperty(options, opt.name)) {
                    continue;
                }
                const value = options[opt.name];
                if (isString(value)) {
                    options[opt.name] = parseCustomTypeOption(opt, value, diagnostics);
                }
                else {
                    if (!forEachEntry(opt.type, (v) => v === value)) {
                        diagnostics.push(createCompilerDiagnosticForInvalidCustomType(opt));
                    }
                }
            }
            return options;
        }
        var optionsRedundantWithVerbatimModuleSyntax, commandLineOptionsStringToEnum;
        var init_transpile = __esm({
            "src/services/transpile.ts"() {
                "use strict";
                init_ts4();
                optionsRedundantWithVerbatimModuleSyntax = /* @__PURE__ */ new Set([
                    "isolatedModules",
                    "preserveValueImports",
                    "importsNotUsedAsValues"
                ]);
            }
        });
        // src/services/navigateTo.ts
        function getNavigateToItems(sourceFiles, checker, cancellationToken, searchValue, maxResultCount, excludeDtsFiles, excludeLibFiles) {
            const patternMatcher = createPatternMatcher(searchValue);
            if (!patternMatcher)
                return emptyArray;
            const rawItems = [];
            const singleCurrentFile = sourceFiles.length === 1 ? sourceFiles[0] : void 0;
            for (const sourceFile of sourceFiles) {
                cancellationToken.throwIfCancellationRequested();
                if (excludeDtsFiles && sourceFile.isDeclarationFile) {
                    continue;
                }
                if (shouldExcludeFile(sourceFile, !!excludeLibFiles, singleCurrentFile)) {
                    continue;
                }
                sourceFile.getNamedDeclarations().forEach((declarations, name) => {
                    getItemsFromNamedDeclaration(patternMatcher, name, declarations, checker, sourceFile.fileName, !!excludeLibFiles, singleCurrentFile, rawItems);
                });
            }
            rawItems.sort(compareNavigateToItems);
            return (maxResultCount === void 0 ? rawItems : rawItems.slice(0, maxResultCount)).map(createNavigateToItem);
        }
        function shouldExcludeFile(file, excludeLibFiles, singleCurrentFile) {
            return file !== singleCurrentFile && excludeLibFiles && (isInsideNodeModules(file.path) || file.hasNoDefaultLib);
        }
        function getItemsFromNamedDeclaration(patternMatcher, name, declarations, checker, fileName, excludeLibFiles, singleCurrentFile, rawItems) {
            const match = patternMatcher.getMatchForLastSegmentOfPattern(name);
            if (!match) {
                return;
            }
            for (const declaration of declarations) {
                if (!shouldKeepItem(declaration, checker, excludeLibFiles, singleCurrentFile))
                    continue;
                if (patternMatcher.patternContainsDots) {
                    const fullMatch = patternMatcher.getFullMatch(getContainers(declaration), name);
                    if (fullMatch) {
                        rawItems.push({ name, fileName, matchKind: fullMatch.kind, isCaseSensitive: fullMatch.isCaseSensitive, declaration });
                    }
                }
                else {
                    rawItems.push({ name, fileName, matchKind: match.kind, isCaseSensitive: match.isCaseSensitive, declaration });
                }
            }
        }
        function shouldKeepItem(declaration, checker, excludeLibFiles, singleCurrentFile) {
            var _a;
            switch (declaration.kind) {
                case 273 /* ImportClause */:
                case 276 /* ImportSpecifier */:
                case 271 /* ImportEqualsDeclaration */:
                    const importer = checker.getSymbolAtLocation(declaration.name);
                    const imported = checker.getAliasedSymbol(importer);
                    return importer.escapedName !== imported.escapedName && !((_a = imported.declarations) == null ? void 0 : _a.every((d) => shouldExcludeFile(d.getSourceFile(), excludeLibFiles, singleCurrentFile)));
                default:
                    return true;
            }
        }
        function tryAddSingleDeclarationName(declaration, containers) {
            const name = getNameOfDeclaration(declaration);
            return !!name && (pushLiteral(name, containers) || name.kind === 167 /* ComputedPropertyName */ && tryAddComputedPropertyName(name.expression, containers));
        }
        function tryAddComputedPropertyName(expression, containers) {
            return pushLiteral(expression, containers) || isPropertyAccessExpression(expression) && (containers.push(expression.name.text), true) && tryAddComputedPropertyName(expression.expression, containers);
        }
        function pushLiteral(node, containers) {
            return isPropertyNameLiteral(node) && (containers.push(getTextOfIdentifierOrLiteral(node)), true);
        }
        function getContainers(declaration) {
            const containers = [];
            const name = getNameOfDeclaration(declaration);
            if (name && name.kind === 167 /* ComputedPropertyName */ && !tryAddComputedPropertyName(name.expression, containers)) {
                return emptyArray;
            }
            containers.shift();
            let container = getContainerNode(declaration);
            while (container) {
                if (!tryAddSingleDeclarationName(container, containers)) {
                    return emptyArray;
                }
                container = getContainerNode(container);
            }
            return containers.reverse();
        }
        function compareNavigateToItems(i1, i2) {
            return compareValues(i1.matchKind, i2.matchKind) || compareStringsCaseSensitiveUI(i1.name, i2.name);
        }
        function createNavigateToItem(rawItem) {
            const declaration = rawItem.declaration;
            const container = getContainerNode(declaration);
            const containerName = container && getNameOfDeclaration(container);
            return {
                name: rawItem.name,
                kind: getNodeKind(declaration),
                kindModifiers: getNodeModifiers(declaration),
                matchKind: PatternMatchKind[rawItem.matchKind],
                isCaseSensitive: rawItem.isCaseSensitive,
                fileName: rawItem.fileName,
                textSpan: createTextSpanFromNode(declaration),
                // TODO(jfreeman): What should be the containerName when the container has a computed name?
                containerName: containerName ? containerName.text : "",
                containerKind: containerName ? getNodeKind(container) : "" /* unknown */
            };
        }
        var init_navigateTo = __esm({
            "src/services/navigateTo.ts"() {
                "use strict";
                init_ts4();
            }
        });
        // src/services/_namespaces/ts.NavigateTo.ts
        var ts_NavigateTo_exports = {};
        __export(ts_NavigateTo_exports, {
            getNavigateToItems: () => getNavigateToItems
        });
        var init_ts_NavigateTo = __esm({
            "src/services/_namespaces/ts.NavigateTo.ts"() {
                "use strict";
                init_navigateTo();
            }
        });
        // src/services/navigationBar.ts
        function getNavigationBarItems(sourceFile, cancellationToken) {
            curCancellationToken = cancellationToken;
            curSourceFile = sourceFile;
            try {
                return map(primaryNavBarMenuItems(rootNavigationBarNode(sourceFile)), convertToPrimaryNavBarMenuItem);
            }
            finally {
                reset();
            }
        }
        function getNavigationTree(sourceFile, cancellationToken) {
            curCancellationToken = cancellationToken;
            curSourceFile = sourceFile;
            try {
                return convertToTree(rootNavigationBarNode(sourceFile));
            }
            finally {
                reset();
            }
        }
        function reset() {
            curSourceFile = void 0;
            curCancellationToken = void 0;
            parentsStack = [];
            parent = void 0;
            emptyChildItemArray = [];
        }
        function nodeText(node) {
            return cleanText(node.getText(curSourceFile));
        }
        function navigationBarNodeKind(n) {
            return n.node.kind;
        }
        function pushChild(parent2, child) {
            if (parent2.children) {
                parent2.children.push(child);
            }
            else {
                parent2.children = [child];
            }
        }
        function rootNavigationBarNode(sourceFile) {
            Debug.assert(!parentsStack.length);
            const root = { node: sourceFile, name: void 0, additionalNodes: void 0, parent: void 0, children: void 0, indent: 0 };
            parent = root;
            for (const statement of sourceFile.statements) {
                addChildrenRecursively(statement);
            }
            endNode();
            Debug.assert(!parent && !parentsStack.length);
            return root;
        }
        function addLeafNode(node, name) {
            pushChild(parent, emptyNavigationBarNode(node, name));
        }
        function emptyNavigationBarNode(node, name) {
            return {
                node,
                name: name || (isDeclaration(node) || isExpression(node) ? getNameOfDeclaration(node) : void 0),
                additionalNodes: void 0,
                parent,
                children: void 0,
                indent: parent.indent + 1
            };
        }
        function addTrackedEs5Class(name) {
            if (!trackedEs5Classes) {
                trackedEs5Classes = /* @__PURE__ */ new Map();
            }
            trackedEs5Classes.set(name, true);
        }
        function endNestedNodes(depth) {
            for (let i = 0; i < depth; i++)
                endNode();
        }
        function startNestedNodes(targetNode, entityName) {
            const names = [];
            while (!isPropertyNameLiteral(entityName)) {
                const name = getNameOrArgument(entityName);
                const nameText = getElementOrPropertyAccessName(entityName);
                entityName = entityName.expression;
                if (nameText === "prototype" || isPrivateIdentifier(name))
                    continue;
                names.push(name);
            }
            names.push(entityName);
            for (let i = names.length - 1; i > 0; i--) {
                const name = names[i];
                startNode(targetNode, name);
            }
            return [names.length - 1, names[0]];
        }
        function startNode(node, name) {
            const navNode = emptyNavigationBarNode(node, name);
            pushChild(parent, navNode);
            parentsStack.push(parent);
            trackedEs5ClassesStack.push(trackedEs5Classes);
            trackedEs5Classes = void 0;
            parent = navNode;
        }
        function endNode() {
            if (parent.children) {
                mergeChildren(parent.children, parent);
                sortChildren(parent.children);
            }
            parent = parentsStack.pop();
            trackedEs5Classes = trackedEs5ClassesStack.pop();
        }
        function addNodeWithRecursiveChild(node, child, name) {
            startNode(node, name);
            addChildrenRecursively(child);
            endNode();
        }
        function addNodeWithRecursiveInitializer(node) {
            if (node.initializer && isFunctionOrClassExpression(node.initializer)) {
                startNode(node);
                forEachChild(node.initializer, addChildrenRecursively);
                endNode();
            }
            else {
                addNodeWithRecursiveChild(node, node.initializer);
            }
        }
        function hasNavigationBarName(node) {
            const name = getNameOfDeclaration(node);
            if (name === void 0)
                return false;
            if (isComputedPropertyName(name)) {
                const expression = name.expression;
                return isEntityNameExpression(expression) || isNumericLiteral(expression) || isStringOrNumericLiteralLike(expression);
            }
            return !!name;
        }
        function addChildrenRecursively(node) {
            curCancellationToken.throwIfCancellationRequested();
            if (!node || isToken(node)) {
                return;
            }
            switch (node.kind) {
                case 176 /* Constructor */:
                    const ctr = node;
                    addNodeWithRecursiveChild(ctr, ctr.body);
                    for (const param of ctr.parameters) {
                        if (isParameterPropertyDeclaration(param, ctr)) {
                            addLeafNode(param);
                        }
                    }
                    break;
                case 174 /* MethodDeclaration */:
                case 177 /* GetAccessor */:
                case 178 /* SetAccessor */:
                case 173 /* MethodSignature */:
                    if (hasNavigationBarName(node)) {
                        addNodeWithRecursiveChild(node, node.body);
                    }
                    break;
                case 172 /* PropertyDeclaration */:
                    if (hasNavigationBarName(node)) {
                        addNodeWithRecursiveInitializer(node);
                    }
                    break;
                case 171 /* PropertySignature */:
                    if (hasNavigationBarName(node)) {
                        addLeafNode(node);
                    }
                    break;
                case 273 /* ImportClause */:
                    const importClause = node;
                    if (importClause.name) {
                        addLeafNode(importClause.name);
                    }
                    const { namedBindings } = importClause;
                    if (namedBindings) {
                        if (namedBindings.kind === 274 /* NamespaceImport */) {
                            addLeafNode(namedBindings);
                        }
                        else {
                            for (const element of namedBindings.elements) {
                                addLeafNode(element);
                            }
                        }
                    }
                    break;
                case 304 /* ShorthandPropertyAssignment */:
                    addNodeWithRecursiveChild(node, node.name);
                    break;
                case 305 /* SpreadAssignment */:
                    const { expression } = node;
                    isIdentifier(expression) ? addLeafNode(node, expression) : addLeafNode(node);
                    break;
                case 208 /* BindingElement */:
                case 303 /* PropertyAssignment */:
                case 260 /* VariableDeclaration */: {
                    const child = node;
                    if (isBindingPattern(child.name)) {
                        addChildrenRecursively(child.name);
                    }
                    else {
                        addNodeWithRecursiveInitializer(child);
                    }
                    break;
                }
                case 262 /* FunctionDeclaration */:
                    const nameNode = node.name;
                    if (nameNode && isIdentifier(nameNode)) {
                        addTrackedEs5Class(nameNode.text);
                    }
                    addNodeWithRecursiveChild(node, node.body);
                    break;
                case 219 /* ArrowFunction */:
                case 218 /* FunctionExpression */:
                    addNodeWithRecursiveChild(node, node.body);
                    break;
                case 266 /* EnumDeclaration */:
                    startNode(node);
                    for (const member of node.members) {
                        if (!isComputedProperty(member)) {
                            addLeafNode(member);
                        }
                    }
                    endNode();
                    break;
                case 263 /* ClassDeclaration */:
                case 231 /* ClassExpression */:
                case 264 /* InterfaceDeclaration */:
                    startNode(node);
                    for (const member of node.members) {
                        addChildrenRecursively(member);
                    }
                    endNode();
                    break;
                case 267 /* ModuleDeclaration */:
                    addNodeWithRecursiveChild(node, getInteriorModule(node).body);
                    break;
                case 277 /* ExportAssignment */: {
                    const expression2 = node.expression;
                    const child = isObjectLiteralExpression(expression2) || isCallExpression(expression2) ? expression2 : isArrowFunction(expression2) || isFunctionExpression(expression2) ? expression2.body : void 0;
                    if (child) {
                        startNode(node);
                        addChildrenRecursively(child);
                        endNode();
                    }
                    else {
                        addLeafNode(node);
                    }
                    break;
                }
                case 281 /* ExportSpecifier */:
                case 271 /* ImportEqualsDeclaration */:
                case 181 /* IndexSignature */:
                case 179 /* CallSignature */:
                case 180 /* ConstructSignature */:
                case 265 /* TypeAliasDeclaration */:
                    addLeafNode(node);
                    break;
                case 213 /* CallExpression */:
                case 226 /* BinaryExpression */: {
                    const special = getAssignmentDeclarationKind(node);
                    switch (special) {
                        case 1 /* ExportsProperty */:
                        case 2 /* ModuleExports */:
                            addNodeWithRecursiveChild(node, node.right);
                            return;
                        case 6 /* Prototype */:
                        case 3 /* PrototypeProperty */: {
                            const binaryExpression = node;
                            const assignmentTarget = binaryExpression.left;
                            const prototypeAccess = special === 3 /* PrototypeProperty */ ? assignmentTarget.expression : assignmentTarget;
                            let depth = 0;
                            let className;
                            if (isIdentifier(prototypeAccess.expression)) {
                                addTrackedEs5Class(prototypeAccess.expression.text);
                                className = prototypeAccess.expression;
                            }
                            else {
                                [depth, className] = startNestedNodes(binaryExpression, prototypeAccess.expression);
                            }
                            if (special === 6 /* Prototype */) {
                                if (isObjectLiteralExpression(binaryExpression.right)) {
                                    if (binaryExpression.right.properties.length > 0) {
                                        startNode(binaryExpression, className);
                                        forEachChild(binaryExpression.right, addChildrenRecursively);
                                        endNode();
                                    }
                                }
                            }
                            else if (isFunctionExpression(binaryExpression.right) || isArrowFunction(binaryExpression.right)) {
                                addNodeWithRecursiveChild(node, binaryExpression.right, className);
                            }
                            else {
                                startNode(binaryExpression, className);
                                addNodeWithRecursiveChild(node, binaryExpression.right, assignmentTarget.name);
                                endNode();
                            }
                            endNestedNodes(depth);
                            return;
                        }
                        case 7 /* ObjectDefinePropertyValue */:
                        case 9 /* ObjectDefinePrototypeProperty */: {
                            const defineCall = node;
                            const className = special === 7 /* ObjectDefinePropertyValue */ ? defineCall.arguments[0] : defineCall.arguments[0].expression;
                            const memberName = defineCall.arguments[1];
                            const [depth, classNameIdentifier] = startNestedNodes(node, className);
                            startNode(node, classNameIdentifier);
                            startNode(node, setTextRange(factory.createIdentifier(memberName.text), memberName));
                            addChildrenRecursively(node.arguments[2]);
                            endNode();
                            endNode();
                            endNestedNodes(depth);
                            return;
                        }
                        case 5 /* Property */: {
                            const binaryExpression = node;
                            const assignmentTarget = binaryExpression.left;
                            const targetFunction = assignmentTarget.expression;
                            if (isIdentifier(targetFunction) && getElementOrPropertyAccessName(assignmentTarget) !== "prototype" && trackedEs5Classes && trackedEs5Classes.has(targetFunction.text)) {
                                if (isFunctionExpression(binaryExpression.right) || isArrowFunction(binaryExpression.right)) {
                                    addNodeWithRecursiveChild(node, binaryExpression.right, targetFunction);
                                }
                                else if (isBindableStaticAccessExpression(assignmentTarget)) {
                                    startNode(binaryExpression, targetFunction);
                                    addNodeWithRecursiveChild(binaryExpression.left, binaryExpression.right, getNameOrArgument(assignmentTarget));
                                    endNode();
                                }
                                return;
                            }
                            break;
                        }
                        case 4 /* ThisProperty */:
                        case 0 /* None */:
                        case 8 /* ObjectDefinePropertyExports */:
                            break;
                        default:
                            Debug.assertNever(special);
                    }
                }
                default:
                    if (hasJSDocNodes(node)) {
                        forEach(node.jsDoc, (jsDoc) => {
                            forEach(jsDoc.tags, (tag) => {
                                if (isJSDocTypeAlias(tag)) {
                                    addLeafNode(tag);
                                }
                            });
                        });
                    }
                    forEachChild(node, addChildrenRecursively);
            }
        }
        function mergeChildren(children, node) {
            const nameToItems = /* @__PURE__ */ new Map();
            filterMutate(children, (child, index) => {
                const declName = child.name || getNameOfDeclaration(child.node);
                const name = declName && nodeText(declName);
                if (!name) {
                    return true;
                }
                const itemsWithSameName = nameToItems.get(name);
                if (!itemsWithSameName) {
                    nameToItems.set(name, child);
                    return true;
                }
                if (itemsWithSameName instanceof Array) {
                    for (const itemWithSameName of itemsWithSameName) {
                        if (tryMerge(itemWithSameName, child, index, node)) {
                            return false;
                        }
                    }
                    itemsWithSameName.push(child);
                    return true;
                }
                else {
                    const itemWithSameName = itemsWithSameName;
                    if (tryMerge(itemWithSameName, child, index, node)) {
                        return false;
                    }
                    nameToItems.set(name, [itemWithSameName, child]);
                    return true;
                }
            });
        }
        function tryMergeEs5Class(a, b, bIndex, parent2) {
            function isPossibleConstructor(node) {
                return isFunctionExpression(node) || isFunctionDeclaration(node) || isVariableDeclaration(node);
            }
            const bAssignmentDeclarationKind = isBinaryExpression(b.node) || isCallExpression(b.node) ? getAssignmentDeclarationKind(b.node) : 0 /* None */;
            const aAssignmentDeclarationKind = isBinaryExpression(a.node) || isCallExpression(a.node) ? getAssignmentDeclarationKind(a.node) : 0 /* None */;
            if (isEs5ClassMember[bAssignmentDeclarationKind] && isEs5ClassMember[aAssignmentDeclarationKind] || isPossibleConstructor(a.node) && isEs5ClassMember[bAssignmentDeclarationKind] || isPossibleConstructor(b.node) && isEs5ClassMember[aAssignmentDeclarationKind] || isClassDeclaration(a.node) && isSynthesized(a.node) && isEs5ClassMember[bAssignmentDeclarationKind] || isClassDeclaration(b.node) && isEs5ClassMember[aAssignmentDeclarationKind] || isClassDeclaration(a.node) && isSynthesized(a.node) && isPossibleConstructor(b.node) || isClassDeclaration(b.node) && isPossibleConstructor(a.node) && isSynthesized(a.node)) {
                let lastANode = a.additionalNodes && lastOrUndefined(a.additionalNodes) || a.node;
                if (!isClassDeclaration(a.node) && !isClassDeclaration(b.node) || isPossibleConstructor(a.node) || isPossibleConstructor(b.node)) {
                    const ctorFunction = isPossibleConstructor(a.node) ? a.node : isPossibleConstructor(b.node) ? b.node : void 0;
                    if (ctorFunction !== void 0) {
                        const ctorNode = setTextRange(factory.createConstructorDeclaration(
                        /*modifiers*/
                        void 0, [], 
                        /*body*/
                        void 0), ctorFunction);
                        const ctor = emptyNavigationBarNode(ctorNode);
                        ctor.indent = a.indent + 1;
                        ctor.children = a.node === ctorFunction ? a.children : b.children;
                        a.children = a.node === ctorFunction ? concatenate([ctor], b.children || [b]) : concatenate(a.children || [{ ...a }], [ctor]);
                    }
                    else {
                        if (a.children || b.children) {
                            a.children = concatenate(a.children || [{ ...a }], b.children || [b]);
                            if (a.children) {
                                mergeChildren(a.children, a);
                                sortChildren(a.children);
                            }
                        }
                    }
                    lastANode = a.node = setTextRange(factory.createClassDeclaration(
                    /*modifiers*/
                    void 0, a.name || factory.createIdentifier("__class__"), 
                    /*typeParameters*/
                    void 0, 
                    /*heritageClauses*/
                    void 0, []), a.node);
                }
                else {
                    a.children = concatenate(a.children, b.children);
                    if (a.children) {
                        mergeChildren(a.children, a);
                    }
                }
                const bNode = b.node;
                if (parent2.children[bIndex - 1].node.end === lastANode.end) {
                    setTextRange(lastANode, { pos: lastANode.pos, end: bNode.end });
                }
                else {
                    if (!a.additionalNodes)
                        a.additionalNodes = [];
                    a.additionalNodes.push(setTextRange(factory.createClassDeclaration(
                    /*modifiers*/
                    void 0, a.name || factory.createIdentifier("__class__"), 
                    /*typeParameters*/
                    void 0, 
                    /*heritageClauses*/
                    void 0, []), b.node));
                }
                return true;
            }
            return bAssignmentDeclarationKind === 0 /* None */ ? false : true;
        }
        function tryMerge(a, b, bIndex, parent2) {
            if (tryMergeEs5Class(a, b, bIndex, parent2)) {
                return true;
            }
            if (shouldReallyMerge(a.node, b.node, parent2)) {
                merge(a, b);
                return true;
            }
            return false;
        }
        function shouldReallyMerge(a, b, parent2) {
            if (a.kind !== b.kind || a.parent !== b.parent && !(isOwnChild(a, parent2) && isOwnChild(b, parent2))) {
                return false;
            }
            switch (a.kind) {
                case 172 /* PropertyDeclaration */:
                case 174 /* MethodDeclaration */:
                case 177 /* GetAccessor */:
                case 178 /* SetAccessor */:
                    return isStatic(a) === isStatic(b);
                case 267 /* ModuleDeclaration */:
                    return areSameModule(a, b) && getFullyQualifiedModuleName(a) === getFullyQualifiedModuleName(b);
                default:
                    return true;
            }
        }
        function isSynthesized(node) {
            return !!(node.flags & 16 /* Synthesized */);
        }
        function isOwnChild(n, parent2) {
            const par = isModuleBlock(n.parent) ? n.parent.parent : n.parent;
            return par === parent2.node || contains(parent2.additionalNodes, par);
        }
        function areSameModule(a, b) {
            if (!a.body || !b.body) {
                return a.body === b.body;
            }
            return a.body.kind === b.body.kind && (a.body.kind !== 267 /* ModuleDeclaration */ || areSameModule(a.body, b.body));
        }
        function merge(target, source) {
            target.additionalNodes = target.additionalNodes || [];
            target.additionalNodes.push(source.node);
            if (source.additionalNodes) {
                target.additionalNodes.push(...source.additionalNodes);
            }
            target.children = concatenate(target.children, source.children);
            if (target.children) {
                mergeChildren(target.children, target);
                sortChildren(target.children);
            }
        }
        function sortChildren(children) {
            children.sort(compareChildren);
        }
        function compareChildren(child1, child2) {
            return compareStringsCaseSensitiveUI(tryGetName(child1.node), tryGetName(child2.node)) || compareValues(navigationBarNodeKind(child1), navigationBarNodeKind(child2));
        }
        function tryGetName(node) {
            if (node.kind === 267 /* ModuleDeclaration */) {
                return getModuleName(node);
            }
            const declName = getNameOfDeclaration(node);
            if (declName && isPropertyName(declName)) {
                const propertyName = getPropertyNameForPropertyNameNode(declName);
                return propertyName && unescapeLeadingUnderscores(propertyName);
            }
            switch (node.kind) {
                case 218 /* FunctionExpression */:
                case 219 /* ArrowFunction */:
                case 231 /* ClassExpression */:
                    return getFunctionOrClassName(node);
                default:
                    return void 0;
            }
        }
        function getItemName(node, name) {
            if (node.kind === 267 /* ModuleDeclaration */) {
                return cleanText(getModuleName(node));
            }
            if (name) {
                const text = isIdentifier(name) ? name.text : isElementAccessExpression(name) ? `[${nodeText(name.argumentExpression)}]` : nodeText(name);
                if (text.length > 0) {
                    return cleanText(text);
                }
            }
            switch (node.kind) {
                case 312 /* SourceFile */:
                    const sourceFile = node;
                    return isExternalModule(sourceFile) ? `"${escapeString(getBaseFileName(removeFileExtension(normalizePath(sourceFile.fileName))))}"` : "<global>";
                case 277 /* ExportAssignment */:
                    return isExportAssignment(node) && node.isExportEquals ? "export=" /* ExportEquals */ : "default" /* Default */;
                case 219 /* ArrowFunction */:
                case 262 /* FunctionDeclaration */:
                case 218 /* FunctionExpression */:
                case 263 /* ClassDeclaration */:
                case 231 /* ClassExpression */:
                    if (getSyntacticModifierFlags(node) & 2048 /* Default */) {
                        return "default";
                    }
                    return getFunctionOrClassName(node);
                case 176 /* Constructor */:
                    return "constructor";
                case 180 /* ConstructSignature */:
                    return "new()";
                case 179 /* CallSignature */:
                    return "()";
                case 181 /* IndexSignature */:
                    return "[]";
                default:
                    return "<unknown>";
            }
        }
        function primaryNavBarMenuItems(root) {
            const primaryNavBarMenuItems2 = [];
            function recur(item) {
                if (shouldAppearInPrimaryNavBarMenu(item)) {
                    primaryNavBarMenuItems2.push(item);
                    if (item.children) {
                        for (const child of item.children) {
                            recur(child);
                        }
                    }
                }
            }
            recur(root);
            return primaryNavBarMenuItems2;
            function shouldAppearInPrimaryNavBarMenu(item) {
                if (item.children) {
                    return true;
                }
                switch (navigationBarNodeKind(item)) {
                    case 263 /* ClassDeclaration */:
                    case 231 /* ClassExpression */:
                    case 266 /* EnumDeclaration */:
                    case 264 /* InterfaceDeclaration */:
                    case 267 /* ModuleDeclaration */:
                    case 312 /* SourceFile */:
                    case 265 /* TypeAliasDeclaration */:
                    case 353 /* JSDocTypedefTag */:
                    case 345 /* JSDocCallbackTag */:
                        return true;
                    case 219 /* ArrowFunction */:
                    case 262 /* FunctionDeclaration */:
                    case 218 /* FunctionExpression */:
                        return isTopLevelFunctionDeclaration(item);
                    default:
                        return false;
                }
                function isTopLevelFunctionDeclaration(item2) {
                    if (!item2.node.body) {
                        return false;
                    }
                    switch (navigationBarNodeKind(item2.parent)) {
                        case 268 /* ModuleBlock */:
                        case 312 /* SourceFile */:
                        case 174 /* MethodDeclaration */:
                        case 176 /* Constructor */:
                            return true;
                        default:
                            return false;
                    }
                }
            }
        }
        function convertToTree(n) {
            return {
                text: getItemName(n.node, n.name),
                kind: getNodeKind(n.node),
                kindModifiers: getModifiers2(n.node),
                spans: getSpans(n),
                nameSpan: n.name && getNodeSpan(n.name),
                childItems: map(n.children, convertToTree)
            };
        }
        function convertToPrimaryNavBarMenuItem(n) {
            return {
                text: getItemName(n.node, n.name),
                kind: getNodeKind(n.node),
                kindModifiers: getModifiers2(n.node),
                spans: getSpans(n),
                childItems: map(n.children, convertToSecondaryNavBarMenuItem) || emptyChildItemArray,
                indent: n.indent,
                bolded: false,
                grayed: false
            };
            function convertToSecondaryNavBarMenuItem(n2) {
                return {
                    text: getItemName(n2.node, n2.name),
                    kind: getNodeKind(n2.node),
                    kindModifiers: getNodeModifiers(n2.node),
                    spans: getSpans(n2),
                    childItems: emptyChildItemArray,
                    indent: 0,
                    bolded: false,
                    grayed: false
                };
            }
        }
        function getSpans(n) {
            const spans = [getNodeSpan(n.node)];
            if (n.additionalNodes) {
                for (const node of n.additionalNodes) {
                    spans.push(getNodeSpan(node));
                }
            }
            return spans;
        }
        function getModuleName(moduleDeclaration) {
            if (isAmbientModule(moduleDeclaration)) {
                return getTextOfNode(moduleDeclaration.name);
            }
            return getFullyQualifiedModuleName(moduleDeclaration);
        }
        function getFullyQualifiedModuleName(moduleDeclaration) {
            const result = [getTextOfIdentifierOrLiteral(moduleDeclaration.name)];
            while (moduleDeclaration.body && moduleDeclaration.body.kind === 267 /* ModuleDeclaration */) {
                moduleDeclaration = moduleDeclaration.body;
                result.push(getTextOfIdentifierOrLiteral(moduleDeclaration.name));
            }
            return result.join(".");
        }
        function getInteriorModule(decl) {
            return decl.body && isModuleDeclaration(decl.body) ? getInteriorModule(decl.body) : decl;
        }
        function isComputedProperty(member) {
            return !member.name || member.name.kind === 167 /* ComputedPropertyName */;
        }
        function getNodeSpan(node) {
            return node.kind === 312 /* SourceFile */ ? createTextSpanFromRange(node) : createTextSpanFromNode(node, curSourceFile);
        }
        function getModifiers2(node) {
            if (node.parent && node.parent.kind === 260 /* VariableDeclaration */) {
                node = node.parent;
            }
            return getNodeModifiers(node);
        }
        function getFunctionOrClassName(node) {
            const { parent: parent2 } = node;
            if (node.name && getFullWidth(node.name) > 0) {
                return cleanText(declarationNameToString(node.name));
            }
            else if (isVariableDeclaration(parent2)) {
                return cleanText(declarationNameToString(parent2.name));
            }
            else if (isBinaryExpression(parent2) && parent2.operatorToken.kind === 64 /* EqualsToken */) {
                return nodeText(parent2.left).replace(whiteSpaceRegex, "");
            }
            else if (isPropertyAssignment(parent2)) {
                return nodeText(parent2.name);
            }
            else if (getSyntacticModifierFlags(node) & 2048 /* Default */) {
                return "default";
            }
            else if (isClassLike(node)) {
                return "<class>";
            }
            else if (isCallExpression(parent2)) {
                let name = getCalledExpressionName(parent2.expression);
                if (name !== void 0) {
                    name = cleanText(name);
                    if (name.length > maxLength) {
                        return `${name} callback`;
                    }
                    const args = cleanText(mapDefined(parent2.arguments, (a) => isStringLiteralLike(a) || isTemplateLiteral(a) ? a.getText(curSourceFile) : void 0).join(", "));
                    return `${name}(${args}) callback`;
                }
            }
            return "<function>";
        }
        function getCalledExpressionName(expr) {
            if (isIdentifier(expr)) {
                return expr.text;
            }
            else if (isPropertyAccessExpression(expr)) {
                const left = getCalledExpressionName(expr.expression);
                const right = expr.name.text;
                return left === void 0 ? right : `${left}.${right}`;
            }
            else {
                return void 0;
            }
        }
        function isFunctionOrClassExpression(node) {
            switch (node.kind) {
                case 219 /* ArrowFunction */:
                case 218 /* FunctionExpression */:
                case 231 /* ClassExpression */:
                    return true;
                default:
                    return false;
            }
        }
        function cleanText(text) {
            text = text.length > maxLength ? text.substring(0, maxLength) + "..." : text;
            return text.replace(/\\?(\r?\n|\r|\u2028|\u2029)/g, "");
        }
        var whiteSpaceRegex, maxLength, curCancellationToken, curSourceFile, parentsStack, parent, trackedEs5ClassesStack, trackedEs5Classes, emptyChildItemArray, isEs5ClassMember;
        var init_navigationBar = __esm({
            "src/services/navigationBar.ts"() {
                "use strict";
                init_ts4();
                whiteSpaceRegex = /\s+/g;
                maxLength = 150;
                parentsStack = [];
                trackedEs5ClassesStack = [];
                emptyChildItemArray = [];
                isEs5ClassMember = {
                    [5 /* Property */]: true,
                    [3 /* PrototypeProperty */]: true,
                    [7 /* ObjectDefinePropertyValue */]: true,
                    [9 /* ObjectDefinePrototypeProperty */]: true,
                    [0 /* None */]: false,
                    [1 /* ExportsProperty */]: false,
                    [2 /* ModuleExports */]: false,
                    [8 /* ObjectDefinePropertyExports */]: false,
                    [6 /* Prototype */]: true,
                    [4 /* ThisProperty */]: false
                };
            }
        });
        // src/services/_namespaces/ts.NavigationBar.ts
        var ts_NavigationBar_exports = {};
        __export(ts_NavigationBar_exports, {
            getNavigationBarItems: () => getNavigationBarItems,
            getNavigationTree: () => getNavigationTree
        });
        var init_ts_NavigationBar = __esm({
            "src/services/_namespaces/ts.NavigationBar.ts"() {
                "use strict";
                init_navigationBar();
            }
        });
        // src/services/refactorProvider.ts
        function registerRefactor(name, refactor) {
            refactors.set(name, refactor);
        }
        function getApplicableRefactors(context, includeInteractiveActions) {
            return arrayFrom(flatMapIterator(refactors.values(), (refactor) => {
                var _a;
                return context.cancellationToken && context.cancellationToken.isCancellationRequested() || !((_a = refactor.kinds) == null ? void 0 : _a.some((kind) => refactorKindBeginsWith(kind, context.kind))) ? void 0 : refactor.getAvailableActions(context, includeInteractiveActions);
            }));
        }
        function getEditsForRefactor(context, refactorName14, actionName2, interactiveRefactorArguments) {
            const refactor = refactors.get(refactorName14);
            return refactor && refactor.getEditsForAction(context, actionName2, interactiveRefactorArguments);
        }
        var refactors;
        var init_refactorProvider = __esm({
            "src/services/refactorProvider.ts"() {
                "use strict";
                init_ts4();
                init_ts_refactor();
                refactors = /* @__PURE__ */ new Map();
            }
        });
        // src/services/refactors/convertExport.ts
        function getInfo2(context, considerPartialSpans = true) {
            const { file, program } = context;
            const span = getRefactorContextSpan(context);
            const token = getTokenAtPosition(file, span.start);
            const exportNode = !!(token.parent && getSyntacticModifierFlags(token.parent) & 32 /* Export */) && considerPartialSpans ? token.parent : getParentNodeInSpan(token, file, span);
            if (!exportNode || !isSourceFile(exportNode.parent) && !(isModuleBlock(exportNode.parent) && isAmbientModule(exportNode.parent.parent))) {
                return { error: getLocaleSpecificMessage(Diagnostics.Could_not_find_export_statement) };
            }
            const checker = program.getTypeChecker();
            const exportingModuleSymbol = getExportingModuleSymbol(exportNode.parent, checker);
            const flags = getSyntacticModifierFlags(exportNode) || (isExportAssignment(exportNode) && !exportNode.isExportEquals ? 2080 /* ExportDefault */ : 0 /* None */);
            const wasDefault = !!(flags & 2048 /* Default */);
            if (!(flags & 32 /* Export */) || !wasDefault && exportingModuleSymbol.exports.has("default" /* Default */)) {
                return { error: getLocaleSpecificMessage(Diagnostics.This_file_already_has_a_default_export) };
            }
            const noSymbolError = (id) => isIdentifier(id) && checker.getSymbolAtLocation(id) ? void 0 : { error: getLocaleSpecificMessage(Diagnostics.Can_only_convert_named_export) };
            switch (exportNode.kind) {
                case 262 /* FunctionDeclaration */:
                case 263 /* ClassDeclaration */:
                case 264 /* InterfaceDeclaration */:
                case 266 /* EnumDeclaration */:
                case 265 /* TypeAliasDeclaration */:
                case 267 /* ModuleDeclaration */: {
                    const node = exportNode;
                    if (!node.name)
                        return void 0;
                    return noSymbolError(node.name) || { exportNode: node, exportName: node.name, wasDefault, exportingModuleSymbol };
                }
                case 243 /* VariableStatement */: {
                    const vs = exportNode;
                    if (!(vs.declarationList.flags & 2 /* Const */) || vs.declarationList.declarations.length !== 1) {
                        return void 0;
                    }
                    const decl = first(vs.declarationList.declarations);
                    if (!decl.initializer)
                        return void 0;
                    Debug.assert(!wasDefault, "Can't have a default flag here");
                    return noSymbolError(decl.name) || { exportNode: vs, exportName: decl.name, wasDefault, exportingModuleSymbol };
                }
                case 277 /* ExportAssignment */: {
                    const node = exportNode;
                    if (node.isExportEquals)
                        return void 0;
                    return noSymbolError(node.expression) || { exportNode: node, exportName: node.expression, wasDefault, exportingModuleSymbol };
                }
                default:
                    return void 0;
            }
        }
        function doChange(exportingSourceFile, program, info, changes, cancellationToken) {
            changeExport(exportingSourceFile, info, changes, program.getTypeChecker());
            changeImports(program, info, changes, cancellationToken);
        }
        function changeExport(exportingSourceFile, { wasDefault, exportNode, exportName }, changes, checker) {
            if (wasDefault) {
                if (isExportAssignment(exportNode) && !exportNode.isExportEquals) {
                    const exp = exportNode.expression;
                    const spec = makeExportSpecifier(exp.text, exp.text);
                    changes.replaceNode(exportingSourceFile, exportNode, factory.createExportDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*isTypeOnly*/
                    false, factory.createNamedExports([spec])));
                }
                else {
                    changes.delete(exportingSourceFile, Debug.checkDefined(findModifier(exportNode, 90 /* DefaultKeyword */), "Should find a default keyword in modifier list"));
                }
            }
            else {
                const exportKeyword = Debug.checkDefined(findModifier(exportNode, 95 /* ExportKeyword */), "Should find an export keyword in modifier list");
                switch (exportNode.kind) {
                    case 262 /* FunctionDeclaration */:
                    case 263 /* ClassDeclaration */:
                    case 264 /* InterfaceDeclaration */:
                        changes.insertNodeAfter(exportingSourceFile, exportKeyword, factory.createToken(90 /* DefaultKeyword */));
                        break;
                    case 243 /* VariableStatement */:
                        const decl = first(exportNode.declarationList.declarations);
                        if (!ts_FindAllReferences_exports.Core.isSymbolReferencedInFile(exportName, checker, exportingSourceFile) && !decl.type) {
                            changes.replaceNode(exportingSourceFile, exportNode, factory.createExportDefault(Debug.checkDefined(decl.initializer, "Initializer was previously known to be present")));
                            break;
                        }
                    case 266 /* EnumDeclaration */:
                    case 265 /* TypeAliasDeclaration */:
                    case 267 /* ModuleDeclaration */:
                        changes.deleteModifier(exportingSourceFile, exportKeyword);
                        changes.insertNodeAfter(exportingSourceFile, exportNode, factory.createExportDefault(factory.createIdentifier(exportName.text)));
                        break;
                    default:
                        Debug.fail(`Unexpected exportNode kind ${exportNode.kind}`);
                }
            }
        }
        function changeImports(program, { wasDefault, exportName, exportingModuleSymbol }, changes, cancellationToken) {
            const checker = program.getTypeChecker();
            const exportSymbol = Debug.checkDefined(checker.getSymbolAtLocation(exportName), "Export name should resolve to a symbol");
            ts_FindAllReferences_exports.Core.eachExportReference(program.getSourceFiles(), checker, cancellationToken, exportSymbol, exportingModuleSymbol, exportName.text, wasDefault, (ref) => {
                if (exportName === ref)
                    return;
                const importingSourceFile = ref.getSourceFile();
                if (wasDefault) {
                    changeDefaultToNamedImport(importingSourceFile, ref, changes, exportName.text);
                }
                else {
                    changeNamedToDefaultImport(importingSourceFile, ref, changes);
                }
            });
        }
        function changeDefaultToNamedImport(importingSourceFile, ref, changes, exportName) {
            const { parent: parent2 } = ref;
            switch (parent2.kind) {
                case 211 /* PropertyAccessExpression */:
                    changes.replaceNode(importingSourceFile, ref, factory.createIdentifier(exportName));
                    break;
                case 276 /* ImportSpecifier */:
                case 281 /* ExportSpecifier */: {
                    const spec = parent2;
                    changes.replaceNode(importingSourceFile, spec, makeImportSpecifier(exportName, spec.name.text));
                    break;
                }
                case 273 /* ImportClause */: {
                    const clause = parent2;
                    Debug.assert(clause.name === ref, "Import clause name should match provided ref");
                    const spec = makeImportSpecifier(exportName, ref.text);
                    const { namedBindings } = clause;
                    if (!namedBindings) {
                        changes.replaceNode(importingSourceFile, ref, factory.createNamedImports([spec]));
                    }
                    else if (namedBindings.kind === 274 /* NamespaceImport */) {
                        changes.deleteRange(importingSourceFile, { pos: ref.getStart(importingSourceFile), end: namedBindings.getStart(importingSourceFile) });
                        const quotePreference = isStringLiteral(clause.parent.moduleSpecifier) ? quotePreferenceFromString(clause.parent.moduleSpecifier, importingSourceFile) : 1 /* Double */;
                        const newImport = makeImport(
                        /*defaultImport*/
                        void 0, [makeImportSpecifier(exportName, ref.text)], clause.parent.moduleSpecifier, quotePreference);
                        changes.insertNodeAfter(importingSourceFile, clause.parent, newImport);
                    }
                    else {
                        changes.delete(importingSourceFile, ref);
                        changes.insertNodeAtEndOfList(importingSourceFile, namedBindings.elements, spec);
                    }
                    break;
                }
                case 205 /* ImportType */:
                    const importTypeNode = parent2;
                    changes.replaceNode(importingSourceFile, parent2, factory.createImportTypeNode(importTypeNode.argument, importTypeNode.attributes, factory.createIdentifier(exportName), importTypeNode.typeArguments, importTypeNode.isTypeOf));
                    break;
                default:
                    Debug.failBadSyntaxKind(parent2);
            }
        }
        function changeNamedToDefaultImport(importingSourceFile, ref, changes) {
            const parent2 = ref.parent;
            switch (parent2.kind) {
                case 211 /* PropertyAccessExpression */:
                    changes.replaceNode(importingSourceFile, ref, factory.createIdentifier("default"));
                    break;
                case 276 /* ImportSpecifier */: {
                    const defaultImport = factory.createIdentifier(parent2.name.text);
                    if (parent2.parent.elements.length === 1) {
                        changes.replaceNode(importingSourceFile, parent2.parent, defaultImport);
                    }
                    else {
                        changes.delete(importingSourceFile, parent2);
                        changes.insertNodeBefore(importingSourceFile, parent2.parent, defaultImport);
                    }
                    break;
                }
                case 281 /* ExportSpecifier */: {
                    changes.replaceNode(importingSourceFile, parent2, makeExportSpecifier("default", parent2.name.text));
                    break;
                }
                default:
                    Debug.assertNever(parent2, `Unexpected parent kind ${parent2.kind}`);
            }
        }
        function makeImportSpecifier(propertyName, name) {
            return factory.createImportSpecifier(
            /*isTypeOnly*/
            false, propertyName === name ? void 0 : factory.createIdentifier(propertyName), factory.createIdentifier(name));
        }
        function makeExportSpecifier(propertyName, name) {
            return factory.createExportSpecifier(
            /*isTypeOnly*/
            false, propertyName === name ? void 0 : factory.createIdentifier(propertyName), factory.createIdentifier(name));
        }
        function getExportingModuleSymbol(parent2, checker) {
            if (isSourceFile(parent2)) {
                return parent2.symbol;
            }
            const symbol = parent2.parent.symbol;
            if (symbol.valueDeclaration && isExternalModuleAugmentation(symbol.valueDeclaration)) {
                return checker.getMergedSymbol(symbol);
            }
            return symbol;
        }
        var refactorName, defaultToNamedAction, namedToDefaultAction;
        var init_convertExport = __esm({
            "src/services/refactors/convertExport.ts"() {
                "use strict";
                init_ts4();
                init_ts_refactor();
                refactorName = "Convert export";
                defaultToNamedAction = {
                    name: "Convert default export to named export",
                    description: getLocaleSpecificMessage(Diagnostics.Convert_default_export_to_named_export),
                    kind: "refactor.rewrite.export.named"
                };
                namedToDefaultAction = {
                    name: "Convert named export to default export",
                    description: getLocaleSpecificMessage(Diagnostics.Convert_named_export_to_default_export),
                    kind: "refactor.rewrite.export.default"
                };
                registerRefactor(refactorName, {
                    kinds: [
                        defaultToNamedAction.kind,
                        namedToDefaultAction.kind
                    ],
                    getAvailableActions: function getRefactorActionsToConvertBetweenNamedAndDefaultExports(context) {
                        const info = getInfo2(context, context.triggerReason === "invoked");
                        if (!info)
                            return emptyArray;
                        if (!isRefactorErrorInfo(info)) {
                            const action = info.wasDefault ? defaultToNamedAction : namedToDefaultAction;
                            return [{ name: refactorName, description: action.description, actions: [action] }];
                        }
                        if (context.preferences.provideRefactorNotApplicableReason) {
                            return [
                                {
                                    name: refactorName,
                                    description: getLocaleSpecificMessage(Diagnostics.Convert_default_export_to_named_export),
                                    actions: [
                                        { ...defaultToNamedAction, notApplicableReason: info.error },
                                        { ...namedToDefaultAction, notApplicableReason: info.error }
                                    ]
                                }
                            ];
                        }
                        return emptyArray;
                    },
                    getEditsForAction: function getRefactorEditsToConvertBetweenNamedAndDefaultExports(context, actionName2) {
                        Debug.assert(actionName2 === defaultToNamedAction.name || actionName2 === namedToDefaultAction.name, "Unexpected action name");
                        const info = getInfo2(context);
                        Debug.assert(info && !isRefactorErrorInfo(info), "Expected applicable refactor info");
                        const edits = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange(context.file, context.program, info, t, context.cancellationToken));
                        return { edits, renameFilename: void 0, renameLocation: void 0 };
                    }
                });
            }
        });
        // src/services/refactors/convertImport.ts
        function getImportConversionInfo(context, considerPartialSpans = true) {
            const { file } = context;
            const span = getRefactorContextSpan(context);
            const token = getTokenAtPosition(file, span.start);
            const importDecl = considerPartialSpans ? findAncestor(token, isImportDeclaration) : getParentNodeInSpan(token, file, span);
            if (!importDecl || !isImportDeclaration(importDecl))
                return { error: "Selection is not an import declaration." };
            const end = span.start + span.length;
            const nextToken = findNextToken(importDecl, importDecl.parent, file);
            if (nextToken && end > nextToken.getStart())
                return void 0;
            const { importClause } = importDecl;
            if (!importClause) {
                return { error: getLocaleSpecificMessage(Diagnostics.Could_not_find_import_clause) };
            }
            if (!importClause.namedBindings) {
                return { error: getLocaleSpecificMessage(Diagnostics.Could_not_find_namespace_import_or_named_imports) };
            }
            if (importClause.namedBindings.kind === 274 /* NamespaceImport */) {
                return { convertTo: 0 /* Named */, import: importClause.namedBindings };
            }
            const shouldUseDefault = getShouldUseDefault(context.program, importClause);
            return shouldUseDefault ? { convertTo: 1 /* Default */, import: importClause.namedBindings } : { convertTo: 2 /* Namespace */, import: importClause.namedBindings };
        }
        function getShouldUseDefault(program, importClause) {
            return getAllowSyntheticDefaultImports(program.getCompilerOptions()) && isExportEqualsModule(importClause.parent.moduleSpecifier, program.getTypeChecker());
        }
        function doChange2(sourceFile, program, changes, info) {
            const checker = program.getTypeChecker();
            if (info.convertTo === 0 /* Named */) {
                doChangeNamespaceToNamed(sourceFile, checker, changes, info.import, getAllowSyntheticDefaultImports(program.getCompilerOptions()));
            }
            else {
                doChangeNamedToNamespaceOrDefault(sourceFile, program, changes, info.import, info.convertTo === 1 /* Default */);
            }
        }
        function doChangeNamespaceToNamed(sourceFile, checker, changes, toConvert, allowSyntheticDefaultImports) {
            let usedAsNamespaceOrDefault = false;
            const nodesToReplace = [];
            const conflictingNames = /* @__PURE__ */ new Map();
            ts_FindAllReferences_exports.Core.eachSymbolReferenceInFile(toConvert.name, checker, sourceFile, (id) => {
                if (!isPropertyAccessOrQualifiedName(id.parent)) {
                    usedAsNamespaceOrDefault = true;
                }
                else {
                    const exportName = getRightOfPropertyAccessOrQualifiedName(id.parent).text;
                    if (checker.resolveName(exportName, id, -1 /* All */, 
                    /*excludeGlobals*/
                    true)) {
                        conflictingNames.set(exportName, true);
                    }
                    Debug.assert(getLeftOfPropertyAccessOrQualifiedName(id.parent) === id, "Parent expression should match id");
                    nodesToReplace.push(id.parent);
                }
            });
            const exportNameToImportName = /* @__PURE__ */ new Map();
            for (const propertyAccessOrQualifiedName of nodesToReplace) {
                const exportName = getRightOfPropertyAccessOrQualifiedName(propertyAccessOrQualifiedName).text;
                let importName = exportNameToImportName.get(exportName);
                if (importName === void 0) {
                    exportNameToImportName.set(exportName, importName = conflictingNames.has(exportName) ? getUniqueName(exportName, sourceFile) : exportName);
                }
                changes.replaceNode(sourceFile, propertyAccessOrQualifiedName, factory.createIdentifier(importName));
            }
            const importSpecifiers = [];
            exportNameToImportName.forEach((name, propertyName) => {
                importSpecifiers.push(factory.createImportSpecifier(
                /*isTypeOnly*/
                false, name === propertyName ? void 0 : factory.createIdentifier(propertyName), factory.createIdentifier(name)));
            });
            const importDecl = toConvert.parent.parent;
            if (usedAsNamespaceOrDefault && !allowSyntheticDefaultImports) {
                changes.insertNodeAfter(sourceFile, importDecl, updateImport(importDecl, 
                /*defaultImportName*/
                void 0, importSpecifiers));
            }
            else {
                changes.replaceNode(sourceFile, importDecl, updateImport(importDecl, usedAsNamespaceOrDefault ? factory.createIdentifier(toConvert.name.text) : void 0, importSpecifiers));
            }
        }
        function getRightOfPropertyAccessOrQualifiedName(propertyAccessOrQualifiedName) {
            return isPropertyAccessExpression(propertyAccessOrQualifiedName) ? propertyAccessOrQualifiedName.name : propertyAccessOrQualifiedName.right;
        }
        function getLeftOfPropertyAccessOrQualifiedName(propertyAccessOrQualifiedName) {
            return isPropertyAccessExpression(propertyAccessOrQualifiedName) ? propertyAccessOrQualifiedName.expression : propertyAccessOrQualifiedName.left;
        }
        function doChangeNamedToNamespaceOrDefault(sourceFile, program, changes, toConvert, shouldUseDefault = getShouldUseDefault(program, toConvert.parent)) {
            const checker = program.getTypeChecker();
            const importDecl = toConvert.parent.parent;
            const { moduleSpecifier } = importDecl;
            const toConvertSymbols = /* @__PURE__ */ new Set();
            toConvert.elements.forEach((namedImport) => {
                const symbol = checker.getSymbolAtLocation(namedImport.name);
                if (symbol) {
                    toConvertSymbols.add(symbol);
                }
            });
            const preferredName = moduleSpecifier && isStringLiteral(moduleSpecifier) ? ts_codefix_exports.moduleSpecifierToValidIdentifier(moduleSpecifier.text, 99 /* ESNext */) : "module";
            function hasNamespaceNameConflict(namedImport) {
                return !!ts_FindAllReferences_exports.Core.eachSymbolReferenceInFile(namedImport.name, checker, sourceFile, (id) => {
                    const symbol = checker.resolveName(preferredName, id, -1 /* All */, 
                    /*excludeGlobals*/
                    true);
                    if (symbol) {
                        if (toConvertSymbols.has(symbol)) {
                            return isExportSpecifier(id.parent);
                        }
                        return true;
                    }
                    return false;
                });
            }
            const namespaceNameConflicts = toConvert.elements.some(hasNamespaceNameConflict);
            const namespaceImportName = namespaceNameConflicts ? getUniqueName(preferredName, sourceFile) : preferredName;
            const neededNamedImports = /* @__PURE__ */ new Set();
            for (const element of toConvert.elements) {
                const propertyName = (element.propertyName || element.name).text;
                ts_FindAllReferences_exports.Core.eachSymbolReferenceInFile(element.name, checker, sourceFile, (id) => {
                    const access = factory.createPropertyAccessExpression(factory.createIdentifier(namespaceImportName), propertyName);
                    if (isShorthandPropertyAssignment(id.parent)) {
                        changes.replaceNode(sourceFile, id.parent, factory.createPropertyAssignment(id.text, access));
                    }
                    else if (isExportSpecifier(id.parent)) {
                        neededNamedImports.add(element);
                    }
                    else {
                        changes.replaceNode(sourceFile, id, access);
                    }
                });
            }
            changes.replaceNode(sourceFile, toConvert, shouldUseDefault ? factory.createIdentifier(namespaceImportName) : factory.createNamespaceImport(factory.createIdentifier(namespaceImportName)));
            if (neededNamedImports.size) {
                const newNamedImports = arrayFrom(neededNamedImports.values(), (element) => factory.createImportSpecifier(element.isTypeOnly, element.propertyName && factory.createIdentifier(element.propertyName.text), factory.createIdentifier(element.name.text)));
                changes.insertNodeAfter(sourceFile, toConvert.parent.parent, updateImport(importDecl, 
                /*defaultImportName*/
                void 0, newNamedImports));
            }
        }
        function isExportEqualsModule(moduleSpecifier, checker) {
            const externalModule = checker.resolveExternalModuleName(moduleSpecifier);
            if (!externalModule)
                return false;
            const exportEquals = checker.resolveExternalModuleSymbol(externalModule);
            return externalModule !== exportEquals;
        }
        function updateImport(old, defaultImportName, elements) {
            return factory.createImportDeclaration(
            /*modifiers*/
            void 0, factory.createImportClause(
            /*isTypeOnly*/
            false, defaultImportName, elements && elements.length ? factory.createNamedImports(elements) : void 0), old.moduleSpecifier, 
            /*attributes*/
            void 0);
        }
        var refactorName2, actions;
        var init_convertImport = __esm({
            "src/services/refactors/convertImport.ts"() {
                "use strict";
                init_ts4();
                init_ts_refactor();
                refactorName2 = "Convert import";
                actions = {
                    [0 /* Named */]: {
                        name: "Convert namespace import to named imports",
                        description: getLocaleSpecificMessage(Diagnostics.Convert_namespace_import_to_named_imports),
                        kind: "refactor.rewrite.import.named"
                    },
                    [2 /* Namespace */]: {
                        name: "Convert named imports to namespace import",
                        description: getLocaleSpecificMessage(Diagnostics.Convert_named_imports_to_namespace_import),
                        kind: "refactor.rewrite.import.namespace"
                    },
                    [1 /* Default */]: {
                        name: "Convert named imports to default import",
                        description: getLocaleSpecificMessage(Diagnostics.Convert_named_imports_to_default_import),
                        kind: "refactor.rewrite.import.default"
                    }
                };
                registerRefactor(refactorName2, {
                    kinds: getOwnValues(actions).map((a) => a.kind),
                    getAvailableActions: function getRefactorActionsToConvertBetweenNamedAndNamespacedImports(context) {
                        const info = getImportConversionInfo(context, context.triggerReason === "invoked");
                        if (!info)
                            return emptyArray;
                        if (!isRefactorErrorInfo(info)) {
                            const action = actions[info.convertTo];
                            return [{ name: refactorName2, description: action.description, actions: [action] }];
                        }
                        if (context.preferences.provideRefactorNotApplicableReason) {
                            return getOwnValues(actions).map((action) => ({
                                name: refactorName2,
                                description: action.description,
                                actions: [{ ...action, notApplicableReason: info.error }]
                            }));
                        }
                        return emptyArray;
                    },
                    getEditsForAction: function getRefactorEditsToConvertBetweenNamedAndNamespacedImports(context, actionName2) {
                        Debug.assert(some(getOwnValues(actions), (action) => action.name === actionName2), "Unexpected action name");
                        const info = getImportConversionInfo(context);
                        Debug.assert(info && !isRefactorErrorInfo(info), "Expected applicable refactor info");
                        const edits = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange2(context.file, context.program, t, info));
                        return { edits, renameFilename: void 0, renameLocation: void 0 };
                    }
                });
            }
        });
        // src/services/refactors/extractType.ts
        function getRangeToExtract(context, considerEmptySpans = true) {
            const { file, startPosition } = context;
            const isJS = isSourceFileJS(file);
            const range = createTextRangeFromSpan(getRefactorContextSpan(context));
            const isCursorRequest = range.pos === range.end && considerEmptySpans;
            const firstType = getFirstTypeAt(file, startPosition, range, isCursorRequest);
            if (!firstType || !isTypeNode(firstType))
                return { error: getLocaleSpecificMessage(Diagnostics.Selection_is_not_a_valid_type_node) };
            const checker = context.program.getTypeChecker();
            const enclosingNode = getEnclosingNode(firstType, isJS);
            if (enclosingNode === void 0)
                return { error: getLocaleSpecificMessage(Diagnostics.No_type_could_be_extracted_from_this_type_node) };
            const expandedFirstType = getExpandedSelectionNode(firstType, enclosingNode);
            if (!isTypeNode(expandedFirstType))
                return { error: getLocaleSpecificMessage(Diagnostics.Selection_is_not_a_valid_type_node) };
            const typeList = [];
            if ((isUnionTypeNode(expandedFirstType.parent) || isIntersectionTypeNode(expandedFirstType.parent)) && range.end > firstType.end) {
                addRange(typeList, expandedFirstType.parent.types.filter((type) => {
                    return nodeOverlapsWithStartEnd(type, file, range.pos, range.end);
                }));
            }
            const selection = typeList.length > 1 ? typeList : expandedFirstType;
            const typeParameters = collectTypeParameters(checker, selection, enclosingNode, file);
            if (!typeParameters)
                return { error: getLocaleSpecificMessage(Diagnostics.No_type_could_be_extracted_from_this_type_node) };
            const typeElements = flattenTypeLiteralNodeReference(checker, selection);
            return { isJS, selection, enclosingNode, typeParameters, typeElements };
        }
        function getFirstTypeAt(file, startPosition, range, isCursorRequest) {
            const currentNodes = [
                () => getTokenAtPosition(file, startPosition),
                () => getTouchingToken(file, startPosition, () => true)
            ];
            for (const f of currentNodes) {
                const current = f();
                const overlappingRange = nodeOverlapsWithStartEnd(current, file, range.pos, range.end);
                const firstType = findAncestor(current, (node) => node.parent && isTypeNode(node) && !rangeContainsSkipTrivia(range, node.parent, file) && (isCursorRequest || overlappingRange));
                if (firstType) {
                    return firstType;
                }
            }
            return void 0;
        }
        function flattenTypeLiteralNodeReference(checker, selection) {
            if (!selection)
                return void 0;
            if (isArray(selection)) {
                const result = [];
                for (const type of selection) {
                    const flattenedTypeMembers = flattenTypeLiteralNodeReference(checker, type);
                    if (!flattenedTypeMembers)
                        return void 0;
                    addRange(result, flattenedTypeMembers);
                }
                return result;
            }
            if (isIntersectionTypeNode(selection)) {
                const result = [];
                const seen = /* @__PURE__ */ new Map();
                for (const type of selection.types) {
                    const flattenedTypeMembers = flattenTypeLiteralNodeReference(checker, type);
                    if (!flattenedTypeMembers || !flattenedTypeMembers.every((type2) => type2.name && addToSeen(seen, getNameFromPropertyName(type2.name)))) {
                        return void 0;
                    }
                    addRange(result, flattenedTypeMembers);
                }
                return result;
            }
            else if (isParenthesizedTypeNode(selection)) {
                return flattenTypeLiteralNodeReference(checker, selection.type);
            }
            else if (isTypeLiteralNode(selection)) {
                return selection.members;
            }
            return void 0;
        }
        function rangeContainsSkipTrivia(r1, node, file) {
            return rangeContainsStartEnd(r1, skipTrivia(file.text, node.pos), node.end);
        }
        function collectTypeParameters(checker, selection, enclosingNode, file) {
            const result = [];
            const selectionArray = toArray(selection);
            const selectionRange = { pos: selectionArray[0].pos, end: selectionArray[selectionArray.length - 1].end };
            for (const t of selectionArray) {
                if (visitor(t))
                    return void 0;
            }
            return result;
            function visitor(node) {
                if (isTypeReferenceNode(node)) {
                    if (isIdentifier(node.typeName)) {
                        const typeName = node.typeName;
                        const symbol = checker.resolveName(typeName.text, typeName, 262144 /* TypeParameter */, 
                        /*excludeGlobals*/
                        true);
                        for (const decl of (symbol == null ? void 0 : symbol.declarations) || emptyArray) {
                            if (isTypeParameterDeclaration(decl) && decl.getSourceFile() === file) {
                                if (decl.name.escapedText === typeName.escapedText && rangeContainsSkipTrivia(decl, selectionRange, file)) {
                                    return true;
                                }
                                if (rangeContainsSkipTrivia(enclosingNode, decl, file) && !rangeContainsSkipTrivia(selectionRange, decl, file)) {
                                    pushIfUnique(result, decl);
                                    break;
                                }
                            }
                        }
                    }
                }
                else if (isInferTypeNode(node)) {
                    const conditionalTypeNode = findAncestor(node, (n) => isConditionalTypeNode(n) && rangeContainsSkipTrivia(n.extendsType, node, file));
                    if (!conditionalTypeNode || !rangeContainsSkipTrivia(selectionRange, conditionalTypeNode, file)) {
                        return true;
                    }
                }
                else if (isTypePredicateNode(node) || isThisTypeNode(node)) {
                    const functionLikeNode = findAncestor(node.parent, isFunctionLike);
                    if (functionLikeNode && functionLikeNode.type && rangeContainsSkipTrivia(functionLikeNode.type, node, file) && !rangeContainsSkipTrivia(selectionRange, functionLikeNode, file)) {
                        return true;
                    }
                }
                else if (isTypeQueryNode(node)) {
                    if (isIdentifier(node.exprName)) {
                        const symbol = checker.resolveName(node.exprName.text, node.exprName, 111551 /* Value */, 
                        /*excludeGlobals*/
                        false);
                        if ((symbol == null ? void 0 : symbol.valueDeclaration) && rangeContainsSkipTrivia(enclosingNode, symbol.valueDeclaration, file) && !rangeContainsSkipTrivia(selectionRange, symbol.valueDeclaration, file)) {
                            return true;
                        }
                    }
                    else {
                        if (isThisIdentifier(node.exprName.left) && !rangeContainsSkipTrivia(selectionRange, node.parent, file)) {
                            return true;
                        }
                    }
                }
                if (file && isTupleTypeNode(node) && getLineAndCharacterOfPosition(file, node.pos).line === getLineAndCharacterOfPosition(file, node.end).line) {
                    setEmitFlags(node, 1 /* SingleLine */);
                }
                return forEachChild(node, visitor);
            }
        }
        function doTypeAliasChange(changes, file, name, info) {
            const { enclosingNode, typeParameters } = info;
            const { firstTypeNode, lastTypeNode, newTypeNode } = getNodesToEdit(info);
            const newTypeDeclaration = factory.createTypeAliasDeclaration(
            /*modifiers*/
            void 0, name, typeParameters.map((id) => factory.updateTypeParameterDeclaration(id, id.modifiers, id.name, id.constraint, 
            /*defaultType*/
            void 0)), newTypeNode);
            changes.insertNodeBefore(file, enclosingNode, ignoreSourceNewlines(newTypeDeclaration), 
            /*blankLineBetween*/
            true);
            changes.replaceNodeRange(file, firstTypeNode, lastTypeNode, factory.createTypeReferenceNode(name, typeParameters.map((id) => factory.createTypeReferenceNode(id.name, 
            /*typeArguments*/
            void 0))), { leadingTriviaOption: ts_textChanges_exports.LeadingTriviaOption.Exclude, trailingTriviaOption: ts_textChanges_exports.TrailingTriviaOption.ExcludeWhitespace });
        }
        function doInterfaceChange(changes, file, name, info) {
            var _a;
            const { enclosingNode, typeParameters, typeElements } = info;
            const newTypeNode = factory.createInterfaceDeclaration(
            /*modifiers*/
            void 0, name, typeParameters, 
            /*heritageClauses*/
            void 0, typeElements);
            setTextRange(newTypeNode, (_a = typeElements[0]) == null ? void 0 : _a.parent);
            changes.insertNodeBefore(file, enclosingNode, ignoreSourceNewlines(newTypeNode), 
            /*blankLineBetween*/
            true);
            const { firstTypeNode, lastTypeNode } = getNodesToEdit(info);
            changes.replaceNodeRange(file, firstTypeNode, lastTypeNode, factory.createTypeReferenceNode(name, typeParameters.map((id) => factory.createTypeReferenceNode(id.name, 
            /*typeArguments*/
            void 0))), { leadingTriviaOption: ts_textChanges_exports.LeadingTriviaOption.Exclude, trailingTriviaOption: ts_textChanges_exports.TrailingTriviaOption.ExcludeWhitespace });
        }
        function doTypedefChange(changes, context, file, name, info) {
            var _a;
            toArray(info.selection).forEach((typeNode) => {
                setEmitFlags(typeNode, 3072 /* NoComments */ | 4096 /* NoNestedComments */);
            });
            const { enclosingNode, typeParameters } = info;
            const { firstTypeNode, lastTypeNode, newTypeNode } = getNodesToEdit(info);
            const node = factory.createJSDocTypedefTag(factory.createIdentifier("typedef"), factory.createJSDocTypeExpression(newTypeNode), factory.createIdentifier(name));
            const templates = [];
            forEach(typeParameters, (typeParameter) => {
                const constraint = getEffectiveConstraintOfTypeParameter(typeParameter);
                const parameter = factory.createTypeParameterDeclaration(
                /*modifiers*/
                void 0, typeParameter.name);
                const template = factory.createJSDocTemplateTag(factory.createIdentifier("template"), constraint && cast(constraint, isJSDocTypeExpression), [parameter]);
                templates.push(template);
            });
            const jsDoc = factory.createJSDocComment(
            /*comment*/
            void 0, factory.createNodeArray(concatenate(templates, [node])));
            if (isJSDoc(enclosingNode)) {
                const pos = enclosingNode.getStart(file);
                const newLineCharacter = getNewLineOrDefaultFromHost(context.host, (_a = context.formatContext) == null ? void 0 : _a.options);
                changes.insertNodeAt(file, enclosingNode.getStart(file), jsDoc, {
                    suffix: newLineCharacter + newLineCharacter + file.text.slice(getPrecedingNonSpaceCharacterPosition(file.text, pos - 1), pos)
                });
            }
            else {
                changes.insertNodeBefore(file, enclosingNode, jsDoc, 
                /*blankLineBetween*/
                true);
            }
            changes.replaceNodeRange(file, firstTypeNode, lastTypeNode, factory.createTypeReferenceNode(name, typeParameters.map((id) => factory.createTypeReferenceNode(id.name, 
            /*typeArguments*/
            void 0))));
        }
        function getNodesToEdit(info) {
            if (isArray(info.selection)) {
                return {
                    firstTypeNode: info.selection[0],
                    lastTypeNode: info.selection[info.selection.length - 1],
                    newTypeNode: isUnionTypeNode(info.selection[0].parent) ? factory.createUnionTypeNode(info.selection) : factory.createIntersectionTypeNode(info.selection)
                };
            }
            return {
                firstTypeNode: info.selection,
                lastTypeNode: info.selection,
                newTypeNode: info.selection
            };
        }
        function getEnclosingNode(node, isJS) {
            return findAncestor(node, isStatement) || (isJS ? findAncestor(node, isJSDoc) : void 0);
        }
        function getExpandedSelectionNode(firstType, enclosingNode) {
            return findAncestor(firstType, (node) => {
                if (node === enclosingNode)
                    return "quit";
                if (isUnionTypeNode(node.parent) || isIntersectionTypeNode(node.parent)) {
                    return true;
                }
                return false;
            }) ?? firstType;
        }
        var refactorName3, extractToTypeAliasAction, extractToInterfaceAction, extractToTypeDefAction;
        var init_extractType = __esm({
            "src/services/refactors/extractType.ts"() {
                "use strict";
                init_ts4();
                init_ts_refactor();
                refactorName3 = "Extract type";
                extractToTypeAliasAction = {
                    name: "Extract to type alias",
                    description: getLocaleSpecificMessage(Diagnostics.Extract_to_type_alias),
                    kind: "refactor.extract.type"
                };
                extractToInterfaceAction = {
                    name: "Extract to interface",
                    description: getLocaleSpecificMessage(Diagnostics.Extract_to_interface),
                    kind: "refactor.extract.interface"
                };
                extractToTypeDefAction = {
                    name: "Extract to typedef",
                    description: getLocaleSpecificMessage(Diagnostics.Extract_to_typedef),
                    kind: "refactor.extract.typedef"
                };
                registerRefactor(refactorName3, {
                    kinds: [
                        extractToTypeAliasAction.kind,
                        extractToInterfaceAction.kind,
                        extractToTypeDefAction.kind
                    ],
                    getAvailableActions: function getRefactorActionsToExtractType(context) {
                        const info = getRangeToExtract(context, context.triggerReason === "invoked");
                        if (!info)
                            return emptyArray;
                        if (!isRefactorErrorInfo(info)) {
                            return [{
                                    name: refactorName3,
                                    description: getLocaleSpecificMessage(Diagnostics.Extract_type),
                                    actions: info.isJS ? [extractToTypeDefAction] : append([extractToTypeAliasAction], info.typeElements && extractToInterfaceAction)
                                }];
                        }
                        if (context.preferences.provideRefactorNotApplicableReason) {
                            return [{
                                    name: refactorName3,
                                    description: getLocaleSpecificMessage(Diagnostics.Extract_type),
                                    actions: [
                                        { ...extractToTypeDefAction, notApplicableReason: info.error },
                                        { ...extractToTypeAliasAction, notApplicableReason: info.error },
                                        { ...extractToInterfaceAction, notApplicableReason: info.error }
                                    ]
                                }];
                        }
                        return emptyArray;
                    },
                    getEditsForAction: function getRefactorEditsToExtractType(context, actionName2) {
                        const { file } = context;
                        const info = getRangeToExtract(context);
                        Debug.assert(info && !isRefactorErrorInfo(info), "Expected to find a range to extract");
                        const name = getUniqueName("NewType", file);
                        const edits = ts_textChanges_exports.ChangeTracker.with(context, (changes) => {
                            switch (actionName2) {
                                case extractToTypeAliasAction.name:
                                    Debug.assert(!info.isJS, "Invalid actionName/JS combo");
                                    return doTypeAliasChange(changes, file, name, info);
                                case extractToTypeDefAction.name:
                                    Debug.assert(info.isJS, "Invalid actionName/JS combo");
                                    return doTypedefChange(changes, context, file, name, info);
                                case extractToInterfaceAction.name:
                                    Debug.assert(!info.isJS && !!info.typeElements, "Invalid actionName/JS combo");
                                    return doInterfaceChange(changes, file, name, info);
                                default:
                                    Debug.fail("Unexpected action name");
                            }
                        });
                        const renameFilename = file.fileName;
                        const renameLocation = getRenameLocation(edits, renameFilename, name, 
                        /*preferLastLocation*/
                        false);
                        return { edits, renameFilename, renameLocation };
                    }
                });
            }
        });
        // src/services/refactors/helpers.ts
        function isRefactorErrorInfo(info) {
            return info.error !== void 0;
        }
        function refactorKindBeginsWith(known, requested) {
            if (!requested)
                return true;
            return known.substr(0, requested.length) === requested;
        }
        var init_helpers = __esm({
            "src/services/refactors/helpers.ts"() {
                "use strict";
            }
        });
        // src/services/refactors/inlineVariable.ts
        function getInliningInfo(file, startPosition, tryWithReferenceToken, program) {
            var _a, _b;
            const checker = program.getTypeChecker();
            const token = getTouchingPropertyName(file, startPosition);
            const parent2 = token.parent;
            if (!isIdentifier(token)) {
                return void 0;
            }
            if (isInitializedVariable(parent2) && isVariableDeclarationInVariableStatement(parent2) && isIdentifier(parent2.name)) {
                if (((_a = checker.getMergedSymbol(parent2.symbol).declarations) == null ? void 0 : _a.length) !== 1) {
                    return { error: getLocaleSpecificMessage(Diagnostics.Variables_with_multiple_declarations_cannot_be_inlined) };
                }
                if (isDeclarationExported(parent2)) {
                    return void 0;
                }
                const references = getReferenceNodes(parent2, checker, file);
                return references && { references, declaration: parent2, replacement: parent2.initializer };
            }
            if (tryWithReferenceToken) {
                let definition = checker.resolveName(token.text, token, 111551 /* Value */, 
                /*excludeGlobals*/
                false);
                definition = definition && checker.getMergedSymbol(definition);
                if (((_b = definition == null ? void 0 : definition.declarations) == null ? void 0 : _b.length) !== 1) {
                    return { error: getLocaleSpecificMessage(Diagnostics.Variables_with_multiple_declarations_cannot_be_inlined) };
                }
                const declaration = definition.declarations[0];
                if (!isInitializedVariable(declaration) || !isVariableDeclarationInVariableStatement(declaration) || !isIdentifier(declaration.name)) {
                    return void 0;
                }
                if (isDeclarationExported(declaration)) {
                    return void 0;
                }
                const references = getReferenceNodes(declaration, checker, file);
                return references && { references, declaration, replacement: declaration.initializer };
            }
            return { error: getLocaleSpecificMessage(Diagnostics.Could_not_find_variable_to_inline) };
        }
        function isDeclarationExported(declaration) {
            const variableStatement = cast(declaration.parent.parent, isVariableStatement);
            return some(variableStatement.modifiers, isExportModifier);
        }
        function getReferenceNodes(declaration, checker, file) {
            const references = [];
            const cannotInline = ts_FindAllReferences_exports.Core.eachSymbolReferenceInFile(declaration.name, checker, file, (ref) => {
                if (ts_FindAllReferences_exports.isWriteAccessForReference(ref) && !isShorthandPropertyAssignment(ref.parent)) {
                    return true;
                }
                if (isExportSpecifier(ref.parent) || isExportAssignment(ref.parent)) {
                    return true;
                }
                if (isTypeQueryNode(ref.parent)) {
                    return true;
                }
                if (textRangeContainsPositionInclusive(declaration, ref.pos)) {
                    return true;
                }
                references.push(ref);
            });
            return references.length === 0 || cannotInline ? void 0 : references;
        }
        function getReplacementExpression(reference, replacement) {
            replacement = getSynthesizedDeepClone(replacement);
            const { parent: parent2 } = reference;
            if (isExpression(parent2) && (getExpressionPrecedence(replacement) < getExpressionPrecedence(parent2) || needsParentheses(parent2))) {
                return factory.createParenthesizedExpression(replacement);
            }
            if (isFunctionLike(replacement) && (isCallLikeExpression(parent2) || isPropertyAccessExpression(parent2))) {
                return factory.createParenthesizedExpression(replacement);
            }
            if (isPropertyAccessExpression(parent2) && (isNumericLiteral(replacement) || isObjectLiteralExpression(replacement))) {
                return factory.createParenthesizedExpression(replacement);
            }
            if (isIdentifier(reference) && isShorthandPropertyAssignment(parent2)) {
                return factory.createPropertyAssignment(reference, replacement);
            }
            return replacement;
        }
        var refactorName4, refactorDescription, inlineVariableAction;
        var init_inlineVariable = __esm({
            "src/services/refactors/inlineVariable.ts"() {
                "use strict";
                init_ts4();
                init_ts_refactor();
                refactorName4 = "Inline variable";
                refactorDescription = getLocaleSpecificMessage(Diagnostics.Inline_variable);
                inlineVariableAction = {
                    name: refactorName4,
                    description: refactorDescription,
                    kind: "refactor.inline.variable"
                };
                registerRefactor(refactorName4, {
                    kinds: [inlineVariableAction.kind],
                    getAvailableActions(context) {
                        const { file, program, preferences, startPosition, triggerReason } = context;
                        const info = getInliningInfo(file, startPosition, triggerReason === "invoked", program);
                        if (!info) {
                            return emptyArray;
                        }
                        if (!ts_refactor_exports.isRefactorErrorInfo(info)) {
                            return [{
                                    name: refactorName4,
                                    description: refactorDescription,
                                    actions: [inlineVariableAction]
                                }];
                        }
                        if (preferences.provideRefactorNotApplicableReason) {
                            return [{
                                    name: refactorName4,
                                    description: refactorDescription,
                                    actions: [{
                                            ...inlineVariableAction,
                                            notApplicableReason: info.error
                                        }]
                                }];
                        }
                        return emptyArray;
                    },
                    getEditsForAction(context, actionName2) {
                        Debug.assert(actionName2 === refactorName4, "Unexpected refactor invoked");
                        const { file, program, startPosition } = context;
                        const info = getInliningInfo(file, startPosition, 
                        /*tryWithReferenceToken*/
                        true, program);
                        if (!info || ts_refactor_exports.isRefactorErrorInfo(info)) {
                            return void 0;
                        }
                        const { references, declaration, replacement } = info;
                        const edits = ts_textChanges_exports.ChangeTracker.with(context, (tracker) => {
                            for (const node of references) {
                                tracker.replaceNode(file, node, getReplacementExpression(node, replacement));
                            }
                            tracker.delete(file, declaration);
                        });
                        return { edits };
                    }
                });
            }
        });
        // src/services/refactors/moveToNewFile.ts
        function doChange3(oldFile, program, toMove, changes, host, preferences) {
            const checker = program.getTypeChecker();
            const usage = getUsageInfo(oldFile, toMove.all, checker);
            const newFilename = createNewFileName(oldFile, program, host, toMove);
            changes.createNewFile(oldFile, newFilename, getNewStatementsAndRemoveFromOldFile(oldFile, usage, changes, toMove, program, host, newFilename, preferences));
            addNewFileToTsconfig(program, changes, oldFile.fileName, newFilename, hostGetCanonicalFileName(host));
        }
        function getNewStatementsAndRemoveFromOldFile(oldFile, usage, changes, toMove, program, host, newFilename, preferences) {
            const checker = program.getTypeChecker();
            const prologueDirectives = takeWhile(oldFile.statements, isPrologueDirective);
            if (oldFile.externalModuleIndicator === void 0 && oldFile.commonJsModuleIndicator === void 0 && usage.oldImportsNeededByTargetFile.size === 0) {
                deleteMovedStatements(oldFile, toMove.ranges, changes);
                return [...prologueDirectives, ...toMove.all];
            }
            const useEsModuleSyntax = !fileShouldUseJavaScriptRequire(newFilename, program, host, !!oldFile.commonJsModuleIndicator);
            const quotePreference = getQuotePreference(oldFile, preferences);
            const importsFromNewFile = createOldFileImportsFromTargetFile(oldFile, usage.oldFileImportsFromTargetFile, newFilename, program, host, useEsModuleSyntax, quotePreference);
            if (importsFromNewFile) {
                insertImports(changes, oldFile, importsFromNewFile, 
                /*blankLineBetween*/
                true, preferences);
            }
            deleteUnusedOldImports(oldFile, toMove.all, changes, usage.unusedImportsFromOldFile, checker);
            deleteMovedStatements(oldFile, toMove.ranges, changes);
            updateImportsInOtherFiles(changes, program, host, oldFile, usage.movedSymbols, newFilename, quotePreference);
            const imports = getNewFileImportsAndAddExportInOldFile(oldFile, usage.oldImportsNeededByTargetFile, usage.targetFileImportsFromOldFile, changes, checker, program, host, useEsModuleSyntax, quotePreference);
            const body = addExports(oldFile, toMove.all, usage.oldFileImportsFromTargetFile, useEsModuleSyntax);
            if (imports.length && body.length) {
                return [
                    ...prologueDirectives,
                    ...imports,
                    4 /* NewLineTrivia */,
                    ...body
                ];
            }
            return [
                ...prologueDirectives,
                ...imports,
                ...body
            ];
        }
        function getNewFileImportsAndAddExportInOldFile(oldFile, importsToCopy, newFileImportsFromOldFile, changes, checker, program, host, useEsModuleSyntax, quotePreference) {
            const copiedOldImports = [];
            for (const oldStatement of oldFile.statements) {
                forEachImportInStatement(oldStatement, (i) => {
                    append(copiedOldImports, filterImport(i, moduleSpecifierFromImport(i), (name) => importsToCopy.has(checker.getSymbolAtLocation(name))));
                });
            }
            let oldFileDefault;
            const oldFileNamedImports = [];
            const markSeenTop = nodeSeenTracker();
            newFileImportsFromOldFile.forEach((symbol) => {
                if (!symbol.declarations) {
                    return;
                }
                for (const decl of symbol.declarations) {
                    if (!isTopLevelDeclaration(decl))
                        continue;
                    const name = nameOfTopLevelDeclaration(decl);
                    if (!name)
                        continue;
                    const top = getTopLevelDeclarationStatement(decl);
                    if (markSeenTop(top)) {
                        addExportToChanges(oldFile, top, name, changes, useEsModuleSyntax);
                    }
                    if (hasSyntacticModifier(decl, 2048 /* Default */)) {
                        oldFileDefault = name;
                    }
                    else {
                        oldFileNamedImports.push(name.text);
                    }
                }
            });
            append(copiedOldImports, makeImportOrRequire(oldFile, oldFileDefault, oldFileNamedImports, getBaseFileName(oldFile.fileName), program, host, useEsModuleSyntax, quotePreference));
            return copiedOldImports;
        }
        var refactorName5, description, moveToNewFileAction;
        var init_moveToNewFile = __esm({
            "src/services/refactors/moveToNewFile.ts"() {
                "use strict";
                init_ts4();
                init_ts_refactor();
                refactorName5 = "Move to a new file";
                description = getLocaleSpecificMessage(Diagnostics.Move_to_a_new_file);
                moveToNewFileAction = {
                    name: refactorName5,
                    description,
                    kind: "refactor.move.newFile"
                };
                registerRefactor(refactorName5, {
                    kinds: [moveToNewFileAction.kind],
                    getAvailableActions: function getRefactorActionsToMoveToNewFile(context) {
                        const statements = getStatementsToMove(context);
                        if (context.preferences.allowTextChangesInNewFiles && statements) {
                            return [{ name: refactorName5, description, actions: [moveToNewFileAction] }];
                        }
                        if (context.preferences.provideRefactorNotApplicableReason) {
                            return [{ name: refactorName5, description, actions: [{ ...moveToNewFileAction, notApplicableReason: getLocaleSpecificMessage(Diagnostics.Selection_is_not_a_valid_statement_or_statements) }] }];
                        }
                        return emptyArray;
                    },
                    getEditsForAction: function getRefactorEditsToMoveToNewFile(context, actionName2) {
                        Debug.assert(actionName2 === refactorName5, "Wrong refactor invoked");
                        const statements = Debug.checkDefined(getStatementsToMove(context));
                        const edits = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange3(context.file, context.program, statements, t, context.host, context.preferences));
                        return { edits, renameFilename: void 0, renameLocation: void 0 };
                    }
                });
            }
        });
        // src/services/refactors/moveToFile.ts
        function error(notApplicableReason) {
            return { edits: [], renameFilename: void 0, renameLocation: void 0, notApplicableReason };
        }
        function doChange4(context, oldFile, targetFile, program, toMove, changes, host, preferences) {
            const checker = program.getTypeChecker();
            if (!host.fileExists(targetFile)) {
                changes.createNewFile(oldFile, targetFile, getNewStatementsAndRemoveFromOldFile2(oldFile, targetFile, getUsageInfo(oldFile, toMove.all, checker), changes, toMove, program, host, preferences));
                addNewFileToTsconfig(program, changes, oldFile.fileName, targetFile, hostGetCanonicalFileName(host));
            }
            else {
                const targetSourceFile = Debug.checkDefined(program.getSourceFile(targetFile));
                const importAdder = ts_codefix_exports.createImportAdder(targetSourceFile, context.program, context.preferences, context.host);
                getNewStatementsAndRemoveFromOldFile2(oldFile, targetSourceFile, getUsageInfo(oldFile, toMove.all, checker, getExistingLocals(targetSourceFile, toMove.all, checker)), changes, toMove, program, host, preferences, importAdder);
            }
        }
        function getNewStatementsAndRemoveFromOldFile2(oldFile, targetFile, usage, changes, toMove, program, host, preferences, importAdder) {
            const checker = program.getTypeChecker();
            const prologueDirectives = takeWhile(oldFile.statements, isPrologueDirective);
            if (oldFile.externalModuleIndicator === void 0 && oldFile.commonJsModuleIndicator === void 0 && usage.oldImportsNeededByTargetFile.size === 0 && usage.targetFileImportsFromOldFile.size === 0 && typeof targetFile === "string") {
                deleteMovedStatements(oldFile, toMove.ranges, changes);
                return [...prologueDirectives, ...toMove.all];
            }
            const targetFileName = typeof targetFile === "string" ? targetFile : targetFile.fileName;
            const useEsModuleSyntax = !fileShouldUseJavaScriptRequire(targetFileName, program, host, !!oldFile.commonJsModuleIndicator);
            const quotePreference = getQuotePreference(oldFile, preferences);
            const importsFromTargetFile = createOldFileImportsFromTargetFile(oldFile, usage.oldFileImportsFromTargetFile, targetFileName, program, host, useEsModuleSyntax, quotePreference);
            if (importsFromTargetFile) {
                insertImports(changes, oldFile, importsFromTargetFile, 
                /*blankLineBetween*/
                true, preferences);
            }
            deleteUnusedOldImports(oldFile, toMove.all, changes, usage.unusedImportsFromOldFile, checker);
            deleteMovedStatements(oldFile, toMove.ranges, changes);
            updateImportsInOtherFiles(changes, program, host, oldFile, usage.movedSymbols, targetFileName, quotePreference);
            const imports = getTargetFileImportsAndAddExportInOldFile(oldFile, targetFileName, usage.oldImportsNeededByTargetFile, usage.targetFileImportsFromOldFile, changes, checker, program, host, useEsModuleSyntax, quotePreference, importAdder);
            const body = addExports(oldFile, toMove.all, usage.oldFileImportsFromTargetFile, useEsModuleSyntax);
            if (typeof targetFile !== "string") {
                if (targetFile.statements.length > 0) {
                    moveStatementsToTargetFile(changes, program, body, targetFile, toMove);
                }
                else {
                    changes.insertNodesAtEndOfFile(targetFile, body, 
                    /*blankLineBetween*/
                    false);
                }
                if (imports.length > 0) {
                    insertImports(changes, targetFile, imports, 
                    /*blankLineBetween*/
                    true, preferences);
                }
            }
            if (importAdder) {
                importAdder.writeFixes(changes, quotePreference);
            }
            if (imports.length && body.length) {
                return [
                    ...prologueDirectives,
                    ...imports,
                    4 /* NewLineTrivia */,
                    ...body
                ];
            }
            return [
                ...prologueDirectives,
                ...imports,
                ...body
            ];
        }
        function getTargetFileImportsAndAddExportInOldFile(oldFile, targetFile, importsToCopy, targetFileImportsFromOldFile, changes, checker, program, host, useEsModuleSyntax, quotePreference, importAdder) {
            const copiedOldImports = [];
            if (importAdder) {
                importsToCopy.forEach((isValidTypeOnlyUseSite, symbol) => {
                    try {
                        importAdder.addImportFromExportedSymbol(skipAlias(symbol, checker), isValidTypeOnlyUseSite);
                    }
                    catch {
                        for (const oldStatement of oldFile.statements) {
                            forEachImportInStatement(oldStatement, (i) => {
                                append(copiedOldImports, filterImport(i, factory.createStringLiteral(moduleSpecifierFromImport(i).text), (name) => importsToCopy.has(checker.getSymbolAtLocation(name))));
                            });
                        }
                    }
                });
            }
            else {
                const targetSourceFile = program.getSourceFile(targetFile);
                for (const oldStatement of oldFile.statements) {
                    forEachImportInStatement(oldStatement, (i) => {
                        var _a;
                        const moduleSpecifier = moduleSpecifierFromImport(i);
                        const compilerOptions = program.getCompilerOptions();
                        const resolved = program.getResolvedModuleFromModuleSpecifier(moduleSpecifier);
                        const fileName = (_a = resolved == null ? void 0 : resolved.resolvedModule) == null ? void 0 : _a.resolvedFileName;
                        if (fileName && targetSourceFile) {
                            const newModuleSpecifier = getModuleSpecifier(compilerOptions, targetSourceFile, targetSourceFile.fileName, fileName, createModuleSpecifierResolutionHost(program, host));
                            append(copiedOldImports, filterImport(i, makeStringLiteral(newModuleSpecifier, quotePreference), (name) => importsToCopy.has(checker.getSymbolAtLocation(name))));
                        }
                        else {
                            append(copiedOldImports, filterImport(i, factory.createStringLiteral(moduleSpecifierFromImport(i).text), (name) => importsToCopy.has(checker.getSymbolAtLocation(name))));
                        }
                    });
                }
            }
            const targetFileSourceFile = program.getSourceFile(targetFile);
            let oldFileDefault;
            const oldFileNamedImports = [];
            const markSeenTop = nodeSeenTracker();
            targetFileImportsFromOldFile.forEach((symbol) => {
                if (!symbol.declarations) {
                    return;
                }
                for (const decl of symbol.declarations) {
                    if (!isTopLevelDeclaration(decl))
                        continue;
                    const name = nameOfTopLevelDeclaration(decl);
                    if (!name)
                        continue;
                    const top = getTopLevelDeclarationStatement(decl);
                    if (markSeenTop(top)) {
                        addExportToChanges(oldFile, top, name, changes, useEsModuleSyntax);
                    }
                    if (importAdder && checker.isUnknownSymbol(symbol)) {
                        importAdder.addImportFromExportedSymbol(skipAlias(symbol, checker));
                    }
                    else {
                        if (hasSyntacticModifier(decl, 2048 /* Default */)) {
                            oldFileDefault = name;
                        }
                        else {
                            oldFileNamedImports.push(name.text);
                        }
                    }
                }
            });
            return targetFileSourceFile ? append(copiedOldImports, makeImportOrRequire(targetFileSourceFile, oldFileDefault, oldFileNamedImports, oldFile.fileName, program, host, useEsModuleSyntax, quotePreference)) : append(copiedOldImports, makeImportOrRequire(oldFile, oldFileDefault, oldFileNamedImports, oldFile.fileName, program, host, useEsModuleSyntax, quotePreference));
        }
        function addNewFileToTsconfig(program, changes, oldFileName, newFileNameWithExtension, getCanonicalFileName) {
            const cfg = program.getCompilerOptions().configFile;
            if (!cfg)
                return;
            const newFileAbsolutePath = normalizePath(combinePaths(oldFileName, "..", newFileNameWithExtension));
            const newFilePath = getRelativePathFromFile(cfg.fileName, newFileAbsolutePath, getCanonicalFileName);
            const cfgObject = cfg.statements[0] && tryCast(cfg.statements[0].expression, isObjectLiteralExpression);
            const filesProp = cfgObject && find(cfgObject.properties, (prop) => isPropertyAssignment(prop) && isStringLiteral(prop.name) && prop.name.text === "files");
            if (filesProp && isArrayLiteralExpression(filesProp.initializer)) {
                changes.insertNodeInListAfter(cfg, last(filesProp.initializer.elements), factory.createStringLiteral(newFilePath), filesProp.initializer.elements);
            }
        }
        function deleteMovedStatements(sourceFile, moved, changes) {
            for (const { first: first2, afterLast } of moved) {
                changes.deleteNodeRangeExcludingEnd(sourceFile, first2, afterLast);
            }
        }
        function deleteUnusedOldImports(oldFile, toMove, changes, toDelete, checker) {
            for (const statement of oldFile.statements) {
                if (contains(toMove, statement))
                    continue;
                forEachImportInStatement(statement, (i) => deleteUnusedImports(oldFile, i, changes, (name) => toDelete.has(checker.getSymbolAtLocation(name))));
            }
        }
        function updateImportsInOtherFiles(changes, program, host, oldFile, movedSymbols, targetFileName, quotePreference) {
            const checker = program.getTypeChecker();
            for (const sourceFile of program.getSourceFiles()) {
                if (sourceFile === oldFile)
                    continue;
                for (const statement of sourceFile.statements) {
                    forEachImportInStatement(statement, (importNode) => {
                        if (checker.getSymbolAtLocation(moduleSpecifierFromImport(importNode)) !== oldFile.symbol)
                            return;
                        const shouldMove = (name) => {
                            const symbol = isBindingElement(name.parent) ? getPropertySymbolFromBindingElement(checker, name.parent) : skipAlias(checker.getSymbolAtLocation(name), checker);
                            return !!symbol && movedSymbols.has(symbol);
                        };
                        deleteUnusedImports(sourceFile, importNode, changes, shouldMove);
                        const pathToTargetFileWithExtension = resolvePath(getDirectoryPath(oldFile.path), targetFileName);
                        const newModuleSpecifier = getModuleSpecifier(program.getCompilerOptions(), sourceFile, sourceFile.fileName, pathToTargetFileWithExtension, createModuleSpecifierResolutionHost(program, host));
                        const newImportDeclaration = filterImport(importNode, makeStringLiteral(newModuleSpecifier, quotePreference), shouldMove);
                        if (newImportDeclaration)
                            changes.insertNodeAfter(sourceFile, statement, newImportDeclaration);
                        const ns = getNamespaceLikeImport(importNode);
                        if (ns)
                            updateNamespaceLikeImport(changes, sourceFile, checker, movedSymbols, newModuleSpecifier, ns, importNode, quotePreference);
                    });
                }
            }
        }
        function getNamespaceLikeImport(node) {
            switch (node.kind) {
                case 272 /* ImportDeclaration */:
                    return node.importClause && node.importClause.namedBindings && node.importClause.namedBindings.kind === 274 /* NamespaceImport */ ? node.importClause.namedBindings.name : void 0;
                case 271 /* ImportEqualsDeclaration */:
                    return node.name;
                case 260 /* VariableDeclaration */:
                    return tryCast(node.name, isIdentifier);
                default:
                    return Debug.assertNever(node, `Unexpected node kind ${node.kind}`);
            }
        }
        function updateNamespaceLikeImport(changes, sourceFile, checker, movedSymbols, newModuleSpecifier, oldImportId, oldImportNode, quotePreference) {
            const preferredNewNamespaceName = ts_codefix_exports.moduleSpecifierToValidIdentifier(newModuleSpecifier, 99 /* ESNext */);
            let needUniqueName = false;
            const toChange = [];
            ts_FindAllReferences_exports.Core.eachSymbolReferenceInFile(oldImportId, checker, sourceFile, (ref) => {
                if (!isPropertyAccessExpression(ref.parent))
                    return;
                needUniqueName = needUniqueName || !!checker.resolveName(preferredNewNamespaceName, ref, -1 /* All */, 
                /*excludeGlobals*/
                true);
                if (movedSymbols.has(checker.getSymbolAtLocation(ref.parent.name))) {
                    toChange.push(ref);
                }
            });
            if (toChange.length) {
                const newNamespaceName = needUniqueName ? getUniqueName(preferredNewNamespaceName, sourceFile) : preferredNewNamespaceName;
                for (const ref of toChange) {
                    changes.replaceNode(sourceFile, ref, factory.createIdentifier(newNamespaceName));
                }
                changes.insertNodeAfter(sourceFile, oldImportNode, updateNamespaceLikeImportNode(oldImportNode, preferredNewNamespaceName, newModuleSpecifier, quotePreference));
            }
        }
        function updateNamespaceLikeImportNode(node, newNamespaceName, newModuleSpecifier, quotePreference) {
            const newNamespaceId = factory.createIdentifier(newNamespaceName);
            const newModuleString = makeStringLiteral(newModuleSpecifier, quotePreference);
            switch (node.kind) {
                case 272 /* ImportDeclaration */:
                    return factory.createImportDeclaration(
                    /*modifiers*/
                    void 0, factory.createImportClause(
                    /*isTypeOnly*/
                    false, 
                    /*name*/
                    void 0, factory.createNamespaceImport(newNamespaceId)), newModuleString, 
                    /*attributes*/
                    void 0);
                case 271 /* ImportEqualsDeclaration */:
                    return factory.createImportEqualsDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*isTypeOnly*/
                    false, newNamespaceId, factory.createExternalModuleReference(newModuleString));
                case 260 /* VariableDeclaration */:
                    return factory.createVariableDeclaration(newNamespaceId, 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, createRequireCall(newModuleString));
                default:
                    return Debug.assertNever(node, `Unexpected node kind ${node.kind}`);
            }
        }
        function createRequireCall(moduleSpecifier) {
            return factory.createCallExpression(factory.createIdentifier("require"), 
            /*typeArguments*/
            void 0, [moduleSpecifier]);
        }
        function moduleSpecifierFromImport(i) {
            return i.kind === 272 /* ImportDeclaration */ ? i.moduleSpecifier : i.kind === 271 /* ImportEqualsDeclaration */ ? i.moduleReference.expression : i.initializer.arguments[0];
        }
        function forEachImportInStatement(statement, cb) {
            if (isImportDeclaration(statement)) {
                if (isStringLiteral(statement.moduleSpecifier))
                    cb(statement);
            }
            else if (isImportEqualsDeclaration(statement)) {
                if (isExternalModuleReference(statement.moduleReference) && isStringLiteralLike(statement.moduleReference.expression)) {
                    cb(statement);
                }
            }
            else if (isVariableStatement(statement)) {
                for (const decl of statement.declarationList.declarations) {
                    if (decl.initializer && isRequireCall(decl.initializer, 
                    /*requireStringLiteralLikeArgument*/
                    true)) {
                        cb(decl);
                    }
                }
            }
        }
        function createOldFileImportsFromTargetFile(sourceFile, targetFileNeedExport, targetFileNameWithExtension, program, host, useEs6Imports, quotePreference) {
            let defaultImport;
            const imports = [];
            targetFileNeedExport.forEach((symbol) => {
                if (symbol.escapedName === "default" /* Default */) {
                    defaultImport = factory.createIdentifier(symbolNameNoDefault(symbol));
                }
                else {
                    imports.push(symbol.name);
                }
            });
            return makeImportOrRequire(sourceFile, defaultImport, imports, targetFileNameWithExtension, program, host, useEs6Imports, quotePreference);
        }
        function makeImportOrRequire(sourceFile, defaultImport, imports, targetFileNameWithExtension, program, host, useEs6Imports, quotePreference) {
            const pathToTargetFile = resolvePath(getDirectoryPath(sourceFile.path), targetFileNameWithExtension);
            const pathToTargetFileWithCorrectExtension = getModuleSpecifier(program.getCompilerOptions(), sourceFile, sourceFile.fileName, pathToTargetFile, createModuleSpecifierResolutionHost(program, host));
            if (useEs6Imports) {
                const specifiers = imports.map((i) => factory.createImportSpecifier(
                /*isTypeOnly*/
                false, 
                /*propertyName*/
                void 0, factory.createIdentifier(i)));
                return makeImportIfNecessary(defaultImport, specifiers, pathToTargetFileWithCorrectExtension, quotePreference);
            }
            else {
                Debug.assert(!defaultImport, "No default import should exist");
                const bindingElements = imports.map((i) => factory.createBindingElement(
                /*dotDotDotToken*/
                void 0, 
                /*propertyName*/
                void 0, i));
                return bindingElements.length ? makeVariableStatement(factory.createObjectBindingPattern(bindingElements), 
                /*type*/
                void 0, createRequireCall(makeStringLiteral(pathToTargetFileWithCorrectExtension, quotePreference))) : void 0;
            }
        }
        function makeVariableStatement(name, type, initializer, flags = 2 /* Const */) {
            return factory.createVariableStatement(
            /*modifiers*/
            void 0, factory.createVariableDeclarationList([factory.createVariableDeclaration(name, 
                /*exclamationToken*/
                void 0, type, initializer)], flags));
        }
        function addExports(sourceFile, toMove, needExport, useEs6Exports) {
            return flatMap(toMove, (statement) => {
                if (isTopLevelDeclarationStatement(statement) && !isExported(sourceFile, statement, useEs6Exports) && forEachTopLevelDeclaration(statement, (d) => {
                    var _a;
                    return needExport.has(Debug.checkDefined((_a = tryCast(d, canHaveSymbol)) == null ? void 0 : _a.symbol));
                })) {
                    const exports = addExport(getSynthesizedDeepClone(statement), useEs6Exports);
                    if (exports)
                        return exports;
                }
                return getSynthesizedDeepClone(statement);
            });
        }
        function isExported(sourceFile, decl, useEs6Exports, name) {
            var _a;
            if (useEs6Exports) {
                return !isExpressionStatement(decl) && hasSyntacticModifier(decl, 32 /* Export */) || !!(name && sourceFile.symbol && ((_a = sourceFile.symbol.exports) == null ? void 0 : _a.has(name.escapedText)));
            }
            return !!sourceFile.symbol && !!sourceFile.symbol.exports && getNamesToExportInCommonJS(decl).some((name2) => sourceFile.symbol.exports.has(escapeLeadingUnderscores(name2)));
        }
        function deleteUnusedImports(sourceFile, importDecl, changes, isUnused) {
            switch (importDecl.kind) {
                case 272 /* ImportDeclaration */:
                    deleteUnusedImportsInDeclaration(sourceFile, importDecl, changes, isUnused);
                    break;
                case 271 /* ImportEqualsDeclaration */:
                    if (isUnused(importDecl.name)) {
                        changes.delete(sourceFile, importDecl);
                    }
                    break;
                case 260 /* VariableDeclaration */:
                    deleteUnusedImportsInVariableDeclaration(sourceFile, importDecl, changes, isUnused);
                    break;
                default:
                    Debug.assertNever(importDecl, `Unexpected import decl kind ${importDecl.kind}`);
            }
        }
        function deleteUnusedImportsInDeclaration(sourceFile, importDecl, changes, isUnused) {
            if (!importDecl.importClause)
                return;
            const { name, namedBindings } = importDecl.importClause;
            const defaultUnused = !name || isUnused(name);
            const namedBindingsUnused = !namedBindings || (namedBindings.kind === 274 /* NamespaceImport */ ? isUnused(namedBindings.name) : namedBindings.elements.length !== 0 && namedBindings.elements.every((e) => isUnused(e.name)));
            if (defaultUnused && namedBindingsUnused) {
                changes.delete(sourceFile, importDecl);
            }
            else {
                if (name && defaultUnused) {
                    changes.delete(sourceFile, name);
                }
                if (namedBindings) {
                    if (namedBindingsUnused) {
                        changes.replaceNode(sourceFile, importDecl.importClause, factory.updateImportClause(importDecl.importClause, importDecl.importClause.isTypeOnly, name, 
                        /*namedBindings*/
                        void 0));
                    }
                    else if (namedBindings.kind === 275 /* NamedImports */) {
                        for (const element of namedBindings.elements) {
                            if (isUnused(element.name))
                                changes.delete(sourceFile, element);
                        }
                    }
                }
            }
        }
        function deleteUnusedImportsInVariableDeclaration(sourceFile, varDecl, changes, isUnused) {
            const { name } = varDecl;
            switch (name.kind) {
                case 80 /* Identifier */:
                    if (isUnused(name)) {
                        if (varDecl.initializer && isRequireCall(varDecl.initializer, 
                        /*requireStringLiteralLikeArgument*/
                        true)) {
                            changes.delete(sourceFile, isVariableDeclarationList(varDecl.parent) && length(varDecl.parent.declarations) === 1 ? varDecl.parent.parent : varDecl);
                        }
                        else {
                            changes.delete(sourceFile, name);
                        }
                    }
                    break;
                case 207 /* ArrayBindingPattern */:
                    break;
                case 206 /* ObjectBindingPattern */:
                    if (name.elements.every((e) => isIdentifier(e.name) && isUnused(e.name))) {
                        changes.delete(sourceFile, isVariableDeclarationList(varDecl.parent) && varDecl.parent.declarations.length === 1 ? varDecl.parent.parent : varDecl);
                    }
                    else {
                        for (const element of name.elements) {
                            if (isIdentifier(element.name) && isUnused(element.name)) {
                                changes.delete(sourceFile, element.name);
                            }
                        }
                    }
                    break;
            }
        }
        function isTopLevelDeclarationStatement(node) {
            Debug.assert(isSourceFile(node.parent), "Node parent should be a SourceFile");
            return isNonVariableTopLevelDeclaration(node) || isVariableStatement(node);
        }
        function addExport(decl, useEs6Exports) {
            return useEs6Exports ? [addEs6Export(decl)] : addCommonjsExport(decl);
        }
        function addEs6Export(d) {
            const modifiers = canHaveModifiers(d) ? concatenate([factory.createModifier(95 /* ExportKeyword */)], getModifiers(d)) : void 0;
            switch (d.kind) {
                case 262 /* FunctionDeclaration */:
                    return factory.updateFunctionDeclaration(d, modifiers, d.asteriskToken, d.name, d.typeParameters, d.parameters, d.type, d.body);
                case 263 /* ClassDeclaration */:
                    const decorators = canHaveDecorators(d) ? getDecorators(d) : void 0;
                    return factory.updateClassDeclaration(d, concatenate(decorators, modifiers), d.name, d.typeParameters, d.heritageClauses, d.members);
                case 243 /* VariableStatement */:
                    return factory.updateVariableStatement(d, modifiers, d.declarationList);
                case 267 /* ModuleDeclaration */:
                    return factory.updateModuleDeclaration(d, modifiers, d.name, d.body);
                case 266 /* EnumDeclaration */:
                    return factory.updateEnumDeclaration(d, modifiers, d.name, d.members);
                case 265 /* TypeAliasDeclaration */:
                    return factory.updateTypeAliasDeclaration(d, modifiers, d.name, d.typeParameters, d.type);
                case 264 /* InterfaceDeclaration */:
                    return factory.updateInterfaceDeclaration(d, modifiers, d.name, d.typeParameters, d.heritageClauses, d.members);
                case 271 /* ImportEqualsDeclaration */:
                    return factory.updateImportEqualsDeclaration(d, modifiers, d.isTypeOnly, d.name, d.moduleReference);
                case 244 /* ExpressionStatement */:
                    return Debug.fail();
                default:
                    return Debug.assertNever(d, `Unexpected declaration kind ${d.kind}`);
            }
        }
        function addCommonjsExport(decl) {
            return [decl, ...getNamesToExportInCommonJS(decl).map(createExportAssignment)];
        }
        function createExportAssignment(name) {
            return factory.createExpressionStatement(factory.createBinaryExpression(factory.createPropertyAccessExpression(factory.createIdentifier("exports"), factory.createIdentifier(name)), 64 /* EqualsToken */, factory.createIdentifier(name)));
        }
        function getNamesToExportInCommonJS(decl) {
            switch (decl.kind) {
                case 262 /* FunctionDeclaration */:
                case 263 /* ClassDeclaration */:
                    return [decl.name.text];
                case 243 /* VariableStatement */:
                    return mapDefined(decl.declarationList.declarations, (d) => isIdentifier(d.name) ? d.name.text : void 0);
                case 267 /* ModuleDeclaration */:
                case 266 /* EnumDeclaration */:
                case 265 /* TypeAliasDeclaration */:
                case 264 /* InterfaceDeclaration */:
                case 271 /* ImportEqualsDeclaration */:
                    return emptyArray;
                case 244 /* ExpressionStatement */:
                    return Debug.fail("Can't export an ExpressionStatement");
                default:
                    return Debug.assertNever(decl, `Unexpected decl kind ${decl.kind}`);
            }
        }
        function filterImport(i, moduleSpecifier, keep) {
            switch (i.kind) {
                case 272 /* ImportDeclaration */: {
                    const clause = i.importClause;
                    if (!clause)
                        return void 0;
                    const defaultImport = clause.name && keep(clause.name) ? clause.name : void 0;
                    const namedBindings = clause.namedBindings && filterNamedBindings(clause.namedBindings, keep);
                    return defaultImport || namedBindings ? factory.createImportDeclaration(
                    /*modifiers*/
                    void 0, factory.createImportClause(clause.isTypeOnly, defaultImport, namedBindings), getSynthesizedDeepClone(moduleSpecifier), 
                    /*attributes*/
                    void 0) : void 0;
                }
                case 271 /* ImportEqualsDeclaration */:
                    return keep(i.name) ? i : void 0;
                case 260 /* VariableDeclaration */: {
                    const name = filterBindingName(i.name, keep);
                    return name ? makeVariableStatement(name, i.type, createRequireCall(moduleSpecifier), i.parent.flags) : void 0;
                }
                default:
                    return Debug.assertNever(i, `Unexpected import kind ${i.kind}`);
            }
        }
        function filterNamedBindings(namedBindings, keep) {
            if (namedBindings.kind === 274 /* NamespaceImport */) {
                return keep(namedBindings.name) ? namedBindings : void 0;
            }
            else {
                const newElements = namedBindings.elements.filter((e) => keep(e.name));
                return newElements.length ? factory.createNamedImports(newElements) : void 0;
            }
        }
        function filterBindingName(name, keep) {
            switch (name.kind) {
                case 80 /* Identifier */:
                    return keep(name) ? name : void 0;
                case 207 /* ArrayBindingPattern */:
                    return name;
                case 206 /* ObjectBindingPattern */: {
                    const newElements = name.elements.filter((prop) => prop.propertyName || !isIdentifier(prop.name) || keep(prop.name));
                    return newElements.length ? factory.createObjectBindingPattern(newElements) : void 0;
                }
            }
        }
        function nameOfTopLevelDeclaration(d) {
            return isExpressionStatement(d) ? tryCast(d.expression.left.name, isIdentifier) : tryCast(d.name, isIdentifier);
        }
        function getTopLevelDeclarationStatement(d) {
            switch (d.kind) {
                case 260 /* VariableDeclaration */:
                    return d.parent.parent;
                case 208 /* BindingElement */:
                    return getTopLevelDeclarationStatement(cast(d.parent.parent, (p) => isVariableDeclaration(p) || isBindingElement(p)));
                default:
                    return d;
            }
        }
        function addExportToChanges(sourceFile, decl, name, changes, useEs6Exports) {
            if (isExported(sourceFile, decl, useEs6Exports, name))
                return;
            if (useEs6Exports) {
                if (!isExpressionStatement(decl))
                    changes.insertExportModifier(sourceFile, decl);
            }
            else {
                const names = getNamesToExportInCommonJS(decl);
                if (names.length !== 0)
                    changes.insertNodesAfter(sourceFile, decl, names.map(createExportAssignment));
            }
        }
        function createNewFileName(oldFile, program, host, toMove) {
            const checker = program.getTypeChecker();
            if (toMove) {
                const usage = getUsageInfo(oldFile, toMove.all, checker);
                const currentDirectory = getDirectoryPath(oldFile.fileName);
                const extension = extensionFromPath(oldFile.fileName);
                const newFileName = combinePaths(
                // new file is always placed in the same directory as the old file
                currentDirectory, 
                // ensures the filename computed below isn't already taken
                makeUniqueFilename(
                // infers a name for the new file from the symbols being moved
                inferNewFileName(usage.oldFileImportsFromTargetFile, usage.movedSymbols), extension, currentDirectory, host)) + extension;
                return newFileName;
            }
            return "";
        }
        function getRangeToMove(context) {
            const { file } = context;
            const range = createTextRangeFromSpan(getRefactorContextSpan(context));
            const { statements } = file;
            let startNodeIndex = findIndex(statements, (s) => s.end > range.pos);
            if (startNodeIndex === -1)
                return void 0;
            const startStatement = statements[startNodeIndex];
            const overloadRangeToMove = getOverloadRangeToMove(file, startStatement);
            if (overloadRangeToMove) {
                startNodeIndex = overloadRangeToMove.start;
            }
            let endNodeIndex = findIndex(statements, (s) => s.end >= range.end, startNodeIndex);
            if (endNodeIndex !== -1 && range.end <= statements[endNodeIndex].getStart()) {
                endNodeIndex--;
            }
            const endingOverloadRangeToMove = getOverloadRangeToMove(file, statements[endNodeIndex]);
            if (endingOverloadRangeToMove) {
                endNodeIndex = endingOverloadRangeToMove.end;
            }
            return {
                toMove: statements.slice(startNodeIndex, endNodeIndex === -1 ? statements.length : endNodeIndex + 1),
                afterLast: endNodeIndex === -1 ? void 0 : statements[endNodeIndex + 1]
            };
        }
        function getStatementsToMove(context) {
            const rangeToMove = getRangeToMove(context);
            if (rangeToMove === void 0)
                return void 0;
            const all = [];
            const ranges = [];
            const { toMove, afterLast } = rangeToMove;
            getRangesWhere(toMove, isAllowedStatementToMove, (start, afterEndIndex) => {
                for (let i = start; i < afterEndIndex; i++)
                    all.push(toMove[i]);
                ranges.push({ first: toMove[start], afterLast });
            });
            return all.length === 0 ? void 0 : { all, ranges };
        }
        function containsJsx(statements) {
            return find(statements, (statement) => !!(statement.transformFlags & 2 /* ContainsJsx */));
        }
        function isAllowedStatementToMove(statement) {
            return !isPureImport(statement) && !isPrologueDirective(statement);
        }
        function isPureImport(node) {
            switch (node.kind) {
                case 272 /* ImportDeclaration */:
                    return true;
                case 271 /* ImportEqualsDeclaration */:
                    return !hasSyntacticModifier(node, 32 /* Export */);
                case 243 /* VariableStatement */:
                    return node.declarationList.declarations.every((d) => !!d.initializer && isRequireCall(d.initializer, 
                    /*requireStringLiteralLikeArgument*/
                    true));
                default:
                    return false;
            }
        }
        function getUsageInfo(oldFile, toMove, checker, existingTargetLocals = /* @__PURE__ */ new Set()) {
            const movedSymbols = /* @__PURE__ */ new Set();
            const oldImportsNeededByTargetFile = /* @__PURE__ */ new Map();
            const targetFileImportsFromOldFile = /* @__PURE__ */ new Set();
            const jsxNamespaceSymbol = getJsxNamespaceSymbol(containsJsx(toMove));
            if (jsxNamespaceSymbol) {
                oldImportsNeededByTargetFile.set(jsxNamespaceSymbol, false);
            }
            for (const statement of toMove) {
                forEachTopLevelDeclaration(statement, (decl) => {
                    movedSymbols.add(Debug.checkDefined(isExpressionStatement(decl) ? checker.getSymbolAtLocation(decl.expression.left) : decl.symbol, "Need a symbol here"));
                });
            }
            const unusedImportsFromOldFile = /* @__PURE__ */ new Set();
            for (const statement of toMove) {
                forEachReference(statement, checker, (symbol, isValidTypeOnlyUseSite) => {
                    if (!symbol.declarations) {
                        return;
                    }
                    if (existingTargetLocals.has(skipAlias(symbol, checker))) {
                        unusedImportsFromOldFile.add(symbol);
                        return;
                    }
                    for (const decl of symbol.declarations) {
                        if (isInImport(decl)) {
                            const prevIsTypeOnly = oldImportsNeededByTargetFile.get(symbol);
                            oldImportsNeededByTargetFile.set(symbol, prevIsTypeOnly === void 0 ? isValidTypeOnlyUseSite : prevIsTypeOnly && isValidTypeOnlyUseSite);
                        }
                        else if (isTopLevelDeclaration(decl) && sourceFileOfTopLevelDeclaration(decl) === oldFile && !movedSymbols.has(symbol)) {
                            targetFileImportsFromOldFile.add(symbol);
                        }
                    }
                });
            }
            for (const unusedImport of oldImportsNeededByTargetFile.keys()) {
                unusedImportsFromOldFile.add(unusedImport);
            }
            const oldFileImportsFromTargetFile = /* @__PURE__ */ new Set();
            for (const statement of oldFile.statements) {
                if (contains(toMove, statement))
                    continue;
                if (jsxNamespaceSymbol && !!(statement.transformFlags & 2 /* ContainsJsx */)) {
                    unusedImportsFromOldFile.delete(jsxNamespaceSymbol);
                }
                forEachReference(statement, checker, (symbol) => {
                    if (movedSymbols.has(symbol))
                        oldFileImportsFromTargetFile.add(symbol);
                    unusedImportsFromOldFile.delete(symbol);
                });
            }
            return { movedSymbols, targetFileImportsFromOldFile, oldFileImportsFromTargetFile, oldImportsNeededByTargetFile, unusedImportsFromOldFile };
            function getJsxNamespaceSymbol(containsJsx2) {
                if (containsJsx2 === void 0) {
                    return void 0;
                }
                const jsxNamespace = checker.getJsxNamespace(containsJsx2);
                const jsxNamespaceSymbol2 = checker.resolveName(jsxNamespace, containsJsx2, 1920 /* Namespace */, 
                /*excludeGlobals*/
                true);
                return !!jsxNamespaceSymbol2 && some(jsxNamespaceSymbol2.declarations, isInImport) ? jsxNamespaceSymbol2 : void 0;
            }
        }
        function makeUniqueFilename(proposedFilename, extension, inDirectory, host) {
            let newFilename = proposedFilename;
            for (let i = 1;; i++) {
                const name = combinePaths(inDirectory, newFilename + extension);
                if (!host.fileExists(name))
                    return newFilename;
                newFilename = `${proposedFilename}.${i}`;
            }
        }
        function inferNewFileName(importsFromNewFile, movedSymbols) {
            return forEachKey(importsFromNewFile, symbolNameNoDefault) || forEachKey(movedSymbols, symbolNameNoDefault) || "newFile";
        }
        function forEachReference(node, checker, onReference) {
            node.forEachChild(function cb(node2) {
                if (isIdentifier(node2) && !isDeclarationName(node2)) {
                    const sym = checker.getSymbolAtLocation(node2);
                    if (sym)
                        onReference(sym, isValidTypeOnlyAliasUseSite(node2));
                }
                else {
                    node2.forEachChild(cb);
                }
            });
        }
        function forEachTopLevelDeclaration(statement, cb) {
            switch (statement.kind) {
                case 262 /* FunctionDeclaration */:
                case 263 /* ClassDeclaration */:
                case 267 /* ModuleDeclaration */:
                case 266 /* EnumDeclaration */:
                case 265 /* TypeAliasDeclaration */:
                case 264 /* InterfaceDeclaration */:
                case 271 /* ImportEqualsDeclaration */:
                    return cb(statement);
                case 243 /* VariableStatement */:
                    return firstDefined(statement.declarationList.declarations, (decl) => forEachTopLevelDeclarationInBindingName(decl.name, cb));
                case 244 /* ExpressionStatement */: {
                    const { expression } = statement;
                    return isBinaryExpression(expression) && getAssignmentDeclarationKind(expression) === 1 /* ExportsProperty */ ? cb(statement) : void 0;
                }
            }
        }
        function isInImport(decl) {
            switch (decl.kind) {
                case 271 /* ImportEqualsDeclaration */:
                case 276 /* ImportSpecifier */:
                case 273 /* ImportClause */:
                case 274 /* NamespaceImport */:
                    return true;
                case 260 /* VariableDeclaration */:
                    return isVariableDeclarationInImport(decl);
                case 208 /* BindingElement */:
                    return isVariableDeclaration(decl.parent.parent) && isVariableDeclarationInImport(decl.parent.parent);
                default:
                    return false;
            }
        }
        function isVariableDeclarationInImport(decl) {
            return isSourceFile(decl.parent.parent.parent) && !!decl.initializer && isRequireCall(decl.initializer, 
            /*requireStringLiteralLikeArgument*/
            true);
        }
        function isTopLevelDeclaration(node) {
            return isNonVariableTopLevelDeclaration(node) && isSourceFile(node.parent) || isVariableDeclaration(node) && isSourceFile(node.parent.parent.parent);
        }
        function sourceFileOfTopLevelDeclaration(node) {
            return isVariableDeclaration(node) ? node.parent.parent.parent : node.parent;
        }
        function forEachTopLevelDeclarationInBindingName(name, cb) {
            switch (name.kind) {
                case 80 /* Identifier */:
                    return cb(cast(name.parent, (x) => isVariableDeclaration(x) || isBindingElement(x)));
                case 207 /* ArrayBindingPattern */:
                case 206 /* ObjectBindingPattern */:
                    return firstDefined(name.elements, (em) => isOmittedExpression(em) ? void 0 : forEachTopLevelDeclarationInBindingName(em.name, cb));
                default:
                    return Debug.assertNever(name, `Unexpected name kind ${name.kind}`);
            }
        }
        function isNonVariableTopLevelDeclaration(node) {
            switch (node.kind) {
                case 262 /* FunctionDeclaration */:
                case 263 /* ClassDeclaration */:
                case 267 /* ModuleDeclaration */:
                case 266 /* EnumDeclaration */:
                case 265 /* TypeAliasDeclaration */:
                case 264 /* InterfaceDeclaration */:
                case 271 /* ImportEqualsDeclaration */:
                    return true;
                default:
                    return false;
            }
        }
        function moveStatementsToTargetFile(changes, program, statements, targetFile, toMove) {
            var _a;
            const removedExports = /* @__PURE__ */ new Set();
            const targetExports = (_a = targetFile.symbol) == null ? void 0 : _a.exports;
            if (targetExports) {
                const checker = program.getTypeChecker();
                const targetToSourceExports = /* @__PURE__ */ new Map();
                for (const node of toMove.all) {
                    if (isTopLevelDeclarationStatement(node) && hasSyntacticModifier(node, 32 /* Export */)) {
                        forEachTopLevelDeclaration(node, (declaration) => {
                            var _a2;
                            const targetDeclarations = canHaveSymbol(declaration) ? (_a2 = targetExports.get(declaration.symbol.escapedName)) == null ? void 0 : _a2.declarations : void 0;
                            const exportDeclaration = firstDefined(targetDeclarations, (d) => isExportDeclaration(d) ? d : isExportSpecifier(d) ? tryCast(d.parent.parent, isExportDeclaration) : void 0);
                            if (exportDeclaration && exportDeclaration.moduleSpecifier) {
                                targetToSourceExports.set(exportDeclaration, (targetToSourceExports.get(exportDeclaration) || /* @__PURE__ */ new Set()).add(declaration));
                            }
                        });
                    }
                }
                for (const [exportDeclaration, topLevelDeclarations] of arrayFrom(targetToSourceExports)) {
                    if (exportDeclaration.exportClause && isNamedExports(exportDeclaration.exportClause) && length(exportDeclaration.exportClause.elements)) {
                        const elements = exportDeclaration.exportClause.elements;
                        const updatedElements = filter(elements, (elem) => find(skipAlias(elem.symbol, checker).declarations, (d) => isTopLevelDeclaration(d) && topLevelDeclarations.has(d)) === void 0);
                        if (length(updatedElements) === 0) {
                            changes.deleteNode(targetFile, exportDeclaration);
                            removedExports.add(exportDeclaration);
                            continue;
                        }
                        if (length(updatedElements) < length(elements)) {
                            changes.replaceNode(targetFile, exportDeclaration, factory.updateExportDeclaration(exportDeclaration, exportDeclaration.modifiers, exportDeclaration.isTypeOnly, factory.updateNamedExports(exportDeclaration.exportClause, factory.createNodeArray(updatedElements, elements.hasTrailingComma)), exportDeclaration.moduleSpecifier, exportDeclaration.attributes));
                        }
                    }
                }
            }
            const lastReExport = findLast(targetFile.statements, (n) => isExportDeclaration(n) && !!n.moduleSpecifier && !removedExports.has(n));
            if (lastReExport) {
                changes.insertNodesBefore(targetFile, lastReExport, statements, 
                /*blankLineBetween*/
                true);
            }
            else {
                changes.insertNodesAfter(targetFile, targetFile.statements[targetFile.statements.length - 1], statements);
            }
        }
        function getOverloadRangeToMove(sourceFile, statement) {
            if (isFunctionLikeDeclaration(statement)) {
                const declarations = statement.symbol.declarations;
                if (declarations === void 0 || length(declarations) <= 1 || !contains(declarations, statement)) {
                    return void 0;
                }
                const firstDecl = declarations[0];
                const lastDecl = declarations[length(declarations) - 1];
                const statementsToMove = mapDefined(declarations, (d) => getSourceFileOfNode(d) === sourceFile && isStatement(d) ? d : void 0);
                const end = findIndex(sourceFile.statements, (s) => s.end >= lastDecl.end);
                const start = findIndex(sourceFile.statements, (s) => s.end >= firstDecl.end);
                return { toMove: statementsToMove, start, end };
            }
            return void 0;
        }
        function getExistingLocals(sourceFile, statements, checker) {
            const existingLocals = /* @__PURE__ */ new Set();
            for (const moduleSpecifier of sourceFile.imports) {
                const declaration = importFromModuleSpecifier(moduleSpecifier);
                if (isImportDeclaration(declaration) && declaration.importClause && declaration.importClause.namedBindings && isNamedImports(declaration.importClause.namedBindings)) {
                    for (const e of declaration.importClause.namedBindings.elements) {
                        const symbol = checker.getSymbolAtLocation(e.propertyName || e.name);
                        if (symbol) {
                            existingLocals.add(skipAlias(symbol, checker));
                        }
                    }
                }
                if (isVariableDeclarationInitializedToRequire(declaration.parent) && isObjectBindingPattern(declaration.parent.name)) {
                    for (const e of declaration.parent.name.elements) {
                        const symbol = checker.getSymbolAtLocation(e.propertyName || e.name);
                        if (symbol) {
                            existingLocals.add(skipAlias(symbol, checker));
                        }
                    }
                }
            }
            for (const statement of statements) {
                forEachReference(statement, checker, (s) => {
                    const symbol = skipAlias(s, checker);
                    if (symbol.valueDeclaration && getSourceFileOfNode(symbol.valueDeclaration) === sourceFile) {
                        existingLocals.add(symbol);
                    }
                });
            }
            return existingLocals;
        }
        var refactorNameForMoveToFile, description2, moveToFileAction;
        var init_moveToFile = __esm({
            "src/services/refactors/moveToFile.ts"() {
                "use strict";
                init_moduleSpecifiers();
                init_ts4();
                init_refactorProvider();
                refactorNameForMoveToFile = "Move to file";
                description2 = getLocaleSpecificMessage(Diagnostics.Move_to_file);
                moveToFileAction = {
                    name: "Move to file",
                    description: description2,
                    kind: "refactor.move.file"
                };
                registerRefactor(refactorNameForMoveToFile, {
                    kinds: [moveToFileAction.kind],
                    getAvailableActions: function getRefactorActionsToMoveToFile(context, interactiveRefactorArguments) {
                        const statements = getStatementsToMove(context);
                        if (!interactiveRefactorArguments) {
                            return emptyArray;
                        }
                        if (context.preferences.allowTextChangesInNewFiles && statements) {
                            return [{ name: refactorNameForMoveToFile, description: description2, actions: [moveToFileAction] }];
                        }
                        if (context.preferences.provideRefactorNotApplicableReason) {
                            return [{ name: refactorNameForMoveToFile, description: description2, actions: [{ ...moveToFileAction, notApplicableReason: getLocaleSpecificMessage(Diagnostics.Selection_is_not_a_valid_statement_or_statements) }] }];
                        }
                        return emptyArray;
                    },
                    getEditsForAction: function getRefactorEditsToMoveToFile(context, actionName2, interactiveRefactorArguments) {
                        Debug.assert(actionName2 === refactorNameForMoveToFile, "Wrong refactor invoked");
                        const statements = Debug.checkDefined(getStatementsToMove(context));
                        const { host, program } = context;
                        Debug.assert(interactiveRefactorArguments, "No interactive refactor arguments available");
                        const targetFile = interactiveRefactorArguments.targetFile;
                        if (hasJSFileExtension(targetFile) || hasTSFileExtension(targetFile)) {
                            if (host.fileExists(targetFile) && program.getSourceFile(targetFile) === void 0) {
                                return error(getLocaleSpecificMessage(Diagnostics.Cannot_move_statements_to_the_selected_file));
                            }
                            const edits = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange4(context, context.file, interactiveRefactorArguments.targetFile, context.program, statements, t, context.host, context.preferences));
                            return { edits, renameFilename: void 0, renameLocation: void 0 };
                        }
                        return error(getLocaleSpecificMessage(Diagnostics.Cannot_move_to_file_selected_file_is_invalid));
                    }
                });
            }
        });
        // src/services/refactors/convertOverloadListToSingleSignature.ts
        function getRefactorActionsToConvertOverloadsToOneSignature(context) {
            const { file, startPosition, program } = context;
            const info = getConvertableOverloadListAtPosition(file, startPosition, program);
            if (!info)
                return emptyArray;
            return [{
                    name: refactorName6,
                    description: refactorDescription2,
                    actions: [functionOverloadAction]
                }];
        }
        function getRefactorEditsToConvertOverloadsToOneSignature(context) {
            const { file, startPosition, program } = context;
            const signatureDecls = getConvertableOverloadListAtPosition(file, startPosition, program);
            if (!signatureDecls)
                return void 0;
            const checker = program.getTypeChecker();
            const lastDeclaration = signatureDecls[signatureDecls.length - 1];
            let updated = lastDeclaration;
            switch (lastDeclaration.kind) {
                case 173 /* MethodSignature */: {
                    updated = factory.updateMethodSignature(lastDeclaration, lastDeclaration.modifiers, lastDeclaration.name, lastDeclaration.questionToken, lastDeclaration.typeParameters, getNewParametersForCombinedSignature(signatureDecls), lastDeclaration.type);
                    break;
                }
                case 174 /* MethodDeclaration */: {
                    updated = factory.updateMethodDeclaration(lastDeclaration, lastDeclaration.modifiers, lastDeclaration.asteriskToken, lastDeclaration.name, lastDeclaration.questionToken, lastDeclaration.typeParameters, getNewParametersForCombinedSignature(signatureDecls), lastDeclaration.type, lastDeclaration.body);
                    break;
                }
                case 179 /* CallSignature */: {
                    updated = factory.updateCallSignature(lastDeclaration, lastDeclaration.typeParameters, getNewParametersForCombinedSignature(signatureDecls), lastDeclaration.type);
                    break;
                }
                case 176 /* Constructor */: {
                    updated = factory.updateConstructorDeclaration(lastDeclaration, lastDeclaration.modifiers, getNewParametersForCombinedSignature(signatureDecls), lastDeclaration.body);
                    break;
                }
                case 180 /* ConstructSignature */: {
                    updated = factory.updateConstructSignature(lastDeclaration, lastDeclaration.typeParameters, getNewParametersForCombinedSignature(signatureDecls), lastDeclaration.type);
                    break;
                }
                case 262 /* FunctionDeclaration */: {
                    updated = factory.updateFunctionDeclaration(lastDeclaration, lastDeclaration.modifiers, lastDeclaration.asteriskToken, lastDeclaration.name, lastDeclaration.typeParameters, getNewParametersForCombinedSignature(signatureDecls), lastDeclaration.type, lastDeclaration.body);
                    break;
                }
                default:
                    return Debug.failBadSyntaxKind(lastDeclaration, "Unhandled signature kind in overload list conversion refactoring");
            }
            if (updated === lastDeclaration) {
                return;
            }
            const edits = ts_textChanges_exports.ChangeTracker.with(context, (t) => {
                t.replaceNodeRange(file, signatureDecls[0], signatureDecls[signatureDecls.length - 1], updated);
            });
            return { renameFilename: void 0, renameLocation: void 0, edits };
            function getNewParametersForCombinedSignature(signatureDeclarations) {
                const lastSig = signatureDeclarations[signatureDeclarations.length - 1];
                if (isFunctionLikeDeclaration(lastSig) && lastSig.body) {
                    signatureDeclarations = signatureDeclarations.slice(0, signatureDeclarations.length - 1);
                }
                return factory.createNodeArray([
                    factory.createParameterDeclaration(
                    /*modifiers*/
                    void 0, factory.createToken(26 /* DotDotDotToken */), "args", 
                    /*questionToken*/
                    void 0, factory.createUnionTypeNode(map(signatureDeclarations, convertSignatureParametersToTuple)))
                ]);
            }
            function convertSignatureParametersToTuple(decl) {
                const members = map(decl.parameters, convertParameterToNamedTupleMember);
                return setEmitFlags(factory.createTupleTypeNode(members), some(members, (m) => !!length(getSyntheticLeadingComments(m))) ? 0 /* None */ : 1 /* SingleLine */);
            }
            function convertParameterToNamedTupleMember(p) {
                Debug.assert(isIdentifier(p.name));
                const result = setTextRange(factory.createNamedTupleMember(p.dotDotDotToken, p.name, p.questionToken, p.type || factory.createKeywordTypeNode(133 /* AnyKeyword */)), p);
                const parameterDocComment = p.symbol && p.symbol.getDocumentationComment(checker);
                if (parameterDocComment) {
                    const newComment = displayPartsToString(parameterDocComment);
                    if (newComment.length) {
                        setSyntheticLeadingComments(result, [{
                                text: `*
${newComment.split("\n").map((c) => ` * ${c}`).join("\n")}
 `,
                                kind: 3 /* MultiLineCommentTrivia */,
                                pos: -1,
                                end: -1,
                                hasTrailingNewLine: true,
                                hasLeadingNewline: true
                            }]);
                    }
                }
                return result;
            }
        }
        function isConvertableSignatureDeclaration(d) {
            switch (d.kind) {
                case 173 /* MethodSignature */:
                case 174 /* MethodDeclaration */:
                case 179 /* CallSignature */:
                case 176 /* Constructor */:
                case 180 /* ConstructSignature */:
                case 262 /* FunctionDeclaration */:
                    return true;
            }
            return false;
        }
        function getConvertableOverloadListAtPosition(file, startPosition, program) {
            const node = getTokenAtPosition(file, startPosition);
            const containingDecl = findAncestor(node, isConvertableSignatureDeclaration);
            if (!containingDecl) {
                return;
            }
            if (isFunctionLikeDeclaration(containingDecl) && containingDecl.body && rangeContainsPosition(containingDecl.body, startPosition)) {
                return;
            }
            const checker = program.getTypeChecker();
            const signatureSymbol = containingDecl.symbol;
            if (!signatureSymbol) {
                return;
            }
            const decls = signatureSymbol.declarations;
            if (length(decls) <= 1) {
                return;
            }
            if (!every(decls, (d) => getSourceFileOfNode(d) === file)) {
                return;
            }
            if (!isConvertableSignatureDeclaration(decls[0])) {
                return;
            }
            const kindOne = decls[0].kind;
            if (!every(decls, (d) => d.kind === kindOne)) {
                return;
            }
            const signatureDecls = decls;
            if (some(signatureDecls, (d) => !!d.typeParameters || some(d.parameters, (p) => !!p.modifiers || !isIdentifier(p.name)))) {
                return;
            }
            const signatures = mapDefined(signatureDecls, (d) => checker.getSignatureFromDeclaration(d));
            if (length(signatures) !== length(decls)) {
                return;
            }
            const returnOne = checker.getReturnTypeOfSignature(signatures[0]);
            if (!every(signatures, (s) => checker.getReturnTypeOfSignature(s) === returnOne)) {
                return;
            }
            return signatureDecls;
        }
        var refactorName6, refactorDescription2, functionOverloadAction;
        var init_convertOverloadListToSingleSignature = __esm({
            "src/services/refactors/convertOverloadListToSingleSignature.ts"() {
                "use strict";
                init_ts4();
                init_ts_refactor();
                refactorName6 = "Convert overload list to single signature";
                refactorDescription2 = getLocaleSpecificMessage(Diagnostics.Convert_overload_list_to_single_signature);
                functionOverloadAction = {
                    name: refactorName6,
                    description: refactorDescription2,
                    kind: "refactor.rewrite.function.overloadList"
                };
                registerRefactor(refactorName6, {
                    kinds: [functionOverloadAction.kind],
                    getEditsForAction: getRefactorEditsToConvertOverloadsToOneSignature,
                    getAvailableActions: getRefactorActionsToConvertOverloadsToOneSignature
                });
            }
        });
        // src/services/refactors/addOrRemoveBracesToArrowFunction.ts
        function getRefactorActionsToRemoveFunctionBraces(context) {
            const { file, startPosition, triggerReason } = context;
            const info = getConvertibleArrowFunctionAtPosition(file, startPosition, triggerReason === "invoked");
            if (!info)
                return emptyArray;
            if (!isRefactorErrorInfo(info)) {
                return [{
                        name: refactorName7,
                        description: refactorDescription3,
                        actions: [
                            info.addBraces ? addBracesAction : removeBracesAction
                        ]
                    }];
            }
            if (context.preferences.provideRefactorNotApplicableReason) {
                return [{
                        name: refactorName7,
                        description: refactorDescription3,
                        actions: [
                            { ...addBracesAction, notApplicableReason: info.error },
                            { ...removeBracesAction, notApplicableReason: info.error }
                        ]
                    }];
            }
            return emptyArray;
        }
        function getRefactorEditsToRemoveFunctionBraces(context, actionName2) {
            const { file, startPosition } = context;
            const info = getConvertibleArrowFunctionAtPosition(file, startPosition);
            Debug.assert(info && !isRefactorErrorInfo(info), "Expected applicable refactor info");
            const { expression, returnStatement, func } = info;
            let body;
            if (actionName2 === addBracesAction.name) {
                const returnStatement2 = factory.createReturnStatement(expression);
                body = factory.createBlock([returnStatement2], 
                /*multiLine*/
                true);
                copyLeadingComments(expression, returnStatement2, file, 3 /* MultiLineCommentTrivia */, 
                /*hasTrailingNewLine*/
                true);
            }
            else if (actionName2 === removeBracesAction.name && returnStatement) {
                const actualExpression = expression || factory.createVoidZero();
                body = needsParentheses(actualExpression) ? factory.createParenthesizedExpression(actualExpression) : actualExpression;
                copyTrailingAsLeadingComments(returnStatement, body, file, 3 /* MultiLineCommentTrivia */, 
                /*hasTrailingNewLine*/
                false);
                copyLeadingComments(returnStatement, body, file, 3 /* MultiLineCommentTrivia */, 
                /*hasTrailingNewLine*/
                false);
                copyTrailingComments(returnStatement, body, file, 3 /* MultiLineCommentTrivia */, 
                /*hasTrailingNewLine*/
                false);
            }
            else {
                Debug.fail("invalid action");
            }
            const edits = ts_textChanges_exports.ChangeTracker.with(context, (t) => {
                t.replaceNode(file, func.body, body);
            });
            return { renameFilename: void 0, renameLocation: void 0, edits };
        }
        function getConvertibleArrowFunctionAtPosition(file, startPosition, considerFunctionBodies = true, kind) {
            const node = getTokenAtPosition(file, startPosition);
            const func = getContainingFunction(node);
            if (!func) {
                return {
                    error: getLocaleSpecificMessage(Diagnostics.Could_not_find_a_containing_arrow_function)
                };
            }
            if (!isArrowFunction(func)) {
                return {
                    error: getLocaleSpecificMessage(Diagnostics.Containing_function_is_not_an_arrow_function)
                };
            }
            if (!rangeContainsRange(func, node) || rangeContainsRange(func.body, node) && !considerFunctionBodies) {
                return void 0;
            }
            if (refactorKindBeginsWith(addBracesAction.kind, kind) && isExpression(func.body)) {
                return { func, addBraces: true, expression: func.body };
            }
            else if (refactorKindBeginsWith(removeBracesAction.kind, kind) && isBlock(func.body) && func.body.statements.length === 1) {
                const firstStatement = first(func.body.statements);
                if (isReturnStatement(firstStatement)) {
                    const expression = firstStatement.expression && isObjectLiteralExpression(getLeftmostExpression(firstStatement.expression, 
                    /*stopAtCallExpressions*/
                    false)) ? factory.createParenthesizedExpression(firstStatement.expression) : firstStatement.expression;
                    return { func, addBraces: false, expression, returnStatement: firstStatement };
                }
            }
            return void 0;
        }
        var refactorName7, refactorDescription3, addBracesAction, removeBracesAction;
        var init_addOrRemoveBracesToArrowFunction = __esm({
            "src/services/refactors/addOrRemoveBracesToArrowFunction.ts"() {
                "use strict";
                init_ts4();
                init_ts_refactor();
                refactorName7 = "Add or remove braces in an arrow function";
                refactorDescription3 = getLocaleSpecificMessage(Diagnostics.Add_or_remove_braces_in_an_arrow_function);
                addBracesAction = {
                    name: "Add braces to arrow function",
                    description: getLocaleSpecificMessage(Diagnostics.Add_braces_to_arrow_function),
                    kind: "refactor.rewrite.arrow.braces.add"
                };
                removeBracesAction = {
                    name: "Remove braces from arrow function",
                    description: getLocaleSpecificMessage(Diagnostics.Remove_braces_from_arrow_function),
                    kind: "refactor.rewrite.arrow.braces.remove"
                };
                registerRefactor(refactorName7, {
                    kinds: [removeBracesAction.kind],
                    getEditsForAction: getRefactorEditsToRemoveFunctionBraces,
                    getAvailableActions: getRefactorActionsToRemoveFunctionBraces
                });
            }
        });
        // src/services/_namespaces/ts.refactor.addOrRemoveBracesToArrowFunction.ts
        var ts_refactor_addOrRemoveBracesToArrowFunction_exports = {};
        var init_ts_refactor_addOrRemoveBracesToArrowFunction = __esm({
            "src/services/_namespaces/ts.refactor.addOrRemoveBracesToArrowFunction.ts"() {
                "use strict";
                init_convertOverloadListToSingleSignature();
                init_addOrRemoveBracesToArrowFunction();
            }
        });
        // src/services/refactors/convertArrowFunctionOrFunctionExpression.ts
        function getRefactorActionsToConvertFunctionExpressions(context) {
            const { file, startPosition, program, kind } = context;
            const info = getFunctionInfo(file, startPosition, program);
            if (!info)
                return emptyArray;
            const { selectedVariableDeclaration, func } = info;
            const possibleActions = [];
            const errors = [];
            if (refactorKindBeginsWith(toNamedFunctionAction.kind, kind)) {
                const error2 = selectedVariableDeclaration || isArrowFunction(func) && isVariableDeclaration(func.parent) ? void 0 : getLocaleSpecificMessage(Diagnostics.Could_not_convert_to_named_function);
                if (error2) {
                    errors.push({ ...toNamedFunctionAction, notApplicableReason: error2 });
                }
                else {
                    possibleActions.push(toNamedFunctionAction);
                }
            }
            if (refactorKindBeginsWith(toAnonymousFunctionAction.kind, kind)) {
                const error2 = !selectedVariableDeclaration && isArrowFunction(func) ? void 0 : getLocaleSpecificMessage(Diagnostics.Could_not_convert_to_anonymous_function);
                if (error2) {
                    errors.push({ ...toAnonymousFunctionAction, notApplicableReason: error2 });
                }
                else {
                    possibleActions.push(toAnonymousFunctionAction);
                }
            }
            if (refactorKindBeginsWith(toArrowFunctionAction.kind, kind)) {
                const error2 = isFunctionExpression(func) ? void 0 : getLocaleSpecificMessage(Diagnostics.Could_not_convert_to_arrow_function);
                if (error2) {
                    errors.push({ ...toArrowFunctionAction, notApplicableReason: error2 });
                }
                else {
                    possibleActions.push(toArrowFunctionAction);
                }
            }
            return [{
                    name: refactorName8,
                    description: refactorDescription4,
                    actions: possibleActions.length === 0 && context.preferences.provideRefactorNotApplicableReason ? errors : possibleActions
                }];
        }
        function getRefactorEditsToConvertFunctionExpressions(context, actionName2) {
            const { file, startPosition, program } = context;
            const info = getFunctionInfo(file, startPosition, program);
            if (!info)
                return void 0;
            const { func } = info;
            const edits = [];
            switch (actionName2) {
                case toAnonymousFunctionAction.name:
                    edits.push(...getEditInfoForConvertToAnonymousFunction(context, func));
                    break;
                case toNamedFunctionAction.name:
                    const variableInfo = getVariableInfo(func);
                    if (!variableInfo)
                        return void 0;
                    edits.push(...getEditInfoForConvertToNamedFunction(context, func, variableInfo));
                    break;
                case toArrowFunctionAction.name:
                    if (!isFunctionExpression(func))
                        return void 0;
                    edits.push(...getEditInfoForConvertToArrowFunction(context, func));
                    break;
                default:
                    return Debug.fail("invalid action");
            }
            return { renameFilename: void 0, renameLocation: void 0, edits };
        }
        function containingThis(node) {
            let containsThis = false;
            node.forEachChild(function checkThis(child) {
                if (isThis(child)) {
                    containsThis = true;
                    return;
                }
                if (!isClassLike(child) && !isFunctionDeclaration(child) && !isFunctionExpression(child)) {
                    forEachChild(child, checkThis);
                }
            });
            return containsThis;
        }
        function getFunctionInfo(file, startPosition, program) {
            const token = getTokenAtPosition(file, startPosition);
            const typeChecker = program.getTypeChecker();
            const func = tryGetFunctionFromVariableDeclaration(file, typeChecker, token.parent);
            if (func && !containingThis(func.body) && !typeChecker.containsArgumentsReference(func)) {
                return { selectedVariableDeclaration: true, func };
            }
            const maybeFunc = getContainingFunction(token);
            if (maybeFunc && (isFunctionExpression(maybeFunc) || isArrowFunction(maybeFunc)) && !rangeContainsRange(maybeFunc.body, token) && !containingThis(maybeFunc.body) && !typeChecker.containsArgumentsReference(maybeFunc)) {
                if (isFunctionExpression(maybeFunc) && isFunctionReferencedInFile(file, typeChecker, maybeFunc))
                    return void 0;
                return { selectedVariableDeclaration: false, func: maybeFunc };
            }
            return void 0;
        }
        function isSingleVariableDeclaration(parent2) {
            return isVariableDeclaration(parent2) || isVariableDeclarationList(parent2) && parent2.declarations.length === 1;
        }
        function tryGetFunctionFromVariableDeclaration(sourceFile, typeChecker, parent2) {
            if (!isSingleVariableDeclaration(parent2)) {
                return void 0;
            }
            const variableDeclaration = isVariableDeclaration(parent2) ? parent2 : first(parent2.declarations);
            const initializer = variableDeclaration.initializer;
            if (initializer && (isArrowFunction(initializer) || isFunctionExpression(initializer) && !isFunctionReferencedInFile(sourceFile, typeChecker, initializer))) {
                return initializer;
            }
            return void 0;
        }
        function convertToBlock(body) {
            if (isExpression(body)) {
                const returnStatement = factory.createReturnStatement(body);
                const file = body.getSourceFile();
                setTextRange(returnStatement, body);
                suppressLeadingAndTrailingTrivia(returnStatement);
                copyTrailingAsLeadingComments(body, returnStatement, file, 
                /*commentKind*/
                void 0, 
                /*hasTrailingNewLine*/
                true);
                return factory.createBlock([returnStatement], 
                /*multiLine*/
                true);
            }
            else {
                return body;
            }
        }
        function getVariableInfo(func) {
            const variableDeclaration = func.parent;
            if (!isVariableDeclaration(variableDeclaration) || !isVariableDeclarationInVariableStatement(variableDeclaration))
                return void 0;
            const variableDeclarationList = variableDeclaration.parent;
            const statement = variableDeclarationList.parent;
            if (!isVariableDeclarationList(variableDeclarationList) || !isVariableStatement(statement) || !isIdentifier(variableDeclaration.name))
                return void 0;
            return { variableDeclaration, variableDeclarationList, statement, name: variableDeclaration.name };
        }
        function getEditInfoForConvertToAnonymousFunction(context, func) {
            const { file } = context;
            const body = convertToBlock(func.body);
            const newNode = factory.createFunctionExpression(func.modifiers, func.asteriskToken, 
            /*name*/
            void 0, func.typeParameters, func.parameters, func.type, body);
            return ts_textChanges_exports.ChangeTracker.with(context, (t) => t.replaceNode(file, func, newNode));
        }
        function getEditInfoForConvertToNamedFunction(context, func, variableInfo) {
            const { file } = context;
            const body = convertToBlock(func.body);
            const { variableDeclaration, variableDeclarationList, statement, name } = variableInfo;
            suppressLeadingTrivia(statement);
            const modifiersFlags = getCombinedModifierFlags(variableDeclaration) & 32 /* Export */ | getEffectiveModifierFlags(func);
            const modifiers = factory.createModifiersFromModifierFlags(modifiersFlags);
            const newNode = factory.createFunctionDeclaration(length(modifiers) ? modifiers : void 0, func.asteriskToken, name, func.typeParameters, func.parameters, func.type, body);
            if (variableDeclarationList.declarations.length === 1) {
                return ts_textChanges_exports.ChangeTracker.with(context, (t) => t.replaceNode(file, statement, newNode));
            }
            else {
                return ts_textChanges_exports.ChangeTracker.with(context, (t) => {
                    t.delete(file, variableDeclaration);
                    t.insertNodeAfter(file, statement, newNode);
                });
            }
        }
        function getEditInfoForConvertToArrowFunction(context, func) {
            const { file } = context;
            const statements = func.body.statements;
            const head = statements[0];
            let body;
            if (canBeConvertedToExpression(func.body, head)) {
                body = head.expression;
                suppressLeadingAndTrailingTrivia(body);
                copyComments(head, body);
            }
            else {
                body = func.body;
            }
            const newNode = factory.createArrowFunction(func.modifiers, func.typeParameters, func.parameters, func.type, factory.createToken(39 /* EqualsGreaterThanToken */), body);
            return ts_textChanges_exports.ChangeTracker.with(context, (t) => t.replaceNode(file, func, newNode));
        }
        function canBeConvertedToExpression(body, head) {
            return body.statements.length === 1 && (isReturnStatement(head) && !!head.expression);
        }
        function isFunctionReferencedInFile(sourceFile, typeChecker, node) {
            return !!node.name && ts_FindAllReferences_exports.Core.isSymbolReferencedInFile(node.name, typeChecker, sourceFile);
        }
        var refactorName8, refactorDescription4, toAnonymousFunctionAction, toNamedFunctionAction, toArrowFunctionAction;
        var init_convertArrowFunctionOrFunctionExpression = __esm({
            "src/services/refactors/convertArrowFunctionOrFunctionExpression.ts"() {
                "use strict";
                init_ts4();
                init_ts_refactor();
                refactorName8 = "Convert arrow function or function expression";
                refactorDescription4 = getLocaleSpecificMessage(Diagnostics.Convert_arrow_function_or_function_expression);
                toAnonymousFunctionAction = {
                    name: "Convert to anonymous function",
                    description: getLocaleSpecificMessage(Diagnostics.Convert_to_anonymous_function),
                    kind: "refactor.rewrite.function.anonymous"
                };
                toNamedFunctionAction = {
                    name: "Convert to named function",
                    description: getLocaleSpecificMessage(Diagnostics.Convert_to_named_function),
                    kind: "refactor.rewrite.function.named"
                };
                toArrowFunctionAction = {
                    name: "Convert to arrow function",
                    description: getLocaleSpecificMessage(Diagnostics.Convert_to_arrow_function),
                    kind: "refactor.rewrite.function.arrow"
                };
                registerRefactor(refactorName8, {
                    kinds: [
                        toAnonymousFunctionAction.kind,
                        toNamedFunctionAction.kind,
                        toArrowFunctionAction.kind
                    ],
                    getEditsForAction: getRefactorEditsToConvertFunctionExpressions,
                    getAvailableActions: getRefactorActionsToConvertFunctionExpressions
                });
            }
        });
        // src/services/_namespaces/ts.refactor.convertArrowFunctionOrFunctionExpression.ts
        var ts_refactor_convertArrowFunctionOrFunctionExpression_exports = {};
        var init_ts_refactor_convertArrowFunctionOrFunctionExpression = __esm({
            "src/services/_namespaces/ts.refactor.convertArrowFunctionOrFunctionExpression.ts"() {
                "use strict";
                init_convertArrowFunctionOrFunctionExpression();
            }
        });
        // src/services/refactors/convertParamsToDestructuredObject.ts
        function getRefactorActionsToConvertParametersToDestructuredObject(context) {
            const { file, startPosition } = context;
            const isJSFile = isSourceFileJS(file);
            if (isJSFile)
                return emptyArray;
            const functionDeclaration = getFunctionDeclarationAtPosition(file, startPosition, context.program.getTypeChecker());
            if (!functionDeclaration)
                return emptyArray;
            return [{
                    name: refactorName9,
                    description: refactorDescription5,
                    actions: [toDestructuredAction]
                }];
        }
        function getRefactorEditsToConvertParametersToDestructuredObject(context, actionName2) {
            Debug.assert(actionName2 === refactorName9, "Unexpected action name");
            const { file, startPosition, program, cancellationToken, host } = context;
            const functionDeclaration = getFunctionDeclarationAtPosition(file, startPosition, program.getTypeChecker());
            if (!functionDeclaration || !cancellationToken)
                return void 0;
            const groupedReferences = getGroupedReferences(functionDeclaration, program, cancellationToken);
            if (groupedReferences.valid) {
                const edits = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange5(file, program, host, t, functionDeclaration, groupedReferences));
                return { renameFilename: void 0, renameLocation: void 0, edits };
            }
            return { edits: [] };
        }
        function doChange5(sourceFile, program, host, changes, functionDeclaration, groupedReferences) {
            const signature = groupedReferences.signature;
            const newFunctionDeclarationParams = map(createNewParameters(functionDeclaration, program, host), (param) => getSynthesizedDeepClone(param));
            if (signature) {
                const newSignatureParams = map(createNewParameters(signature, program, host), (param) => getSynthesizedDeepClone(param));
                replaceParameters(signature, newSignatureParams);
            }
            replaceParameters(functionDeclaration, newFunctionDeclarationParams);
            const functionCalls = sortAndDeduplicate(groupedReferences.functionCalls, 
            /*comparer*/
            (a, b) => compareValues(a.pos, b.pos));
            for (const call of functionCalls) {
                if (call.arguments && call.arguments.length) {
                    const newArgument = getSynthesizedDeepClone(createNewArgument(functionDeclaration, call.arguments), 
                    /*includeTrivia*/
                    true);
                    changes.replaceNodeRange(getSourceFileOfNode(call), first(call.arguments), last(call.arguments), newArgument, { leadingTriviaOption: ts_textChanges_exports.LeadingTriviaOption.IncludeAll, trailingTriviaOption: ts_textChanges_exports.TrailingTriviaOption.Include });
                }
            }
            function replaceParameters(declarationOrSignature, parameterDeclarations) {
                changes.replaceNodeRangeWithNodes(sourceFile, first(declarationOrSignature.parameters), last(declarationOrSignature.parameters), parameterDeclarations, {
                    joiner: ", ",
                    // indentation is set to 0 because otherwise the object parameter will be indented if there is a `this` parameter
                    indentation: 0,
                    leadingTriviaOption: ts_textChanges_exports.LeadingTriviaOption.IncludeAll,
                    trailingTriviaOption: ts_textChanges_exports.TrailingTriviaOption.Include
                });
            }
        }
        function getGroupedReferences(functionDeclaration, program, cancellationToken) {
            const functionNames = getFunctionNames(functionDeclaration);
            const classNames = isConstructorDeclaration(functionDeclaration) ? getClassNames(functionDeclaration) : [];
            const names = deduplicate([...functionNames, ...classNames], equateValues);
            const checker = program.getTypeChecker();
            const references = flatMap(names, 
            /*mapfn*/
            (name) => ts_FindAllReferences_exports.getReferenceEntriesForNode(-1, name, program, program.getSourceFiles(), cancellationToken));
            const groupedReferences = groupReferences(references);
            if (!every(groupedReferences.declarations, 
            /*callback*/
            (decl) => contains(names, decl))) {
                groupedReferences.valid = false;
            }
            return groupedReferences;
            function groupReferences(referenceEntries) {
                const classReferences = { accessExpressions: [], typeUsages: [] };
                const groupedReferences2 = { functionCalls: [], declarations: [], classReferences, valid: true };
                const functionSymbols = map(functionNames, getSymbolTargetAtLocation);
                const classSymbols = map(classNames, getSymbolTargetAtLocation);
                const isConstructor = isConstructorDeclaration(functionDeclaration);
                const contextualSymbols = map(functionNames, (name) => getSymbolForContextualType(name, checker));
                for (const entry of referenceEntries) {
                    if (entry.kind === ts_FindAllReferences_exports.EntryKind.Span) {
                        groupedReferences2.valid = false;
                        continue;
                    }
                    if (contains(contextualSymbols, getSymbolTargetAtLocation(entry.node))) {
                        if (isValidMethodSignature(entry.node.parent)) {
                            groupedReferences2.signature = entry.node.parent;
                            continue;
                        }
                        const call = entryToFunctionCall(entry);
                        if (call) {
                            groupedReferences2.functionCalls.push(call);
                            continue;
                        }
                    }
                    const contextualSymbol = getSymbolForContextualType(entry.node, checker);
                    if (contextualSymbol && contains(contextualSymbols, contextualSymbol)) {
                        const decl = entryToDeclaration(entry);
                        if (decl) {
                            groupedReferences2.declarations.push(decl);
                            continue;
                        }
                    }
                    if (contains(functionSymbols, getSymbolTargetAtLocation(entry.node)) || isNewExpressionTarget(entry.node)) {
                        const importOrExportReference = entryToImportOrExport(entry);
                        if (importOrExportReference) {
                            continue;
                        }
                        const decl = entryToDeclaration(entry);
                        if (decl) {
                            groupedReferences2.declarations.push(decl);
                            continue;
                        }
                        const call = entryToFunctionCall(entry);
                        if (call) {
                            groupedReferences2.functionCalls.push(call);
                            continue;
                        }
                    }
                    if (isConstructor && contains(classSymbols, getSymbolTargetAtLocation(entry.node))) {
                        const importOrExportReference = entryToImportOrExport(entry);
                        if (importOrExportReference) {
                            continue;
                        }
                        const decl = entryToDeclaration(entry);
                        if (decl) {
                            groupedReferences2.declarations.push(decl);
                            continue;
                        }
                        const accessExpression = entryToAccessExpression(entry);
                        if (accessExpression) {
                            classReferences.accessExpressions.push(accessExpression);
                            continue;
                        }
                        if (isClassDeclaration(functionDeclaration.parent)) {
                            const type = entryToType(entry);
                            if (type) {
                                classReferences.typeUsages.push(type);
                                continue;
                            }
                        }
                    }
                    groupedReferences2.valid = false;
                }
                return groupedReferences2;
            }
            function getSymbolTargetAtLocation(node) {
                const symbol = checker.getSymbolAtLocation(node);
                return symbol && getSymbolTarget(symbol, checker);
            }
        }
        function getSymbolForContextualType(node, checker) {
            const element = getContainingObjectLiteralElement(node);
            if (element) {
                const contextualType = checker.getContextualTypeForObjectLiteralElement(element);
                const symbol = contextualType == null ? void 0 : contextualType.getSymbol();
                if (symbol && !(getCheckFlags(symbol) & 6 /* Synthetic */)) {
                    return symbol;
                }
            }
        }
        function entryToImportOrExport(entry) {
            const node = entry.node;
            if (isImportSpecifier(node.parent) || isImportClause(node.parent) || isImportEqualsDeclaration(node.parent) || isNamespaceImport(node.parent)) {
                return node;
            }
            if (isExportSpecifier(node.parent) || isExportAssignment(node.parent)) {
                return node;
            }
            return void 0;
        }
        function entryToDeclaration(entry) {
            if (isDeclaration(entry.node.parent)) {
                return entry.node;
            }
            return void 0;
        }
        function entryToFunctionCall(entry) {
            if (entry.node.parent) {
                const functionReference = entry.node;
                const parent2 = functionReference.parent;
                switch (parent2.kind) {
                    case 213 /* CallExpression */:
                    case 214 /* NewExpression */:
                        const callOrNewExpression = tryCast(parent2, isCallOrNewExpression);
                        if (callOrNewExpression && callOrNewExpression.expression === functionReference) {
                            return callOrNewExpression;
                        }
                        break;
                    case 211 /* PropertyAccessExpression */:
                        const propertyAccessExpression = tryCast(parent2, isPropertyAccessExpression);
                        if (propertyAccessExpression && propertyAccessExpression.parent && propertyAccessExpression.name === functionReference) {
                            const callOrNewExpression2 = tryCast(propertyAccessExpression.parent, isCallOrNewExpression);
                            if (callOrNewExpression2 && callOrNewExpression2.expression === propertyAccessExpression) {
                                return callOrNewExpression2;
                            }
                        }
                        break;
                    case 212 /* ElementAccessExpression */:
                        const elementAccessExpression = tryCast(parent2, isElementAccessExpression);
                        if (elementAccessExpression && elementAccessExpression.parent && elementAccessExpression.argumentExpression === functionReference) {
                            const callOrNewExpression2 = tryCast(elementAccessExpression.parent, isCallOrNewExpression);
                            if (callOrNewExpression2 && callOrNewExpression2.expression === elementAccessExpression) {
                                return callOrNewExpression2;
                            }
                        }
                        break;
                }
            }
            return void 0;
        }
        function entryToAccessExpression(entry) {
            if (entry.node.parent) {
                const reference = entry.node;
                const parent2 = reference.parent;
                switch (parent2.kind) {
                    case 211 /* PropertyAccessExpression */:
                        const propertyAccessExpression = tryCast(parent2, isPropertyAccessExpression);
                        if (propertyAccessExpression && propertyAccessExpression.expression === reference) {
                            return propertyAccessExpression;
                        }
                        break;
                    case 212 /* ElementAccessExpression */:
                        const elementAccessExpression = tryCast(parent2, isElementAccessExpression);
                        if (elementAccessExpression && elementAccessExpression.expression === reference) {
                            return elementAccessExpression;
                        }
                        break;
                }
            }
            return void 0;
        }
        function entryToType(entry) {
            const reference = entry.node;
            if (getMeaningFromLocation(reference) === 2 /* Type */ || isExpressionWithTypeArgumentsInClassExtendsClause(reference.parent)) {
                return reference;
            }
            return void 0;
        }
        function getFunctionDeclarationAtPosition(file, startPosition, checker) {
            const node = getTouchingToken(file, startPosition);
            const functionDeclaration = getContainingFunctionDeclaration(node);
            if (isTopLevelJSDoc(node))
                return void 0;
            if (functionDeclaration && isValidFunctionDeclaration(functionDeclaration, checker) && rangeContainsRange(functionDeclaration, node) && !(functionDeclaration.body && rangeContainsRange(functionDeclaration.body, node)))
                return functionDeclaration;
            return void 0;
        }
        function isTopLevelJSDoc(node) {
            const containingJSDoc = findAncestor(node, isJSDocNode);
            if (containingJSDoc) {
                const containingNonJSDoc = findAncestor(containingJSDoc, (n) => !isJSDocNode(n));
                return !!containingNonJSDoc && isFunctionLikeDeclaration(containingNonJSDoc);
            }
            return false;
        }
        function isValidMethodSignature(node) {
            return isMethodSignature(node) && (isInterfaceDeclaration(node.parent) || isTypeLiteralNode(node.parent));
        }
        function isValidFunctionDeclaration(functionDeclaration, checker) {
            var _a;
            if (!isValidParameterNodeArray(functionDeclaration.parameters, checker))
                return false;
            switch (functionDeclaration.kind) {
                case 262 /* FunctionDeclaration */:
                    return hasNameOrDefault(functionDeclaration) && isSingleImplementation(functionDeclaration, checker);
                case 174 /* MethodDeclaration */:
                    if (isObjectLiteralExpression(functionDeclaration.parent)) {
                        const contextualSymbol = getSymbolForContextualType(functionDeclaration.name, checker);
                        return ((_a = contextualSymbol == null ? void 0 : contextualSymbol.declarations) == null ? void 0 : _a.length) === 1 && isSingleImplementation(functionDeclaration, checker);
                    }
                    return isSingleImplementation(functionDeclaration, checker);
                case 176 /* Constructor */:
                    if (isClassDeclaration(functionDeclaration.parent)) {
                        return hasNameOrDefault(functionDeclaration.parent) && isSingleImplementation(functionDeclaration, checker);
                    }
                    else {
                        return isValidVariableDeclaration(functionDeclaration.parent.parent) && isSingleImplementation(functionDeclaration, checker);
                    }
                case 218 /* FunctionExpression */:
                case 219 /* ArrowFunction */:
                    return isValidVariableDeclaration(functionDeclaration.parent);
            }
            return false;
        }
        function isSingleImplementation(functionDeclaration, checker) {
            return !!functionDeclaration.body && !checker.isImplementationOfOverload(functionDeclaration);
        }
        function hasNameOrDefault(functionOrClassDeclaration) {
            if (!functionOrClassDeclaration.name) {
                const defaultKeyword = findModifier(functionOrClassDeclaration, 90 /* DefaultKeyword */);
                return !!defaultKeyword;
            }
            return true;
        }
        function isValidParameterNodeArray(parameters, checker) {
            return getRefactorableParametersLength(parameters) >= minimumParameterLength && every(parameters, 
            /*callback*/
            (paramDecl) => isValidParameterDeclaration(paramDecl, checker));
        }
        function isValidParameterDeclaration(parameterDeclaration, checker) {
            if (isRestParameter(parameterDeclaration)) {
                const type = checker.getTypeAtLocation(parameterDeclaration);
                if (!checker.isArrayType(type) && !checker.isTupleType(type))
                    return false;
            }
            return !parameterDeclaration.modifiers && isIdentifier(parameterDeclaration.name);
        }
        function isValidVariableDeclaration(node) {
            return isVariableDeclaration(node) && isVarConst(node) && isIdentifier(node.name) && !node.type;
        }
        function hasThisParameter(parameters) {
            return parameters.length > 0 && isThis(parameters[0].name);
        }
        function getRefactorableParametersLength(parameters) {
            if (hasThisParameter(parameters)) {
                return parameters.length - 1;
            }
            return parameters.length;
        }
        function getRefactorableParameters(parameters) {
            if (hasThisParameter(parameters)) {
                parameters = factory.createNodeArray(parameters.slice(1), parameters.hasTrailingComma);
            }
            return parameters;
        }
        function createPropertyOrShorthandAssignment(name, initializer) {
            if (isIdentifier(initializer) && getTextOfIdentifierOrLiteral(initializer) === name) {
                return factory.createShorthandPropertyAssignment(name);
            }
            return factory.createPropertyAssignment(name, initializer);
        }
        function createNewArgument(functionDeclaration, functionArguments) {
            const parameters = getRefactorableParameters(functionDeclaration.parameters);
            const hasRestParameter2 = isRestParameter(last(parameters));
            const nonRestArguments = hasRestParameter2 ? functionArguments.slice(0, parameters.length - 1) : functionArguments;
            const properties = map(nonRestArguments, (arg, i) => {
                const parameterName = getParameterName(parameters[i]);
                const property = createPropertyOrShorthandAssignment(parameterName, arg);
                suppressLeadingAndTrailingTrivia(property.name);
                if (isPropertyAssignment(property))
                    suppressLeadingAndTrailingTrivia(property.initializer);
                copyComments(arg, property);
                return property;
            });
            if (hasRestParameter2 && functionArguments.length >= parameters.length) {
                const restArguments = functionArguments.slice(parameters.length - 1);
                const restProperty = factory.createPropertyAssignment(getParameterName(last(parameters)), factory.createArrayLiteralExpression(restArguments));
                properties.push(restProperty);
            }
            const objectLiteral = factory.createObjectLiteralExpression(properties, 
            /*multiLine*/
            false);
            return objectLiteral;
        }
        function createNewParameters(functionDeclaration, program, host) {
            const checker = program.getTypeChecker();
            const refactorableParameters = getRefactorableParameters(functionDeclaration.parameters);
            const bindingElements = map(refactorableParameters, createBindingElementFromParameterDeclaration);
            const objectParameterName = factory.createObjectBindingPattern(bindingElements);
            const objectParameterType = createParameterTypeNode(refactorableParameters);
            let objectInitializer;
            if (every(refactorableParameters, isOptionalParameter)) {
                objectInitializer = factory.createObjectLiteralExpression();
            }
            const objectParameter = factory.createParameterDeclaration(
            /*modifiers*/
            void 0, 
            /*dotDotDotToken*/
            void 0, objectParameterName, 
            /*questionToken*/
            void 0, objectParameterType, objectInitializer);
            if (hasThisParameter(functionDeclaration.parameters)) {
                const thisParameter = functionDeclaration.parameters[0];
                const newThisParameter = factory.createParameterDeclaration(
                /*modifiers*/
                void 0, 
                /*dotDotDotToken*/
                void 0, thisParameter.name, 
                /*questionToken*/
                void 0, thisParameter.type);
                suppressLeadingAndTrailingTrivia(newThisParameter.name);
                copyComments(thisParameter.name, newThisParameter.name);
                if (thisParameter.type) {
                    suppressLeadingAndTrailingTrivia(newThisParameter.type);
                    copyComments(thisParameter.type, newThisParameter.type);
                }
                return factory.createNodeArray([newThisParameter, objectParameter]);
            }
            return factory.createNodeArray([objectParameter]);
            function createBindingElementFromParameterDeclaration(parameterDeclaration) {
                const element = factory.createBindingElement(
                /*dotDotDotToken*/
                void 0, 
                /*propertyName*/
                void 0, getParameterName(parameterDeclaration), isRestParameter(parameterDeclaration) && isOptionalParameter(parameterDeclaration) ? factory.createArrayLiteralExpression() : parameterDeclaration.initializer);
                suppressLeadingAndTrailingTrivia(element);
                if (parameterDeclaration.initializer && element.initializer) {
                    copyComments(parameterDeclaration.initializer, element.initializer);
                }
                return element;
            }
            function createParameterTypeNode(parameters) {
                const members = map(parameters, createPropertySignatureFromParameterDeclaration);
                const typeNode = addEmitFlags(factory.createTypeLiteralNode(members), 1 /* SingleLine */);
                return typeNode;
            }
            function createPropertySignatureFromParameterDeclaration(parameterDeclaration) {
                let parameterType = parameterDeclaration.type;
                if (!parameterType && (parameterDeclaration.initializer || isRestParameter(parameterDeclaration))) {
                    parameterType = getTypeNode3(parameterDeclaration);
                }
                const propertySignature = factory.createPropertySignature(
                /*modifiers*/
                void 0, getParameterName(parameterDeclaration), isOptionalParameter(parameterDeclaration) ? factory.createToken(58 /* QuestionToken */) : parameterDeclaration.questionToken, parameterType);
                suppressLeadingAndTrailingTrivia(propertySignature);
                copyComments(parameterDeclaration.name, propertySignature.name);
                if (parameterDeclaration.type && propertySignature.type) {
                    copyComments(parameterDeclaration.type, propertySignature.type);
                }
                return propertySignature;
            }
            function getTypeNode3(node) {
                const type = checker.getTypeAtLocation(node);
                return getTypeNodeIfAccessible(type, node, program, host);
            }
            function isOptionalParameter(parameterDeclaration) {
                if (isRestParameter(parameterDeclaration)) {
                    const type = checker.getTypeAtLocation(parameterDeclaration);
                    return !checker.isTupleType(type);
                }
                return checker.isOptionalParameter(parameterDeclaration);
            }
        }
        function getParameterName(paramDeclaration) {
            return getTextOfIdentifierOrLiteral(paramDeclaration.name);
        }
        function getClassNames(constructorDeclaration) {
            switch (constructorDeclaration.parent.kind) {
                case 263 /* ClassDeclaration */:
                    const classDeclaration = constructorDeclaration.parent;
                    if (classDeclaration.name)
                        return [classDeclaration.name];
                    const defaultModifier = Debug.checkDefined(findModifier(classDeclaration, 90 /* DefaultKeyword */), "Nameless class declaration should be a default export");
                    return [defaultModifier];
                case 231 /* ClassExpression */:
                    const classExpression = constructorDeclaration.parent;
                    const variableDeclaration = constructorDeclaration.parent.parent;
                    const className = classExpression.name;
                    if (className)
                        return [className, variableDeclaration.name];
                    return [variableDeclaration.name];
            }
        }
        function getFunctionNames(functionDeclaration) {
            switch (functionDeclaration.kind) {
                case 262 /* FunctionDeclaration */:
                    if (functionDeclaration.name)
                        return [functionDeclaration.name];
                    const defaultModifier = Debug.checkDefined(findModifier(functionDeclaration, 90 /* DefaultKeyword */), "Nameless function declaration should be a default export");
                    return [defaultModifier];
                case 174 /* MethodDeclaration */:
                    return [functionDeclaration.name];
                case 176 /* Constructor */:
                    const ctrKeyword = Debug.checkDefined(findChildOfKind(functionDeclaration, 137 /* ConstructorKeyword */, functionDeclaration.getSourceFile()), "Constructor declaration should have constructor keyword");
                    if (functionDeclaration.parent.kind === 231 /* ClassExpression */) {
                        const variableDeclaration = functionDeclaration.parent.parent;
                        return [variableDeclaration.name, ctrKeyword];
                    }
                    return [ctrKeyword];
                case 219 /* ArrowFunction */:
                    return [functionDeclaration.parent.name];
                case 218 /* FunctionExpression */:
                    if (functionDeclaration.name)
                        return [functionDeclaration.name, functionDeclaration.parent.name];
                    return [functionDeclaration.parent.name];
                default:
                    return Debug.assertNever(functionDeclaration, `Unexpected function declaration kind ${functionDeclaration.kind}`);
            }
        }
        var refactorName9, minimumParameterLength, refactorDescription5, toDestructuredAction;
        var init_convertParamsToDestructuredObject = __esm({
            "src/services/refactors/convertParamsToDestructuredObject.ts"() {
                "use strict";
                init_ts4();
                init_ts_refactor();
                refactorName9 = "Convert parameters to destructured object";
                minimumParameterLength = 1;
                refactorDescription5 = getLocaleSpecificMessage(Diagnostics.Convert_parameters_to_destructured_object);
                toDestructuredAction = {
                    name: refactorName9,
                    description: refactorDescription5,
                    kind: "refactor.rewrite.parameters.toDestructured"
                };
                registerRefactor(refactorName9, {
                    kinds: [toDestructuredAction.kind],
                    getEditsForAction: getRefactorEditsToConvertParametersToDestructuredObject,
                    getAvailableActions: getRefactorActionsToConvertParametersToDestructuredObject
                });
            }
        });
        // src/services/_namespaces/ts.refactor.convertParamsToDestructuredObject.ts
        var ts_refactor_convertParamsToDestructuredObject_exports = {};
        var init_ts_refactor_convertParamsToDestructuredObject = __esm({
            "src/services/_namespaces/ts.refactor.convertParamsToDestructuredObject.ts"() {
                "use strict";
                init_convertParamsToDestructuredObject();
            }
        });
        // src/services/refactors/convertStringOrTemplateLiteral.ts
        function getRefactorActionsToConvertToTemplateString(context) {
            const { file, startPosition } = context;
            const node = getNodeOrParentOfParentheses(file, startPosition);
            const maybeBinary = getParentBinaryExpression(node);
            const nodeIsStringLiteral = isStringLiteral(maybeBinary);
            const refactorInfo = { name: refactorName10, description: refactorDescription6, actions: [] };
            if (nodeIsStringLiteral && context.triggerReason !== "invoked") {
                return emptyArray;
            }
            if (isExpressionNode(maybeBinary) && (nodeIsStringLiteral || isBinaryExpression(maybeBinary) && treeToArray(maybeBinary).isValidConcatenation)) {
                refactorInfo.actions.push(convertStringAction);
                return [refactorInfo];
            }
            else if (context.preferences.provideRefactorNotApplicableReason) {
                refactorInfo.actions.push({ ...convertStringAction, notApplicableReason: getLocaleSpecificMessage(Diagnostics.Can_only_convert_string_concatenations_and_string_literals) });
                return [refactorInfo];
            }
            return emptyArray;
        }
        function getNodeOrParentOfParentheses(file, startPosition) {
            const node = getTokenAtPosition(file, startPosition);
            const nestedBinary = getParentBinaryExpression(node);
            const isNonStringBinary = !treeToArray(nestedBinary).isValidConcatenation;
            if (isNonStringBinary && isParenthesizedExpression(nestedBinary.parent) && isBinaryExpression(nestedBinary.parent.parent)) {
                return nestedBinary.parent.parent;
            }
            return node;
        }
        function getRefactorEditsToConvertToTemplateString(context, actionName2) {
            const { file, startPosition } = context;
            const node = getNodeOrParentOfParentheses(file, startPosition);
            switch (actionName2) {
                case refactorDescription6:
                    return { edits: getEditsForToTemplateLiteral(context, node) };
                default:
                    return Debug.fail("invalid action");
            }
        }
        function getEditsForToTemplateLiteral(context, node) {
            const maybeBinary = getParentBinaryExpression(node);
            const file = context.file;
            const templateLiteral = nodesToTemplate(treeToArray(maybeBinary), file);
            const trailingCommentRanges = getTrailingCommentRanges(file.text, maybeBinary.end);
            if (trailingCommentRanges) {
                const lastComment = trailingCommentRanges[trailingCommentRanges.length - 1];
                const trailingRange = { pos: trailingCommentRanges[0].pos, end: lastComment.end };
                return ts_textChanges_exports.ChangeTracker.with(context, (t) => {
                    t.deleteRange(file, trailingRange);
                    t.replaceNode(file, maybeBinary, templateLiteral);
                });
            }
            else {
                return ts_textChanges_exports.ChangeTracker.with(context, (t) => t.replaceNode(file, maybeBinary, templateLiteral));
            }
        }
        function isNotEqualsOperator(node) {
            return !(node.operatorToken.kind === 64 /* EqualsToken */ || node.operatorToken.kind === 65 /* PlusEqualsToken */);
        }
        function getParentBinaryExpression(expr) {
            const container = findAncestor(expr.parent, (n) => {
                switch (n.kind) {
                    case 211 /* PropertyAccessExpression */:
                    case 212 /* ElementAccessExpression */:
                        return false;
                    case 228 /* TemplateExpression */:
                    case 226 /* BinaryExpression */:
                        return !(isBinaryExpression(n.parent) && isNotEqualsOperator(n.parent));
                    default:
                        return "quit";
                }
            });
            return container || expr;
        }
        function treeToArray(current) {
            const loop = (current2) => {
                if (!isBinaryExpression(current2)) {
                    return { nodes: [current2], operators: [], validOperators: true, hasString: isStringLiteral(current2) || isNoSubstitutionTemplateLiteral(current2) };
                }
                const { nodes: nodes2, operators: operators2, hasString: leftHasString, validOperators: leftOperatorValid } = loop(current2.left);
                if (!(leftHasString || isStringLiteral(current2.right) || isTemplateExpression(current2.right))) {
                    return { nodes: [current2], operators: [], hasString: false, validOperators: true };
                }
                const currentOperatorValid = current2.operatorToken.kind === 40 /* PlusToken */;
                const validOperators2 = leftOperatorValid && currentOperatorValid;
                nodes2.push(current2.right);
                operators2.push(current2.operatorToken);
                return { nodes: nodes2, operators: operators2, hasString: true, validOperators: validOperators2 };
            };
            const { nodes, operators, validOperators, hasString } = loop(current);
            return { nodes, operators, isValidConcatenation: validOperators && hasString };
        }
        function escapeRawStringForTemplate(s) {
            return s.replace(/\\.|[$`]/g, (m) => m[0] === "\\" ? m : "\\" + m);
        }
        function getRawTextOfTemplate(node) {
            const rightShaving = isTemplateHead(node) || isTemplateMiddle(node) ? -2 : -1;
            return getTextOfNode(node).slice(1, rightShaving);
        }
        function concatConsecutiveString(index, nodes) {
            const indexes = [];
            let text = "", rawText = "";
            while (index < nodes.length) {
                const node = nodes[index];
                if (isStringLiteralLike(node)) {
                    text += node.text;
                    rawText += escapeRawStringForTemplate(getTextOfNode(node).slice(1, -1));
                    indexes.push(index);
                    index++;
                }
                else if (isTemplateExpression(node)) {
                    text += node.head.text;
                    rawText += getRawTextOfTemplate(node.head);
                    break;
                }
                else {
                    break;
                }
            }
            return [index, text, rawText, indexes];
        }
        function nodesToTemplate({ nodes, operators }, file) {
            const copyOperatorComments = copyTrailingOperatorComments(operators, file);
            const copyCommentFromStringLiterals = copyCommentFromMultiNode(nodes, file, copyOperatorComments);
            const [begin, headText, rawHeadText, headIndexes] = concatConsecutiveString(0, nodes);
            if (begin === nodes.length) {
                const noSubstitutionTemplateLiteral = factory.createNoSubstitutionTemplateLiteral(headText, rawHeadText);
                copyCommentFromStringLiterals(headIndexes, noSubstitutionTemplateLiteral);
                return noSubstitutionTemplateLiteral;
            }
            const templateSpans = [];
            const templateHead = factory.createTemplateHead(headText, rawHeadText);
            copyCommentFromStringLiterals(headIndexes, templateHead);
            for (let i = begin; i < nodes.length; i++) {
                const currentNode = getExpressionFromParenthesesOrExpression(nodes[i]);
                copyOperatorComments(i, currentNode);
                const [newIndex, subsequentText, rawSubsequentText, stringIndexes] = concatConsecutiveString(i + 1, nodes);
                i = newIndex - 1;
                const isLast = i === nodes.length - 1;
                if (isTemplateExpression(currentNode)) {
                    const spans = map(currentNode.templateSpans, (span, index) => {
                        copyExpressionComments(span);
                        const isLastSpan = index === currentNode.templateSpans.length - 1;
                        const text = span.literal.text + (isLastSpan ? subsequentText : "");
                        const rawText = getRawTextOfTemplate(span.literal) + (isLastSpan ? rawSubsequentText : "");
                        return factory.createTemplateSpan(span.expression, isLast && isLastSpan ? factory.createTemplateTail(text, rawText) : factory.createTemplateMiddle(text, rawText));
                    });
                    templateSpans.push(...spans);
                }
                else {
                    const templatePart = isLast ? factory.createTemplateTail(subsequentText, rawSubsequentText) : factory.createTemplateMiddle(subsequentText, rawSubsequentText);
                    copyCommentFromStringLiterals(stringIndexes, templatePart);
                    templateSpans.push(factory.createTemplateSpan(currentNode, templatePart));
                }
            }
            return factory.createTemplateExpression(templateHead, templateSpans);
        }
        function copyExpressionComments(node) {
            const file = node.getSourceFile();
            copyTrailingComments(node, node.expression, file, 3 /* MultiLineCommentTrivia */, 
            /*hasTrailingNewLine*/
            false);
            copyTrailingAsLeadingComments(node.expression, node.expression, file, 3 /* MultiLineCommentTrivia */, 
            /*hasTrailingNewLine*/
            false);
        }
        function getExpressionFromParenthesesOrExpression(node) {
            if (isParenthesizedExpression(node)) {
                copyExpressionComments(node);
                node = node.expression;
            }
            return node;
        }
        var refactorName10, refactorDescription6, convertStringAction, copyTrailingOperatorComments, copyCommentFromMultiNode;
        var init_convertStringOrTemplateLiteral = __esm({
            "src/services/refactors/convertStringOrTemplateLiteral.ts"() {
                "use strict";
                init_ts4();
                init_ts_refactor();
                refactorName10 = "Convert to template string";
                refactorDescription6 = getLocaleSpecificMessage(Diagnostics.Convert_to_template_string);
                convertStringAction = {
                    name: refactorName10,
                    description: refactorDescription6,
                    kind: "refactor.rewrite.string"
                };
                registerRefactor(refactorName10, {
                    kinds: [convertStringAction.kind],
                    getEditsForAction: getRefactorEditsToConvertToTemplateString,
                    getAvailableActions: getRefactorActionsToConvertToTemplateString
                });
                copyTrailingOperatorComments = (operators, file) => (index, targetNode) => {
                    if (index < operators.length) {
                        copyTrailingComments(operators[index], targetNode, file, 3 /* MultiLineCommentTrivia */, 
                        /*hasTrailingNewLine*/
                        false);
                    }
                };
                copyCommentFromMultiNode = (nodes, file, copyOperatorComments) => (indexes, targetNode) => {
                    while (indexes.length > 0) {
                        const index = indexes.shift();
                        copyTrailingComments(nodes[index], targetNode, file, 3 /* MultiLineCommentTrivia */, 
                        /*hasTrailingNewLine*/
                        false);
                        copyOperatorComments(index, targetNode);
                    }
                };
            }
        });
        // src/services/_namespaces/ts.refactor.convertStringOrTemplateLiteral.ts
        var ts_refactor_convertStringOrTemplateLiteral_exports = {};
        var init_ts_refactor_convertStringOrTemplateLiteral = __esm({
            "src/services/_namespaces/ts.refactor.convertStringOrTemplateLiteral.ts"() {
                "use strict";
                init_convertStringOrTemplateLiteral();
            }
        });
        // src/services/refactors/convertToOptionalChainExpression.ts
        function getRefactorActionsToConvertToOptionalChain(context) {
            const info = getInfo3(context, context.triggerReason === "invoked");
            if (!info)
                return emptyArray;
            if (!isRefactorErrorInfo(info)) {
                return [{
                        name: refactorName11,
                        description: convertToOptionalChainExpressionMessage,
                        actions: [toOptionalChainAction]
                    }];
            }
            if (context.preferences.provideRefactorNotApplicableReason) {
                return [{
                        name: refactorName11,
                        description: convertToOptionalChainExpressionMessage,
                        actions: [{ ...toOptionalChainAction, notApplicableReason: info.error }]
                    }];
            }
            return emptyArray;
        }
        function getRefactorEditsToConvertToOptionalChain(context, actionName2) {
            const info = getInfo3(context);
            Debug.assert(info && !isRefactorErrorInfo(info), "Expected applicable refactor info");
            const edits = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange6(context.file, context.program.getTypeChecker(), t, info, actionName2));
            return { edits, renameFilename: void 0, renameLocation: void 0 };
        }
        function isValidExpression(node) {
            return isBinaryExpression(node) || isConditionalExpression(node);
        }
        function isValidStatement(node) {
            return isExpressionStatement(node) || isReturnStatement(node) || isVariableStatement(node);
        }
        function isValidExpressionOrStatement(node) {
            return isValidExpression(node) || isValidStatement(node);
        }
        function getInfo3(context, considerEmptySpans = true) {
            const { file, program } = context;
            const span = getRefactorContextSpan(context);
            const forEmptySpan = span.length === 0;
            if (forEmptySpan && !considerEmptySpans)
                return void 0;
            const startToken = getTokenAtPosition(file, span.start);
            const endToken = findTokenOnLeftOfPosition(file, span.start + span.length);
            const adjustedSpan = createTextSpanFromBounds(startToken.pos, endToken && endToken.end >= startToken.pos ? endToken.getEnd() : startToken.getEnd());
            const parent2 = forEmptySpan ? getValidParentNodeOfEmptySpan(startToken) : getValidParentNodeContainingSpan(startToken, adjustedSpan);
            const expression = parent2 && isValidExpressionOrStatement(parent2) ? getExpression(parent2) : void 0;
            if (!expression)
                return { error: getLocaleSpecificMessage(Diagnostics.Could_not_find_convertible_access_expression) };
            const checker = program.getTypeChecker();
            return isConditionalExpression(expression) ? getConditionalInfo(expression, checker) : getBinaryInfo(expression);
        }
        function getConditionalInfo(expression, checker) {
            const condition = expression.condition;
            const finalExpression = getFinalExpressionInChain(expression.whenTrue);
            if (!finalExpression || checker.isNullableType(checker.getTypeAtLocation(finalExpression))) {
                return { error: getLocaleSpecificMessage(Diagnostics.Could_not_find_convertible_access_expression) };
            }
            if ((isPropertyAccessExpression(condition) || isIdentifier(condition)) && getMatchingStart(condition, finalExpression.expression)) {
                return { finalExpression, occurrences: [condition], expression };
            }
            else if (isBinaryExpression(condition)) {
                const occurrences = getOccurrencesInExpression(finalExpression.expression, condition);
                return occurrences ? { finalExpression, occurrences, expression } : { error: getLocaleSpecificMessage(Diagnostics.Could_not_find_matching_access_expressions) };
            }
        }
        function getBinaryInfo(expression) {
            if (expression.operatorToken.kind !== 56 /* AmpersandAmpersandToken */) {
                return { error: getLocaleSpecificMessage(Diagnostics.Can_only_convert_logical_AND_access_chains) };
            }
            const finalExpression = getFinalExpressionInChain(expression.right);
            if (!finalExpression)
                return { error: getLocaleSpecificMessage(Diagnostics.Could_not_find_convertible_access_expression) };
            const occurrences = getOccurrencesInExpression(finalExpression.expression, expression.left);
            return occurrences ? { finalExpression, occurrences, expression } : { error: getLocaleSpecificMessage(Diagnostics.Could_not_find_matching_access_expressions) };
        }
        function getOccurrencesInExpression(matchTo, expression) {
            const occurrences = [];
            while (isBinaryExpression(expression) && expression.operatorToken.kind === 56 /* AmpersandAmpersandToken */) {
                const match = getMatchingStart(skipParentheses(matchTo), skipParentheses(expression.right));
                if (!match) {
                    break;
                }
                occurrences.push(match);
                matchTo = match;
                expression = expression.left;
            }
            const finalMatch = getMatchingStart(matchTo, expression);
            if (finalMatch) {
                occurrences.push(finalMatch);
            }
            return occurrences.length > 0 ? occurrences : void 0;
        }
        function getMatchingStart(chain, subchain) {
            if (!isIdentifier(subchain) && !isPropertyAccessExpression(subchain) && !isElementAccessExpression(subchain)) {
                return void 0;
            }
            return chainStartsWith(chain, subchain) ? subchain : void 0;
        }
        function chainStartsWith(chain, subchain) {
            while (isCallExpression(chain) || isPropertyAccessExpression(chain) || isElementAccessExpression(chain)) {
                if (getTextOfChainNode(chain) === getTextOfChainNode(subchain))
                    break;
                chain = chain.expression;
            }
            while (isPropertyAccessExpression(chain) && isPropertyAccessExpression(subchain) || isElementAccessExpression(chain) && isElementAccessExpression(subchain)) {
                if (getTextOfChainNode(chain) !== getTextOfChainNode(subchain))
                    return false;
                chain = chain.expression;
                subchain = subchain.expression;
            }
            return isIdentifier(chain) && isIdentifier(subchain) && chain.getText() === subchain.getText();
        }
        function getTextOfChainNode(node) {
            if (isIdentifier(node) || isStringOrNumericLiteralLike(node)) {
                return node.getText();
            }
            if (isPropertyAccessExpression(node)) {
                return getTextOfChainNode(node.name);
            }
            if (isElementAccessExpression(node)) {
                return getTextOfChainNode(node.argumentExpression);
            }
            return void 0;
        }
        function getValidParentNodeContainingSpan(node, span) {
            while (node.parent) {
                if (isValidExpressionOrStatement(node) && span.length !== 0 && node.end >= span.start + span.length) {
                    return node;
                }
                node = node.parent;
            }
            return void 0;
        }
        function getValidParentNodeOfEmptySpan(node) {
            while (node.parent) {
                if (isValidExpressionOrStatement(node) && !isValidExpressionOrStatement(node.parent)) {
                    return node;
                }
                node = node.parent;
            }
            return void 0;
        }
        function getExpression(node) {
            if (isValidExpression(node)) {
                return node;
            }
            if (isVariableStatement(node)) {
                const variable = getSingleVariableOfVariableStatement(node);
                const initializer = variable == null ? void 0 : variable.initializer;
                return initializer && isValidExpression(initializer) ? initializer : void 0;
            }
            return node.expression && isValidExpression(node.expression) ? node.expression : void 0;
        }
        function getFinalExpressionInChain(node) {
            node = skipParentheses(node);
            if (isBinaryExpression(node)) {
                return getFinalExpressionInChain(node.left);
            }
            else if ((isPropertyAccessExpression(node) || isElementAccessExpression(node) || isCallExpression(node)) && !isOptionalChain(node)) {
                return node;
            }
            return void 0;
        }
        function convertOccurrences(checker, toConvert, occurrences) {
            if (isPropertyAccessExpression(toConvert) || isElementAccessExpression(toConvert) || isCallExpression(toConvert)) {
                const chain = convertOccurrences(checker, toConvert.expression, occurrences);
                const lastOccurrence = occurrences.length > 0 ? occurrences[occurrences.length - 1] : void 0;
                const isOccurrence = (lastOccurrence == null ? void 0 : lastOccurrence.getText()) === toConvert.expression.getText();
                if (isOccurrence)
                    occurrences.pop();
                if (isCallExpression(toConvert)) {
                    return isOccurrence ? factory.createCallChain(chain, factory.createToken(29 /* QuestionDotToken */), toConvert.typeArguments, toConvert.arguments) : factory.createCallChain(chain, toConvert.questionDotToken, toConvert.typeArguments, toConvert.arguments);
                }
                else if (isPropertyAccessExpression(toConvert)) {
                    return isOccurrence ? factory.createPropertyAccessChain(chain, factory.createToken(29 /* QuestionDotToken */), toConvert.name) : factory.createPropertyAccessChain(chain, toConvert.questionDotToken, toConvert.name);
                }
                else if (isElementAccessExpression(toConvert)) {
                    return isOccurrence ? factory.createElementAccessChain(chain, factory.createToken(29 /* QuestionDotToken */), toConvert.argumentExpression) : factory.createElementAccessChain(chain, toConvert.questionDotToken, toConvert.argumentExpression);
                }
            }
            return toConvert;
        }
        function doChange6(sourceFile, checker, changes, info, _actionName) {
            const { finalExpression, occurrences, expression } = info;
            const firstOccurrence = occurrences[occurrences.length - 1];
            const convertedChain = convertOccurrences(checker, finalExpression, occurrences);
            if (convertedChain && (isPropertyAccessExpression(convertedChain) || isElementAccessExpression(convertedChain) || isCallExpression(convertedChain))) {
                if (isBinaryExpression(expression)) {
                    changes.replaceNodeRange(sourceFile, firstOccurrence, finalExpression, convertedChain);
                }
                else if (isConditionalExpression(expression)) {
                    changes.replaceNode(sourceFile, expression, factory.createBinaryExpression(convertedChain, factory.createToken(61 /* QuestionQuestionToken */), expression.whenFalse));
                }
            }
        }
        var refactorName11, convertToOptionalChainExpressionMessage, toOptionalChainAction;
        var init_convertToOptionalChainExpression = __esm({
            "src/services/refactors/convertToOptionalChainExpression.ts"() {
                "use strict";
                init_ts4();
                init_ts_refactor();
                refactorName11 = "Convert to optional chain expression";
                convertToOptionalChainExpressionMessage = getLocaleSpecificMessage(Diagnostics.Convert_to_optional_chain_expression);
                toOptionalChainAction = {
                    name: refactorName11,
                    description: convertToOptionalChainExpressionMessage,
                    kind: "refactor.rewrite.expression.optionalChain"
                };
                registerRefactor(refactorName11, {
                    kinds: [toOptionalChainAction.kind],
                    getEditsForAction: getRefactorEditsToConvertToOptionalChain,
                    getAvailableActions: getRefactorActionsToConvertToOptionalChain
                });
            }
        });
        // src/services/_namespaces/ts.refactor.convertToOptionalChainExpression.ts
        var ts_refactor_convertToOptionalChainExpression_exports = {};
        var init_ts_refactor_convertToOptionalChainExpression = __esm({
            "src/services/_namespaces/ts.refactor.convertToOptionalChainExpression.ts"() {
                "use strict";
                init_convertToOptionalChainExpression();
            }
        });
        // src/services/refactors/extractSymbol.ts
        function getRefactorActionsToExtractSymbol(context) {
            const requestedRefactor = context.kind;
            const rangeToExtract = getRangeToExtract2(context.file, getRefactorContextSpan(context), context.triggerReason === "invoked");
            const targetRange = rangeToExtract.targetRange;
            if (targetRange === void 0) {
                if (!rangeToExtract.errors || rangeToExtract.errors.length === 0 || !context.preferences.provideRefactorNotApplicableReason) {
                    return emptyArray;
                }
                const errors = [];
                if (refactorKindBeginsWith(extractFunctionAction.kind, requestedRefactor)) {
                    errors.push({
                        name: refactorName12,
                        description: extractFunctionAction.description,
                        actions: [{ ...extractFunctionAction, notApplicableReason: getStringError(rangeToExtract.errors) }]
                    });
                }
                if (refactorKindBeginsWith(extractConstantAction.kind, requestedRefactor)) {
                    errors.push({
                        name: refactorName12,
                        description: extractConstantAction.description,
                        actions: [{ ...extractConstantAction, notApplicableReason: getStringError(rangeToExtract.errors) }]
                    });
                }
                return errors;
            }
            const extractions = getPossibleExtractions(targetRange, context);
            if (extractions === void 0) {
                return emptyArray;
            }
            const functionActions = [];
            const usedFunctionNames = /* @__PURE__ */ new Map();
            let innermostErrorFunctionAction;
            const constantActions = [];
            const usedConstantNames = /* @__PURE__ */ new Map();
            let innermostErrorConstantAction;
            let i = 0;
            for (const { functionExtraction, constantExtraction } of extractions) {
                if (refactorKindBeginsWith(extractFunctionAction.kind, requestedRefactor)) {
                    const description3 = functionExtraction.description;
                    if (functionExtraction.errors.length === 0) {
                        if (!usedFunctionNames.has(description3)) {
                            usedFunctionNames.set(description3, true);
                            functionActions.push({
                                description: description3,
                                name: `function_scope_${i}`,
                                kind: extractFunctionAction.kind
                            });
                        }
                    }
                    else if (!innermostErrorFunctionAction) {
                        innermostErrorFunctionAction = {
                            description: description3,
                            name: `function_scope_${i}`,
                            notApplicableReason: getStringError(functionExtraction.errors),
                            kind: extractFunctionAction.kind
                        };
                    }
                }
                if (refactorKindBeginsWith(extractConstantAction.kind, requestedRefactor)) {
                    const description3 = constantExtraction.description;
                    if (constantExtraction.errors.length === 0) {
                        if (!usedConstantNames.has(description3)) {
                            usedConstantNames.set(description3, true);
                            constantActions.push({
                                description: description3,
                                name: `constant_scope_${i}`,
                                kind: extractConstantAction.kind
                            });
                        }
                    }
                    else if (!innermostErrorConstantAction) {
                        innermostErrorConstantAction = {
                            description: description3,
                            name: `constant_scope_${i}`,
                            notApplicableReason: getStringError(constantExtraction.errors),
                            kind: extractConstantAction.kind
                        };
                    }
                }
                i++;
            }
            const infos = [];
            if (functionActions.length) {
                infos.push({
                    name: refactorName12,
                    description: getLocaleSpecificMessage(Diagnostics.Extract_function),
                    actions: functionActions
                });
            }
            else if (context.preferences.provideRefactorNotApplicableReason && innermostErrorFunctionAction) {
                infos.push({
                    name: refactorName12,
                    description: getLocaleSpecificMessage(Diagnostics.Extract_function),
                    actions: [innermostErrorFunctionAction]
                });
            }
            if (constantActions.length) {
                infos.push({
                    name: refactorName12,
                    description: getLocaleSpecificMessage(Diagnostics.Extract_constant),
                    actions: constantActions
                });
            }
            else if (context.preferences.provideRefactorNotApplicableReason && innermostErrorConstantAction) {
                infos.push({
                    name: refactorName12,
                    description: getLocaleSpecificMessage(Diagnostics.Extract_constant),
                    actions: [innermostErrorConstantAction]
                });
            }
            return infos.length ? infos : emptyArray;
            function getStringError(errors) {
                let error2 = errors[0].messageText;
                if (typeof error2 !== "string") {
                    error2 = error2.messageText;
                }
                return error2;
            }
        }
        function getRefactorEditsToExtractSymbol(context, actionName2) {
            const rangeToExtract = getRangeToExtract2(context.file, getRefactorContextSpan(context));
            const targetRange = rangeToExtract.targetRange;
            const parsedFunctionIndexMatch = /^function_scope_(\d+)$/.exec(actionName2);
            if (parsedFunctionIndexMatch) {
                const index = +parsedFunctionIndexMatch[1];
                Debug.assert(isFinite(index), "Expected to parse a finite number from the function scope index");
                return getFunctionExtractionAtIndex(targetRange, context, index);
            }
            const parsedConstantIndexMatch = /^constant_scope_(\d+)$/.exec(actionName2);
            if (parsedConstantIndexMatch) {
                const index = +parsedConstantIndexMatch[1];
                Debug.assert(isFinite(index), "Expected to parse a finite number from the constant scope index");
                return getConstantExtractionAtIndex(targetRange, context, index);
            }
            Debug.fail("Unrecognized action name");
        }
        function getRangeToExtract2(sourceFile, span, invoked = true) {
            const { length: length2 } = span;
            if (length2 === 0 && !invoked) {
                return { errors: [createFileDiagnostic(sourceFile, span.start, length2, Messages.cannotExtractEmpty)] };
            }
            const cursorRequest = length2 === 0 && invoked;
            const startToken = findFirstNonJsxWhitespaceToken(sourceFile, span.start);
            const endToken = findTokenOnLeftOfPosition(sourceFile, textSpanEnd(span));
            const adjustedSpan = startToken && endToken && invoked ? getAdjustedSpanFromNodes(startToken, endToken, sourceFile) : span;
            const start = cursorRequest ? getExtractableParent(startToken) : getParentNodeInSpan(startToken, sourceFile, adjustedSpan);
            const end = cursorRequest ? start : getParentNodeInSpan(endToken, sourceFile, adjustedSpan);
            let rangeFacts = 0 /* None */;
            let thisNode;
            if (!start || !end) {
                return { errors: [createFileDiagnostic(sourceFile, span.start, length2, Messages.cannotExtractRange)] };
            }
            if (start.flags & 16777216 /* JSDoc */) {
                return { errors: [createFileDiagnostic(sourceFile, span.start, length2, Messages.cannotExtractJSDoc)] };
            }
            if (start.parent !== end.parent) {
                return { errors: [createFileDiagnostic(sourceFile, span.start, length2, Messages.cannotExtractRange)] };
            }
            if (start !== end) {
                if (!isBlockLike(start.parent)) {
                    return { errors: [createFileDiagnostic(sourceFile, span.start, length2, Messages.cannotExtractRange)] };
                }
                const statements = [];
                for (const statement of start.parent.statements) {
                    if (statement === start || statements.length) {
                        const errors2 = checkNode(statement);
                        if (errors2) {
                            return { errors: errors2 };
                        }
                        statements.push(statement);
                    }
                    if (statement === end) {
                        break;
                    }
                }
                if (!statements.length) {
                    return { errors: [createFileDiagnostic(sourceFile, span.start, length2, Messages.cannotExtractRange)] };
                }
                return { targetRange: { range: statements, facts: rangeFacts, thisNode } };
            }
            if (isReturnStatement(start) && !start.expression) {
                return { errors: [createFileDiagnostic(sourceFile, span.start, length2, Messages.cannotExtractRange)] };
            }
            const node = refineNode(start);
            const errors = checkRootNode(node) || checkNode(node);
            if (errors) {
                return { errors };
            }
            return { targetRange: { range: getStatementOrExpressionRange(node), facts: rangeFacts, thisNode } };
            function refineNode(node2) {
                if (isReturnStatement(node2)) {
                    if (node2.expression) {
                        return node2.expression;
                    }
                }
                else if (isVariableStatement(node2) || isVariableDeclarationList(node2)) {
                    const declarations = isVariableStatement(node2) ? node2.declarationList.declarations : node2.declarations;
                    let numInitializers = 0;
                    let lastInitializer;
                    for (const declaration of declarations) {
                        if (declaration.initializer) {
                            numInitializers++;
                            lastInitializer = declaration.initializer;
                        }
                    }
                    if (numInitializers === 1) {
                        return lastInitializer;
                    }
                }
                else if (isVariableDeclaration(node2)) {
                    if (node2.initializer) {
                        return node2.initializer;
                    }
                }
                return node2;
            }
            function checkRootNode(node2) {
                if (isIdentifier(isExpressionStatement(node2) ? node2.expression : node2)) {
                    return [createDiagnosticForNode(node2, Messages.cannotExtractIdentifier)];
                }
                return void 0;
            }
            function checkForStaticContext(nodeToCheck, containingClass) {
                let current = nodeToCheck;
                while (current !== containingClass) {
                    if (current.kind === 172 /* PropertyDeclaration */) {
                        if (isStatic(current)) {
                            rangeFacts |= 32 /* InStaticRegion */;
                        }
                        break;
                    }
                    else if (current.kind === 169 /* Parameter */) {
                        const ctorOrMethod = getContainingFunction(current);
                        if (ctorOrMethod.kind === 176 /* Constructor */) {
                            rangeFacts |= 32 /* InStaticRegion */;
                        }
                        break;
                    }
                    else if (current.kind === 174 /* MethodDeclaration */) {
                        if (isStatic(current)) {
                            rangeFacts |= 32 /* InStaticRegion */;
                        }
                    }
                    current = current.parent;
                }
            }
            function checkNode(nodeToCheck) {
                let PermittedJumps;
                ((PermittedJumps2) => {
                    PermittedJumps2[PermittedJumps2["None"] = 0] = "None";
                    PermittedJumps2[PermittedJumps2["Break"] = 1] = "Break";
                    PermittedJumps2[PermittedJumps2["Continue"] = 2] = "Continue";
                    PermittedJumps2[PermittedJumps2["Return"] = 4] = "Return";
                })(PermittedJumps || (PermittedJumps = {}));
                Debug.assert(nodeToCheck.pos <= nodeToCheck.end, "This failure could trigger https://github.com/Microsoft/TypeScript/issues/20809 (1)");
                Debug.assert(!positionIsSynthesized(nodeToCheck.pos), "This failure could trigger https://github.com/Microsoft/TypeScript/issues/20809 (2)");
                if (!isStatement(nodeToCheck) && !(isExpressionNode(nodeToCheck) && isExtractableExpression(nodeToCheck)) && !isStringLiteralJsxAttribute(nodeToCheck)) {
                    return [createDiagnosticForNode(nodeToCheck, Messages.statementOrExpressionExpected)];
                }
                if (nodeToCheck.flags & 33554432 /* Ambient */) {
                    return [createDiagnosticForNode(nodeToCheck, Messages.cannotExtractAmbientBlock)];
                }
                const containingClass = getContainingClass(nodeToCheck);
                if (containingClass) {
                    checkForStaticContext(nodeToCheck, containingClass);
                }
                let errors2;
                let permittedJumps = 4 /* Return */;
                let seenLabels;
                visit(nodeToCheck);
                if (rangeFacts & 8 /* UsesThis */) {
                    const container = getThisContainer(nodeToCheck, 
                    /*includeArrowFunctions*/
                    false, 
                    /*includeClassComputedPropertyName*/
                    false);
                    if (container.kind === 262 /* FunctionDeclaration */ || container.kind === 174 /* MethodDeclaration */ && container.parent.kind === 210 /* ObjectLiteralExpression */ || container.kind === 218 /* FunctionExpression */) {
                        rangeFacts |= 16 /* UsesThisInFunction */;
                    }
                }
                return errors2;
                function visit(node2) {
                    if (errors2) {
                        return true;
                    }
                    if (isDeclaration(node2)) {
                        const declaringNode = node2.kind === 260 /* VariableDeclaration */ ? node2.parent.parent : node2;
                        if (hasSyntacticModifier(declaringNode, 32 /* Export */)) {
                            (errors2 || (errors2 = [])).push(createDiagnosticForNode(node2, Messages.cannotExtractExportedEntity));
                            return true;
                        }
                    }
                    switch (node2.kind) {
                        case 272 /* ImportDeclaration */:
                            (errors2 || (errors2 = [])).push(createDiagnosticForNode(node2, Messages.cannotExtractImport));
                            return true;
                        case 277 /* ExportAssignment */:
                            (errors2 || (errors2 = [])).push(createDiagnosticForNode(node2, Messages.cannotExtractExportedEntity));
                            return true;
                        case 108 /* SuperKeyword */:
                            if (node2.parent.kind === 213 /* CallExpression */) {
                                const containingClass2 = getContainingClass(node2);
                                if (containingClass2 === void 0 || containingClass2.pos < span.start || containingClass2.end >= span.start + span.length) {
                                    (errors2 || (errors2 = [])).push(createDiagnosticForNode(node2, Messages.cannotExtractSuper));
                                    return true;
                                }
                            }
                            else {
                                rangeFacts |= 8 /* UsesThis */;
                                thisNode = node2;
                            }
                            break;
                        case 219 /* ArrowFunction */:
                            forEachChild(node2, function check(n) {
                                if (isThis(n)) {
                                    rangeFacts |= 8 /* UsesThis */;
                                    thisNode = node2;
                                }
                                else if (isClassLike(n) || isFunctionLike(n) && !isArrowFunction(n)) {
                                    return false;
                                }
                                else {
                                    forEachChild(n, check);
                                }
                            });
                        case 263 /* ClassDeclaration */:
                        case 262 /* FunctionDeclaration */:
                            if (isSourceFile(node2.parent) && node2.parent.externalModuleIndicator === void 0) {
                                (errors2 || (errors2 = [])).push(createDiagnosticForNode(node2, Messages.functionWillNotBeVisibleInTheNewScope));
                            }
                        case 231 /* ClassExpression */:
                        case 218 /* FunctionExpression */:
                        case 174 /* MethodDeclaration */:
                        case 176 /* Constructor */:
                        case 177 /* GetAccessor */:
                        case 178 /* SetAccessor */:
                            return false;
                    }
                    const savedPermittedJumps = permittedJumps;
                    switch (node2.kind) {
                        case 245 /* IfStatement */:
                            permittedJumps &= ~4 /* Return */;
                            break;
                        case 258 /* TryStatement */:
                            permittedJumps = 0 /* None */;
                            break;
                        case 241 /* Block */:
                            if (node2.parent && node2.parent.kind === 258 /* TryStatement */ && node2.parent.finallyBlock === node2) {
                                permittedJumps = 4 /* Return */;
                            }
                            break;
                        case 297 /* DefaultClause */:
                        case 296 /* CaseClause */:
                            permittedJumps |= 1 /* Break */;
                            break;
                        default:
                            if (isIterationStatement(node2, 
                            /*lookInLabeledStatements*/
                            false)) {
                                permittedJumps |= 1 /* Break */ | 2 /* Continue */;
                            }
                            break;
                    }
                    switch (node2.kind) {
                        case 197 /* ThisType */:
                        case 110 /* ThisKeyword */:
                            rangeFacts |= 8 /* UsesThis */;
                            thisNode = node2;
                            break;
                        case 256 /* LabeledStatement */: {
                            const label = node2.label;
                            (seenLabels || (seenLabels = [])).push(label.escapedText);
                            forEachChild(node2, visit);
                            seenLabels.pop();
                            break;
                        }
                        case 252 /* BreakStatement */:
                        case 251 /* ContinueStatement */: {
                            const label = node2.label;
                            if (label) {
                                if (!contains(seenLabels, label.escapedText)) {
                                    (errors2 || (errors2 = [])).push(createDiagnosticForNode(node2, Messages.cannotExtractRangeContainingLabeledBreakOrContinueStatementWithTargetOutsideOfTheRange));
                                }
                            }
                            else {
                                if (!(permittedJumps & (node2.kind === 252 /* BreakStatement */ ? 1 /* Break */ : 2 /* Continue */))) {
                                    (errors2 || (errors2 = [])).push(createDiagnosticForNode(node2, Messages.cannotExtractRangeContainingConditionalBreakOrContinueStatements));
                                }
                            }
                            break;
                        }
                        case 223 /* AwaitExpression */:
                            rangeFacts |= 4 /* IsAsyncFunction */;
                            break;
                        case 229 /* YieldExpression */:
                            rangeFacts |= 2 /* IsGenerator */;
                            break;
                        case 253 /* ReturnStatement */:
                            if (permittedJumps & 4 /* Return */) {
                                rangeFacts |= 1 /* HasReturn */;
                            }
                            else {
                                (errors2 || (errors2 = [])).push(createDiagnosticForNode(node2, Messages.cannotExtractRangeContainingConditionalReturnStatement));
                            }
                            break;
                        default:
                            forEachChild(node2, visit);
                            break;
                    }
                    permittedJumps = savedPermittedJumps;
                }
            }
        }
        function getAdjustedSpanFromNodes(startNode2, endNode2, sourceFile) {
            const start = startNode2.getStart(sourceFile);
            let end = endNode2.getEnd();
            if (sourceFile.text.charCodeAt(end) === 59 /* semicolon */) {
                end++;
            }
            return { start, length: end - start };
        }
        function getStatementOrExpressionRange(node) {
            if (isStatement(node)) {
                return [node];
            }
            if (isExpressionNode(node)) {
                return isExpressionStatement(node.parent) ? [node.parent] : node;
            }
            if (isStringLiteralJsxAttribute(node)) {
                return node;
            }
            return void 0;
        }
        function isScope(node) {
            return isArrowFunction(node) ? isFunctionBody(node.body) : isFunctionLikeDeclaration(node) || isSourceFile(node) || isModuleBlock(node) || isClassLike(node);
        }
        function collectEnclosingScopes(range) {
            let current = isReadonlyArray(range.range) ? first(range.range) : range.range;
            if (range.facts & 8 /* UsesThis */ && !(range.facts & 16 /* UsesThisInFunction */)) {
                const containingClass = getContainingClass(current);
                if (containingClass) {
                    const containingFunction = findAncestor(current, isFunctionLikeDeclaration);
                    return containingFunction ? [containingFunction, containingClass] : [containingClass];
                }
            }
            const scopes = [];
            while (true) {
                current = current.parent;
                if (current.kind === 169 /* Parameter */) {
                    current = findAncestor(current, (parent2) => isFunctionLikeDeclaration(parent2)).parent;
                }
                if (isScope(current)) {
                    scopes.push(current);
                    if (current.kind === 312 /* SourceFile */) {
                        return scopes;
                    }
                }
            }
        }
        function getFunctionExtractionAtIndex(targetRange, context, requestedChangesIndex) {
            const { scopes, readsAndWrites: { target, usagesPerScope, functionErrorsPerScope, exposedVariableDeclarations } } = getPossibleExtractionsWorker(targetRange, context);
            Debug.assert(!functionErrorsPerScope[requestedChangesIndex].length, "The extraction went missing? How?");
            context.cancellationToken.throwIfCancellationRequested();
            return extractFunctionInScope(target, scopes[requestedChangesIndex], usagesPerScope[requestedChangesIndex], exposedVariableDeclarations, targetRange, context);
        }
        function getConstantExtractionAtIndex(targetRange, context, requestedChangesIndex) {
            const { scopes, readsAndWrites: { target, usagesPerScope, constantErrorsPerScope, exposedVariableDeclarations } } = getPossibleExtractionsWorker(targetRange, context);
            Debug.assert(!constantErrorsPerScope[requestedChangesIndex].length, "The extraction went missing? How?");
            Debug.assert(exposedVariableDeclarations.length === 0, "Extract constant accepted a range containing a variable declaration?");
            context.cancellationToken.throwIfCancellationRequested();
            const expression = isExpression(target) ? target : target.statements[0].expression;
            return extractConstantInScope(expression, scopes[requestedChangesIndex], usagesPerScope[requestedChangesIndex], targetRange.facts, context);
        }
        function getPossibleExtractions(targetRange, context) {
            const { scopes, readsAndWrites: { functionErrorsPerScope, constantErrorsPerScope } } = getPossibleExtractionsWorker(targetRange, context);
            const extractions = scopes.map((scope, i) => {
                const functionDescriptionPart = getDescriptionForFunctionInScope(scope);
                const constantDescriptionPart = getDescriptionForConstantInScope(scope);
                const scopeDescription = isFunctionLikeDeclaration(scope) ? getDescriptionForFunctionLikeDeclaration(scope) : isClassLike(scope) ? getDescriptionForClassLikeDeclaration(scope) : getDescriptionForModuleLikeDeclaration(scope);
                let functionDescription;
                let constantDescription;
                if (scopeDescription === 1 /* Global */) {
                    functionDescription = formatStringFromArgs(getLocaleSpecificMessage(Diagnostics.Extract_to_0_in_1_scope), [functionDescriptionPart, "global"]);
                    constantDescription = formatStringFromArgs(getLocaleSpecificMessage(Diagnostics.Extract_to_0_in_1_scope), [constantDescriptionPart, "global"]);
                }
                else if (scopeDescription === 0 /* Module */) {
                    functionDescription = formatStringFromArgs(getLocaleSpecificMessage(Diagnostics.Extract_to_0_in_1_scope), [functionDescriptionPart, "module"]);
                    constantDescription = formatStringFromArgs(getLocaleSpecificMessage(Diagnostics.Extract_to_0_in_1_scope), [constantDescriptionPart, "module"]);
                }
                else {
                    functionDescription = formatStringFromArgs(getLocaleSpecificMessage(Diagnostics.Extract_to_0_in_1), [functionDescriptionPart, scopeDescription]);
                    constantDescription = formatStringFromArgs(getLocaleSpecificMessage(Diagnostics.Extract_to_0_in_1), [constantDescriptionPart, scopeDescription]);
                }
                if (i === 0 && !isClassLike(scope)) {
                    constantDescription = formatStringFromArgs(getLocaleSpecificMessage(Diagnostics.Extract_to_0_in_enclosing_scope), [constantDescriptionPart]);
                }
                return {
                    functionExtraction: {
                        description: functionDescription,
                        errors: functionErrorsPerScope[i]
                    },
                    constantExtraction: {
                        description: constantDescription,
                        errors: constantErrorsPerScope[i]
                    }
                };
            });
            return extractions;
        }
        function getPossibleExtractionsWorker(targetRange, context) {
            const { file: sourceFile } = context;
            const scopes = collectEnclosingScopes(targetRange);
            const enclosingTextRange = getEnclosingTextRange(targetRange, sourceFile);
            const readsAndWrites = collectReadsAndWrites(targetRange, scopes, enclosingTextRange, sourceFile, context.program.getTypeChecker(), context.cancellationToken);
            return { scopes, readsAndWrites };
        }
        function getDescriptionForFunctionInScope(scope) {
            return isFunctionLikeDeclaration(scope) ? "inner function" : isClassLike(scope) ? "method" : "function";
        }
        function getDescriptionForConstantInScope(scope) {
            return isClassLike(scope) ? "readonly field" : "constant";
        }
        function getDescriptionForFunctionLikeDeclaration(scope) {
            switch (scope.kind) {
                case 176 /* Constructor */:
                    return "constructor";
                case 218 /* FunctionExpression */:
                case 262 /* FunctionDeclaration */:
                    return scope.name ? `function '${scope.name.text}'` : ANONYMOUS;
                case 219 /* ArrowFunction */:
                    return "arrow function";
                case 174 /* MethodDeclaration */:
                    return `method '${scope.name.getText()}'`;
                case 177 /* GetAccessor */:
                    return `'get ${scope.name.getText()}'`;
                case 178 /* SetAccessor */:
                    return `'set ${scope.name.getText()}'`;
                default:
                    Debug.assertNever(scope, `Unexpected scope kind ${scope.kind}`);
            }
        }
        function getDescriptionForClassLikeDeclaration(scope) {
            return scope.kind === 263 /* ClassDeclaration */ ? scope.name ? `class '${scope.name.text}'` : "anonymous class declaration" : scope.name ? `class expression '${scope.name.text}'` : "anonymous class expression";
        }
        function getDescriptionForModuleLikeDeclaration(scope) {
            return scope.kind === 268 /* ModuleBlock */ ? `namespace '${scope.parent.name.getText()}'` : scope.externalModuleIndicator ? 0 /* Module */ : 1 /* Global */;
        }
        function extractFunctionInScope(node, scope, { usages: usagesInScope, typeParameterUsages, substitutions }, exposedVariableDeclarations, range, context) {
            const checker = context.program.getTypeChecker();
            const scriptTarget = getEmitScriptTarget(context.program.getCompilerOptions());
            const importAdder = ts_codefix_exports.createImportAdder(context.file, context.program, context.preferences, context.host);
            const file = scope.getSourceFile();
            const functionNameText = getUniqueName(isClassLike(scope) ? "newMethod" : "newFunction", file);
            const isJS = isInJSFile(scope);
            const functionName = factory.createIdentifier(functionNameText);
            let returnType;
            const parameters = [];
            const callArguments = [];
            let writes;
            usagesInScope.forEach((usage, name) => {
                let typeNode;
                if (!isJS) {
                    let type = checker.getTypeOfSymbolAtLocation(usage.symbol, usage.node);
                    type = checker.getBaseTypeOfLiteralType(type);
                    typeNode = ts_codefix_exports.typeToAutoImportableTypeNode(checker, importAdder, type, scope, scriptTarget, 1 /* NoTruncation */);
                }
                const paramDecl = factory.createParameterDeclaration(
                /*modifiers*/
                void 0, 
                /*dotDotDotToken*/
                void 0, 
                /*name*/
                name, 
                /*questionToken*/
                void 0, typeNode);
                parameters.push(paramDecl);
                if (usage.usage === 2 /* Write */) {
                    (writes || (writes = [])).push(usage);
                }
                callArguments.push(factory.createIdentifier(name));
            });
            const typeParametersAndDeclarations = arrayFrom(typeParameterUsages.values(), (type) => ({ type, declaration: getFirstDeclarationBeforePosition(type, context.startPosition) }));
            const sortedTypeParametersAndDeclarations = typeParametersAndDeclarations.sort(compareTypesByDeclarationOrder);
            const typeParameters = sortedTypeParametersAndDeclarations.length === 0 ? void 0 : mapDefined(sortedTypeParametersAndDeclarations, ({ declaration }) => declaration);
            const callTypeArguments = typeParameters !== void 0 ? typeParameters.map((decl) => factory.createTypeReferenceNode(decl.name, 
            /*typeArguments*/
            void 0)) : void 0;
            if (isExpression(node) && !isJS) {
                const contextualType = checker.getContextualType(node);
                returnType = checker.typeToTypeNode(contextualType, scope, 1 /* NoTruncation */);
            }
            const { body, returnValueProperty } = transformFunctionBody(node, exposedVariableDeclarations, writes, substitutions, !!(range.facts & 1 /* HasReturn */));
            suppressLeadingAndTrailingTrivia(body);
            let newFunction;
            const callThis = !!(range.facts & 16 /* UsesThisInFunction */);
            if (isClassLike(scope)) {
                const modifiers = isJS ? [] : [factory.createModifier(123 /* PrivateKeyword */)];
                if (range.facts & 32 /* InStaticRegion */) {
                    modifiers.push(factory.createModifier(126 /* StaticKeyword */));
                }
                if (range.facts & 4 /* IsAsyncFunction */) {
                    modifiers.push(factory.createModifier(134 /* AsyncKeyword */));
                }
                newFunction = factory.createMethodDeclaration(modifiers.length ? modifiers : void 0, range.facts & 2 /* IsGenerator */ ? factory.createToken(42 /* AsteriskToken */) : void 0, functionName, 
                /*questionToken*/
                void 0, typeParameters, parameters, returnType, body);
            }
            else {
                if (callThis) {
                    parameters.unshift(factory.createParameterDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*dotDotDotToken*/
                    void 0, 
                    /*name*/
                    "this", 
                    /*questionToken*/
                    void 0, checker.typeToTypeNode(checker.getTypeAtLocation(range.thisNode), scope, 1 /* NoTruncation */), 
                    /*initializer*/
                    void 0));
                }
                newFunction = factory.createFunctionDeclaration(range.facts & 4 /* IsAsyncFunction */ ? [factory.createToken(134 /* AsyncKeyword */)] : void 0, range.facts & 2 /* IsGenerator */ ? factory.createToken(42 /* AsteriskToken */) : void 0, functionName, typeParameters, parameters, returnType, body);
            }
            const changeTracker = ts_textChanges_exports.ChangeTracker.fromContext(context);
            const minInsertionPos = (isReadonlyArray(range.range) ? last(range.range) : range.range).end;
            const nodeToInsertBefore = getNodeToInsertFunctionBefore(minInsertionPos, scope);
            if (nodeToInsertBefore) {
                changeTracker.insertNodeBefore(context.file, nodeToInsertBefore, newFunction, 
                /*blankLineBetween*/
                true);
            }
            else {
                changeTracker.insertNodeAtEndOfScope(context.file, scope, newFunction);
            }
            importAdder.writeFixes(changeTracker);
            const newNodes = [];
            const called = getCalledExpression(scope, range, functionNameText);
            if (callThis) {
                callArguments.unshift(factory.createIdentifier("this"));
            }
            let call = factory.createCallExpression(callThis ? factory.createPropertyAccessExpression(called, "call") : called, callTypeArguments, 
            // Note that no attempt is made to take advantage of type argument inference
            callArguments);
            if (range.facts & 2 /* IsGenerator */) {
                call = factory.createYieldExpression(factory.createToken(42 /* AsteriskToken */), call);
            }
            if (range.facts & 4 /* IsAsyncFunction */) {
                call = factory.createAwaitExpression(call);
            }
            if (isInJSXContent(node)) {
                call = factory.createJsxExpression(
                /*dotDotDotToken*/
                void 0, call);
            }
            if (exposedVariableDeclarations.length && !writes) {
                Debug.assert(!returnValueProperty, "Expected no returnValueProperty");
                Debug.assert(!(range.facts & 1 /* HasReturn */), "Expected RangeFacts.HasReturn flag to be unset");
                if (exposedVariableDeclarations.length === 1) {
                    const variableDeclaration = exposedVariableDeclarations[0];
                    newNodes.push(factory.createVariableStatement(
                    /*modifiers*/
                    void 0, factory.createVariableDeclarationList([factory.createVariableDeclaration(getSynthesizedDeepClone(variableDeclaration.name), 
                        /*exclamationToken*/
                        void 0, 
                        /*type*/
                        getSynthesizedDeepClone(variableDeclaration.type), 
                        /*initializer*/
                        call)], variableDeclaration.parent.flags)));
                }
                else {
                    const bindingElements = [];
                    const typeElements = [];
                    let commonNodeFlags = exposedVariableDeclarations[0].parent.flags;
                    let sawExplicitType = false;
                    for (const variableDeclaration of exposedVariableDeclarations) {
                        bindingElements.push(factory.createBindingElement(
                        /*dotDotDotToken*/
                        void 0, 
                        /*propertyName*/
                        void 0, 
                        /*name*/
                        getSynthesizedDeepClone(variableDeclaration.name)));
                        const variableType = checker.typeToTypeNode(checker.getBaseTypeOfLiteralType(checker.getTypeAtLocation(variableDeclaration)), scope, 1 /* NoTruncation */);
                        typeElements.push(factory.createPropertySignature(
                        /*modifiers*/
                        void 0, 
                        /*name*/
                        variableDeclaration.symbol.name, 
                        /*questionToken*/
                        void 0, 
                        /*type*/
                        variableType));
                        sawExplicitType = sawExplicitType || variableDeclaration.type !== void 0;
                        commonNodeFlags = commonNodeFlags & variableDeclaration.parent.flags;
                    }
                    const typeLiteral = sawExplicitType ? factory.createTypeLiteralNode(typeElements) : void 0;
                    if (typeLiteral) {
                        setEmitFlags(typeLiteral, 1 /* SingleLine */);
                    }
                    newNodes.push(factory.createVariableStatement(
                    /*modifiers*/
                    void 0, factory.createVariableDeclarationList([factory.createVariableDeclaration(factory.createObjectBindingPattern(bindingElements), 
                        /*exclamationToken*/
                        void 0, 
                        /*type*/
                        typeLiteral, 
                        /*initializer*/
                        call)], commonNodeFlags)));
                }
            }
            else if (exposedVariableDeclarations.length || writes) {
                if (exposedVariableDeclarations.length) {
                    for (const variableDeclaration of exposedVariableDeclarations) {
                        let flags = variableDeclaration.parent.flags;
                        if (flags & 2 /* Const */) {
                            flags = flags & ~2 /* Const */ | 1 /* Let */;
                        }
                        newNodes.push(factory.createVariableStatement(
                        /*modifiers*/
                        void 0, factory.createVariableDeclarationList([factory.createVariableDeclaration(variableDeclaration.symbol.name, 
                            /*exclamationToken*/
                            void 0, getTypeDeepCloneUnionUndefined(variableDeclaration.type))], flags)));
                    }
                }
                if (returnValueProperty) {
                    newNodes.push(factory.createVariableStatement(
                    /*modifiers*/
                    void 0, factory.createVariableDeclarationList([factory.createVariableDeclaration(returnValueProperty, 
                        /*exclamationToken*/
                        void 0, getTypeDeepCloneUnionUndefined(returnType))], 1 /* Let */)));
                }
                const assignments = getPropertyAssignmentsForWritesAndVariableDeclarations(exposedVariableDeclarations, writes);
                if (returnValueProperty) {
                    assignments.unshift(factory.createShorthandPropertyAssignment(returnValueProperty));
                }
                if (assignments.length === 1) {
                    Debug.assert(!returnValueProperty, "Shouldn't have returnValueProperty here");
                    newNodes.push(factory.createExpressionStatement(factory.createAssignment(assignments[0].name, call)));
                    if (range.facts & 1 /* HasReturn */) {
                        newNodes.push(factory.createReturnStatement());
                    }
                }
                else {
                    newNodes.push(factory.createExpressionStatement(factory.createAssignment(factory.createObjectLiteralExpression(assignments), call)));
                    if (returnValueProperty) {
                        newNodes.push(factory.createReturnStatement(factory.createIdentifier(returnValueProperty)));
                    }
                }
            }
            else {
                if (range.facts & 1 /* HasReturn */) {
                    newNodes.push(factory.createReturnStatement(call));
                }
                else if (isReadonlyArray(range.range)) {
                    newNodes.push(factory.createExpressionStatement(call));
                }
                else {
                    newNodes.push(call);
                }
            }
            if (isReadonlyArray(range.range)) {
                changeTracker.replaceNodeRangeWithNodes(context.file, first(range.range), last(range.range), newNodes);
            }
            else {
                changeTracker.replaceNodeWithNodes(context.file, range.range, newNodes);
            }
            const edits = changeTracker.getChanges();
            const renameRange = isReadonlyArray(range.range) ? first(range.range) : range.range;
            const renameFilename = renameRange.getSourceFile().fileName;
            const renameLocation = getRenameLocation(edits, renameFilename, functionNameText, 
            /*preferLastLocation*/
            false);
            return { renameFilename, renameLocation, edits };
            function getTypeDeepCloneUnionUndefined(typeNode) {
                if (typeNode === void 0) {
                    return void 0;
                }
                const clone2 = getSynthesizedDeepClone(typeNode);
                let withoutParens = clone2;
                while (isParenthesizedTypeNode(withoutParens)) {
                    withoutParens = withoutParens.type;
                }
                return isUnionTypeNode(withoutParens) && find(withoutParens.types, (t) => t.kind === 157 /* UndefinedKeyword */) ? clone2 : factory.createUnionTypeNode([clone2, factory.createKeywordTypeNode(157 /* UndefinedKeyword */)]);
            }
        }
        function extractConstantInScope(node, scope, { substitutions }, rangeFacts, context) {
            const checker = context.program.getTypeChecker();
            const file = scope.getSourceFile();
            const localNameText = isPropertyAccessExpression(node) && !isClassLike(scope) && !checker.resolveName(node.name.text, node, 111551 /* Value */, 
            /*excludeGlobals*/
            false) && !isPrivateIdentifier(node.name) && !identifierToKeywordKind(node.name) ? node.name.text : getUniqueName(isClassLike(scope) ? "newProperty" : "newLocal", file);
            const isJS = isInJSFile(scope);
            let variableType = isJS || !checker.isContextSensitive(node) ? void 0 : checker.typeToTypeNode(checker.getContextualType(node), scope, 1 /* NoTruncation */);
            let initializer = transformConstantInitializer(skipParentheses(node), substitutions);
            ({ variableType, initializer } = transformFunctionInitializerAndType(variableType, initializer));
            suppressLeadingAndTrailingTrivia(initializer);
            const changeTracker = ts_textChanges_exports.ChangeTracker.fromContext(context);
            if (isClassLike(scope)) {
                Debug.assert(!isJS, "Cannot extract to a JS class");
                const modifiers = [];
                modifiers.push(factory.createModifier(123 /* PrivateKeyword */));
                if (rangeFacts & 32 /* InStaticRegion */) {
                    modifiers.push(factory.createModifier(126 /* StaticKeyword */));
                }
                modifiers.push(factory.createModifier(148 /* ReadonlyKeyword */));
                const newVariable = factory.createPropertyDeclaration(modifiers, localNameText, 
                /*questionOrExclamationToken*/
                void 0, variableType, initializer);
                let localReference = factory.createPropertyAccessExpression(rangeFacts & 32 /* InStaticRegion */ ? factory.createIdentifier(scope.name.getText()) : factory.createThis(), factory.createIdentifier(localNameText));
                if (isInJSXContent(node)) {
                    localReference = factory.createJsxExpression(
                    /*dotDotDotToken*/
                    void 0, localReference);
                }
                const maxInsertionPos = node.pos;
                const nodeToInsertBefore = getNodeToInsertPropertyBefore(maxInsertionPos, scope);
                changeTracker.insertNodeBefore(context.file, nodeToInsertBefore, newVariable, 
                /*blankLineBetween*/
                true);
                changeTracker.replaceNode(context.file, node, localReference);
            }
            else {
                const newVariableDeclaration = factory.createVariableDeclaration(localNameText, 
                /*exclamationToken*/
                void 0, variableType, initializer);
                const oldVariableDeclaration = getContainingVariableDeclarationIfInList(node, scope);
                if (oldVariableDeclaration) {
                    changeTracker.insertNodeBefore(context.file, oldVariableDeclaration, newVariableDeclaration);
                    const localReference = factory.createIdentifier(localNameText);
                    changeTracker.replaceNode(context.file, node, localReference);
                }
                else if (node.parent.kind === 244 /* ExpressionStatement */ && scope === findAncestor(node, isScope)) {
                    const newVariableStatement = factory.createVariableStatement(
                    /*modifiers*/
                    void 0, factory.createVariableDeclarationList([newVariableDeclaration], 2 /* Const */));
                    changeTracker.replaceNode(context.file, node.parent, newVariableStatement);
                }
                else {
                    const newVariableStatement = factory.createVariableStatement(
                    /*modifiers*/
                    void 0, factory.createVariableDeclarationList([newVariableDeclaration], 2 /* Const */));
                    const nodeToInsertBefore = getNodeToInsertConstantBefore(node, scope);
                    if (nodeToInsertBefore.pos === 0) {
                        changeTracker.insertNodeAtTopOfFile(context.file, newVariableStatement, 
                        /*blankLineBetween*/
                        false);
                    }
                    else {
                        changeTracker.insertNodeBefore(context.file, nodeToInsertBefore, newVariableStatement, 
                        /*blankLineBetween*/
                        false);
                    }
                    if (node.parent.kind === 244 /* ExpressionStatement */) {
                        changeTracker.delete(context.file, node.parent);
                    }
                    else {
                        let localReference = factory.createIdentifier(localNameText);
                        if (isInJSXContent(node)) {
                            localReference = factory.createJsxExpression(
                            /*dotDotDotToken*/
                            void 0, localReference);
                        }
                        changeTracker.replaceNode(context.file, node, localReference);
                    }
                }
            }
            const edits = changeTracker.getChanges();
            const renameFilename = node.getSourceFile().fileName;
            const renameLocation = getRenameLocation(edits, renameFilename, localNameText, 
            /*preferLastLocation*/
            true);
            return { renameFilename, renameLocation, edits };
            function transformFunctionInitializerAndType(variableType2, initializer2) {
                if (variableType2 === void 0)
                    return { variableType: variableType2, initializer: initializer2 };
                if (!isFunctionExpression(initializer2) && !isArrowFunction(initializer2) || !!initializer2.typeParameters)
                    return { variableType: variableType2, initializer: initializer2 };
                const functionType = checker.getTypeAtLocation(node);
                const functionSignature = singleOrUndefined(checker.getSignaturesOfType(functionType, 0 /* Call */));
                if (!functionSignature)
                    return { variableType: variableType2, initializer: initializer2 };
                if (!!functionSignature.getTypeParameters())
                    return { variableType: variableType2, initializer: initializer2 };
                const parameters = [];
                let hasAny = false;
                for (const p of initializer2.parameters) {
                    if (p.type) {
                        parameters.push(p);
                    }
                    else {
                        const paramType = checker.getTypeAtLocation(p);
                        if (paramType === checker.getAnyType())
                            hasAny = true;
                        parameters.push(factory.updateParameterDeclaration(p, p.modifiers, p.dotDotDotToken, p.name, p.questionToken, p.type || checker.typeToTypeNode(paramType, scope, 1 /* NoTruncation */), p.initializer));
                    }
                }
                if (hasAny)
                    return { variableType: variableType2, initializer: initializer2 };
                variableType2 = void 0;
                if (isArrowFunction(initializer2)) {
                    initializer2 = factory.updateArrowFunction(initializer2, canHaveModifiers(node) ? getModifiers(node) : void 0, initializer2.typeParameters, parameters, initializer2.type || checker.typeToTypeNode(functionSignature.getReturnType(), scope, 1 /* NoTruncation */), initializer2.equalsGreaterThanToken, initializer2.body);
                }
                else {
                    if (functionSignature && !!functionSignature.thisParameter) {
                        const firstParameter = firstOrUndefined(parameters);
                        if (!firstParameter || isIdentifier(firstParameter.name) && firstParameter.name.escapedText !== "this") {
                            const thisType = checker.getTypeOfSymbolAtLocation(functionSignature.thisParameter, node);
                            parameters.splice(0, 0, factory.createParameterDeclaration(
                            /*modifiers*/
                            void 0, 
                            /*dotDotDotToken*/
                            void 0, "this", 
                            /*questionToken*/
                            void 0, checker.typeToTypeNode(thisType, scope, 1 /* NoTruncation */)));
                        }
                    }
                    initializer2 = factory.updateFunctionExpression(initializer2, canHaveModifiers(node) ? getModifiers(node) : void 0, initializer2.asteriskToken, initializer2.name, initializer2.typeParameters, parameters, initializer2.type || checker.typeToTypeNode(functionSignature.getReturnType(), scope, 1 /* NoTruncation */), initializer2.body);
                }
                return { variableType: variableType2, initializer: initializer2 };
            }
        }
        function getContainingVariableDeclarationIfInList(node, scope) {
            let prevNode;
            while (node !== void 0 && node !== scope) {
                if (isVariableDeclaration(node) && node.initializer === prevNode && isVariableDeclarationList(node.parent) && node.parent.declarations.length > 1) {
                    return node;
                }
                prevNode = node;
                node = node.parent;
            }
        }
        function getFirstDeclarationBeforePosition(type, position) {
            let firstDeclaration;
            const symbol = type.symbol;
            if (symbol && symbol.declarations) {
                for (const declaration of symbol.declarations) {
                    if ((firstDeclaration === void 0 || declaration.pos < firstDeclaration.pos) && declaration.pos < position) {
                        firstDeclaration = declaration;
                    }
                }
            }
            return firstDeclaration;
        }
        function compareTypesByDeclarationOrder({ type: type1, declaration: declaration1 }, { type: type2, declaration: declaration2 }) {
            return compareProperties(declaration1, declaration2, "pos", compareValues) || compareStringsCaseSensitive(type1.symbol ? type1.symbol.getName() : "", type2.symbol ? type2.symbol.getName() : "") || compareValues(type1.id, type2.id);
        }
        function getCalledExpression(scope, range, functionNameText) {
            const functionReference = factory.createIdentifier(functionNameText);
            if (isClassLike(scope)) {
                const lhs = range.facts & 32 /* InStaticRegion */ ? factory.createIdentifier(scope.name.text) : factory.createThis();
                return factory.createPropertyAccessExpression(lhs, functionReference);
            }
            else {
                return functionReference;
            }
        }
        function transformFunctionBody(body, exposedVariableDeclarations, writes, substitutions, hasReturn2) {
            const hasWritesOrVariableDeclarations = writes !== void 0 || exposedVariableDeclarations.length > 0;
            if (isBlock(body) && !hasWritesOrVariableDeclarations && substitutions.size === 0) {
                return { body: factory.createBlock(body.statements, 
                    /*multiLine*/
                    true), returnValueProperty: void 0 };
            }
            let returnValueProperty;
            let ignoreReturns = false;
            const statements = factory.createNodeArray(isBlock(body) ? body.statements.slice(0) : [isStatement(body) ? body : factory.createReturnStatement(skipParentheses(body))]);
            if (hasWritesOrVariableDeclarations || substitutions.size) {
                const rewrittenStatements = visitNodes2(statements, visitor, isStatement).slice();
                if (hasWritesOrVariableDeclarations && !hasReturn2 && isStatement(body)) {
                    const assignments = getPropertyAssignmentsForWritesAndVariableDeclarations(exposedVariableDeclarations, writes);
                    if (assignments.length === 1) {
                        rewrittenStatements.push(factory.createReturnStatement(assignments[0].name));
                    }
                    else {
                        rewrittenStatements.push(factory.createReturnStatement(factory.createObjectLiteralExpression(assignments)));
                    }
                }
                return { body: factory.createBlock(rewrittenStatements, 
                    /*multiLine*/
                    true), returnValueProperty };
            }
            else {
                return { body: factory.createBlock(statements, 
                    /*multiLine*/
                    true), returnValueProperty: void 0 };
            }
            function visitor(node) {
                if (!ignoreReturns && isReturnStatement(node) && hasWritesOrVariableDeclarations) {
                    const assignments = getPropertyAssignmentsForWritesAndVariableDeclarations(exposedVariableDeclarations, writes);
                    if (node.expression) {
                        if (!returnValueProperty) {
                            returnValueProperty = "__return";
                        }
                        assignments.unshift(factory.createPropertyAssignment(returnValueProperty, visitNode(node.expression, visitor, isExpression)));
                    }
                    if (assignments.length === 1) {
                        return factory.createReturnStatement(assignments[0].name);
                    }
                    else {
                        return factory.createReturnStatement(factory.createObjectLiteralExpression(assignments));
                    }
                }
                else {
                    const oldIgnoreReturns = ignoreReturns;
                    ignoreReturns = ignoreReturns || isFunctionLikeDeclaration(node) || isClassLike(node);
                    const substitution = substitutions.get(getNodeId(node).toString());
                    const result = substitution ? getSynthesizedDeepClone(substitution) : visitEachChild(node, visitor, 
                    /*context*/
                    void 0);
                    ignoreReturns = oldIgnoreReturns;
                    return result;
                }
            }
        }
        function transformConstantInitializer(initializer, substitutions) {
            return substitutions.size ? visitor(initializer) : initializer;
            function visitor(node) {
                const substitution = substitutions.get(getNodeId(node).toString());
                return substitution ? getSynthesizedDeepClone(substitution) : visitEachChild(node, visitor, 
                /*context*/
                void 0);
            }
        }
        function getStatementsOrClassElements(scope) {
            if (isFunctionLikeDeclaration(scope)) {
                const body = scope.body;
                if (isBlock(body)) {
                    return body.statements;
                }
            }
            else if (isModuleBlock(scope) || isSourceFile(scope)) {
                return scope.statements;
            }
            else if (isClassLike(scope)) {
                return scope.members;
            }
            else {
                assertType(scope);
            }
            return emptyArray;
        }
        function getNodeToInsertFunctionBefore(minPos, scope) {
            return find(getStatementsOrClassElements(scope), (child) => child.pos >= minPos && isFunctionLikeDeclaration(child) && !isConstructorDeclaration(child));
        }
        function getNodeToInsertPropertyBefore(maxPos, scope) {
            const members = scope.members;
            Debug.assert(members.length > 0, "Found no members");
            let prevMember;
            let allProperties = true;
            for (const member of members) {
                if (member.pos > maxPos) {
                    return prevMember || members[0];
                }
                if (allProperties && !isPropertyDeclaration(member)) {
                    if (prevMember !== void 0) {
                        return member;
                    }
                    allProperties = false;
                }
                prevMember = member;
            }
            if (prevMember === void 0)
                return Debug.fail();
            return prevMember;
        }
        function getNodeToInsertConstantBefore(node, scope) {
            Debug.assert(!isClassLike(scope));
            let prevScope;
            for (let curr = node; curr !== scope; curr = curr.parent) {
                if (isScope(curr)) {
                    prevScope = curr;
                }
            }
            for (let curr = (prevScope || node).parent;; curr = curr.parent) {
                if (isBlockLike(curr)) {
                    let prevStatement;
                    for (const statement of curr.statements) {
                        if (statement.pos > node.pos) {
                            break;
                        }
                        prevStatement = statement;
                    }
                    if (!prevStatement && isCaseClause(curr)) {
                        Debug.assert(isSwitchStatement(curr.parent.parent), "Grandparent isn't a switch statement");
                        return curr.parent.parent;
                    }
                    return Debug.checkDefined(prevStatement, "prevStatement failed to get set");
                }
                Debug.assert(curr !== scope, "Didn't encounter a block-like before encountering scope");
            }
        }
        function getPropertyAssignmentsForWritesAndVariableDeclarations(exposedVariableDeclarations, writes) {
            const variableAssignments = map(exposedVariableDeclarations, (v) => factory.createShorthandPropertyAssignment(v.symbol.name));
            const writeAssignments = map(writes, (w) => factory.createShorthandPropertyAssignment(w.symbol.name));
            return variableAssignments === void 0 ? writeAssignments : writeAssignments === void 0 ? variableAssignments : variableAssignments.concat(writeAssignments);
        }
        function isReadonlyArray(v) {
            return isArray(v);
        }
        function getEnclosingTextRange(targetRange, sourceFile) {
            return isReadonlyArray(targetRange.range) ? { pos: first(targetRange.range).getStart(sourceFile), end: last(targetRange.range).getEnd() } : targetRange.range;
        }
        function collectReadsAndWrites(targetRange, scopes, enclosingTextRange, sourceFile, checker, cancellationToken) {
            const allTypeParameterUsages = /* @__PURE__ */ new Map();
            const usagesPerScope = [];
            const substitutionsPerScope = [];
            const functionErrorsPerScope = [];
            const constantErrorsPerScope = [];
            const visibleDeclarationsInExtractedRange = [];
            const exposedVariableSymbolSet = /* @__PURE__ */ new Map();
            const exposedVariableDeclarations = [];
            let firstExposedNonVariableDeclaration;
            const expression = !isReadonlyArray(targetRange.range) ? targetRange.range : targetRange.range.length === 1 && isExpressionStatement(targetRange.range[0]) ? targetRange.range[0].expression : void 0;
            let expressionDiagnostic;
            if (expression === void 0) {
                const statements = targetRange.range;
                const start = first(statements).getStart();
                const end = last(statements).end;
                expressionDiagnostic = createFileDiagnostic(sourceFile, start, end - start, Messages.expressionExpected);
            }
            else if (checker.getTypeAtLocation(expression).flags & (16384 /* Void */ | 131072 /* Never */)) {
                expressionDiagnostic = createDiagnosticForNode(expression, Messages.uselessConstantType);
            }
            for (const scope of scopes) {
                usagesPerScope.push({ usages: /* @__PURE__ */ new Map(), typeParameterUsages: /* @__PURE__ */ new Map(), substitutions: /* @__PURE__ */ new Map() });
                substitutionsPerScope.push(/* @__PURE__ */ new Map());
                functionErrorsPerScope.push([]);
                const constantErrors = [];
                if (expressionDiagnostic) {
                    constantErrors.push(expressionDiagnostic);
                }
                if (isClassLike(scope) && isInJSFile(scope)) {
                    constantErrors.push(createDiagnosticForNode(scope, Messages.cannotExtractToJSClass));
                }
                if (isArrowFunction(scope) && !isBlock(scope.body)) {
                    constantErrors.push(createDiagnosticForNode(scope, Messages.cannotExtractToExpressionArrowFunction));
                }
                constantErrorsPerScope.push(constantErrors);
            }
            const seenUsages = /* @__PURE__ */ new Map();
            const target = isReadonlyArray(targetRange.range) ? factory.createBlock(targetRange.range) : targetRange.range;
            const unmodifiedNode = isReadonlyArray(targetRange.range) ? first(targetRange.range) : targetRange.range;
            const inGenericContext = isInGenericContext(unmodifiedNode);
            collectUsages(target);
            if (inGenericContext && !isReadonlyArray(targetRange.range) && !isJsxAttribute(targetRange.range)) {
                const contextualType = checker.getContextualType(targetRange.range);
                recordTypeParameterUsages(contextualType);
            }
            if (allTypeParameterUsages.size > 0) {
                const seenTypeParameterUsages = /* @__PURE__ */ new Map();
                let i = 0;
                for (let curr = unmodifiedNode; curr !== void 0 && i < scopes.length; curr = curr.parent) {
                    if (curr === scopes[i]) {
                        seenTypeParameterUsages.forEach((typeParameter, id) => {
                            usagesPerScope[i].typeParameterUsages.set(id, typeParameter);
                        });
                        i++;
                    }
                    if (isDeclarationWithTypeParameters(curr)) {
                        for (const typeParameterDecl of getEffectiveTypeParameterDeclarations(curr)) {
                            const typeParameter = checker.getTypeAtLocation(typeParameterDecl);
                            if (allTypeParameterUsages.has(typeParameter.id.toString())) {
                                seenTypeParameterUsages.set(typeParameter.id.toString(), typeParameter);
                            }
                        }
                    }
                }
                Debug.assert(i === scopes.length, "Should have iterated all scopes");
            }
            if (visibleDeclarationsInExtractedRange.length) {
                const containingLexicalScopeOfExtraction = isBlockScope(scopes[0], scopes[0].parent) ? scopes[0] : getEnclosingBlockScopeContainer(scopes[0]);
                forEachChild(containingLexicalScopeOfExtraction, checkForUsedDeclarations);
            }
            for (let i = 0; i < scopes.length; i++) {
                const scopeUsages = usagesPerScope[i];
                if (i > 0 && (scopeUsages.usages.size > 0 || scopeUsages.typeParameterUsages.size > 0)) {
                    const errorNode = isReadonlyArray(targetRange.range) ? targetRange.range[0] : targetRange.range;
                    constantErrorsPerScope[i].push(createDiagnosticForNode(errorNode, Messages.cannotAccessVariablesFromNestedScopes));
                }
                if (targetRange.facts & 16 /* UsesThisInFunction */ && isClassLike(scopes[i])) {
                    functionErrorsPerScope[i].push(createDiagnosticForNode(targetRange.thisNode, Messages.cannotExtractFunctionsContainingThisToMethod));
                }
                let hasWrite = false;
                let readonlyClassPropertyWrite;
                usagesPerScope[i].usages.forEach((value) => {
                    if (value.usage === 2 /* Write */) {
                        hasWrite = true;
                        if (value.symbol.flags & 106500 /* ClassMember */ && value.symbol.valueDeclaration && hasEffectiveModifier(value.symbol.valueDeclaration, 8 /* Readonly */)) {
                            readonlyClassPropertyWrite = value.symbol.valueDeclaration;
                        }
                    }
                });
                Debug.assert(isReadonlyArray(targetRange.range) || exposedVariableDeclarations.length === 0, "No variable declarations expected if something was extracted");
                if (hasWrite && !isReadonlyArray(targetRange.range)) {
                    const diag2 = createDiagnosticForNode(targetRange.range, Messages.cannotWriteInExpression);
                    functionErrorsPerScope[i].push(diag2);
                    constantErrorsPerScope[i].push(diag2);
                }
                else if (readonlyClassPropertyWrite && i > 0) {
                    const diag2 = createDiagnosticForNode(readonlyClassPropertyWrite, Messages.cannotExtractReadonlyPropertyInitializerOutsideConstructor);
                    functionErrorsPerScope[i].push(diag2);
                    constantErrorsPerScope[i].push(diag2);
                }
                else if (firstExposedNonVariableDeclaration) {
                    const diag2 = createDiagnosticForNode(firstExposedNonVariableDeclaration, Messages.cannotExtractExportedEntity);
                    functionErrorsPerScope[i].push(diag2);
                    constantErrorsPerScope[i].push(diag2);
                }
            }
            return { target, usagesPerScope, functionErrorsPerScope, constantErrorsPerScope, exposedVariableDeclarations };
            function isInGenericContext(node) {
                return !!findAncestor(node, (n) => isDeclarationWithTypeParameters(n) && getEffectiveTypeParameterDeclarations(n).length !== 0);
            }
            function recordTypeParameterUsages(type) {
                const symbolWalker = checker.getSymbolWalker(() => (cancellationToken.throwIfCancellationRequested(), true));
                const { visitedTypes } = symbolWalker.walkType(type);
                for (const visitedType of visitedTypes) {
                    if (visitedType.isTypeParameter()) {
                        allTypeParameterUsages.set(visitedType.id.toString(), visitedType);
                    }
                }
            }
            function collectUsages(node, valueUsage = 1 /* Read */) {
                if (inGenericContext) {
                    const type = checker.getTypeAtLocation(node);
                    recordTypeParameterUsages(type);
                }
                if (isDeclaration(node) && node.symbol) {
                    visibleDeclarationsInExtractedRange.push(node);
                }
                if (isAssignmentExpression(node)) {
                    collectUsages(node.left, 2 /* Write */);
                    collectUsages(node.right);
                }
                else if (isUnaryExpressionWithWrite(node)) {
                    collectUsages(node.operand, 2 /* Write */);
                }
                else if (isPropertyAccessExpression(node) || isElementAccessExpression(node)) {
                    forEachChild(node, collectUsages);
                }
                else if (isIdentifier(node)) {
                    if (!node.parent) {
                        return;
                    }
                    if (isQualifiedName(node.parent) && node !== node.parent.left) {
                        return;
                    }
                    if (isPropertyAccessExpression(node.parent) && node !== node.parent.expression) {
                        return;
                    }
                    recordUsage(node, valueUsage, 
                    /*isTypeNode*/
                    isPartOfTypeNode(node));
                }
                else {
                    forEachChild(node, collectUsages);
                }
            }
            function recordUsage(n, usage, isTypeNode2) {
                const symbolId = recordUsagebySymbol(n, usage, isTypeNode2);
                if (symbolId) {
                    for (let i = 0; i < scopes.length; i++) {
                        const substitution = substitutionsPerScope[i].get(symbolId);
                        if (substitution) {
                            usagesPerScope[i].substitutions.set(getNodeId(n).toString(), substitution);
                        }
                    }
                }
            }
            function recordUsagebySymbol(identifier, usage, isTypeName) {
                const symbol = getSymbolReferencedByIdentifier(identifier);
                if (!symbol) {
                    return void 0;
                }
                const symbolId = getSymbolId(symbol).toString();
                const lastUsage = seenUsages.get(symbolId);
                if (lastUsage && lastUsage >= usage) {
                    return symbolId;
                }
                seenUsages.set(symbolId, usage);
                if (lastUsage) {
                    for (const perScope of usagesPerScope) {
                        const prevEntry = perScope.usages.get(identifier.text);
                        if (prevEntry) {
                            perScope.usages.set(identifier.text, { usage, symbol, node: identifier });
                        }
                    }
                    return symbolId;
                }
                const decls = symbol.getDeclarations();
                const declInFile = decls && find(decls, (d) => d.getSourceFile() === sourceFile);
                if (!declInFile) {
                    return void 0;
                }
                if (rangeContainsStartEnd(enclosingTextRange, declInFile.getStart(), declInFile.end)) {
                    return void 0;
                }
                if (targetRange.facts & 2 /* IsGenerator */ && usage === 2 /* Write */) {
                    const diag2 = createDiagnosticForNode(identifier, Messages.cannotExtractRangeThatContainsWritesToReferencesLocatedOutsideOfTheTargetRangeInGenerators);
                    for (const errors of functionErrorsPerScope) {
                        errors.push(diag2);
                    }
                    for (const errors of constantErrorsPerScope) {
                        errors.push(diag2);
                    }
                }
                for (let i = 0; i < scopes.length; i++) {
                    const scope = scopes[i];
                    const resolvedSymbol = checker.resolveName(symbol.name, scope, symbol.flags, 
                    /*excludeGlobals*/
                    false);
                    if (resolvedSymbol === symbol) {
                        continue;
                    }
                    if (!substitutionsPerScope[i].has(symbolId)) {
                        const substitution = tryReplaceWithQualifiedNameOrPropertyAccess(symbol.exportSymbol || symbol, scope, isTypeName);
                        if (substitution) {
                            substitutionsPerScope[i].set(symbolId, substitution);
                        }
                        else if (isTypeName) {
                            if (!(symbol.flags & 262144 /* TypeParameter */)) {
                                const diag2 = createDiagnosticForNode(identifier, Messages.typeWillNotBeVisibleInTheNewScope);
                                functionErrorsPerScope[i].push(diag2);
                                constantErrorsPerScope[i].push(diag2);
                            }
                        }
                        else {
                            usagesPerScope[i].usages.set(identifier.text, { usage, symbol, node: identifier });
                        }
                    }
                }
                return symbolId;
            }
            function checkForUsedDeclarations(node) {
                if (node === targetRange.range || isReadonlyArray(targetRange.range) && targetRange.range.includes(node)) {
                    return;
                }
                const sym = isIdentifier(node) ? getSymbolReferencedByIdentifier(node) : checker.getSymbolAtLocation(node);
                if (sym) {
                    const decl = find(visibleDeclarationsInExtractedRange, (d) => d.symbol === sym);
                    if (decl) {
                        if (isVariableDeclaration(decl)) {
                            const idString = decl.symbol.id.toString();
                            if (!exposedVariableSymbolSet.has(idString)) {
                                exposedVariableDeclarations.push(decl);
                                exposedVariableSymbolSet.set(idString, true);
                            }
                        }
                        else {
                            firstExposedNonVariableDeclaration = firstExposedNonVariableDeclaration || decl;
                        }
                    }
                }
                forEachChild(node, checkForUsedDeclarations);
            }
            function getSymbolReferencedByIdentifier(identifier) {
                return identifier.parent && isShorthandPropertyAssignment(identifier.parent) && identifier.parent.name === identifier ? checker.getShorthandAssignmentValueSymbol(identifier.parent) : checker.getSymbolAtLocation(identifier);
            }
            function tryReplaceWithQualifiedNameOrPropertyAccess(symbol, scopeDecl, isTypeNode2) {
                if (!symbol) {
                    return void 0;
                }
                const decls = symbol.getDeclarations();
                if (decls && decls.some((d) => d.parent === scopeDecl)) {
                    return factory.createIdentifier(symbol.name);
                }
                const prefix = tryReplaceWithQualifiedNameOrPropertyAccess(symbol.parent, scopeDecl, isTypeNode2);
                if (prefix === void 0) {
                    return void 0;
                }
                return isTypeNode2 ? factory.createQualifiedName(prefix, factory.createIdentifier(symbol.name)) : factory.createPropertyAccessExpression(prefix, symbol.name);
            }
        }
        function getExtractableParent(node) {
            return findAncestor(node, (node2) => node2.parent && isExtractableExpression(node2) && !isBinaryExpression(node2.parent));
        }
        function isExtractableExpression(node) {
            const { parent: parent2 } = node;
            switch (parent2.kind) {
                case 306 /* EnumMember */:
                    return false;
            }
            switch (node.kind) {
                case 11 /* StringLiteral */:
                    return parent2.kind !== 272 /* ImportDeclaration */ && parent2.kind !== 276 /* ImportSpecifier */;
                case 230 /* SpreadElement */:
                case 206 /* ObjectBindingPattern */:
                case 208 /* BindingElement */:
                    return false;
                case 80 /* Identifier */:
                    return parent2.kind !== 208 /* BindingElement */ && parent2.kind !== 276 /* ImportSpecifier */ && parent2.kind !== 281 /* ExportSpecifier */;
            }
            return true;
        }
        function isBlockLike(node) {
            switch (node.kind) {
                case 241 /* Block */:
                case 312 /* SourceFile */:
                case 268 /* ModuleBlock */:
                case 296 /* CaseClause */:
                    return true;
                default:
                    return false;
            }
        }
        function isInJSXContent(node) {
            return isStringLiteralJsxAttribute(node) || (isJsxElement(node) || isJsxSelfClosingElement(node) || isJsxFragment(node)) && (isJsxElement(node.parent) || isJsxFragment(node.parent));
        }
        function isStringLiteralJsxAttribute(node) {
            return isStringLiteral(node) && node.parent && isJsxAttribute(node.parent);
        }
        var refactorName12, extractConstantAction, extractFunctionAction, Messages, RangeFacts;
        var init_extractSymbol = __esm({
            "src/services/refactors/extractSymbol.ts"() {
                "use strict";
                init_ts4();
                init_ts_refactor();
                refactorName12 = "Extract Symbol";
                extractConstantAction = {
                    name: "Extract Constant",
                    description: getLocaleSpecificMessage(Diagnostics.Extract_constant),
                    kind: "refactor.extract.constant"
                };
                extractFunctionAction = {
                    name: "Extract Function",
                    description: getLocaleSpecificMessage(Diagnostics.Extract_function),
                    kind: "refactor.extract.function"
                };
                registerRefactor(refactorName12, {
                    kinds: [
                        extractConstantAction.kind,
                        extractFunctionAction.kind
                    ],
                    getEditsForAction: getRefactorEditsToExtractSymbol,
                    getAvailableActions: getRefactorActionsToExtractSymbol
                });
                ((Messages2) => {
                    function createMessage(message) {
                        return { message, code: 0, category: 3 /* Message */, key: message };
                    }
                    Messages2.cannotExtractRange = createMessage("Cannot extract range.");
                    Messages2.cannotExtractImport = createMessage("Cannot extract import statement.");
                    Messages2.cannotExtractSuper = createMessage("Cannot extract super call.");
                    Messages2.cannotExtractJSDoc = createMessage("Cannot extract JSDoc.");
                    Messages2.cannotExtractEmpty = createMessage("Cannot extract empty range.");
                    Messages2.expressionExpected = createMessage("expression expected.");
                    Messages2.uselessConstantType = createMessage("No reason to extract constant of type.");
                    Messages2.statementOrExpressionExpected = createMessage("Statement or expression expected.");
                    Messages2.cannotExtractRangeContainingConditionalBreakOrContinueStatements = createMessage("Cannot extract range containing conditional break or continue statements.");
                    Messages2.cannotExtractRangeContainingConditionalReturnStatement = createMessage("Cannot extract range containing conditional return statement.");
                    Messages2.cannotExtractRangeContainingLabeledBreakOrContinueStatementWithTargetOutsideOfTheRange = createMessage("Cannot extract range containing labeled break or continue with target outside of the range.");
                    Messages2.cannotExtractRangeThatContainsWritesToReferencesLocatedOutsideOfTheTargetRangeInGenerators = createMessage("Cannot extract range containing writes to references located outside of the target range in generators.");
                    Messages2.typeWillNotBeVisibleInTheNewScope = createMessage("Type will not visible in the new scope.");
                    Messages2.functionWillNotBeVisibleInTheNewScope = createMessage("Function will not visible in the new scope.");
                    Messages2.cannotExtractIdentifier = createMessage("Select more than a single identifier.");
                    Messages2.cannotExtractExportedEntity = createMessage("Cannot extract exported declaration");
                    Messages2.cannotWriteInExpression = createMessage("Cannot write back side-effects when extracting an expression");
                    Messages2.cannotExtractReadonlyPropertyInitializerOutsideConstructor = createMessage("Cannot move initialization of read-only class property outside of the constructor");
                    Messages2.cannotExtractAmbientBlock = createMessage("Cannot extract code from ambient contexts");
                    Messages2.cannotAccessVariablesFromNestedScopes = createMessage("Cannot access variables from nested scopes");
                    Messages2.cannotExtractToJSClass = createMessage("Cannot extract constant to a class scope in JS");
                    Messages2.cannotExtractToExpressionArrowFunction = createMessage("Cannot extract constant to an arrow function without a block");
                    Messages2.cannotExtractFunctionsContainingThisToMethod = createMessage("Cannot extract functions containing this to method");
                })(Messages || (Messages = {}));
                RangeFacts = /* @__PURE__ */ ((RangeFacts2) => {
                    RangeFacts2[RangeFacts2["None"] = 0] = "None";
                    RangeFacts2[RangeFacts2["HasReturn"] = 1] = "HasReturn";
                    RangeFacts2[RangeFacts2["IsGenerator"] = 2] = "IsGenerator";
                    RangeFacts2[RangeFacts2["IsAsyncFunction"] = 4] = "IsAsyncFunction";
                    RangeFacts2[RangeFacts2["UsesThis"] = 8] = "UsesThis";
                    RangeFacts2[RangeFacts2["UsesThisInFunction"] = 16] = "UsesThisInFunction";
                    RangeFacts2[RangeFacts2["InStaticRegion"] = 32] = "InStaticRegion";
                    return RangeFacts2;
                })(RangeFacts || {});
            }
        });
        // src/services/_namespaces/ts.refactor.extractSymbol.ts
        var ts_refactor_extractSymbol_exports = {};
        __export(ts_refactor_extractSymbol_exports, {
            Messages: () => Messages,
            RangeFacts: () => RangeFacts,
            getRangeToExtract: () => getRangeToExtract2,
            getRefactorActionsToExtractSymbol: () => getRefactorActionsToExtractSymbol,
            getRefactorEditsToExtractSymbol: () => getRefactorEditsToExtractSymbol
        });
        var init_ts_refactor_extractSymbol = __esm({
            "src/services/_namespaces/ts.refactor.extractSymbol.ts"() {
                "use strict";
                init_extractSymbol();
            }
        });
        // src/services/refactors/generateGetAccessorAndSetAccessor.ts
        var actionName, actionDescription, generateGetSetAction;
        var init_generateGetAccessorAndSetAccessor = __esm({
            "src/services/refactors/generateGetAccessorAndSetAccessor.ts"() {
                "use strict";
                init_ts4();
                init_ts_refactor();
                actionName = "Generate 'get' and 'set' accessors";
                actionDescription = getLocaleSpecificMessage(Diagnostics.Generate_get_and_set_accessors);
                generateGetSetAction = {
                    name: actionName,
                    description: actionDescription,
                    kind: "refactor.rewrite.property.generateAccessors"
                };
                registerRefactor(actionName, {
                    kinds: [generateGetSetAction.kind],
                    getEditsForAction: function getRefactorActionsToGenerateGetAndSetAccessors(context, actionName2) {
                        if (!context.endPosition)
                            return void 0;
                        const info = ts_codefix_exports.getAccessorConvertiblePropertyAtPosition(context.file, context.program, context.startPosition, context.endPosition);
                        Debug.assert(info && !isRefactorErrorInfo(info), "Expected applicable refactor info");
                        const edits = ts_codefix_exports.generateAccessorFromProperty(context.file, context.program, context.startPosition, context.endPosition, context, actionName2);
                        if (!edits)
                            return void 0;
                        const renameFilename = context.file.fileName;
                        const nameNeedRename = info.renameAccessor ? info.accessorName : info.fieldName;
                        const renameLocationOffset = isIdentifier(nameNeedRename) ? 0 : -1;
                        const renameLocation = renameLocationOffset + getRenameLocation(edits, renameFilename, nameNeedRename.text, 
                        /*preferLastLocation*/
                        isParameter(info.declaration));
                        return { renameFilename, renameLocation, edits };
                    },
                    getAvailableActions(context) {
                        if (!context.endPosition)
                            return emptyArray;
                        const info = ts_codefix_exports.getAccessorConvertiblePropertyAtPosition(context.file, context.program, context.startPosition, context.endPosition, context.triggerReason === "invoked");
                        if (!info)
                            return emptyArray;
                        if (!isRefactorErrorInfo(info)) {
                            return [{
                                    name: actionName,
                                    description: actionDescription,
                                    actions: [generateGetSetAction]
                                }];
                        }
                        if (context.preferences.provideRefactorNotApplicableReason) {
                            return [{
                                    name: actionName,
                                    description: actionDescription,
                                    actions: [{ ...generateGetSetAction, notApplicableReason: info.error }]
                                }];
                        }
                        return emptyArray;
                    }
                });
            }
        });
        // src/services/_namespaces/ts.refactor.generateGetAccessorAndSetAccessor.ts
        var ts_refactor_generateGetAccessorAndSetAccessor_exports = {};
        var init_ts_refactor_generateGetAccessorAndSetAccessor = __esm({
            "src/services/_namespaces/ts.refactor.generateGetAccessorAndSetAccessor.ts"() {
                "use strict";
                init_generateGetAccessorAndSetAccessor();
            }
        });
        // src/services/refactors/inferFunctionReturnType.ts
        function getRefactorEditsToInferReturnType(context) {
            const info = getInfo4(context);
            if (info && !isRefactorErrorInfo(info)) {
                const edits = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange7(context.file, t, info.declaration, info.returnTypeNode));
                return { renameFilename: void 0, renameLocation: void 0, edits };
            }
            return void 0;
        }
        function getRefactorActionsToInferReturnType(context) {
            const info = getInfo4(context);
            if (!info)
                return emptyArray;
            if (!isRefactorErrorInfo(info)) {
                return [{
                        name: refactorName13,
                        description: refactorDescription7,
                        actions: [inferReturnTypeAction]
                    }];
            }
            if (context.preferences.provideRefactorNotApplicableReason) {
                return [{
                        name: refactorName13,
                        description: refactorDescription7,
                        actions: [{ ...inferReturnTypeAction, notApplicableReason: info.error }]
                    }];
            }
            return emptyArray;
        }
        function doChange7(sourceFile, changes, declaration, typeNode) {
            const closeParen = findChildOfKind(declaration, 22 /* CloseParenToken */, sourceFile);
            const needParens = isArrowFunction(declaration) && closeParen === void 0;
            const endNode2 = needParens ? first(declaration.parameters) : closeParen;
            if (endNode2) {
                if (needParens) {
                    changes.insertNodeBefore(sourceFile, endNode2, factory.createToken(21 /* OpenParenToken */));
                    changes.insertNodeAfter(sourceFile, endNode2, factory.createToken(22 /* CloseParenToken */));
                }
                changes.insertNodeAt(sourceFile, endNode2.end, typeNode, { prefix: ": " });
            }
        }
        function getInfo4(context) {
            if (isInJSFile(context.file) || !refactorKindBeginsWith(inferReturnTypeAction.kind, context.kind))
                return;
            const token = getTouchingPropertyName(context.file, context.startPosition);
            const declaration = findAncestor(token, (n) => isBlock(n) || n.parent && isArrowFunction(n.parent) && (n.kind === 39 /* EqualsGreaterThanToken */ || n.parent.body === n) ? "quit" : isConvertibleDeclaration(n));
            if (!declaration || !declaration.body || declaration.type) {
                return { error: getLocaleSpecificMessage(Diagnostics.Return_type_must_be_inferred_from_a_function) };
            }
            const typeChecker = context.program.getTypeChecker();
            const returnType = tryGetReturnType(typeChecker, declaration);
            if (!returnType) {
                return { error: getLocaleSpecificMessage(Diagnostics.Could_not_determine_function_return_type) };
            }
            const returnTypeNode = typeChecker.typeToTypeNode(returnType, declaration, 1 /* NoTruncation */);
            if (returnTypeNode) {
                return { declaration, returnTypeNode };
            }
        }
        function isConvertibleDeclaration(node) {
            switch (node.kind) {
                case 262 /* FunctionDeclaration */:
                case 218 /* FunctionExpression */:
                case 219 /* ArrowFunction */:
                case 174 /* MethodDeclaration */:
                    return true;
                default:
                    return false;
            }
        }
        function tryGetReturnType(typeChecker, node) {
            if (typeChecker.isImplementationOfOverload(node)) {
                const signatures = typeChecker.getTypeAtLocation(node).getCallSignatures();
                if (signatures.length > 1) {
                    return typeChecker.getUnionType(mapDefined(signatures, (s) => s.getReturnType()));
                }
            }
            const signature = typeChecker.getSignatureFromDeclaration(node);
            if (signature) {
                return typeChecker.getReturnTypeOfSignature(signature);
            }
        }
        var refactorName13, refactorDescription7, inferReturnTypeAction;
        var init_inferFunctionReturnType = __esm({
            "src/services/refactors/inferFunctionReturnType.ts"() {
                "use strict";
                init_ts4();
                init_ts_refactor();
                refactorName13 = "Infer function return type";
                refactorDescription7 = getLocaleSpecificMessage(Diagnostics.Infer_function_return_type);
                inferReturnTypeAction = {
                    name: refactorName13,
                    description: refactorDescription7,
                    kind: "refactor.rewrite.function.returnType"
                };
                registerRefactor(refactorName13, {
                    kinds: [inferReturnTypeAction.kind],
                    getEditsForAction: getRefactorEditsToInferReturnType,
                    getAvailableActions: getRefactorActionsToInferReturnType
                });
            }
        });
        // src/services/_namespaces/ts.refactor.inferFunctionReturnType.ts
        var ts_refactor_inferFunctionReturnType_exports = {};
        var init_ts_refactor_inferFunctionReturnType = __esm({
            "src/services/_namespaces/ts.refactor.inferFunctionReturnType.ts"() {
                "use strict";
                init_inferFunctionReturnType();
            }
        });
        // src/services/_namespaces/ts.refactor.ts
        var ts_refactor_exports = {};
        __export(ts_refactor_exports, {
            addExportToChanges: () => addExportToChanges,
            addExports: () => addExports,
            addNewFileToTsconfig: () => addNewFileToTsconfig,
            addOrRemoveBracesToArrowFunction: () => ts_refactor_addOrRemoveBracesToArrowFunction_exports,
            containsJsx: () => containsJsx,
            convertArrowFunctionOrFunctionExpression: () => ts_refactor_convertArrowFunctionOrFunctionExpression_exports,
            convertParamsToDestructuredObject: () => ts_refactor_convertParamsToDestructuredObject_exports,
            convertStringOrTemplateLiteral: () => ts_refactor_convertStringOrTemplateLiteral_exports,
            convertToOptionalChainExpression: () => ts_refactor_convertToOptionalChainExpression_exports,
            createNewFileName: () => createNewFileName,
            createOldFileImportsFromTargetFile: () => createOldFileImportsFromTargetFile,
            deleteMovedStatements: () => deleteMovedStatements,
            deleteUnusedImports: () => deleteUnusedImports,
            deleteUnusedOldImports: () => deleteUnusedOldImports,
            doChangeNamedToNamespaceOrDefault: () => doChangeNamedToNamespaceOrDefault,
            extractSymbol: () => ts_refactor_extractSymbol_exports,
            filterImport: () => filterImport,
            forEachImportInStatement: () => forEachImportInStatement,
            generateGetAccessorAndSetAccessor: () => ts_refactor_generateGetAccessorAndSetAccessor_exports,
            getApplicableRefactors: () => getApplicableRefactors,
            getEditsForRefactor: () => getEditsForRefactor,
            getStatementsToMove: () => getStatementsToMove,
            getTopLevelDeclarationStatement: () => getTopLevelDeclarationStatement,
            getUsageInfo: () => getUsageInfo,
            inferFunctionReturnType: () => ts_refactor_inferFunctionReturnType_exports,
            isRefactorErrorInfo: () => isRefactorErrorInfo,
            isTopLevelDeclaration: () => isTopLevelDeclaration,
            makeImportOrRequire: () => makeImportOrRequire,
            moduleSpecifierFromImport: () => moduleSpecifierFromImport,
            nameOfTopLevelDeclaration: () => nameOfTopLevelDeclaration,
            refactorKindBeginsWith: () => refactorKindBeginsWith,
            registerRefactor: () => registerRefactor,
            updateImportsInOtherFiles: () => updateImportsInOtherFiles
        });
        var init_ts_refactor = __esm({
            "src/services/_namespaces/ts.refactor.ts"() {
                "use strict";
                init_refactorProvider();
                init_convertExport();
                init_convertImport();
                init_extractType();
                init_helpers();
                init_inlineVariable();
                init_moveToNewFile();
                init_moveToFile();
                init_ts_refactor_addOrRemoveBracesToArrowFunction();
                init_ts_refactor_convertArrowFunctionOrFunctionExpression();
                init_ts_refactor_convertParamsToDestructuredObject();
                init_ts_refactor_convertStringOrTemplateLiteral();
                init_ts_refactor_convertToOptionalChainExpression();
                init_ts_refactor_extractSymbol();
                init_ts_refactor_generateGetAccessorAndSetAccessor();
                init_ts_refactor_inferFunctionReturnType();
            }
        });
        // src/services/classifier2020.ts
        function getSemanticClassifications2(program, cancellationToken, sourceFile, span) {
            const classifications = getEncodedSemanticClassifications2(program, cancellationToken, sourceFile, span);
            Debug.assert(classifications.spans.length % 3 === 0);
            const dense = classifications.spans;
            const result = [];
            for (let i = 0; i < dense.length; i += 3) {
                result.push({
                    textSpan: createTextSpan(dense[i], dense[i + 1]),
                    classificationType: dense[i + 2]
                });
            }
            return result;
        }
        function getEncodedSemanticClassifications2(program, cancellationToken, sourceFile, span) {
            return {
                spans: getSemanticTokens(program, sourceFile, span, cancellationToken),
                endOfLineState: 0 /* None */
            };
        }
        function getSemanticTokens(program, sourceFile, span, cancellationToken) {
            const resultTokens = [];
            const collector = (node, typeIdx, modifierSet) => {
                resultTokens.push(node.getStart(sourceFile), node.getWidth(sourceFile), (typeIdx + 1 << 8 /* typeOffset */) + modifierSet);
            };
            if (program && sourceFile) {
                collectTokens(program, sourceFile, span, collector, cancellationToken);
            }
            return resultTokens;
        }
        function collectTokens(program, sourceFile, span, collector, cancellationToken) {
            const typeChecker = program.getTypeChecker();
            let inJSXElement = false;
            function visit(node) {
                switch (node.kind) {
                    case 267 /* ModuleDeclaration */:
                    case 263 /* ClassDeclaration */:
                    case 264 /* InterfaceDeclaration */:
                    case 262 /* FunctionDeclaration */:
                    case 231 /* ClassExpression */:
                    case 218 /* FunctionExpression */:
                    case 219 /* ArrowFunction */:
                        cancellationToken.throwIfCancellationRequested();
                }
                if (!node || !textSpanIntersectsWith(span, node.pos, node.getFullWidth()) || node.getFullWidth() === 0) {
                    return;
                }
                const prevInJSXElement = inJSXElement;
                if (isJsxElement(node) || isJsxSelfClosingElement(node)) {
                    inJSXElement = true;
                }
                if (isJsxExpression(node)) {
                    inJSXElement = false;
                }
                if (isIdentifier(node) && !inJSXElement && !inImportClause(node) && !isInfinityOrNaNString(node.escapedText)) {
                    let symbol = typeChecker.getSymbolAtLocation(node);
                    if (symbol) {
                        if (symbol.flags & 2097152 /* Alias */) {
                            symbol = typeChecker.getAliasedSymbol(symbol);
                        }
                        let typeIdx = classifySymbol2(symbol, getMeaningFromLocation(node));
                        if (typeIdx !== void 0) {
                            let modifierSet = 0;
                            if (node.parent) {
                                const parentIsDeclaration = isBindingElement(node.parent) || tokenFromDeclarationMapping.get(node.parent.kind) === typeIdx;
                                if (parentIsDeclaration && node.parent.name === node) {
                                    modifierSet = 1 << 0 /* declaration */;
                                }
                            }
                            if (typeIdx === 6 /* parameter */ && isRightSideOfQualifiedNameOrPropertyAccess2(node)) {
                                typeIdx = 9 /* property */;
                            }
                            typeIdx = reclassifyByType(typeChecker, node, typeIdx);
                            const decl = symbol.valueDeclaration;
                            if (decl) {
                                const modifiers = getCombinedModifierFlags(decl);
                                const nodeFlags = getCombinedNodeFlags(decl);
                                if (modifiers & 256 /* Static */) {
                                    modifierSet |= 1 << 1 /* static */;
                                }
                                if (modifiers & 1024 /* Async */) {
                                    modifierSet |= 1 << 2 /* async */;
                                }
                                if (typeIdx !== 0 /* class */ && typeIdx !== 2 /* interface */) {
                                    if (modifiers & 8 /* Readonly */ || nodeFlags & 2 /* Const */ || symbol.getFlags() & 8 /* EnumMember */) {
                                        modifierSet |= 1 << 3 /* readonly */;
                                    }
                                }
                                if ((typeIdx === 7 /* variable */ || typeIdx === 10 /* function */) && isLocalDeclaration(decl, sourceFile)) {
                                    modifierSet |= 1 << 5 /* local */;
                                }
                                if (program.isSourceFileDefaultLibrary(decl.getSourceFile())) {
                                    modifierSet |= 1 << 4 /* defaultLibrary */;
                                }
                            }
                            else if (symbol.declarations && symbol.declarations.some((d) => program.isSourceFileDefaultLibrary(d.getSourceFile()))) {
                                modifierSet |= 1 << 4 /* defaultLibrary */;
                            }
                            collector(node, typeIdx, modifierSet);
                        }
                    }
                }
                forEachChild(node, visit);
                inJSXElement = prevInJSXElement;
            }
            visit(sourceFile);
        }
        function classifySymbol2(symbol, meaning) {
            const flags = symbol.getFlags();
            if (flags & 32 /* Class */) {
                return 0 /* class */;
            }
            else if (flags & 384 /* Enum */) {
                return 1 /* enum */;
            }
            else if (flags & 524288 /* TypeAlias */) {
                return 5 /* type */;
            }
            else if (flags & 64 /* Interface */) {
                if (meaning & 2 /* Type */) {
                    return 2 /* interface */;
                }
            }
            else if (flags & 262144 /* TypeParameter */) {
                return 4 /* typeParameter */;
            }
            let decl = symbol.valueDeclaration || symbol.declarations && symbol.declarations[0];
            if (decl && isBindingElement(decl)) {
                decl = getDeclarationForBindingElement(decl);
            }
            return decl && tokenFromDeclarationMapping.get(decl.kind);
        }
        function reclassifyByType(typeChecker, node, typeIdx) {
            if (typeIdx === 7 /* variable */ || typeIdx === 9 /* property */ || typeIdx === 6 /* parameter */) {
                const type = typeChecker.getTypeAtLocation(node);
                if (type) {
                    const test = (condition) => {
                        return condition(type) || type.isUnion() && type.types.some(condition);
                    };
                    if (typeIdx !== 6 /* parameter */ && test((t) => t.getConstructSignatures().length > 0)) {
                        return 0 /* class */;
                    }
                    if (test((t) => t.getCallSignatures().length > 0) && !test((t) => t.getProperties().length > 0) || isExpressionInCallExpression(node)) {
                        return typeIdx === 9 /* property */ ? 11 /* member */ : 10 /* function */;
                    }
                }
            }
            return typeIdx;
        }
        function isLocalDeclaration(decl, sourceFile) {
            if (isBindingElement(decl)) {
                decl = getDeclarationForBindingElement(decl);
            }
            if (isVariableDeclaration(decl)) {
                return (!isSourceFile(decl.parent.parent.parent) || isCatchClause(decl.parent)) && decl.getSourceFile() === sourceFile;
            }
            else if (isFunctionDeclaration(decl)) {
                return !isSourceFile(decl.parent) && decl.getSourceFile() === sourceFile;
            }
            return false;
        }
        function getDeclarationForBindingElement(element) {
            while (true) {
                if (isBindingElement(element.parent.parent)) {
                    element = element.parent.parent;
                }
                else {
                    return element.parent.parent;
                }
            }
        }
        function inImportClause(node) {
            const parent2 = node.parent;
            return parent2 && (isImportClause(parent2) || isImportSpecifier(parent2) || isNamespaceImport(parent2));
        }
        function isExpressionInCallExpression(node) {
            while (isRightSideOfQualifiedNameOrPropertyAccess2(node)) {
                node = node.parent;
            }
            return isCallExpression(node.parent) && node.parent.expression === node;
        }
        function isRightSideOfQualifiedNameOrPropertyAccess2(node) {
            return isQualifiedName(node.parent) && node.parent.right === node || isPropertyAccessExpression(node.parent) && node.parent.name === node;
        }
        var TokenEncodingConsts, TokenType, TokenModifier, tokenFromDeclarationMapping;
        var init_classifier2020 = __esm({
            "src/services/classifier2020.ts"() {
                "use strict";
                init_ts4();
                TokenEncodingConsts = /* @__PURE__ */ ((TokenEncodingConsts2) => {
                    TokenEncodingConsts2[TokenEncodingConsts2["typeOffset"] = 8] = "typeOffset";
                    TokenEncodingConsts2[TokenEncodingConsts2["modifierMask"] = 255] = "modifierMask";
                    return TokenEncodingConsts2;
                })(TokenEncodingConsts || {});
                TokenType = /* @__PURE__ */ ((TokenType2) => {
                    TokenType2[TokenType2["class"] = 0] = "class";
                    TokenType2[TokenType2["enum"] = 1] = "enum";
                    TokenType2[TokenType2["interface"] = 2] = "interface";
                    TokenType2[TokenType2["namespace"] = 3] = "namespace";
                    TokenType2[TokenType2["typeParameter"] = 4] = "typeParameter";
                    TokenType2[TokenType2["type"] = 5] = "type";
                    TokenType2[TokenType2["parameter"] = 6] = "parameter";
                    TokenType2[TokenType2["variable"] = 7] = "variable";
                    TokenType2[TokenType2["enumMember"] = 8] = "enumMember";
                    TokenType2[TokenType2["property"] = 9] = "property";
                    TokenType2[TokenType2["function"] = 10] = "function";
                    TokenType2[TokenType2["member"] = 11] = "member";
                    return TokenType2;
                })(TokenType || {});
                TokenModifier = /* @__PURE__ */ ((TokenModifier2) => {
                    TokenModifier2[TokenModifier2["declaration"] = 0] = "declaration";
                    TokenModifier2[TokenModifier2["static"] = 1] = "static";
                    TokenModifier2[TokenModifier2["async"] = 2] = "async";
                    TokenModifier2[TokenModifier2["readonly"] = 3] = "readonly";
                    TokenModifier2[TokenModifier2["defaultLibrary"] = 4] = "defaultLibrary";
                    TokenModifier2[TokenModifier2["local"] = 5] = "local";
                    return TokenModifier2;
                })(TokenModifier || {});
                tokenFromDeclarationMapping = /* @__PURE__ */ new Map([
                    [260 /* VariableDeclaration */, 7 /* variable */],
                    [169 /* Parameter */, 6 /* parameter */],
                    [172 /* PropertyDeclaration */, 9 /* property */],
                    [267 /* ModuleDeclaration */, 3 /* namespace */],
                    [266 /* EnumDeclaration */, 1 /* enum */],
                    [306 /* EnumMember */, 8 /* enumMember */],
                    [263 /* ClassDeclaration */, 0 /* class */],
                    [174 /* MethodDeclaration */, 11 /* member */],
                    [262 /* FunctionDeclaration */, 10 /* function */],
                    [218 /* FunctionExpression */, 10 /* function */],
                    [173 /* MethodSignature */, 11 /* member */],
                    [177 /* GetAccessor */, 9 /* property */],
                    [178 /* SetAccessor */, 9 /* property */],
                    [171 /* PropertySignature */, 9 /* property */],
                    [264 /* InterfaceDeclaration */, 2 /* interface */],
                    [265 /* TypeAliasDeclaration */, 5 /* type */],
                    [168 /* TypeParameter */, 4 /* typeParameter */],
                    [303 /* PropertyAssignment */, 9 /* property */],
                    [304 /* ShorthandPropertyAssignment */, 9 /* property */]
                ]);
            }
        });
        // src/services/services.ts
        function createNode(kind, pos, end, parent2) {
            const node = isNodeKind(kind) ? new NodeObject(kind, pos, end) : kind === 80 /* Identifier */ ? new IdentifierObject(80 /* Identifier */, pos, end) : kind === 81 /* PrivateIdentifier */ ? new PrivateIdentifierObject(81 /* PrivateIdentifier */, pos, end) : new TokenObject(kind, pos, end);
            node.parent = parent2;
            node.flags = parent2.flags & 101441536 /* ContextFlags */;
            return node;
        }
        function createChildren(node, sourceFile) {
            if (!isNodeKind(node.kind)) {
                return emptyArray;
            }
            const children = [];
            if (isJSDocCommentContainingNode(node)) {
                node.forEachChild((child) => {
                    children.push(child);
                });
                return children;
            }
            scanner.setText((sourceFile || node.getSourceFile()).text);
            let pos = node.pos;
            const processNode = (child) => {
                addSyntheticNodes(children, pos, child.pos, node);
                children.push(child);
                pos = child.end;
            };
            const processNodes = (nodes) => {
                addSyntheticNodes(children, pos, nodes.pos, node);
                children.push(createSyntaxList(nodes, node));
                pos = nodes.end;
            };
            forEach(node.jsDoc, processNode);
            pos = node.pos;
            node.forEachChild(processNode, processNodes);
            addSyntheticNodes(children, pos, node.end, node);
            scanner.setText(void 0);
            return children;
        }
        function addSyntheticNodes(nodes, pos, end, parent2) {
            scanner.resetTokenState(pos);
            while (pos < end) {
                const token = scanner.scan();
                const textPos = scanner.getTokenEnd();
                if (textPos <= end) {
                    if (token === 80 /* Identifier */) {
                        if (hasTabstop(parent2)) {
                            continue;
                        }
                        Debug.fail(`Did not expect ${Debug.formatSyntaxKind(parent2.kind)} to have an Identifier in its trivia`);
                    }
                    nodes.push(createNode(token, pos, textPos, parent2));
                }
                pos = textPos;
                if (token === 1 /* EndOfFileToken */) {
                    break;
                }
            }
        }
        function createSyntaxList(nodes, parent2) {
            const list = createNode(358 /* SyntaxList */, nodes.pos, nodes.end, parent2);
            list._children = [];
            let pos = nodes.pos;
            for (const node of nodes) {
                addSyntheticNodes(list._children, pos, node.pos, parent2);
                list._children.push(node);
                pos = node.end;
            }
            addSyntheticNodes(list._children, pos, nodes.end, parent2);
            return list;
        }
        function hasJSDocInheritDocTag(node) {
            return getJSDocTags(node).some((tag) => tag.tagName.text === "inheritDoc" || tag.tagName.text === "inheritdoc");
        }
        function getJsDocTagsOfDeclarations(declarations, checker) {
            if (!declarations)
                return emptyArray;
            let tags = ts_JsDoc_exports.getJsDocTagsFromDeclarations(declarations, checker);
            if (checker && (tags.length === 0 || declarations.some(hasJSDocInheritDocTag))) {
                const seenSymbols = /* @__PURE__ */ new Set();
                for (const declaration of declarations) {
                    const inheritedTags = findBaseOfDeclaration(checker, declaration, (symbol) => {
                        var _a;
                        if (!seenSymbols.has(symbol)) {
                            seenSymbols.add(symbol);
                            if (declaration.kind === 177 /* GetAccessor */ || declaration.kind === 178 /* SetAccessor */) {
                                return symbol.getContextualJsDocTags(declaration, checker);
                            }
                            return ((_a = symbol.declarations) == null ? void 0 : _a.length) === 1 ? symbol.getJsDocTags() : void 0;
                        }
                    });
                    if (inheritedTags) {
                        tags = [...inheritedTags, ...tags];
                    }
                }
            }
            return tags;
        }
        function getDocumentationComment(declarations, checker) {
            if (!declarations)
                return emptyArray;
            let doc = ts_JsDoc_exports.getJsDocCommentsFromDeclarations(declarations, checker);
            if (checker && (doc.length === 0 || declarations.some(hasJSDocInheritDocTag))) {
                const seenSymbols = /* @__PURE__ */ new Set();
                for (const declaration of declarations) {
                    const inheritedDocs = findBaseOfDeclaration(checker, declaration, (symbol) => {
                        if (!seenSymbols.has(symbol)) {
                            seenSymbols.add(symbol);
                            if (declaration.kind === 177 /* GetAccessor */ || declaration.kind === 178 /* SetAccessor */) {
                                return symbol.getContextualDocumentationComment(declaration, checker);
                            }
                            return symbol.getDocumentationComment(checker);
                        }
                    });
                    if (inheritedDocs)
                        doc = doc.length === 0 ? inheritedDocs.slice() : inheritedDocs.concat(lineBreakPart(), doc);
                }
            }
            return doc;
        }
        function findBaseOfDeclaration(checker, declaration, cb) {
            var _a;
            const classOrInterfaceDeclaration = ((_a = declaration.parent) == null ? void 0 : _a.kind) === 176 /* Constructor */ ? declaration.parent.parent : declaration.parent;
            if (!classOrInterfaceDeclaration)
                return;
            const isStaticMember = hasStaticModifier(declaration);
            return firstDefined(getAllSuperTypeNodes(classOrInterfaceDeclaration), (superTypeNode) => {
                const baseType = checker.getTypeAtLocation(superTypeNode);
                const type = isStaticMember && baseType.symbol ? checker.getTypeOfSymbol(baseType.symbol) : baseType;
                const symbol = checker.getPropertyOfType(type, declaration.symbol.name);
                return symbol ? cb(symbol) : void 0;
            });
        }
        function getServicesObjectAllocator() {
            return {
                getNodeConstructor: () => NodeObject,
                getTokenConstructor: () => TokenObject,
                getIdentifierConstructor: () => IdentifierObject,
                getPrivateIdentifierConstructor: () => PrivateIdentifierObject,
                getSourceFileConstructor: () => SourceFileObject,
                getSymbolConstructor: () => SymbolObject,
                getTypeConstructor: () => TypeObject,
                getSignatureConstructor: () => SignatureObject,
                getSourceMapSourceConstructor: () => SourceMapSourceObject
            };
        }
        function toEditorSettings(optionsAsMap) {
            let allPropertiesAreCamelCased = true;
            for (const key in optionsAsMap) {
                if (hasProperty(optionsAsMap, key) && !isCamelCase(key)) {
                    allPropertiesAreCamelCased = false;
                    break;
                }
            }
            if (allPropertiesAreCamelCased) {
                return optionsAsMap;
            }
            const settings = {};
            for (const key in optionsAsMap) {
                if (hasProperty(optionsAsMap, key)) {
                    const newKey = isCamelCase(key) ? key : key.charAt(0).toLowerCase() + key.substr(1);
                    settings[newKey] = optionsAsMap[key];
                }
            }
            return settings;
        }
        function isCamelCase(s) {
            return !s.length || s.charAt(0) === s.charAt(0).toLowerCase();
        }
        function displayPartsToString(displayParts) {
            if (displayParts) {
                return map(displayParts, (displayPart2) => displayPart2.text).join("");
            }
            return "";
        }
        function getDefaultCompilerOptions2() {
            return {
                target: 1 /* ES5 */,
                jsx: 1 /* Preserve */
            };
        }
        function getSupportedCodeFixes() {
            return ts_codefix_exports.getSupportedErrorCodes();
        }
        function setSourceFileFields(sourceFile, scriptSnapshot, version2) {
            sourceFile.version = version2;
            sourceFile.scriptSnapshot = scriptSnapshot;
        }
        function createLanguageServiceSourceFile(fileName, scriptSnapshot, scriptTargetOrOptions, version2, setNodeParents, scriptKind) {
            const sourceFile = createSourceFile(fileName, getSnapshotText(scriptSnapshot), scriptTargetOrOptions, setNodeParents, scriptKind);
            setSourceFileFields(sourceFile, scriptSnapshot, version2);
            return sourceFile;
        }
        function updateLanguageServiceSourceFile(sourceFile, scriptSnapshot, version2, textChangeRange, aggressiveChecks) {
            if (textChangeRange) {
                if (version2 !== sourceFile.version) {
                    let newText;
                    const prefix = textChangeRange.span.start !== 0 ? sourceFile.text.substr(0, textChangeRange.span.start) : "";
                    const suffix = textSpanEnd(textChangeRange.span) !== sourceFile.text.length ? sourceFile.text.substr(textSpanEnd(textChangeRange.span)) : "";
                    if (textChangeRange.newLength === 0) {
                        newText = prefix && suffix ? prefix + suffix : prefix || suffix;
                    }
                    else {
                        const changedText = scriptSnapshot.getText(textChangeRange.span.start, textChangeRange.span.start + textChangeRange.newLength);
                        newText = prefix && suffix ? prefix + changedText + suffix : prefix ? prefix + changedText : changedText + suffix;
                    }
                    const newSourceFile = updateSourceFile(sourceFile, newText, textChangeRange, aggressiveChecks);
                    setSourceFileFields(newSourceFile, scriptSnapshot, version2);
                    newSourceFile.nameTable = void 0;
                    if (sourceFile !== newSourceFile && sourceFile.scriptSnapshot) {
                        if (sourceFile.scriptSnapshot.dispose) {
                            sourceFile.scriptSnapshot.dispose();
                        }
                        sourceFile.scriptSnapshot = void 0;
                    }
                    return newSourceFile;
                }
            }
            const options = {
                languageVersion: sourceFile.languageVersion,
                impliedNodeFormat: sourceFile.impliedNodeFormat,
                setExternalModuleIndicator: sourceFile.setExternalModuleIndicator,
                jsDocParsingMode: sourceFile.jsDocParsingMode
            };
            return createLanguageServiceSourceFile(sourceFile.fileName, scriptSnapshot, options, version2, 
            /*setNodeParents*/
            true, sourceFile.scriptKind);
        }
        function createLanguageService(host, documentRegistry = createDocumentRegistry(host.useCaseSensitiveFileNames && host.useCaseSensitiveFileNames(), host.getCurrentDirectory()), syntaxOnlyOrLanguageServiceMode) {
            var _a;
            let languageServiceMode;
            if (syntaxOnlyOrLanguageServiceMode === void 0) {
                languageServiceMode = 0 /* Semantic */;
            }
            else if (typeof syntaxOnlyOrLanguageServiceMode === "boolean") {
                languageServiceMode = syntaxOnlyOrLanguageServiceMode ? 2 /* Syntactic */ : 0 /* Semantic */;
            }
            else {
                languageServiceMode = syntaxOnlyOrLanguageServiceMode;
            }
            const syntaxTreeCache = new SyntaxTreeCache(host);
            let program;
            let lastProjectVersion;
            let lastTypesRootVersion = 0;
            const cancellationToken = host.getCancellationToken ? new CancellationTokenObject(host.getCancellationToken()) : NoopCancellationToken;
            const currentDirectory = host.getCurrentDirectory();
            maybeSetLocalizedDiagnosticMessages((_a = host.getLocalizedDiagnosticMessages) == null ? void 0 : _a.bind(host));
            function log(message) {
                if (host.log) {
                    host.log(message);
                }
            }
            const useCaseSensitiveFileNames2 = hostUsesCaseSensitiveFileNames(host);
            const getCanonicalFileName = createGetCanonicalFileName(useCaseSensitiveFileNames2);
            const sourceMapper = getSourceMapper({
                useCaseSensitiveFileNames: () => useCaseSensitiveFileNames2,
                getCurrentDirectory: () => currentDirectory,
                getProgram,
                fileExists: maybeBind(host, host.fileExists),
                readFile: maybeBind(host, host.readFile),
                getDocumentPositionMapper: maybeBind(host, host.getDocumentPositionMapper),
                getSourceFileLike: maybeBind(host, host.getSourceFileLike),
                log
            });
            function getValidSourceFile(fileName) {
                const sourceFile = program.getSourceFile(fileName);
                if (!sourceFile) {
                    const error2 = new Error(`Could not find source file: '${fileName}'.`);
                    error2.ProgramFiles = program.getSourceFiles().map((f) => f.fileName);
                    throw error2;
                }
                return sourceFile;
            }
            function synchronizeHostData() {
                if (host.updateFromProject && !host.updateFromProjectInProgress) {
                    host.updateFromProject();
                }
                else {
                    synchronizeHostDataWorker();
                }
            }
            function synchronizeHostDataWorker() {
                var _a2, _b, _c;
                Debug.assert(languageServiceMode !== 2 /* Syntactic */);
                if (host.getProjectVersion) {
                    const hostProjectVersion = host.getProjectVersion();
                    if (hostProjectVersion) {
                        if (lastProjectVersion === hostProjectVersion && !((_a2 = host.hasChangedAutomaticTypeDirectiveNames) == null ? void 0 : _a2.call(host))) {
                            return;
                        }
                        lastProjectVersion = hostProjectVersion;
                    }
                }
                const typeRootsVersion = host.getTypeRootsVersion ? host.getTypeRootsVersion() : 0;
                if (lastTypesRootVersion !== typeRootsVersion) {
                    log("TypeRoots version has changed; provide new program");
                    program = void 0;
                    lastTypesRootVersion = typeRootsVersion;
                }
                const rootFileNames = host.getScriptFileNames().slice();
                const newSettings = host.getCompilationSettings() || getDefaultCompilerOptions2();
                const hasInvalidatedResolutions = host.hasInvalidatedResolutions || returnFalse;
                const hasInvalidatedLibResolutions = maybeBind(host, host.hasInvalidatedLibResolutions) || returnFalse;
                const hasChangedAutomaticTypeDirectiveNames = maybeBind(host, host.hasChangedAutomaticTypeDirectiveNames);
                const projectReferences = (_b = host.getProjectReferences) == null ? void 0 : _b.call(host);
                let parsedCommandLines;
                let compilerHost = {
                    getSourceFile: getOrCreateSourceFile,
                    getSourceFileByPath: getOrCreateSourceFileByPath,
                    getCancellationToken: () => cancellationToken,
                    getCanonicalFileName,
                    useCaseSensitiveFileNames: () => useCaseSensitiveFileNames2,
                    getNewLine: () => getNewLineCharacter(newSettings),
                    getDefaultLibFileName: (options2) => host.getDefaultLibFileName(options2),
                    writeFile: noop,
                    getCurrentDirectory: () => currentDirectory,
                    fileExists: (fileName) => host.fileExists(fileName),
                    readFile: (fileName) => host.readFile && host.readFile(fileName),
                    getSymlinkCache: maybeBind(host, host.getSymlinkCache),
                    realpath: maybeBind(host, host.realpath),
                    directoryExists: (directoryName) => {
                        return directoryProbablyExists(directoryName, host);
                    },
                    getDirectories: (path) => {
                        return host.getDirectories ? host.getDirectories(path) : [];
                    },
                    readDirectory: (path, extensions, exclude, include, depth) => {
                        Debug.checkDefined(host.readDirectory, "'LanguageServiceHost.readDirectory' must be implemented to correctly process 'projectReferences'");
                        return host.readDirectory(path, extensions, exclude, include, depth);
                    },
                    onReleaseOldSourceFile,
                    onReleaseParsedCommandLine,
                    hasInvalidatedResolutions,
                    hasInvalidatedLibResolutions,
                    hasChangedAutomaticTypeDirectiveNames,
                    trace: maybeBind(host, host.trace),
                    resolveModuleNames: maybeBind(host, host.resolveModuleNames),
                    getModuleResolutionCache: maybeBind(host, host.getModuleResolutionCache),
                    createHash: maybeBind(host, host.createHash),
                    resolveTypeReferenceDirectives: maybeBind(host, host.resolveTypeReferenceDirectives),
                    resolveModuleNameLiterals: maybeBind(host, host.resolveModuleNameLiterals),
                    resolveTypeReferenceDirectiveReferences: maybeBind(host, host.resolveTypeReferenceDirectiveReferences),
                    resolveLibrary: maybeBind(host, host.resolveLibrary),
                    useSourceOfProjectReferenceRedirect: maybeBind(host, host.useSourceOfProjectReferenceRedirect),
                    getParsedCommandLine,
                    jsDocParsingMode: host.jsDocParsingMode
                };
                const originalGetSourceFile = compilerHost.getSourceFile;
                const { getSourceFileWithCache } = changeCompilerHostLikeToUseCache(compilerHost, (fileName) => toPath(fileName, currentDirectory, getCanonicalFileName), (...args) => originalGetSourceFile.call(compilerHost, ...args));
                compilerHost.getSourceFile = getSourceFileWithCache;
                (_c = host.setCompilerHost) == null ? void 0 : _c.call(host, compilerHost);
                const parseConfigHost = {
                    useCaseSensitiveFileNames: useCaseSensitiveFileNames2,
                    fileExists: (fileName) => compilerHost.fileExists(fileName),
                    readFile: (fileName) => compilerHost.readFile(fileName),
                    directoryExists: (f) => compilerHost.directoryExists(f),
                    getDirectories: (f) => compilerHost.getDirectories(f),
                    realpath: compilerHost.realpath,
                    readDirectory: (...args) => compilerHost.readDirectory(...args),
                    trace: compilerHost.trace,
                    getCurrentDirectory: compilerHost.getCurrentDirectory,
                    onUnRecoverableConfigFileDiagnostic: noop
                };
                const documentRegistryBucketKey = documentRegistry.getKeyForCompilationSettings(newSettings);
                let releasedScriptKinds = /* @__PURE__ */ new Set();
                if (isProgramUptoDate(program, rootFileNames, newSettings, (_path, fileName) => host.getScriptVersion(fileName), (fileName) => compilerHost.fileExists(fileName), hasInvalidatedResolutions, hasInvalidatedLibResolutions, hasChangedAutomaticTypeDirectiveNames, getParsedCommandLine, projectReferences)) {
                    compilerHost = void 0;
                    parsedCommandLines = void 0;
                    releasedScriptKinds = void 0;
                    return;
                }
                const options = {
                    rootNames: rootFileNames,
                    options: newSettings,
                    host: compilerHost,
                    oldProgram: program,
                    projectReferences
                };
                program = createProgram(options);
                compilerHost = void 0;
                parsedCommandLines = void 0;
                releasedScriptKinds = void 0;
                sourceMapper.clearCache();
                program.getTypeChecker();
                return;
                function getParsedCommandLine(fileName) {
                    const path = toPath(fileName, currentDirectory, getCanonicalFileName);
                    const existing = parsedCommandLines == null ? void 0 : parsedCommandLines.get(path);
                    if (existing !== void 0)
                        return existing || void 0;
                    const result = host.getParsedCommandLine ? host.getParsedCommandLine(fileName) : getParsedCommandLineOfConfigFileUsingSourceFile(fileName);
                    (parsedCommandLines || (parsedCommandLines = /* @__PURE__ */ new Map())).set(path, result || false);
                    return result;
                }
                function getParsedCommandLineOfConfigFileUsingSourceFile(configFileName) {
                    const result = getOrCreateSourceFile(configFileName, 100 /* JSON */);
                    if (!result)
                        return void 0;
                    result.path = toPath(configFileName, currentDirectory, getCanonicalFileName);
                    result.resolvedPath = result.path;
                    result.originalFileName = result.fileName;
                    return parseJsonSourceFileConfigFileContent(result, parseConfigHost, getNormalizedAbsolutePath(getDirectoryPath(configFileName), currentDirectory), 
                    /*existingOptions*/
                    void 0, getNormalizedAbsolutePath(configFileName, currentDirectory));
                }
                function onReleaseParsedCommandLine(configFileName, oldResolvedRef, oldOptions) {
                    var _a3;
                    if (host.getParsedCommandLine) {
                        (_a3 = host.onReleaseParsedCommandLine) == null ? void 0 : _a3.call(host, configFileName, oldResolvedRef, oldOptions);
                    }
                    else if (oldResolvedRef) {
                        onReleaseOldSourceFile(oldResolvedRef.sourceFile, oldOptions);
                    }
                }
                function onReleaseOldSourceFile(oldSourceFile, oldOptions) {
                    const oldSettingsKey = documentRegistry.getKeyForCompilationSettings(oldOptions);
                    documentRegistry.releaseDocumentWithKey(oldSourceFile.resolvedPath, oldSettingsKey, oldSourceFile.scriptKind, oldSourceFile.impliedNodeFormat);
                }
                function getOrCreateSourceFile(fileName, languageVersionOrOptions, onError, shouldCreateNewSourceFile) {
                    return getOrCreateSourceFileByPath(fileName, toPath(fileName, currentDirectory, getCanonicalFileName), languageVersionOrOptions, onError, shouldCreateNewSourceFile);
                }
                function getOrCreateSourceFileByPath(fileName, path, languageVersionOrOptions, _onError, shouldCreateNewSourceFile) {
                    Debug.assert(compilerHost, "getOrCreateSourceFileByPath called after typical CompilerHost lifetime, check the callstack something with a reference to an old host.");
                    const scriptSnapshot = host.getScriptSnapshot(fileName);
                    if (!scriptSnapshot) {
                        return void 0;
                    }
                    const scriptKind = getScriptKind(fileName, host);
                    const scriptVersion = host.getScriptVersion(fileName);
                    if (!shouldCreateNewSourceFile) {
                        const oldSourceFile = program && program.getSourceFileByPath(path);
                        if (oldSourceFile) {
                            if (scriptKind === oldSourceFile.scriptKind || releasedScriptKinds.has(oldSourceFile.resolvedPath)) {
                                return documentRegistry.updateDocumentWithKey(fileName, path, host, documentRegistryBucketKey, scriptSnapshot, scriptVersion, scriptKind, languageVersionOrOptions);
                            }
                            else {
                                documentRegistry.releaseDocumentWithKey(oldSourceFile.resolvedPath, documentRegistry.getKeyForCompilationSettings(program.getCompilerOptions()), oldSourceFile.scriptKind, oldSourceFile.impliedNodeFormat);
                                releasedScriptKinds.add(oldSourceFile.resolvedPath);
                            }
                        }
                    }
                    return documentRegistry.acquireDocumentWithKey(fileName, path, host, documentRegistryBucketKey, scriptSnapshot, scriptVersion, scriptKind, languageVersionOrOptions);
                }
            }
            function getProgram() {
                if (languageServiceMode === 2 /* Syntactic */) {
                    Debug.assert(program === void 0);
                    return void 0;
                }
                synchronizeHostData();
                return program;
            }
            function getAutoImportProvider() {
                var _a2;
                return (_a2 = host.getPackageJsonAutoImportProvider) == null ? void 0 : _a2.call(host);
            }
            function updateIsDefinitionOfReferencedSymbols(referencedSymbols, knownSymbolSpans) {
                const checker = program.getTypeChecker();
                const symbol = getSymbolForProgram();
                if (!symbol)
                    return false;
                for (const referencedSymbol of referencedSymbols) {
                    for (const ref of referencedSymbol.references) {
                        const refNode = getNodeForSpan(ref);
                        Debug.assertIsDefined(refNode);
                        if (knownSymbolSpans.has(ref) || ts_FindAllReferences_exports.isDeclarationOfSymbol(refNode, symbol)) {
                            knownSymbolSpans.add(ref);
                            ref.isDefinition = true;
                            const mappedSpan = getMappedDocumentSpan(ref, sourceMapper, maybeBind(host, host.fileExists));
                            if (mappedSpan) {
                                knownSymbolSpans.add(mappedSpan);
                            }
                        }
                        else {
                            ref.isDefinition = false;
                        }
                    }
                }
                return true;
                function getSymbolForProgram() {
                    for (const referencedSymbol of referencedSymbols) {
                        for (const ref of referencedSymbol.references) {
                            if (knownSymbolSpans.has(ref)) {
                                const refNode = getNodeForSpan(ref);
                                Debug.assertIsDefined(refNode);
                                return checker.getSymbolAtLocation(refNode);
                            }
                            const mappedSpan = getMappedDocumentSpan(ref, sourceMapper, maybeBind(host, host.fileExists));
                            if (mappedSpan && knownSymbolSpans.has(mappedSpan)) {
                                const refNode = getNodeForSpan(mappedSpan);
                                if (refNode) {
                                    return checker.getSymbolAtLocation(refNode);
                                }
                            }
                        }
                    }
                    return void 0;
                }
                function getNodeForSpan(docSpan) {
                    const sourceFile = program.getSourceFile(docSpan.fileName);
                    if (!sourceFile)
                        return void 0;
                    const rawNode = getTouchingPropertyName(sourceFile, docSpan.textSpan.start);
                    const adjustedNode = ts_FindAllReferences_exports.Core.getAdjustedNode(rawNode, { use: ts_FindAllReferences_exports.FindReferencesUse.References });
                    return adjustedNode;
                }
            }
            function cleanupSemanticCache() {
                if (program) {
                    const key = documentRegistry.getKeyForCompilationSettings(program.getCompilerOptions());
                    forEach(program.getSourceFiles(), (f) => documentRegistry.releaseDocumentWithKey(f.resolvedPath, key, f.scriptKind, f.impliedNodeFormat));
                    program = void 0;
                }
            }
            function dispose() {
                cleanupSemanticCache();
                host = void 0;
            }
            function getSyntacticDiagnostics(fileName) {
                synchronizeHostData();
                return program.getSyntacticDiagnostics(getValidSourceFile(fileName), cancellationToken).slice();
            }
            function getSemanticDiagnostics(fileName) {
                synchronizeHostData();
                const targetSourceFile = getValidSourceFile(fileName);
                const semanticDiagnostics = program.getSemanticDiagnostics(targetSourceFile, cancellationToken);
                if (!getEmitDeclarations(program.getCompilerOptions())) {
                    return semanticDiagnostics.slice();
                }
                const declarationDiagnostics = program.getDeclarationDiagnostics(targetSourceFile, cancellationToken);
                return [...semanticDiagnostics, ...declarationDiagnostics];
            }
            function getSuggestionDiagnostics(fileName) {
                synchronizeHostData();
                return computeSuggestionDiagnostics(getValidSourceFile(fileName), program, cancellationToken);
            }
            function getCompilerOptionsDiagnostics() {
                synchronizeHostData();
                return [...program.getOptionsDiagnostics(cancellationToken), ...program.getGlobalDiagnostics(cancellationToken)];
            }
            function getCompletionsAtPosition2(fileName, position, options = emptyOptions, formattingSettings) {
                const fullPreferences = {
                    ...identity(options),
                    // avoid excess property check
                    includeCompletionsForModuleExports: options.includeCompletionsForModuleExports || options.includeExternalModuleExports,
                    includeCompletionsWithInsertText: options.includeCompletionsWithInsertText || options.includeInsertTextCompletions
                };
                synchronizeHostData();
                return ts_Completions_exports.getCompletionsAtPosition(host, program, log, getValidSourceFile(fileName), position, fullPreferences, options.triggerCharacter, options.triggerKind, cancellationToken, formattingSettings && ts_formatting_exports.getFormatContext(formattingSettings, host), options.includeSymbol);
            }
            function getCompletionEntryDetails2(fileName, position, name, formattingOptions, source, preferences = emptyOptions, data) {
                synchronizeHostData();
                return ts_Completions_exports.getCompletionEntryDetails(program, log, getValidSourceFile(fileName), position, { name, source, data }, host, formattingOptions && ts_formatting_exports.getFormatContext(formattingOptions, host), 
                // TODO: GH#18217
                preferences, cancellationToken);
            }
            function getCompletionEntrySymbol2(fileName, position, name, source, preferences = emptyOptions) {
                synchronizeHostData();
                return ts_Completions_exports.getCompletionEntrySymbol(program, log, getValidSourceFile(fileName), position, { name, source }, host, preferences);
            }
            function getQuickInfoAtPosition(fileName, position) {
                synchronizeHostData();
                const sourceFile = getValidSourceFile(fileName);
                const node = getTouchingPropertyName(sourceFile, position);
                if (node === sourceFile) {
                    return void 0;
                }
                const typeChecker = program.getTypeChecker();
                const nodeForQuickInfo = getNodeForQuickInfo(node);
                const symbol = getSymbolAtLocationForQuickInfo(nodeForQuickInfo, typeChecker);
                if (!symbol || typeChecker.isUnknownSymbol(symbol)) {
                    const type = shouldGetType(sourceFile, nodeForQuickInfo, position) ? typeChecker.getTypeAtLocation(nodeForQuickInfo) : void 0;
                    return type && {
                        kind: "" /* unknown */,
                        kindModifiers: "" /* none */,
                        textSpan: createTextSpanFromNode(nodeForQuickInfo, sourceFile),
                        displayParts: typeChecker.runWithCancellationToken(cancellationToken, (typeChecker2) => typeToDisplayParts(typeChecker2, type, getContainerNode(nodeForQuickInfo))),
                        documentation: type.symbol ? type.symbol.getDocumentationComment(typeChecker) : void 0,
                        tags: type.symbol ? type.symbol.getJsDocTags(typeChecker) : void 0
                    };
                }
                const { symbolKind, displayParts, documentation, tags } = typeChecker.runWithCancellationToken(cancellationToken, (typeChecker2) => ts_SymbolDisplay_exports.getSymbolDisplayPartsDocumentationAndSymbolKind(typeChecker2, symbol, sourceFile, getContainerNode(nodeForQuickInfo), nodeForQuickInfo));
                return {
                    kind: symbolKind,
                    kindModifiers: ts_SymbolDisplay_exports.getSymbolModifiers(typeChecker, symbol),
                    textSpan: createTextSpanFromNode(nodeForQuickInfo, sourceFile),
                    displayParts,
                    documentation,
                    tags
                };
            }
            function getNodeForQuickInfo(node) {
                if (isNewExpression(node.parent) && node.pos === node.parent.pos) {
                    return node.parent.expression;
                }
                if (isNamedTupleMember(node.parent) && node.pos === node.parent.pos) {
                    return node.parent;
                }
                if (isImportMeta(node.parent) && node.parent.name === node) {
                    return node.parent;
                }
                if (isJsxNamespacedName(node.parent)) {
                    return node.parent;
                }
                return node;
            }
            function shouldGetType(sourceFile, node, position) {
                switch (node.kind) {
                    case 80 /* Identifier */:
                        return !isLabelName(node) && !isTagName(node) && !isConstTypeReference(node.parent);
                    case 211 /* PropertyAccessExpression */:
                    case 166 /* QualifiedName */:
                        return !isInComment(sourceFile, position);
                    case 110 /* ThisKeyword */:
                    case 197 /* ThisType */:
                    case 108 /* SuperKeyword */:
                    case 202 /* NamedTupleMember */:
                        return true;
                    case 236 /* MetaProperty */:
                        return isImportMeta(node);
                    default:
                        return false;
                }
            }
            function getDefinitionAtPosition2(fileName, position, searchOtherFilesOnly, stopAtAlias) {
                synchronizeHostData();
                return ts_GoToDefinition_exports.getDefinitionAtPosition(program, getValidSourceFile(fileName), position, searchOtherFilesOnly, stopAtAlias);
            }
            function getDefinitionAndBoundSpan2(fileName, position) {
                synchronizeHostData();
                return ts_GoToDefinition_exports.getDefinitionAndBoundSpan(program, getValidSourceFile(fileName), position);
            }
            function getTypeDefinitionAtPosition2(fileName, position) {
                synchronizeHostData();
                return ts_GoToDefinition_exports.getTypeDefinitionAtPosition(program.getTypeChecker(), getValidSourceFile(fileName), position);
            }
            function getImplementationAtPosition(fileName, position) {
                synchronizeHostData();
                return ts_FindAllReferences_exports.getImplementationsAtPosition(program, cancellationToken, program.getSourceFiles(), getValidSourceFile(fileName), position);
            }
            function getDocumentHighlights(fileName, position, filesToSearch) {
                const normalizedFileName = normalizePath(fileName);
                Debug.assert(filesToSearch.some((f) => normalizePath(f) === normalizedFileName));
                synchronizeHostData();
                const sourceFilesToSearch = mapDefined(filesToSearch, (fileName2) => program.getSourceFile(fileName2));
                const sourceFile = getValidSourceFile(fileName);
                return DocumentHighlights.getDocumentHighlights(program, cancellationToken, sourceFile, position, sourceFilesToSearch);
            }
            function findRenameLocations(fileName, position, findInStrings, findInComments, preferences) {
                synchronizeHostData();
                const sourceFile = getValidSourceFile(fileName);
                const node = getAdjustedRenameLocation(getTouchingPropertyName(sourceFile, position));
                if (!ts_Rename_exports.nodeIsEligibleForRename(node))
                    return void 0;
                if (isIdentifier(node) && (isJsxOpeningElement(node.parent) || isJsxClosingElement(node.parent)) && isIntrinsicJsxName(node.escapedText)) {
                    const { openingElement, closingElement } = node.parent.parent;
                    return [openingElement, closingElement].map((node2) => {
                        const textSpan = createTextSpanFromNode(node2.tagName, sourceFile);
                        return {
                            fileName: sourceFile.fileName,
                            textSpan,
                            ...ts_FindAllReferences_exports.toContextSpan(textSpan, sourceFile, node2.parent)
                        };
                    });
                }
                else {
                    const quotePreference = getQuotePreference(sourceFile, preferences ?? emptyOptions);
                    const providePrefixAndSuffixTextForRename = typeof preferences === "boolean" ? preferences : preferences == null ? void 0 : preferences.providePrefixAndSuffixTextForRename;
                    return getReferencesWorker2(node, position, { findInStrings, findInComments, providePrefixAndSuffixTextForRename, use: ts_FindAllReferences_exports.FindReferencesUse.Rename }, (entry, originalNode, checker) => ts_FindAllReferences_exports.toRenameLocation(entry, originalNode, checker, providePrefixAndSuffixTextForRename || false, quotePreference));
                }
            }
            function getReferencesAtPosition(fileName, position) {
                synchronizeHostData();
                return getReferencesWorker2(getTouchingPropertyName(getValidSourceFile(fileName), position), position, { use: ts_FindAllReferences_exports.FindReferencesUse.References }, ts_FindAllReferences_exports.toReferenceEntry);
            }
            function getReferencesWorker2(node, position, options, cb) {
                synchronizeHostData();
                const sourceFiles = options && options.use === ts_FindAllReferences_exports.FindReferencesUse.Rename ? program.getSourceFiles().filter((sourceFile) => !program.isSourceFileDefaultLibrary(sourceFile)) : program.getSourceFiles();
                return ts_FindAllReferences_exports.findReferenceOrRenameEntries(program, cancellationToken, sourceFiles, node, position, options, cb);
            }
            function findReferences(fileName, position) {
                synchronizeHostData();
                return ts_FindAllReferences_exports.findReferencedSymbols(program, cancellationToken, program.getSourceFiles(), getValidSourceFile(fileName), position);
            }
            function getFileReferences(fileName) {
                synchronizeHostData();
                return ts_FindAllReferences_exports.Core.getReferencesForFileName(fileName, program, program.getSourceFiles()).map(ts_FindAllReferences_exports.toReferenceEntry);
            }
            function getNavigateToItems2(searchValue, maxResultCount, fileName, excludeDtsFiles = false, excludeLibFiles = false) {
                synchronizeHostData();
                const sourceFiles = fileName ? [getValidSourceFile(fileName)] : program.getSourceFiles();
                return getNavigateToItems(sourceFiles, program.getTypeChecker(), cancellationToken, searchValue, maxResultCount, excludeDtsFiles, excludeLibFiles);
            }
            function getEmitOutput(fileName, emitOnlyDtsFiles, forceDtsEmit) {
                synchronizeHostData();
                const sourceFile = getValidSourceFile(fileName);
                const customTransformers = host.getCustomTransformers && host.getCustomTransformers();
                return getFileEmitOutput(program, sourceFile, !!emitOnlyDtsFiles, cancellationToken, customTransformers, forceDtsEmit);
            }
            function getSignatureHelpItems2(fileName, position, { triggerReason } = emptyOptions) {
                synchronizeHostData();
                const sourceFile = getValidSourceFile(fileName);
                return ts_SignatureHelp_exports.getSignatureHelpItems(program, sourceFile, position, triggerReason, cancellationToken);
            }
            function getNonBoundSourceFile(fileName) {
                return syntaxTreeCache.getCurrentSourceFile(fileName);
            }
            function getNameOrDottedNameSpan(fileName, startPos, _endPos) {
                const sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
                const node = getTouchingPropertyName(sourceFile, startPos);
                if (node === sourceFile) {
                    return void 0;
                }
                switch (node.kind) {
                    case 211 /* PropertyAccessExpression */:
                    case 166 /* QualifiedName */:
                    case 11 /* StringLiteral */:
                    case 97 /* FalseKeyword */:
                    case 112 /* TrueKeyword */:
                    case 106 /* NullKeyword */:
                    case 108 /* SuperKeyword */:
                    case 110 /* ThisKeyword */:
                    case 197 /* ThisType */:
                    case 80 /* Identifier */:
                        break;
                    default:
                        return void 0;
                }
                let nodeForStartPos = node;
                while (true) {
                    if (isRightSideOfPropertyAccess(nodeForStartPos) || isRightSideOfQualifiedName(nodeForStartPos)) {
                        nodeForStartPos = nodeForStartPos.parent;
                    }
                    else if (isNameOfModuleDeclaration(nodeForStartPos)) {
                        if (nodeForStartPos.parent.parent.kind === 267 /* ModuleDeclaration */ && nodeForStartPos.parent.parent.body === nodeForStartPos.parent) {
                            nodeForStartPos = nodeForStartPos.parent.parent.name;
                        }
                        else {
                            break;
                        }
                    }
                    else {
                        break;
                    }
                }
                return createTextSpanFromBounds(nodeForStartPos.getStart(), node.getEnd());
            }
            function getBreakpointStatementAtPosition(fileName, position) {
                const sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
                return ts_BreakpointResolver_exports.spanInSourceFileAtLocation(sourceFile, position);
            }
            function getNavigationBarItems2(fileName) {
                return getNavigationBarItems(syntaxTreeCache.getCurrentSourceFile(fileName), cancellationToken);
            }
            function getNavigationTree2(fileName) {
                return getNavigationTree(syntaxTreeCache.getCurrentSourceFile(fileName), cancellationToken);
            }
            function getSemanticClassifications3(fileName, span, format) {
                synchronizeHostData();
                const responseFormat = format || "original" /* Original */;
                if (responseFormat === "2020" /* TwentyTwenty */) {
                    return getSemanticClassifications2(program, cancellationToken, getValidSourceFile(fileName), span);
                }
                else {
                    return getSemanticClassifications(program.getTypeChecker(), cancellationToken, getValidSourceFile(fileName), program.getClassifiableNames(), span);
                }
            }
            function getEncodedSemanticClassifications3(fileName, span, format) {
                synchronizeHostData();
                const responseFormat = format || "original" /* Original */;
                if (responseFormat === "original" /* Original */) {
                    return getEncodedSemanticClassifications(program.getTypeChecker(), cancellationToken, getValidSourceFile(fileName), program.getClassifiableNames(), span);
                }
                else {
                    return getEncodedSemanticClassifications2(program, cancellationToken, getValidSourceFile(fileName), span);
                }
            }
            function getSyntacticClassifications2(fileName, span) {
                return getSyntacticClassifications(cancellationToken, syntaxTreeCache.getCurrentSourceFile(fileName), span);
            }
            function getEncodedSyntacticClassifications2(fileName, span) {
                return getEncodedSyntacticClassifications(cancellationToken, syntaxTreeCache.getCurrentSourceFile(fileName), span);
            }
            function getOutliningSpans(fileName) {
                const sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
                return ts_OutliningElementsCollector_exports.collectElements(sourceFile, cancellationToken);
            }
            const braceMatching = new Map(Object.entries({
                [19 /* OpenBraceToken */]: 20 /* CloseBraceToken */,
                [21 /* OpenParenToken */]: 22 /* CloseParenToken */,
                [23 /* OpenBracketToken */]: 24 /* CloseBracketToken */,
                [32 /* GreaterThanToken */]: 30 /* LessThanToken */
            }));
            braceMatching.forEach((value, key) => braceMatching.set(value.toString(), Number(key)));
            function getBraceMatchingAtPosition(fileName, position) {
                const sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
                const token = getTouchingToken(sourceFile, position);
                const matchKind = token.getStart(sourceFile) === position ? braceMatching.get(token.kind.toString()) : void 0;
                const match = matchKind && findChildOfKind(token.parent, matchKind, sourceFile);
                return match ? [createTextSpanFromNode(token, sourceFile), createTextSpanFromNode(match, sourceFile)].sort((a, b) => a.start - b.start) : emptyArray;
            }
            function getIndentationAtPosition(fileName, position, editorOptions) {
                let start = timestamp();
                const settings = toEditorSettings(editorOptions);
                const sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
                log("getIndentationAtPosition: getCurrentSourceFile: " + (timestamp() - start));
                start = timestamp();
                const result = ts_formatting_exports.SmartIndenter.getIndentation(position, sourceFile, settings);
                log("getIndentationAtPosition: computeIndentation  : " + (timestamp() - start));
                return result;
            }
            function getFormattingEditsForRange(fileName, start, end, options) {
                const sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
                return ts_formatting_exports.formatSelection(start, end, sourceFile, ts_formatting_exports.getFormatContext(toEditorSettings(options), host));
            }
            function getFormattingEditsForDocument(fileName, options) {
                return ts_formatting_exports.formatDocument(syntaxTreeCache.getCurrentSourceFile(fileName), ts_formatting_exports.getFormatContext(toEditorSettings(options), host));
            }
            function getFormattingEditsAfterKeystroke(fileName, position, key, options) {
                const sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
                const formatContext = ts_formatting_exports.getFormatContext(toEditorSettings(options), host);
                if (!isInComment(sourceFile, position)) {
                    switch (key) {
                        case "{":
                            return ts_formatting_exports.formatOnOpeningCurly(position, sourceFile, formatContext);
                        case "}":
                            return ts_formatting_exports.formatOnClosingCurly(position, sourceFile, formatContext);
                        case ";":
                            return ts_formatting_exports.formatOnSemicolon(position, sourceFile, formatContext);
                        case "\n":
                            return ts_formatting_exports.formatOnEnter(position, sourceFile, formatContext);
                    }
                }
                return [];
            }
            function getCodeFixesAtPosition(fileName, start, end, errorCodes65, formatOptions, preferences = emptyOptions) {
                synchronizeHostData();
                const sourceFile = getValidSourceFile(fileName);
                const span = createTextSpanFromBounds(start, end);
                const formatContext = ts_formatting_exports.getFormatContext(formatOptions, host);
                return flatMap(deduplicate(errorCodes65, equateValues, compareValues), (errorCode) => {
                    cancellationToken.throwIfCancellationRequested();
                    return ts_codefix_exports.getFixes({ errorCode, sourceFile, span, program, host, cancellationToken, formatContext, preferences });
                });
            }
            function getCombinedCodeFix(scope, fixId52, formatOptions, preferences = emptyOptions) {
                synchronizeHostData();
                Debug.assert(scope.type === "file");
                const sourceFile = getValidSourceFile(scope.fileName);
                const formatContext = ts_formatting_exports.getFormatContext(formatOptions, host);
                return ts_codefix_exports.getAllFixes({ fixId: fixId52, sourceFile, program, host, cancellationToken, formatContext, preferences });
            }
            function organizeImports2(args, formatOptions, preferences = emptyOptions) {
                synchronizeHostData();
                Debug.assert(args.type === "file");
                const sourceFile = getValidSourceFile(args.fileName);
                const formatContext = ts_formatting_exports.getFormatContext(formatOptions, host);
                const mode = args.mode ?? (args.skipDestructiveCodeActions ? "SortAndCombine" /* SortAndCombine */ : "All" /* All */);
                return ts_OrganizeImports_exports.organizeImports(sourceFile, formatContext, host, program, preferences, mode);
            }
            function getEditsForFileRename2(oldFilePath, newFilePath, formatOptions, preferences = emptyOptions) {
                return getEditsForFileRename(getProgram(), oldFilePath, newFilePath, host, ts_formatting_exports.getFormatContext(formatOptions, host), preferences, sourceMapper);
            }
            function applyCodeActionCommand(fileName, actionOrFormatSettingsOrUndefined) {
                const action = typeof fileName === "string" ? actionOrFormatSettingsOrUndefined : fileName;
                return isArray(action) ? Promise.all(action.map((a) => applySingleCodeActionCommand(a))) : applySingleCodeActionCommand(action);
            }
            function applySingleCodeActionCommand(action) {
                const getPath = (path) => toPath(path, currentDirectory, getCanonicalFileName);
                Debug.assertEqual(action.type, "install package");
                return host.installPackage ? host.installPackage({ fileName: getPath(action.file), packageName: action.packageName }) : Promise.reject("Host does not implement `installPackage`");
            }
            function getDocCommentTemplateAtPosition2(fileName, position, options, formatOptions) {
                const formatSettings = formatOptions ? ts_formatting_exports.getFormatContext(formatOptions, host).options : void 0;
                return ts_JsDoc_exports.getDocCommentTemplateAtPosition(getNewLineOrDefaultFromHost(host, formatSettings), syntaxTreeCache.getCurrentSourceFile(fileName), position, options);
            }
            function isValidBraceCompletionAtPosition(fileName, position, openingBrace) {
                if (openingBrace === 60 /* lessThan */) {
                    return false;
                }
                const sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
                if (isInString(sourceFile, position)) {
                    return false;
                }
                if (isInsideJsxElementOrAttribute(sourceFile, position)) {
                    return openingBrace === 123 /* openBrace */;
                }
                if (isInTemplateString(sourceFile, position)) {
                    return false;
                }
                switch (openingBrace) {
                    case 39 /* singleQuote */:
                    case 34 /* doubleQuote */:
                    case 96 /* backtick */:
                        return !isInComment(sourceFile, position);
                }
                return true;
            }
            function getJsxClosingTagAtPosition(fileName, position) {
                const sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
                const token = findPrecedingToken(position, sourceFile);
                if (!token)
                    return void 0;
                const element = token.kind === 32 /* GreaterThanToken */ && isJsxOpeningElement(token.parent) ? token.parent.parent : isJsxText(token) && isJsxElement(token.parent) ? token.parent : void 0;
                if (element && isUnclosedTag(element)) {
                    return { newText: `</${element.openingElement.tagName.getText(sourceFile)}>` };
                }
                const fragment = token.kind === 32 /* GreaterThanToken */ && isJsxOpeningFragment(token.parent) ? token.parent.parent : isJsxText(token) && isJsxFragment(token.parent) ? token.parent : void 0;
                if (fragment && isUnclosedFragment(fragment)) {
                    return { newText: "</>" };
                }
            }
            function getLinkedEditingRangeAtPosition(fileName, position) {
                const sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
                const token = findPrecedingToken(position, sourceFile);
                if (!token || token.parent.kind === 312 /* SourceFile */)
                    return void 0;
                const jsxTagWordPattern = "[a-zA-Z0-9:\\-\\._$]*";
                if (isJsxFragment(token.parent.parent)) {
                    const openFragment = token.parent.parent.openingFragment;
                    const closeFragment = token.parent.parent.closingFragment;
                    if (containsParseError(openFragment) || containsParseError(closeFragment))
                        return void 0;
                    const openPos = openFragment.getStart(sourceFile) + 1;
                    const closePos = closeFragment.getStart(sourceFile) + 2;
                    if (position !== openPos && position !== closePos)
                        return void 0;
                    return {
                        ranges: [{ start: openPos, length: 0 }, { start: closePos, length: 0 }],
                        wordPattern: jsxTagWordPattern
                    };
                }
                else {
                    const tag = findAncestor(token.parent, (n) => {
                        if (isJsxOpeningElement(n) || isJsxClosingElement(n)) {
                            return true;
                        }
                        return false;
                    });
                    if (!tag)
                        return void 0;
                    Debug.assert(isJsxOpeningElement(tag) || isJsxClosingElement(tag), "tag should be opening or closing element");
                    const openTag = tag.parent.openingElement;
                    const closeTag = tag.parent.closingElement;
                    const openTagNameStart = openTag.tagName.getStart(sourceFile);
                    const openTagNameEnd = openTag.tagName.end;
                    const closeTagNameStart = closeTag.tagName.getStart(sourceFile);
                    const closeTagNameEnd = closeTag.tagName.end;
                    if (openTagNameStart === openTag.getStart(sourceFile) || closeTagNameStart === closeTag.getStart(sourceFile) || openTagNameEnd === openTag.getEnd() || closeTagNameEnd === closeTag.getEnd())
                        return void 0;
                    if (!(openTagNameStart <= position && position <= openTagNameEnd || closeTagNameStart <= position && position <= closeTagNameEnd))
                        return void 0;
                    const openingTagText = openTag.tagName.getText(sourceFile);
                    if (openingTagText !== closeTag.tagName.getText(sourceFile))
                        return void 0;
                    return {
                        ranges: [{ start: openTagNameStart, length: openTagNameEnd - openTagNameStart }, { start: closeTagNameStart, length: closeTagNameEnd - closeTagNameStart }],
                        wordPattern: jsxTagWordPattern
                    };
                }
            }
            function getLinesForRange(sourceFile, textRange) {
                return {
                    lineStarts: sourceFile.getLineStarts(),
                    firstLine: sourceFile.getLineAndCharacterOfPosition(textRange.pos).line,
                    lastLine: sourceFile.getLineAndCharacterOfPosition(textRange.end).line
                };
            }
            function toggleLineComment(fileName, textRange, insertComment) {
                const sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
                const textChanges2 = [];
                const { lineStarts, firstLine, lastLine } = getLinesForRange(sourceFile, textRange);
                let isCommenting = insertComment || false;
                let leftMostPosition = Number.MAX_VALUE;
                const lineTextStarts = /* @__PURE__ */ new Map();
                const firstNonWhitespaceCharacterRegex = new RegExp(/\S/);
                const isJsx = isInsideJsxElement(sourceFile, lineStarts[firstLine]);
                const openComment = isJsx ? "{/*" : "//";
                for (let i = firstLine; i <= lastLine; i++) {
                    const lineText = sourceFile.text.substring(lineStarts[i], sourceFile.getLineEndOfPosition(lineStarts[i]));
                    const regExec = firstNonWhitespaceCharacterRegex.exec(lineText);
                    if (regExec) {
                        leftMostPosition = Math.min(leftMostPosition, regExec.index);
                        lineTextStarts.set(i.toString(), regExec.index);
                        if (lineText.substr(regExec.index, openComment.length) !== openComment) {
                            isCommenting = insertComment === void 0 || insertComment;
                        }
                    }
                }
                for (let i = firstLine; i <= lastLine; i++) {
                    if (firstLine !== lastLine && lineStarts[i] === textRange.end) {
                        continue;
                    }
                    const lineTextStart = lineTextStarts.get(i.toString());
                    if (lineTextStart !== void 0) {
                        if (isJsx) {
                            textChanges2.push(...toggleMultilineComment(fileName, { pos: lineStarts[i] + leftMostPosition, end: sourceFile.getLineEndOfPosition(lineStarts[i]) }, isCommenting, isJsx));
                        }
                        else if (isCommenting) {
                            textChanges2.push({
                                newText: openComment,
                                span: {
                                    length: 0,
                                    start: lineStarts[i] + leftMostPosition
                                }
                            });
                        }
                        else if (sourceFile.text.substr(lineStarts[i] + lineTextStart, openComment.length) === openComment) {
                            textChanges2.push({
                                newText: "",
                                span: {
                                    length: openComment.length,
                                    start: lineStarts[i] + lineTextStart
                                }
                            });
                        }
                    }
                }
                return textChanges2;
            }
            function toggleMultilineComment(fileName, textRange, insertComment, isInsideJsx) {
                var _a2;
                const sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
                const textChanges2 = [];
                const { text } = sourceFile;
                let hasComment = false;
                let isCommenting = insertComment || false;
                const positions = [];
                let { pos } = textRange;
                const isJsx = isInsideJsx !== void 0 ? isInsideJsx : isInsideJsxElement(sourceFile, pos);
                const openMultiline = isJsx ? "{/*" : "/*";
                const closeMultiline = isJsx ? "*/}" : "*/";
                const openMultilineRegex = isJsx ? "\\{\\/\\*" : "\\/\\*";
                const closeMultilineRegex = isJsx ? "\\*\\/\\}" : "\\*\\/";
                while (pos <= textRange.end) {
                    const offset = text.substr(pos, openMultiline.length) === openMultiline ? openMultiline.length : 0;
                    const commentRange = isInComment(sourceFile, pos + offset);
                    if (commentRange) {
                        if (isJsx) {
                            commentRange.pos--;
                            commentRange.end++;
                        }
                        positions.push(commentRange.pos);
                        if (commentRange.kind === 3 /* MultiLineCommentTrivia */) {
                            positions.push(commentRange.end);
                        }
                        hasComment = true;
                        pos = commentRange.end + 1;
                    }
                    else {
                        const newPos = text.substring(pos, textRange.end).search(`(${openMultilineRegex})|(${closeMultilineRegex})`);
                        isCommenting = insertComment !== void 0 ? insertComment : isCommenting || !isTextWhiteSpaceLike(text, pos, newPos === -1 ? textRange.end : pos + newPos);
                        pos = newPos === -1 ? textRange.end + 1 : pos + newPos + closeMultiline.length;
                    }
                }
                if (isCommenting || !hasComment) {
                    if (((_a2 = isInComment(sourceFile, textRange.pos)) == null ? void 0 : _a2.kind) !== 2 /* SingleLineCommentTrivia */) {
                        insertSorted(positions, textRange.pos, compareValues);
                    }
                    insertSorted(positions, textRange.end, compareValues);
                    const firstPos = positions[0];
                    if (text.substr(firstPos, openMultiline.length) !== openMultiline) {
                        textChanges2.push({
                            newText: openMultiline,
                            span: {
                                length: 0,
                                start: firstPos
                            }
                        });
                    }
                    for (let i = 1; i < positions.length - 1; i++) {
                        if (text.substr(positions[i] - closeMultiline.length, closeMultiline.length) !== closeMultiline) {
                            textChanges2.push({
                                newText: closeMultiline,
                                span: {
                                    length: 0,
                                    start: positions[i]
                                }
                            });
                        }
                        if (text.substr(positions[i], openMultiline.length) !== openMultiline) {
                            textChanges2.push({
                                newText: openMultiline,
                                span: {
                                    length: 0,
                                    start: positions[i]
                                }
                            });
                        }
                    }
                    if (textChanges2.length % 2 !== 0) {
                        textChanges2.push({
                            newText: closeMultiline,
                            span: {
                                length: 0,
                                start: positions[positions.length - 1]
                            }
                        });
                    }
                }
                else {
                    for (const pos2 of positions) {
                        const from = pos2 - closeMultiline.length > 0 ? pos2 - closeMultiline.length : 0;
                        const offset = text.substr(from, closeMultiline.length) === closeMultiline ? closeMultiline.length : 0;
                        textChanges2.push({
                            newText: "",
                            span: {
                                length: openMultiline.length,
                                start: pos2 - offset
                            }
                        });
                    }
                }
                return textChanges2;
            }
            function commentSelection(fileName, textRange) {
                const sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
                const { firstLine, lastLine } = getLinesForRange(sourceFile, textRange);
                return firstLine === lastLine && textRange.pos !== textRange.end ? toggleMultilineComment(fileName, textRange, 
                /*insertComment*/
                true) : toggleLineComment(fileName, textRange, 
                /*insertComment*/
                true);
            }
            function uncommentSelection(fileName, textRange) {
                const sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
                const textChanges2 = [];
                const { pos } = textRange;
                let { end } = textRange;
                if (pos === end) {
                    end += isInsideJsxElement(sourceFile, pos) ? 2 : 1;
                }
                for (let i = pos; i <= end; i++) {
                    const commentRange = isInComment(sourceFile, i);
                    if (commentRange) {
                        switch (commentRange.kind) {
                            case 2 /* SingleLineCommentTrivia */:
                                textChanges2.push(...toggleLineComment(fileName, { end: commentRange.end, pos: commentRange.pos + 1 }, 
                                /*insertComment*/
                                false));
                                break;
                            case 3 /* MultiLineCommentTrivia */:
                                textChanges2.push(...toggleMultilineComment(fileName, { end: commentRange.end, pos: commentRange.pos + 1 }, 
                                /*insertComment*/
                                false));
                        }
                        i = commentRange.end + 1;
                    }
                }
                return textChanges2;
            }
            function isUnclosedTag({ openingElement, closingElement, parent: parent2 }) {
                return !tagNamesAreEquivalent(openingElement.tagName, closingElement.tagName) || isJsxElement(parent2) && tagNamesAreEquivalent(openingElement.tagName, parent2.openingElement.tagName) && isUnclosedTag(parent2);
            }
            function isUnclosedFragment({ closingFragment, parent: parent2 }) {
                return !!(closingFragment.flags & 262144 /* ThisNodeHasError */) || isJsxFragment(parent2) && isUnclosedFragment(parent2);
            }
            function getSpanOfEnclosingComment(fileName, position, onlyMultiLine) {
                const sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
                const range = ts_formatting_exports.getRangeOfEnclosingComment(sourceFile, position);
                return range && (!onlyMultiLine || range.kind === 3 /* MultiLineCommentTrivia */) ? createTextSpanFromRange(range) : void 0;
            }
            function getTodoComments(fileName, descriptors) {
                synchronizeHostData();
                const sourceFile = getValidSourceFile(fileName);
                cancellationToken.throwIfCancellationRequested();
                const fileContents = sourceFile.text;
                const result = [];
                if (descriptors.length > 0 && !isNodeModulesFile(sourceFile.fileName)) {
                    const regExp = getTodoCommentsRegExp();
                    let matchArray;
                    while (matchArray = regExp.exec(fileContents)) {
                        cancellationToken.throwIfCancellationRequested();
                        const firstDescriptorCaptureIndex = 3;
                        Debug.assert(matchArray.length === descriptors.length + firstDescriptorCaptureIndex);
                        const preamble = matchArray[1];
                        const matchPosition = matchArray.index + preamble.length;
                        if (!isInComment(sourceFile, matchPosition)) {
                            continue;
                        }
                        let descriptor;
                        for (let i = 0; i < descriptors.length; i++) {
                            if (matchArray[i + firstDescriptorCaptureIndex]) {
                                descriptor = descriptors[i];
                            }
                        }
                        if (descriptor === void 0)
                            return Debug.fail();
                        if (isLetterOrDigit(fileContents.charCodeAt(matchPosition + descriptor.text.length))) {
                            continue;
                        }
                        const message = matchArray[2];
                        result.push({ descriptor, message, position: matchPosition });
                    }
                }
                return result;
                function escapeRegExp(str) {
                    return str.replace(/[-[\]/{}()*+?.\\^$|]/g, "\\$&");
                }
                function getTodoCommentsRegExp() {
                    const singleLineCommentStart = /(?:\/\/+\s*)/.source;
                    const multiLineCommentStart = /(?:\/\*+\s*)/.source;
                    const anyNumberOfSpacesAndAsterisksAtStartOfLine = /(?:^(?:\s|\*)*)/.source;
                    const preamble = "(" + anyNumberOfSpacesAndAsterisksAtStartOfLine + "|" + singleLineCommentStart + "|" + multiLineCommentStart + ")";
                    const literals = "(?:" + map(descriptors, (d) => "(" + escapeRegExp(d.text) + ")").join("|") + ")";
                    const endOfLineOrEndOfComment = /(?:$|\*\/)/.source;
                    const messageRemainder = /(?:.*?)/.source;
                    const messagePortion = "(" + literals + messageRemainder + ")";
                    const regExpString = preamble + messagePortion + endOfLineOrEndOfComment;
                    return new RegExp(regExpString, "gim");
                }
                function isLetterOrDigit(char) {
                    return char >= 97 /* a */ && char <= 122 /* z */ || char >= 65 /* A */ && char <= 90 /* Z */ || char >= 48 /* _0 */ && char <= 57 /* _9 */;
                }
                function isNodeModulesFile(path) {
                    return path.includes("/node_modules/");
                }
            }
            function getRenameInfo2(fileName, position, preferences) {
                synchronizeHostData();
                return ts_Rename_exports.getRenameInfo(program, getValidSourceFile(fileName), position, preferences || {});
            }
            function getRefactorContext(file, positionOrRange, preferences, formatOptions, triggerReason, kind) {
                const [startPosition, endPosition] = typeof positionOrRange === "number" ? [positionOrRange, void 0] : [positionOrRange.pos, positionOrRange.end];
                return {
                    file,
                    startPosition,
                    endPosition,
                    program: getProgram(),
                    host,
                    formatContext: ts_formatting_exports.getFormatContext(formatOptions, host),
                    // TODO: GH#18217
                    cancellationToken,
                    preferences,
                    triggerReason,
                    kind
                };
            }
            function getInlayHintsContext(file, span, preferences) {
                return {
                    file,
                    program: getProgram(),
                    host,
                    span,
                    preferences,
                    cancellationToken
                };
            }
            function getSmartSelectionRange2(fileName, position) {
                return ts_SmartSelectionRange_exports.getSmartSelectionRange(position, syntaxTreeCache.getCurrentSourceFile(fileName));
            }
            function getApplicableRefactors2(fileName, positionOrRange, preferences = emptyOptions, triggerReason, kind, includeInteractiveActions) {
                synchronizeHostData();
                const file = getValidSourceFile(fileName);
                return ts_refactor_exports.getApplicableRefactors(getRefactorContext(file, positionOrRange, preferences, emptyOptions, triggerReason, kind), includeInteractiveActions);
            }
            function getMoveToRefactoringFileSuggestions(fileName, positionOrRange, preferences = emptyOptions) {
                synchronizeHostData();
                const sourceFile = getValidSourceFile(fileName);
                const allFiles = Debug.checkDefined(program.getSourceFiles());
                const extension = extensionFromPath(fileName);
                const toMove = getStatementsToMove(getRefactorContext(sourceFile, positionOrRange, preferences, emptyOptions));
                const toMoveContainsJsx = containsJsx(toMove == null ? void 0 : toMove.all);
                const files = mapDefined(allFiles, (file) => {
                    const fileNameExtension = extensionFromPath(file.fileName);
                    const isValidSourceFile = !(program == null ? void 0 : program.isSourceFileFromExternalLibrary(sourceFile)) && !(sourceFile === getValidSourceFile(file.fileName) || extension === ".ts" /* Ts */ && fileNameExtension === ".d.ts" /* Dts */ || extension === ".d.ts" /* Dts */ && startsWith(getBaseFileName(file.fileName), "lib.") && fileNameExtension === ".d.ts" /* Dts */);
                    return isValidSourceFile && (extension === fileNameExtension || (extension === ".tsx" /* Tsx */ && fileNameExtension === ".ts" /* Ts */ || extension === ".jsx" /* Jsx */ && fileNameExtension === ".js" /* Js */) && !toMoveContainsJsx) ? file.fileName : void 0;
                });
                return { newFileName: createNewFileName(sourceFile, program, host, toMove), files };
            }
            function getEditsForRefactor2(fileName, formatOptions, positionOrRange, refactorName14, actionName2, preferences = emptyOptions, interactiveRefactorArguments) {
                synchronizeHostData();
                const file = getValidSourceFile(fileName);
                return ts_refactor_exports.getEditsForRefactor(getRefactorContext(file, positionOrRange, preferences, formatOptions), refactorName14, actionName2, interactiveRefactorArguments);
            }
            function toLineColumnOffset(fileName, position) {
                if (position === 0) {
                    return { line: 0, character: 0 };
                }
                return sourceMapper.toLineColumnOffset(fileName, position);
            }
            function prepareCallHierarchy(fileName, position) {
                synchronizeHostData();
                const declarations = ts_CallHierarchy_exports.resolveCallHierarchyDeclaration(program, getTouchingPropertyName(getValidSourceFile(fileName), position));
                return declarations && mapOneOrMany(declarations, (declaration) => ts_CallHierarchy_exports.createCallHierarchyItem(program, declaration));
            }
            function provideCallHierarchyIncomingCalls(fileName, position) {
                synchronizeHostData();
                const sourceFile = getValidSourceFile(fileName);
                const declaration = firstOrOnly(ts_CallHierarchy_exports.resolveCallHierarchyDeclaration(program, position === 0 ? sourceFile : getTouchingPropertyName(sourceFile, position)));
                return declaration ? ts_CallHierarchy_exports.getIncomingCalls(program, declaration, cancellationToken) : [];
            }
            function provideCallHierarchyOutgoingCalls(fileName, position) {
                synchronizeHostData();
                const sourceFile = getValidSourceFile(fileName);
                const declaration = firstOrOnly(ts_CallHierarchy_exports.resolveCallHierarchyDeclaration(program, position === 0 ? sourceFile : getTouchingPropertyName(sourceFile, position)));
                return declaration ? ts_CallHierarchy_exports.getOutgoingCalls(program, declaration) : [];
            }
            function provideInlayHints2(fileName, span, preferences = emptyOptions) {
                synchronizeHostData();
                const sourceFile = getValidSourceFile(fileName);
                return ts_InlayHints_exports.provideInlayHints(getInlayHintsContext(sourceFile, span, preferences));
            }
            const ls = {
                dispose,
                cleanupSemanticCache,
                getSyntacticDiagnostics,
                getSemanticDiagnostics,
                getSuggestionDiagnostics,
                getCompilerOptionsDiagnostics,
                getSyntacticClassifications: getSyntacticClassifications2,
                getSemanticClassifications: getSemanticClassifications3,
                getEncodedSyntacticClassifications: getEncodedSyntacticClassifications2,
                getEncodedSemanticClassifications: getEncodedSemanticClassifications3,
                getCompletionsAtPosition: getCompletionsAtPosition2,
                getCompletionEntryDetails: getCompletionEntryDetails2,
                getCompletionEntrySymbol: getCompletionEntrySymbol2,
                getSignatureHelpItems: getSignatureHelpItems2,
                getQuickInfoAtPosition,
                getDefinitionAtPosition: getDefinitionAtPosition2,
                getDefinitionAndBoundSpan: getDefinitionAndBoundSpan2,
                getImplementationAtPosition,
                getTypeDefinitionAtPosition: getTypeDefinitionAtPosition2,
                getReferencesAtPosition,
                findReferences,
                getFileReferences,
                getDocumentHighlights,
                getNameOrDottedNameSpan,
                getBreakpointStatementAtPosition,
                getNavigateToItems: getNavigateToItems2,
                getRenameInfo: getRenameInfo2,
                getSmartSelectionRange: getSmartSelectionRange2,
                findRenameLocations,
                getNavigationBarItems: getNavigationBarItems2,
                getNavigationTree: getNavigationTree2,
                getOutliningSpans,
                getTodoComments,
                getBraceMatchingAtPosition,
                getIndentationAtPosition,
                getFormattingEditsForRange,
                getFormattingEditsForDocument,
                getFormattingEditsAfterKeystroke,
                getDocCommentTemplateAtPosition: getDocCommentTemplateAtPosition2,
                isValidBraceCompletionAtPosition,
                getJsxClosingTagAtPosition,
                getLinkedEditingRangeAtPosition,
                getSpanOfEnclosingComment,
                getCodeFixesAtPosition,
                getCombinedCodeFix,
                applyCodeActionCommand,
                organizeImports: organizeImports2,
                getEditsForFileRename: getEditsForFileRename2,
                getEmitOutput,
                getNonBoundSourceFile,
                getProgram,
                getCurrentProgram: () => program,
                getAutoImportProvider,
                updateIsDefinitionOfReferencedSymbols,
                getApplicableRefactors: getApplicableRefactors2,
                getEditsForRefactor: getEditsForRefactor2,
                getMoveToRefactoringFileSuggestions,
                toLineColumnOffset,
                getSourceMapper: () => sourceMapper,
                clearSourceMapperCache: () => sourceMapper.clearCache(),
                prepareCallHierarchy,
                provideCallHierarchyIncomingCalls,
                provideCallHierarchyOutgoingCalls,
                toggleLineComment,
                toggleMultilineComment,
                commentSelection,
                uncommentSelection,
                provideInlayHints: provideInlayHints2,
                getSupportedCodeFixes
            };
            switch (languageServiceMode) {
                case 0 /* Semantic */:
                    break;
                case 1 /* PartialSemantic */:
                    invalidOperationsInPartialSemanticMode.forEach((key) => ls[key] = () => {
                        throw new Error(`LanguageService Operation: ${key} not allowed in LanguageServiceMode.PartialSemantic`);
                    });
                    break;
                case 2 /* Syntactic */:
                    invalidOperationsInSyntacticMode.forEach((key) => ls[key] = () => {
                        throw new Error(`LanguageService Operation: ${key} not allowed in LanguageServiceMode.Syntactic`);
                    });
                    break;
                default:
                    Debug.assertNever(languageServiceMode);
            }
            return ls;
        }
        function getNameTable(sourceFile) {
            if (!sourceFile.nameTable) {
                initializeNameTable(sourceFile);
            }
            return sourceFile.nameTable;
        }
        function initializeNameTable(sourceFile) {
            const nameTable = sourceFile.nameTable = /* @__PURE__ */ new Map();
            sourceFile.forEachChild(function walk(node) {
                if (isIdentifier(node) && !isTagName(node) && node.escapedText || isStringOrNumericLiteralLike(node) && literalIsName(node)) {
                    const text = getEscapedTextOfIdentifierOrLiteral(node);
                    nameTable.set(text, nameTable.get(text) === void 0 ? node.pos : -1);
                }
                else if (isPrivateIdentifier(node)) {
                    const text = node.escapedText;
                    nameTable.set(text, nameTable.get(text) === void 0 ? node.pos : -1);
                }
                forEachChild(node, walk);
                if (hasJSDocNodes(node)) {
                    for (const jsDoc of node.jsDoc) {
                        forEachChild(jsDoc, walk);
                    }
                }
            });
        }
        function literalIsName(node) {
            return isDeclarationName(node) || node.parent.kind === 283 /* ExternalModuleReference */ || isArgumentOfElementAccessExpression(node) || isLiteralComputedPropertyDeclarationName(node);
        }
        function getContainingObjectLiteralElement(node) {
            const element = getContainingObjectLiteralElementWorker(node);
            return element && (isObjectLiteralExpression(element.parent) || isJsxAttributes(element.parent)) ? element : void 0;
        }
        function getContainingObjectLiteralElementWorker(node) {
            switch (node.kind) {
                case 11 /* StringLiteral */:
                case 15 /* NoSubstitutionTemplateLiteral */:
                case 9 /* NumericLiteral */:
                    if (node.parent.kind === 167 /* ComputedPropertyName */) {
                        return isObjectLiteralElement(node.parent.parent) ? node.parent.parent : void 0;
                    }
                case 80 /* Identifier */:
                    return isObjectLiteralElement(node.parent) && (node.parent.parent.kind === 210 /* ObjectLiteralExpression */ || node.parent.parent.kind === 292 /* JsxAttributes */) && node.parent.name === node ? node.parent : void 0;
            }
            return void 0;
        }
        function getSymbolAtLocationForQuickInfo(node, checker) {
            const object = getContainingObjectLiteralElement(node);
            if (object) {
                const contextualType = checker.getContextualType(object.parent);
                const properties = contextualType && getPropertySymbolsFromContextualType(object, checker, contextualType, 
                /*unionSymbolOk*/
                false);
                if (properties && properties.length === 1) {
                    return first(properties);
                }
            }
            return checker.getSymbolAtLocation(node);
        }
        function getPropertySymbolsFromContextualType(node, checker, contextualType, unionSymbolOk) {
            const name = getNameFromPropertyName(node.name);
            if (!name)
                return emptyArray;
            if (!contextualType.isUnion()) {
                const symbol = contextualType.getProperty(name);
                return symbol ? [symbol] : emptyArray;
            }
            const filteredTypes = isObjectLiteralExpression(node.parent) || isJsxAttributes(node.parent) ? filter(contextualType.types, (t) => !checker.isTypeInvalidDueToUnionDiscriminant(t, node.parent)) : contextualType.types;
            const discriminatedPropertySymbols = mapDefined(filteredTypes, (t) => t.getProperty(name));
            if (unionSymbolOk && (discriminatedPropertySymbols.length === 0 || discriminatedPropertySymbols.length === contextualType.types.length)) {
                const symbol = contextualType.getProperty(name);
                if (symbol)
                    return [symbol];
            }
            if (!filteredTypes.length && !discriminatedPropertySymbols.length) {
                return mapDefined(contextualType.types, (t) => t.getProperty(name));
            }
            return deduplicate(discriminatedPropertySymbols, equateValues);
        }
        function isArgumentOfElementAccessExpression(node) {
            return node && node.parent && node.parent.kind === 212 /* ElementAccessExpression */ && node.parent.argumentExpression === node;
        }
        function getDefaultLibFilePath(options) {
            if (sys) {
                return combinePaths(getDirectoryPath(normalizePath(sys.getExecutingFilePath())), getDefaultLibFileName(options));
            }
            throw new Error("getDefaultLibFilePath is only supported when consumed as a node module. ");
        }
        var servicesVersion, NodeObject, TokenOrIdentifierObject, SymbolObject, TokenObject, IdentifierObject, PrivateIdentifierObject, TypeObject, SignatureObject, SourceFileObject, SourceMapSourceObject, SyntaxTreeCache, NoopCancellationToken, CancellationTokenObject, ThrottledCancellationToken, invalidOperationsInPartialSemanticMode, invalidOperationsInSyntacticMode;
        var init_services = __esm({
            "src/services/services.ts"() {
                "use strict";
                init_ts4();
                init_ts_NavigateTo();
                init_ts_NavigationBar();
                init_ts_refactor();
                init_classifier();
                init_classifier2020();
                servicesVersion = "0.8";
                NodeObject = class {
                    constructor(kind, pos, end) {
                        this.pos = pos;
                        this.end = end;
                        this.flags = 0 /* None */;
                        this.modifierFlagsCache = 0 /* None */;
                        this.transformFlags = 0 /* None */;
                        this.parent = void 0;
                        this.kind = kind;
                    }
                    assertHasRealPosition(message) {
                        Debug.assert(!positionIsSynthesized(this.pos) && !positionIsSynthesized(this.end), message || "Node must have a real position for this operation");
                    }
                    getSourceFile() {
                        return getSourceFileOfNode(this);
                    }
                    getStart(sourceFile, includeJsDocComment) {
                        this.assertHasRealPosition();
                        return getTokenPosOfNode(this, sourceFile, includeJsDocComment);
                    }
                    getFullStart() {
                        this.assertHasRealPosition();
                        return this.pos;
                    }
                    getEnd() {
                        this.assertHasRealPosition();
                        return this.end;
                    }
                    getWidth(sourceFile) {
                        this.assertHasRealPosition();
                        return this.getEnd() - this.getStart(sourceFile);
                    }
                    getFullWidth() {
                        this.assertHasRealPosition();
                        return this.end - this.pos;
                    }
                    getLeadingTriviaWidth(sourceFile) {
                        this.assertHasRealPosition();
                        return this.getStart(sourceFile) - this.pos;
                    }
                    getFullText(sourceFile) {
                        this.assertHasRealPosition();
                        return (sourceFile || this.getSourceFile()).text.substring(this.pos, this.end);
                    }
                    getText(sourceFile) {
                        this.assertHasRealPosition();
                        if (!sourceFile) {
                            sourceFile = this.getSourceFile();
                        }
                        return sourceFile.text.substring(this.getStart(sourceFile), this.getEnd());
                    }
                    getChildCount(sourceFile) {
                        return this.getChildren(sourceFile).length;
                    }
                    getChildAt(index, sourceFile) {
                        return this.getChildren(sourceFile)[index];
                    }
                    getChildren(sourceFile) {
                        this.assertHasRealPosition("Node without a real position cannot be scanned and thus has no token nodes - use forEachChild and collect the result if that's fine");
                        return this._children || (this._children = createChildren(this, sourceFile));
                    }
                    getFirstToken(sourceFile) {
                        this.assertHasRealPosition();
                        const children = this.getChildren(sourceFile);
                        if (!children.length) {
                            return void 0;
                        }
                        const child = find(children, (kid) => kid.kind < 316 /* FirstJSDocNode */ || kid.kind > 357 /* LastJSDocNode */);
                        return child.kind < 166 /* FirstNode */ ? child : child.getFirstToken(sourceFile);
                    }
                    getLastToken(sourceFile) {
                        this.assertHasRealPosition();
                        const children = this.getChildren(sourceFile);
                        const child = lastOrUndefined(children);
                        if (!child) {
                            return void 0;
                        }
                        return child.kind < 166 /* FirstNode */ ? child : child.getLastToken(sourceFile);
                    }
                    forEachChild(cbNode, cbNodeArray) {
                        return forEachChild(this, cbNode, cbNodeArray);
                    }
                };
                TokenOrIdentifierObject = class {
                    constructor(pos, end) {
                        this.pos = pos;
                        this.end = end;
                        this.flags = 0 /* None */;
                        this.modifierFlagsCache = 0 /* None */;
                        this.transformFlags = 0 /* None */;
                        this.parent = void 0;
                    }
                    getSourceFile() {
                        return getSourceFileOfNode(this);
                    }
                    getStart(sourceFile, includeJsDocComment) {
                        return getTokenPosOfNode(this, sourceFile, includeJsDocComment);
                    }
                    getFullStart() {
                        return this.pos;
                    }
                    getEnd() {
                        return this.end;
                    }
                    getWidth(sourceFile) {
                        return this.getEnd() - this.getStart(sourceFile);
                    }
                    getFullWidth() {
                        return this.end - this.pos;
                    }
                    getLeadingTriviaWidth(sourceFile) {
                        return this.getStart(sourceFile) - this.pos;
                    }
                    getFullText(sourceFile) {
                        return (sourceFile || this.getSourceFile()).text.substring(this.pos, this.end);
                    }
                    getText(sourceFile) {
                        if (!sourceFile) {
                            sourceFile = this.getSourceFile();
                        }
                        return sourceFile.text.substring(this.getStart(sourceFile), this.getEnd());
                    }
                    getChildCount() {
                        return this.getChildren().length;
                    }
                    getChildAt(index) {
                        return this.getChildren()[index];
                    }
                    getChildren() {
                        return this.kind === 1 /* EndOfFileToken */ ? this.jsDoc || emptyArray : emptyArray;
                    }
                    getFirstToken() {
                        return void 0;
                    }
                    getLastToken() {
                        return void 0;
                    }
                    forEachChild() {
                        return void 0;
                    }
                };
                SymbolObject = class {
                    constructor(flags, name) {
                        this.id = 0;
                        this.mergeId = 0;
                        this.flags = flags;
                        this.escapedName = name;
                    }
                    getFlags() {
                        return this.flags;
                    }
                    get name() {
                        return symbolName(this);
                    }
                    getEscapedName() {
                        return this.escapedName;
                    }
                    getName() {
                        return this.name;
                    }
                    getDeclarations() {
                        return this.declarations;
                    }
                    getDocumentationComment(checker) {
                        if (!this.documentationComment) {
                            this.documentationComment = emptyArray;
                            if (!this.declarations && isTransientSymbol(this) && this.links.target && isTransientSymbol(this.links.target) && this.links.target.links.tupleLabelDeclaration) {
                                const labelDecl = this.links.target.links.tupleLabelDeclaration;
                                this.documentationComment = getDocumentationComment([labelDecl], checker);
                            }
                            else {
                                this.documentationComment = getDocumentationComment(this.declarations, checker);
                            }
                        }
                        return this.documentationComment;
                    }
                    getContextualDocumentationComment(context, checker) {
                        if (context) {
                            if (isGetAccessor(context)) {
                                if (!this.contextualGetAccessorDocumentationComment) {
                                    this.contextualGetAccessorDocumentationComment = getDocumentationComment(filter(this.declarations, isGetAccessor), checker);
                                }
                                if (length(this.contextualGetAccessorDocumentationComment)) {
                                    return this.contextualGetAccessorDocumentationComment;
                                }
                            }
                            if (isSetAccessor(context)) {
                                if (!this.contextualSetAccessorDocumentationComment) {
                                    this.contextualSetAccessorDocumentationComment = getDocumentationComment(filter(this.declarations, isSetAccessor), checker);
                                }
                                if (length(this.contextualSetAccessorDocumentationComment)) {
                                    return this.contextualSetAccessorDocumentationComment;
                                }
                            }
                        }
                        return this.getDocumentationComment(checker);
                    }
                    getJsDocTags(checker) {
                        if (this.tags === void 0) {
                            this.tags = getJsDocTagsOfDeclarations(this.declarations, checker);
                        }
                        return this.tags;
                    }
                    getContextualJsDocTags(context, checker) {
                        if (context) {
                            if (isGetAccessor(context)) {
                                if (!this.contextualGetAccessorTags) {
                                    this.contextualGetAccessorTags = getJsDocTagsOfDeclarations(filter(this.declarations, isGetAccessor), checker);
                                }
                                if (length(this.contextualGetAccessorTags)) {
                                    return this.contextualGetAccessorTags;
                                }
                            }
                            if (isSetAccessor(context)) {
                                if (!this.contextualSetAccessorTags) {
                                    this.contextualSetAccessorTags = getJsDocTagsOfDeclarations(filter(this.declarations, isSetAccessor), checker);
                                }
                                if (length(this.contextualSetAccessorTags)) {
                                    return this.contextualSetAccessorTags;
                                }
                            }
                        }
                        return this.getJsDocTags(checker);
                    }
                };
                TokenObject = class extends TokenOrIdentifierObject {
                    constructor(kind, pos, end) {
                        super(pos, end);
                        this.kind = kind;
                    }
                };
                IdentifierObject = class extends TokenOrIdentifierObject {
                    constructor(_kind, pos, end) {
                        super(pos, end);
                        this.kind = 80 /* Identifier */;
                    }
                    get text() {
                        return idText(this);
                    }
                };
                IdentifierObject.prototype.kind = 80 /* Identifier */;
                PrivateIdentifierObject = class extends TokenOrIdentifierObject {
                    constructor(_kind, pos, end) {
                        super(pos, end);
                        this.kind = 81 /* PrivateIdentifier */;
                    }
                    get text() {
                        return idText(this);
                    }
                };
                PrivateIdentifierObject.prototype.kind = 81 /* PrivateIdentifier */;
                TypeObject = class {
                    constructor(checker, flags) {
                        this.checker = checker;
                        this.flags = flags;
                    }
                    getFlags() {
                        return this.flags;
                    }
                    getSymbol() {
                        return this.symbol;
                    }
                    getProperties() {
                        return this.checker.getPropertiesOfType(this);
                    }
                    getProperty(propertyName) {
                        return this.checker.getPropertyOfType(this, propertyName);
                    }
                    getApparentProperties() {
                        return this.checker.getAugmentedPropertiesOfType(this);
                    }
                    getCallSignatures() {
                        return this.checker.getSignaturesOfType(this, 0 /* Call */);
                    }
                    getConstructSignatures() {
                        return this.checker.getSignaturesOfType(this, 1 /* Construct */);
                    }
                    getStringIndexType() {
                        return this.checker.getIndexTypeOfType(this, 0 /* String */);
                    }
                    getNumberIndexType() {
                        return this.checker.getIndexTypeOfType(this, 1 /* Number */);
                    }
                    getBaseTypes() {
                        return this.isClassOrInterface() ? this.checker.getBaseTypes(this) : void 0;
                    }
                    isNullableType() {
                        return this.checker.isNullableType(this);
                    }
                    getNonNullableType() {
                        return this.checker.getNonNullableType(this);
                    }
                    getNonOptionalType() {
                        return this.checker.getNonOptionalType(this);
                    }
                    getConstraint() {
                        return this.checker.getBaseConstraintOfType(this);
                    }
                    getDefault() {
                        return this.checker.getDefaultFromTypeParameter(this);
                    }
                    isUnion() {
                        return !!(this.flags & 1048576 /* Union */);
                    }
                    isIntersection() {
                        return !!(this.flags & 2097152 /* Intersection */);
                    }
                    isUnionOrIntersection() {
                        return !!(this.flags & 3145728 /* UnionOrIntersection */);
                    }
                    isLiteral() {
                        return !!(this.flags & (128 /* StringLiteral */ | 256 /* NumberLiteral */ | 2048 /* BigIntLiteral */));
                    }
                    isStringLiteral() {
                        return !!(this.flags & 128 /* StringLiteral */);
                    }
                    isNumberLiteral() {
                        return !!(this.flags & 256 /* NumberLiteral */);
                    }
                    isTypeParameter() {
                        return !!(this.flags & 262144 /* TypeParameter */);
                    }
                    isClassOrInterface() {
                        return !!(getObjectFlags(this) & 3 /* ClassOrInterface */);
                    }
                    isClass() {
                        return !!(getObjectFlags(this) & 1 /* Class */);
                    }
                    isIndexType() {
                        return !!(this.flags & 4194304 /* Index */);
                    }
                    /**
                     * This polyfills `referenceType.typeArguments` for API consumers
                     */
                    get typeArguments() {
                        if (getObjectFlags(this) & 4 /* Reference */) {
                            return this.checker.getTypeArguments(this);
                        }
                        return void 0;
                    }
                };
                SignatureObject = class {
                    // same
                    constructor(checker, flags) {
                        this.checker = checker;
                        this.flags = flags;
                    }
                    getDeclaration() {
                        return this.declaration;
                    }
                    getTypeParameters() {
                        return this.typeParameters;
                    }
                    getParameters() {
                        return this.parameters;
                    }
                    getReturnType() {
                        return this.checker.getReturnTypeOfSignature(this);
                    }
                    getTypeParameterAtPosition(pos) {
                        const type = this.checker.getParameterType(this, pos);
                        if (type.isIndexType() && isThisTypeParameter(type.type)) {
                            const constraint = type.type.getConstraint();
                            if (constraint) {
                                return this.checker.getIndexType(constraint);
                            }
                        }
                        return type;
                    }
                    getDocumentationComment() {
                        return this.documentationComment || (this.documentationComment = getDocumentationComment(singleElementArray(this.declaration), this.checker));
                    }
                    getJsDocTags() {
                        return this.jsDocTags || (this.jsDocTags = getJsDocTagsOfDeclarations(singleElementArray(this.declaration), this.checker));
                    }
                };
                SourceFileObject = class extends NodeObject {
                    constructor(kind, pos, end) {
                        super(kind, pos, end);
                        this.kind = 312 /* SourceFile */;
                    }
                    update(newText, textChangeRange) {
                        return updateSourceFile(this, newText, textChangeRange);
                    }
                    getLineAndCharacterOfPosition(position) {
                        return getLineAndCharacterOfPosition(this, position);
                    }
                    getLineStarts() {
                        return getLineStarts(this);
                    }
                    getPositionOfLineAndCharacter(line, character, allowEdits) {
                        return computePositionOfLineAndCharacter(getLineStarts(this), line, character, this.text, allowEdits);
                    }
                    getLineEndOfPosition(pos) {
                        const { line } = this.getLineAndCharacterOfPosition(pos);
                        const lineStarts = this.getLineStarts();
                        let lastCharPos;
                        if (line + 1 >= lineStarts.length) {
                            lastCharPos = this.getEnd();
                        }
                        if (!lastCharPos) {
                            lastCharPos = lineStarts[line + 1] - 1;
                        }
                        const fullText = this.getFullText();
                        return fullText[lastCharPos] === "\n" && fullText[lastCharPos - 1] === "\r" ? lastCharPos - 1 : lastCharPos;
                    }
                    getNamedDeclarations() {
                        if (!this.namedDeclarations) {
                            this.namedDeclarations = this.computeNamedDeclarations();
                        }
                        return this.namedDeclarations;
                    }
                    computeNamedDeclarations() {
                        const result = createMultiMap();
                        this.forEachChild(visit);
                        return result;
                        function addDeclaration(declaration) {
                            const name = getDeclarationName(declaration);
                            if (name) {
                                result.add(name, declaration);
                            }
                        }
                        function getDeclarations(name) {
                            let declarations = result.get(name);
                            if (!declarations) {
                                result.set(name, declarations = []);
                            }
                            return declarations;
                        }
                        function getDeclarationName(declaration) {
                            const name = getNonAssignedNameOfDeclaration(declaration);
                            return name && (isComputedPropertyName(name) && isPropertyAccessExpression(name.expression) ? name.expression.name.text : isPropertyName(name) ? getNameFromPropertyName(name) : void 0);
                        }
                        function visit(node) {
                            switch (node.kind) {
                                case 262 /* FunctionDeclaration */:
                                case 218 /* FunctionExpression */:
                                case 174 /* MethodDeclaration */:
                                case 173 /* MethodSignature */:
                                    const functionDeclaration = node;
                                    const declarationName = getDeclarationName(functionDeclaration);
                                    if (declarationName) {
                                        const declarations = getDeclarations(declarationName);
                                        const lastDeclaration = lastOrUndefined(declarations);
                                        if (lastDeclaration && functionDeclaration.parent === lastDeclaration.parent && functionDeclaration.symbol === lastDeclaration.symbol) {
                                            if (functionDeclaration.body && !lastDeclaration.body) {
                                                declarations[declarations.length - 1] = functionDeclaration;
                                            }
                                        }
                                        else {
                                            declarations.push(functionDeclaration);
                                        }
                                    }
                                    forEachChild(node, visit);
                                    break;
                                case 263 /* ClassDeclaration */:
                                case 231 /* ClassExpression */:
                                case 264 /* InterfaceDeclaration */:
                                case 265 /* TypeAliasDeclaration */:
                                case 266 /* EnumDeclaration */:
                                case 267 /* ModuleDeclaration */:
                                case 271 /* ImportEqualsDeclaration */:
                                case 281 /* ExportSpecifier */:
                                case 276 /* ImportSpecifier */:
                                case 273 /* ImportClause */:
                                case 274 /* NamespaceImport */:
                                case 177 /* GetAccessor */:
                                case 178 /* SetAccessor */:
                                case 187 /* TypeLiteral */:
                                    addDeclaration(node);
                                    forEachChild(node, visit);
                                    break;
                                case 169 /* Parameter */:
                                    if (!hasSyntacticModifier(node, 31 /* ParameterPropertyModifier */)) {
                                        break;
                                    }
                                case 260 /* VariableDeclaration */:
                                case 208 /* BindingElement */: {
                                    const decl = node;
                                    if (isBindingPattern(decl.name)) {
                                        forEachChild(decl.name, visit);
                                        break;
                                    }
                                    if (decl.initializer) {
                                        visit(decl.initializer);
                                    }
                                }
                                case 306 /* EnumMember */:
                                case 172 /* PropertyDeclaration */:
                                case 171 /* PropertySignature */:
                                    addDeclaration(node);
                                    break;
                                case 278 /* ExportDeclaration */:
                                    const exportDeclaration = node;
                                    if (exportDeclaration.exportClause) {
                                        if (isNamedExports(exportDeclaration.exportClause)) {
                                            forEach(exportDeclaration.exportClause.elements, visit);
                                        }
                                        else {
                                            visit(exportDeclaration.exportClause.name);
                                        }
                                    }
                                    break;
                                case 272 /* ImportDeclaration */:
                                    const importClause = node.importClause;
                                    if (importClause) {
                                        if (importClause.name) {
                                            addDeclaration(importClause.name);
                                        }
                                        if (importClause.namedBindings) {
                                            if (importClause.namedBindings.kind === 274 /* NamespaceImport */) {
                                                addDeclaration(importClause.namedBindings);
                                            }
                                            else {
                                                forEach(importClause.namedBindings.elements, visit);
                                            }
                                        }
                                    }
                                    break;
                                case 226 /* BinaryExpression */:
                                    if (getAssignmentDeclarationKind(node) !== 0 /* None */) {
                                        addDeclaration(node);
                                    }
                                default:
                                    forEachChild(node, visit);
                            }
                        }
                    }
                };
                SourceMapSourceObject = class {
                    constructor(fileName, text, skipTrivia2) {
                        this.fileName = fileName;
                        this.text = text;
                        this.skipTrivia = skipTrivia2;
                    }
                    getLineAndCharacterOfPosition(pos) {
                        return getLineAndCharacterOfPosition(this, pos);
                    }
                };
                SyntaxTreeCache = class {
                    constructor(host) {
                        this.host = host;
                    }
                    getCurrentSourceFile(fileName) {
                        var _a, _b, _c, _d, _e, _f, _g, _h;
                        const scriptSnapshot = this.host.getScriptSnapshot(fileName);
                        if (!scriptSnapshot) {
                            throw new Error("Could not find file: '" + fileName + "'.");
                        }
                        const scriptKind = getScriptKind(fileName, this.host);
                        const version2 = this.host.getScriptVersion(fileName);
                        let sourceFile;
                        if (this.currentFileName !== fileName) {
                            const options = {
                                languageVersion: 99 /* Latest */,
                                impliedNodeFormat: getImpliedNodeFormatForFile(toPath(fileName, this.host.getCurrentDirectory(), ((_c = (_b = (_a = this.host).getCompilerHost) == null ? void 0 : _b.call(_a)) == null ? void 0 : _c.getCanonicalFileName) || hostGetCanonicalFileName(this.host)), (_h = (_g = (_f = (_e = (_d = this.host).getCompilerHost) == null ? void 0 : _e.call(_d)) == null ? void 0 : _f.getModuleResolutionCache) == null ? void 0 : _g.call(_f)) == null ? void 0 : _h.getPackageJsonInfoCache(), this.host, this.host.getCompilationSettings()),
                                setExternalModuleIndicator: getSetExternalModuleIndicator(this.host.getCompilationSettings()),
                                // These files are used to produce syntax-based highlighting, which reads JSDoc, so we must use ParseAll.
                                jsDocParsingMode: 0 /* ParseAll */
                            };
                            sourceFile = createLanguageServiceSourceFile(fileName, scriptSnapshot, options, version2, 
                            /*setNodeParents*/
                            true, scriptKind);
                        }
                        else if (this.currentFileVersion !== version2) {
                            const editRange = scriptSnapshot.getChangeRange(this.currentFileScriptSnapshot);
                            sourceFile = updateLanguageServiceSourceFile(this.currentSourceFile, scriptSnapshot, version2, editRange);
                        }
                        if (sourceFile) {
                            this.currentFileVersion = version2;
                            this.currentFileName = fileName;
                            this.currentFileScriptSnapshot = scriptSnapshot;
                            this.currentSourceFile = sourceFile;
                        }
                        return this.currentSourceFile;
                    }
                };
                NoopCancellationToken = {
                    isCancellationRequested: returnFalse,
                    throwIfCancellationRequested: noop
                };
                CancellationTokenObject = class {
                    constructor(cancellationToken) {
                        this.cancellationToken = cancellationToken;
                    }
                    isCancellationRequested() {
                        return this.cancellationToken.isCancellationRequested();
                    }
                    throwIfCancellationRequested() {
                        var _a;
                        if (this.isCancellationRequested()) {
                            (_a = tracing) == null ? void 0 : _a.instant(tracing.Phase.Session, "cancellationThrown", { kind: "CancellationTokenObject" });
                            throw new OperationCanceledException();
                        }
                    }
                };
                ThrottledCancellationToken = class {
                    constructor(hostCancellationToken, throttleWaitMilliseconds = 20) {
                        this.hostCancellationToken = hostCancellationToken;
                        this.throttleWaitMilliseconds = throttleWaitMilliseconds;
                        // Store when we last tried to cancel.  Checking cancellation can be expensive (as we have
                        // to marshall over to the host layer).  So we only bother actually checking once enough
                        // time has passed.
                        this.lastCancellationCheckTime = 0;
                    }
                    isCancellationRequested() {
                        const time = timestamp();
                        const duration = Math.abs(time - this.lastCancellationCheckTime);
                        if (duration >= this.throttleWaitMilliseconds) {
                            this.lastCancellationCheckTime = time;
                            return this.hostCancellationToken.isCancellationRequested();
                        }
                        return false;
                    }
                    throwIfCancellationRequested() {
                        var _a;
                        if (this.isCancellationRequested()) {
                            (_a = tracing) == null ? void 0 : _a.instant(tracing.Phase.Session, "cancellationThrown", { kind: "ThrottledCancellationToken" });
                            throw new OperationCanceledException();
                        }
                    }
                };
                invalidOperationsInPartialSemanticMode = [
                    "getSemanticDiagnostics",
                    "getSuggestionDiagnostics",
                    "getCompilerOptionsDiagnostics",
                    "getSemanticClassifications",
                    "getEncodedSemanticClassifications",
                    "getCodeFixesAtPosition",
                    "getCombinedCodeFix",
                    "applyCodeActionCommand",
                    "organizeImports",
                    "getEditsForFileRename",
                    "getEmitOutput",
                    "getApplicableRefactors",
                    "getEditsForRefactor",
                    "prepareCallHierarchy",
                    "provideCallHierarchyIncomingCalls",
                    "provideCallHierarchyOutgoingCalls",
                    "provideInlayHints",
                    "getSupportedCodeFixes"
                ];
                invalidOperationsInSyntacticMode = [
                    ...invalidOperationsInPartialSemanticMode,
                    "getCompletionsAtPosition",
                    "getCompletionEntryDetails",
                    "getCompletionEntrySymbol",
                    "getSignatureHelpItems",
                    "getQuickInfoAtPosition",
                    "getDefinitionAtPosition",
                    "getDefinitionAndBoundSpan",
                    "getImplementationAtPosition",
                    "getTypeDefinitionAtPosition",
                    "getReferencesAtPosition",
                    "findReferences",
                    "getDocumentHighlights",
                    "getNavigateToItems",
                    "getRenameInfo",
                    "findRenameLocations",
                    "getApplicableRefactors"
                ];
                setObjectAllocator(getServicesObjectAllocator());
            }
        });
        // src/services/transform.ts
        function transform(source, transformers, compilerOptions) {
            const diagnostics = [];
            compilerOptions = fixupCompilerOptions(compilerOptions, diagnostics);
            const nodes = isArray(source) ? source : [source];
            const result = transformNodes(
            /*resolver*/
            void 0, 
            /*host*/
            void 0, factory, compilerOptions, nodes, transformers, 
            /*allowDtsFiles*/
            true);
            result.diagnostics = concatenate(result.diagnostics, diagnostics);
            return result;
        }
        var init_transform = __esm({
            "src/services/transform.ts"() {
                "use strict";
                init_ts4();
            }
        });
        // src/services/breakpoints.ts
        function spanInSourceFileAtLocation(sourceFile, position) {
            if (sourceFile.isDeclarationFile) {
                return void 0;
            }
            let tokenAtLocation = getTokenAtPosition(sourceFile, position);
            const lineOfPosition = sourceFile.getLineAndCharacterOfPosition(position).line;
            if (sourceFile.getLineAndCharacterOfPosition(tokenAtLocation.getStart(sourceFile)).line > lineOfPosition) {
                const preceding = findPrecedingToken(tokenAtLocation.pos, sourceFile);
                if (!preceding || sourceFile.getLineAndCharacterOfPosition(preceding.getEnd()).line !== lineOfPosition) {
                    return void 0;
                }
                tokenAtLocation = preceding;
            }
            if (tokenAtLocation.flags & 33554432 /* Ambient */) {
                return void 0;
            }
            return spanInNode(tokenAtLocation);
            function textSpan(startNode2, endNode2) {
                const lastDecorator = canHaveDecorators(startNode2) ? findLast(startNode2.modifiers, isDecorator) : void 0;
                const start = lastDecorator ? skipTrivia(sourceFile.text, lastDecorator.end) : startNode2.getStart(sourceFile);
                return createTextSpanFromBounds(start, (endNode2 || startNode2).getEnd());
            }
            function textSpanEndingAtNextToken(startNode2, previousTokenToFindNextEndToken) {
                return textSpan(startNode2, findNextToken(previousTokenToFindNextEndToken, previousTokenToFindNextEndToken.parent, sourceFile));
            }
            function spanInNodeIfStartsOnSameLine(node, otherwiseOnNode) {
                if (node && lineOfPosition === sourceFile.getLineAndCharacterOfPosition(node.getStart(sourceFile)).line) {
                    return spanInNode(node);
                }
                return spanInNode(otherwiseOnNode);
            }
            function spanInNodeArray(nodeArray, node, match) {
                if (nodeArray) {
                    const index = nodeArray.indexOf(node);
                    if (index >= 0) {
                        let start = index;
                        let end = index + 1;
                        while (start > 0 && match(nodeArray[start - 1]))
                            start--;
                        while (end < nodeArray.length && match(nodeArray[end]))
                            end++;
                        return createTextSpanFromBounds(skipTrivia(sourceFile.text, nodeArray[start].pos), nodeArray[end - 1].end);
                    }
                }
                return textSpan(node);
            }
            function spanInPreviousNode(node) {
                return spanInNode(findPrecedingToken(node.pos, sourceFile));
            }
            function spanInNextNode(node) {
                return spanInNode(findNextToken(node, node.parent, sourceFile));
            }
            function spanInNode(node) {
                if (node) {
                    const { parent: parent2 } = node;
                    switch (node.kind) {
                        case 243 /* VariableStatement */:
                            return spanInVariableDeclaration(node.declarationList.declarations[0]);
                        case 260 /* VariableDeclaration */:
                        case 172 /* PropertyDeclaration */:
                        case 171 /* PropertySignature */:
                            return spanInVariableDeclaration(node);
                        case 169 /* Parameter */:
                            return spanInParameterDeclaration(node);
                        case 262 /* FunctionDeclaration */:
                        case 174 /* MethodDeclaration */:
                        case 173 /* MethodSignature */:
                        case 177 /* GetAccessor */:
                        case 178 /* SetAccessor */:
                        case 176 /* Constructor */:
                        case 218 /* FunctionExpression */:
                        case 219 /* ArrowFunction */:
                            return spanInFunctionDeclaration(node);
                        case 241 /* Block */:
                            if (isFunctionBlock(node)) {
                                return spanInFunctionBlock(node);
                            }
                        case 268 /* ModuleBlock */:
                            return spanInBlock(node);
                        case 299 /* CatchClause */:
                            return spanInBlock(node.block);
                        case 244 /* ExpressionStatement */:
                            return textSpan(node.expression);
                        case 253 /* ReturnStatement */:
                            return textSpan(node.getChildAt(0), node.expression);
                        case 247 /* WhileStatement */:
                            return textSpanEndingAtNextToken(node, node.expression);
                        case 246 /* DoStatement */:
                            return spanInNode(node.statement);
                        case 259 /* DebuggerStatement */:
                            return textSpan(node.getChildAt(0));
                        case 245 /* IfStatement */:
                            return textSpanEndingAtNextToken(node, node.expression);
                        case 256 /* LabeledStatement */:
                            return spanInNode(node.statement);
                        case 252 /* BreakStatement */:
                        case 251 /* ContinueStatement */:
                            return textSpan(node.getChildAt(0), node.label);
                        case 248 /* ForStatement */:
                            return spanInForStatement(node);
                        case 249 /* ForInStatement */:
                            return textSpanEndingAtNextToken(node, node.expression);
                        case 250 /* ForOfStatement */:
                            return spanInInitializerOfForLike(node);
                        case 255 /* SwitchStatement */:
                            return textSpanEndingAtNextToken(node, node.expression);
                        case 296 /* CaseClause */:
                        case 297 /* DefaultClause */:
                            return spanInNode(node.statements[0]);
                        case 258 /* TryStatement */:
                            return spanInBlock(node.tryBlock);
                        case 257 /* ThrowStatement */:
                            return textSpan(node, node.expression);
                        case 277 /* ExportAssignment */:
                            return textSpan(node, node.expression);
                        case 271 /* ImportEqualsDeclaration */:
                            return textSpan(node, node.moduleReference);
                        case 272 /* ImportDeclaration */:
                            return textSpan(node, node.moduleSpecifier);
                        case 278 /* ExportDeclaration */:
                            return textSpan(node, node.moduleSpecifier);
                        case 267 /* ModuleDeclaration */:
                            if (getModuleInstanceState(node) !== 1 /* Instantiated */) {
                                return void 0;
                            }
                        case 263 /* ClassDeclaration */:
                        case 266 /* EnumDeclaration */:
                        case 306 /* EnumMember */:
                        case 208 /* BindingElement */:
                            return textSpan(node);
                        case 254 /* WithStatement */:
                            return spanInNode(node.statement);
                        case 170 /* Decorator */:
                            return spanInNodeArray(parent2.modifiers, node, isDecorator);
                        case 206 /* ObjectBindingPattern */:
                        case 207 /* ArrayBindingPattern */:
                            return spanInBindingPattern(node);
                        case 264 /* InterfaceDeclaration */:
                        case 265 /* TypeAliasDeclaration */:
                            return void 0;
                        case 27 /* SemicolonToken */:
                        case 1 /* EndOfFileToken */:
                            return spanInNodeIfStartsOnSameLine(findPrecedingToken(node.pos, sourceFile));
                        case 28 /* CommaToken */:
                            return spanInPreviousNode(node);
                        case 19 /* OpenBraceToken */:
                            return spanInOpenBraceToken(node);
                        case 20 /* CloseBraceToken */:
                            return spanInCloseBraceToken(node);
                        case 24 /* CloseBracketToken */:
                            return spanInCloseBracketToken(node);
                        case 21 /* OpenParenToken */:
                            return spanInOpenParenToken(node);
                        case 22 /* CloseParenToken */:
                            return spanInCloseParenToken(node);
                        case 59 /* ColonToken */:
                            return spanInColonToken(node);
                        case 32 /* GreaterThanToken */:
                        case 30 /* LessThanToken */:
                            return spanInGreaterThanOrLessThanToken(node);
                        case 117 /* WhileKeyword */:
                            return spanInWhileKeyword(node);
                        case 93 /* ElseKeyword */:
                        case 85 /* CatchKeyword */:
                        case 98 /* FinallyKeyword */:
                            return spanInNextNode(node);
                        case 165 /* OfKeyword */:
                            return spanInOfKeyword(node);
                        default:
                            if (isArrayLiteralOrObjectLiteralDestructuringPattern(node)) {
                                return spanInArrayLiteralOrObjectLiteralDestructuringPattern(node);
                            }
                            if ((node.kind === 80 /* Identifier */ || node.kind === 230 /* SpreadElement */ || node.kind === 303 /* PropertyAssignment */ || node.kind === 304 /* ShorthandPropertyAssignment */) && isArrayLiteralOrObjectLiteralDestructuringPattern(parent2)) {
                                return textSpan(node);
                            }
                            if (node.kind === 226 /* BinaryExpression */) {
                                const { left, operatorToken } = node;
                                if (isArrayLiteralOrObjectLiteralDestructuringPattern(left)) {
                                    return spanInArrayLiteralOrObjectLiteralDestructuringPattern(left);
                                }
                                if (operatorToken.kind === 64 /* EqualsToken */ && isArrayLiteralOrObjectLiteralDestructuringPattern(node.parent)) {
                                    return textSpan(node);
                                }
                                if (operatorToken.kind === 28 /* CommaToken */) {
                                    return spanInNode(left);
                                }
                            }
                            if (isExpressionNode(node)) {
                                switch (parent2.kind) {
                                    case 246 /* DoStatement */:
                                        return spanInPreviousNode(node);
                                    case 170 /* Decorator */:
                                        return spanInNode(node.parent);
                                    case 248 /* ForStatement */:
                                    case 250 /* ForOfStatement */:
                                        return textSpan(node);
                                    case 226 /* BinaryExpression */:
                                        if (node.parent.operatorToken.kind === 28 /* CommaToken */) {
                                            return textSpan(node);
                                        }
                                        break;
                                    case 219 /* ArrowFunction */:
                                        if (node.parent.body === node) {
                                            return textSpan(node);
                                        }
                                        break;
                                }
                            }
                            switch (node.parent.kind) {
                                case 303 /* PropertyAssignment */:
                                    if (node.parent.name === node && !isArrayLiteralOrObjectLiteralDestructuringPattern(node.parent.parent)) {
                                        return spanInNode(node.parent.initializer);
                                    }
                                    break;
                                case 216 /* TypeAssertionExpression */:
                                    if (node.parent.type === node) {
                                        return spanInNextNode(node.parent.type);
                                    }
                                    break;
                                case 260 /* VariableDeclaration */:
                                case 169 /* Parameter */: {
                                    const { initializer, type } = node.parent;
                                    if (initializer === node || type === node || isAssignmentOperator(node.kind)) {
                                        return spanInPreviousNode(node);
                                    }
                                    break;
                                }
                                case 226 /* BinaryExpression */: {
                                    const { left } = node.parent;
                                    if (isArrayLiteralOrObjectLiteralDestructuringPattern(left) && node !== left) {
                                        return spanInPreviousNode(node);
                                    }
                                    break;
                                }
                                default:
                                    if (isFunctionLike(node.parent) && node.parent.type === node) {
                                        return spanInPreviousNode(node);
                                    }
                            }
                            return spanInNode(node.parent);
                    }
                }
                function textSpanFromVariableDeclaration(variableDeclaration) {
                    if (isVariableDeclarationList(variableDeclaration.parent) && variableDeclaration.parent.declarations[0] === variableDeclaration) {
                        return textSpan(findPrecedingToken(variableDeclaration.pos, sourceFile, variableDeclaration.parent), variableDeclaration);
                    }
                    else {
                        return textSpan(variableDeclaration);
                    }
                }
                function spanInVariableDeclaration(variableDeclaration) {
                    if (variableDeclaration.parent.parent.kind === 249 /* ForInStatement */) {
                        return spanInNode(variableDeclaration.parent.parent);
                    }
                    const parent2 = variableDeclaration.parent;
                    if (isBindingPattern(variableDeclaration.name)) {
                        return spanInBindingPattern(variableDeclaration.name);
                    }
                    if (hasOnlyExpressionInitializer(variableDeclaration) && variableDeclaration.initializer || hasSyntacticModifier(variableDeclaration, 32 /* Export */) || parent2.parent.kind === 250 /* ForOfStatement */) {
                        return textSpanFromVariableDeclaration(variableDeclaration);
                    }
                    if (isVariableDeclarationList(variableDeclaration.parent) && variableDeclaration.parent.declarations[0] !== variableDeclaration) {
                        return spanInNode(findPrecedingToken(variableDeclaration.pos, sourceFile, variableDeclaration.parent));
                    }
                }
                function canHaveSpanInParameterDeclaration(parameter) {
                    return !!parameter.initializer || parameter.dotDotDotToken !== void 0 || hasSyntacticModifier(parameter, 1 /* Public */ | 2 /* Private */);
                }
                function spanInParameterDeclaration(parameter) {
                    if (isBindingPattern(parameter.name)) {
                        return spanInBindingPattern(parameter.name);
                    }
                    else if (canHaveSpanInParameterDeclaration(parameter)) {
                        return textSpan(parameter);
                    }
                    else {
                        const functionDeclaration = parameter.parent;
                        const indexOfParameter = functionDeclaration.parameters.indexOf(parameter);
                        Debug.assert(indexOfParameter !== -1);
                        if (indexOfParameter !== 0) {
                            return spanInParameterDeclaration(functionDeclaration.parameters[indexOfParameter - 1]);
                        }
                        else {
                            return spanInNode(functionDeclaration.body);
                        }
                    }
                }
                function canFunctionHaveSpanInWholeDeclaration(functionDeclaration) {
                    return hasSyntacticModifier(functionDeclaration, 32 /* Export */) || functionDeclaration.parent.kind === 263 /* ClassDeclaration */ && functionDeclaration.kind !== 176 /* Constructor */;
                }
                function spanInFunctionDeclaration(functionDeclaration) {
                    if (!functionDeclaration.body) {
                        return void 0;
                    }
                    if (canFunctionHaveSpanInWholeDeclaration(functionDeclaration)) {
                        return textSpan(functionDeclaration);
                    }
                    return spanInNode(functionDeclaration.body);
                }
                function spanInFunctionBlock(block) {
                    const nodeForSpanInBlock = block.statements.length ? block.statements[0] : block.getLastToken();
                    if (canFunctionHaveSpanInWholeDeclaration(block.parent)) {
                        return spanInNodeIfStartsOnSameLine(block.parent, nodeForSpanInBlock);
                    }
                    return spanInNode(nodeForSpanInBlock);
                }
                function spanInBlock(block) {
                    switch (block.parent.kind) {
                        case 267 /* ModuleDeclaration */:
                            if (getModuleInstanceState(block.parent) !== 1 /* Instantiated */) {
                                return void 0;
                            }
                        case 247 /* WhileStatement */:
                        case 245 /* IfStatement */:
                        case 249 /* ForInStatement */:
                            return spanInNodeIfStartsOnSameLine(block.parent, block.statements[0]);
                        case 248 /* ForStatement */:
                        case 250 /* ForOfStatement */:
                            return spanInNodeIfStartsOnSameLine(findPrecedingToken(block.pos, sourceFile, block.parent), block.statements[0]);
                    }
                    return spanInNode(block.statements[0]);
                }
                function spanInInitializerOfForLike(forLikeStatement) {
                    if (forLikeStatement.initializer.kind === 261 /* VariableDeclarationList */) {
                        const variableDeclarationList = forLikeStatement.initializer;
                        if (variableDeclarationList.declarations.length > 0) {
                            return spanInNode(variableDeclarationList.declarations[0]);
                        }
                    }
                    else {
                        return spanInNode(forLikeStatement.initializer);
                    }
                }
                function spanInForStatement(forStatement) {
                    if (forStatement.initializer) {
                        return spanInInitializerOfForLike(forStatement);
                    }
                    if (forStatement.condition) {
                        return textSpan(forStatement.condition);
                    }
                    if (forStatement.incrementor) {
                        return textSpan(forStatement.incrementor);
                    }
                }
                function spanInBindingPattern(bindingPattern) {
                    const firstBindingElement = forEach(bindingPattern.elements, (element) => element.kind !== 232 /* OmittedExpression */ ? element : void 0);
                    if (firstBindingElement) {
                        return spanInNode(firstBindingElement);
                    }
                    if (bindingPattern.parent.kind === 208 /* BindingElement */) {
                        return textSpan(bindingPattern.parent);
                    }
                    return textSpanFromVariableDeclaration(bindingPattern.parent);
                }
                function spanInArrayLiteralOrObjectLiteralDestructuringPattern(node2) {
                    Debug.assert(node2.kind !== 207 /* ArrayBindingPattern */ && node2.kind !== 206 /* ObjectBindingPattern */);
                    const elements = node2.kind === 209 /* ArrayLiteralExpression */ ? node2.elements : node2.properties;
                    const firstBindingElement = forEach(elements, (element) => element.kind !== 232 /* OmittedExpression */ ? element : void 0);
                    if (firstBindingElement) {
                        return spanInNode(firstBindingElement);
                    }
                    return textSpan(node2.parent.kind === 226 /* BinaryExpression */ ? node2.parent : node2);
                }
                function spanInOpenBraceToken(node2) {
                    switch (node2.parent.kind) {
                        case 266 /* EnumDeclaration */:
                            const enumDeclaration = node2.parent;
                            return spanInNodeIfStartsOnSameLine(findPrecedingToken(node2.pos, sourceFile, node2.parent), enumDeclaration.members.length ? enumDeclaration.members[0] : enumDeclaration.getLastToken(sourceFile));
                        case 263 /* ClassDeclaration */:
                            const classDeclaration = node2.parent;
                            return spanInNodeIfStartsOnSameLine(findPrecedingToken(node2.pos, sourceFile, node2.parent), classDeclaration.members.length ? classDeclaration.members[0] : classDeclaration.getLastToken(sourceFile));
                        case 269 /* CaseBlock */:
                            return spanInNodeIfStartsOnSameLine(node2.parent.parent, node2.parent.clauses[0]);
                    }
                    return spanInNode(node2.parent);
                }
                function spanInCloseBraceToken(node2) {
                    switch (node2.parent.kind) {
                        case 268 /* ModuleBlock */:
                            if (getModuleInstanceState(node2.parent.parent) !== 1 /* Instantiated */) {
                                return void 0;
                            }
                        case 266 /* EnumDeclaration */:
                        case 263 /* ClassDeclaration */:
                            return textSpan(node2);
                        case 241 /* Block */:
                            if (isFunctionBlock(node2.parent)) {
                                return textSpan(node2);
                            }
                        case 299 /* CatchClause */:
                            return spanInNode(lastOrUndefined(node2.parent.statements));
                        case 269 /* CaseBlock */:
                            const caseBlock = node2.parent;
                            const lastClause = lastOrUndefined(caseBlock.clauses);
                            if (lastClause) {
                                return spanInNode(lastOrUndefined(lastClause.statements));
                            }
                            return void 0;
                        case 206 /* ObjectBindingPattern */:
                            const bindingPattern = node2.parent;
                            return spanInNode(lastOrUndefined(bindingPattern.elements) || bindingPattern);
                        default:
                            if (isArrayLiteralOrObjectLiteralDestructuringPattern(node2.parent)) {
                                const objectLiteral = node2.parent;
                                return textSpan(lastOrUndefined(objectLiteral.properties) || objectLiteral);
                            }
                            return spanInNode(node2.parent);
                    }
                }
                function spanInCloseBracketToken(node2) {
                    switch (node2.parent.kind) {
                        case 207 /* ArrayBindingPattern */:
                            const bindingPattern = node2.parent;
                            return textSpan(lastOrUndefined(bindingPattern.elements) || bindingPattern);
                        default:
                            if (isArrayLiteralOrObjectLiteralDestructuringPattern(node2.parent)) {
                                const arrayLiteral = node2.parent;
                                return textSpan(lastOrUndefined(arrayLiteral.elements) || arrayLiteral);
                            }
                            return spanInNode(node2.parent);
                    }
                }
                function spanInOpenParenToken(node2) {
                    if (node2.parent.kind === 246 /* DoStatement */ || // Go to while keyword and do action instead
                        node2.parent.kind === 213 /* CallExpression */ || node2.parent.kind === 214 /* NewExpression */) {
                        return spanInPreviousNode(node2);
                    }
                    if (node2.parent.kind === 217 /* ParenthesizedExpression */) {
                        return spanInNextNode(node2);
                    }
                    return spanInNode(node2.parent);
                }
                function spanInCloseParenToken(node2) {
                    switch (node2.parent.kind) {
                        case 218 /* FunctionExpression */:
                        case 262 /* FunctionDeclaration */:
                        case 219 /* ArrowFunction */:
                        case 174 /* MethodDeclaration */:
                        case 173 /* MethodSignature */:
                        case 177 /* GetAccessor */:
                        case 178 /* SetAccessor */:
                        case 176 /* Constructor */:
                        case 247 /* WhileStatement */:
                        case 246 /* DoStatement */:
                        case 248 /* ForStatement */:
                        case 250 /* ForOfStatement */:
                        case 213 /* CallExpression */:
                        case 214 /* NewExpression */:
                        case 217 /* ParenthesizedExpression */:
                            return spanInPreviousNode(node2);
                        default:
                            return spanInNode(node2.parent);
                    }
                }
                function spanInColonToken(node2) {
                    if (isFunctionLike(node2.parent) || node2.parent.kind === 303 /* PropertyAssignment */ || node2.parent.kind === 169 /* Parameter */) {
                        return spanInPreviousNode(node2);
                    }
                    return spanInNode(node2.parent);
                }
                function spanInGreaterThanOrLessThanToken(node2) {
                    if (node2.parent.kind === 216 /* TypeAssertionExpression */) {
                        return spanInNextNode(node2);
                    }
                    return spanInNode(node2.parent);
                }
                function spanInWhileKeyword(node2) {
                    if (node2.parent.kind === 246 /* DoStatement */) {
                        return textSpanEndingAtNextToken(node2, node2.parent.expression);
                    }
                    return spanInNode(node2.parent);
                }
                function spanInOfKeyword(node2) {
                    if (node2.parent.kind === 250 /* ForOfStatement */) {
                        return spanInNextNode(node2);
                    }
                    return spanInNode(node2.parent);
                }
            }
        }
        var init_breakpoints = __esm({
            "src/services/breakpoints.ts"() {
                "use strict";
                init_ts4();
            }
        });
        // src/services/_namespaces/ts.BreakpointResolver.ts
        var ts_BreakpointResolver_exports = {};
        __export(ts_BreakpointResolver_exports, {
            spanInSourceFileAtLocation: () => spanInSourceFileAtLocation
        });
        var init_ts_BreakpointResolver = __esm({
            "src/services/_namespaces/ts.BreakpointResolver.ts"() {
                "use strict";
                init_breakpoints();
            }
        });
        // src/services/callHierarchy.ts
        function isNamedExpression(node) {
            return (isFunctionExpression(node) || isClassExpression(node)) && isNamedDeclaration(node);
        }
        function isVariableLike2(node) {
            return isPropertyDeclaration(node) || isVariableDeclaration(node);
        }
        function isAssignedExpression(node) {
            return (isFunctionExpression(node) || isArrowFunction(node) || isClassExpression(node)) && isVariableLike2(node.parent) && node === node.parent.initializer && isIdentifier(node.parent.name) && (!!(getCombinedNodeFlags(node.parent) & 2 /* Const */) || isPropertyDeclaration(node.parent));
        }
        function isPossibleCallHierarchyDeclaration(node) {
            return isSourceFile(node) || isModuleDeclaration(node) || isFunctionDeclaration(node) || isFunctionExpression(node) || isClassDeclaration(node) || isClassExpression(node) || isClassStaticBlockDeclaration(node) || isMethodDeclaration(node) || isMethodSignature(node) || isGetAccessorDeclaration(node) || isSetAccessorDeclaration(node);
        }
        function isValidCallHierarchyDeclaration(node) {
            return isSourceFile(node) || isModuleDeclaration(node) && isIdentifier(node.name) || isFunctionDeclaration(node) || isClassDeclaration(node) || isClassStaticBlockDeclaration(node) || isMethodDeclaration(node) || isMethodSignature(node) || isGetAccessorDeclaration(node) || isSetAccessorDeclaration(node) || isNamedExpression(node) || isAssignedExpression(node);
        }
        function getCallHierarchyDeclarationReferenceNode(node) {
            if (isSourceFile(node))
                return node;
            if (isNamedDeclaration(node))
                return node.name;
            if (isAssignedExpression(node))
                return node.parent.name;
            return Debug.checkDefined(node.modifiers && find(node.modifiers, isDefaultModifier3));
        }
        function isDefaultModifier3(node) {
            return node.kind === 90 /* DefaultKeyword */;
        }
        function getSymbolOfCallHierarchyDeclaration(typeChecker, node) {
            const location = getCallHierarchyDeclarationReferenceNode(node);
            return location && typeChecker.getSymbolAtLocation(location);
        }
        function getCallHierarchyItemName(program, node) {
            if (isSourceFile(node)) {
                return { text: node.fileName, pos: 0, end: 0 };
            }
            if ((isFunctionDeclaration(node) || isClassDeclaration(node)) && !isNamedDeclaration(node)) {
                const defaultModifier = node.modifiers && find(node.modifiers, isDefaultModifier3);
                if (defaultModifier) {
                    return { text: "default", pos: defaultModifier.getStart(), end: defaultModifier.getEnd() };
                }
            }
            if (isClassStaticBlockDeclaration(node)) {
                const sourceFile = node.getSourceFile();
                const pos = skipTrivia(sourceFile.text, moveRangePastModifiers(node).pos);
                const end = pos + 6;
                const typeChecker = program.getTypeChecker();
                const symbol = typeChecker.getSymbolAtLocation(node.parent);
                const prefix = symbol ? `${typeChecker.symbolToString(symbol, node.parent)} ` : "";
                return { text: `${prefix}static {}`, pos, end };
            }
            const declName = isAssignedExpression(node) ? node.parent.name : Debug.checkDefined(getNameOfDeclaration(node), "Expected call hierarchy item to have a name");
            let text = isIdentifier(declName) ? idText(declName) : isStringOrNumericLiteralLike(declName) ? declName.text : isComputedPropertyName(declName) ? isStringOrNumericLiteralLike(declName.expression) ? declName.expression.text : void 0 : void 0;
            if (text === void 0) {
                const typeChecker = program.getTypeChecker();
                const symbol = typeChecker.getSymbolAtLocation(declName);
                if (symbol) {
                    text = typeChecker.symbolToString(symbol, node);
                }
            }
            if (text === void 0) {
                const printer = createPrinterWithRemoveCommentsOmitTrailingSemicolon();
                text = usingSingleLineStringWriter((writer) => printer.writeNode(4 /* Unspecified */, node, node.getSourceFile(), writer));
            }
            return { text, pos: declName.getStart(), end: declName.getEnd() };
        }
        function getCallHierarchItemContainerName(node) {
            var _a, _b, _c, _d;
            if (isAssignedExpression(node)) {
                if (isPropertyDeclaration(node.parent) && isClassLike(node.parent.parent)) {
                    return isClassExpression(node.parent.parent) ? (_a = getAssignedName(node.parent.parent)) == null ? void 0 : _a.getText() : (_b = node.parent.parent.name) == null ? void 0 : _b.getText();
                }
                if (isModuleBlock(node.parent.parent.parent.parent) && isIdentifier(node.parent.parent.parent.parent.parent.name)) {
                    return node.parent.parent.parent.parent.parent.name.getText();
                }
                return;
            }
            switch (node.kind) {
                case 177 /* GetAccessor */:
                case 178 /* SetAccessor */:
                case 174 /* MethodDeclaration */:
                    if (node.parent.kind === 210 /* ObjectLiteralExpression */) {
                        return (_c = getAssignedName(node.parent)) == null ? void 0 : _c.getText();
                    }
                    return (_d = getNameOfDeclaration(node.parent)) == null ? void 0 : _d.getText();
                case 262 /* FunctionDeclaration */:
                case 263 /* ClassDeclaration */:
                case 267 /* ModuleDeclaration */:
                    if (isModuleBlock(node.parent) && isIdentifier(node.parent.parent.name)) {
                        return node.parent.parent.name.getText();
                    }
            }
        }
        function findImplementation(typeChecker, node) {
            if (node.body) {
                return node;
            }
            if (isConstructorDeclaration(node)) {
                return getFirstConstructorWithBody(node.parent);
            }
            if (isFunctionDeclaration(node) || isMethodDeclaration(node)) {
                const symbol = getSymbolOfCallHierarchyDeclaration(typeChecker, node);
                if (symbol && symbol.valueDeclaration && isFunctionLikeDeclaration(symbol.valueDeclaration) && symbol.valueDeclaration.body) {
                    return symbol.valueDeclaration;
                }
                return void 0;
            }
            return node;
        }
        function findAllInitialDeclarations(typeChecker, node) {
            const symbol = getSymbolOfCallHierarchyDeclaration(typeChecker, node);
            let declarations;
            if (symbol && symbol.declarations) {
                const indices = indicesOf(symbol.declarations);
                const keys = map(symbol.declarations, (decl) => ({ file: decl.getSourceFile().fileName, pos: decl.pos }));
                indices.sort((a, b) => compareStringsCaseSensitive(keys[a].file, keys[b].file) || keys[a].pos - keys[b].pos);
                const sortedDeclarations = map(indices, (i) => symbol.declarations[i]);
                let lastDecl;
                for (const decl of sortedDeclarations) {
                    if (isValidCallHierarchyDeclaration(decl)) {
                        if (!lastDecl || lastDecl.parent !== decl.parent || lastDecl.end !== decl.pos) {
                            declarations = append(declarations, decl);
                        }
                        lastDecl = decl;
                    }
                }
            }
            return declarations;
        }
        function findImplementationOrAllInitialDeclarations(typeChecker, node) {
            if (isClassStaticBlockDeclaration(node)) {
                return node;
            }
            if (isFunctionLikeDeclaration(node)) {
                return findImplementation(typeChecker, node) ?? findAllInitialDeclarations(typeChecker, node) ?? node;
            }
            return findAllInitialDeclarations(typeChecker, node) ?? node;
        }
        function resolveCallHierarchyDeclaration(program, location) {
            const typeChecker = program.getTypeChecker();
            let followingSymbol = false;
            while (true) {
                if (isValidCallHierarchyDeclaration(location)) {
                    return findImplementationOrAllInitialDeclarations(typeChecker, location);
                }
                if (isPossibleCallHierarchyDeclaration(location)) {
                    const ancestor = findAncestor(location, isValidCallHierarchyDeclaration);
                    return ancestor && findImplementationOrAllInitialDeclarations(typeChecker, ancestor);
                }
                if (isDeclarationName(location)) {
                    if (isValidCallHierarchyDeclaration(location.parent)) {
                        return findImplementationOrAllInitialDeclarations(typeChecker, location.parent);
                    }
                    if (isPossibleCallHierarchyDeclaration(location.parent)) {
                        const ancestor = findAncestor(location.parent, isValidCallHierarchyDeclaration);
                        return ancestor && findImplementationOrAllInitialDeclarations(typeChecker, ancestor);
                    }
                    if (isVariableLike2(location.parent) && location.parent.initializer && isAssignedExpression(location.parent.initializer)) {
                        return location.parent.initializer;
                    }
                    return void 0;
                }
                if (isConstructorDeclaration(location)) {
                    if (isValidCallHierarchyDeclaration(location.parent)) {
                        return location.parent;
                    }
                    return void 0;
                }
                if (location.kind === 126 /* StaticKeyword */ && isClassStaticBlockDeclaration(location.parent)) {
                    location = location.parent;
                    continue;
                }
                if (isVariableDeclaration(location) && location.initializer && isAssignedExpression(location.initializer)) {
                    return location.initializer;
                }
                if (!followingSymbol) {
                    let symbol = typeChecker.getSymbolAtLocation(location);
                    if (symbol) {
                        if (symbol.flags & 2097152 /* Alias */) {
                            symbol = typeChecker.getAliasedSymbol(symbol);
                        }
                        if (symbol.valueDeclaration) {
                            followingSymbol = true;
                            location = symbol.valueDeclaration;
                            continue;
                        }
                    }
                }
                return void 0;
            }
        }
        function createCallHierarchyItem(program, node) {
            const sourceFile = node.getSourceFile();
            const name = getCallHierarchyItemName(program, node);
            const containerName = getCallHierarchItemContainerName(node);
            const kind = getNodeKind(node);
            const kindModifiers = getNodeModifiers(node);
            const span = createTextSpanFromBounds(skipTrivia(sourceFile.text, node.getFullStart(), 
            /*stopAfterLineBreak*/
            false, 
            /*stopAtComments*/
            true), node.getEnd());
            const selectionSpan = createTextSpanFromBounds(name.pos, name.end);
            return { file: sourceFile.fileName, kind, kindModifiers, name: name.text, containerName, span, selectionSpan };
        }
        function isDefined(x) {
            return x !== void 0;
        }
        function convertEntryToCallSite(entry) {
            if (entry.kind === ts_FindAllReferences_exports.EntryKind.Node) {
                const { node } = entry;
                if (isCallOrNewExpressionTarget(node, 
                /*includeElementAccess*/
                true, 
                /*skipPastOuterExpressions*/
                true) || isTaggedTemplateTag(node, 
                /*includeElementAccess*/
                true, 
                /*skipPastOuterExpressions*/
                true) || isDecoratorTarget(node, 
                /*includeElementAccess*/
                true, 
                /*skipPastOuterExpressions*/
                true) || isJsxOpeningLikeElementTagName(node, 
                /*includeElementAccess*/
                true, 
                /*skipPastOuterExpressions*/
                true) || isRightSideOfPropertyAccess(node) || isArgumentExpressionOfElementAccess(node)) {
                    const sourceFile = node.getSourceFile();
                    const ancestor = findAncestor(node, isValidCallHierarchyDeclaration) || sourceFile;
                    return { declaration: ancestor, range: createTextRangeFromNode(node, sourceFile) };
                }
            }
        }
        function getCallSiteGroupKey(entry) {
            return getNodeId(entry.declaration);
        }
        function createCallHierarchyIncomingCall(from, fromSpans) {
            return { from, fromSpans };
        }
        function convertCallSiteGroupToIncomingCall(program, entries) {
            return createCallHierarchyIncomingCall(createCallHierarchyItem(program, entries[0].declaration), map(entries, (entry) => createTextSpanFromRange(entry.range)));
        }
        function getIncomingCalls(program, declaration, cancellationToken) {
            if (isSourceFile(declaration) || isModuleDeclaration(declaration) || isClassStaticBlockDeclaration(declaration)) {
                return [];
            }
            const location = getCallHierarchyDeclarationReferenceNode(declaration);
            const calls = filter(ts_FindAllReferences_exports.findReferenceOrRenameEntries(program, cancellationToken, program.getSourceFiles(), location, 
            /*position*/
            0, { use: ts_FindAllReferences_exports.FindReferencesUse.References }, convertEntryToCallSite), isDefined);
            return calls ? group(calls, getCallSiteGroupKey, (entries) => convertCallSiteGroupToIncomingCall(program, entries)) : [];
        }
        function createCallSiteCollector(program, callSites) {
            function recordCallSite(node) {
                const target = isTaggedTemplateExpression(node) ? node.tag : isJsxOpeningLikeElement(node) ? node.tagName : isAccessExpression(node) ? node : isClassStaticBlockDeclaration(node) ? node : node.expression;
                const declaration = resolveCallHierarchyDeclaration(program, target);
                if (declaration) {
                    const range = createTextRangeFromNode(target, node.getSourceFile());
                    if (isArray(declaration)) {
                        for (const decl of declaration) {
                            callSites.push({ declaration: decl, range });
                        }
                    }
                    else {
                        callSites.push({ declaration, range });
                    }
                }
            }
            function collect(node) {
                if (!node)
                    return;
                if (node.flags & 33554432 /* Ambient */) {
                    return;
                }
                if (isValidCallHierarchyDeclaration(node)) {
                    if (isClassLike(node)) {
                        for (const member of node.members) {
                            if (member.name && isComputedPropertyName(member.name)) {
                                collect(member.name.expression);
                            }
                        }
                    }
                    return;
                }
                switch (node.kind) {
                    case 80 /* Identifier */:
                    case 271 /* ImportEqualsDeclaration */:
                    case 272 /* ImportDeclaration */:
                    case 278 /* ExportDeclaration */:
                    case 264 /* InterfaceDeclaration */:
                    case 265 /* TypeAliasDeclaration */:
                        return;
                    case 175 /* ClassStaticBlockDeclaration */:
                        recordCallSite(node);
                        return;
                    case 216 /* TypeAssertionExpression */:
                    case 234 /* AsExpression */:
                        collect(node.expression);
                        return;
                    case 260 /* VariableDeclaration */:
                    case 169 /* Parameter */:
                        collect(node.name);
                        collect(node.initializer);
                        return;
                    case 213 /* CallExpression */:
                        recordCallSite(node);
                        collect(node.expression);
                        forEach(node.arguments, collect);
                        return;
                    case 214 /* NewExpression */:
                        recordCallSite(node);
                        collect(node.expression);
                        forEach(node.arguments, collect);
                        return;
                    case 215 /* TaggedTemplateExpression */:
                        recordCallSite(node);
                        collect(node.tag);
                        collect(node.template);
                        return;
                    case 286 /* JsxOpeningElement */:
                    case 285 /* JsxSelfClosingElement */:
                        recordCallSite(node);
                        collect(node.tagName);
                        collect(node.attributes);
                        return;
                    case 170 /* Decorator */:
                        recordCallSite(node);
                        collect(node.expression);
                        return;
                    case 211 /* PropertyAccessExpression */:
                    case 212 /* ElementAccessExpression */:
                        recordCallSite(node);
                        forEachChild(node, collect);
                        break;
                    case 238 /* SatisfiesExpression */:
                        collect(node.expression);
                        return;
                }
                if (isPartOfTypeNode(node)) {
                    return;
                }
                forEachChild(node, collect);
            }
            return collect;
        }
        function collectCallSitesOfSourceFile(node, collect) {
            forEach(node.statements, collect);
        }
        function collectCallSitesOfModuleDeclaration(node, collect) {
            if (!hasSyntacticModifier(node, 128 /* Ambient */) && node.body && isModuleBlock(node.body)) {
                forEach(node.body.statements, collect);
            }
        }
        function collectCallSitesOfFunctionLikeDeclaration(typeChecker, node, collect) {
            const implementation = findImplementation(typeChecker, node);
            if (implementation) {
                forEach(implementation.parameters, collect);
                collect(implementation.body);
            }
        }
        function collectCallSitesOfClassStaticBlockDeclaration(node, collect) {
            collect(node.body);
        }
        function collectCallSitesOfClassLikeDeclaration(node, collect) {
            forEach(node.modifiers, collect);
            const heritage = getClassExtendsHeritageElement(node);
            if (heritage) {
                collect(heritage.expression);
            }
            for (const member of node.members) {
                if (canHaveModifiers(member)) {
                    forEach(member.modifiers, collect);
                }
                if (isPropertyDeclaration(member)) {
                    collect(member.initializer);
                }
                else if (isConstructorDeclaration(member) && member.body) {
                    forEach(member.parameters, collect);
                    collect(member.body);
                }
                else if (isClassStaticBlockDeclaration(member)) {
                    collect(member);
                }
            }
        }
        function collectCallSites(program, node) {
            const callSites = [];
            const collect = createCallSiteCollector(program, callSites);
            switch (node.kind) {
                case 312 /* SourceFile */:
                    collectCallSitesOfSourceFile(node, collect);
                    break;
                case 267 /* ModuleDeclaration */:
                    collectCallSitesOfModuleDeclaration(node, collect);
                    break;
                case 262 /* FunctionDeclaration */:
                case 218 /* FunctionExpression */:
                case 219 /* ArrowFunction */:
                case 174 /* MethodDeclaration */:
                case 177 /* GetAccessor */:
                case 178 /* SetAccessor */:
                    collectCallSitesOfFunctionLikeDeclaration(program.getTypeChecker(), node, collect);
                    break;
                case 263 /* ClassDeclaration */:
                case 231 /* ClassExpression */:
                    collectCallSitesOfClassLikeDeclaration(node, collect);
                    break;
                case 175 /* ClassStaticBlockDeclaration */:
                    collectCallSitesOfClassStaticBlockDeclaration(node, collect);
                    break;
                default:
                    Debug.assertNever(node);
            }
            return callSites;
        }
        function createCallHierarchyOutgoingCall(to, fromSpans) {
            return { to, fromSpans };
        }
        function convertCallSiteGroupToOutgoingCall(program, entries) {
            return createCallHierarchyOutgoingCall(createCallHierarchyItem(program, entries[0].declaration), map(entries, (entry) => createTextSpanFromRange(entry.range)));
        }
        function getOutgoingCalls(program, declaration) {
            if (declaration.flags & 33554432 /* Ambient */ || isMethodSignature(declaration)) {
                return [];
            }
            return group(collectCallSites(program, declaration), getCallSiteGroupKey, (entries) => convertCallSiteGroupToOutgoingCall(program, entries));
        }
        var init_callHierarchy = __esm({
            "src/services/callHierarchy.ts"() {
                "use strict";
                init_ts4();
            }
        });
        // src/services/_namespaces/ts.CallHierarchy.ts
        var ts_CallHierarchy_exports = {};
        __export(ts_CallHierarchy_exports, {
            createCallHierarchyItem: () => createCallHierarchyItem,
            getIncomingCalls: () => getIncomingCalls,
            getOutgoingCalls: () => getOutgoingCalls,
            resolveCallHierarchyDeclaration: () => resolveCallHierarchyDeclaration
        });
        var init_ts_CallHierarchy = __esm({
            "src/services/_namespaces/ts.CallHierarchy.ts"() {
                "use strict";
                init_callHierarchy();
            }
        });
        // src/services/_namespaces/ts.classifier.v2020.ts
        var ts_classifier_v2020_exports = {};
        __export(ts_classifier_v2020_exports, {
            TokenEncodingConsts: () => TokenEncodingConsts,
            TokenModifier: () => TokenModifier,
            TokenType: () => TokenType,
            getEncodedSemanticClassifications: () => getEncodedSemanticClassifications2,
            getSemanticClassifications: () => getSemanticClassifications2
        });
        var init_ts_classifier_v2020 = __esm({
            "src/services/_namespaces/ts.classifier.v2020.ts"() {
                "use strict";
                init_classifier2020();
            }
        });
        // src/services/_namespaces/ts.classifier.ts
        var ts_classifier_exports = {};
        __export(ts_classifier_exports, {
            v2020: () => ts_classifier_v2020_exports
        });
        var init_ts_classifier = __esm({
            "src/services/_namespaces/ts.classifier.ts"() {
                "use strict";
                init_ts_classifier_v2020();
            }
        });
        // src/services/codeFixProvider.ts
        function createCodeFixActionWithoutFixAll(fixName8, changes, description3) {
            return createCodeFixActionWorker(fixName8, diagnosticToString(description3), changes, 
            /*fixId*/
            void 0, 
            /*fixAllDescription*/
            void 0);
        }
        function createCodeFixAction(fixName8, changes, description3, fixId52, fixAllDescription, command) {
            return createCodeFixActionWorker(fixName8, diagnosticToString(description3), changes, fixId52, diagnosticToString(fixAllDescription), command);
        }
        function createCodeFixActionMaybeFixAll(fixName8, changes, description3, fixId52, fixAllDescription, command) {
            return createCodeFixActionWorker(fixName8, diagnosticToString(description3), changes, fixId52, fixAllDescription && diagnosticToString(fixAllDescription), command);
        }
        function createCodeFixActionWorker(fixName8, description3, changes, fixId52, fixAllDescription, command) {
            return { fixName: fixName8, description: description3, changes, fixId: fixId52, fixAllDescription, commands: command ? [command] : void 0 };
        }
        function registerCodeFix(reg) {
            for (const error2 of reg.errorCodes) {
                errorCodeToFixesArray = void 0;
                errorCodeToFixes.add(String(error2), reg);
            }
            if (reg.fixIds) {
                for (const fixId52 of reg.fixIds) {
                    Debug.assert(!fixIdToRegistration.has(fixId52));
                    fixIdToRegistration.set(fixId52, reg);
                }
            }
        }
        function getSupportedErrorCodes() {
            return errorCodeToFixesArray ?? (errorCodeToFixesArray = arrayFrom(errorCodeToFixes.keys()));
        }
        function removeFixIdIfFixAllUnavailable(registration, diagnostics) {
            const { errorCodes: errorCodes65 } = registration;
            let maybeFixableDiagnostics = 0;
            for (const diag2 of diagnostics) {
                if (contains(errorCodes65, diag2.code))
                    maybeFixableDiagnostics++;
                if (maybeFixableDiagnostics > 1)
                    break;
            }
            const fixAllUnavailable = maybeFixableDiagnostics < 2;
            return ({ fixId: fixId52, fixAllDescription, ...action }) => {
                return fixAllUnavailable ? action : { ...action, fixId: fixId52, fixAllDescription };
            };
        }
        function getFixes(context) {
            const diagnostics = getDiagnostics(context);
            const registrations = errorCodeToFixes.get(String(context.errorCode));
            return flatMap(registrations, (f) => map(f.getCodeActions(context), removeFixIdIfFixAllUnavailable(f, diagnostics)));
        }
        function getAllFixes(context) {
            return fixIdToRegistration.get(cast(context.fixId, isString)).getAllCodeActions(context);
        }
        function createCombinedCodeActions(changes, commands) {
            return { changes, commands };
        }
        function createFileTextChanges(fileName, textChanges2) {
            return { fileName, textChanges: textChanges2 };
        }
        function codeFixAll(context, errorCodes65, use) {
            const commands = [];
            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => eachDiagnostic(context, errorCodes65, (diag2) => use(t, diag2, commands)));
            return createCombinedCodeActions(changes, commands.length === 0 ? void 0 : commands);
        }
        function eachDiagnostic(context, errorCodes65, cb) {
            for (const diag2 of getDiagnostics(context)) {
                if (contains(errorCodes65, diag2.code)) {
                    cb(diag2);
                }
            }
        }
        function getDiagnostics({ program, sourceFile, cancellationToken }) {
            return [
                ...program.getSemanticDiagnostics(sourceFile, cancellationToken),
                ...program.getSyntacticDiagnostics(sourceFile, cancellationToken),
                ...computeSuggestionDiagnostics(sourceFile, program, cancellationToken)
            ];
        }
        var errorCodeToFixes, fixIdToRegistration, errorCodeToFixesArray;
        var init_codeFixProvider = __esm({
            "src/services/codeFixProvider.ts"() {
                "use strict";
                init_ts4();
                errorCodeToFixes = createMultiMap();
                fixIdToRegistration = /* @__PURE__ */ new Map();
            }
        });
        // src/services/codefixes/addConvertToUnknownForNonOverlappingTypes.ts
        function makeChange(changeTracker, sourceFile, assertion) {
            const replacement = isAsExpression(assertion) ? factory.createAsExpression(assertion.expression, factory.createKeywordTypeNode(159 /* UnknownKeyword */)) : factory.createTypeAssertion(factory.createKeywordTypeNode(159 /* UnknownKeyword */), assertion.expression);
            changeTracker.replaceNode(sourceFile, assertion.expression, replacement);
        }
        function getAssertion(sourceFile, pos) {
            if (isInJSFile(sourceFile))
                return void 0;
            return findAncestor(getTokenAtPosition(sourceFile, pos), (n) => isAsExpression(n) || isTypeAssertionExpression(n));
        }
        var fixId, errorCodes;
        var init_addConvertToUnknownForNonOverlappingTypes = __esm({
            "src/services/codefixes/addConvertToUnknownForNonOverlappingTypes.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId = "addConvertToUnknownForNonOverlappingTypes";
                errorCodes = [Diagnostics.Conversion_of_type_0_to_type_1_may_be_a_mistake_because_neither_type_sufficiently_overlaps_with_the_other_If_this_was_intentional_convert_the_expression_to_unknown_first.code];
                registerCodeFix({
                    errorCodes,
                    getCodeActions: function getCodeActionsToAddConvertToUnknownForNonOverlappingTypes(context) {
                        const assertion = getAssertion(context.sourceFile, context.span.start);
                        if (assertion === void 0)
                            return void 0;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => makeChange(t, context.sourceFile, assertion));
                        return [createCodeFixAction(fixId, changes, Diagnostics.Add_unknown_conversion_for_non_overlapping_types, fixId, Diagnostics.Add_unknown_to_all_conversions_of_non_overlapping_types)];
                    },
                    fixIds: [fixId],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes, (changes, diag2) => {
                        const assertion = getAssertion(diag2.file, diag2.start);
                        if (assertion) {
                            makeChange(changes, diag2.file, assertion);
                        }
                    })
                });
            }
        });
        // src/services/codefixes/addEmptyExportDeclaration.ts
        var init_addEmptyExportDeclaration = __esm({
            "src/services/codefixes/addEmptyExportDeclaration.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                registerCodeFix({
                    errorCodes: [
                        Diagnostics.await_expressions_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_has_no_imports_or_exports_Consider_adding_an_empty_export_to_make_this_file_a_module.code,
                        Diagnostics.await_using_statements_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_has_no_imports_or_exports_Consider_adding_an_empty_export_to_make_this_file_a_module.code,
                        Diagnostics.for_await_loops_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_has_no_imports_or_exports_Consider_adding_an_empty_export_to_make_this_file_a_module.code
                    ],
                    getCodeActions: function getCodeActionsToAddEmptyExportDeclaration(context) {
                        const { sourceFile } = context;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (changes2) => {
                            const exportDeclaration = factory.createExportDeclaration(
                            /*modifiers*/
                            void 0, 
                            /*isTypeOnly*/
                            false, factory.createNamedExports([]), 
                            /*moduleSpecifier*/
                            void 0);
                            changes2.insertNodeAtEndOfScope(sourceFile, sourceFile, exportDeclaration);
                        });
                        return [createCodeFixActionWithoutFixAll("addEmptyExportDeclaration", changes, Diagnostics.Add_export_to_make_this_file_into_a_module)];
                    }
                });
            }
        });
        // src/services/codefixes/addMissingAsync.ts
        function getFix(context, decl, trackChanges, fixedDeclarations) {
            const changes = trackChanges((t) => makeChange2(t, context.sourceFile, decl, fixedDeclarations));
            return createCodeFixAction(fixId2, changes, Diagnostics.Add_async_modifier_to_containing_function, fixId2, Diagnostics.Add_all_missing_async_modifiers);
        }
        function makeChange2(changeTracker, sourceFile, insertionSite, fixedDeclarations) {
            if (fixedDeclarations) {
                if (fixedDeclarations.has(getNodeId(insertionSite))) {
                    return;
                }
            }
            fixedDeclarations == null ? void 0 : fixedDeclarations.add(getNodeId(insertionSite));
            const cloneWithModifier = factory.replaceModifiers(getSynthesizedDeepClone(insertionSite, 
            /*includeTrivia*/
            true), factory.createNodeArray(factory.createModifiersFromModifierFlags(getSyntacticModifierFlags(insertionSite) | 1024 /* Async */)));
            changeTracker.replaceNode(sourceFile, insertionSite, cloneWithModifier);
        }
        function getFixableErrorSpanDeclaration(sourceFile, span) {
            if (!span)
                return void 0;
            const token = getTokenAtPosition(sourceFile, span.start);
            const decl = findAncestor(token, (node) => {
                if (node.getStart(sourceFile) < span.start || node.getEnd() > textSpanEnd(span)) {
                    return "quit";
                }
                return (isArrowFunction(node) || isMethodDeclaration(node) || isFunctionExpression(node) || isFunctionDeclaration(node)) && textSpansEqual(span, createTextSpanFromNode(node, sourceFile));
            });
            return decl;
        }
        function getIsMatchingAsyncError(span, errorCode) {
            return ({ start, length: length2, relatedInformation, code }) => isNumber(start) && isNumber(length2) && textSpansEqual({ start, length: length2 }, span) && code === errorCode && !!relatedInformation && some(relatedInformation, (related) => related.code === Diagnostics.Did_you_mean_to_mark_this_function_as_async.code);
        }
        var fixId2, errorCodes2;
        var init_addMissingAsync = __esm({
            "src/services/codefixes/addMissingAsync.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId2 = "addMissingAsync";
                errorCodes2 = [
                    Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1.code,
                    Diagnostics.Type_0_is_not_assignable_to_type_1.code,
                    Diagnostics.Type_0_is_not_comparable_to_type_1.code
                ];
                registerCodeFix({
                    fixIds: [fixId2],
                    errorCodes: errorCodes2,
                    getCodeActions: function getCodeActionsToAddMissingAsync(context) {
                        const { sourceFile, errorCode, cancellationToken, program, span } = context;
                        const diagnostic = find(program.getTypeChecker().getDiagnostics(sourceFile, cancellationToken), getIsMatchingAsyncError(span, errorCode));
                        const directSpan = diagnostic && diagnostic.relatedInformation && find(diagnostic.relatedInformation, (r) => r.code === Diagnostics.Did_you_mean_to_mark_this_function_as_async.code);
                        const decl = getFixableErrorSpanDeclaration(sourceFile, directSpan);
                        if (!decl) {
                            return;
                        }
                        const trackChanges = (cb) => ts_textChanges_exports.ChangeTracker.with(context, cb);
                        return [getFix(context, decl, trackChanges)];
                    },
                    getAllCodeActions: (context) => {
                        const { sourceFile } = context;
                        const fixedDeclarations = /* @__PURE__ */ new Set();
                        return codeFixAll(context, errorCodes2, (t, diagnostic) => {
                            const span = diagnostic.relatedInformation && find(diagnostic.relatedInformation, (r) => r.code === Diagnostics.Did_you_mean_to_mark_this_function_as_async.code);
                            const decl = getFixableErrorSpanDeclaration(sourceFile, span);
                            if (!decl) {
                                return;
                            }
                            const trackChanges = (cb) => (cb(t), []);
                            return getFix(context, decl, trackChanges, fixedDeclarations);
                        });
                    }
                });
            }
        });
        // src/services/codefixes/addMissingAwait.ts
        function getAwaitErrorSpanExpression(sourceFile, errorCode, span, cancellationToken, program) {
            const expression = getFixableErrorSpanExpression(sourceFile, span);
            return expression && isMissingAwaitError(sourceFile, errorCode, span, cancellationToken, program) && isInsideAwaitableBody(expression) ? expression : void 0;
        }
        function getDeclarationSiteFix(context, expression, errorCode, checker, trackChanges, fixedDeclarations) {
            const { sourceFile, program, cancellationToken } = context;
            const awaitableInitializers = findAwaitableInitializers(expression, sourceFile, cancellationToken, program, checker);
            if (awaitableInitializers) {
                const initializerChanges = trackChanges((t) => {
                    forEach(awaitableInitializers.initializers, ({ expression: expression2 }) => makeChange3(t, errorCode, sourceFile, checker, expression2, fixedDeclarations));
                    if (fixedDeclarations && awaitableInitializers.needsSecondPassForFixAll) {
                        makeChange3(t, errorCode, sourceFile, checker, expression, fixedDeclarations);
                    }
                });
                return createCodeFixActionWithoutFixAll("addMissingAwaitToInitializer", initializerChanges, awaitableInitializers.initializers.length === 1 ? [Diagnostics.Add_await_to_initializer_for_0, awaitableInitializers.initializers[0].declarationSymbol.name] : Diagnostics.Add_await_to_initializers);
            }
        }
        function getUseSiteFix(context, expression, errorCode, checker, trackChanges, fixedDeclarations) {
            const changes = trackChanges((t) => makeChange3(t, errorCode, context.sourceFile, checker, expression, fixedDeclarations));
            return createCodeFixAction(fixId3, changes, Diagnostics.Add_await, fixId3, Diagnostics.Fix_all_expressions_possibly_missing_await);
        }
        function isMissingAwaitError(sourceFile, errorCode, span, cancellationToken, program) {
            const checker = program.getTypeChecker();
            const diagnostics = checker.getDiagnostics(sourceFile, cancellationToken);
            return some(diagnostics, ({ start, length: length2, relatedInformation, code }) => isNumber(start) && isNumber(length2) && textSpansEqual({ start, length: length2 }, span) && code === errorCode && !!relatedInformation && some(relatedInformation, (related) => related.code === Diagnostics.Did_you_forget_to_use_await.code));
        }
        function findAwaitableInitializers(expression, sourceFile, cancellationToken, program, checker) {
            const identifiers = getIdentifiersFromErrorSpanExpression(expression, checker);
            if (!identifiers) {
                return;
            }
            let isCompleteFix = identifiers.isCompleteFix;
            let initializers;
            for (const identifier of identifiers.identifiers) {
                const symbol = checker.getSymbolAtLocation(identifier);
                if (!symbol) {
                    continue;
                }
                const declaration = tryCast(symbol.valueDeclaration, isVariableDeclaration);
                const variableName = declaration && tryCast(declaration.name, isIdentifier);
                const variableStatement = getAncestor(declaration, 243 /* VariableStatement */);
                if (!declaration || !variableStatement || declaration.type || !declaration.initializer || variableStatement.getSourceFile() !== sourceFile || hasSyntacticModifier(variableStatement, 32 /* Export */) || !variableName || !isInsideAwaitableBody(declaration.initializer)) {
                    isCompleteFix = false;
                    continue;
                }
                const diagnostics = program.getSemanticDiagnostics(sourceFile, cancellationToken);
                const isUsedElsewhere = ts_FindAllReferences_exports.Core.eachSymbolReferenceInFile(variableName, checker, sourceFile, (reference) => {
                    return identifier !== reference && !symbolReferenceIsAlsoMissingAwait(reference, diagnostics, sourceFile, checker);
                });
                if (isUsedElsewhere) {
                    isCompleteFix = false;
                    continue;
                }
                (initializers || (initializers = [])).push({
                    expression: declaration.initializer,
                    declarationSymbol: symbol
                });
            }
            return initializers && {
                initializers,
                needsSecondPassForFixAll: !isCompleteFix
            };
        }
        function getIdentifiersFromErrorSpanExpression(expression, checker) {
            if (isPropertyAccessExpression(expression.parent) && isIdentifier(expression.parent.expression)) {
                return { identifiers: [expression.parent.expression], isCompleteFix: true };
            }
            if (isIdentifier(expression)) {
                return { identifiers: [expression], isCompleteFix: true };
            }
            if (isBinaryExpression(expression)) {
                let sides;
                let isCompleteFix = true;
                for (const side of [expression.left, expression.right]) {
                    const type = checker.getTypeAtLocation(side);
                    if (checker.getPromisedTypeOfPromise(type)) {
                        if (!isIdentifier(side)) {
                            isCompleteFix = false;
                            continue;
                        }
                        (sides || (sides = [])).push(side);
                    }
                }
                return sides && { identifiers: sides, isCompleteFix };
            }
        }
        function symbolReferenceIsAlsoMissingAwait(reference, diagnostics, sourceFile, checker) {
            const errorNode = isPropertyAccessExpression(reference.parent) ? reference.parent.name : isBinaryExpression(reference.parent) ? reference.parent : reference;
            const diagnostic = find(diagnostics, (diagnostic2) => diagnostic2.start === errorNode.getStart(sourceFile) && diagnostic2.start + diagnostic2.length === errorNode.getEnd());
            return diagnostic && contains(errorCodes3, diagnostic.code) || // A Promise is usually not correct in a binary expression (it's not valid
                // in an arithmetic expression and an equality comparison seems unusual),
                // but if the other side of the binary expression has an error, the side
                // is typed `any` which will squash the error that would identify this
                // Promise as an invalid operand. So if the whole binary expression is
                // typed `any` as a result, there is a strong likelihood that this Promise
                // is accidentally missing `await`.
                checker.getTypeAtLocation(errorNode).flags & 1 /* Any */;
        }
        function isInsideAwaitableBody(node) {
            return node.flags & 65536 /* AwaitContext */ || !!findAncestor(node, (ancestor) => ancestor.parent && isArrowFunction(ancestor.parent) && ancestor.parent.body === ancestor || isBlock(ancestor) && (ancestor.parent.kind === 262 /* FunctionDeclaration */ || ancestor.parent.kind === 218 /* FunctionExpression */ || ancestor.parent.kind === 219 /* ArrowFunction */ || ancestor.parent.kind === 174 /* MethodDeclaration */));
        }
        function makeChange3(changeTracker, errorCode, sourceFile, checker, insertionSite, fixedDeclarations) {
            if (isForOfStatement(insertionSite.parent) && !insertionSite.parent.awaitModifier) {
                const exprType = checker.getTypeAtLocation(insertionSite);
                const asyncIter = checker.getAsyncIterableType();
                if (asyncIter && checker.isTypeAssignableTo(exprType, asyncIter)) {
                    const forOf = insertionSite.parent;
                    changeTracker.replaceNode(sourceFile, forOf, factory.updateForOfStatement(forOf, factory.createToken(135 /* AwaitKeyword */), forOf.initializer, forOf.expression, forOf.statement));
                    return;
                }
            }
            if (isBinaryExpression(insertionSite)) {
                for (const side of [insertionSite.left, insertionSite.right]) {
                    if (fixedDeclarations && isIdentifier(side)) {
                        const symbol = checker.getSymbolAtLocation(side);
                        if (symbol && fixedDeclarations.has(getSymbolId(symbol))) {
                            continue;
                        }
                    }
                    const type = checker.getTypeAtLocation(side);
                    const newNode = checker.getPromisedTypeOfPromise(type) ? factory.createAwaitExpression(side) : side;
                    changeTracker.replaceNode(sourceFile, side, newNode);
                }
            }
            else if (errorCode === propertyAccessCode && isPropertyAccessExpression(insertionSite.parent)) {
                if (fixedDeclarations && isIdentifier(insertionSite.parent.expression)) {
                    const symbol = checker.getSymbolAtLocation(insertionSite.parent.expression);
                    if (symbol && fixedDeclarations.has(getSymbolId(symbol))) {
                        return;
                    }
                }
                changeTracker.replaceNode(sourceFile, insertionSite.parent.expression, factory.createParenthesizedExpression(factory.createAwaitExpression(insertionSite.parent.expression)));
                insertLeadingSemicolonIfNeeded(changeTracker, insertionSite.parent.expression, sourceFile);
            }
            else if (contains(callableConstructableErrorCodes, errorCode) && isCallOrNewExpression(insertionSite.parent)) {
                if (fixedDeclarations && isIdentifier(insertionSite)) {
                    const symbol = checker.getSymbolAtLocation(insertionSite);
                    if (symbol && fixedDeclarations.has(getSymbolId(symbol))) {
                        return;
                    }
                }
                changeTracker.replaceNode(sourceFile, insertionSite, factory.createParenthesizedExpression(factory.createAwaitExpression(insertionSite)));
                insertLeadingSemicolonIfNeeded(changeTracker, insertionSite, sourceFile);
            }
            else {
                if (fixedDeclarations && isVariableDeclaration(insertionSite.parent) && isIdentifier(insertionSite.parent.name)) {
                    const symbol = checker.getSymbolAtLocation(insertionSite.parent.name);
                    if (symbol && !tryAddToSet(fixedDeclarations, getSymbolId(symbol))) {
                        return;
                    }
                }
                changeTracker.replaceNode(sourceFile, insertionSite, factory.createAwaitExpression(insertionSite));
            }
        }
        function insertLeadingSemicolonIfNeeded(changeTracker, beforeNode, sourceFile) {
            const precedingToken = findPrecedingToken(beforeNode.pos, sourceFile);
            if (precedingToken && positionIsASICandidate(precedingToken.end, precedingToken.parent, sourceFile)) {
                changeTracker.insertText(sourceFile, beforeNode.getStart(sourceFile), ";");
            }
        }
        var fixId3, propertyAccessCode, callableConstructableErrorCodes, errorCodes3;
        var init_addMissingAwait = __esm({
            "src/services/codefixes/addMissingAwait.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId3 = "addMissingAwait";
                propertyAccessCode = Diagnostics.Property_0_does_not_exist_on_type_1.code;
                callableConstructableErrorCodes = [
                    Diagnostics.This_expression_is_not_callable.code,
                    Diagnostics.This_expression_is_not_constructable.code
                ];
                errorCodes3 = [
                    Diagnostics.An_arithmetic_operand_must_be_of_type_any_number_bigint_or_an_enum_type.code,
                    Diagnostics.The_left_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type.code,
                    Diagnostics.The_right_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type.code,
                    Diagnostics.Operator_0_cannot_be_applied_to_type_1.code,
                    Diagnostics.Operator_0_cannot_be_applied_to_types_1_and_2.code,
                    Diagnostics.This_comparison_appears_to_be_unintentional_because_the_types_0_and_1_have_no_overlap.code,
                    Diagnostics.This_condition_will_always_return_true_since_this_0_is_always_defined.code,
                    Diagnostics.Type_0_is_not_an_array_type.code,
                    Diagnostics.Type_0_is_not_an_array_type_or_a_string_type.code,
                    Diagnostics.Type_0_can_only_be_iterated_through_when_using_the_downlevelIteration_flag_or_with_a_target_of_es2015_or_higher.code,
                    Diagnostics.Type_0_is_not_an_array_type_or_a_string_type_or_does_not_have_a_Symbol_iterator_method_that_returns_an_iterator.code,
                    Diagnostics.Type_0_is_not_an_array_type_or_does_not_have_a_Symbol_iterator_method_that_returns_an_iterator.code,
                    Diagnostics.Type_0_must_have_a_Symbol_iterator_method_that_returns_an_iterator.code,
                    Diagnostics.Type_0_must_have_a_Symbol_asyncIterator_method_that_returns_an_async_iterator.code,
                    Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1.code,
                    propertyAccessCode,
                    ...callableConstructableErrorCodes
                ];
                registerCodeFix({
                    fixIds: [fixId3],
                    errorCodes: errorCodes3,
                    getCodeActions: function getCodeActionsToAddMissingAwait(context) {
                        const { sourceFile, errorCode, span, cancellationToken, program } = context;
                        const expression = getAwaitErrorSpanExpression(sourceFile, errorCode, span, cancellationToken, program);
                        if (!expression) {
                            return;
                        }
                        const checker = context.program.getTypeChecker();
                        const trackChanges = (cb) => ts_textChanges_exports.ChangeTracker.with(context, cb);
                        return compact([
                            getDeclarationSiteFix(context, expression, errorCode, checker, trackChanges),
                            getUseSiteFix(context, expression, errorCode, checker, trackChanges)
                        ]);
                    },
                    getAllCodeActions: (context) => {
                        const { sourceFile, program, cancellationToken } = context;
                        const checker = context.program.getTypeChecker();
                        const fixedDeclarations = /* @__PURE__ */ new Set();
                        return codeFixAll(context, errorCodes3, (t, diagnostic) => {
                            const expression = getAwaitErrorSpanExpression(sourceFile, diagnostic.code, diagnostic, cancellationToken, program);
                            if (!expression) {
                                return;
                            }
                            const trackChanges = (cb) => (cb(t), []);
                            return getDeclarationSiteFix(context, expression, diagnostic.code, checker, trackChanges, fixedDeclarations) || getUseSiteFix(context, expression, diagnostic.code, checker, trackChanges, fixedDeclarations);
                        });
                    }
                });
            }
        });
        // src/services/codefixes/addMissingConst.ts
        function makeChange4(changeTracker, sourceFile, pos, program, fixedNodes) {
            const token = getTokenAtPosition(sourceFile, pos);
            const forInitializer = findAncestor(token, (node) => isForInOrOfStatement(node.parent) ? node.parent.initializer === node : isPossiblyPartOfDestructuring(node) ? false : "quit");
            if (forInitializer)
                return applyChange(changeTracker, forInitializer, sourceFile, fixedNodes);
            const parent2 = token.parent;
            if (isBinaryExpression(parent2) && parent2.operatorToken.kind === 64 /* EqualsToken */ && isExpressionStatement(parent2.parent)) {
                return applyChange(changeTracker, token, sourceFile, fixedNodes);
            }
            if (isArrayLiteralExpression(parent2)) {
                const checker = program.getTypeChecker();
                if (!every(parent2.elements, (element) => arrayElementCouldBeVariableDeclaration(element, checker))) {
                    return;
                }
                return applyChange(changeTracker, parent2, sourceFile, fixedNodes);
            }
            const commaExpression = findAncestor(token, (node) => isExpressionStatement(node.parent) ? true : isPossiblyPartOfCommaSeperatedInitializer(node) ? false : "quit");
            if (commaExpression) {
                const checker = program.getTypeChecker();
                if (!expressionCouldBeVariableDeclaration(commaExpression, checker)) {
                    return;
                }
                return applyChange(changeTracker, commaExpression, sourceFile, fixedNodes);
            }
        }
        function applyChange(changeTracker, initializer, sourceFile, fixedNodes) {
            if (!fixedNodes || tryAddToSet(fixedNodes, initializer)) {
                changeTracker.insertModifierBefore(sourceFile, 87 /* ConstKeyword */, initializer);
            }
        }
        function isPossiblyPartOfDestructuring(node) {
            switch (node.kind) {
                case 80 /* Identifier */:
                case 209 /* ArrayLiteralExpression */:
                case 210 /* ObjectLiteralExpression */:
                case 303 /* PropertyAssignment */:
                case 304 /* ShorthandPropertyAssignment */:
                    return true;
                default:
                    return false;
            }
        }
        function arrayElementCouldBeVariableDeclaration(expression, checker) {
            const identifier = isIdentifier(expression) ? expression : isAssignmentExpression(expression, 
            /*excludeCompoundAssignment*/
            true) && isIdentifier(expression.left) ? expression.left : void 0;
            return !!identifier && !checker.getSymbolAtLocation(identifier);
        }
        function isPossiblyPartOfCommaSeperatedInitializer(node) {
            switch (node.kind) {
                case 80 /* Identifier */:
                case 226 /* BinaryExpression */:
                case 28 /* CommaToken */:
                    return true;
                default:
                    return false;
            }
        }
        function expressionCouldBeVariableDeclaration(expression, checker) {
            if (!isBinaryExpression(expression)) {
                return false;
            }
            if (expression.operatorToken.kind === 28 /* CommaToken */) {
                return every([expression.left, expression.right], (expression2) => expressionCouldBeVariableDeclaration(expression2, checker));
            }
            return expression.operatorToken.kind === 64 /* EqualsToken */ && isIdentifier(expression.left) && !checker.getSymbolAtLocation(expression.left);
        }
        var fixId4, errorCodes4;
        var init_addMissingConst = __esm({
            "src/services/codefixes/addMissingConst.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId4 = "addMissingConst";
                errorCodes4 = [
                    Diagnostics.Cannot_find_name_0.code,
                    Diagnostics.No_value_exists_in_scope_for_the_shorthand_property_0_Either_declare_one_or_provide_an_initializer.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes4,
                    getCodeActions: function getCodeActionsToAddMissingConst(context) {
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => makeChange4(t, context.sourceFile, context.span.start, context.program));
                        if (changes.length > 0) {
                            return [createCodeFixAction(fixId4, changes, Diagnostics.Add_const_to_unresolved_variable, fixId4, Diagnostics.Add_const_to_all_unresolved_variables)];
                        }
                    },
                    fixIds: [fixId4],
                    getAllCodeActions: (context) => {
                        const fixedNodes = /* @__PURE__ */ new Set();
                        return codeFixAll(context, errorCodes4, (changes, diag2) => makeChange4(changes, diag2.file, diag2.start, context.program, fixedNodes));
                    }
                });
            }
        });
        // src/services/codefixes/addMissingDeclareProperty.ts
        function makeChange5(changeTracker, sourceFile, pos, fixedNodes) {
            const token = getTokenAtPosition(sourceFile, pos);
            if (!isIdentifier(token)) {
                return;
            }
            const declaration = token.parent;
            if (declaration.kind === 172 /* PropertyDeclaration */ && (!fixedNodes || tryAddToSet(fixedNodes, declaration))) {
                changeTracker.insertModifierBefore(sourceFile, 138 /* DeclareKeyword */, declaration);
            }
        }
        var fixId5, errorCodes5;
        var init_addMissingDeclareProperty = __esm({
            "src/services/codefixes/addMissingDeclareProperty.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId5 = "addMissingDeclareProperty";
                errorCodes5 = [
                    Diagnostics.Property_0_will_overwrite_the_base_property_in_1_If_this_is_intentional_add_an_initializer_Otherwise_add_a_declare_modifier_or_remove_the_redundant_declaration.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes5,
                    getCodeActions: function getCodeActionsToAddMissingDeclareOnProperty(context) {
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => makeChange5(t, context.sourceFile, context.span.start));
                        if (changes.length > 0) {
                            return [createCodeFixAction(fixId5, changes, Diagnostics.Prefix_with_declare, fixId5, Diagnostics.Prefix_all_incorrect_property_declarations_with_declare)];
                        }
                    },
                    fixIds: [fixId5],
                    getAllCodeActions: (context) => {
                        const fixedNodes = /* @__PURE__ */ new Set();
                        return codeFixAll(context, errorCodes5, (changes, diag2) => makeChange5(changes, diag2.file, diag2.start, fixedNodes));
                    }
                });
            }
        });
        // src/services/codefixes/addMissingInvocationForDecorator.ts
        function makeChange6(changeTracker, sourceFile, pos) {
            const token = getTokenAtPosition(sourceFile, pos);
            const decorator = findAncestor(token, isDecorator);
            Debug.assert(!!decorator, "Expected position to be owned by a decorator.");
            const replacement = factory.createCallExpression(decorator.expression, 
            /*typeArguments*/
            void 0, 
            /*argumentsArray*/
            void 0);
            changeTracker.replaceNode(sourceFile, decorator.expression, replacement);
        }
        var fixId6, errorCodes6;
        var init_addMissingInvocationForDecorator = __esm({
            "src/services/codefixes/addMissingInvocationForDecorator.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId6 = "addMissingInvocationForDecorator";
                errorCodes6 = [Diagnostics._0_accepts_too_few_arguments_to_be_used_as_a_decorator_here_Did_you_mean_to_call_it_first_and_write_0.code];
                registerCodeFix({
                    errorCodes: errorCodes6,
                    getCodeActions: function getCodeActionsToAddMissingInvocationForDecorator(context) {
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => makeChange6(t, context.sourceFile, context.span.start));
                        return [createCodeFixAction(fixId6, changes, Diagnostics.Call_decorator_expression, fixId6, Diagnostics.Add_to_all_uncalled_decorators)];
                    },
                    fixIds: [fixId6],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes6, (changes, diag2) => makeChange6(changes, diag2.file, diag2.start))
                });
            }
        });
        // src/services/codefixes/addNameToNamelessParameter.ts
        function makeChange7(changeTracker, sourceFile, start) {
            const token = getTokenAtPosition(sourceFile, start);
            const param = token.parent;
            if (!isParameter(param)) {
                return Debug.fail("Tried to add a parameter name to a non-parameter: " + Debug.formatSyntaxKind(token.kind));
            }
            const i = param.parent.parameters.indexOf(param);
            Debug.assert(!param.type, "Tried to add a parameter name to a parameter that already had one.");
            Debug.assert(i > -1, "Parameter not found in parent parameter list.");
            let end = param.name.getEnd();
            let typeNode = factory.createTypeReferenceNode(param.name, 
            /*typeArguments*/
            void 0);
            let nextParam = tryGetNextParam(sourceFile, param);
            while (nextParam) {
                typeNode = factory.createArrayTypeNode(typeNode);
                end = nextParam.getEnd();
                nextParam = tryGetNextParam(sourceFile, nextParam);
            }
            const replacement = factory.createParameterDeclaration(param.modifiers, param.dotDotDotToken, "arg" + i, param.questionToken, param.dotDotDotToken && !isArrayTypeNode(typeNode) ? factory.createArrayTypeNode(typeNode) : typeNode, param.initializer);
            changeTracker.replaceRange(sourceFile, createRange(param.getStart(sourceFile), end), replacement);
        }
        function tryGetNextParam(sourceFile, param) {
            const nextToken = findNextToken(param.name, param.parent, sourceFile);
            if (nextToken && nextToken.kind === 23 /* OpenBracketToken */ && isArrayBindingPattern(nextToken.parent) && isParameter(nextToken.parent.parent)) {
                return nextToken.parent.parent;
            }
            return void 0;
        }
        var fixId7, errorCodes7;
        var init_addNameToNamelessParameter = __esm({
            "src/services/codefixes/addNameToNamelessParameter.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId7 = "addNameToNamelessParameter";
                errorCodes7 = [Diagnostics.Parameter_has_a_name_but_no_type_Did_you_mean_0_Colon_1.code];
                registerCodeFix({
                    errorCodes: errorCodes7,
                    getCodeActions: function getCodeActionsToAddNameToNamelessParameter(context) {
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => makeChange7(t, context.sourceFile, context.span.start));
                        return [createCodeFixAction(fixId7, changes, Diagnostics.Add_parameter_name, fixId7, Diagnostics.Add_names_to_all_parameters_without_names)];
                    },
                    fixIds: [fixId7],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes7, (changes, diag2) => makeChange7(changes, diag2.file, diag2.start))
                });
            }
        });
        // src/services/codefixes/addOptionalPropertyUndefined.ts
        function getPropertiesToAdd(file, span, checker) {
            var _a, _b;
            const sourceTarget = getSourceTarget(getFixableErrorSpanExpression(file, span), checker);
            if (!sourceTarget) {
                return emptyArray;
            }
            const { source: sourceNode, target: targetNode } = sourceTarget;
            const target = shouldUseParentTypeOfProperty(sourceNode, targetNode, checker) ? checker.getTypeAtLocation(targetNode.expression) : checker.getTypeAtLocation(targetNode);
            if ((_b = (_a = target.symbol) == null ? void 0 : _a.declarations) == null ? void 0 : _b.some((d) => getSourceFileOfNode(d).fileName.match(/\.d\.ts$/))) {
                return emptyArray;
            }
            return checker.getExactOptionalProperties(target);
        }
        function shouldUseParentTypeOfProperty(sourceNode, targetNode, checker) {
            return isPropertyAccessExpression(targetNode) && !!checker.getExactOptionalProperties(checker.getTypeAtLocation(targetNode.expression)).length && checker.getTypeAtLocation(sourceNode) === checker.getUndefinedType();
        }
        function getSourceTarget(errorNode, checker) {
            var _a;
            if (!errorNode) {
                return void 0;
            }
            else if (isBinaryExpression(errorNode.parent) && errorNode.parent.operatorToken.kind === 64 /* EqualsToken */) {
                return { source: errorNode.parent.right, target: errorNode.parent.left };
            }
            else if (isVariableDeclaration(errorNode.parent) && errorNode.parent.initializer) {
                return { source: errorNode.parent.initializer, target: errorNode.parent.name };
            }
            else if (isCallExpression(errorNode.parent)) {
                const n = checker.getSymbolAtLocation(errorNode.parent.expression);
                if (!(n == null ? void 0 : n.valueDeclaration) || !isFunctionLikeKind(n.valueDeclaration.kind))
                    return void 0;
                if (!isExpression(errorNode))
                    return void 0;
                const i = errorNode.parent.arguments.indexOf(errorNode);
                if (i === -1)
                    return void 0;
                const name = n.valueDeclaration.parameters[i].name;
                if (isIdentifier(name))
                    return { source: errorNode, target: name };
            }
            else if (isPropertyAssignment(errorNode.parent) && isIdentifier(errorNode.parent.name) || isShorthandPropertyAssignment(errorNode.parent)) {
                const parentTarget = getSourceTarget(errorNode.parent.parent, checker);
                if (!parentTarget)
                    return void 0;
                const prop = checker.getPropertyOfType(checker.getTypeAtLocation(parentTarget.target), errorNode.parent.name.text);
                const declaration = (_a = prop == null ? void 0 : prop.declarations) == null ? void 0 : _a[0];
                if (!declaration)
                    return void 0;
                return {
                    source: isPropertyAssignment(errorNode.parent) ? errorNode.parent.initializer : errorNode.parent.name,
                    target: declaration
                };
            }
            return void 0;
        }
        function addUndefinedToOptionalProperty(changes, toAdd) {
            for (const add of toAdd) {
                const d = add.valueDeclaration;
                if (d && (isPropertySignature(d) || isPropertyDeclaration(d)) && d.type) {
                    const t = factory.createUnionTypeNode([
                        ...d.type.kind === 192 /* UnionType */ ? d.type.types : [d.type],
                        factory.createTypeReferenceNode("undefined")
                    ]);
                    changes.replaceNode(d.getSourceFile(), d.type, t);
                }
            }
        }
        var addOptionalPropertyUndefined, errorCodes8;
        var init_addOptionalPropertyUndefined = __esm({
            "src/services/codefixes/addOptionalPropertyUndefined.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                addOptionalPropertyUndefined = "addOptionalPropertyUndefined";
                errorCodes8 = [
                    Diagnostics.Type_0_is_not_assignable_to_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_type_of_the_target.code,
                    Diagnostics.Type_0_is_not_assignable_to_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_types_of_the_target_s_properties.code,
                    Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_types_of_the_target_s_properties.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes8,
                    getCodeActions(context) {
                        const typeChecker = context.program.getTypeChecker();
                        const toAdd = getPropertiesToAdd(context.sourceFile, context.span, typeChecker);
                        if (!toAdd.length) {
                            return void 0;
                        }
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => addUndefinedToOptionalProperty(t, toAdd));
                        return [createCodeFixActionWithoutFixAll(addOptionalPropertyUndefined, changes, Diagnostics.Add_undefined_to_optional_property_type)];
                    },
                    fixIds: [addOptionalPropertyUndefined]
                });
            }
        });
        // src/services/codefixes/annotateWithTypeFromJSDoc.ts
        function getDeclaration(file, pos) {
            const name = getTokenAtPosition(file, pos);
            return tryCast(isParameter(name.parent) ? name.parent.parent : name.parent, parameterShouldGetTypeFromJSDoc);
        }
        function parameterShouldGetTypeFromJSDoc(node) {
            return isDeclarationWithType(node) && hasUsableJSDoc(node);
        }
        function hasUsableJSDoc(decl) {
            return isFunctionLikeDeclaration(decl) ? decl.parameters.some(hasUsableJSDoc) || !decl.type && !!getJSDocReturnType(decl) : !decl.type && !!getJSDocType(decl);
        }
        function doChange8(changes, sourceFile, decl) {
            if (isFunctionLikeDeclaration(decl) && (getJSDocReturnType(decl) || decl.parameters.some((p) => !!getJSDocType(p)))) {
                if (!decl.typeParameters) {
                    const typeParameters = getJSDocTypeParameterDeclarations(decl);
                    if (typeParameters.length)
                        changes.insertTypeParameters(sourceFile, decl, typeParameters);
                }
                const needParens = isArrowFunction(decl) && !findChildOfKind(decl, 21 /* OpenParenToken */, sourceFile);
                if (needParens)
                    changes.insertNodeBefore(sourceFile, first(decl.parameters), factory.createToken(21 /* OpenParenToken */));
                for (const param of decl.parameters) {
                    if (!param.type) {
                        const paramType = getJSDocType(param);
                        if (paramType)
                            changes.tryInsertTypeAnnotation(sourceFile, param, visitNode(paramType, transformJSDocType, isTypeNode));
                    }
                }
                if (needParens)
                    changes.insertNodeAfter(sourceFile, last(decl.parameters), factory.createToken(22 /* CloseParenToken */));
                if (!decl.type) {
                    const returnType = getJSDocReturnType(decl);
                    if (returnType)
                        changes.tryInsertTypeAnnotation(sourceFile, decl, visitNode(returnType, transformJSDocType, isTypeNode));
                }
            }
            else {
                const jsdocType = Debug.checkDefined(getJSDocType(decl), "A JSDocType for this declaration should exist");
                Debug.assert(!decl.type, "The JSDocType decl should have a type");
                changes.tryInsertTypeAnnotation(sourceFile, decl, visitNode(jsdocType, transformJSDocType, isTypeNode));
            }
        }
        function isDeclarationWithType(node) {
            return isFunctionLikeDeclaration(node) || node.kind === 260 /* VariableDeclaration */ || node.kind === 171 /* PropertySignature */ || node.kind === 172 /* PropertyDeclaration */;
        }
        function transformJSDocType(node) {
            switch (node.kind) {
                case 319 /* JSDocAllType */:
                case 320 /* JSDocUnknownType */:
                    return factory.createTypeReferenceNode("any", emptyArray);
                case 323 /* JSDocOptionalType */:
                    return transformJSDocOptionalType(node);
                case 322 /* JSDocNonNullableType */:
                    return transformJSDocType(node.type);
                case 321 /* JSDocNullableType */:
                    return transformJSDocNullableType(node);
                case 325 /* JSDocVariadicType */:
                    return transformJSDocVariadicType(node);
                case 324 /* JSDocFunctionType */:
                    return transformJSDocFunctionType(node);
                case 183 /* TypeReference */:
                    return transformJSDocTypeReference(node);
                case 329 /* JSDocTypeLiteral */:
                    return transformJSDocTypeLiteral(node);
                default:
                    const visited = visitEachChild(node, transformJSDocType, 
                    /*context*/
                    void 0);
                    setEmitFlags(visited, 1 /* SingleLine */);
                    return visited;
            }
        }
        function transformJSDocTypeLiteral(node) {
            const typeNode = factory.createTypeLiteralNode(map(node.jsDocPropertyTags, (tag) => factory.createPropertySignature(
            /*modifiers*/
            void 0, isIdentifier(tag.name) ? tag.name : tag.name.right, isOptionalJSDocPropertyLikeTag(tag) ? factory.createToken(58 /* QuestionToken */) : void 0, tag.typeExpression && visitNode(tag.typeExpression.type, transformJSDocType, isTypeNode) || factory.createKeywordTypeNode(133 /* AnyKeyword */))));
            setEmitFlags(typeNode, 1 /* SingleLine */);
            return typeNode;
        }
        function transformJSDocOptionalType(node) {
            return factory.createUnionTypeNode([visitNode(node.type, transformJSDocType, isTypeNode), factory.createTypeReferenceNode("undefined", emptyArray)]);
        }
        function transformJSDocNullableType(node) {
            return factory.createUnionTypeNode([visitNode(node.type, transformJSDocType, isTypeNode), factory.createTypeReferenceNode("null", emptyArray)]);
        }
        function transformJSDocVariadicType(node) {
            return factory.createArrayTypeNode(visitNode(node.type, transformJSDocType, isTypeNode));
        }
        function transformJSDocFunctionType(node) {
            return factory.createFunctionTypeNode(emptyArray, node.parameters.map(transformJSDocParameter), node.type ?? factory.createKeywordTypeNode(133 /* AnyKeyword */));
        }
        function transformJSDocParameter(node) {
            const index = node.parent.parameters.indexOf(node);
            const isRest = node.type.kind === 325 /* JSDocVariadicType */ && index === node.parent.parameters.length - 1;
            const name = node.name || (isRest ? "rest" : "arg" + index);
            const dotdotdot = isRest ? factory.createToken(26 /* DotDotDotToken */) : node.dotDotDotToken;
            return factory.createParameterDeclaration(node.modifiers, dotdotdot, name, node.questionToken, visitNode(node.type, transformJSDocType, isTypeNode), node.initializer);
        }
        function transformJSDocTypeReference(node) {
            let name = node.typeName;
            let args = node.typeArguments;
            if (isIdentifier(node.typeName)) {
                if (isJSDocIndexSignature(node)) {
                    return transformJSDocIndexSignature(node);
                }
                let text = node.typeName.text;
                switch (node.typeName.text) {
                    case "String":
                    case "Boolean":
                    case "Object":
                    case "Number":
                        text = text.toLowerCase();
                        break;
                    case "array":
                    case "date":
                    case "promise":
                        text = text[0].toUpperCase() + text.slice(1);
                        break;
                }
                name = factory.createIdentifier(text);
                if ((text === "Array" || text === "Promise") && !node.typeArguments) {
                    args = factory.createNodeArray([factory.createTypeReferenceNode("any", emptyArray)]);
                }
                else {
                    args = visitNodes2(node.typeArguments, transformJSDocType, isTypeNode);
                }
            }
            return factory.createTypeReferenceNode(name, args);
        }
        function transformJSDocIndexSignature(node) {
            const index = factory.createParameterDeclaration(
            /*modifiers*/
            void 0, 
            /*dotDotDotToken*/
            void 0, node.typeArguments[0].kind === 150 /* NumberKeyword */ ? "n" : "s", 
            /*questionToken*/
            void 0, factory.createTypeReferenceNode(node.typeArguments[0].kind === 150 /* NumberKeyword */ ? "number" : "string", []), 
            /*initializer*/
            void 0);
            const indexSignature = factory.createTypeLiteralNode([factory.createIndexSignature(
                /*modifiers*/
                void 0, [index], node.typeArguments[1])]);
            setEmitFlags(indexSignature, 1 /* SingleLine */);
            return indexSignature;
        }
        var fixId8, errorCodes9;
        var init_annotateWithTypeFromJSDoc = __esm({
            "src/services/codefixes/annotateWithTypeFromJSDoc.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId8 = "annotateWithTypeFromJSDoc";
                errorCodes9 = [Diagnostics.JSDoc_types_may_be_moved_to_TypeScript_types.code];
                registerCodeFix({
                    errorCodes: errorCodes9,
                    getCodeActions(context) {
                        const decl = getDeclaration(context.sourceFile, context.span.start);
                        if (!decl)
                            return;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange8(t, context.sourceFile, decl));
                        return [createCodeFixAction(fixId8, changes, Diagnostics.Annotate_with_type_from_JSDoc, fixId8, Diagnostics.Annotate_everything_with_types_from_JSDoc)];
                    },
                    fixIds: [fixId8],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes9, (changes, diag2) => {
                        const decl = getDeclaration(diag2.file, diag2.start);
                        if (decl)
                            doChange8(changes, diag2.file, decl);
                    })
                });
            }
        });
        // src/services/codefixes/convertFunctionToEs6Class.ts
        function doChange9(changes, sourceFile, position, checker, preferences, compilerOptions) {
            const ctorSymbol = checker.getSymbolAtLocation(getTokenAtPosition(sourceFile, position));
            if (!ctorSymbol || !ctorSymbol.valueDeclaration || !(ctorSymbol.flags & (16 /* Function */ | 3 /* Variable */))) {
                return void 0;
            }
            const ctorDeclaration = ctorSymbol.valueDeclaration;
            if (isFunctionDeclaration(ctorDeclaration) || isFunctionExpression(ctorDeclaration)) {
                changes.replaceNode(sourceFile, ctorDeclaration, createClassFromFunction(ctorDeclaration));
            }
            else if (isVariableDeclaration(ctorDeclaration)) {
                const classDeclaration = createClassFromVariableDeclaration(ctorDeclaration);
                if (!classDeclaration) {
                    return void 0;
                }
                const ancestor = ctorDeclaration.parent.parent;
                if (isVariableDeclarationList(ctorDeclaration.parent) && ctorDeclaration.parent.declarations.length > 1) {
                    changes.delete(sourceFile, ctorDeclaration);
                    changes.insertNodeAfter(sourceFile, ancestor, classDeclaration);
                }
                else {
                    changes.replaceNode(sourceFile, ancestor, classDeclaration);
                }
            }
            function createClassElementsFromSymbol(symbol) {
                const memberElements = [];
                if (symbol.exports) {
                    symbol.exports.forEach((member) => {
                        if (member.name === "prototype" && member.declarations) {
                            const firstDeclaration = member.declarations[0];
                            if (member.declarations.length === 1 && isPropertyAccessExpression(firstDeclaration) && isBinaryExpression(firstDeclaration.parent) && firstDeclaration.parent.operatorToken.kind === 64 /* EqualsToken */ && isObjectLiteralExpression(firstDeclaration.parent.right)) {
                                const prototypes = firstDeclaration.parent.right;
                                createClassElement(prototypes.symbol, 
                                /*modifiers*/
                                void 0, memberElements);
                            }
                        }
                        else {
                            createClassElement(member, [factory.createToken(126 /* StaticKeyword */)], memberElements);
                        }
                    });
                }
                if (symbol.members) {
                    symbol.members.forEach((member, key) => {
                        var _a, _b, _c, _d;
                        if (key === "constructor" && member.valueDeclaration) {
                            const prototypeAssignment = (_d = (_c = (_b = (_a = symbol.exports) == null ? void 0 : _a.get("prototype")) == null ? void 0 : _b.declarations) == null ? void 0 : _c[0]) == null ? void 0 : _d.parent;
                            if (prototypeAssignment && isBinaryExpression(prototypeAssignment) && isObjectLiteralExpression(prototypeAssignment.right) && some(prototypeAssignment.right.properties, isConstructorAssignment)) {
                            }
                            else {
                                changes.delete(sourceFile, member.valueDeclaration.parent);
                            }
                            return;
                        }
                        createClassElement(member, 
                        /*modifiers*/
                        void 0, memberElements);
                    });
                }
                return memberElements;
                function shouldConvertDeclaration(_target, source) {
                    if (isAccessExpression(_target)) {
                        if (isPropertyAccessExpression(_target) && isConstructorAssignment(_target))
                            return true;
                        return isFunctionLike(source);
                    }
                    else {
                        return every(_target.properties, (property) => {
                            if (isMethodDeclaration(property) || isGetOrSetAccessorDeclaration(property))
                                return true;
                            if (isPropertyAssignment(property) && isFunctionExpression(property.initializer) && !!property.name)
                                return true;
                            if (isConstructorAssignment(property))
                                return true;
                            return false;
                        });
                    }
                }
                function createClassElement(symbol2, modifiers, members) {
                    if (!(symbol2.flags & 8192 /* Method */) && !(symbol2.flags & 4096 /* ObjectLiteral */)) {
                        return;
                    }
                    const memberDeclaration = symbol2.valueDeclaration;
                    const assignmentBinaryExpression = memberDeclaration.parent;
                    const assignmentExpr = assignmentBinaryExpression.right;
                    if (!shouldConvertDeclaration(memberDeclaration, assignmentExpr)) {
                        return;
                    }
                    if (some(members, (m) => {
                        const name = getNameOfDeclaration(m);
                        if (name && isIdentifier(name) && idText(name) === symbolName(symbol2)) {
                            return true;
                        }
                        return false;
                    })) {
                        return;
                    }
                    const nodeToDelete = assignmentBinaryExpression.parent && assignmentBinaryExpression.parent.kind === 244 /* ExpressionStatement */ ? assignmentBinaryExpression.parent : assignmentBinaryExpression;
                    changes.delete(sourceFile, nodeToDelete);
                    if (!assignmentExpr) {
                        members.push(factory.createPropertyDeclaration(modifiers, symbol2.name, 
                        /*questionOrExclamationToken*/
                        void 0, 
                        /*type*/
                        void 0, 
                        /*initializer*/
                        void 0));
                        return;
                    }
                    if (isAccessExpression(memberDeclaration) && (isFunctionExpression(assignmentExpr) || isArrowFunction(assignmentExpr))) {
                        const quotePreference = getQuotePreference(sourceFile, preferences);
                        const name = tryGetPropertyName(memberDeclaration, compilerOptions, quotePreference);
                        if (name) {
                            createFunctionLikeExpressionMember(members, assignmentExpr, name);
                        }
                        return;
                    }
                    else if (isObjectLiteralExpression(assignmentExpr)) {
                        forEach(assignmentExpr.properties, (property) => {
                            if (isMethodDeclaration(property) || isGetOrSetAccessorDeclaration(property)) {
                                members.push(property);
                            }
                            if (isPropertyAssignment(property) && isFunctionExpression(property.initializer)) {
                                createFunctionLikeExpressionMember(members, property.initializer, property.name);
                            }
                            if (isConstructorAssignment(property))
                                return;
                            return;
                        });
                        return;
                    }
                    else {
                        if (isSourceFileJS(sourceFile))
                            return;
                        if (!isPropertyAccessExpression(memberDeclaration))
                            return;
                        const prop = factory.createPropertyDeclaration(modifiers, memberDeclaration.name, 
                        /*questionOrExclamationToken*/
                        void 0, 
                        /*type*/
                        void 0, assignmentExpr);
                        copyLeadingComments(assignmentBinaryExpression.parent, prop, sourceFile);
                        members.push(prop);
                        return;
                    }
                    function createFunctionLikeExpressionMember(members2, expression, name) {
                        if (isFunctionExpression(expression))
                            return createFunctionExpressionMember(members2, expression, name);
                        else
                            return createArrowFunctionExpressionMember(members2, expression, name);
                    }
                    function createFunctionExpressionMember(members2, functionExpression, name) {
                        const fullModifiers = concatenate(modifiers, getModifierKindFromSource(functionExpression, 134 /* AsyncKeyword */));
                        const method = factory.createMethodDeclaration(fullModifiers, 
                        /*asteriskToken*/
                        void 0, name, 
                        /*questionToken*/
                        void 0, 
                        /*typeParameters*/
                        void 0, functionExpression.parameters, 
                        /*type*/
                        void 0, functionExpression.body);
                        copyLeadingComments(assignmentBinaryExpression, method, sourceFile);
                        members2.push(method);
                        return;
                    }
                    function createArrowFunctionExpressionMember(members2, arrowFunction, name) {
                        const arrowFunctionBody = arrowFunction.body;
                        let bodyBlock;
                        if (arrowFunctionBody.kind === 241 /* Block */) {
                            bodyBlock = arrowFunctionBody;
                        }
                        else {
                            bodyBlock = factory.createBlock([factory.createReturnStatement(arrowFunctionBody)]);
                        }
                        const fullModifiers = concatenate(modifiers, getModifierKindFromSource(arrowFunction, 134 /* AsyncKeyword */));
                        const method = factory.createMethodDeclaration(fullModifiers, 
                        /*asteriskToken*/
                        void 0, name, 
                        /*questionToken*/
                        void 0, 
                        /*typeParameters*/
                        void 0, arrowFunction.parameters, 
                        /*type*/
                        void 0, bodyBlock);
                        copyLeadingComments(assignmentBinaryExpression, method, sourceFile);
                        members2.push(method);
                    }
                }
            }
            function createClassFromVariableDeclaration(node) {
                const initializer = node.initializer;
                if (!initializer || !isFunctionExpression(initializer) || !isIdentifier(node.name)) {
                    return void 0;
                }
                const memberElements = createClassElementsFromSymbol(node.symbol);
                if (initializer.body) {
                    memberElements.unshift(factory.createConstructorDeclaration(
                    /*modifiers*/
                    void 0, initializer.parameters, initializer.body));
                }
                const modifiers = getModifierKindFromSource(node.parent.parent, 95 /* ExportKeyword */);
                const cls = factory.createClassDeclaration(modifiers, node.name, 
                /*typeParameters*/
                void 0, 
                /*heritageClauses*/
                void 0, memberElements);
                return cls;
            }
            function createClassFromFunction(node) {
                const memberElements = createClassElementsFromSymbol(ctorSymbol);
                if (node.body) {
                    memberElements.unshift(factory.createConstructorDeclaration(
                    /*modifiers*/
                    void 0, node.parameters, node.body));
                }
                const modifiers = getModifierKindFromSource(node, 95 /* ExportKeyword */);
                const cls = factory.createClassDeclaration(modifiers, node.name, 
                /*typeParameters*/
                void 0, 
                /*heritageClauses*/
                void 0, memberElements);
                return cls;
            }
        }
        function getModifierKindFromSource(source, kind) {
            return canHaveModifiers(source) ? filter(source.modifiers, (modifier) => modifier.kind === kind) : void 0;
        }
        function isConstructorAssignment(x) {
            if (!x.name)
                return false;
            if (isIdentifier(x.name) && x.name.text === "constructor")
                return true;
            return false;
        }
        function tryGetPropertyName(node, compilerOptions, quotePreference) {
            if (isPropertyAccessExpression(node)) {
                return node.name;
            }
            const propName = node.argumentExpression;
            if (isNumericLiteral(propName)) {
                return propName;
            }
            if (isStringLiteralLike(propName)) {
                return isIdentifierText(propName.text, getEmitScriptTarget(compilerOptions)) ? factory.createIdentifier(propName.text) : isNoSubstitutionTemplateLiteral(propName) ? factory.createStringLiteral(propName.text, quotePreference === 0 /* Single */) : propName;
            }
            return void 0;
        }
        var fixId9, errorCodes10;
        var init_convertFunctionToEs6Class = __esm({
            "src/services/codefixes/convertFunctionToEs6Class.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId9 = "convertFunctionToEs6Class";
                errorCodes10 = [Diagnostics.This_constructor_function_may_be_converted_to_a_class_declaration.code];
                registerCodeFix({
                    errorCodes: errorCodes10,
                    getCodeActions(context) {
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange9(t, context.sourceFile, context.span.start, context.program.getTypeChecker(), context.preferences, context.program.getCompilerOptions()));
                        return [createCodeFixAction(fixId9, changes, Diagnostics.Convert_function_to_an_ES2015_class, fixId9, Diagnostics.Convert_all_constructor_functions_to_classes)];
                    },
                    fixIds: [fixId9],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes10, (changes, err) => doChange9(changes, err.file, err.start, context.program.getTypeChecker(), context.preferences, context.program.getCompilerOptions()))
                });
            }
        });
        // src/services/codefixes/convertToAsyncFunction.ts
        function convertToAsyncFunction(changes, sourceFile, position, checker) {
            const tokenAtPosition = getTokenAtPosition(sourceFile, position);
            let functionToConvert;
            if (isIdentifier(tokenAtPosition) && isVariableDeclaration(tokenAtPosition.parent) && tokenAtPosition.parent.initializer && isFunctionLikeDeclaration(tokenAtPosition.parent.initializer)) {
                functionToConvert = tokenAtPosition.parent.initializer;
            }
            else {
                functionToConvert = tryCast(getContainingFunction(getTokenAtPosition(sourceFile, position)), canBeConvertedToAsync);
            }
            if (!functionToConvert) {
                return;
            }
            const synthNamesMap = /* @__PURE__ */ new Map();
            const isInJavascript = isInJSFile(functionToConvert);
            const setOfExpressionsToReturn = getAllPromiseExpressionsToReturn(functionToConvert, checker);
            const functionToConvertRenamed = renameCollidingVarNames(functionToConvert, checker, synthNamesMap);
            if (!returnsPromise(functionToConvertRenamed, checker)) {
                return;
            }
            const returnStatements = functionToConvertRenamed.body && isBlock(functionToConvertRenamed.body) ? getReturnStatementsWithPromiseHandlers(functionToConvertRenamed.body, checker) : emptyArray;
            const transformer = { checker, synthNamesMap, setOfExpressionsToReturn, isInJSFile: isInJavascript };
            if (!returnStatements.length) {
                return;
            }
            const pos = skipTrivia(sourceFile.text, moveRangePastModifiers(functionToConvert).pos);
            changes.insertModifierAt(sourceFile, pos, 134 /* AsyncKeyword */, { suffix: " " });
            for (const returnStatement of returnStatements) {
                forEachChild(returnStatement, function visit(node) {
                    if (isCallExpression(node)) {
                        const newNodes = transformExpression(node, node, transformer, 
                        /*hasContinuation*/
                        false);
                        if (hasFailed()) {
                            return true;
                        }
                        changes.replaceNodeWithNodes(sourceFile, returnStatement, newNodes);
                    }
                    else if (!isFunctionLike(node)) {
                        forEachChild(node, visit);
                        if (hasFailed()) {
                            return true;
                        }
                    }
                });
                if (hasFailed()) {
                    return;
                }
            }
        }
        function getReturnStatementsWithPromiseHandlers(body, checker) {
            const res = [];
            forEachReturnStatement(body, (ret) => {
                if (isReturnStatementWithFixablePromiseHandler(ret, checker))
                    res.push(ret);
            });
            return res;
        }
        function getAllPromiseExpressionsToReturn(func, checker) {
            if (!func.body) {
                return /* @__PURE__ */ new Set();
            }
            const setOfExpressionsToReturn = /* @__PURE__ */ new Set();
            forEachChild(func.body, function visit(node) {
                if (isPromiseReturningCallExpression(node, checker, "then")) {
                    setOfExpressionsToReturn.add(getNodeId(node));
                    forEach(node.arguments, visit);
                }
                else if (isPromiseReturningCallExpression(node, checker, "catch") || isPromiseReturningCallExpression(node, checker, "finally")) {
                    setOfExpressionsToReturn.add(getNodeId(node));
                    forEachChild(node, visit);
                }
                else if (isPromiseTypedExpression(node, checker)) {
                    setOfExpressionsToReturn.add(getNodeId(node));
                }
                else {
                    forEachChild(node, visit);
                }
            });
            return setOfExpressionsToReturn;
        }
        function isPromiseReturningCallExpression(node, checker, name) {
            if (!isCallExpression(node))
                return false;
            const isExpressionOfName = hasPropertyAccessExpressionWithName(node, name);
            const nodeType = isExpressionOfName && checker.getTypeAtLocation(node);
            return !!(nodeType && checker.getPromisedTypeOfPromise(nodeType));
        }
        function isReferenceToType(type, target) {
            return (getObjectFlags(type) & 4 /* Reference */) !== 0 && type.target === target;
        }
        function getExplicitPromisedTypeOfPromiseReturningCallExpression(node, callback, checker) {
            if (node.expression.name.escapedText === "finally") {
                return void 0;
            }
            const promiseType = checker.getTypeAtLocation(node.expression.expression);
            if (isReferenceToType(promiseType, checker.getPromiseType()) || isReferenceToType(promiseType, checker.getPromiseLikeType())) {
                if (node.expression.name.escapedText === "then") {
                    if (callback === elementAt(node.arguments, 0)) {
                        return elementAt(node.typeArguments, 0);
                    }
                    else if (callback === elementAt(node.arguments, 1)) {
                        return elementAt(node.typeArguments, 1);
                    }
                }
                else {
                    return elementAt(node.typeArguments, 0);
                }
            }
        }
        function isPromiseTypedExpression(node, checker) {
            if (!isExpression(node))
                return false;
            return !!checker.getPromisedTypeOfPromise(checker.getTypeAtLocation(node));
        }
        function renameCollidingVarNames(nodeToRename, checker, synthNamesMap) {
            const identsToRenameMap = /* @__PURE__ */ new Map();
            const collidingSymbolMap = createMultiMap();
            forEachChild(nodeToRename, function visit(node) {
                if (!isIdentifier(node)) {
                    forEachChild(node, visit);
                    return;
                }
                const symbol = checker.getSymbolAtLocation(node);
                if (symbol) {
                    const type = checker.getTypeAtLocation(node);
                    const lastCallSignature = getLastCallSignature(type, checker);
                    const symbolIdString = getSymbolId(symbol).toString();
                    if (lastCallSignature && !isParameter(node.parent) && !isFunctionLikeDeclaration(node.parent) && !synthNamesMap.has(symbolIdString)) {
                        const firstParameter = firstOrUndefined(lastCallSignature.parameters);
                        const ident = (firstParameter == null ? void 0 : firstParameter.valueDeclaration) && isParameter(firstParameter.valueDeclaration) && tryCast(firstParameter.valueDeclaration.name, isIdentifier) || factory.createUniqueName("result", 16 /* Optimistic */);
                        const synthName = getNewNameIfConflict(ident, collidingSymbolMap);
                        synthNamesMap.set(symbolIdString, synthName);
                        collidingSymbolMap.add(ident.text, symbol);
                    }
                    else if (node.parent && (isParameter(node.parent) || isVariableDeclaration(node.parent) || isBindingElement(node.parent))) {
                        const originalName = node.text;
                        const collidingSymbols = collidingSymbolMap.get(originalName);
                        if (collidingSymbols && collidingSymbols.some((prevSymbol) => prevSymbol !== symbol)) {
                            const newName = getNewNameIfConflict(node, collidingSymbolMap);
                            identsToRenameMap.set(symbolIdString, newName.identifier);
                            synthNamesMap.set(symbolIdString, newName);
                            collidingSymbolMap.add(originalName, symbol);
                        }
                        else {
                            const identifier = getSynthesizedDeepClone(node);
                            synthNamesMap.set(symbolIdString, createSynthIdentifier(identifier));
                            collidingSymbolMap.add(originalName, symbol);
                        }
                    }
                }
            });
            return getSynthesizedDeepCloneWithReplacements(nodeToRename, 
            /*includeTrivia*/
            true, (original) => {
                if (isBindingElement(original) && isIdentifier(original.name) && isObjectBindingPattern(original.parent)) {
                    const symbol = checker.getSymbolAtLocation(original.name);
                    const renameInfo = symbol && identsToRenameMap.get(String(getSymbolId(symbol)));
                    if (renameInfo && renameInfo.text !== (original.name || original.propertyName).getText()) {
                        return factory.createBindingElement(original.dotDotDotToken, original.propertyName || original.name, renameInfo, original.initializer);
                    }
                }
                else if (isIdentifier(original)) {
                    const symbol = checker.getSymbolAtLocation(original);
                    const renameInfo = symbol && identsToRenameMap.get(String(getSymbolId(symbol)));
                    if (renameInfo) {
                        return factory.createIdentifier(renameInfo.text);
                    }
                }
            });
        }
        function getNewNameIfConflict(name, originalNames) {
            const numVarsSameName = (originalNames.get(name.text) || emptyArray).length;
            const identifier = numVarsSameName === 0 ? name : factory.createIdentifier(name.text + "_" + numVarsSameName);
            return createSynthIdentifier(identifier);
        }
        function hasFailed() {
            return !codeActionSucceeded;
        }
        function silentFail() {
            codeActionSucceeded = false;
            return emptyArray;
        }
        function transformExpression(returnContextNode, node, transformer, hasContinuation, continuationArgName) {
            if (isPromiseReturningCallExpression(node, transformer.checker, "then")) {
                return transformThen(node, elementAt(node.arguments, 0), elementAt(node.arguments, 1), transformer, hasContinuation, continuationArgName);
            }
            if (isPromiseReturningCallExpression(node, transformer.checker, "catch")) {
                return transformCatch(node, elementAt(node.arguments, 0), transformer, hasContinuation, continuationArgName);
            }
            if (isPromiseReturningCallExpression(node, transformer.checker, "finally")) {
                return transformFinally(node, elementAt(node.arguments, 0), transformer, hasContinuation, continuationArgName);
            }
            if (isPropertyAccessExpression(node)) {
                return transformExpression(returnContextNode, node.expression, transformer, hasContinuation, continuationArgName);
            }
            const nodeType = transformer.checker.getTypeAtLocation(node);
            if (nodeType && transformer.checker.getPromisedTypeOfPromise(nodeType)) {
                Debug.assertNode(getOriginalNode(node).parent, isPropertyAccessExpression);
                return transformPromiseExpressionOfPropertyAccess(returnContextNode, node, transformer, hasContinuation, continuationArgName);
            }
            return silentFail();
        }
        function isNullOrUndefined2({ checker }, node) {
            if (node.kind === 106 /* NullKeyword */)
                return true;
            if (isIdentifier(node) && !isGeneratedIdentifier(node) && idText(node) === "undefined") {
                const symbol = checker.getSymbolAtLocation(node);
                return !symbol || checker.isUndefinedSymbol(symbol);
            }
            return false;
        }
        function createUniqueSynthName(prevArgName) {
            const renamedPrevArg = factory.createUniqueName(prevArgName.identifier.text, 16 /* Optimistic */);
            return createSynthIdentifier(renamedPrevArg);
        }
        function getPossibleNameForVarDecl(node, transformer, continuationArgName) {
            let possibleNameForVarDecl;
            if (continuationArgName && !shouldReturn(node, transformer)) {
                if (isSynthIdentifier(continuationArgName)) {
                    possibleNameForVarDecl = continuationArgName;
                    transformer.synthNamesMap.forEach((val, key) => {
                        if (val.identifier.text === continuationArgName.identifier.text) {
                            const newSynthName = createUniqueSynthName(continuationArgName);
                            transformer.synthNamesMap.set(key, newSynthName);
                        }
                    });
                }
                else {
                    possibleNameForVarDecl = createSynthIdentifier(factory.createUniqueName("result", 16 /* Optimistic */), continuationArgName.types);
                }
                declareSynthIdentifier(possibleNameForVarDecl);
            }
            return possibleNameForVarDecl;
        }
        function finishCatchOrFinallyTransform(node, transformer, tryStatement, possibleNameForVarDecl, continuationArgName) {
            const statements = [];
            let varDeclIdentifier;
            if (possibleNameForVarDecl && !shouldReturn(node, transformer)) {
                varDeclIdentifier = getSynthesizedDeepClone(declareSynthIdentifier(possibleNameForVarDecl));
                const typeArray = possibleNameForVarDecl.types;
                const unionType = transformer.checker.getUnionType(typeArray, 2 /* Subtype */);
                const unionTypeNode = transformer.isInJSFile ? void 0 : transformer.checker.typeToTypeNode(unionType, 
                /*enclosingDeclaration*/
                void 0, 
                /*flags*/
                void 0);
                const varDecl = [factory.createVariableDeclaration(varDeclIdentifier, 
                    /*exclamationToken*/
                    void 0, unionTypeNode)];
                const varDeclList = factory.createVariableStatement(
                /*modifiers*/
                void 0, factory.createVariableDeclarationList(varDecl, 1 /* Let */));
                statements.push(varDeclList);
            }
            statements.push(tryStatement);
            if (continuationArgName && varDeclIdentifier && isSynthBindingPattern(continuationArgName)) {
                statements.push(factory.createVariableStatement(
                /*modifiers*/
                void 0, factory.createVariableDeclarationList([
                    factory.createVariableDeclaration(getSynthesizedDeepClone(declareSynthBindingPattern(continuationArgName)), 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, varDeclIdentifier)
                ], 2 /* Const */)));
            }
            return statements;
        }
        function transformFinally(node, onFinally, transformer, hasContinuation, continuationArgName) {
            if (!onFinally || isNullOrUndefined2(transformer, onFinally)) {
                return transformExpression(
                /* returnContextNode */
                node, node.expression.expression, transformer, hasContinuation, continuationArgName);
            }
            const possibleNameForVarDecl = getPossibleNameForVarDecl(node, transformer, continuationArgName);
            const inlinedLeftHandSide = transformExpression(
            /*returnContextNode*/
            node, node.expression.expression, transformer, 
            /*hasContinuation*/
            true, possibleNameForVarDecl);
            if (hasFailed())
                return silentFail();
            const inlinedCallback = transformCallbackArgument(onFinally, hasContinuation, 
            /*continuationArgName*/
            void 0, 
            /*inputArgName*/
            void 0, node, transformer);
            if (hasFailed())
                return silentFail();
            const tryBlock = factory.createBlock(inlinedLeftHandSide);
            const finallyBlock = factory.createBlock(inlinedCallback);
            const tryStatement = factory.createTryStatement(tryBlock, 
            /*catchClause*/
            void 0, finallyBlock);
            return finishCatchOrFinallyTransform(node, transformer, tryStatement, possibleNameForVarDecl, continuationArgName);
        }
        function transformCatch(node, onRejected, transformer, hasContinuation, continuationArgName) {
            if (!onRejected || isNullOrUndefined2(transformer, onRejected)) {
                return transformExpression(
                /* returnContextNode */
                node, node.expression.expression, transformer, hasContinuation, continuationArgName);
            }
            const inputArgName = getArgBindingName(onRejected, transformer);
            const possibleNameForVarDecl = getPossibleNameForVarDecl(node, transformer, continuationArgName);
            const inlinedLeftHandSide = transformExpression(
            /*returnContextNode*/
            node, node.expression.expression, transformer, 
            /*hasContinuation*/
            true, possibleNameForVarDecl);
            if (hasFailed())
                return silentFail();
            const inlinedCallback = transformCallbackArgument(onRejected, hasContinuation, possibleNameForVarDecl, inputArgName, node, transformer);
            if (hasFailed())
                return silentFail();
            const tryBlock = factory.createBlock(inlinedLeftHandSide);
            const catchClause = factory.createCatchClause(inputArgName && getSynthesizedDeepClone(declareSynthBindingName(inputArgName)), factory.createBlock(inlinedCallback));
            const tryStatement = factory.createTryStatement(tryBlock, catchClause, 
            /*finallyBlock*/
            void 0);
            return finishCatchOrFinallyTransform(node, transformer, tryStatement, possibleNameForVarDecl, continuationArgName);
        }
        function transformThen(node, onFulfilled, onRejected, transformer, hasContinuation, continuationArgName) {
            if (!onFulfilled || isNullOrUndefined2(transformer, onFulfilled)) {
                return transformCatch(node, onRejected, transformer, hasContinuation, continuationArgName);
            }
            if (onRejected && !isNullOrUndefined2(transformer, onRejected)) {
                return silentFail();
            }
            const inputArgName = getArgBindingName(onFulfilled, transformer);
            const inlinedLeftHandSide = transformExpression(node.expression.expression, node.expression.expression, transformer, 
            /*hasContinuation*/
            true, inputArgName);
            if (hasFailed())
                return silentFail();
            const inlinedCallback = transformCallbackArgument(onFulfilled, hasContinuation, continuationArgName, inputArgName, node, transformer);
            if (hasFailed())
                return silentFail();
            return concatenate(inlinedLeftHandSide, inlinedCallback);
        }
        function transformPromiseExpressionOfPropertyAccess(returnContextNode, node, transformer, hasContinuation, continuationArgName) {
            if (shouldReturn(returnContextNode, transformer)) {
                let returnValue = getSynthesizedDeepClone(node);
                if (hasContinuation) {
                    returnValue = factory.createAwaitExpression(returnValue);
                }
                return [factory.createReturnStatement(returnValue)];
            }
            return createVariableOrAssignmentOrExpressionStatement(continuationArgName, factory.createAwaitExpression(node), 
            /*typeAnnotation*/
            void 0);
        }
        function createVariableOrAssignmentOrExpressionStatement(variableName, rightHandSide, typeAnnotation) {
            if (!variableName || isEmptyBindingName(variableName)) {
                return [factory.createExpressionStatement(rightHandSide)];
            }
            if (isSynthIdentifier(variableName) && variableName.hasBeenDeclared) {
                return [factory.createExpressionStatement(factory.createAssignment(getSynthesizedDeepClone(referenceSynthIdentifier(variableName)), rightHandSide))];
            }
            return [
                factory.createVariableStatement(
                /*modifiers*/
                void 0, factory.createVariableDeclarationList([
                    factory.createVariableDeclaration(getSynthesizedDeepClone(declareSynthBindingName(variableName)), 
                    /*exclamationToken*/
                    void 0, typeAnnotation, rightHandSide)
                ], 2 /* Const */))
            ];
        }
        function maybeAnnotateAndReturn(expressionToReturn, typeAnnotation) {
            if (typeAnnotation && expressionToReturn) {
                const name = factory.createUniqueName("result", 16 /* Optimistic */);
                return [
                    ...createVariableOrAssignmentOrExpressionStatement(createSynthIdentifier(name), expressionToReturn, typeAnnotation),
                    factory.createReturnStatement(name)
                ];
            }
            return [factory.createReturnStatement(expressionToReturn)];
        }
        function transformCallbackArgument(func, hasContinuation, continuationArgName, inputArgName, parent2, transformer) {
            var _a;
            switch (func.kind) {
                case 106 /* NullKeyword */:
                    break;
                case 211 /* PropertyAccessExpression */:
                case 80 /* Identifier */:
                    if (!inputArgName) {
                        break;
                    }
                    const synthCall = factory.createCallExpression(getSynthesizedDeepClone(func), 
                    /*typeArguments*/
                    void 0, isSynthIdentifier(inputArgName) ? [referenceSynthIdentifier(inputArgName)] : []);
                    if (shouldReturn(parent2, transformer)) {
                        return maybeAnnotateAndReturn(synthCall, getExplicitPromisedTypeOfPromiseReturningCallExpression(parent2, func, transformer.checker));
                    }
                    const type = transformer.checker.getTypeAtLocation(func);
                    const callSignatures = transformer.checker.getSignaturesOfType(type, 0 /* Call */);
                    if (!callSignatures.length) {
                        return silentFail();
                    }
                    const returnType = callSignatures[0].getReturnType();
                    const varDeclOrAssignment = createVariableOrAssignmentOrExpressionStatement(continuationArgName, factory.createAwaitExpression(synthCall), getExplicitPromisedTypeOfPromiseReturningCallExpression(parent2, func, transformer.checker));
                    if (continuationArgName) {
                        continuationArgName.types.push(transformer.checker.getAwaitedType(returnType) || returnType);
                    }
                    return varDeclOrAssignment;
                case 218 /* FunctionExpression */:
                case 219 /* ArrowFunction */: {
                    const funcBody = func.body;
                    const returnType2 = (_a = getLastCallSignature(transformer.checker.getTypeAtLocation(func), transformer.checker)) == null ? void 0 : _a.getReturnType();
                    if (isBlock(funcBody)) {
                        let refactoredStmts = [];
                        let seenReturnStatement = false;
                        for (const statement of funcBody.statements) {
                            if (isReturnStatement(statement)) {
                                seenReturnStatement = true;
                                if (isReturnStatementWithFixablePromiseHandler(statement, transformer.checker)) {
                                    refactoredStmts = refactoredStmts.concat(transformReturnStatementWithFixablePromiseHandler(transformer, statement, hasContinuation, continuationArgName));
                                }
                                else {
                                    const possiblyAwaitedRightHandSide = returnType2 && statement.expression ? getPossiblyAwaitedRightHandSide(transformer.checker, returnType2, statement.expression) : statement.expression;
                                    refactoredStmts.push(...maybeAnnotateAndReturn(possiblyAwaitedRightHandSide, getExplicitPromisedTypeOfPromiseReturningCallExpression(parent2, func, transformer.checker)));
                                }
                            }
                            else if (hasContinuation && forEachReturnStatement(statement, returnTrue)) {
                                return silentFail();
                            }
                            else {
                                refactoredStmts.push(statement);
                            }
                        }
                        return shouldReturn(parent2, transformer) ? refactoredStmts.map((s) => getSynthesizedDeepClone(s)) : removeReturns(refactoredStmts, continuationArgName, transformer, seenReturnStatement);
                    }
                    else {
                        const inlinedStatements = isFixablePromiseHandler(funcBody, transformer.checker) ? transformReturnStatementWithFixablePromiseHandler(transformer, factory.createReturnStatement(funcBody), hasContinuation, continuationArgName) : emptyArray;
                        if (inlinedStatements.length > 0) {
                            return inlinedStatements;
                        }
                        if (returnType2) {
                            const possiblyAwaitedRightHandSide = getPossiblyAwaitedRightHandSide(transformer.checker, returnType2, funcBody);
                            if (!shouldReturn(parent2, transformer)) {
                                const transformedStatement = createVariableOrAssignmentOrExpressionStatement(continuationArgName, possiblyAwaitedRightHandSide, 
                                /*typeAnnotation*/
                                void 0);
                                if (continuationArgName) {
                                    continuationArgName.types.push(transformer.checker.getAwaitedType(returnType2) || returnType2);
                                }
                                return transformedStatement;
                            }
                            else {
                                return maybeAnnotateAndReturn(possiblyAwaitedRightHandSide, getExplicitPromisedTypeOfPromiseReturningCallExpression(parent2, func, transformer.checker));
                            }
                        }
                        else {
                            return silentFail();
                        }
                    }
                }
                default:
                    return silentFail();
            }
            return emptyArray;
        }
        function getPossiblyAwaitedRightHandSide(checker, type, expr) {
            const rightHandSide = getSynthesizedDeepClone(expr);
            return !!checker.getPromisedTypeOfPromise(type) ? factory.createAwaitExpression(rightHandSide) : rightHandSide;
        }
        function getLastCallSignature(type, checker) {
            const callSignatures = checker.getSignaturesOfType(type, 0 /* Call */);
            return lastOrUndefined(callSignatures);
        }
        function removeReturns(stmts, prevArgName, transformer, seenReturnStatement) {
            const ret = [];
            for (const stmt of stmts) {
                if (isReturnStatement(stmt)) {
                    if (stmt.expression) {
                        const possiblyAwaitedExpression = isPromiseTypedExpression(stmt.expression, transformer.checker) ? factory.createAwaitExpression(stmt.expression) : stmt.expression;
                        if (prevArgName === void 0) {
                            ret.push(factory.createExpressionStatement(possiblyAwaitedExpression));
                        }
                        else if (isSynthIdentifier(prevArgName) && prevArgName.hasBeenDeclared) {
                            ret.push(factory.createExpressionStatement(factory.createAssignment(referenceSynthIdentifier(prevArgName), possiblyAwaitedExpression)));
                        }
                        else {
                            ret.push(factory.createVariableStatement(
                            /*modifiers*/
                            void 0, factory.createVariableDeclarationList([factory.createVariableDeclaration(declareSynthBindingName(prevArgName), 
                                /*exclamationToken*/
                                void 0, 
                                /*type*/
                                void 0, possiblyAwaitedExpression)], 2 /* Const */)));
                        }
                    }
                }
                else {
                    ret.push(getSynthesizedDeepClone(stmt));
                }
            }
            if (!seenReturnStatement && prevArgName !== void 0) {
                ret.push(factory.createVariableStatement(
                /*modifiers*/
                void 0, factory.createVariableDeclarationList([factory.createVariableDeclaration(declareSynthBindingName(prevArgName), 
                    /*exclamationToken*/
                    void 0, 
                    /*type*/
                    void 0, factory.createIdentifier("undefined"))], 2 /* Const */)));
            }
            return ret;
        }
        function transformReturnStatementWithFixablePromiseHandler(transformer, innerRetStmt, hasContinuation, continuationArgName) {
            let innerCbBody = [];
            forEachChild(innerRetStmt, function visit(node) {
                if (isCallExpression(node)) {
                    const temp = transformExpression(node, node, transformer, hasContinuation, continuationArgName);
                    innerCbBody = innerCbBody.concat(temp);
                    if (innerCbBody.length > 0) {
                        return;
                    }
                }
                else if (!isFunctionLike(node)) {
                    forEachChild(node, visit);
                }
            });
            return innerCbBody;
        }
        function getArgBindingName(funcNode, transformer) {
            const types = [];
            let name;
            if (isFunctionLikeDeclaration(funcNode)) {
                if (funcNode.parameters.length > 0) {
                    const param = funcNode.parameters[0].name;
                    name = getMappedBindingNameOrDefault(param);
                }
            }
            else if (isIdentifier(funcNode)) {
                name = getMapEntryOrDefault(funcNode);
            }
            else if (isPropertyAccessExpression(funcNode) && isIdentifier(funcNode.name)) {
                name = getMapEntryOrDefault(funcNode.name);
            }
            if (!name || "identifier" in name && name.identifier.text === "undefined") {
                return void 0;
            }
            return name;
            function getMappedBindingNameOrDefault(bindingName) {
                if (isIdentifier(bindingName))
                    return getMapEntryOrDefault(bindingName);
                const elements = flatMap(bindingName.elements, (element) => {
                    if (isOmittedExpression(element))
                        return [];
                    return [getMappedBindingNameOrDefault(element.name)];
                });
                return createSynthBindingPattern(bindingName, elements);
            }
            function getMapEntryOrDefault(identifier) {
                const originalNode = getOriginalNode2(identifier);
                const symbol = getSymbol2(originalNode);
                if (!symbol) {
                    return createSynthIdentifier(identifier, types);
                }
                const mapEntry = transformer.synthNamesMap.get(getSymbolId(symbol).toString());
                return mapEntry || createSynthIdentifier(identifier, types);
            }
            function getSymbol2(node) {
                var _a;
                return ((_a = tryCast(node, canHaveSymbol)) == null ? void 0 : _a.symbol) ?? transformer.checker.getSymbolAtLocation(node);
            }
            function getOriginalNode2(node) {
                return node.original ? node.original : node;
            }
        }
        function isEmptyBindingName(bindingName) {
            if (!bindingName) {
                return true;
            }
            if (isSynthIdentifier(bindingName)) {
                return !bindingName.identifier.text;
            }
            return every(bindingName.elements, isEmptyBindingName);
        }
        function createSynthIdentifier(identifier, types = []) {
            return { kind: 0 /* Identifier */, identifier, types, hasBeenDeclared: false, hasBeenReferenced: false };
        }
        function createSynthBindingPattern(bindingPattern, elements = emptyArray, types = []) {
            return { kind: 1 /* BindingPattern */, bindingPattern, elements, types };
        }
        function referenceSynthIdentifier(synthId) {
            synthId.hasBeenReferenced = true;
            return synthId.identifier;
        }
        function declareSynthBindingName(synthName) {
            return isSynthIdentifier(synthName) ? declareSynthIdentifier(synthName) : declareSynthBindingPattern(synthName);
        }
        function declareSynthBindingPattern(synthPattern) {
            for (const element of synthPattern.elements) {
                declareSynthBindingName(element);
            }
            return synthPattern.bindingPattern;
        }
        function declareSynthIdentifier(synthId) {
            synthId.hasBeenDeclared = true;
            return synthId.identifier;
        }
        function isSynthIdentifier(bindingName) {
            return bindingName.kind === 0 /* Identifier */;
        }
        function isSynthBindingPattern(bindingName) {
            return bindingName.kind === 1 /* BindingPattern */;
        }
        function shouldReturn(expression, transformer) {
            return !!expression.original && transformer.setOfExpressionsToReturn.has(getNodeId(expression.original));
        }
        var fixId10, errorCodes11, codeActionSucceeded;
        var init_convertToAsyncFunction = __esm({
            "src/services/codefixes/convertToAsyncFunction.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId10 = "convertToAsyncFunction";
                errorCodes11 = [Diagnostics.This_may_be_converted_to_an_async_function.code];
                codeActionSucceeded = true;
                registerCodeFix({
                    errorCodes: errorCodes11,
                    getCodeActions(context) {
                        codeActionSucceeded = true;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => convertToAsyncFunction(t, context.sourceFile, context.span.start, context.program.getTypeChecker()));
                        return codeActionSucceeded ? [createCodeFixAction(fixId10, changes, Diagnostics.Convert_to_async_function, fixId10, Diagnostics.Convert_all_to_async_functions)] : [];
                    },
                    fixIds: [fixId10],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes11, (changes, err) => convertToAsyncFunction(changes, err.file, err.start, context.program.getTypeChecker()))
                });
            }
        });
        // src/services/codefixes/convertToEsModule.ts
        function fixImportOfModuleExports(importingFile, exportingFile, program, changes, quotePreference) {
            var _a;
            for (const moduleSpecifier of importingFile.imports) {
                const imported = (_a = program.getResolvedModuleFromModuleSpecifier(moduleSpecifier)) == null ? void 0 : _a.resolvedModule;
                if (!imported || imported.resolvedFileName !== exportingFile.fileName) {
                    continue;
                }
                const importNode = importFromModuleSpecifier(moduleSpecifier);
                switch (importNode.kind) {
                    case 271 /* ImportEqualsDeclaration */:
                        changes.replaceNode(importingFile, importNode, makeImport(importNode.name, 
                        /*namedImports*/
                        void 0, moduleSpecifier, quotePreference));
                        break;
                    case 213 /* CallExpression */:
                        if (isRequireCall(importNode, 
                        /*requireStringLiteralLikeArgument*/
                        false)) {
                            changes.replaceNode(importingFile, importNode, factory.createPropertyAccessExpression(getSynthesizedDeepClone(importNode), "default"));
                        }
                        break;
                }
            }
        }
        function convertFileToEsModule(sourceFile, checker, changes, target, quotePreference) {
            const identifiers = { original: collectFreeIdentifiers(sourceFile), additional: /* @__PURE__ */ new Set() };
            const exports = collectExportRenames(sourceFile, checker, identifiers);
            convertExportsAccesses(sourceFile, exports, changes);
            let moduleExportsChangedToDefault = false;
            let useSitesToUnqualify;
            for (const statement of filter(sourceFile.statements, isVariableStatement)) {
                const newUseSites = convertVariableStatement(sourceFile, statement, changes, checker, identifiers, target, quotePreference);
                if (newUseSites) {
                    copyEntries(newUseSites, useSitesToUnqualify ?? (useSitesToUnqualify = /* @__PURE__ */ new Map()));
                }
            }
            for (const statement of filter(sourceFile.statements, (s) => !isVariableStatement(s))) {
                const moduleExportsChanged = convertStatement(sourceFile, statement, checker, changes, identifiers, target, exports, useSitesToUnqualify, quotePreference);
                moduleExportsChangedToDefault = moduleExportsChangedToDefault || moduleExportsChanged;
            }
            useSitesToUnqualify == null ? void 0 : useSitesToUnqualify.forEach((replacement, original) => {
                changes.replaceNode(sourceFile, original, replacement);
            });
            return moduleExportsChangedToDefault;
        }
        function collectExportRenames(sourceFile, checker, identifiers) {
            const res = /* @__PURE__ */ new Map();
            forEachExportReference(sourceFile, (node) => {
                const { text } = node.name;
                if (!res.has(text) && (isIdentifierANonContextualKeyword(node.name) || checker.resolveName(text, node, 111551 /* Value */, 
                /*excludeGlobals*/
                true))) {
                    res.set(text, makeUniqueName(`_${text}`, identifiers));
                }
            });
            return res;
        }
        function convertExportsAccesses(sourceFile, exports, changes) {
            forEachExportReference(sourceFile, (node, isAssignmentLhs) => {
                if (isAssignmentLhs) {
                    return;
                }
                const { text } = node.name;
                changes.replaceNode(sourceFile, node, factory.createIdentifier(exports.get(text) || text));
            });
        }
        function forEachExportReference(sourceFile, cb) {
            sourceFile.forEachChild(function recur(node) {
                if (isPropertyAccessExpression(node) && isExportsOrModuleExportsOrAlias(sourceFile, node.expression) && isIdentifier(node.name)) {
                    const { parent: parent2 } = node;
                    cb(node, isBinaryExpression(parent2) && parent2.left === node && parent2.operatorToken.kind === 64 /* EqualsToken */);
                }
                node.forEachChild(recur);
            });
        }
        function convertStatement(sourceFile, statement, checker, changes, identifiers, target, exports, useSitesToUnqualify, quotePreference) {
            switch (statement.kind) {
                case 243 /* VariableStatement */:
                    convertVariableStatement(sourceFile, statement, changes, checker, identifiers, target, quotePreference);
                    return false;
                case 244 /* ExpressionStatement */: {
                    const { expression } = statement;
                    switch (expression.kind) {
                        case 213 /* CallExpression */: {
                            if (isRequireCall(expression, 
                            /*requireStringLiteralLikeArgument*/
                            true)) {
                                changes.replaceNode(sourceFile, statement, makeImport(
                                /*defaultImport*/
                                void 0, 
                                /*namedImports*/
                                void 0, expression.arguments[0], quotePreference));
                            }
                            return false;
                        }
                        case 226 /* BinaryExpression */: {
                            const { operatorToken } = expression;
                            return operatorToken.kind === 64 /* EqualsToken */ && convertAssignment(sourceFile, checker, expression, changes, exports, useSitesToUnqualify);
                        }
                    }
                }
                default:
                    return false;
            }
        }
        function convertVariableStatement(sourceFile, statement, changes, checker, identifiers, target, quotePreference) {
            const { declarationList } = statement;
            let foundImport = false;
            const converted = map(declarationList.declarations, (decl) => {
                const { name, initializer } = decl;
                if (initializer) {
                    if (isExportsOrModuleExportsOrAlias(sourceFile, initializer)) {
                        foundImport = true;
                        return convertedImports([]);
                    }
                    else if (isRequireCall(initializer, 
                    /*requireStringLiteralLikeArgument*/
                    true)) {
                        foundImport = true;
                        return convertSingleImport(name, initializer.arguments[0], checker, identifiers, target, quotePreference);
                    }
                    else if (isPropertyAccessExpression(initializer) && isRequireCall(initializer.expression, 
                    /*requireStringLiteralLikeArgument*/
                    true)) {
                        foundImport = true;
                        return convertPropertyAccessImport(name, initializer.name.text, initializer.expression.arguments[0], identifiers, quotePreference);
                    }
                }
                return convertedImports([factory.createVariableStatement(
                    /*modifiers*/
                    void 0, factory.createVariableDeclarationList([decl], declarationList.flags))]);
            });
            if (foundImport) {
                changes.replaceNodeWithNodes(sourceFile, statement, flatMap(converted, (c) => c.newImports));
                let combinedUseSites;
                forEach(converted, (c) => {
                    if (c.useSitesToUnqualify) {
                        copyEntries(c.useSitesToUnqualify, combinedUseSites ?? (combinedUseSites = /* @__PURE__ */ new Map()));
                    }
                });
                return combinedUseSites;
            }
        }
        function convertPropertyAccessImport(name, propertyName, moduleSpecifier, identifiers, quotePreference) {
            switch (name.kind) {
                case 206 /* ObjectBindingPattern */:
                case 207 /* ArrayBindingPattern */: {
                    const tmp = makeUniqueName(propertyName, identifiers);
                    return convertedImports([
                        makeSingleImport(tmp, propertyName, moduleSpecifier, quotePreference),
                        makeConst(
                        /*modifiers*/
                        void 0, name, factory.createIdentifier(tmp))
                    ]);
                }
                case 80 /* Identifier */:
                    return convertedImports([makeSingleImport(name.text, propertyName, moduleSpecifier, quotePreference)]);
                default:
                    return Debug.assertNever(name, `Convert to ES module got invalid syntax form ${name.kind}`);
            }
        }
        function convertAssignment(sourceFile, checker, assignment, changes, exports, useSitesToUnqualify) {
            const { left, right } = assignment;
            if (!isPropertyAccessExpression(left)) {
                return false;
            }
            if (isExportsOrModuleExportsOrAlias(sourceFile, left)) {
                if (isExportsOrModuleExportsOrAlias(sourceFile, right)) {
                    changes.delete(sourceFile, assignment.parent);
                }
                else {
                    const replacement = isObjectLiteralExpression(right) ? tryChangeModuleExportsObject(right, useSitesToUnqualify) : isRequireCall(right, 
                    /*requireStringLiteralLikeArgument*/
                    true) ? convertReExportAll(right.arguments[0], checker) : void 0;
                    if (replacement) {
                        changes.replaceNodeWithNodes(sourceFile, assignment.parent, replacement[0]);
                        return replacement[1];
                    }
                    else {
                        changes.replaceRangeWithText(sourceFile, createRange(left.getStart(sourceFile), right.pos), "export default");
                        return true;
                    }
                }
            }
            else if (isExportsOrModuleExportsOrAlias(sourceFile, left.expression)) {
                convertNamedExport(sourceFile, assignment, changes, exports);
            }
            return false;
        }
        function tryChangeModuleExportsObject(object, useSitesToUnqualify) {
            const statements = mapAllOrFail(object.properties, (prop) => {
                switch (prop.kind) {
                    case 177 /* GetAccessor */:
                    case 178 /* SetAccessor */:
                    case 304 /* ShorthandPropertyAssignment */:
                    case 305 /* SpreadAssignment */:
                        return void 0;
                    case 303 /* PropertyAssignment */:
                        return !isIdentifier(prop.name) ? void 0 : convertExportsDotXEquals_replaceNode(prop.name.text, prop.initializer, useSitesToUnqualify);
                    case 174 /* MethodDeclaration */:
                        return !isIdentifier(prop.name) ? void 0 : functionExpressionToDeclaration(prop.name.text, [factory.createToken(95 /* ExportKeyword */)], prop, useSitesToUnqualify);
                    default:
                        Debug.assertNever(prop, `Convert to ES6 got invalid prop kind ${prop.kind}`);
                }
            });
            return statements && [statements, false];
        }
        function convertNamedExport(sourceFile, assignment, changes, exports) {
            const { text } = assignment.left.name;
            const rename = exports.get(text);
            if (rename !== void 0) {
                const newNodes = [
                    makeConst(
                    /*modifiers*/
                    void 0, rename, assignment.right),
                    makeExportDeclaration([factory.createExportSpecifier(
                        /*isTypeOnly*/
                        false, rename, text)])
                ];
                changes.replaceNodeWithNodes(sourceFile, assignment.parent, newNodes);
            }
            else {
                convertExportsPropertyAssignment(assignment, sourceFile, changes);
            }
        }
        function convertReExportAll(reExported, checker) {
            const moduleSpecifier = reExported.text;
            const moduleSymbol = checker.getSymbolAtLocation(reExported);
            const exports = moduleSymbol ? moduleSymbol.exports : emptyMap;
            return exports.has("export=" /* ExportEquals */) ? [[reExportDefault(moduleSpecifier)], true] : !exports.has("default" /* Default */) ? [[reExportStar(moduleSpecifier)], false] : (
            // If there's some non-default export, must include both `export *` and `export default`.
            exports.size > 1 ? [[reExportStar(moduleSpecifier), reExportDefault(moduleSpecifier)], true] : [[reExportDefault(moduleSpecifier)], true]);
        }
        function reExportStar(moduleSpecifier) {
            return makeExportDeclaration(
            /*exportSpecifiers*/
            void 0, moduleSpecifier);
        }
        function reExportDefault(moduleSpecifier) {
            return makeExportDeclaration([factory.createExportSpecifier(
                /*isTypeOnly*/
                false, 
                /*propertyName*/
                void 0, "default")], moduleSpecifier);
        }
        function convertExportsPropertyAssignment({ left, right, parent: parent2 }, sourceFile, changes) {
            const name = left.name.text;
            if ((isFunctionExpression(right) || isArrowFunction(right) || isClassExpression(right)) && (!right.name || right.name.text === name)) {
                changes.replaceRange(sourceFile, { pos: left.getStart(sourceFile), end: right.getStart(sourceFile) }, factory.createToken(95 /* ExportKeyword */), { suffix: " " });
                if (!right.name)
                    changes.insertName(sourceFile, right, name);
                const semi = findChildOfKind(parent2, 27 /* SemicolonToken */, sourceFile);
                if (semi)
                    changes.delete(sourceFile, semi);
            }
            else {
                changes.replaceNodeRangeWithNodes(sourceFile, left.expression, findChildOfKind(left, 25 /* DotToken */, sourceFile), [factory.createToken(95 /* ExportKeyword */), factory.createToken(87 /* ConstKeyword */)], { joiner: " ", suffix: " " });
            }
        }
        function convertExportsDotXEquals_replaceNode(name, exported, useSitesToUnqualify) {
            const modifiers = [factory.createToken(95 /* ExportKeyword */)];
            switch (exported.kind) {
                case 218 /* FunctionExpression */: {
                    const { name: expressionName } = exported;
                    if (expressionName && expressionName.text !== name) {
                        return exportConst();
                    }
                }
                case 219 /* ArrowFunction */:
                    return functionExpressionToDeclaration(name, modifiers, exported, useSitesToUnqualify);
                case 231 /* ClassExpression */:
                    return classExpressionToDeclaration(name, modifiers, exported, useSitesToUnqualify);
                default:
                    return exportConst();
            }
            function exportConst() {
                return makeConst(modifiers, factory.createIdentifier(name), replaceImportUseSites(exported, useSitesToUnqualify));
            }
        }
        function replaceImportUseSites(nodeOrNodes, useSitesToUnqualify) {
            if (!useSitesToUnqualify || !some(arrayFrom(useSitesToUnqualify.keys()), (original) => rangeContainsRange(nodeOrNodes, original))) {
                return nodeOrNodes;
            }
            return isArray(nodeOrNodes) ? getSynthesizedDeepClonesWithReplacements(nodeOrNodes, 
            /*includeTrivia*/
            true, replaceNode) : getSynthesizedDeepCloneWithReplacements(nodeOrNodes, 
            /*includeTrivia*/
            true, replaceNode);
            function replaceNode(original) {
                if (original.kind === 211 /* PropertyAccessExpression */) {
                    const replacement = useSitesToUnqualify.get(original);
                    useSitesToUnqualify.delete(original);
                    return replacement;
                }
            }
        }
        function convertSingleImport(name, moduleSpecifier, checker, identifiers, target, quotePreference) {
            switch (name.kind) {
                case 206 /* ObjectBindingPattern */: {
                    const importSpecifiers = mapAllOrFail(name.elements, (e) => e.dotDotDotToken || e.initializer || e.propertyName && !isIdentifier(e.propertyName) || !isIdentifier(e.name) ? void 0 : makeImportSpecifier2(e.propertyName && e.propertyName.text, e.name.text));
                    if (importSpecifiers) {
                        return convertedImports([makeImport(
                            /*defaultImport*/
                            void 0, importSpecifiers, moduleSpecifier, quotePreference)]);
                    }
                }
                case 207 /* ArrayBindingPattern */: {
                    const tmp = makeUniqueName(moduleSpecifierToValidIdentifier(moduleSpecifier.text, target), identifiers);
                    return convertedImports([
                        makeImport(factory.createIdentifier(tmp), 
                        /*namedImports*/
                        void 0, moduleSpecifier, quotePreference),
                        makeConst(
                        /*modifiers*/
                        void 0, getSynthesizedDeepClone(name), factory.createIdentifier(tmp))
                    ]);
                }
                case 80 /* Identifier */:
                    return convertSingleIdentifierImport(name, moduleSpecifier, checker, identifiers, quotePreference);
                default:
                    return Debug.assertNever(name, `Convert to ES module got invalid name kind ${name.kind}`);
            }
        }
        function convertSingleIdentifierImport(name, moduleSpecifier, checker, identifiers, quotePreference) {
            const nameSymbol = checker.getSymbolAtLocation(name);
            const namedBindingsNames = /* @__PURE__ */ new Map();
            let needDefaultImport = false;
            let useSitesToUnqualify;
            for (const use of identifiers.original.get(name.text)) {
                if (checker.getSymbolAtLocation(use) !== nameSymbol || use === name) {
                    continue;
                }
                const { parent: parent2 } = use;
                if (isPropertyAccessExpression(parent2)) {
                    const { name: { text: propertyName } } = parent2;
                    if (propertyName === "default") {
                        needDefaultImport = true;
                        const importDefaultName = use.getText();
                        (useSitesToUnqualify ?? (useSitesToUnqualify = /* @__PURE__ */ new Map())).set(parent2, factory.createIdentifier(importDefaultName));
                    }
                    else {
                        Debug.assert(parent2.expression === use, "Didn't expect expression === use");
                        let idName = namedBindingsNames.get(propertyName);
                        if (idName === void 0) {
                            idName = makeUniqueName(propertyName, identifiers);
                            namedBindingsNames.set(propertyName, idName);
                        }
                        (useSitesToUnqualify ?? (useSitesToUnqualify = /* @__PURE__ */ new Map())).set(parent2, factory.createIdentifier(idName));
                    }
                }
                else {
                    needDefaultImport = true;
                }
            }
            const namedBindings = namedBindingsNames.size === 0 ? void 0 : arrayFrom(mapIterator(namedBindingsNames.entries(), ([propertyName, idName]) => factory.createImportSpecifier(
            /*isTypeOnly*/
            false, propertyName === idName ? void 0 : factory.createIdentifier(propertyName), factory.createIdentifier(idName))));
            if (!namedBindings) {
                needDefaultImport = true;
            }
            return convertedImports([makeImport(needDefaultImport ? getSynthesizedDeepClone(name) : void 0, namedBindings, moduleSpecifier, quotePreference)], useSitesToUnqualify);
        }
        function makeUniqueName(name, identifiers) {
            while (identifiers.original.has(name) || identifiers.additional.has(name)) {
                name = `_${name}`;
            }
            identifiers.additional.add(name);
            return name;
        }
        function collectFreeIdentifiers(file) {
            const map2 = createMultiMap();
            forEachFreeIdentifier(file, (id) => map2.add(id.text, id));
            return map2;
        }
        function forEachFreeIdentifier(node, cb) {
            if (isIdentifier(node) && isFreeIdentifier(node))
                cb(node);
            node.forEachChild((child) => forEachFreeIdentifier(child, cb));
        }
        function isFreeIdentifier(node) {
            const { parent: parent2 } = node;
            switch (parent2.kind) {
                case 211 /* PropertyAccessExpression */:
                    return parent2.name !== node;
                case 208 /* BindingElement */:
                    return parent2.propertyName !== node;
                case 276 /* ImportSpecifier */:
                    return parent2.propertyName !== node;
                default:
                    return true;
            }
        }
        function functionExpressionToDeclaration(name, additionalModifiers, fn, useSitesToUnqualify) {
            return factory.createFunctionDeclaration(concatenate(additionalModifiers, getSynthesizedDeepClones(fn.modifiers)), getSynthesizedDeepClone(fn.asteriskToken), name, getSynthesizedDeepClones(fn.typeParameters), getSynthesizedDeepClones(fn.parameters), getSynthesizedDeepClone(fn.type), factory.converters.convertToFunctionBlock(replaceImportUseSites(fn.body, useSitesToUnqualify)));
        }
        function classExpressionToDeclaration(name, additionalModifiers, cls, useSitesToUnqualify) {
            return factory.createClassDeclaration(concatenate(additionalModifiers, getSynthesizedDeepClones(cls.modifiers)), name, getSynthesizedDeepClones(cls.typeParameters), getSynthesizedDeepClones(cls.heritageClauses), replaceImportUseSites(cls.members, useSitesToUnqualify));
        }
        function makeSingleImport(localName, propertyName, moduleSpecifier, quotePreference) {
            return propertyName === "default" ? makeImport(factory.createIdentifier(localName), 
            /*namedImports*/
            void 0, moduleSpecifier, quotePreference) : makeImport(
            /*defaultImport*/
            void 0, [makeImportSpecifier2(propertyName, localName)], moduleSpecifier, quotePreference);
        }
        function makeImportSpecifier2(propertyName, name) {
            return factory.createImportSpecifier(
            /*isTypeOnly*/
            false, propertyName !== void 0 && propertyName !== name ? factory.createIdentifier(propertyName) : void 0, factory.createIdentifier(name));
        }
        function makeConst(modifiers, name, init) {
            return factory.createVariableStatement(modifiers, factory.createVariableDeclarationList([factory.createVariableDeclaration(name, 
                /*exclamationToken*/
                void 0, 
                /*type*/
                void 0, init)], 2 /* Const */));
        }
        function makeExportDeclaration(exportSpecifiers, moduleSpecifier) {
            return factory.createExportDeclaration(
            /*modifiers*/
            void 0, 
            /*isTypeOnly*/
            false, exportSpecifiers && factory.createNamedExports(exportSpecifiers), moduleSpecifier === void 0 ? void 0 : factory.createStringLiteral(moduleSpecifier));
        }
        function convertedImports(newImports, useSitesToUnqualify) {
            return {
                newImports,
                useSitesToUnqualify
            };
        }
        var init_convertToEsModule = __esm({
            "src/services/codefixes/convertToEsModule.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                registerCodeFix({
                    errorCodes: [Diagnostics.File_is_a_CommonJS_module_it_may_be_converted_to_an_ES_module.code],
                    getCodeActions(context) {
                        const { sourceFile, program, preferences } = context;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (changes2) => {
                            const moduleExportsChangedToDefault = convertFileToEsModule(sourceFile, program.getTypeChecker(), changes2, getEmitScriptTarget(program.getCompilerOptions()), getQuotePreference(sourceFile, preferences));
                            if (moduleExportsChangedToDefault) {
                                for (const importingFile of program.getSourceFiles()) {
                                    fixImportOfModuleExports(importingFile, sourceFile, program, changes2, getQuotePreference(importingFile, preferences));
                                }
                            }
                        });
                        return [createCodeFixActionWithoutFixAll("convertToEsModule", changes, Diagnostics.Convert_to_ES_module)];
                    }
                });
            }
        });
        // src/services/codefixes/correctQualifiedNameToIndexedAccessType.ts
        function getQualifiedName(sourceFile, pos) {
            const qualifiedName = findAncestor(getTokenAtPosition(sourceFile, pos), isQualifiedName);
            Debug.assert(!!qualifiedName, "Expected position to be owned by a qualified name.");
            return isIdentifier(qualifiedName.left) ? qualifiedName : void 0;
        }
        function doChange10(changeTracker, sourceFile, qualifiedName) {
            const rightText = qualifiedName.right.text;
            const replacement = factory.createIndexedAccessTypeNode(factory.createTypeReferenceNode(qualifiedName.left, 
            /*typeArguments*/
            void 0), factory.createLiteralTypeNode(factory.createStringLiteral(rightText)));
            changeTracker.replaceNode(sourceFile, qualifiedName, replacement);
        }
        var fixId11, errorCodes12;
        var init_correctQualifiedNameToIndexedAccessType = __esm({
            "src/services/codefixes/correctQualifiedNameToIndexedAccessType.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId11 = "correctQualifiedNameToIndexedAccessType";
                errorCodes12 = [Diagnostics.Cannot_access_0_1_because_0_is_a_type_but_not_a_namespace_Did_you_mean_to_retrieve_the_type_of_the_property_1_in_0_with_0_1.code];
                registerCodeFix({
                    errorCodes: errorCodes12,
                    getCodeActions(context) {
                        const qualifiedName = getQualifiedName(context.sourceFile, context.span.start);
                        if (!qualifiedName)
                            return void 0;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange10(t, context.sourceFile, qualifiedName));
                        const newText = `${qualifiedName.left.text}["${qualifiedName.right.text}"]`;
                        return [createCodeFixAction(fixId11, changes, [Diagnostics.Rewrite_as_the_indexed_access_type_0, newText], fixId11, Diagnostics.Rewrite_all_as_indexed_access_types)];
                    },
                    fixIds: [fixId11],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes12, (changes, diag2) => {
                        const q = getQualifiedName(diag2.file, diag2.start);
                        if (q) {
                            doChange10(changes, diag2.file, q);
                        }
                    })
                });
            }
        });
        // src/services/codefixes/convertToTypeOnlyExport.ts
        function getExportSpecifierForDiagnosticSpan(span, sourceFile) {
            return tryCast(getTokenAtPosition(sourceFile, span.start).parent, isExportSpecifier);
        }
        function fixSingleExportDeclaration(changes, exportSpecifier, context) {
            if (!exportSpecifier) {
                return;
            }
            const exportClause = exportSpecifier.parent;
            const exportDeclaration = exportClause.parent;
            const typeExportSpecifiers = getTypeExportSpecifiers(exportSpecifier, context);
            if (typeExportSpecifiers.length === exportClause.elements.length) {
                changes.insertModifierBefore(context.sourceFile, 156 /* TypeKeyword */, exportClause);
            }
            else {
                const valueExportDeclaration = factory.updateExportDeclaration(exportDeclaration, exportDeclaration.modifiers, 
                /*isTypeOnly*/
                false, factory.updateNamedExports(exportClause, filter(exportClause.elements, (e) => !contains(typeExportSpecifiers, e))), exportDeclaration.moduleSpecifier, 
                /*attributes*/
                void 0);
                const typeExportDeclaration = factory.createExportDeclaration(
                /*modifiers*/
                void 0, 
                /*isTypeOnly*/
                true, factory.createNamedExports(typeExportSpecifiers), exportDeclaration.moduleSpecifier, 
                /*attributes*/
                void 0);
                changes.replaceNode(context.sourceFile, exportDeclaration, valueExportDeclaration, {
                    leadingTriviaOption: ts_textChanges_exports.LeadingTriviaOption.IncludeAll,
                    trailingTriviaOption: ts_textChanges_exports.TrailingTriviaOption.Exclude
                });
                changes.insertNodeAfter(context.sourceFile, exportDeclaration, typeExportDeclaration);
            }
        }
        function getTypeExportSpecifiers(originExportSpecifier, context) {
            const exportClause = originExportSpecifier.parent;
            if (exportClause.elements.length === 1) {
                return exportClause.elements;
            }
            const diagnostics = getDiagnosticsWithinSpan(createTextSpanFromNode(exportClause), context.program.getSemanticDiagnostics(context.sourceFile, context.cancellationToken));
            return filter(exportClause.elements, (element) => {
                var _a;
                return element === originExportSpecifier || ((_a = findDiagnosticForNode(element, diagnostics)) == null ? void 0 : _a.code) === errorCodes13[0];
            });
        }
        var errorCodes13, fixId12;
        var init_convertToTypeOnlyExport = __esm({
            "src/services/codefixes/convertToTypeOnlyExport.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                errorCodes13 = [Diagnostics.Re_exporting_a_type_when_0_is_enabled_requires_using_export_type.code];
                fixId12 = "convertToTypeOnlyExport";
                registerCodeFix({
                    errorCodes: errorCodes13,
                    getCodeActions: function getCodeActionsToConvertToTypeOnlyExport(context) {
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => fixSingleExportDeclaration(t, getExportSpecifierForDiagnosticSpan(context.span, context.sourceFile), context));
                        if (changes.length) {
                            return [createCodeFixAction(fixId12, changes, Diagnostics.Convert_to_type_only_export, fixId12, Diagnostics.Convert_all_re_exported_types_to_type_only_exports)];
                        }
                    },
                    fixIds: [fixId12],
                    getAllCodeActions: function getAllCodeActionsToConvertToTypeOnlyExport(context) {
                        const fixedExportDeclarations = /* @__PURE__ */ new Map();
                        return codeFixAll(context, errorCodes13, (changes, diag2) => {
                            const exportSpecifier = getExportSpecifierForDiagnosticSpan(diag2, context.sourceFile);
                            if (exportSpecifier && addToSeen(fixedExportDeclarations, getNodeId(exportSpecifier.parent.parent))) {
                                fixSingleExportDeclaration(changes, exportSpecifier, context);
                            }
                        });
                    }
                });
            }
        });
        // src/services/codefixes/convertToTypeOnlyImport.ts
        function getDeclaration2(sourceFile, pos) {
            const { parent: parent2 } = getTokenAtPosition(sourceFile, pos);
            return isImportSpecifier(parent2) || isImportDeclaration(parent2) && parent2.importClause ? parent2 : void 0;
        }
        function canConvertImportDeclarationForSpecifier(specifier, sourceFile, program) {
            if (specifier.parent.parent.name) {
                return false;
            }
            const nonTypeOnlySpecifiers = specifier.parent.elements.filter((e) => !e.isTypeOnly);
            if (nonTypeOnlySpecifiers.length === 1) {
                return true;
            }
            const checker = program.getTypeChecker();
            for (const specifier2 of nonTypeOnlySpecifiers) {
                const isUsedAsValue = ts_FindAllReferences_exports.Core.eachSymbolReferenceInFile(specifier2.name, checker, sourceFile, (usage) => {
                    return !isValidTypeOnlyAliasUseSite(usage);
                });
                if (isUsedAsValue) {
                    return false;
                }
            }
            return true;
        }
        function doChange11(changes, sourceFile, declaration) {
            var _a;
            if (isImportSpecifier(declaration)) {
                changes.replaceNode(sourceFile, declaration, factory.updateImportSpecifier(declaration, 
                /*isTypeOnly*/
                true, declaration.propertyName, declaration.name));
            }
            else {
                const importClause = declaration.importClause;
                if (importClause.name && importClause.namedBindings) {
                    changes.replaceNodeWithNodes(sourceFile, declaration, [
                        factory.createImportDeclaration(getSynthesizedDeepClones(declaration.modifiers, 
                        /*includeTrivia*/
                        true), factory.createImportClause(
                        /*isTypeOnly*/
                        true, getSynthesizedDeepClone(importClause.name, 
                        /*includeTrivia*/
                        true), 
                        /*namedBindings*/
                        void 0), getSynthesizedDeepClone(declaration.moduleSpecifier, 
                        /*includeTrivia*/
                        true), getSynthesizedDeepClone(declaration.attributes, 
                        /*includeTrivia*/
                        true)),
                        factory.createImportDeclaration(getSynthesizedDeepClones(declaration.modifiers, 
                        /*includeTrivia*/
                        true), factory.createImportClause(
                        /*isTypeOnly*/
                        true, 
                        /*name*/
                        void 0, getSynthesizedDeepClone(importClause.namedBindings, 
                        /*includeTrivia*/
                        true)), getSynthesizedDeepClone(declaration.moduleSpecifier, 
                        /*includeTrivia*/
                        true), getSynthesizedDeepClone(declaration.attributes, 
                        /*includeTrivia*/
                        true))
                    ]);
                }
                else {
                    const newNamedBindings = ((_a = importClause.namedBindings) == null ? void 0 : _a.kind) === 275 /* NamedImports */ ? factory.updateNamedImports(importClause.namedBindings, sameMap(importClause.namedBindings.elements, (e) => factory.updateImportSpecifier(e, 
                    /*isTypeOnly*/
                    false, e.propertyName, e.name))) : importClause.namedBindings;
                    const importDeclaration = factory.updateImportDeclaration(declaration, declaration.modifiers, factory.updateImportClause(importClause, 
                    /*isTypeOnly*/
                    true, importClause.name, newNamedBindings), declaration.moduleSpecifier, declaration.attributes);
                    changes.replaceNode(sourceFile, declaration, importDeclaration);
                }
            }
        }
        var errorCodes14, fixId13;
        var init_convertToTypeOnlyImport = __esm({
            "src/services/codefixes/convertToTypeOnlyImport.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                errorCodes14 = [
                    Diagnostics.This_import_is_never_used_as_a_value_and_must_use_import_type_because_importsNotUsedAsValues_is_set_to_error.code,
                    Diagnostics._0_is_a_type_and_must_be_imported_using_a_type_only_import_when_verbatimModuleSyntax_is_enabled.code,
                    Diagnostics._0_resolves_to_a_type_only_declaration_and_must_be_imported_using_a_type_only_import_when_verbatimModuleSyntax_is_enabled.code
                ];
                fixId13 = "convertToTypeOnlyImport";
                registerCodeFix({
                    errorCodes: errorCodes14,
                    getCodeActions: function getCodeActionsToConvertToTypeOnlyImport(context) {
                        var _a;
                        const declaration = getDeclaration2(context.sourceFile, context.span.start);
                        if (declaration) {
                            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange11(t, context.sourceFile, declaration));
                            const importDeclarationChanges = declaration.kind === 276 /* ImportSpecifier */ && canConvertImportDeclarationForSpecifier(declaration, context.sourceFile, context.program) ? ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange11(t, context.sourceFile, declaration.parent.parent.parent)) : void 0;
                            const mainAction = createCodeFixAction(fixId13, changes, declaration.kind === 276 /* ImportSpecifier */ ? [Diagnostics.Use_type_0, ((_a = declaration.propertyName) == null ? void 0 : _a.text) ?? declaration.name.text] : Diagnostics.Use_import_type, fixId13, Diagnostics.Fix_all_with_type_only_imports);
                            if (some(importDeclarationChanges)) {
                                return [
                                    createCodeFixActionWithoutFixAll(fixId13, importDeclarationChanges, Diagnostics.Use_import_type),
                                    mainAction
                                ];
                            }
                            return [mainAction];
                        }
                        return void 0;
                    },
                    fixIds: [fixId13],
                    getAllCodeActions: function getAllCodeActionsToConvertToTypeOnlyImport(context) {
                        const fixedImportDeclarations = /* @__PURE__ */ new Set();
                        return codeFixAll(context, errorCodes14, (changes, diag2) => {
                            const errorDeclaration = getDeclaration2(diag2.file, diag2.start);
                            if ((errorDeclaration == null ? void 0 : errorDeclaration.kind) === 272 /* ImportDeclaration */ && !fixedImportDeclarations.has(errorDeclaration)) {
                                doChange11(changes, diag2.file, errorDeclaration);
                                fixedImportDeclarations.add(errorDeclaration);
                            }
                            else if ((errorDeclaration == null ? void 0 : errorDeclaration.kind) === 276 /* ImportSpecifier */ && !fixedImportDeclarations.has(errorDeclaration.parent.parent.parent) && canConvertImportDeclarationForSpecifier(errorDeclaration, diag2.file, context.program)) {
                                doChange11(changes, diag2.file, errorDeclaration.parent.parent.parent);
                                fixedImportDeclarations.add(errorDeclaration.parent.parent.parent);
                            }
                            else if ((errorDeclaration == null ? void 0 : errorDeclaration.kind) === 276 /* ImportSpecifier */) {
                                doChange11(changes, diag2.file, errorDeclaration);
                            }
                        });
                    }
                });
            }
        });
        // src/services/codefixes/convertTypedefToType.ts
        function doChange12(changes, node, sourceFile, newLine, fixAll = false) {
            if (!isJSDocTypedefTag(node))
                return;
            const declaration = createDeclaration(node);
            if (!declaration)
                return;
            const commentNode = node.parent;
            const { leftSibling, rightSibling } = getLeftAndRightSiblings(node);
            let pos = commentNode.getStart();
            let prefix = "";
            if (!leftSibling && commentNode.comment) {
                pos = findEndOfTextBetween(commentNode, commentNode.getStart(), node.getStart());
                prefix = `${newLine} */${newLine}`;
            }
            if (leftSibling) {
                if (fixAll && isJSDocTypedefTag(leftSibling)) {
                    pos = node.getStart();
                    prefix = "";
                }
                else {
                    pos = findEndOfTextBetween(commentNode, leftSibling.getStart(), node.getStart());
                    prefix = `${newLine} */${newLine}`;
                }
            }
            let end = commentNode.getEnd();
            let suffix = "";
            if (rightSibling) {
                if (fixAll && isJSDocTypedefTag(rightSibling)) {
                    end = rightSibling.getStart();
                    suffix = `${newLine}${newLine}`;
                }
                else {
                    end = rightSibling.getStart();
                    suffix = `${newLine}/**${newLine} * `;
                }
            }
            changes.replaceRange(sourceFile, { pos, end }, declaration, { prefix, suffix });
        }
        function getLeftAndRightSiblings(typedefNode) {
            const commentNode = typedefNode.parent;
            const maxChildIndex = commentNode.getChildCount() - 1;
            const currentNodeIndex = commentNode.getChildren().findIndex((n) => n.getStart() === typedefNode.getStart() && n.getEnd() === typedefNode.getEnd());
            const leftSibling = currentNodeIndex > 0 ? commentNode.getChildAt(currentNodeIndex - 1) : void 0;
            const rightSibling = currentNodeIndex < maxChildIndex ? commentNode.getChildAt(currentNodeIndex + 1) : void 0;
            return { leftSibling, rightSibling };
        }
        function findEndOfTextBetween(jsDocComment, from, to) {
            const comment = jsDocComment.getText().substring(from - jsDocComment.getStart(), to - jsDocComment.getStart());
            for (let i = comment.length; i > 0; i--) {
                if (!/[*/\s]/g.test(comment.substring(i - 1, i))) {
                    return from + i;
                }
            }
            return to;
        }
        function createDeclaration(tag) {
            var _a;
            const { typeExpression } = tag;
            if (!typeExpression)
                return;
            const typeName = (_a = tag.name) == null ? void 0 : _a.getText();
            if (!typeName)
                return;
            if (typeExpression.kind === 329 /* JSDocTypeLiteral */) {
                return createInterfaceForTypeLiteral(typeName, typeExpression);
            }
            if (typeExpression.kind === 316 /* JSDocTypeExpression */) {
                return createTypeAliasForTypeExpression(typeName, typeExpression);
            }
        }
        function createInterfaceForTypeLiteral(typeName, typeLiteral) {
            const propertySignatures = createSignatureFromTypeLiteral(typeLiteral);
            if (!some(propertySignatures))
                return;
            return factory.createInterfaceDeclaration(
            /*modifiers*/
            void 0, typeName, 
            /*typeParameters*/
            void 0, 
            /*heritageClauses*/
            void 0, propertySignatures);
        }
        function createTypeAliasForTypeExpression(typeName, typeExpression) {
            const typeReference = getSynthesizedDeepClone(typeExpression.type);
            if (!typeReference)
                return;
            return factory.createTypeAliasDeclaration(
            /*modifiers*/
            void 0, factory.createIdentifier(typeName), 
            /*typeParameters*/
            void 0, typeReference);
        }
        function createSignatureFromTypeLiteral(typeLiteral) {
            const propertyTags = typeLiteral.jsDocPropertyTags;
            if (!some(propertyTags))
                return;
            const getSignature = (tag) => {
                var _a;
                const name = getPropertyName(tag);
                const type = (_a = tag.typeExpression) == null ? void 0 : _a.type;
                const isOptional = tag.isBracketed;
                let typeReference;
                if (type && isJSDocTypeLiteral(type)) {
                    const signatures = createSignatureFromTypeLiteral(type);
                    typeReference = factory.createTypeLiteralNode(signatures);
                }
                else if (type) {
                    typeReference = getSynthesizedDeepClone(type);
                }
                if (typeReference && name) {
                    const questionToken = isOptional ? factory.createToken(58 /* QuestionToken */) : void 0;
                    return factory.createPropertySignature(
                    /*modifiers*/
                    void 0, name, questionToken, typeReference);
                }
            };
            return mapDefined(propertyTags, getSignature);
        }
        function getPropertyName(tag) {
            return tag.name.kind === 80 /* Identifier */ ? tag.name.text : tag.name.right.text;
        }
        function getJSDocTypedefNodes(node) {
            if (hasJSDocNodes(node)) {
                return flatMap(node.jsDoc, (doc) => {
                    var _a;
                    return (_a = doc.tags) == null ? void 0 : _a.filter((tag) => isJSDocTypedefTag(tag));
                });
            }
            return [];
        }
        var fixId14, errorCodes15;
        var init_convertTypedefToType = __esm({
            "src/services/codefixes/convertTypedefToType.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId14 = "convertTypedefToType";
                errorCodes15 = [Diagnostics.JSDoc_typedef_may_be_converted_to_TypeScript_type.code];
                registerCodeFix({
                    fixIds: [fixId14],
                    errorCodes: errorCodes15,
                    getCodeActions(context) {
                        const newLineCharacter = getNewLineOrDefaultFromHost(context.host, context.formatContext.options);
                        const node = getTokenAtPosition(context.sourceFile, context.span.start);
                        if (!node)
                            return;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange12(t, node, context.sourceFile, newLineCharacter));
                        if (changes.length > 0) {
                            return [
                                createCodeFixAction(fixId14, changes, Diagnostics.Convert_typedef_to_TypeScript_type, fixId14, Diagnostics.Convert_all_typedef_to_TypeScript_types)
                            ];
                        }
                    },
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes15, (changes, diag2) => {
                        const newLineCharacter = getNewLineOrDefaultFromHost(context.host, context.formatContext.options);
                        const node = getTokenAtPosition(diag2.file, diag2.start);
                        const fixAll = true;
                        if (node)
                            doChange12(changes, node, diag2.file, newLineCharacter, fixAll);
                    })
                });
            }
        });
        // src/services/codefixes/convertLiteralTypeToMappedType.ts
        function getInfo5(sourceFile, pos) {
            const token = getTokenAtPosition(sourceFile, pos);
            if (isIdentifier(token)) {
                const propertySignature = cast(token.parent.parent, isPropertySignature);
                const propertyName = token.getText(sourceFile);
                return {
                    container: cast(propertySignature.parent, isTypeLiteralNode),
                    typeNode: propertySignature.type,
                    constraint: propertyName,
                    name: propertyName === "K" ? "P" : "K"
                };
            }
            return void 0;
        }
        function doChange13(changes, sourceFile, { container, typeNode, constraint, name }) {
            changes.replaceNode(sourceFile, container, factory.createMappedTypeNode(
            /*readonlyToken*/
            void 0, factory.createTypeParameterDeclaration(
            /*modifiers*/
            void 0, name, factory.createTypeReferenceNode(constraint)), 
            /*nameType*/
            void 0, 
            /*questionToken*/
            void 0, typeNode, 
            /*members*/
            void 0));
        }
        var fixId15, errorCodes16;
        var init_convertLiteralTypeToMappedType = __esm({
            "src/services/codefixes/convertLiteralTypeToMappedType.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId15 = "convertLiteralTypeToMappedType";
                errorCodes16 = [Diagnostics._0_only_refers_to_a_type_but_is_being_used_as_a_value_here_Did_you_mean_to_use_1_in_0.code];
                registerCodeFix({
                    errorCodes: errorCodes16,
                    getCodeActions: function getCodeActionsToConvertLiteralTypeToMappedType(context) {
                        const { sourceFile, span } = context;
                        const info = getInfo5(sourceFile, span.start);
                        if (!info) {
                            return void 0;
                        }
                        const { name, constraint } = info;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange13(t, sourceFile, info));
                        return [createCodeFixAction(fixId15, changes, [Diagnostics.Convert_0_to_1_in_0, constraint, name], fixId15, Diagnostics.Convert_all_type_literals_to_mapped_type)];
                    },
                    fixIds: [fixId15],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes16, (changes, diag2) => {
                        const info = getInfo5(diag2.file, diag2.start);
                        if (info) {
                            doChange13(changes, diag2.file, info);
                        }
                    })
                });
            }
        });
        // src/services/codefixes/fixClassIncorrectlyImplementsInterface.ts
        function getClass(sourceFile, pos) {
            return Debug.checkDefined(getContainingClass(getTokenAtPosition(sourceFile, pos)), "There should be a containing class");
        }
        function symbolPointsToNonPrivateMember(symbol) {
            return !symbol.valueDeclaration || !(getEffectiveModifierFlags(symbol.valueDeclaration) & 2 /* Private */);
        }
        function addMissingDeclarations(context, implementedTypeNode, sourceFile, classDeclaration, changeTracker, preferences) {
            const checker = context.program.getTypeChecker();
            const maybeHeritageClauseSymbol = getHeritageClauseSymbolTable(classDeclaration, checker);
            const implementedType = checker.getTypeAtLocation(implementedTypeNode);
            const implementedTypeSymbols = checker.getPropertiesOfType(implementedType);
            const nonPrivateAndNotExistedInHeritageClauseMembers = implementedTypeSymbols.filter(and(symbolPointsToNonPrivateMember, (symbol) => !maybeHeritageClauseSymbol.has(symbol.escapedName)));
            const classType = checker.getTypeAtLocation(classDeclaration);
            const constructor = find(classDeclaration.members, (m) => isConstructorDeclaration(m));
            if (!classType.getNumberIndexType()) {
                createMissingIndexSignatureDeclaration(implementedType, 1 /* Number */);
            }
            if (!classType.getStringIndexType()) {
                createMissingIndexSignatureDeclaration(implementedType, 0 /* String */);
            }
            const importAdder = createImportAdder(sourceFile, context.program, preferences, context.host);
            createMissingMemberNodes(classDeclaration, nonPrivateAndNotExistedInHeritageClauseMembers, sourceFile, context, preferences, importAdder, (member) => insertInterfaceMemberNode(sourceFile, classDeclaration, member));
            importAdder.writeFixes(changeTracker);
            function createMissingIndexSignatureDeclaration(type, kind) {
                const indexInfoOfKind = checker.getIndexInfoOfType(type, kind);
                if (indexInfoOfKind) {
                    insertInterfaceMemberNode(sourceFile, classDeclaration, checker.indexInfoToIndexSignatureDeclaration(indexInfoOfKind, classDeclaration, 
                    /*flags*/
                    void 0, getNoopSymbolTrackerWithResolver(context)));
                }
            }
            function insertInterfaceMemberNode(sourceFile2, cls, newElement) {
                if (constructor) {
                    changeTracker.insertNodeAfter(sourceFile2, constructor, newElement);
                }
                else {
                    changeTracker.insertMemberAtStart(sourceFile2, cls, newElement);
                }
            }
        }
        function getHeritageClauseSymbolTable(classDeclaration, checker) {
            const heritageClauseNode = getEffectiveBaseTypeNode(classDeclaration);
            if (!heritageClauseNode)
                return createSymbolTable();
            const heritageClauseType = checker.getTypeAtLocation(heritageClauseNode);
            const heritageClauseTypeSymbols = checker.getPropertiesOfType(heritageClauseType);
            return createSymbolTable(heritageClauseTypeSymbols.filter(symbolPointsToNonPrivateMember));
        }
        var errorCodes17, fixId16;
        var init_fixClassIncorrectlyImplementsInterface = __esm({
            "src/services/codefixes/fixClassIncorrectlyImplementsInterface.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                errorCodes17 = [
                    Diagnostics.Class_0_incorrectly_implements_interface_1.code,
                    Diagnostics.Class_0_incorrectly_implements_class_1_Did_you_mean_to_extend_1_and_inherit_its_members_as_a_subclass.code
                ];
                fixId16 = "fixClassIncorrectlyImplementsInterface";
                registerCodeFix({
                    errorCodes: errorCodes17,
                    getCodeActions(context) {
                        const { sourceFile, span } = context;
                        const classDeclaration = getClass(sourceFile, span.start);
                        return mapDefined(getEffectiveImplementsTypeNodes(classDeclaration), (implementedTypeNode) => {
                            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => addMissingDeclarations(context, implementedTypeNode, sourceFile, classDeclaration, t, context.preferences));
                            return changes.length === 0 ? void 0 : createCodeFixAction(fixId16, changes, [Diagnostics.Implement_interface_0, implementedTypeNode.getText(sourceFile)], fixId16, Diagnostics.Implement_all_unimplemented_interfaces);
                        });
                    },
                    fixIds: [fixId16],
                    getAllCodeActions(context) {
                        const seenClassDeclarations = /* @__PURE__ */ new Map();
                        return codeFixAll(context, errorCodes17, (changes, diag2) => {
                            const classDeclaration = getClass(diag2.file, diag2.start);
                            if (addToSeen(seenClassDeclarations, getNodeId(classDeclaration))) {
                                for (const implementedTypeNode of getEffectiveImplementsTypeNodes(classDeclaration)) {
                                    addMissingDeclarations(context, implementedTypeNode, diag2.file, classDeclaration, changes, context.preferences);
                                }
                            }
                        });
                    }
                });
            }
        });
        // src/services/codefixes/importFixes.ts
        function createImportAdder(sourceFile, program, preferences, host, cancellationToken) {
            return createImportAdderWorker(sourceFile, program, 
            /*useAutoImportProvider*/
            false, preferences, host, cancellationToken);
        }
        function createImportAdderWorker(sourceFile, program, useAutoImportProvider, preferences, host, cancellationToken) {
            const compilerOptions = program.getCompilerOptions();
            const addToNamespace = [];
            const importType = [];
            const addToExisting = /* @__PURE__ */ new Map();
            const newImports = /* @__PURE__ */ new Map();
            return { addImportFromDiagnostic, addImportFromExportedSymbol, writeFixes, hasFixes };
            function addImportFromDiagnostic(diagnostic, context) {
                const info = getFixInfos(context, diagnostic.code, diagnostic.start, useAutoImportProvider);
                if (!info || !info.length)
                    return;
                addImport(first(info));
            }
            function addImportFromExportedSymbol(exportedSymbol, isValidTypeOnlyUseSite) {
                const moduleSymbol = Debug.checkDefined(exportedSymbol.parent);
                const symbolName2 = getNameForExportedSymbol(exportedSymbol, getEmitScriptTarget(compilerOptions));
                const checker = program.getTypeChecker();
                const symbol = checker.getMergedSymbol(skipAlias(exportedSymbol, checker));
                const exportInfo = getAllExportInfoForSymbol(sourceFile, symbol, symbolName2, moduleSymbol, 
                /*preferCapitalized*/
                false, program, host, preferences, cancellationToken);
                const useRequire = shouldUseRequire(sourceFile, program);
                const fix = getImportFixForSymbol(sourceFile, Debug.checkDefined(exportInfo), program, 
                /*position*/
                void 0, !!isValidTypeOnlyUseSite, useRequire, host, preferences);
                if (fix) {
                    addImport({ fix, symbolName: symbolName2, errorIdentifierText: void 0 });
                }
            }
            function addImport(info) {
                var _a, _b;
                const { fix, symbolName: symbolName2 } = info;
                switch (fix.kind) {
                    case 0 /* UseNamespace */:
                        addToNamespace.push(fix);
                        break;
                    case 1 /* JsdocTypeImport */:
                        importType.push(fix);
                        break;
                    case 2 /* AddToExisting */: {
                        const { importClauseOrBindingPattern, importKind, addAsTypeOnly } = fix;
                        const key = String(getNodeId(importClauseOrBindingPattern));
                        let entry = addToExisting.get(key);
                        if (!entry) {
                            addToExisting.set(key, entry = { importClauseOrBindingPattern, defaultImport: void 0, namedImports: /* @__PURE__ */ new Map() });
                        }
                        if (importKind === 0 /* Named */) {
                            const prevValue = entry == null ? void 0 : entry.namedImports.get(symbolName2);
                            entry.namedImports.set(symbolName2, reduceAddAsTypeOnlyValues(prevValue, addAsTypeOnly));
                        }
                        else {
                            Debug.assert(entry.defaultImport === void 0 || entry.defaultImport.name === symbolName2, "(Add to Existing) Default import should be missing or match symbolName");
                            entry.defaultImport = {
                                name: symbolName2,
                                addAsTypeOnly: reduceAddAsTypeOnlyValues((_a = entry.defaultImport) == null ? void 0 : _a.addAsTypeOnly, addAsTypeOnly)
                            };
                        }
                        break;
                    }
                    case 3 /* AddNew */: {
                        const { moduleSpecifier, importKind, useRequire, addAsTypeOnly } = fix;
                        const entry = getNewImportEntry(moduleSpecifier, importKind, useRequire, addAsTypeOnly);
                        Debug.assert(entry.useRequire === useRequire, "(Add new) Tried to add an `import` and a `require` for the same module");
                        switch (importKind) {
                            case 1 /* Default */:
                                Debug.assert(entry.defaultImport === void 0 || entry.defaultImport.name === symbolName2, "(Add new) Default import should be missing or match symbolName");
                                entry.defaultImport = { name: symbolName2, addAsTypeOnly: reduceAddAsTypeOnlyValues((_b = entry.defaultImport) == null ? void 0 : _b.addAsTypeOnly, addAsTypeOnly) };
                                break;
                            case 0 /* Named */:
                                const prevValue = (entry.namedImports || (entry.namedImports = /* @__PURE__ */ new Map())).get(symbolName2);
                                entry.namedImports.set(symbolName2, reduceAddAsTypeOnlyValues(prevValue, addAsTypeOnly));
                                break;
                            case 3 /* CommonJS */:
                            case 2 /* Namespace */:
                                Debug.assert(entry.namespaceLikeImport === void 0 || entry.namespaceLikeImport.name === symbolName2, "Namespacelike import shoudl be missing or match symbolName");
                                entry.namespaceLikeImport = { importKind, name: symbolName2, addAsTypeOnly };
                                break;
                        }
                        break;
                    }
                    case 4 /* PromoteTypeOnly */:
                        break;
                    default:
                        Debug.assertNever(fix, `fix wasn't never - got kind ${fix.kind}`);
                }
                function reduceAddAsTypeOnlyValues(prevValue, newValue) {
                    return Math.max(prevValue ?? 0, newValue);
                }
                function getNewImportEntry(moduleSpecifier, importKind, useRequire, addAsTypeOnly) {
                    const typeOnlyKey = newImportsKey(moduleSpecifier, 
                    /*topLevelTypeOnly*/
                    true);
                    const nonTypeOnlyKey = newImportsKey(moduleSpecifier, 
                    /*topLevelTypeOnly*/
                    false);
                    const typeOnlyEntry = newImports.get(typeOnlyKey);
                    const nonTypeOnlyEntry = newImports.get(nonTypeOnlyKey);
                    const newEntry = {
                        defaultImport: void 0,
                        namedImports: void 0,
                        namespaceLikeImport: void 0,
                        useRequire
                    };
                    if (importKind === 1 /* Default */ && addAsTypeOnly === 2 /* Required */) {
                        if (typeOnlyEntry)
                            return typeOnlyEntry;
                        newImports.set(typeOnlyKey, newEntry);
                        return newEntry;
                    }
                    if (addAsTypeOnly === 1 /* Allowed */ && (typeOnlyEntry || nonTypeOnlyEntry)) {
                        return typeOnlyEntry || nonTypeOnlyEntry;
                    }
                    if (nonTypeOnlyEntry) {
                        return nonTypeOnlyEntry;
                    }
                    newImports.set(nonTypeOnlyKey, newEntry);
                    return newEntry;
                }
                function newImportsKey(moduleSpecifier, topLevelTypeOnly) {
                    return `${topLevelTypeOnly ? 1 : 0}|${moduleSpecifier}`;
                }
            }
            function writeFixes(changeTracker, oldFileQuotePreference) {
                let quotePreference;
                if (sourceFile.imports.length === 0 && oldFileQuotePreference !== void 0) {
                    quotePreference = oldFileQuotePreference;
                }
                else {
                    quotePreference = getQuotePreference(sourceFile, preferences);
                }
                for (const fix of addToNamespace) {
                    addNamespaceQualifier(changeTracker, sourceFile, fix);
                }
                for (const fix of importType) {
                    addImportType(changeTracker, sourceFile, fix, quotePreference);
                }
                addToExisting.forEach(({ importClauseOrBindingPattern, defaultImport, namedImports }) => {
                    doAddExistingFix(changeTracker, sourceFile, importClauseOrBindingPattern, defaultImport, arrayFrom(namedImports.entries(), ([name, addAsTypeOnly]) => ({ addAsTypeOnly, name })), preferences);
                });
                let newDeclarations;
                newImports.forEach(({ useRequire, defaultImport, namedImports, namespaceLikeImport }, key) => {
                    const moduleSpecifier = key.slice(2);
                    const getDeclarations = useRequire ? getNewRequires : getNewImports;
                    const declarations = getDeclarations(moduleSpecifier, quotePreference, defaultImport, namedImports && arrayFrom(namedImports.entries(), ([name, addAsTypeOnly]) => ({ addAsTypeOnly, name })), namespaceLikeImport, compilerOptions, preferences);
                    newDeclarations = combine(newDeclarations, declarations);
                });
                if (newDeclarations) {
                    insertImports(changeTracker, sourceFile, newDeclarations, 
                    /*blankLineBetween*/
                    true, preferences);
                }
            }
            function hasFixes() {
                return addToNamespace.length > 0 || importType.length > 0 || addToExisting.size > 0 || newImports.size > 0;
            }
        }
        function createImportSpecifierResolver(importingFile, program, host, preferences) {
            const packageJsonImportFilter = createPackageJsonImportFilter(importingFile, preferences, host);
            const importMap = createExistingImportMap(program.getTypeChecker(), importingFile, program.getCompilerOptions());
            return { getModuleSpecifierForBestExportInfo };
            function getModuleSpecifierForBestExportInfo(exportInfo, position, isValidTypeOnlyUseSite, fromCacheOnly) {
                const { fixes, computedWithoutCacheCount } = getImportFixes(exportInfo, position, isValidTypeOnlyUseSite, 
                /*useRequire*/
                false, program, importingFile, host, preferences, importMap, fromCacheOnly);
                const result = getBestFix(fixes, importingFile, program, packageJsonImportFilter, host);
                return result && { ...result, computedWithoutCacheCount };
            }
        }
        function getImportCompletionAction(targetSymbol, moduleSymbol, exportMapKey, sourceFile, symbolName2, isJsxTagName, host, program, formatContext, position, preferences, cancellationToken) {
            let exportInfos;
            if (exportMapKey) {
                exportInfos = getExportInfoMap(sourceFile, host, program, preferences, cancellationToken).get(sourceFile.path, exportMapKey);
                Debug.assertIsDefined(exportInfos, "Some exportInfo should match the specified exportMapKey");
            }
            else {
                exportInfos = pathIsBareSpecifier(stripQuotes(moduleSymbol.name)) ? [getSingleExportInfoForSymbol(targetSymbol, symbolName2, moduleSymbol, program, host)] : getAllExportInfoForSymbol(sourceFile, targetSymbol, symbolName2, moduleSymbol, isJsxTagName, program, host, preferences, cancellationToken);
                Debug.assertIsDefined(exportInfos, "Some exportInfo should match the specified symbol / moduleSymbol");
            }
            const useRequire = shouldUseRequire(sourceFile, program);
            const isValidTypeOnlyUseSite = isValidTypeOnlyAliasUseSite(getTokenAtPosition(sourceFile, position));
            const fix = Debug.checkDefined(getImportFixForSymbol(sourceFile, exportInfos, program, position, isValidTypeOnlyUseSite, useRequire, host, preferences));
            return {
                moduleSpecifier: fix.moduleSpecifier,
                codeAction: codeFixActionToCodeAction(codeActionForFix({ host, formatContext, preferences }, sourceFile, symbolName2, fix, 
                /*includeSymbolNameInDescription*/
                false, program, preferences))
            };
        }
        function getPromoteTypeOnlyCompletionAction(sourceFile, symbolToken, program, host, formatContext, preferences) {
            const compilerOptions = program.getCompilerOptions();
            const symbolName2 = single(getSymbolNamesToImport(sourceFile, program.getTypeChecker(), symbolToken, compilerOptions));
            const fix = getTypeOnlyPromotionFix(sourceFile, symbolToken, symbolName2, program);
            const includeSymbolNameInDescription = symbolName2 !== symbolToken.text;
            return fix && codeFixActionToCodeAction(codeActionForFix({ host, formatContext, preferences }, sourceFile, symbolName2, fix, includeSymbolNameInDescription, program, preferences));
        }
        function getImportFixForSymbol(sourceFile, exportInfos, program, position, isValidTypeOnlyUseSite, useRequire, host, preferences) {
            const packageJsonImportFilter = createPackageJsonImportFilter(sourceFile, preferences, host);
            return getBestFix(getImportFixes(exportInfos, position, isValidTypeOnlyUseSite, useRequire, program, sourceFile, host, preferences).fixes, sourceFile, program, packageJsonImportFilter, host);
        }
        function codeFixActionToCodeAction({ description: description3, changes, commands }) {
            return { description: description3, changes, commands };
        }
        function getAllExportInfoForSymbol(importingFile, symbol, symbolName2, moduleSymbol, preferCapitalized, program, host, preferences, cancellationToken) {
            const getChecker = createGetChecker(program, host);
            return getExportInfoMap(importingFile, host, program, preferences, cancellationToken).search(importingFile.path, preferCapitalized, (name) => name === symbolName2, (info) => {
                if (skipAlias(info[0].symbol, getChecker(info[0].isFromPackageJson)) === symbol && info.some((i) => i.moduleSymbol === moduleSymbol || i.symbol.parent === moduleSymbol)) {
                    return info;
                }
            });
        }
        function getSingleExportInfoForSymbol(symbol, symbolName2, moduleSymbol, program, host) {
            var _a, _b;
            const compilerOptions = program.getCompilerOptions();
            const mainProgramInfo = getInfoWithChecker(program.getTypeChecker(), 
            /*isFromPackageJson*/
            false);
            if (mainProgramInfo) {
                return mainProgramInfo;
            }
            const autoImportProvider = (_b = (_a = host.getPackageJsonAutoImportProvider) == null ? void 0 : _a.call(host)) == null ? void 0 : _b.getTypeChecker();
            return Debug.checkDefined(autoImportProvider && getInfoWithChecker(autoImportProvider, 
            /*isFromPackageJson*/
            true), `Could not find symbol in specified module for code actions`);
            function getInfoWithChecker(checker, isFromPackageJson) {
                const defaultInfo = getDefaultLikeExportInfo(moduleSymbol, checker, compilerOptions);
                if (defaultInfo && skipAlias(defaultInfo.symbol, checker) === symbol) {
                    return { symbol: defaultInfo.symbol, moduleSymbol, moduleFileName: void 0, exportKind: defaultInfo.exportKind, targetFlags: skipAlias(symbol, checker).flags, isFromPackageJson };
                }
                const named = checker.tryGetMemberInModuleExportsAndProperties(symbolName2, moduleSymbol);
                if (named && skipAlias(named, checker) === symbol) {
                    return { symbol: named, moduleSymbol, moduleFileName: void 0, exportKind: 0 /* Named */, targetFlags: skipAlias(symbol, checker).flags, isFromPackageJson };
                }
            }
        }
        function getImportFixes(exportInfos, usagePosition, isValidTypeOnlyUseSite, useRequire, program, sourceFile, host, preferences, importMap = createExistingImportMap(program.getTypeChecker(), sourceFile, program.getCompilerOptions()), fromCacheOnly) {
            const checker = program.getTypeChecker();
            const existingImports = flatMap(exportInfos, importMap.getImportsForExportInfo);
            const useNamespace = usagePosition !== void 0 && tryUseExistingNamespaceImport(existingImports, usagePosition);
            const addToExisting = tryAddToExistingImport(existingImports, isValidTypeOnlyUseSite, checker, program.getCompilerOptions());
            if (addToExisting) {
                return {
                    computedWithoutCacheCount: 0,
                    fixes: [...useNamespace ? [useNamespace] : emptyArray, addToExisting]
                };
            }
            const { fixes, computedWithoutCacheCount = 0 } = getFixesForAddImport(exportInfos, existingImports, program, sourceFile, usagePosition, isValidTypeOnlyUseSite, useRequire, host, preferences, fromCacheOnly);
            return {
                computedWithoutCacheCount,
                fixes: [...useNamespace ? [useNamespace] : emptyArray, ...fixes]
            };
        }
        function tryUseExistingNamespaceImport(existingImports, position) {
            return firstDefined(existingImports, ({ declaration, importKind }) => {
                var _a;
                if (importKind !== 0 /* Named */)
                    return void 0;
                const namespacePrefix = getNamespaceLikeImportText(declaration);
                const moduleSpecifier = namespacePrefix && ((_a = tryGetModuleSpecifierFromDeclaration(declaration)) == null ? void 0 : _a.text);
                if (moduleSpecifier) {
                    return { kind: 0 /* UseNamespace */, namespacePrefix, usagePosition: position, moduleSpecifier };
                }
            });
        }
        function getNamespaceLikeImportText(declaration) {
            var _a, _b, _c;
            switch (declaration.kind) {
                case 260 /* VariableDeclaration */:
                    return (_a = tryCast(declaration.name, isIdentifier)) == null ? void 0 : _a.text;
                case 271 /* ImportEqualsDeclaration */:
                    return declaration.name.text;
                case 272 /* ImportDeclaration */:
                    return (_c = tryCast((_b = declaration.importClause) == null ? void 0 : _b.namedBindings, isNamespaceImport)) == null ? void 0 : _c.name.text;
                default:
                    return Debug.assertNever(declaration);
            }
        }
        function getAddAsTypeOnly(isValidTypeOnlyUseSite, isForNewImportDeclaration, symbol, targetFlags, checker, compilerOptions) {
            if (!isValidTypeOnlyUseSite) {
                return 4 /* NotAllowed */;
            }
            if (isForNewImportDeclaration && compilerOptions.importsNotUsedAsValues === 2 /* Error */) {
                return 2 /* Required */;
            }
            if (importNameElisionDisabled(compilerOptions) && (!(targetFlags & 111551 /* Value */) || !!checker.getTypeOnlyAliasDeclaration(symbol))) {
                return 2 /* Required */;
            }
            return 1 /* Allowed */;
        }
        function tryAddToExistingImport(existingImports, isValidTypeOnlyUseSite, checker, compilerOptions) {
            let best;
            for (const existingImport of existingImports) {
                const fix = getAddToExistingImportFix(existingImport);
                if (!fix)
                    continue;
                const isTypeOnly = isTypeOnlyImportDeclaration(fix.importClauseOrBindingPattern);
                if (fix.addAsTypeOnly !== 4 /* NotAllowed */ && isTypeOnly || fix.addAsTypeOnly === 4 /* NotAllowed */ && !isTypeOnly) {
                    return fix;
                }
                best ?? (best = fix);
            }
            return best;
            function getAddToExistingImportFix({ declaration, importKind, symbol, targetFlags }) {
                if (importKind === 3 /* CommonJS */ || importKind === 2 /* Namespace */ || declaration.kind === 271 /* ImportEqualsDeclaration */) {
                    return void 0;
                }
                if (declaration.kind === 260 /* VariableDeclaration */) {
                    return (importKind === 0 /* Named */ || importKind === 1 /* Default */) && declaration.name.kind === 206 /* ObjectBindingPattern */ ? { kind: 2 /* AddToExisting */, importClauseOrBindingPattern: declaration.name, importKind, moduleSpecifier: declaration.initializer.arguments[0].text, addAsTypeOnly: 4 /* NotAllowed */ } : void 0;
                }
                const { importClause } = declaration;
                if (!importClause || !isStringLiteralLike(declaration.moduleSpecifier)) {
                    return void 0;
                }
                const { name, namedBindings } = importClause;
                if (importClause.isTypeOnly && !(importKind === 0 /* Named */ && namedBindings)) {
                    return void 0;
                }
                const addAsTypeOnly = getAddAsTypeOnly(isValidTypeOnlyUseSite, 
                /*isForNewImportDeclaration*/
                false, symbol, targetFlags, checker, compilerOptions);
                if (importKind === 1 /* Default */ && (name || // Cannot add a default import to a declaration that already has one
                    addAsTypeOnly === 2 /* Required */ && namedBindings)) {
                    return void 0;
                }
                if (importKind === 0 /* Named */ && (namedBindings == null ? void 0 : namedBindings.kind) === 274 /* NamespaceImport */) {
                    return void 0;
                }
                return {
                    kind: 2 /* AddToExisting */,
                    importClauseOrBindingPattern: importClause,
                    importKind,
                    moduleSpecifier: declaration.moduleSpecifier.text,
                    addAsTypeOnly
                };
            }
        }
        function createExistingImportMap(checker, importingFile, compilerOptions) {
            let importMap;
            for (const moduleSpecifier of importingFile.imports) {
                const i = importFromModuleSpecifier(moduleSpecifier);
                if (isVariableDeclarationInitializedToRequire(i.parent)) {
                    const moduleSymbol = checker.resolveExternalModuleName(moduleSpecifier);
                    if (moduleSymbol) {
                        (importMap || (importMap = createMultiMap())).add(getSymbolId(moduleSymbol), i.parent);
                    }
                }
                else if (i.kind === 272 /* ImportDeclaration */ || i.kind === 271 /* ImportEqualsDeclaration */) {
                    const moduleSymbol = checker.getSymbolAtLocation(moduleSpecifier);
                    if (moduleSymbol) {
                        (importMap || (importMap = createMultiMap())).add(getSymbolId(moduleSymbol), i);
                    }
                }
            }
            return {
                getImportsForExportInfo: ({ moduleSymbol, exportKind, targetFlags, symbol }) => {
                    if (!(targetFlags & 111551 /* Value */) && isSourceFileJS(importingFile))
                        return emptyArray;
                    const matchingDeclarations = importMap == null ? void 0 : importMap.get(getSymbolId(moduleSymbol));
                    if (!matchingDeclarations)
                        return emptyArray;
                    const importKind = getImportKind(importingFile, exportKind, compilerOptions);
                    return matchingDeclarations.map((declaration) => ({ declaration, importKind, symbol, targetFlags }));
                }
            };
        }
        function shouldUseRequire(sourceFile, program) {
            if (!isSourceFileJS(sourceFile)) {
                return false;
            }
            if (sourceFile.commonJsModuleIndicator && !sourceFile.externalModuleIndicator)
                return true;
            if (sourceFile.externalModuleIndicator && !sourceFile.commonJsModuleIndicator)
                return false;
            const compilerOptions = program.getCompilerOptions();
            if (compilerOptions.configFile) {
                return getEmitModuleKind(compilerOptions) < 5 /* ES2015 */;
            }
            if (sourceFile.impliedNodeFormat === 1 /* CommonJS */)
                return true;
            if (sourceFile.impliedNodeFormat === 99 /* ESNext */)
                return false;
            for (const otherFile of program.getSourceFiles()) {
                if (otherFile === sourceFile || !isSourceFileJS(otherFile) || program.isSourceFileFromExternalLibrary(otherFile))
                    continue;
                if (otherFile.commonJsModuleIndicator && !otherFile.externalModuleIndicator)
                    return true;
                if (otherFile.externalModuleIndicator && !otherFile.commonJsModuleIndicator)
                    return false;
            }
            return true;
        }
        function createGetChecker(program, host) {
            return memoizeOne((isFromPackageJson) => isFromPackageJson ? host.getPackageJsonAutoImportProvider().getTypeChecker() : program.getTypeChecker());
        }
        function getNewImportFixes(program, sourceFile, usagePosition, isValidTypeOnlyUseSite, useRequire, exportInfo, host, preferences, fromCacheOnly) {
            const isJs = isSourceFileJS(sourceFile);
            const compilerOptions = program.getCompilerOptions();
            const moduleSpecifierResolutionHost = createModuleSpecifierResolutionHost(program, host);
            const getChecker = createGetChecker(program, host);
            const moduleResolution = getEmitModuleResolutionKind(compilerOptions);
            const rejectNodeModulesRelativePaths = moduleResolutionUsesNodeModules(moduleResolution);
            const getModuleSpecifiers2 = fromCacheOnly ? (moduleSymbol) => ({ moduleSpecifiers: ts_moduleSpecifiers_exports.tryGetModuleSpecifiersFromCache(moduleSymbol, sourceFile, moduleSpecifierResolutionHost, preferences), computedWithoutCache: false }) : (moduleSymbol, checker) => ts_moduleSpecifiers_exports.getModuleSpecifiersWithCacheInfo(moduleSymbol, checker, compilerOptions, sourceFile, moduleSpecifierResolutionHost, preferences, 
            /*options*/
            void 0, 
            /*forAutoImport*/
            true);
            let computedWithoutCacheCount = 0;
            const fixes = flatMap(exportInfo, (exportInfo2, i) => {
                const checker = getChecker(exportInfo2.isFromPackageJson);
                const { computedWithoutCache, moduleSpecifiers } = getModuleSpecifiers2(exportInfo2.moduleSymbol, checker);
                const importedSymbolHasValueMeaning = !!(exportInfo2.targetFlags & 111551 /* Value */);
                const addAsTypeOnly = getAddAsTypeOnly(isValidTypeOnlyUseSite, 
                /*isForNewImportDeclaration*/
                true, exportInfo2.symbol, exportInfo2.targetFlags, checker, compilerOptions);
                computedWithoutCacheCount += computedWithoutCache ? 1 : 0;
                return mapDefined(moduleSpecifiers, (moduleSpecifier) => {
                    var _a;
                    if (rejectNodeModulesRelativePaths && pathContainsNodeModules(moduleSpecifier)) {
                        return void 0;
                    }
                    if (!importedSymbolHasValueMeaning && isJs && usagePosition !== void 0) {
                        return { kind: 1 /* JsdocTypeImport */, moduleSpecifier, usagePosition, exportInfo: exportInfo2, isReExport: i > 0 };
                    }
                    const importKind = getImportKind(sourceFile, exportInfo2.exportKind, compilerOptions);
                    let qualification;
                    if (usagePosition !== void 0 && importKind === 3 /* CommonJS */ && exportInfo2.exportKind === 0 /* Named */) {
                        const exportEquals = checker.resolveExternalModuleSymbol(exportInfo2.moduleSymbol);
                        let namespacePrefix;
                        if (exportEquals !== exportInfo2.moduleSymbol) {
                            namespacePrefix = (_a = getDefaultExportInfoWorker(exportEquals, checker, compilerOptions)) == null ? void 0 : _a.name;
                        }
                        namespacePrefix || (namespacePrefix = moduleSymbolToValidIdentifier(exportInfo2.moduleSymbol, getEmitScriptTarget(compilerOptions), 
                        /*forceCapitalize*/
                        false));
                        qualification = { namespacePrefix, usagePosition };
                    }
                    return {
                        kind: 3 /* AddNew */,
                        moduleSpecifier,
                        importKind,
                        useRequire,
                        addAsTypeOnly,
                        exportInfo: exportInfo2,
                        isReExport: i > 0,
                        qualification
                    };
                });
            });
            return { computedWithoutCacheCount, fixes };
        }
        function getFixesForAddImport(exportInfos, existingImports, program, sourceFile, usagePosition, isValidTypeOnlyUseSite, useRequire, host, preferences, fromCacheOnly) {
            const existingDeclaration = firstDefined(existingImports, (info) => newImportInfoFromExistingSpecifier(info, isValidTypeOnlyUseSite, useRequire, program.getTypeChecker(), program.getCompilerOptions()));
            return existingDeclaration ? { fixes: [existingDeclaration] } : getNewImportFixes(program, sourceFile, usagePosition, isValidTypeOnlyUseSite, useRequire, exportInfos, host, preferences, fromCacheOnly);
        }
        function newImportInfoFromExistingSpecifier({ declaration, importKind, symbol, targetFlags }, isValidTypeOnlyUseSite, useRequire, checker, compilerOptions) {
            var _a;
            const moduleSpecifier = (_a = tryGetModuleSpecifierFromDeclaration(declaration)) == null ? void 0 : _a.text;
            if (moduleSpecifier) {
                const addAsTypeOnly = useRequire ? 4 /* NotAllowed */ : getAddAsTypeOnly(isValidTypeOnlyUseSite, 
                /*isForNewImportDeclaration*/
                true, symbol, targetFlags, checker, compilerOptions);
                return { kind: 3 /* AddNew */, moduleSpecifier, importKind, addAsTypeOnly, useRequire };
            }
        }
        function getFixInfos(context, errorCode, pos, useAutoImportProvider) {
            const symbolToken = getTokenAtPosition(context.sourceFile, pos);
            let info;
            if (errorCode === Diagnostics._0_refers_to_a_UMD_global_but_the_current_file_is_a_module_Consider_adding_an_import_instead.code) {
                info = getFixesInfoForUMDImport(context, symbolToken);
            }
            else if (!isIdentifier(symbolToken)) {
                return void 0;
            }
            else if (errorCode === Diagnostics._0_cannot_be_used_as_a_value_because_it_was_imported_using_import_type.code) {
                const symbolName2 = single(getSymbolNamesToImport(context.sourceFile, context.program.getTypeChecker(), symbolToken, context.program.getCompilerOptions()));
                const fix = getTypeOnlyPromotionFix(context.sourceFile, symbolToken, symbolName2, context.program);
                return fix && [{ fix, symbolName: symbolName2, errorIdentifierText: symbolToken.text }];
            }
            else {
                info = getFixesInfoForNonUMDImport(context, symbolToken, useAutoImportProvider);
            }
            const packageJsonImportFilter = createPackageJsonImportFilter(context.sourceFile, context.preferences, context.host);
            return info && sortFixInfo(info, context.sourceFile, context.program, packageJsonImportFilter, context.host);
        }
        function sortFixInfo(fixes, sourceFile, program, packageJsonImportFilter, host) {
            const _toPath = (fileName) => toPath(fileName, host.getCurrentDirectory(), hostGetCanonicalFileName(host));
            return sort(fixes, (a, b) => compareBooleans(!!a.isJsxNamespaceFix, !!b.isJsxNamespaceFix) || compareValues(a.fix.kind, b.fix.kind) || compareModuleSpecifiers(a.fix, b.fix, sourceFile, program, packageJsonImportFilter.allowsImportingSpecifier, _toPath));
        }
        function getBestFix(fixes, sourceFile, program, packageJsonImportFilter, host) {
            if (!some(fixes))
                return;
            if (fixes[0].kind === 0 /* UseNamespace */ || fixes[0].kind === 2 /* AddToExisting */) {
                return fixes[0];
            }
            return fixes.reduce((best, fix) => (
            // Takes true branch of conditional if `fix` is better than `best`
            compareModuleSpecifiers(fix, best, sourceFile, program, packageJsonImportFilter.allowsImportingSpecifier, (fileName) => toPath(fileName, host.getCurrentDirectory(), hostGetCanonicalFileName(host))) === -1 /* LessThan */ ? fix : best));
        }
        function compareModuleSpecifiers(a, b, importingFile, program, allowsImportingSpecifier, toPath3) {
            if (a.kind !== 0 /* UseNamespace */ && b.kind !== 0 /* UseNamespace */) {
                return compareBooleans(allowsImportingSpecifier(b.moduleSpecifier), allowsImportingSpecifier(a.moduleSpecifier)) || compareNodeCoreModuleSpecifiers(a.moduleSpecifier, b.moduleSpecifier, importingFile, program) || compareBooleans(isFixPossiblyReExportingImportingFile(a, importingFile, program.getCompilerOptions(), toPath3), isFixPossiblyReExportingImportingFile(b, importingFile, program.getCompilerOptions(), toPath3)) || compareNumberOfDirectorySeparators(a.moduleSpecifier, b.moduleSpecifier);
            }
            return 0 /* EqualTo */;
        }
        function isFixPossiblyReExportingImportingFile(fix, importingFile, compilerOptions, toPath3) {
            var _a;
            if (fix.isReExport && ((_a = fix.exportInfo) == null ? void 0 : _a.moduleFileName) && isIndexFileName(fix.exportInfo.moduleFileName)) {
                const reExportDir = toPath3(getDirectoryPath(fix.exportInfo.moduleFileName));
                return startsWith(importingFile.path, reExportDir);
            }
            return false;
        }
        function isIndexFileName(fileName) {
            return getBaseFileName(fileName, [".js", ".jsx", ".d.ts", ".ts", ".tsx"], 
            /*ignoreCase*/
            true) === "index";
        }
        function compareNodeCoreModuleSpecifiers(a, b, importingFile, program) {
            if (startsWith(a, "node:") && !startsWith(b, "node:"))
                return shouldUseUriStyleNodeCoreModules(importingFile, program) ? -1 /* LessThan */ : 1 /* GreaterThan */;
            if (startsWith(b, "node:") && !startsWith(a, "node:"))
                return shouldUseUriStyleNodeCoreModules(importingFile, program) ? 1 /* GreaterThan */ : -1 /* LessThan */;
            return 0 /* EqualTo */;
        }
        function getFixesInfoForUMDImport({ sourceFile, program, host, preferences }, token) {
            const checker = program.getTypeChecker();
            const umdSymbol = getUmdSymbol(token, checker);
            if (!umdSymbol)
                return void 0;
            const symbol = checker.getAliasedSymbol(umdSymbol);
            const symbolName2 = umdSymbol.name;
            const exportInfo = [{ symbol: umdSymbol, moduleSymbol: symbol, moduleFileName: void 0, exportKind: 3 /* UMD */, targetFlags: symbol.flags, isFromPackageJson: false }];
            const useRequire = shouldUseRequire(sourceFile, program);
            const fixes = getImportFixes(exportInfo, 
            /*usagePosition*/
            void 0, 
            /*isValidTypeOnlyUseSite*/
            false, useRequire, program, sourceFile, host, preferences).fixes;
            return fixes.map((fix) => {
                var _a;
                return { fix, symbolName: symbolName2, errorIdentifierText: (_a = tryCast(token, isIdentifier)) == null ? void 0 : _a.text };
            });
        }
        function getUmdSymbol(token, checker) {
            const umdSymbol = isIdentifier(token) ? checker.getSymbolAtLocation(token) : void 0;
            if (isUMDExportSymbol(umdSymbol))
                return umdSymbol;
            const { parent: parent2 } = token;
            if (isJsxOpeningLikeElement(parent2) && parent2.tagName === token || isJsxOpeningFragment(parent2)) {
                const parentSymbol = checker.resolveName(checker.getJsxNamespace(parent2), isJsxOpeningLikeElement(parent2) ? token : parent2, 111551 /* Value */, 
                /*excludeGlobals*/
                false);
                if (isUMDExportSymbol(parentSymbol)) {
                    return parentSymbol;
                }
            }
            return void 0;
        }
        function getImportKind(importingFile, exportKind, compilerOptions, forceImportKeyword) {
            if (compilerOptions.verbatimModuleSyntax && (getEmitModuleKind(compilerOptions) === 1 /* CommonJS */ || importingFile.impliedNodeFormat === 1 /* CommonJS */)) {
                return 3 /* CommonJS */;
            }
            switch (exportKind) {
                case 0 /* Named */:
                    return 0 /* Named */;
                case 1 /* Default */:
                    return 1 /* Default */;
                case 2 /* ExportEquals */:
                    return getExportEqualsImportKind(importingFile, compilerOptions, !!forceImportKeyword);
                case 3 /* UMD */:
                    return getUmdImportKind(importingFile, compilerOptions, !!forceImportKeyword);
                default:
                    return Debug.assertNever(exportKind);
            }
        }
        function getUmdImportKind(importingFile, compilerOptions, forceImportKeyword) {
            if (getAllowSyntheticDefaultImports(compilerOptions)) {
                return 1 /* Default */;
            }
            const moduleKind = getEmitModuleKind(compilerOptions);
            switch (moduleKind) {
                case 2 /* AMD */:
                case 1 /* CommonJS */:
                case 3 /* UMD */:
                    if (isInJSFile(importingFile)) {
                        return isExternalModule(importingFile) || forceImportKeyword ? 2 /* Namespace */ : 3 /* CommonJS */;
                    }
                    return 3 /* CommonJS */;
                case 4 /* System */:
                case 5 /* ES2015 */:
                case 6 /* ES2020 */:
                case 7 /* ES2022 */:
                case 99 /* ESNext */:
                case 0 /* None */:
                case 200 /* Preserve */:
                    return 2 /* Namespace */;
                case 100 /* Node16 */:
                case 199 /* NodeNext */:
                    return importingFile.impliedNodeFormat === 99 /* ESNext */ ? 2 /* Namespace */ : 3 /* CommonJS */;
                default:
                    return Debug.assertNever(moduleKind, `Unexpected moduleKind ${moduleKind}`);
            }
        }
        function getFixesInfoForNonUMDImport({ sourceFile, program, cancellationToken, host, preferences }, symbolToken, useAutoImportProvider) {
            const checker = program.getTypeChecker();
            const compilerOptions = program.getCompilerOptions();
            return flatMap(getSymbolNamesToImport(sourceFile, checker, symbolToken, compilerOptions), (symbolName2) => {
                if (symbolName2 === "default" /* Default */) {
                    return void 0;
                }
                const isValidTypeOnlyUseSite = isValidTypeOnlyAliasUseSite(symbolToken);
                const useRequire = shouldUseRequire(sourceFile, program);
                const exportInfo = getExportInfos(symbolName2, isJSXTagName(symbolToken), getMeaningFromLocation(symbolToken), cancellationToken, sourceFile, program, useAutoImportProvider, host, preferences);
                return arrayFrom(flatMapIterator(exportInfo.values(), (exportInfos) => getImportFixes(exportInfos, symbolToken.getStart(sourceFile), isValidTypeOnlyUseSite, useRequire, program, sourceFile, host, preferences).fixes), (fix) => ({ fix, symbolName: symbolName2, errorIdentifierText: symbolToken.text, isJsxNamespaceFix: symbolName2 !== symbolToken.text }));
            });
        }
        function getTypeOnlyPromotionFix(sourceFile, symbolToken, symbolName2, program) {
            const checker = program.getTypeChecker();
            const symbol = checker.resolveName(symbolName2, symbolToken, 111551 /* Value */, 
            /*excludeGlobals*/
            true);
            if (!symbol)
                return void 0;
            const typeOnlyAliasDeclaration = checker.getTypeOnlyAliasDeclaration(symbol);
            if (!typeOnlyAliasDeclaration || getSourceFileOfNode(typeOnlyAliasDeclaration) !== sourceFile)
                return void 0;
            return { kind: 4 /* PromoteTypeOnly */, typeOnlyAliasDeclaration };
        }
        function getSymbolNamesToImport(sourceFile, checker, symbolToken, compilerOptions) {
            const parent2 = symbolToken.parent;
            if ((isJsxOpeningLikeElement(parent2) || isJsxClosingElement(parent2)) && parent2.tagName === symbolToken && jsxModeNeedsExplicitImport(compilerOptions.jsx)) {
                const jsxNamespace = checker.getJsxNamespace(sourceFile);
                if (needsJsxNamespaceFix(jsxNamespace, symbolToken, checker)) {
                    const needsComponentNameFix = !isIntrinsicJsxName(symbolToken.text) && !checker.resolveName(symbolToken.text, symbolToken, 111551 /* Value */, 
                    /*excludeGlobals*/
                    false);
                    return needsComponentNameFix ? [symbolToken.text, jsxNamespace] : [jsxNamespace];
                }
            }
            return [symbolToken.text];
        }
        function needsJsxNamespaceFix(jsxNamespace, symbolToken, checker) {
            if (isIntrinsicJsxName(symbolToken.text))
                return true;
            const namespaceSymbol = checker.resolveName(jsxNamespace, symbolToken, 111551 /* Value */, 
            /*excludeGlobals*/
            true);
            return !namespaceSymbol || some(namespaceSymbol.declarations, isTypeOnlyImportOrExportDeclaration) && !(namespaceSymbol.flags & 111551 /* Value */);
        }
        function getExportInfos(symbolName2, isJsxTagName, currentTokenMeaning, cancellationToken, fromFile, program, useAutoImportProvider, host, preferences) {
            var _a;
            const originalSymbolToExportInfos = createMultiMap();
            const packageJsonFilter = createPackageJsonImportFilter(fromFile, preferences, host);
            const moduleSpecifierCache = (_a = host.getModuleSpecifierCache) == null ? void 0 : _a.call(host);
            const getModuleSpecifierResolutionHost = memoizeOne((isFromPackageJson) => {
                return createModuleSpecifierResolutionHost(isFromPackageJson ? host.getPackageJsonAutoImportProvider() : program, host);
            });
            function addSymbol(moduleSymbol, toFile, exportedSymbol, exportKind, program2, isFromPackageJson) {
                const moduleSpecifierResolutionHost = getModuleSpecifierResolutionHost(isFromPackageJson);
                if (toFile && isImportableFile(program2, fromFile, toFile, preferences, packageJsonFilter, moduleSpecifierResolutionHost, moduleSpecifierCache) || !toFile && packageJsonFilter.allowsImportingAmbientModule(moduleSymbol, moduleSpecifierResolutionHost)) {
                    const checker = program2.getTypeChecker();
                    originalSymbolToExportInfos.add(getUniqueSymbolId(exportedSymbol, checker).toString(), { symbol: exportedSymbol, moduleSymbol, moduleFileName: toFile == null ? void 0 : toFile.fileName, exportKind, targetFlags: skipAlias(exportedSymbol, checker).flags, isFromPackageJson });
                }
            }
            forEachExternalModuleToImportFrom(program, host, preferences, useAutoImportProvider, (moduleSymbol, sourceFile, program2, isFromPackageJson) => {
                const checker = program2.getTypeChecker();
                cancellationToken.throwIfCancellationRequested();
                const compilerOptions = program2.getCompilerOptions();
                const defaultInfo = getDefaultLikeExportInfo(moduleSymbol, checker, compilerOptions);
                if (defaultInfo && (defaultInfo.name === symbolName2 || moduleSymbolToValidIdentifier(moduleSymbol, getEmitScriptTarget(compilerOptions), isJsxTagName) === symbolName2) && symbolHasMeaning(defaultInfo.resolvedSymbol, currentTokenMeaning)) {
                    addSymbol(moduleSymbol, sourceFile, defaultInfo.symbol, defaultInfo.exportKind, program2, isFromPackageJson);
                }
                const exportSymbolWithIdenticalName = checker.tryGetMemberInModuleExportsAndProperties(symbolName2, moduleSymbol);
                if (exportSymbolWithIdenticalName && symbolHasMeaning(exportSymbolWithIdenticalName, currentTokenMeaning)) {
                    addSymbol(moduleSymbol, sourceFile, exportSymbolWithIdenticalName, 0 /* Named */, program2, isFromPackageJson);
                }
            });
            return originalSymbolToExportInfos;
        }
        function getExportEqualsImportKind(importingFile, compilerOptions, forceImportKeyword) {
            const allowSyntheticDefaults = getAllowSyntheticDefaultImports(compilerOptions);
            const isJS = isInJSFile(importingFile);
            if (!isJS && getEmitModuleKind(compilerOptions) >= 5 /* ES2015 */) {
                return allowSyntheticDefaults ? 1 /* Default */ : 2 /* Namespace */;
            }
            if (isJS) {
                return isExternalModule(importingFile) || forceImportKeyword ? allowSyntheticDefaults ? 1 /* Default */ : 2 /* Namespace */ : 3 /* CommonJS */;
            }
            for (const statement of importingFile.statements) {
                if (isImportEqualsDeclaration(statement) && !nodeIsMissing(statement.moduleReference)) {
                    return 3 /* CommonJS */;
                }
            }
            return allowSyntheticDefaults ? 1 /* Default */ : 3 /* CommonJS */;
        }
        function codeActionForFix(context, sourceFile, symbolName2, fix, includeSymbolNameInDescription, program, preferences) {
            let diag2;
            const changes = ts_textChanges_exports.ChangeTracker.with(context, (tracker) => {
                diag2 = codeActionForFixWorker(tracker, sourceFile, symbolName2, fix, includeSymbolNameInDescription, program, preferences);
            });
            return createCodeFixAction(importFixName, changes, diag2, importFixId, Diagnostics.Add_all_missing_imports);
        }
        function codeActionForFixWorker(changes, sourceFile, symbolName2, fix, includeSymbolNameInDescription, program, preferences) {
            const quotePreference = getQuotePreference(sourceFile, preferences);
            switch (fix.kind) {
                case 0 /* UseNamespace */:
                    addNamespaceQualifier(changes, sourceFile, fix);
                    return [Diagnostics.Change_0_to_1, symbolName2, `${fix.namespacePrefix}.${symbolName2}`];
                case 1 /* JsdocTypeImport */:
                    addImportType(changes, sourceFile, fix, quotePreference);
                    return [Diagnostics.Change_0_to_1, symbolName2, getImportTypePrefix(fix.moduleSpecifier, quotePreference) + symbolName2];
                case 2 /* AddToExisting */: {
                    const { importClauseOrBindingPattern, importKind, addAsTypeOnly, moduleSpecifier } = fix;
                    doAddExistingFix(changes, sourceFile, importClauseOrBindingPattern, importKind === 1 /* Default */ ? { name: symbolName2, addAsTypeOnly } : void 0, importKind === 0 /* Named */ ? [{ name: symbolName2, addAsTypeOnly }] : emptyArray, preferences);
                    const moduleSpecifierWithoutQuotes = stripQuotes(moduleSpecifier);
                    return includeSymbolNameInDescription ? [Diagnostics.Import_0_from_1, symbolName2, moduleSpecifierWithoutQuotes] : [Diagnostics.Update_import_from_0, moduleSpecifierWithoutQuotes];
                }
                case 3 /* AddNew */: {
                    const { importKind, moduleSpecifier, addAsTypeOnly, useRequire, qualification } = fix;
                    const getDeclarations = useRequire ? getNewRequires : getNewImports;
                    const defaultImport = importKind === 1 /* Default */ ? { name: symbolName2, addAsTypeOnly } : void 0;
                    const namedImports = importKind === 0 /* Named */ ? [{ name: symbolName2, addAsTypeOnly }] : void 0;
                    const namespaceLikeImport = importKind === 2 /* Namespace */ || importKind === 3 /* CommonJS */ ? { importKind, name: (qualification == null ? void 0 : qualification.namespacePrefix) || symbolName2, addAsTypeOnly } : void 0;
                    insertImports(changes, sourceFile, getDeclarations(moduleSpecifier, quotePreference, defaultImport, namedImports, namespaceLikeImport, program.getCompilerOptions(), preferences), 
                    /*blankLineBetween*/
                    true, preferences);
                    if (qualification) {
                        addNamespaceQualifier(changes, sourceFile, qualification);
                    }
                    return includeSymbolNameInDescription ? [Diagnostics.Import_0_from_1, symbolName2, moduleSpecifier] : [Diagnostics.Add_import_from_0, moduleSpecifier];
                }
                case 4 /* PromoteTypeOnly */: {
                    const { typeOnlyAliasDeclaration } = fix;
                    const promotedDeclaration = promoteFromTypeOnly(changes, typeOnlyAliasDeclaration, program, sourceFile, preferences);
                    return promotedDeclaration.kind === 276 /* ImportSpecifier */ ? [Diagnostics.Remove_type_from_import_of_0_from_1, symbolName2, getModuleSpecifierText(promotedDeclaration.parent.parent)] : [Diagnostics.Remove_type_from_import_declaration_from_0, getModuleSpecifierText(promotedDeclaration)];
                }
                default:
                    return Debug.assertNever(fix, `Unexpected fix kind ${fix.kind}`);
            }
        }
        function getModuleSpecifierText(promotedDeclaration) {
            var _a, _b;
            return promotedDeclaration.kind === 271 /* ImportEqualsDeclaration */ ? ((_b = tryCast((_a = tryCast(promotedDeclaration.moduleReference, isExternalModuleReference)) == null ? void 0 : _a.expression, isStringLiteralLike)) == null ? void 0 : _b.text) || promotedDeclaration.moduleReference.getText() : cast(promotedDeclaration.parent.moduleSpecifier, isStringLiteral).text;
        }
        function promoteFromTypeOnly(changes, aliasDeclaration, program, sourceFile, preferences) {
            const compilerOptions = program.getCompilerOptions();
            const convertExistingToTypeOnly = importNameElisionDisabled(compilerOptions);
            switch (aliasDeclaration.kind) {
                case 276 /* ImportSpecifier */:
                    if (aliasDeclaration.isTypeOnly) {
                        const sortKind = ts_OrganizeImports_exports.detectImportSpecifierSorting(aliasDeclaration.parent.elements, preferences);
                        if (aliasDeclaration.parent.elements.length > 1 && sortKind) {
                            const newSpecifier = factory.updateImportSpecifier(aliasDeclaration, 
                            /*isTypeOnly*/
                            false, aliasDeclaration.propertyName, aliasDeclaration.name);
                            const comparer = ts_OrganizeImports_exports.getOrganizeImportsComparer(preferences, sortKind === 2 /* CaseInsensitive */);
                            const insertionIndex = ts_OrganizeImports_exports.getImportSpecifierInsertionIndex(aliasDeclaration.parent.elements, newSpecifier, comparer, preferences);
                            if (insertionIndex !== aliasDeclaration.parent.elements.indexOf(aliasDeclaration)) {
                                changes.delete(sourceFile, aliasDeclaration);
                                changes.insertImportSpecifierAtIndex(sourceFile, newSpecifier, aliasDeclaration.parent, insertionIndex);
                                return aliasDeclaration;
                            }
                        }
                        changes.deleteRange(sourceFile, { pos: getTokenPosOfNode(aliasDeclaration.getFirstToken()), end: getTokenPosOfNode(aliasDeclaration.propertyName ?? aliasDeclaration.name) });
                        return aliasDeclaration;
                    }
                    else {
                        Debug.assert(aliasDeclaration.parent.parent.isTypeOnly);
                        promoteImportClause(aliasDeclaration.parent.parent);
                        return aliasDeclaration.parent.parent;
                    }
                case 273 /* ImportClause */:
                    promoteImportClause(aliasDeclaration);
                    return aliasDeclaration;
                case 274 /* NamespaceImport */:
                    promoteImportClause(aliasDeclaration.parent);
                    return aliasDeclaration.parent;
                case 271 /* ImportEqualsDeclaration */:
                    changes.deleteRange(sourceFile, aliasDeclaration.getChildAt(1));
                    return aliasDeclaration;
                default:
                    Debug.failBadSyntaxKind(aliasDeclaration);
            }
            function promoteImportClause(importClause) {
                var _a;
                changes.delete(sourceFile, getTypeKeywordOfTypeOnlyImport(importClause, sourceFile));
                if (!compilerOptions.allowImportingTsExtensions) {
                    const moduleSpecifier = tryGetModuleSpecifierFromDeclaration(importClause.parent);
                    const resolvedModule = moduleSpecifier && ((_a = program.getResolvedModuleFromModuleSpecifier(moduleSpecifier)) == null ? void 0 : _a.resolvedModule);
                    if (resolvedModule == null ? void 0 : resolvedModule.resolvedUsingTsExtension) {
                        const changedExtension = changeAnyExtension(moduleSpecifier.text, getOutputExtension(moduleSpecifier.text, compilerOptions));
                        changes.replaceNode(sourceFile, moduleSpecifier, factory.createStringLiteral(changedExtension));
                    }
                }
                if (convertExistingToTypeOnly) {
                    const namedImports = tryCast(importClause.namedBindings, isNamedImports);
                    if (namedImports && namedImports.elements.length > 1) {
                        if (ts_OrganizeImports_exports.detectImportSpecifierSorting(namedImports.elements, preferences) && aliasDeclaration.kind === 276 /* ImportSpecifier */ && namedImports.elements.indexOf(aliasDeclaration) !== 0) {
                            changes.delete(sourceFile, aliasDeclaration);
                            changes.insertImportSpecifierAtIndex(sourceFile, aliasDeclaration, namedImports, 0);
                        }
                        for (const element of namedImports.elements) {
                            if (element !== aliasDeclaration && !element.isTypeOnly) {
                                changes.insertModifierBefore(sourceFile, 156 /* TypeKeyword */, element);
                            }
                        }
                    }
                }
            }
        }
        function doAddExistingFix(changes, sourceFile, clause, defaultImport, namedImports, preferences) {
            var _a;
            if (clause.kind === 206 /* ObjectBindingPattern */) {
                if (defaultImport) {
                    addElementToBindingPattern(clause, defaultImport.name, "default");
                }
                for (const specifier of namedImports) {
                    addElementToBindingPattern(clause, specifier.name, 
                    /*propertyName*/
                    void 0);
                }
                return;
            }
            const promoteFromTypeOnly2 = clause.isTypeOnly && some([defaultImport, ...namedImports], (i) => (i == null ? void 0 : i.addAsTypeOnly) === 4 /* NotAllowed */);
            const existingSpecifiers = clause.namedBindings && ((_a = tryCast(clause.namedBindings, isNamedImports)) == null ? void 0 : _a.elements);
            if (defaultImport) {
                Debug.assert(!clause.name, "Cannot add a default import to an import clause that already has one");
                changes.insertNodeAt(sourceFile, clause.getStart(sourceFile), factory.createIdentifier(defaultImport.name), { suffix: ", " });
            }
            if (namedImports.length) {
                let ignoreCaseForSorting;
                if (typeof preferences.organizeImportsIgnoreCase === "boolean") {
                    ignoreCaseForSorting = preferences.organizeImportsIgnoreCase;
                }
                else if (existingSpecifiers) {
                    const targetImportSorting = ts_OrganizeImports_exports.detectImportSpecifierSorting(existingSpecifiers, preferences);
                    if (targetImportSorting !== 3 /* Both */) {
                        ignoreCaseForSorting = targetImportSorting === 2 /* CaseInsensitive */;
                    }
                }
                if (ignoreCaseForSorting === void 0) {
                    ignoreCaseForSorting = ts_OrganizeImports_exports.detectSorting(sourceFile, preferences) === 2 /* CaseInsensitive */;
                }
                const comparer = ts_OrganizeImports_exports.getOrganizeImportsComparer(preferences, ignoreCaseForSorting);
                const newSpecifiers = stableSort(namedImports.map((namedImport) => factory.createImportSpecifier((!clause.isTypeOnly || promoteFromTypeOnly2) && shouldUseTypeOnly(namedImport, preferences), 
                /*propertyName*/
                void 0, factory.createIdentifier(namedImport.name))), (s1, s2) => ts_OrganizeImports_exports.compareImportOrExportSpecifiers(s1, s2, comparer));
                const specifierSort = (existingSpecifiers == null ? void 0 : existingSpecifiers.length) && ts_OrganizeImports_exports.detectImportSpecifierSorting(existingSpecifiers, preferences);
                if (specifierSort && !(ignoreCaseForSorting && specifierSort === 1 /* CaseSensitive */)) {
                    for (const spec of newSpecifiers) {
                        const insertionIndex = promoteFromTypeOnly2 && !spec.isTypeOnly ? 0 : ts_OrganizeImports_exports.getImportSpecifierInsertionIndex(existingSpecifiers, spec, comparer, preferences);
                        changes.insertImportSpecifierAtIndex(sourceFile, spec, clause.namedBindings, insertionIndex);
                    }
                }
                else if (existingSpecifiers == null ? void 0 : existingSpecifiers.length) {
                    for (const spec of newSpecifiers) {
                        changes.insertNodeInListAfter(sourceFile, last(existingSpecifiers), spec, existingSpecifiers);
                    }
                }
                else {
                    if (newSpecifiers.length) {
                        const namedImports2 = factory.createNamedImports(newSpecifiers);
                        if (clause.namedBindings) {
                            changes.replaceNode(sourceFile, clause.namedBindings, namedImports2);
                        }
                        else {
                            changes.insertNodeAfter(sourceFile, Debug.checkDefined(clause.name, "Import clause must have either named imports or a default import"), namedImports2);
                        }
                    }
                }
            }
            if (promoteFromTypeOnly2) {
                changes.delete(sourceFile, getTypeKeywordOfTypeOnlyImport(clause, sourceFile));
                if (existingSpecifiers) {
                    for (const specifier of existingSpecifiers) {
                        changes.insertModifierBefore(sourceFile, 156 /* TypeKeyword */, specifier);
                    }
                }
            }
            function addElementToBindingPattern(bindingPattern, name, propertyName) {
                const element = factory.createBindingElement(
                /*dotDotDotToken*/
                void 0, propertyName, name);
                if (bindingPattern.elements.length) {
                    changes.insertNodeInListAfter(sourceFile, last(bindingPattern.elements), element);
                }
                else {
                    changes.replaceNode(sourceFile, bindingPattern, factory.createObjectBindingPattern([element]));
                }
            }
        }
        function addNamespaceQualifier(changes, sourceFile, { namespacePrefix, usagePosition }) {
            changes.insertText(sourceFile, usagePosition, namespacePrefix + ".");
        }
        function addImportType(changes, sourceFile, { moduleSpecifier, usagePosition: position }, quotePreference) {
            changes.insertText(sourceFile, position, getImportTypePrefix(moduleSpecifier, quotePreference));
        }
        function getImportTypePrefix(moduleSpecifier, quotePreference) {
            const quote2 = getQuoteFromPreference(quotePreference);
            return `import(${quote2}${moduleSpecifier}${quote2}).`;
        }
        function needsTypeOnly({ addAsTypeOnly }) {
            return addAsTypeOnly === 2 /* Required */;
        }
        function shouldUseTypeOnly(info, preferences) {
            return needsTypeOnly(info) || !!preferences.preferTypeOnlyAutoImports && info.addAsTypeOnly !== 4 /* NotAllowed */;
        }
        function getNewImports(moduleSpecifier, quotePreference, defaultImport, namedImports, namespaceLikeImport, compilerOptions, preferences) {
            const quotedModuleSpecifier = makeStringLiteral(moduleSpecifier, quotePreference);
            let statements;
            if (defaultImport !== void 0 || (namedImports == null ? void 0 : namedImports.length)) {
                const topLevelTypeOnly = (!defaultImport || needsTypeOnly(defaultImport)) && every(namedImports, needsTypeOnly) || (compilerOptions.verbatimModuleSyntax || preferences.preferTypeOnlyAutoImports) && (defaultImport == null ? void 0 : defaultImport.addAsTypeOnly) !== 4 /* NotAllowed */ && !some(namedImports, (i) => i.addAsTypeOnly === 4 /* NotAllowed */);
                statements = combine(statements, makeImport(defaultImport && factory.createIdentifier(defaultImport.name), namedImports == null ? void 0 : namedImports.map((namedImport) => factory.createImportSpecifier(!topLevelTypeOnly && shouldUseTypeOnly(namedImport, preferences), 
                /*propertyName*/
                void 0, factory.createIdentifier(namedImport.name))), moduleSpecifier, quotePreference, topLevelTypeOnly));
            }
            if (namespaceLikeImport) {
                const declaration = namespaceLikeImport.importKind === 3 /* CommonJS */ ? factory.createImportEqualsDeclaration(
                /*modifiers*/
                void 0, shouldUseTypeOnly(namespaceLikeImport, preferences), factory.createIdentifier(namespaceLikeImport.name), factory.createExternalModuleReference(quotedModuleSpecifier)) : factory.createImportDeclaration(
                /*modifiers*/
                void 0, factory.createImportClause(shouldUseTypeOnly(namespaceLikeImport, preferences), 
                /*name*/
                void 0, factory.createNamespaceImport(factory.createIdentifier(namespaceLikeImport.name))), quotedModuleSpecifier, 
                /*attributes*/
                void 0);
                statements = combine(statements, declaration);
            }
            return Debug.checkDefined(statements);
        }
        function getNewRequires(moduleSpecifier, quotePreference, defaultImport, namedImports, namespaceLikeImport) {
            const quotedModuleSpecifier = makeStringLiteral(moduleSpecifier, quotePreference);
            let statements;
            if (defaultImport || (namedImports == null ? void 0 : namedImports.length)) {
                const bindingElements = (namedImports == null ? void 0 : namedImports.map(({ name }) => factory.createBindingElement(
                /*dotDotDotToken*/
                void 0, 
                /*propertyName*/
                void 0, name))) || [];
                if (defaultImport) {
                    bindingElements.unshift(factory.createBindingElement(
                    /*dotDotDotToken*/
                    void 0, "default", defaultImport.name));
                }
                const declaration = createConstEqualsRequireDeclaration(factory.createObjectBindingPattern(bindingElements), quotedModuleSpecifier);
                statements = combine(statements, declaration);
            }
            if (namespaceLikeImport) {
                const declaration = createConstEqualsRequireDeclaration(namespaceLikeImport.name, quotedModuleSpecifier);
                statements = combine(statements, declaration);
            }
            return Debug.checkDefined(statements);
        }
        function createConstEqualsRequireDeclaration(name, quotedModuleSpecifier) {
            return factory.createVariableStatement(
            /*modifiers*/
            void 0, factory.createVariableDeclarationList([
                factory.createVariableDeclaration(typeof name === "string" ? factory.createIdentifier(name) : name, 
                /*exclamationToken*/
                void 0, 
                /*type*/
                void 0, factory.createCallExpression(factory.createIdentifier("require"), 
                /*typeArguments*/
                void 0, [quotedModuleSpecifier]))
            ], 2 /* Const */));
        }
        function symbolHasMeaning({ declarations }, meaning) {
            return some(declarations, (decl) => !!(getMeaningFromDeclaration(decl) & meaning));
        }
        function moduleSymbolToValidIdentifier(moduleSymbol, target, forceCapitalize) {
            return moduleSpecifierToValidIdentifier(removeFileExtension(stripQuotes(moduleSymbol.name)), target, forceCapitalize);
        }
        function moduleSpecifierToValidIdentifier(moduleSpecifier, target, forceCapitalize) {
            const baseName = getBaseFileName(removeSuffix(moduleSpecifier, "/index"));
            let res = "";
            let lastCharWasValid = true;
            const firstCharCode = baseName.charCodeAt(0);
            if (isIdentifierStart(firstCharCode, target)) {
                res += String.fromCharCode(firstCharCode);
                if (forceCapitalize) {
                    res = res.toUpperCase();
                }
            }
            else {
                lastCharWasValid = false;
            }
            for (let i = 1; i < baseName.length; i++) {
                const ch = baseName.charCodeAt(i);
                const isValid = isIdentifierPart(ch, target);
                if (isValid) {
                    let char = String.fromCharCode(ch);
                    if (!lastCharWasValid) {
                        char = char.toUpperCase();
                    }
                    res += char;
                }
                lastCharWasValid = isValid;
            }
            return !isStringANonContextualKeyword(res) ? res || "_" : `_${res}`;
        }
        var importFixName, importFixId, errorCodes18;
        var init_importFixes = __esm({
            "src/services/codefixes/importFixes.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                importFixName = "import";
                importFixId = "fixMissingImport";
                errorCodes18 = [
                    Diagnostics.Cannot_find_name_0.code,
                    Diagnostics.Cannot_find_name_0_Did_you_mean_1.code,
                    Diagnostics.Cannot_find_name_0_Did_you_mean_the_instance_member_this_0.code,
                    Diagnostics.Cannot_find_name_0_Did_you_mean_the_static_member_1_0.code,
                    Diagnostics.Cannot_find_namespace_0.code,
                    Diagnostics._0_refers_to_a_UMD_global_but_the_current_file_is_a_module_Consider_adding_an_import_instead.code,
                    Diagnostics._0_only_refers_to_a_type_but_is_being_used_as_a_value_here.code,
                    Diagnostics.No_value_exists_in_scope_for_the_shorthand_property_0_Either_declare_one_or_provide_an_initializer.code,
                    Diagnostics._0_cannot_be_used_as_a_value_because_it_was_imported_using_import_type.code,
                    Diagnostics.Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_jQuery_Try_npm_i_save_dev_types_Slashjquery.code,
                    Diagnostics.Cannot_find_name_0_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_1_or_later.code,
                    Diagnostics.Cannot_find_name_0_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_include_dom.code,
                    Diagnostics.Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_a_test_runner_Try_npm_i_save_dev_types_Slashjest_or_npm_i_save_dev_types_Slashmocha_and_then_add_jest_or_mocha_to_the_types_field_in_your_tsconfig.code,
                    Diagnostics.Cannot_find_name_0_Did_you_mean_to_write_this_in_an_async_function.code,
                    Diagnostics.Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_jQuery_Try_npm_i_save_dev_types_Slashjquery_and_then_add_jquery_to_the_types_field_in_your_tsconfig.code,
                    Diagnostics.Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_a_test_runner_Try_npm_i_save_dev_types_Slashjest_or_npm_i_save_dev_types_Slashmocha.code,
                    Diagnostics.Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_node_Try_npm_i_save_dev_types_Slashnode.code,
                    Diagnostics.Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_node_Try_npm_i_save_dev_types_Slashnode_and_then_add_node_to_the_types_field_in_your_tsconfig.code,
                    Diagnostics.Cannot_find_namespace_0_Did_you_mean_1.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes18,
                    getCodeActions(context) {
                        const { errorCode, preferences, sourceFile, span, program } = context;
                        const info = getFixInfos(context, errorCode, span.start, 
                        /*useAutoImportProvider*/
                        true);
                        if (!info)
                            return void 0;
                        return info.map(({ fix, symbolName: symbolName2, errorIdentifierText }) => codeActionForFix(context, sourceFile, symbolName2, fix, 
                        /*includeSymbolNameInDescription*/
                        symbolName2 !== errorIdentifierText, program, preferences));
                    },
                    fixIds: [importFixId],
                    getAllCodeActions: (context) => {
                        const { sourceFile, program, preferences, host, cancellationToken } = context;
                        const importAdder = createImportAdderWorker(sourceFile, program, 
                        /*useAutoImportProvider*/
                        true, preferences, host, cancellationToken);
                        eachDiagnostic(context, errorCodes18, (diag2) => importAdder.addImportFromDiagnostic(diag2, context));
                        return createCombinedCodeActions(ts_textChanges_exports.ChangeTracker.with(context, importAdder.writeFixes));
                    }
                });
            }
        });
        // src/services/codefixes/fixAddMissingConstraint.ts
        function getInfo6(program, sourceFile, span) {
            const diag2 = find(program.getSemanticDiagnostics(sourceFile), (diag3) => diag3.start === span.start && diag3.length === span.length);
            if (diag2 === void 0 || diag2.relatedInformation === void 0)
                return;
            const related = find(diag2.relatedInformation, (related2) => related2.code === Diagnostics.This_type_parameter_might_need_an_extends_0_constraint.code);
            if (related === void 0 || related.file === void 0 || related.start === void 0 || related.length === void 0)
                return;
            let declaration = findAncestorMatchingSpan(related.file, createTextSpan(related.start, related.length));
            if (declaration === void 0)
                return;
            if (isIdentifier(declaration) && isTypeParameterDeclaration(declaration.parent)) {
                declaration = declaration.parent;
            }
            if (isTypeParameterDeclaration(declaration)) {
                if (isMappedTypeNode(declaration.parent))
                    return;
                const token = getTokenAtPosition(sourceFile, span.start);
                const checker = program.getTypeChecker();
                const constraint = tryGetConstraintType(checker, token) || tryGetConstraintFromDiagnosticMessage(related.messageText);
                return { constraint, declaration, token };
            }
            return void 0;
        }
        function addMissingConstraint(changes, program, preferences, host, sourceFile, info) {
            const { declaration, constraint } = info;
            const checker = program.getTypeChecker();
            if (isString(constraint)) {
                changes.insertText(sourceFile, declaration.name.end, ` extends ${constraint}`);
            }
            else {
                const scriptTarget = getEmitScriptTarget(program.getCompilerOptions());
                const tracker = getNoopSymbolTrackerWithResolver({ program, host });
                const importAdder = createImportAdder(sourceFile, program, preferences, host);
                const typeNode = typeToAutoImportableTypeNode(checker, importAdder, constraint, 
                /*contextNode*/
                void 0, scriptTarget, 
                /*flags*/
                void 0, tracker);
                if (typeNode) {
                    changes.replaceNode(sourceFile, declaration, factory.updateTypeParameterDeclaration(declaration, 
                    /*modifiers*/
                    void 0, declaration.name, typeNode, declaration.default));
                    importAdder.writeFixes(changes);
                }
            }
        }
        function tryGetConstraintFromDiagnosticMessage(messageText) {
            const [, constraint] = flattenDiagnosticMessageText(messageText, "\n", 0).match(/`extends (.*)`/) || [];
            return constraint;
        }
        function tryGetConstraintType(checker, node) {
            if (isTypeNode(node.parent)) {
                return checker.getTypeArgumentConstraint(node.parent);
            }
            const contextualType = isExpression(node) ? checker.getContextualType(node) : void 0;
            return contextualType || checker.getTypeAtLocation(node);
        }
        var fixId17, errorCodes19;
        var init_fixAddMissingConstraint = __esm({
            "src/services/codefixes/fixAddMissingConstraint.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId17 = "addMissingConstraint";
                errorCodes19 = [
                    // We want errors this could be attached to:
                    // Diagnostics.This_type_parameter_probably_needs_an_extends_0_constraint
                    Diagnostics.Type_0_is_not_comparable_to_type_1.code,
                    Diagnostics.Type_0_is_not_assignable_to_type_1_Two_different_types_with_this_name_exist_but_they_are_unrelated.code,
                    Diagnostics.Type_0_is_not_assignable_to_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_types_of_the_target_s_properties.code,
                    Diagnostics.Type_0_is_not_assignable_to_type_1.code,
                    Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1_with_exactOptionalPropertyTypes_Colon_true_Consider_adding_undefined_to_the_types_of_the_target_s_properties.code,
                    Diagnostics.Property_0_is_incompatible_with_index_signature.code,
                    Diagnostics.Property_0_in_type_1_is_not_assignable_to_type_2.code,
                    Diagnostics.Type_0_does_not_satisfy_the_constraint_1.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes19,
                    getCodeActions(context) {
                        const { sourceFile, span, program, preferences, host } = context;
                        const info = getInfo6(program, sourceFile, span);
                        if (info === void 0)
                            return;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => addMissingConstraint(t, program, preferences, host, sourceFile, info));
                        return [createCodeFixAction(fixId17, changes, Diagnostics.Add_extends_constraint, fixId17, Diagnostics.Add_extends_constraint_to_all_type_parameters)];
                    },
                    fixIds: [fixId17],
                    getAllCodeActions: (context) => {
                        const { program, preferences, host } = context;
                        const seen = /* @__PURE__ */ new Map();
                        return createCombinedCodeActions(ts_textChanges_exports.ChangeTracker.with(context, (changes) => {
                            eachDiagnostic(context, errorCodes19, (diag2) => {
                                const info = getInfo6(program, diag2.file, createTextSpan(diag2.start, diag2.length));
                                if (info) {
                                    if (addToSeen(seen, getNodeId(info.declaration))) {
                                        return addMissingConstraint(changes, program, preferences, host, diag2.file, info);
                                    }
                                }
                                return void 0;
                            });
                        }));
                    }
                });
            }
        });
        // src/services/codefixes/fixOverrideModifier.ts
        function dispatchChanges(changeTracker, context, errorCode, pos) {
            switch (errorCode) {
                case Diagnostics.This_member_must_have_an_override_modifier_because_it_overrides_a_member_in_the_base_class_0.code:
                case Diagnostics.This_member_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_in_the_base_class_0.code:
                case Diagnostics.This_member_must_have_an_override_modifier_because_it_overrides_an_abstract_method_that_is_declared_in_the_base_class_0.code:
                case Diagnostics.This_parameter_property_must_have_an_override_modifier_because_it_overrides_a_member_in_base_class_0.code:
                case Diagnostics.This_parameter_property_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_in_the_base_class_0.code:
                    return doAddOverrideModifierChange(changeTracker, context.sourceFile, pos);
                case Diagnostics.This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0.code:
                case Diagnostics.This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_it_is_not_declared_in_the_base_class_0.code:
                case Diagnostics.This_member_cannot_have_an_override_modifier_because_its_containing_class_0_does_not_extend_another_class.code:
                case Diagnostics.This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_its_containing_class_0_does_not_extend_another_class.code:
                    return doRemoveOverrideModifierChange(changeTracker, context.sourceFile, pos);
                default:
                    Debug.fail("Unexpected error code: " + errorCode);
            }
        }
        function doAddOverrideModifierChange(changeTracker, sourceFile, pos) {
            const classElement = findContainerClassElementLike(sourceFile, pos);
            if (isSourceFileJS(sourceFile)) {
                changeTracker.addJSDocTags(sourceFile, classElement, [factory.createJSDocOverrideTag(factory.createIdentifier("override"))]);
                return;
            }
            const modifiers = classElement.modifiers || emptyArray;
            const staticModifier = find(modifiers, isStaticModifier);
            const abstractModifier = find(modifiers, isAbstractModifier);
            const accessibilityModifier = find(modifiers, (m) => isAccessibilityModifier(m.kind));
            const lastDecorator = findLast(modifiers, isDecorator);
            const modifierPos = abstractModifier ? abstractModifier.end : staticModifier ? staticModifier.end : accessibilityModifier ? accessibilityModifier.end : lastDecorator ? skipTrivia(sourceFile.text, lastDecorator.end) : classElement.getStart(sourceFile);
            const options = accessibilityModifier || staticModifier || abstractModifier ? { prefix: " " } : { suffix: " " };
            changeTracker.insertModifierAt(sourceFile, modifierPos, 164 /* OverrideKeyword */, options);
        }
        function doRemoveOverrideModifierChange(changeTracker, sourceFile, pos) {
            const classElement = findContainerClassElementLike(sourceFile, pos);
            if (isSourceFileJS(sourceFile)) {
                changeTracker.filterJSDocTags(sourceFile, classElement, not(isJSDocOverrideTag));
                return;
            }
            const overrideModifier = find(classElement.modifiers, isOverrideModifier);
            Debug.assertIsDefined(overrideModifier);
            changeTracker.deleteModifier(sourceFile, overrideModifier);
        }
        function isClassElementLikeHasJSDoc(node) {
            switch (node.kind) {
                case 176 /* Constructor */:
                case 172 /* PropertyDeclaration */:
                case 174 /* MethodDeclaration */:
                case 177 /* GetAccessor */:
                case 178 /* SetAccessor */:
                    return true;
                case 169 /* Parameter */:
                    return isParameterPropertyDeclaration(node, node.parent);
                default:
                    return false;
            }
        }
        function findContainerClassElementLike(sourceFile, pos) {
            const token = getTokenAtPosition(sourceFile, pos);
            const classElement = findAncestor(token, (node) => {
                if (isClassLike(node))
                    return "quit";
                return isClassElementLikeHasJSDoc(node);
            });
            Debug.assert(classElement && isClassElementLikeHasJSDoc(classElement));
            return classElement;
        }
        var fixName, fixAddOverrideId, fixRemoveOverrideId, errorCodes20, errorCodeFixIdMap;
        var init_fixOverrideModifier = __esm({
            "src/services/codefixes/fixOverrideModifier.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixName = "fixOverrideModifier";
                fixAddOverrideId = "fixAddOverrideModifier";
                fixRemoveOverrideId = "fixRemoveOverrideModifier";
                errorCodes20 = [
                    Diagnostics.This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0.code,
                    Diagnostics.This_member_cannot_have_an_override_modifier_because_its_containing_class_0_does_not_extend_another_class.code,
                    Diagnostics.This_member_must_have_an_override_modifier_because_it_overrides_an_abstract_method_that_is_declared_in_the_base_class_0.code,
                    Diagnostics.This_member_must_have_an_override_modifier_because_it_overrides_a_member_in_the_base_class_0.code,
                    Diagnostics.This_parameter_property_must_have_an_override_modifier_because_it_overrides_a_member_in_base_class_0.code,
                    Diagnostics.This_member_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_in_the_base_class_0.code,
                    Diagnostics.This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_its_containing_class_0_does_not_extend_another_class.code,
                    Diagnostics.This_parameter_property_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_in_the_base_class_0.code,
                    Diagnostics.This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_it_is_not_declared_in_the_base_class_0.code
                ];
                errorCodeFixIdMap = {
                    // case #1:
                    [Diagnostics.This_member_must_have_an_override_modifier_because_it_overrides_a_member_in_the_base_class_0.code]: {
                        descriptions: Diagnostics.Add_override_modifier,
                        fixId: fixAddOverrideId,
                        fixAllDescriptions: Diagnostics.Add_all_missing_override_modifiers
                    },
                    [Diagnostics.This_member_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_in_the_base_class_0.code]: {
                        descriptions: Diagnostics.Add_override_modifier,
                        fixId: fixAddOverrideId,
                        fixAllDescriptions: Diagnostics.Add_all_missing_override_modifiers
                    },
                    // case #2:
                    [Diagnostics.This_member_cannot_have_an_override_modifier_because_its_containing_class_0_does_not_extend_another_class.code]: {
                        descriptions: Diagnostics.Remove_override_modifier,
                        fixId: fixRemoveOverrideId,
                        fixAllDescriptions: Diagnostics.Remove_all_unnecessary_override_modifiers
                    },
                    [Diagnostics.This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_its_containing_class_0_does_not_extend_another_class.code]: {
                        descriptions: Diagnostics.Remove_override_modifier,
                        fixId: fixRemoveOverrideId,
                        fixAllDescriptions: Diagnostics.Remove_override_modifier
                    },
                    // case #3:
                    [Diagnostics.This_parameter_property_must_have_an_override_modifier_because_it_overrides_a_member_in_base_class_0.code]: {
                        descriptions: Diagnostics.Add_override_modifier,
                        fixId: fixAddOverrideId,
                        fixAllDescriptions: Diagnostics.Add_all_missing_override_modifiers
                    },
                    [Diagnostics.This_parameter_property_must_have_a_JSDoc_comment_with_an_override_tag_because_it_overrides_a_member_in_the_base_class_0.code]: {
                        descriptions: Diagnostics.Add_override_modifier,
                        fixId: fixAddOverrideId,
                        fixAllDescriptions: Diagnostics.Add_all_missing_override_modifiers
                    },
                    // case #4:
                    [Diagnostics.This_member_must_have_an_override_modifier_because_it_overrides_an_abstract_method_that_is_declared_in_the_base_class_0.code]: {
                        descriptions: Diagnostics.Add_override_modifier,
                        fixId: fixAddOverrideId,
                        fixAllDescriptions: Diagnostics.Remove_all_unnecessary_override_modifiers
                    },
                    // case #5:
                    [Diagnostics.This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0.code]: {
                        descriptions: Diagnostics.Remove_override_modifier,
                        fixId: fixRemoveOverrideId,
                        fixAllDescriptions: Diagnostics.Remove_all_unnecessary_override_modifiers
                    },
                    [Diagnostics.This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_it_is_not_declared_in_the_base_class_0.code]: {
                        descriptions: Diagnostics.Remove_override_modifier,
                        fixId: fixRemoveOverrideId,
                        fixAllDescriptions: Diagnostics.Remove_all_unnecessary_override_modifiers
                    }
                };
                registerCodeFix({
                    errorCodes: errorCodes20,
                    getCodeActions: function getCodeActionsToFixOverrideModifierIssues(context) {
                        const { errorCode, span } = context;
                        const info = errorCodeFixIdMap[errorCode];
                        if (!info)
                            return emptyArray;
                        const { descriptions, fixId: fixId52, fixAllDescriptions } = info;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (changes2) => dispatchChanges(changes2, context, errorCode, span.start));
                        return [
                            createCodeFixActionMaybeFixAll(fixName, changes, descriptions, fixId52, fixAllDescriptions)
                        ];
                    },
                    fixIds: [fixName, fixAddOverrideId, fixRemoveOverrideId],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes20, (changes, diag2) => {
                        const { code, start } = diag2;
                        const info = errorCodeFixIdMap[code];
                        if (!info || info.fixId !== context.fixId) {
                            return;
                        }
                        dispatchChanges(changes, context, code, start);
                    })
                });
            }
        });
        // src/services/codefixes/fixNoPropertyAccessFromIndexSignature.ts
        function doChange14(changes, sourceFile, node, preferences) {
            const quotePreference = getQuotePreference(sourceFile, preferences);
            const argumentsExpression = factory.createStringLiteral(node.name.text, quotePreference === 0 /* Single */);
            changes.replaceNode(sourceFile, node, isPropertyAccessChain(node) ? factory.createElementAccessChain(node.expression, node.questionDotToken, argumentsExpression) : factory.createElementAccessExpression(node.expression, argumentsExpression));
        }
        function getPropertyAccessExpression(sourceFile, pos) {
            return cast(getTokenAtPosition(sourceFile, pos).parent, isPropertyAccessExpression);
        }
        var fixId18, errorCodes21;
        var init_fixNoPropertyAccessFromIndexSignature = __esm({
            "src/services/codefixes/fixNoPropertyAccessFromIndexSignature.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId18 = "fixNoPropertyAccessFromIndexSignature";
                errorCodes21 = [
                    Diagnostics.Property_0_comes_from_an_index_signature_so_it_must_be_accessed_with_0.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes21,
                    fixIds: [fixId18],
                    getCodeActions(context) {
                        const { sourceFile, span, preferences } = context;
                        const property = getPropertyAccessExpression(sourceFile, span.start);
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange14(t, context.sourceFile, property, preferences));
                        return [createCodeFixAction(fixId18, changes, [Diagnostics.Use_element_access_for_0, property.name.text], fixId18, Diagnostics.Use_element_access_for_all_undeclared_properties)];
                    },
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes21, (changes, diag2) => doChange14(changes, diag2.file, getPropertyAccessExpression(diag2.file, diag2.start), context.preferences))
                });
            }
        });
        // src/services/codefixes/fixImplicitThis.ts
        function doChange15(changes, sourceFile, pos, checker) {
            const token = getTokenAtPosition(sourceFile, pos);
            if (!isThis(token))
                return void 0;
            const fn = getThisContainer(token, 
            /*includeArrowFunctions*/
            false, 
            /*includeClassComputedPropertyName*/
            false);
            if (!isFunctionDeclaration(fn) && !isFunctionExpression(fn))
                return void 0;
            if (!isSourceFile(getThisContainer(fn, 
            /*includeArrowFunctions*/
            false, 
            /*includeClassComputedPropertyName*/
            false))) {
                const fnKeyword = Debug.checkDefined(findChildOfKind(fn, 100 /* FunctionKeyword */, sourceFile));
                const { name } = fn;
                const body = Debug.checkDefined(fn.body);
                if (isFunctionExpression(fn)) {
                    if (name && ts_FindAllReferences_exports.Core.isSymbolReferencedInFile(name, checker, sourceFile, body)) {
                        return void 0;
                    }
                    changes.delete(sourceFile, fnKeyword);
                    if (name) {
                        changes.delete(sourceFile, name);
                    }
                    changes.insertText(sourceFile, body.pos, " =>");
                    return [Diagnostics.Convert_function_expression_0_to_arrow_function, name ? name.text : ANONYMOUS];
                }
                else {
                    changes.replaceNode(sourceFile, fnKeyword, factory.createToken(87 /* ConstKeyword */));
                    changes.insertText(sourceFile, name.end, " = ");
                    changes.insertText(sourceFile, body.pos, " =>");
                    return [Diagnostics.Convert_function_declaration_0_to_arrow_function, name.text];
                }
            }
        }
        var fixId19, errorCodes22;
        var init_fixImplicitThis = __esm({
            "src/services/codefixes/fixImplicitThis.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId19 = "fixImplicitThis";
                errorCodes22 = [Diagnostics.this_implicitly_has_type_any_because_it_does_not_have_a_type_annotation.code];
                registerCodeFix({
                    errorCodes: errorCodes22,
                    getCodeActions: function getCodeActionsToFixImplicitThis(context) {
                        const { sourceFile, program, span } = context;
                        let diagnostic;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => {
                            diagnostic = doChange15(t, sourceFile, span.start, program.getTypeChecker());
                        });
                        return diagnostic ? [createCodeFixAction(fixId19, changes, diagnostic, fixId19, Diagnostics.Fix_all_implicit_this_errors)] : emptyArray;
                    },
                    fixIds: [fixId19],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes22, (changes, diag2) => {
                        doChange15(changes, diag2.file, diag2.start, context.program.getTypeChecker());
                    })
                });
            }
        });
        // src/services/codefixes/fixImportNonExportedMember.ts
        function getInfo7(sourceFile, pos, program) {
            var _a, _b;
            const token = getTokenAtPosition(sourceFile, pos);
            if (isIdentifier(token)) {
                const importDeclaration = findAncestor(token, isImportDeclaration);
                if (importDeclaration === void 0)
                    return void 0;
                const moduleSpecifier = isStringLiteral(importDeclaration.moduleSpecifier) ? importDeclaration.moduleSpecifier : void 0;
                if (moduleSpecifier === void 0)
                    return void 0;
                const resolvedModule = (_a = program.getResolvedModuleFromModuleSpecifier(moduleSpecifier)) == null ? void 0 : _a.resolvedModule;
                if (resolvedModule === void 0)
                    return void 0;
                const moduleSourceFile = program.getSourceFile(resolvedModule.resolvedFileName);
                if (moduleSourceFile === void 0 || isSourceFileFromLibrary(program, moduleSourceFile))
                    return void 0;
                const moduleSymbol = moduleSourceFile.symbol;
                const locals = (_b = tryCast(moduleSymbol.valueDeclaration, canHaveLocals)) == null ? void 0 : _b.locals;
                if (locals === void 0)
                    return void 0;
                const localSymbol = locals.get(token.escapedText);
                if (localSymbol === void 0)
                    return void 0;
                const node = getNodeOfSymbol(localSymbol);
                if (node === void 0)
                    return void 0;
                const exportName = { node: token, isTypeOnly: isTypeDeclaration(node) };
                return { exportName, node, moduleSourceFile, moduleSpecifier: moduleSpecifier.text };
            }
            return void 0;
        }
        function doChange16(changes, program, { exportName, node, moduleSourceFile }) {
            const exportDeclaration = tryGetExportDeclaration(moduleSourceFile, exportName.isTypeOnly);
            if (exportDeclaration) {
                updateExport(changes, program, moduleSourceFile, exportDeclaration, [exportName]);
            }
            else if (canHaveExportModifier(node)) {
                changes.insertExportModifier(moduleSourceFile, node);
            }
            else {
                createExport(changes, program, moduleSourceFile, [exportName]);
            }
        }
        function doChanges(changes, program, sourceFile, moduleExports, node) {
            if (length(moduleExports)) {
                if (node) {
                    updateExport(changes, program, sourceFile, node, moduleExports);
                }
                else {
                    createExport(changes, program, sourceFile, moduleExports);
                }
            }
        }
        function tryGetExportDeclaration(sourceFile, isTypeOnly) {
            const predicate = (node) => isExportDeclaration(node) && (isTypeOnly && node.isTypeOnly || !node.isTypeOnly);
            return findLast(sourceFile.statements, predicate);
        }
        function updateExport(changes, program, sourceFile, node, names) {
            const namedExports = node.exportClause && isNamedExports(node.exportClause) ? node.exportClause.elements : factory.createNodeArray([]);
            const allowTypeModifier = !node.isTypeOnly && !!(getIsolatedModules(program.getCompilerOptions()) || find(namedExports, (e) => e.isTypeOnly));
            changes.replaceNode(sourceFile, node, factory.updateExportDeclaration(node, node.modifiers, node.isTypeOnly, factory.createNamedExports(factory.createNodeArray([...namedExports, ...createExportSpecifiers(names, allowTypeModifier)], 
            /*hasTrailingComma*/
            namedExports.hasTrailingComma)), node.moduleSpecifier, node.attributes));
        }
        function createExport(changes, program, sourceFile, names) {
            changes.insertNodeAtEndOfScope(sourceFile, sourceFile, factory.createExportDeclaration(
            /*modifiers*/
            void 0, 
            /*isTypeOnly*/
            false, factory.createNamedExports(createExportSpecifiers(names, 
            /*allowTypeModifier*/
            getIsolatedModules(program.getCompilerOptions()))), 
            /*moduleSpecifier*/
            void 0, 
            /*attributes*/
            void 0));
        }
        function createExportSpecifiers(names, allowTypeModifier) {
            return factory.createNodeArray(map(names, (n) => factory.createExportSpecifier(allowTypeModifier && n.isTypeOnly, 
            /*propertyName*/
            void 0, n.node)));
        }
        function getNodeOfSymbol(symbol) {
            if (symbol.valueDeclaration === void 0) {
                return firstOrUndefined(symbol.declarations);
            }
            const declaration = symbol.valueDeclaration;
            const variableStatement = isVariableDeclaration(declaration) ? tryCast(declaration.parent.parent, isVariableStatement) : void 0;
            return variableStatement && length(variableStatement.declarationList.declarations) === 1 ? variableStatement : declaration;
        }
        var fixId20, errorCodes23;
        var init_fixImportNonExportedMember = __esm({
            "src/services/codefixes/fixImportNonExportedMember.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId20 = "fixImportNonExportedMember";
                errorCodes23 = [
                    Diagnostics.Module_0_declares_1_locally_but_it_is_not_exported.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes23,
                    fixIds: [fixId20],
                    getCodeActions(context) {
                        const { sourceFile, span, program } = context;
                        const info = getInfo7(sourceFile, span.start, program);
                        if (info === void 0)
                            return void 0;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange16(t, program, info));
                        return [createCodeFixAction(fixId20, changes, [Diagnostics.Export_0_from_module_1, info.exportName.node.text, info.moduleSpecifier], fixId20, Diagnostics.Export_all_referenced_locals)];
                    },
                    getAllCodeActions(context) {
                        const { program } = context;
                        return createCombinedCodeActions(ts_textChanges_exports.ChangeTracker.with(context, (changes) => {
                            const exports = /* @__PURE__ */ new Map();
                            eachDiagnostic(context, errorCodes23, (diag2) => {
                                const info = getInfo7(diag2.file, diag2.start, program);
                                if (info === void 0)
                                    return void 0;
                                const { exportName, node, moduleSourceFile } = info;
                                if (tryGetExportDeclaration(moduleSourceFile, exportName.isTypeOnly) === void 0 && canHaveExportModifier(node)) {
                                    changes.insertExportModifier(moduleSourceFile, node);
                                }
                                else {
                                    const moduleExports = exports.get(moduleSourceFile) || { typeOnlyExports: [], exports: [] };
                                    if (exportName.isTypeOnly) {
                                        moduleExports.typeOnlyExports.push(exportName);
                                    }
                                    else {
                                        moduleExports.exports.push(exportName);
                                    }
                                    exports.set(moduleSourceFile, moduleExports);
                                }
                            });
                            exports.forEach((moduleExports, moduleSourceFile) => {
                                const exportDeclaration = tryGetExportDeclaration(moduleSourceFile, 
                                /*isTypeOnly*/
                                true);
                                if (exportDeclaration && exportDeclaration.isTypeOnly) {
                                    doChanges(changes, program, moduleSourceFile, moduleExports.typeOnlyExports, exportDeclaration);
                                    doChanges(changes, program, moduleSourceFile, moduleExports.exports, tryGetExportDeclaration(moduleSourceFile, 
                                    /*isTypeOnly*/
                                    false));
                                }
                                else {
                                    doChanges(changes, program, moduleSourceFile, [...moduleExports.exports, ...moduleExports.typeOnlyExports], exportDeclaration);
                                }
                            });
                        }));
                    }
                });
            }
        });
        // src/services/codefixes/fixIncorrectNamedTupleSyntax.ts
        function getNamedTupleMember(sourceFile, pos) {
            const token = getTokenAtPosition(sourceFile, pos);
            return findAncestor(token, (t) => t.kind === 202 /* NamedTupleMember */);
        }
        function doChange17(changes, sourceFile, namedTupleMember) {
            if (!namedTupleMember) {
                return;
            }
            let unwrappedType = namedTupleMember.type;
            let sawOptional = false;
            let sawRest = false;
            while (unwrappedType.kind === 190 /* OptionalType */ || unwrappedType.kind === 191 /* RestType */ || unwrappedType.kind === 196 /* ParenthesizedType */) {
                if (unwrappedType.kind === 190 /* OptionalType */) {
                    sawOptional = true;
                }
                else if (unwrappedType.kind === 191 /* RestType */) {
                    sawRest = true;
                }
                unwrappedType = unwrappedType.type;
            }
            const updated = factory.updateNamedTupleMember(namedTupleMember, namedTupleMember.dotDotDotToken || (sawRest ? factory.createToken(26 /* DotDotDotToken */) : void 0), namedTupleMember.name, namedTupleMember.questionToken || (sawOptional ? factory.createToken(58 /* QuestionToken */) : void 0), unwrappedType);
            if (updated === namedTupleMember) {
                return;
            }
            changes.replaceNode(sourceFile, namedTupleMember, updated);
        }
        var fixId21, errorCodes24;
        var init_fixIncorrectNamedTupleSyntax = __esm({
            "src/services/codefixes/fixIncorrectNamedTupleSyntax.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId21 = "fixIncorrectNamedTupleSyntax";
                errorCodes24 = [
                    Diagnostics.A_labeled_tuple_element_is_declared_as_optional_with_a_question_mark_after_the_name_and_before_the_colon_rather_than_after_the_type.code,
                    Diagnostics.A_labeled_tuple_element_is_declared_as_rest_with_a_before_the_name_rather_than_before_the_type.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes24,
                    getCodeActions: function getCodeActionsToFixIncorrectNamedTupleSyntax(context) {
                        const { sourceFile, span } = context;
                        const namedTupleMember = getNamedTupleMember(sourceFile, span.start);
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange17(t, sourceFile, namedTupleMember));
                        return [createCodeFixAction(fixId21, changes, Diagnostics.Move_labeled_tuple_element_modifiers_to_labels, fixId21, Diagnostics.Move_labeled_tuple_element_modifiers_to_labels)];
                    },
                    fixIds: [fixId21]
                });
            }
        });
        // src/services/codefixes/fixSpelling.ts
        function getInfo8(sourceFile, pos, context, errorCode) {
            const node = getTokenAtPosition(sourceFile, pos);
            const parent2 = node.parent;
            if ((errorCode === Diagnostics.No_overload_matches_this_call.code || errorCode === Diagnostics.Type_0_is_not_assignable_to_type_1.code) && !isJsxAttribute(parent2))
                return void 0;
            const checker = context.program.getTypeChecker();
            let suggestedSymbol;
            if (isPropertyAccessExpression(parent2) && parent2.name === node) {
                Debug.assert(isMemberName(node), "Expected an identifier for spelling (property access)");
                let containingType = checker.getTypeAtLocation(parent2.expression);
                if (parent2.flags & 64 /* OptionalChain */) {
                    containingType = checker.getNonNullableType(containingType);
                }
                suggestedSymbol = checker.getSuggestedSymbolForNonexistentProperty(node, containingType);
            }
            else if (isBinaryExpression(parent2) && parent2.operatorToken.kind === 103 /* InKeyword */ && parent2.left === node && isPrivateIdentifier(node)) {
                const receiverType = checker.getTypeAtLocation(parent2.right);
                suggestedSymbol = checker.getSuggestedSymbolForNonexistentProperty(node, receiverType);
            }
            else if (isQualifiedName(parent2) && parent2.right === node) {
                const symbol = checker.getSymbolAtLocation(parent2.left);
                if (symbol && symbol.flags & 1536 /* Module */) {
                    suggestedSymbol = checker.getSuggestedSymbolForNonexistentModule(parent2.right, symbol);
                }
            }
            else if (isImportSpecifier(parent2) && parent2.name === node) {
                Debug.assertNode(node, isIdentifier, "Expected an identifier for spelling (import)");
                const importDeclaration = findAncestor(node, isImportDeclaration);
                const resolvedSourceFile = getResolvedSourceFileFromImportDeclaration(context, importDeclaration);
                if (resolvedSourceFile && resolvedSourceFile.symbol) {
                    suggestedSymbol = checker.getSuggestedSymbolForNonexistentModule(node, resolvedSourceFile.symbol);
                }
            }
            else if (isJsxAttribute(parent2) && parent2.name === node) {
                Debug.assertNode(node, isIdentifier, "Expected an identifier for JSX attribute");
                const tag = findAncestor(node, isJsxOpeningLikeElement);
                const props = checker.getContextualTypeForArgumentAtIndex(tag, 0);
                suggestedSymbol = checker.getSuggestedSymbolForNonexistentJSXAttribute(node, props);
            }
            else if (hasOverrideModifier(parent2) && isClassElement(parent2) && parent2.name === node) {
                const baseDeclaration = findAncestor(node, isClassLike);
                const baseTypeNode = baseDeclaration ? getEffectiveBaseTypeNode(baseDeclaration) : void 0;
                const baseType = baseTypeNode ? checker.getTypeAtLocation(baseTypeNode) : void 0;
                if (baseType) {
                    suggestedSymbol = checker.getSuggestedSymbolForNonexistentClassMember(getTextOfNode(node), baseType);
                }
            }
            else {
                const meaning = getMeaningFromLocation(node);
                const name = getTextOfNode(node);
                Debug.assert(name !== void 0, "name should be defined");
                suggestedSymbol = checker.getSuggestedSymbolForNonexistentSymbol(node, name, convertSemanticMeaningToSymbolFlags(meaning));
            }
            return suggestedSymbol === void 0 ? void 0 : { node, suggestedSymbol };
        }
        function doChange18(changes, sourceFile, node, suggestedSymbol, target) {
            const suggestion = symbolName(suggestedSymbol);
            if (!isIdentifierText(suggestion, target) && isPropertyAccessExpression(node.parent)) {
                const valDecl = suggestedSymbol.valueDeclaration;
                if (valDecl && isNamedDeclaration(valDecl) && isPrivateIdentifier(valDecl.name)) {
                    changes.replaceNode(sourceFile, node, factory.createIdentifier(suggestion));
                }
                else {
                    changes.replaceNode(sourceFile, node.parent, factory.createElementAccessExpression(node.parent.expression, factory.createStringLiteral(suggestion)));
                }
            }
            else {
                changes.replaceNode(sourceFile, node, factory.createIdentifier(suggestion));
            }
        }
        function convertSemanticMeaningToSymbolFlags(meaning) {
            let flags = 0;
            if (meaning & 4 /* Namespace */) {
                flags |= 1920 /* Namespace */;
            }
            if (meaning & 2 /* Type */) {
                flags |= 788968 /* Type */;
            }
            if (meaning & 1 /* Value */) {
                flags |= 111551 /* Value */;
            }
            return flags;
        }
        function getResolvedSourceFileFromImportDeclaration(context, importDeclaration) {
            var _a;
            if (!importDeclaration || !isStringLiteralLike(importDeclaration.moduleSpecifier))
                return void 0;
            const resolvedModule = (_a = context.program.getResolvedModuleFromModuleSpecifier(importDeclaration.moduleSpecifier)) == null ? void 0 : _a.resolvedModule;
            if (!resolvedModule)
                return void 0;
            return context.program.getSourceFile(resolvedModule.resolvedFileName);
        }
        var fixId22, errorCodes25;
        var init_fixSpelling = __esm({
            "src/services/codefixes/fixSpelling.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId22 = "fixSpelling";
                errorCodes25 = [
                    Diagnostics.Property_0_does_not_exist_on_type_1_Did_you_mean_2.code,
                    Diagnostics.Property_0_may_not_exist_on_type_1_Did_you_mean_2.code,
                    Diagnostics.Cannot_find_name_0_Did_you_mean_1.code,
                    Diagnostics.Could_not_find_name_0_Did_you_mean_1.code,
                    Diagnostics.Cannot_find_namespace_0_Did_you_mean_1.code,
                    Diagnostics.Cannot_find_name_0_Did_you_mean_the_instance_member_this_0.code,
                    Diagnostics.Cannot_find_name_0_Did_you_mean_the_static_member_1_0.code,
                    Diagnostics._0_has_no_exported_member_named_1_Did_you_mean_2.code,
                    Diagnostics.This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0_Did_you_mean_1.code,
                    Diagnostics.This_member_cannot_have_a_JSDoc_comment_with_an_override_tag_because_it_is_not_declared_in_the_base_class_0_Did_you_mean_1.code,
                    // for JSX class components
                    Diagnostics.No_overload_matches_this_call.code,
                    // for JSX FC
                    Diagnostics.Type_0_is_not_assignable_to_type_1.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes25,
                    getCodeActions(context) {
                        const { sourceFile, errorCode } = context;
                        const info = getInfo8(sourceFile, context.span.start, context, errorCode);
                        if (!info)
                            return void 0;
                        const { node, suggestedSymbol } = info;
                        const target = getEmitScriptTarget(context.host.getCompilationSettings());
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange18(t, sourceFile, node, suggestedSymbol, target));
                        return [createCodeFixAction("spelling", changes, [Diagnostics.Change_spelling_to_0, symbolName(suggestedSymbol)], fixId22, Diagnostics.Fix_all_detected_spelling_errors)];
                    },
                    fixIds: [fixId22],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes25, (changes, diag2) => {
                        const info = getInfo8(diag2.file, diag2.start, context, diag2.code);
                        const target = getEmitScriptTarget(context.host.getCompilationSettings());
                        if (info)
                            doChange18(changes, context.sourceFile, info.node, info.suggestedSymbol, target);
                    })
                });
            }
        });
        // src/services/codefixes/returnValueCorrect.ts
        function createObjectTypeFromLabeledExpression(checker, label, expression) {
            const member = checker.createSymbol(4 /* Property */, label.escapedText);
            member.links.type = checker.getTypeAtLocation(expression);
            const members = createSymbolTable([member]);
            return checker.createAnonymousType(
            /*symbol*/
            void 0, members, [], [], []);
        }
        function getFixInfo(checker, declaration, expectType, isFunctionType) {
            if (!declaration.body || !isBlock(declaration.body) || length(declaration.body.statements) !== 1)
                return void 0;
            const firstStatement = first(declaration.body.statements);
            if (isExpressionStatement(firstStatement) && checkFixedAssignableTo(checker, declaration, checker.getTypeAtLocation(firstStatement.expression), expectType, isFunctionType)) {
                return {
                    declaration,
                    kind: 0 /* MissingReturnStatement */,
                    expression: firstStatement.expression,
                    statement: firstStatement,
                    commentSource: firstStatement.expression
                };
            }
            else if (isLabeledStatement(firstStatement) && isExpressionStatement(firstStatement.statement)) {
                const node = factory.createObjectLiteralExpression([factory.createPropertyAssignment(firstStatement.label, firstStatement.statement.expression)]);
                const nodeType = createObjectTypeFromLabeledExpression(checker, firstStatement.label, firstStatement.statement.expression);
                if (checkFixedAssignableTo(checker, declaration, nodeType, expectType, isFunctionType)) {
                    return isArrowFunction(declaration) ? {
                        declaration,
                        kind: 1 /* MissingParentheses */,
                        expression: node,
                        statement: firstStatement,
                        commentSource: firstStatement.statement.expression
                    } : {
                        declaration,
                        kind: 0 /* MissingReturnStatement */,
                        expression: node,
                        statement: firstStatement,
                        commentSource: firstStatement.statement.expression
                    };
                }
            }
            else if (isBlock(firstStatement) && length(firstStatement.statements) === 1) {
                const firstBlockStatement = first(firstStatement.statements);
                if (isLabeledStatement(firstBlockStatement) && isExpressionStatement(firstBlockStatement.statement)) {
                    const node = factory.createObjectLiteralExpression([factory.createPropertyAssignment(firstBlockStatement.label, firstBlockStatement.statement.expression)]);
                    const nodeType = createObjectTypeFromLabeledExpression(checker, firstBlockStatement.label, firstBlockStatement.statement.expression);
                    if (checkFixedAssignableTo(checker, declaration, nodeType, expectType, isFunctionType)) {
                        return {
                            declaration,
                            kind: 0 /* MissingReturnStatement */,
                            expression: node,
                            statement: firstStatement,
                            commentSource: firstBlockStatement
                        };
                    }
                }
            }
            return void 0;
        }
        function checkFixedAssignableTo(checker, declaration, exprType, type, isFunctionType) {
            if (isFunctionType) {
                const sig = checker.getSignatureFromDeclaration(declaration);
                if (sig) {
                    if (hasSyntacticModifier(declaration, 1024 /* Async */)) {
                        exprType = checker.createPromiseType(exprType);
                    }
                    const newSig = checker.createSignature(declaration, sig.typeParameters, sig.thisParameter, sig.parameters, exprType, 
                    /*typePredicate*/
                    void 0, sig.minArgumentCount, sig.flags);
                    exprType = checker.createAnonymousType(
                    /*symbol*/
                    void 0, createSymbolTable(), [newSig], [], []);
                }
                else {
                    exprType = checker.getAnyType();
                }
            }
            return checker.isTypeAssignableTo(exprType, type);
        }
        function getInfo9(checker, sourceFile, position, errorCode) {
            const node = getTokenAtPosition(sourceFile, position);
            if (!node.parent)
                return void 0;
            const declaration = findAncestor(node.parent, isFunctionLikeDeclaration);
            switch (errorCode) {
                case Diagnostics.A_function_whose_declared_type_is_neither_undefined_void_nor_any_must_return_a_value.code:
                    if (!declaration || !declaration.body || !declaration.type || !rangeContainsRange(declaration.type, node))
                        return void 0;
                    return getFixInfo(checker, declaration, checker.getTypeFromTypeNode(declaration.type), 
                    /*isFunctionType*/
                    false);
                case Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1.code:
                    if (!declaration || !isCallExpression(declaration.parent) || !declaration.body)
                        return void 0;
                    const pos = declaration.parent.arguments.indexOf(declaration);
                    if (pos === -1)
                        return void 0;
                    const type = checker.getContextualTypeForArgumentAtIndex(declaration.parent, pos);
                    if (!type)
                        return void 0;
                    return getFixInfo(checker, declaration, type, 
                    /*isFunctionType*/
                    true);
                case Diagnostics.Type_0_is_not_assignable_to_type_1.code:
                    if (!isDeclarationName(node) || !isVariableLike(node.parent) && !isJsxAttribute(node.parent))
                        return void 0;
                    const initializer = getVariableLikeInitializer(node.parent);
                    if (!initializer || !isFunctionLikeDeclaration(initializer) || !initializer.body)
                        return void 0;
                    return getFixInfo(checker, initializer, checker.getTypeAtLocation(node.parent), 
                    /*isFunctionType*/
                    true);
            }
            return void 0;
        }
        function getVariableLikeInitializer(declaration) {
            switch (declaration.kind) {
                case 260 /* VariableDeclaration */:
                case 169 /* Parameter */:
                case 208 /* BindingElement */:
                case 172 /* PropertyDeclaration */:
                case 303 /* PropertyAssignment */:
                    return declaration.initializer;
                case 291 /* JsxAttribute */:
                    return declaration.initializer && (isJsxExpression(declaration.initializer) ? declaration.initializer.expression : void 0);
                case 304 /* ShorthandPropertyAssignment */:
                case 171 /* PropertySignature */:
                case 306 /* EnumMember */:
                case 355 /* JSDocPropertyTag */:
                case 348 /* JSDocParameterTag */:
                    return void 0;
            }
        }
        function addReturnStatement(changes, sourceFile, expression, statement) {
            suppressLeadingAndTrailingTrivia(expression);
            const probablyNeedSemi = probablyUsesSemicolons(sourceFile);
            changes.replaceNode(sourceFile, statement, factory.createReturnStatement(expression), {
                leadingTriviaOption: ts_textChanges_exports.LeadingTriviaOption.Exclude,
                trailingTriviaOption: ts_textChanges_exports.TrailingTriviaOption.Exclude,
                suffix: probablyNeedSemi ? ";" : void 0
            });
        }
        function removeBlockBodyBrace(changes, sourceFile, declaration, expression, commentSource, withParen) {
            const newBody = withParen || needsParentheses(expression) ? factory.createParenthesizedExpression(expression) : expression;
            suppressLeadingAndTrailingTrivia(commentSource);
            copyComments(commentSource, newBody);
            changes.replaceNode(sourceFile, declaration.body, newBody);
        }
        function wrapBlockWithParen(changes, sourceFile, declaration, expression) {
            changes.replaceNode(sourceFile, declaration.body, factory.createParenthesizedExpression(expression));
        }
        function getActionForfixAddReturnStatement(context, expression, statement) {
            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => addReturnStatement(t, context.sourceFile, expression, statement));
            return createCodeFixAction(fixId23, changes, Diagnostics.Add_a_return_statement, fixIdAddReturnStatement, Diagnostics.Add_all_missing_return_statement);
        }
        function getActionForFixRemoveBracesFromArrowFunctionBody(context, declaration, expression, commentSource) {
            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => removeBlockBodyBrace(t, context.sourceFile, declaration, expression, commentSource, 
            /*withParen*/
            false));
            return createCodeFixAction(fixId23, changes, Diagnostics.Remove_braces_from_arrow_function_body, fixRemoveBracesFromArrowFunctionBody, Diagnostics.Remove_braces_from_all_arrow_function_bodies_with_relevant_issues);
        }
        function getActionForfixWrapTheBlockWithParen(context, declaration, expression) {
            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => wrapBlockWithParen(t, context.sourceFile, declaration, expression));
            return createCodeFixAction(fixId23, changes, Diagnostics.Wrap_the_following_body_with_parentheses_which_should_be_an_object_literal, fixIdWrapTheBlockWithParen, Diagnostics.Wrap_all_object_literal_with_parentheses);
        }
        var fixId23, fixIdAddReturnStatement, fixRemoveBracesFromArrowFunctionBody, fixIdWrapTheBlockWithParen, errorCodes26;
        var init_returnValueCorrect = __esm({
            "src/services/codefixes/returnValueCorrect.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId23 = "returnValueCorrect";
                fixIdAddReturnStatement = "fixAddReturnStatement";
                fixRemoveBracesFromArrowFunctionBody = "fixRemoveBracesFromArrowFunctionBody";
                fixIdWrapTheBlockWithParen = "fixWrapTheBlockWithParen";
                errorCodes26 = [
                    Diagnostics.A_function_whose_declared_type_is_neither_undefined_void_nor_any_must_return_a_value.code,
                    Diagnostics.Type_0_is_not_assignable_to_type_1.code,
                    Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes26,
                    fixIds: [fixIdAddReturnStatement, fixRemoveBracesFromArrowFunctionBody, fixIdWrapTheBlockWithParen],
                    getCodeActions: function getCodeActionsToCorrectReturnValue(context) {
                        const { program, sourceFile, span: { start }, errorCode } = context;
                        const info = getInfo9(program.getTypeChecker(), sourceFile, start, errorCode);
                        if (!info)
                            return void 0;
                        if (info.kind === 0 /* MissingReturnStatement */) {
                            return append([getActionForfixAddReturnStatement(context, info.expression, info.statement)], isArrowFunction(info.declaration) ? getActionForFixRemoveBracesFromArrowFunctionBody(context, info.declaration, info.expression, info.commentSource) : void 0);
                        }
                        else {
                            return [getActionForfixWrapTheBlockWithParen(context, info.declaration, info.expression)];
                        }
                    },
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes26, (changes, diag2) => {
                        const info = getInfo9(context.program.getTypeChecker(), diag2.file, diag2.start, diag2.code);
                        if (!info)
                            return void 0;
                        switch (context.fixId) {
                            case fixIdAddReturnStatement:
                                addReturnStatement(changes, diag2.file, info.expression, info.statement);
                                break;
                            case fixRemoveBracesFromArrowFunctionBody:
                                if (!isArrowFunction(info.declaration))
                                    return void 0;
                                removeBlockBodyBrace(changes, diag2.file, info.declaration, info.expression, info.commentSource, 
                                /*withParen*/
                                false);
                                break;
                            case fixIdWrapTheBlockWithParen:
                                if (!isArrowFunction(info.declaration))
                                    return void 0;
                                wrapBlockWithParen(changes, diag2.file, info.declaration, info.expression);
                                break;
                            default:
                                Debug.fail(JSON.stringify(context.fixId));
                        }
                    })
                });
            }
        });
        // src/services/codefixes/fixAddMissingMember.ts
        function getInfo10(sourceFile, tokenPos, errorCode, checker, program) {
            var _a;
            const token = getTokenAtPosition(sourceFile, tokenPos);
            const parent2 = token.parent;
            if (errorCode === Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1.code) {
                if (!(token.kind === 19 /* OpenBraceToken */ && isObjectLiteralExpression(parent2) && isCallExpression(parent2.parent)))
                    return void 0;
                const argIndex = findIndex(parent2.parent.arguments, (arg) => arg === parent2);
                if (argIndex < 0)
                    return void 0;
                const signature = checker.getResolvedSignature(parent2.parent);
                if (!(signature && signature.declaration && signature.parameters[argIndex]))
                    return void 0;
                const param = signature.parameters[argIndex].valueDeclaration;
                if (!(param && isParameter(param) && isIdentifier(param.name)))
                    return void 0;
                const properties = arrayFrom(checker.getUnmatchedProperties(checker.getTypeAtLocation(parent2), checker.getParameterType(signature, argIndex), 
                /*requireOptionalProperties*/
                false, 
                /*matchDiscriminantProperties*/
                false));
                if (!length(properties))
                    return void 0;
                return { kind: 3 /* ObjectLiteral */, token: param.name, identifier: param.name.text, properties, parentDeclaration: parent2 };
            }
            if (token.kind === 19 /* OpenBraceToken */ && isObjectLiteralExpression(parent2)) {
                const targetType = checker.getContextualType(parent2) || checker.getTypeAtLocation(parent2);
                const properties = arrayFrom(checker.getUnmatchedProperties(checker.getTypeAtLocation(parent2), targetType, 
                /*requireOptionalProperties*/
                false, 
                /*matchDiscriminantProperties*/
                false));
                if (!length(properties))
                    return void 0;
                const identifier = "";
                return { kind: 3 /* ObjectLiteral */, token: parent2, identifier, properties, parentDeclaration: parent2 };
            }
            if (!isMemberName(token))
                return void 0;
            if (isIdentifier(token) && hasInitializer(parent2) && parent2.initializer && isObjectLiteralExpression(parent2.initializer)) {
                const targetType = checker.getContextualType(token) || checker.getTypeAtLocation(token);
                const properties = arrayFrom(checker.getUnmatchedProperties(checker.getTypeAtLocation(parent2.initializer), targetType, 
                /*requireOptionalProperties*/
                false, 
                /*matchDiscriminantProperties*/
                false));
                if (!length(properties))
                    return void 0;
                return { kind: 3 /* ObjectLiteral */, token, identifier: token.text, properties, parentDeclaration: parent2.initializer };
            }
            if (isIdentifier(token) && isJsxOpeningLikeElement(token.parent)) {
                const target = getEmitScriptTarget(program.getCompilerOptions());
                const attributes = getUnmatchedAttributes(checker, target, token.parent);
                if (!length(attributes))
                    return void 0;
                return { kind: 4 /* JsxAttributes */, token, attributes, parentDeclaration: token.parent };
            }
            if (isIdentifier(token)) {
                const type = (_a = checker.getContextualType(token)) == null ? void 0 : _a.getNonNullableType();
                if (type && getObjectFlags(type) & 16 /* Anonymous */) {
                    const signature = firstOrUndefined(checker.getSignaturesOfType(type, 0 /* Call */));
                    if (signature === void 0)
                        return void 0;
                    return { kind: 5 /* Signature */, token, signature, sourceFile, parentDeclaration: findScope(token) };
                }
                if (isCallExpression(parent2) && parent2.expression === token) {
                    return { kind: 2 /* Function */, token, call: parent2, sourceFile, modifierFlags: 0 /* None */, parentDeclaration: findScope(token) };
                }
            }
            if (!isPropertyAccessExpression(parent2))
                return void 0;
            const leftExpressionType = skipConstraint(checker.getTypeAtLocation(parent2.expression));
            const symbol = leftExpressionType.symbol;
            if (!symbol || !symbol.declarations)
                return void 0;
            if (isIdentifier(token) && isCallExpression(parent2.parent)) {
                const moduleDeclaration = find(symbol.declarations, isModuleDeclaration);
                const moduleDeclarationSourceFile = moduleDeclaration == null ? void 0 : moduleDeclaration.getSourceFile();
                if (moduleDeclaration && moduleDeclarationSourceFile && !isSourceFileFromLibrary(program, moduleDeclarationSourceFile)) {
                    return { kind: 2 /* Function */, token, call: parent2.parent, sourceFile, modifierFlags: 32 /* Export */, parentDeclaration: moduleDeclaration };
                }
                const moduleSourceFile = find(symbol.declarations, isSourceFile);
                if (sourceFile.commonJsModuleIndicator)
                    return void 0;
                if (moduleSourceFile && !isSourceFileFromLibrary(program, moduleSourceFile)) {
                    return { kind: 2 /* Function */, token, call: parent2.parent, sourceFile: moduleSourceFile, modifierFlags: 32 /* Export */, parentDeclaration: moduleSourceFile };
                }
            }
            const classDeclaration = find(symbol.declarations, isClassLike);
            if (!classDeclaration && isPrivateIdentifier(token))
                return void 0;
            const declaration = classDeclaration || find(symbol.declarations, (d) => isInterfaceDeclaration(d) || isTypeLiteralNode(d));
            if (declaration && !isSourceFileFromLibrary(program, declaration.getSourceFile())) {
                const makeStatic = !isTypeLiteralNode(declaration) && (leftExpressionType.target || leftExpressionType) !== checker.getDeclaredTypeOfSymbol(symbol);
                if (makeStatic && (isPrivateIdentifier(token) || isInterfaceDeclaration(declaration)))
                    return void 0;
                const declSourceFile = declaration.getSourceFile();
                const modifierFlags = isTypeLiteralNode(declaration) ? 0 /* None */ : (makeStatic ? 256 /* Static */ : 0 /* None */) | (startsWithUnderscore(token.text) ? 2 /* Private */ : 0 /* None */);
                const isJSFile = isSourceFileJS(declSourceFile);
                const call = tryCast(parent2.parent, isCallExpression);
                return { kind: 0 /* TypeLikeDeclaration */, token, call, modifierFlags, parentDeclaration: declaration, declSourceFile, isJSFile };
            }
            const enumDeclaration = find(symbol.declarations, isEnumDeclaration);
            if (enumDeclaration && !(leftExpressionType.flags & 1056 /* EnumLike */) && !isPrivateIdentifier(token) && !isSourceFileFromLibrary(program, enumDeclaration.getSourceFile())) {
                return { kind: 1 /* Enum */, token, parentDeclaration: enumDeclaration };
            }
            return void 0;
        }
        function getActionsForMissingMemberDeclaration(context, info) {
            return info.isJSFile ? singleElementArray(createActionForAddMissingMemberInJavascriptFile(context, info)) : createActionsForAddMissingMemberInTypeScriptFile(context, info);
        }
        function createActionForAddMissingMemberInJavascriptFile(context, { parentDeclaration, declSourceFile, modifierFlags, token }) {
            if (isInterfaceDeclaration(parentDeclaration) || isTypeLiteralNode(parentDeclaration)) {
                return void 0;
            }
            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => addMissingMemberInJs(t, declSourceFile, parentDeclaration, token, !!(modifierFlags & 256 /* Static */)));
            if (changes.length === 0) {
                return void 0;
            }
            const diagnostic = modifierFlags & 256 /* Static */ ? Diagnostics.Initialize_static_property_0 : isPrivateIdentifier(token) ? Diagnostics.Declare_a_private_field_named_0 : Diagnostics.Initialize_property_0_in_the_constructor;
            return createCodeFixAction(fixMissingMember, changes, [diagnostic, token.text], fixMissingMember, Diagnostics.Add_all_missing_members);
        }
        function addMissingMemberInJs(changeTracker, sourceFile, classDeclaration, token, makeStatic) {
            const tokenName = token.text;
            if (makeStatic) {
                if (classDeclaration.kind === 231 /* ClassExpression */) {
                    return;
                }
                const className = classDeclaration.name.getText();
                const staticInitialization = initializePropertyToUndefined(factory.createIdentifier(className), tokenName);
                changeTracker.insertNodeAfter(sourceFile, classDeclaration, staticInitialization);
            }
            else if (isPrivateIdentifier(token)) {
                const property = factory.createPropertyDeclaration(
                /*modifiers*/
                void 0, tokenName, 
                /*questionOrExclamationToken*/
                void 0, 
                /*type*/
                void 0, 
                /*initializer*/
                void 0);
                const lastProp = getNodeToInsertPropertyAfter(classDeclaration);
                if (lastProp) {
                    changeTracker.insertNodeAfter(sourceFile, lastProp, property);
                }
                else {
                    changeTracker.insertMemberAtStart(sourceFile, classDeclaration, property);
                }
            }
            else {
                const classConstructor = getFirstConstructorWithBody(classDeclaration);
                if (!classConstructor) {
                    return;
                }
                const propertyInitialization = initializePropertyToUndefined(factory.createThis(), tokenName);
                changeTracker.insertNodeAtConstructorEnd(sourceFile, classConstructor, propertyInitialization);
            }
        }
        function initializePropertyToUndefined(obj, propertyName) {
            return factory.createExpressionStatement(factory.createAssignment(factory.createPropertyAccessExpression(obj, propertyName), createUndefined()));
        }
        function createActionsForAddMissingMemberInTypeScriptFile(context, { parentDeclaration, declSourceFile, modifierFlags, token }) {
            const memberName = token.text;
            const isStatic2 = modifierFlags & 256 /* Static */;
            const typeNode = getTypeNode2(context.program.getTypeChecker(), parentDeclaration, token);
            const addPropertyDeclarationChanges = (modifierFlags2) => ts_textChanges_exports.ChangeTracker.with(context, (t) => addPropertyDeclaration(t, declSourceFile, parentDeclaration, memberName, typeNode, modifierFlags2));
            const actions2 = [createCodeFixAction(fixMissingMember, addPropertyDeclarationChanges(modifierFlags & 256 /* Static */), [isStatic2 ? Diagnostics.Declare_static_property_0 : Diagnostics.Declare_property_0, memberName], fixMissingMember, Diagnostics.Add_all_missing_members)];
            if (isStatic2 || isPrivateIdentifier(token)) {
                return actions2;
            }
            if (modifierFlags & 2 /* Private */) {
                actions2.unshift(createCodeFixActionWithoutFixAll(fixMissingMember, addPropertyDeclarationChanges(2 /* Private */), [Diagnostics.Declare_private_property_0, memberName]));
            }
            actions2.push(createAddIndexSignatureAction(context, declSourceFile, parentDeclaration, token.text, typeNode));
            return actions2;
        }
        function getTypeNode2(checker, node, token) {
            let typeNode;
            if (token.parent.parent.kind === 226 /* BinaryExpression */) {
                const binaryExpression = token.parent.parent;
                const otherExpression = token.parent === binaryExpression.left ? binaryExpression.right : binaryExpression.left;
                const widenedType = checker.getWidenedType(checker.getBaseTypeOfLiteralType(checker.getTypeAtLocation(otherExpression)));
                typeNode = checker.typeToTypeNode(widenedType, node, 1 /* NoTruncation */);
            }
            else {
                const contextualType = checker.getContextualType(token.parent);
                typeNode = contextualType ? checker.typeToTypeNode(contextualType, 
                /*enclosingDeclaration*/
                void 0, 1 /* NoTruncation */) : void 0;
            }
            return typeNode || factory.createKeywordTypeNode(133 /* AnyKeyword */);
        }
        function addPropertyDeclaration(changeTracker, sourceFile, node, tokenName, typeNode, modifierFlags) {
            const modifiers = modifierFlags ? factory.createNodeArray(factory.createModifiersFromModifierFlags(modifierFlags)) : void 0;
            const property = isClassLike(node) ? factory.createPropertyDeclaration(modifiers, tokenName, 
            /*questionOrExclamationToken*/
            void 0, typeNode, 
            /*initializer*/
            void 0) : factory.createPropertySignature(
            /*modifiers*/
            void 0, tokenName, 
            /*questionToken*/
            void 0, typeNode);
            const lastProp = getNodeToInsertPropertyAfter(node);
            if (lastProp) {
                changeTracker.insertNodeAfter(sourceFile, lastProp, property);
            }
            else {
                changeTracker.insertMemberAtStart(sourceFile, node, property);
            }
        }
        function getNodeToInsertPropertyAfter(node) {
            let res;
            for (const member of node.members) {
                if (!isPropertyDeclaration(member))
                    break;
                res = member;
            }
            return res;
        }
        function createAddIndexSignatureAction(context, sourceFile, node, tokenName, typeNode) {
            const stringTypeNode = factory.createKeywordTypeNode(154 /* StringKeyword */);
            const indexingParameter = factory.createParameterDeclaration(
            /*modifiers*/
            void 0, 
            /*dotDotDotToken*/
            void 0, "x", 
            /*questionToken*/
            void 0, stringTypeNode, 
            /*initializer*/
            void 0);
            const indexSignature = factory.createIndexSignature(
            /*modifiers*/
            void 0, [indexingParameter], typeNode);
            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => t.insertMemberAtStart(sourceFile, node, indexSignature));
            return createCodeFixActionWithoutFixAll(fixMissingMember, changes, [Diagnostics.Add_index_signature_for_property_0, tokenName]);
        }
        function getActionsForMissingMethodDeclaration(context, info) {
            const { parentDeclaration, declSourceFile, modifierFlags, token, call } = info;
            if (call === void 0) {
                return void 0;
            }
            const methodName = token.text;
            const addMethodDeclarationChanges = (modifierFlags2) => ts_textChanges_exports.ChangeTracker.with(context, (t) => addMethodDeclaration(context, t, call, token, modifierFlags2, parentDeclaration, declSourceFile));
            const actions2 = [createCodeFixAction(fixMissingMember, addMethodDeclarationChanges(modifierFlags & 256 /* Static */), [modifierFlags & 256 /* Static */ ? Diagnostics.Declare_static_method_0 : Diagnostics.Declare_method_0, methodName], fixMissingMember, Diagnostics.Add_all_missing_members)];
            if (modifierFlags & 2 /* Private */) {
                actions2.unshift(createCodeFixActionWithoutFixAll(fixMissingMember, addMethodDeclarationChanges(2 /* Private */), [Diagnostics.Declare_private_method_0, methodName]));
            }
            return actions2;
        }
        function addMethodDeclaration(context, changes, callExpression, name, modifierFlags, parentDeclaration, sourceFile) {
            const importAdder = createImportAdder(sourceFile, context.program, context.preferences, context.host);
            const kind = isClassLike(parentDeclaration) ? 174 /* MethodDeclaration */ : 173 /* MethodSignature */;
            const signatureDeclaration = createSignatureDeclarationFromCallExpression(kind, context, importAdder, callExpression, name, modifierFlags, parentDeclaration);
            const containingMethodDeclaration = tryGetContainingMethodDeclaration(parentDeclaration, callExpression);
            if (containingMethodDeclaration) {
                changes.insertNodeAfter(sourceFile, containingMethodDeclaration, signatureDeclaration);
            }
            else {
                changes.insertMemberAtStart(sourceFile, parentDeclaration, signatureDeclaration);
            }
            importAdder.writeFixes(changes);
        }
        function addEnumMemberDeclaration(changes, checker, { token, parentDeclaration }) {
            const hasStringInitializer = some(parentDeclaration.members, (member) => {
                const type = checker.getTypeAtLocation(member);
                return !!(type && type.flags & 402653316 /* StringLike */);
            });
            const sourceFile = parentDeclaration.getSourceFile();
            const enumMember = factory.createEnumMember(token, hasStringInitializer ? factory.createStringLiteral(token.text) : void 0);
            const last2 = lastOrUndefined(parentDeclaration.members);
            if (last2) {
                changes.insertNodeInListAfter(sourceFile, last2, enumMember, parentDeclaration.members);
            }
            else {
                changes.insertMemberAtStart(sourceFile, parentDeclaration, enumMember);
            }
        }
        function addFunctionDeclaration(changes, context, info) {
            const quotePreference = getQuotePreference(context.sourceFile, context.preferences);
            const importAdder = createImportAdder(context.sourceFile, context.program, context.preferences, context.host);
            const functionDeclaration = info.kind === 2 /* Function */ ? createSignatureDeclarationFromCallExpression(262 /* FunctionDeclaration */, context, importAdder, info.call, idText(info.token), info.modifierFlags, info.parentDeclaration) : createSignatureDeclarationFromSignature(262 /* FunctionDeclaration */, context, quotePreference, info.signature, createStubbedBody(Diagnostics.Function_not_implemented.message, quotePreference), info.token, 
            /*modifiers*/
            void 0, 
            /*optional*/
            void 0, 
            /*enclosingDeclaration*/
            void 0, importAdder);
            if (functionDeclaration === void 0) {
                Debug.fail("fixMissingFunctionDeclaration codefix got unexpected error.");
            }
            isReturnStatement(info.parentDeclaration) ? changes.insertNodeBefore(info.sourceFile, info.parentDeclaration, functionDeclaration, 
            /*blankLineBetween*/
            true) : changes.insertNodeAtEndOfScope(info.sourceFile, info.parentDeclaration, functionDeclaration);
            importAdder.writeFixes(changes);
        }
        function addJsxAttributes(changes, context, info) {
            const importAdder = createImportAdder(context.sourceFile, context.program, context.preferences, context.host);
            const quotePreference = getQuotePreference(context.sourceFile, context.preferences);
            const checker = context.program.getTypeChecker();
            const jsxAttributesNode = info.parentDeclaration.attributes;
            const hasSpreadAttribute = some(jsxAttributesNode.properties, isJsxSpreadAttribute);
            const attrs = map(info.attributes, (attr) => {
                const value = tryGetValueFromType(context, checker, importAdder, quotePreference, checker.getTypeOfSymbol(attr), info.parentDeclaration);
                const name = factory.createIdentifier(attr.name);
                const jsxAttribute = factory.createJsxAttribute(name, factory.createJsxExpression(
                /*dotDotDotToken*/
                void 0, value));
                setParent(name, jsxAttribute);
                return jsxAttribute;
            });
            const jsxAttributes = factory.createJsxAttributes(hasSpreadAttribute ? [...attrs, ...jsxAttributesNode.properties] : [...jsxAttributesNode.properties, ...attrs]);
            const options = { prefix: jsxAttributesNode.pos === jsxAttributesNode.end ? " " : void 0 };
            changes.replaceNode(context.sourceFile, jsxAttributesNode, jsxAttributes, options);
            importAdder.writeFixes(changes);
        }
        function addObjectLiteralProperties(changes, context, info) {
            const importAdder = createImportAdder(context.sourceFile, context.program, context.preferences, context.host);
            const quotePreference = getQuotePreference(context.sourceFile, context.preferences);
            const target = getEmitScriptTarget(context.program.getCompilerOptions());
            const checker = context.program.getTypeChecker();
            const props = map(info.properties, (prop) => {
                const initializer = tryGetValueFromType(context, checker, importAdder, quotePreference, checker.getTypeOfSymbol(prop), info.parentDeclaration);
                return factory.createPropertyAssignment(createPropertyNameFromSymbol(prop, target, quotePreference, checker), initializer);
            });
            const options = {
                leadingTriviaOption: ts_textChanges_exports.LeadingTriviaOption.Exclude,
                trailingTriviaOption: ts_textChanges_exports.TrailingTriviaOption.Exclude,
                indentation: info.indentation
            };
            changes.replaceNode(context.sourceFile, info.parentDeclaration, factory.createObjectLiteralExpression([...info.parentDeclaration.properties, ...props], 
            /*multiLine*/
            true), options);
            importAdder.writeFixes(changes);
        }
        function tryGetValueFromType(context, checker, importAdder, quotePreference, type, enclosingDeclaration) {
            if (type.flags & 3 /* AnyOrUnknown */) {
                return createUndefined();
            }
            if (type.flags & (4 /* String */ | 134217728 /* TemplateLiteral */)) {
                return factory.createStringLiteral("", 
                /* isSingleQuote */
                quotePreference === 0 /* Single */);
            }
            if (type.flags & 8 /* Number */) {
                return factory.createNumericLiteral(0);
            }
            if (type.flags & 64 /* BigInt */) {
                return factory.createBigIntLiteral("0n");
            }
            if (type.flags & 16 /* Boolean */) {
                return factory.createFalse();
            }
            if (type.flags & 1056 /* EnumLike */) {
                const enumMember = type.symbol.exports ? firstOrUndefinedIterator(type.symbol.exports.values()) : type.symbol;
                const name = checker.symbolToExpression(type.symbol.parent ? type.symbol.parent : type.symbol, 111551 /* Value */, 
                /*enclosingDeclaration*/
                void 0, 
                /*flags*/
                64 /* UseFullyQualifiedType */);
                return enumMember === void 0 || name === void 0 ? factory.createNumericLiteral(0) : factory.createPropertyAccessExpression(name, checker.symbolToString(enumMember));
            }
            if (type.flags & 256 /* NumberLiteral */) {
                return factory.createNumericLiteral(type.value);
            }
            if (type.flags & 2048 /* BigIntLiteral */) {
                return factory.createBigIntLiteral(type.value);
            }
            if (type.flags & 128 /* StringLiteral */) {
                return factory.createStringLiteral(type.value, 
                /* isSingleQuote */
                quotePreference === 0 /* Single */);
            }
            if (type.flags & 512 /* BooleanLiteral */) {
                return type === checker.getFalseType() || type === checker.getFalseType(
                /*fresh*/
                true) ? factory.createFalse() : factory.createTrue();
            }
            if (type.flags & 65536 /* Null */) {
                return factory.createNull();
            }
            if (type.flags & 1048576 /* Union */) {
                const expression = firstDefined(type.types, (t) => tryGetValueFromType(context, checker, importAdder, quotePreference, t, enclosingDeclaration));
                return expression ?? createUndefined();
            }
            if (checker.isArrayLikeType(type)) {
                return factory.createArrayLiteralExpression();
            }
            if (isObjectLiteralType(type)) {
                const props = map(checker.getPropertiesOfType(type), (prop) => {
                    const initializer = tryGetValueFromType(context, checker, importAdder, quotePreference, checker.getTypeOfSymbol(prop), enclosingDeclaration);
                    return factory.createPropertyAssignment(prop.name, initializer);
                });
                return factory.createObjectLiteralExpression(props, 
                /*multiLine*/
                true);
            }
            if (getObjectFlags(type) & 16 /* Anonymous */) {
                const decl = find(type.symbol.declarations || emptyArray, or(isFunctionTypeNode, isMethodSignature, isMethodDeclaration));
                if (decl === void 0)
                    return createUndefined();
                const signature = checker.getSignaturesOfType(type, 0 /* Call */);
                if (signature === void 0)
                    return createUndefined();
                const func = createSignatureDeclarationFromSignature(218 /* FunctionExpression */, context, quotePreference, signature[0], createStubbedBody(Diagnostics.Function_not_implemented.message, quotePreference), 
                /*name*/
                void 0, 
                /*modifiers*/
                void 0, 
                /*optional*/
                void 0, 
                /*enclosingDeclaration*/
                enclosingDeclaration, importAdder);
                return func ?? createUndefined();
            }
            if (getObjectFlags(type) & 1 /* Class */) {
                const classDeclaration = getClassLikeDeclarationOfSymbol(type.symbol);
                if (classDeclaration === void 0 || hasAbstractModifier(classDeclaration))
                    return createUndefined();
                const constructorDeclaration = getFirstConstructorWithBody(classDeclaration);
                if (constructorDeclaration && length(constructorDeclaration.parameters))
                    return createUndefined();
                return factory.createNewExpression(factory.createIdentifier(type.symbol.name), 
                /*typeArguments*/
                void 0, 
                /*argumentsArray*/
                void 0);
            }
            return createUndefined();
        }
        function createUndefined() {
            return factory.createIdentifier("undefined");
        }
        function isObjectLiteralType(type) {
            return type.flags & 524288 /* Object */ && (getObjectFlags(type) & 128 /* ObjectLiteral */ || type.symbol && tryCast(singleOrUndefined(type.symbol.declarations), isTypeLiteralNode));
        }
        function getUnmatchedAttributes(checker, target, source) {
            const attrsType = checker.getContextualType(source.attributes);
            if (attrsType === void 0)
                return emptyArray;
            const targetProps = attrsType.getProperties();
            if (!length(targetProps))
                return emptyArray;
            const seenNames = /* @__PURE__ */ new Set();
            for (const sourceProp of source.attributes.properties) {
                if (isJsxAttribute(sourceProp)) {
                    seenNames.add(getEscapedTextOfJsxAttributeName(sourceProp.name));
                }
                if (isJsxSpreadAttribute(sourceProp)) {
                    const type = checker.getTypeAtLocation(sourceProp.expression);
                    for (const prop of type.getProperties()) {
                        seenNames.add(prop.escapedName);
                    }
                }
            }
            return filter(targetProps, (targetProp) => isIdentifierText(targetProp.name, target, 1 /* JSX */) && !(targetProp.flags & 16777216 /* Optional */ || getCheckFlags(targetProp) & 48 /* Partial */ || seenNames.has(targetProp.escapedName)));
        }
        function tryGetContainingMethodDeclaration(node, callExpression) {
            if (isTypeLiteralNode(node)) {
                return void 0;
            }
            const declaration = findAncestor(callExpression, (n) => isMethodDeclaration(n) || isConstructorDeclaration(n));
            return declaration && declaration.parent === node ? declaration : void 0;
        }
        function createPropertyNameFromSymbol(symbol, target, quotePreference, checker) {
            if (isTransientSymbol(symbol)) {
                const prop = checker.symbolToNode(symbol, 111551 /* Value */, 
                /*enclosingDeclaration*/
                void 0, 1073741824 /* WriteComputedProps */);
                if (prop && isComputedPropertyName(prop))
                    return prop;
            }
            return createPropertyNameNodeForIdentifierOrLiteral(symbol.name, target, quotePreference === 0 /* Single */, 
            /*stringNamed*/
            false, 
            /*isMethod*/
            false);
        }
        function findScope(node) {
            if (findAncestor(node, isJsxExpression)) {
                const returnStatement = findAncestor(node.parent, isReturnStatement);
                if (returnStatement)
                    return returnStatement;
            }
            return getSourceFileOfNode(node);
        }
        var fixMissingMember, fixMissingProperties, fixMissingAttributes, fixMissingFunctionDeclaration, errorCodes27;
        var init_fixAddMissingMember = __esm({
            "src/services/codefixes/fixAddMissingMember.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixMissingMember = "fixMissingMember";
                fixMissingProperties = "fixMissingProperties";
                fixMissingAttributes = "fixMissingAttributes";
                fixMissingFunctionDeclaration = "fixMissingFunctionDeclaration";
                errorCodes27 = [
                    Diagnostics.Property_0_does_not_exist_on_type_1.code,
                    Diagnostics.Property_0_does_not_exist_on_type_1_Did_you_mean_2.code,
                    Diagnostics.Property_0_is_missing_in_type_1_but_required_in_type_2.code,
                    Diagnostics.Type_0_is_missing_the_following_properties_from_type_1_Colon_2.code,
                    Diagnostics.Type_0_is_missing_the_following_properties_from_type_1_Colon_2_and_3_more.code,
                    Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1.code,
                    Diagnostics.Cannot_find_name_0.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes27,
                    getCodeActions(context) {
                        const typeChecker = context.program.getTypeChecker();
                        const info = getInfo10(context.sourceFile, context.span.start, context.errorCode, typeChecker, context.program);
                        if (!info) {
                            return void 0;
                        }
                        if (info.kind === 3 /* ObjectLiteral */) {
                            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => addObjectLiteralProperties(t, context, info));
                            return [createCodeFixAction(fixMissingProperties, changes, Diagnostics.Add_missing_properties, fixMissingProperties, Diagnostics.Add_all_missing_properties)];
                        }
                        if (info.kind === 4 /* JsxAttributes */) {
                            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => addJsxAttributes(t, context, info));
                            return [createCodeFixAction(fixMissingAttributes, changes, Diagnostics.Add_missing_attributes, fixMissingAttributes, Diagnostics.Add_all_missing_attributes)];
                        }
                        if (info.kind === 2 /* Function */ || info.kind === 5 /* Signature */) {
                            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => addFunctionDeclaration(t, context, info));
                            return [createCodeFixAction(fixMissingFunctionDeclaration, changes, [Diagnostics.Add_missing_function_declaration_0, info.token.text], fixMissingFunctionDeclaration, Diagnostics.Add_all_missing_function_declarations)];
                        }
                        if (info.kind === 1 /* Enum */) {
                            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => addEnumMemberDeclaration(t, context.program.getTypeChecker(), info));
                            return [createCodeFixAction(fixMissingMember, changes, [Diagnostics.Add_missing_enum_member_0, info.token.text], fixMissingMember, Diagnostics.Add_all_missing_members)];
                        }
                        return concatenate(getActionsForMissingMethodDeclaration(context, info), getActionsForMissingMemberDeclaration(context, info));
                    },
                    fixIds: [fixMissingMember, fixMissingFunctionDeclaration, fixMissingProperties, fixMissingAttributes],
                    getAllCodeActions: (context) => {
                        const { program, fixId: fixId52 } = context;
                        const checker = program.getTypeChecker();
                        const seen = /* @__PURE__ */ new Map();
                        const typeDeclToMembers = /* @__PURE__ */ new Map();
                        return createCombinedCodeActions(ts_textChanges_exports.ChangeTracker.with(context, (changes) => {
                            eachDiagnostic(context, errorCodes27, (diag2) => {
                                const info = getInfo10(diag2.file, diag2.start, diag2.code, checker, context.program);
                                if (!info || !addToSeen(seen, getNodeId(info.parentDeclaration) + "#" + (info.kind === 3 /* ObjectLiteral */ ? info.identifier : info.token.text))) {
                                    return;
                                }
                                if (fixId52 === fixMissingFunctionDeclaration && (info.kind === 2 /* Function */ || info.kind === 5 /* Signature */)) {
                                    addFunctionDeclaration(changes, context, info);
                                }
                                else if (fixId52 === fixMissingProperties && info.kind === 3 /* ObjectLiteral */) {
                                    addObjectLiteralProperties(changes, context, info);
                                }
                                else if (fixId52 === fixMissingAttributes && info.kind === 4 /* JsxAttributes */) {
                                    addJsxAttributes(changes, context, info);
                                }
                                else {
                                    if (info.kind === 1 /* Enum */) {
                                        addEnumMemberDeclaration(changes, checker, info);
                                    }
                                    if (info.kind === 0 /* TypeLikeDeclaration */) {
                                        const { parentDeclaration, token } = info;
                                        const infos = getOrUpdate(typeDeclToMembers, parentDeclaration, () => []);
                                        if (!infos.some((i) => i.token.text === token.text)) {
                                            infos.push(info);
                                        }
                                    }
                                }
                            });
                            typeDeclToMembers.forEach((infos, declaration) => {
                                const supers = isTypeLiteralNode(declaration) ? void 0 : getAllSupers(declaration, checker);
                                for (const info of infos) {
                                    if (supers == null ? void 0 : supers.some((superClassOrInterface) => {
                                        const superInfos = typeDeclToMembers.get(superClassOrInterface);
                                        return !!superInfos && superInfos.some(({ token: token2 }) => token2.text === info.token.text);
                                    }))
                                        continue;
                                    const { parentDeclaration, declSourceFile, modifierFlags, token, call, isJSFile } = info;
                                    if (call && !isPrivateIdentifier(token)) {
                                        addMethodDeclaration(context, changes, call, token, modifierFlags & 256 /* Static */, parentDeclaration, declSourceFile);
                                    }
                                    else {
                                        if (isJSFile && !isInterfaceDeclaration(parentDeclaration) && !isTypeLiteralNode(parentDeclaration)) {
                                            addMissingMemberInJs(changes, declSourceFile, parentDeclaration, token, !!(modifierFlags & 256 /* Static */));
                                        }
                                        else {
                                            const typeNode = getTypeNode2(checker, parentDeclaration, token);
                                            addPropertyDeclaration(changes, declSourceFile, parentDeclaration, token.text, typeNode, modifierFlags & 256 /* Static */);
                                        }
                                    }
                                }
                            });
                        }));
                    }
                });
            }
        });
        // src/services/codefixes/fixAddMissingNewOperator.ts
        function addMissingNewOperator(changes, sourceFile, span) {
            const call = cast(findAncestorMatchingSpan2(sourceFile, span), isCallExpression);
            const newExpression = factory.createNewExpression(call.expression, call.typeArguments, call.arguments);
            changes.replaceNode(sourceFile, call, newExpression);
        }
        function findAncestorMatchingSpan2(sourceFile, span) {
            let token = getTokenAtPosition(sourceFile, span.start);
            const end = textSpanEnd(span);
            while (token.end < end) {
                token = token.parent;
            }
            return token;
        }
        var fixId24, errorCodes28;
        var init_fixAddMissingNewOperator = __esm({
            "src/services/codefixes/fixAddMissingNewOperator.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId24 = "addMissingNewOperator";
                errorCodes28 = [Diagnostics.Value_of_type_0_is_not_callable_Did_you_mean_to_include_new.code];
                registerCodeFix({
                    errorCodes: errorCodes28,
                    getCodeActions(context) {
                        const { sourceFile, span } = context;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => addMissingNewOperator(t, sourceFile, span));
                        return [createCodeFixAction(fixId24, changes, Diagnostics.Add_missing_new_operator_to_call, fixId24, Diagnostics.Add_missing_new_operator_to_all_calls)];
                    },
                    fixIds: [fixId24],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes28, (changes, diag2) => addMissingNewOperator(changes, context.sourceFile, diag2))
                });
            }
        });
        // src/services/codefixes/fixAddMissingParam.ts
        function getInfo11(sourceFile, program, pos) {
            const token = getTokenAtPosition(sourceFile, pos);
            const callExpression = findAncestor(token, isCallExpression);
            if (callExpression === void 0 || length(callExpression.arguments) === 0) {
                return void 0;
            }
            const checker = program.getTypeChecker();
            const type = checker.getTypeAtLocation(callExpression.expression);
            const convertibleSignatureDeclarations = filter(type.symbol.declarations, isConvertibleSignatureDeclaration);
            if (convertibleSignatureDeclarations === void 0) {
                return void 0;
            }
            const nonOverloadDeclaration = lastOrUndefined(convertibleSignatureDeclarations);
            if (nonOverloadDeclaration === void 0 || nonOverloadDeclaration.body === void 0 || isSourceFileFromLibrary(program, nonOverloadDeclaration.getSourceFile())) {
                return void 0;
            }
            const name = tryGetName2(nonOverloadDeclaration);
            if (name === void 0) {
                return void 0;
            }
            const newParameters = [];
            const newOptionalParameters = [];
            const parametersLength = length(nonOverloadDeclaration.parameters);
            const argumentsLength = length(callExpression.arguments);
            if (parametersLength > argumentsLength) {
                return void 0;
            }
            const declarations = [nonOverloadDeclaration, ...getOverloads(nonOverloadDeclaration, convertibleSignatureDeclarations)];
            for (let i = 0, pos2 = 0, paramIndex = 0; i < argumentsLength; i++) {
                const arg = callExpression.arguments[i];
                const expr = isAccessExpression(arg) ? getNameOfAccessExpression(arg) : arg;
                const type2 = checker.getWidenedType(checker.getBaseTypeOfLiteralType(checker.getTypeAtLocation(arg)));
                const parameter = pos2 < parametersLength ? nonOverloadDeclaration.parameters[pos2] : void 0;
                if (parameter && checker.isTypeAssignableTo(type2, checker.getTypeAtLocation(parameter))) {
                    pos2++;
                    continue;
                }
                const name2 = expr && isIdentifier(expr) ? expr.text : `p${paramIndex++}`;
                const typeNode = typeToTypeNode(checker, type2, nonOverloadDeclaration);
                append(newParameters, {
                    pos: i,
                    declaration: createParameter(name2, typeNode, 
                    /*questionToken*/
                    void 0)
                });
                if (isOptionalPos(declarations, pos2)) {
                    continue;
                }
                append(newOptionalParameters, {
                    pos: i,
                    declaration: createParameter(name2, typeNode, factory.createToken(58 /* QuestionToken */))
                });
            }
            return {
                newParameters,
                newOptionalParameters,
                name: declarationNameToString(name),
                declarations
            };
        }
        function tryGetName2(node) {
            const name = getNameOfDeclaration(node);
            if (name) {
                return name;
            }
            if (isVariableDeclaration(node.parent) && isIdentifier(node.parent.name) || isPropertyDeclaration(node.parent) || isParameter(node.parent)) {
                return node.parent.name;
            }
        }
        function typeToTypeNode(checker, type, enclosingDeclaration) {
            return checker.typeToTypeNode(checker.getWidenedType(type), enclosingDeclaration, 1 /* NoTruncation */) ?? factory.createKeywordTypeNode(159 /* UnknownKeyword */);
        }
        function doChange19(changes, sourceFile, declarations, newParameters) {
            forEach(declarations, (declaration) => {
                if (length(declaration.parameters)) {
                    changes.replaceNodeRangeWithNodes(sourceFile, first(declaration.parameters), last(declaration.parameters), updateParameters(declaration, newParameters), {
                        joiner: ", ",
                        indentation: 0,
                        leadingTriviaOption: ts_textChanges_exports.LeadingTriviaOption.IncludeAll,
                        trailingTriviaOption: ts_textChanges_exports.TrailingTriviaOption.Include
                    });
                }
                else {
                    forEach(updateParameters(declaration, newParameters), (parameter, index) => {
                        if (length(declaration.parameters) === 0 && index === 0) {
                            changes.insertNodeAt(sourceFile, declaration.parameters.end, parameter);
                        }
                        else {
                            changes.insertNodeAtEndOfList(sourceFile, declaration.parameters, parameter);
                        }
                    });
                }
            });
        }
        function isConvertibleSignatureDeclaration(node) {
            switch (node.kind) {
                case 262 /* FunctionDeclaration */:
                case 218 /* FunctionExpression */:
                case 174 /* MethodDeclaration */:
                case 219 /* ArrowFunction */:
                    return true;
                default:
                    return false;
            }
        }
        function updateParameters(node, newParameters) {
            const parameters = map(node.parameters, (p) => factory.createParameterDeclaration(p.modifiers, p.dotDotDotToken, p.name, p.questionToken, p.type, p.initializer));
            for (const { pos, declaration } of newParameters) {
                const prev = pos > 0 ? parameters[pos - 1] : void 0;
                parameters.splice(pos, 0, factory.updateParameterDeclaration(declaration, declaration.modifiers, declaration.dotDotDotToken, declaration.name, prev && prev.questionToken ? factory.createToken(58 /* QuestionToken */) : declaration.questionToken, declaration.type, declaration.initializer));
            }
            return parameters;
        }
        function getOverloads(implementation, declarations) {
            const overloads = [];
            for (const declaration of declarations) {
                if (isOverload(declaration)) {
                    if (length(declaration.parameters) === length(implementation.parameters)) {
                        overloads.push(declaration);
                        continue;
                    }
                    if (length(declaration.parameters) > length(implementation.parameters)) {
                        return [];
                    }
                }
            }
            return overloads;
        }
        function isOverload(declaration) {
            return isConvertibleSignatureDeclaration(declaration) && declaration.body === void 0;
        }
        function createParameter(name, type, questionToken) {
            return factory.createParameterDeclaration(
            /*modifiers*/
            void 0, 
            /*dotDotDotToken*/
            void 0, name, questionToken, type, 
            /*initializer*/
            void 0);
        }
        function isOptionalPos(declarations, pos) {
            return length(declarations) && some(declarations, (d) => pos < length(d.parameters) && !!d.parameters[pos] && d.parameters[pos].questionToken === void 0);
        }
        var addMissingParamFixId, addOptionalParamFixId, errorCodes29;
        var init_fixAddMissingParam = __esm({
            "src/services/codefixes/fixAddMissingParam.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                addMissingParamFixId = "addMissingParam";
                addOptionalParamFixId = "addOptionalParam";
                errorCodes29 = [Diagnostics.Expected_0_arguments_but_got_1.code];
                registerCodeFix({
                    errorCodes: errorCodes29,
                    fixIds: [addMissingParamFixId, addOptionalParamFixId],
                    getCodeActions(context) {
                        const info = getInfo11(context.sourceFile, context.program, context.span.start);
                        if (info === void 0)
                            return void 0;
                        const { name, declarations, newParameters, newOptionalParameters } = info;
                        const actions2 = [];
                        if (length(newParameters)) {
                            append(actions2, createCodeFixAction(addMissingParamFixId, ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange19(t, context.sourceFile, declarations, newParameters)), [length(newParameters) > 1 ? Diagnostics.Add_missing_parameters_to_0 : Diagnostics.Add_missing_parameter_to_0, name], addMissingParamFixId, Diagnostics.Add_all_missing_parameters));
                        }
                        if (length(newOptionalParameters)) {
                            append(actions2, createCodeFixAction(addOptionalParamFixId, ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange19(t, context.sourceFile, declarations, newOptionalParameters)), [length(newOptionalParameters) > 1 ? Diagnostics.Add_optional_parameters_to_0 : Diagnostics.Add_optional_parameter_to_0, name], addOptionalParamFixId, Diagnostics.Add_all_optional_parameters));
                        }
                        return actions2;
                    },
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes29, (changes, diag2) => {
                        const info = getInfo11(context.sourceFile, context.program, diag2.start);
                        if (info) {
                            const { declarations, newParameters, newOptionalParameters } = info;
                            if (context.fixId === addMissingParamFixId) {
                                doChange19(changes, context.sourceFile, declarations, newParameters);
                            }
                            if (context.fixId === addOptionalParamFixId) {
                                doChange19(changes, context.sourceFile, declarations, newOptionalParameters);
                            }
                        }
                    })
                });
            }
        });
        // src/services/codefixes/fixCannotFindModule.ts
        function getInstallCommand(fileName, packageName) {
            return { type: "install package", file: fileName, packageName };
        }
        function tryGetImportedPackageName(sourceFile, pos) {
            const moduleSpecifierText = tryCast(getTokenAtPosition(sourceFile, pos), isStringLiteral);
            if (!moduleSpecifierText)
                return void 0;
            const moduleName = moduleSpecifierText.text;
            const { packageName } = parsePackageName(moduleName);
            return isExternalModuleNameRelative(packageName) ? void 0 : packageName;
        }
        function getTypesPackageNameToInstall(packageName, host, diagCode) {
            var _a;
            return diagCode === errorCodeCannotFindModule ? ts_JsTyping_exports.nodeCoreModules.has(packageName) ? "@types/node" : void 0 : ((_a = host.isKnownTypesPackageName) == null ? void 0 : _a.call(host, packageName)) ? getTypesPackageName(packageName) : void 0;
        }
        var fixName2, fixIdInstallTypesPackage, errorCodeCannotFindModule, errorCodes30;
        var init_fixCannotFindModule = __esm({
            "src/services/codefixes/fixCannotFindModule.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixName2 = "fixCannotFindModule";
                fixIdInstallTypesPackage = "installTypesPackage";
                errorCodeCannotFindModule = Diagnostics.Cannot_find_module_0_or_its_corresponding_type_declarations.code;
                errorCodes30 = [
                    errorCodeCannotFindModule,
                    Diagnostics.Could_not_find_a_declaration_file_for_module_0_1_implicitly_has_an_any_type.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes30,
                    getCodeActions: function getCodeActionsToFixNotFoundModule(context) {
                        const { host, sourceFile, span: { start } } = context;
                        const packageName = tryGetImportedPackageName(sourceFile, start);
                        if (packageName === void 0)
                            return void 0;
                        const typesPackageName = getTypesPackageNameToInstall(packageName, host, context.errorCode);
                        return typesPackageName === void 0 ? [] : [createCodeFixAction(fixName2, 
                            /*changes*/
                            [], [Diagnostics.Install_0, typesPackageName], fixIdInstallTypesPackage, Diagnostics.Install_all_missing_types_packages, getInstallCommand(sourceFile.fileName, typesPackageName))];
                    },
                    fixIds: [fixIdInstallTypesPackage],
                    getAllCodeActions: (context) => {
                        return codeFixAll(context, errorCodes30, (_changes, diag2, commands) => {
                            const packageName = tryGetImportedPackageName(diag2.file, diag2.start);
                            if (packageName === void 0)
                                return void 0;
                            switch (context.fixId) {
                                case fixIdInstallTypesPackage: {
                                    const pkg = getTypesPackageNameToInstall(packageName, context.host, diag2.code);
                                    if (pkg) {
                                        commands.push(getInstallCommand(diag2.file.fileName, pkg));
                                    }
                                    break;
                                }
                                default:
                                    Debug.fail(`Bad fixId: ${context.fixId}`);
                            }
                        });
                    }
                });
            }
        });
        // src/services/codefixes/fixClassDoesntImplementInheritedAbstractMember.ts
        function getClass2(sourceFile, pos) {
            const token = getTokenAtPosition(sourceFile, pos);
            return cast(token.parent, isClassLike);
        }
        function addMissingMembers(classDeclaration, sourceFile, context, changeTracker, preferences) {
            const extendsNode = getEffectiveBaseTypeNode(classDeclaration);
            const checker = context.program.getTypeChecker();
            const instantiatedExtendsType = checker.getTypeAtLocation(extendsNode);
            const abstractAndNonPrivateExtendsSymbols = checker.getPropertiesOfType(instantiatedExtendsType).filter(symbolPointsToNonPrivateAndAbstractMember);
            const importAdder = createImportAdder(sourceFile, context.program, preferences, context.host);
            createMissingMemberNodes(classDeclaration, abstractAndNonPrivateExtendsSymbols, sourceFile, context, preferences, importAdder, (member) => changeTracker.insertMemberAtStart(sourceFile, classDeclaration, member));
            importAdder.writeFixes(changeTracker);
        }
        function symbolPointsToNonPrivateAndAbstractMember(symbol) {
            const flags = getSyntacticModifierFlags(first(symbol.getDeclarations()));
            return !(flags & 2 /* Private */) && !!(flags & 64 /* Abstract */);
        }
        var errorCodes31, fixId25;
        var init_fixClassDoesntImplementInheritedAbstractMember = __esm({
            "src/services/codefixes/fixClassDoesntImplementInheritedAbstractMember.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                errorCodes31 = [
                    Diagnostics.Non_abstract_class_0_does_not_implement_all_abstract_members_of_1.code
                ];
                fixId25 = "fixClassDoesntImplementInheritedAbstractMember";
                registerCodeFix({
                    errorCodes: errorCodes31,
                    getCodeActions: function getCodeActionsToFixClassNotImplementingInheritedMembers(context) {
                        const { sourceFile, span } = context;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => addMissingMembers(getClass2(sourceFile, span.start), sourceFile, context, t, context.preferences));
                        return changes.length === 0 ? void 0 : [createCodeFixAction(fixId25, changes, Diagnostics.Implement_inherited_abstract_class, fixId25, Diagnostics.Implement_all_inherited_abstract_classes)];
                    },
                    fixIds: [fixId25],
                    getAllCodeActions: function getAllCodeActionsToFixClassDoesntImplementInheritedAbstractMember(context) {
                        const seenClassDeclarations = /* @__PURE__ */ new Map();
                        return codeFixAll(context, errorCodes31, (changes, diag2) => {
                            const classDeclaration = getClass2(diag2.file, diag2.start);
                            if (addToSeen(seenClassDeclarations, getNodeId(classDeclaration))) {
                                addMissingMembers(classDeclaration, context.sourceFile, context, changes, context.preferences);
                            }
                        });
                    }
                });
            }
        });
        // src/services/codefixes/fixClassSuperMustPrecedeThisAccess.ts
        function doChange20(changes, sourceFile, constructor, superCall) {
            changes.insertNodeAtConstructorStart(sourceFile, constructor, superCall);
            changes.delete(sourceFile, superCall);
        }
        function getNodes(sourceFile, pos) {
            const token = getTokenAtPosition(sourceFile, pos);
            if (token.kind !== 110 /* ThisKeyword */)
                return void 0;
            const constructor = getContainingFunction(token);
            const superCall = findSuperCall(constructor.body);
            return superCall && !superCall.expression.arguments.some((arg) => isPropertyAccessExpression(arg) && arg.expression === token) ? { constructor, superCall } : void 0;
        }
        function findSuperCall(n) {
            return isExpressionStatement(n) && isSuperCall(n.expression) ? n : isFunctionLike(n) ? void 0 : forEachChild(n, findSuperCall);
        }
        var fixId26, errorCodes32;
        var init_fixClassSuperMustPrecedeThisAccess = __esm({
            "src/services/codefixes/fixClassSuperMustPrecedeThisAccess.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId26 = "classSuperMustPrecedeThisAccess";
                errorCodes32 = [Diagnostics.super_must_be_called_before_accessing_this_in_the_constructor_of_a_derived_class.code];
                registerCodeFix({
                    errorCodes: errorCodes32,
                    getCodeActions(context) {
                        const { sourceFile, span } = context;
                        const nodes = getNodes(sourceFile, span.start);
                        if (!nodes)
                            return void 0;
                        const { constructor, superCall } = nodes;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange20(t, sourceFile, constructor, superCall));
                        return [createCodeFixAction(fixId26, changes, Diagnostics.Make_super_call_the_first_statement_in_the_constructor, fixId26, Diagnostics.Make_all_super_calls_the_first_statement_in_their_constructor)];
                    },
                    fixIds: [fixId26],
                    getAllCodeActions(context) {
                        const { sourceFile } = context;
                        const seenClasses = /* @__PURE__ */ new Map();
                        return codeFixAll(context, errorCodes32, (changes, diag2) => {
                            const nodes = getNodes(diag2.file, diag2.start);
                            if (!nodes)
                                return;
                            const { constructor, superCall } = nodes;
                            if (addToSeen(seenClasses, getNodeId(constructor.parent))) {
                                doChange20(changes, sourceFile, constructor, superCall);
                            }
                        });
                    }
                });
            }
        });
        // src/services/codefixes/fixConstructorForDerivedNeedSuperCall.ts
        function getNode(sourceFile, pos) {
            const token = getTokenAtPosition(sourceFile, pos);
            Debug.assert(isConstructorDeclaration(token.parent), "token should be at the constructor declaration");
            return token.parent;
        }
        function doChange21(changes, sourceFile, ctr) {
            const superCall = factory.createExpressionStatement(factory.createCallExpression(factory.createSuper(), 
            /*typeArguments*/
            void 0, 
            /*argumentsArray*/
            emptyArray));
            changes.insertNodeAtConstructorStart(sourceFile, ctr, superCall);
        }
        var fixId27, errorCodes33;
        var init_fixConstructorForDerivedNeedSuperCall = __esm({
            "src/services/codefixes/fixConstructorForDerivedNeedSuperCall.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId27 = "constructorForDerivedNeedSuperCall";
                errorCodes33 = [Diagnostics.Constructors_for_derived_classes_must_contain_a_super_call.code];
                registerCodeFix({
                    errorCodes: errorCodes33,
                    getCodeActions(context) {
                        const { sourceFile, span } = context;
                        const ctr = getNode(sourceFile, span.start);
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange21(t, sourceFile, ctr));
                        return [createCodeFixAction(fixId27, changes, Diagnostics.Add_missing_super_call, fixId27, Diagnostics.Add_all_missing_super_calls)];
                    },
                    fixIds: [fixId27],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes33, (changes, diag2) => doChange21(changes, context.sourceFile, getNode(diag2.file, diag2.start)))
                });
            }
        });
        // src/services/codefixes/fixEnableJsxFlag.ts
        function doChange22(changeTracker, configFile) {
            setJsonCompilerOptionValue(changeTracker, configFile, "jsx", factory.createStringLiteral("react"));
        }
        var fixID, errorCodes34;
        var init_fixEnableJsxFlag = __esm({
            "src/services/codefixes/fixEnableJsxFlag.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixID = "fixEnableJsxFlag";
                errorCodes34 = [Diagnostics.Cannot_use_JSX_unless_the_jsx_flag_is_provided.code];
                registerCodeFix({
                    errorCodes: errorCodes34,
                    getCodeActions: function getCodeActionsToFixEnableJsxFlag(context) {
                        const { configFile } = context.program.getCompilerOptions();
                        if (configFile === void 0) {
                            return void 0;
                        }
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (changeTracker) => doChange22(changeTracker, configFile));
                        return [
                            createCodeFixActionWithoutFixAll(fixID, changes, Diagnostics.Enable_the_jsx_flag_in_your_configuration_file)
                        ];
                    },
                    fixIds: [fixID],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes34, (changes) => {
                        const { configFile } = context.program.getCompilerOptions();
                        if (configFile === void 0) {
                            return void 0;
                        }
                        doChange22(changes, configFile);
                    })
                });
            }
        });
        // src/services/codefixes/fixNaNEquality.ts
        function getInfo12(program, sourceFile, span) {
            const diag2 = find(program.getSemanticDiagnostics(sourceFile), (diag3) => diag3.start === span.start && diag3.length === span.length);
            if (diag2 === void 0 || diag2.relatedInformation === void 0)
                return;
            const related = find(diag2.relatedInformation, (related2) => related2.code === Diagnostics.Did_you_mean_0.code);
            if (related === void 0 || related.file === void 0 || related.start === void 0 || related.length === void 0)
                return;
            const token = findAncestorMatchingSpan(related.file, createTextSpan(related.start, related.length));
            if (token === void 0)
                return;
            if (isExpression(token) && isBinaryExpression(token.parent)) {
                return { suggestion: getSuggestion(related.messageText), expression: token.parent, arg: token };
            }
            return void 0;
        }
        function doChange23(changes, sourceFile, arg, expression) {
            const callExpression = factory.createCallExpression(factory.createPropertyAccessExpression(factory.createIdentifier("Number"), factory.createIdentifier("isNaN")), 
            /*typeArguments*/
            void 0, [arg]);
            const operator = expression.operatorToken.kind;
            changes.replaceNode(sourceFile, expression, operator === 38 /* ExclamationEqualsEqualsToken */ || operator === 36 /* ExclamationEqualsToken */ ? factory.createPrefixUnaryExpression(54 /* ExclamationToken */, callExpression) : callExpression);
        }
        function getSuggestion(messageText) {
            const [, suggestion] = flattenDiagnosticMessageText(messageText, "\n", 0).match(/'(.*)'/) || [];
            return suggestion;
        }
        var fixId28, errorCodes35;
        var init_fixNaNEquality = __esm({
            "src/services/codefixes/fixNaNEquality.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId28 = "fixNaNEquality";
                errorCodes35 = [
                    Diagnostics.This_condition_will_always_return_0.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes35,
                    getCodeActions(context) {
                        const { sourceFile, span, program } = context;
                        const info = getInfo12(program, sourceFile, span);
                        if (info === void 0)
                            return;
                        const { suggestion, expression, arg } = info;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange23(t, sourceFile, arg, expression));
                        return [createCodeFixAction(fixId28, changes, [Diagnostics.Use_0, suggestion], fixId28, Diagnostics.Use_Number_isNaN_in_all_conditions)];
                    },
                    fixIds: [fixId28],
                    getAllCodeActions: (context) => {
                        return codeFixAll(context, errorCodes35, (changes, diag2) => {
                            const info = getInfo12(context.program, diag2.file, createTextSpan(diag2.start, diag2.length));
                            if (info) {
                                doChange23(changes, diag2.file, info.arg, info.expression);
                            }
                        });
                    }
                });
            }
        });
        // src/services/codefixes/fixModuleAndTargetOptions.ts
        var init_fixModuleAndTargetOptions = __esm({
            "src/services/codefixes/fixModuleAndTargetOptions.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                registerCodeFix({
                    errorCodes: [
                        Diagnostics.Top_level_await_expressions_are_only_allowed_when_the_module_option_is_set_to_es2022_esnext_system_node16_nodenext_or_preserve_and_the_target_option_is_set_to_es2017_or_higher.code,
                        Diagnostics.Top_level_await_using_statements_are_only_allowed_when_the_module_option_is_set_to_es2022_esnext_system_node16_nodenext_or_preserve_and_the_target_option_is_set_to_es2017_or_higher.code,
                        Diagnostics.Top_level_for_await_loops_are_only_allowed_when_the_module_option_is_set_to_es2022_esnext_system_node16_nodenext_or_preserve_and_the_target_option_is_set_to_es2017_or_higher.code
                    ],
                    getCodeActions: function getCodeActionsToFixModuleAndTarget(context) {
                        const compilerOptions = context.program.getCompilerOptions();
                        const { configFile } = compilerOptions;
                        if (configFile === void 0) {
                            return void 0;
                        }
                        const codeFixes = [];
                        const moduleKind = getEmitModuleKind(compilerOptions);
                        const moduleOutOfRange = moduleKind >= 5 /* ES2015 */ && moduleKind < 99 /* ESNext */;
                        if (moduleOutOfRange) {
                            const changes = ts_textChanges_exports.ChangeTracker.with(context, (changes2) => {
                                setJsonCompilerOptionValue(changes2, configFile, "module", factory.createStringLiteral("esnext"));
                            });
                            codeFixes.push(createCodeFixActionWithoutFixAll("fixModuleOption", changes, [Diagnostics.Set_the_module_option_in_your_configuration_file_to_0, "esnext"]));
                        }
                        const target = getEmitScriptTarget(compilerOptions);
                        const targetOutOfRange = target < 4 /* ES2017 */ || target > 99 /* ESNext */;
                        if (targetOutOfRange) {
                            const changes = ts_textChanges_exports.ChangeTracker.with(context, (tracker) => {
                                const configObject = getTsConfigObjectLiteralExpression(configFile);
                                if (!configObject)
                                    return;
                                const options = [["target", factory.createStringLiteral("es2017")]];
                                if (moduleKind === 1 /* CommonJS */) {
                                    options.push(["module", factory.createStringLiteral("commonjs")]);
                                }
                                setJsonCompilerOptionValues(tracker, configFile, options);
                            });
                            codeFixes.push(createCodeFixActionWithoutFixAll("fixTargetOption", changes, [Diagnostics.Set_the_target_option_in_your_configuration_file_to_0, "es2017"]));
                        }
                        return codeFixes.length ? codeFixes : void 0;
                    }
                });
            }
        });
        // src/services/codefixes/fixPropertyAssignment.ts
        function doChange24(changes, sourceFile, node) {
            changes.replaceNode(sourceFile, node, factory.createPropertyAssignment(node.name, node.objectAssignmentInitializer));
        }
        function getProperty2(sourceFile, pos) {
            return cast(getTokenAtPosition(sourceFile, pos).parent, isShorthandPropertyAssignment);
        }
        var fixId29, errorCodes36;
        var init_fixPropertyAssignment = __esm({
            "src/services/codefixes/fixPropertyAssignment.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId29 = "fixPropertyAssignment";
                errorCodes36 = [
                    Diagnostics.Did_you_mean_to_use_a_Colon_An_can_only_follow_a_property_name_when_the_containing_object_literal_is_part_of_a_destructuring_pattern.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes36,
                    fixIds: [fixId29],
                    getCodeActions(context) {
                        const { sourceFile, span } = context;
                        const property = getProperty2(sourceFile, span.start);
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange24(t, context.sourceFile, property));
                        return [createCodeFixAction(fixId29, changes, [Diagnostics.Change_0_to_1, "=", ":"], fixId29, [Diagnostics.Switch_each_misused_0_to_1, "=", ":"])];
                    },
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes36, (changes, diag2) => doChange24(changes, diag2.file, getProperty2(diag2.file, diag2.start)))
                });
            }
        });
        // src/services/codefixes/fixExtendsInterfaceBecomesImplements.ts
        function getNodes2(sourceFile, pos) {
            const token = getTokenAtPosition(sourceFile, pos);
            const heritageClauses = getContainingClass(token).heritageClauses;
            const extendsToken = heritageClauses[0].getFirstToken();
            return extendsToken.kind === 96 /* ExtendsKeyword */ ? { extendsToken, heritageClauses } : void 0;
        }
        function doChanges2(changes, sourceFile, extendsToken, heritageClauses) {
            changes.replaceNode(sourceFile, extendsToken, factory.createToken(119 /* ImplementsKeyword */));
            if (heritageClauses.length === 2 && heritageClauses[0].token === 96 /* ExtendsKeyword */ && heritageClauses[1].token === 119 /* ImplementsKeyword */) {
                const implementsToken = heritageClauses[1].getFirstToken();
                const implementsFullStart = implementsToken.getFullStart();
                changes.replaceRange(sourceFile, { pos: implementsFullStart, end: implementsFullStart }, factory.createToken(28 /* CommaToken */));
                const text = sourceFile.text;
                let end = implementsToken.end;
                while (end < text.length && isWhiteSpaceSingleLine(text.charCodeAt(end))) {
                    end++;
                }
                changes.deleteRange(sourceFile, { pos: implementsToken.getStart(), end });
            }
        }
        var fixId30, errorCodes37;
        var init_fixExtendsInterfaceBecomesImplements = __esm({
            "src/services/codefixes/fixExtendsInterfaceBecomesImplements.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId30 = "extendsInterfaceBecomesImplements";
                errorCodes37 = [Diagnostics.Cannot_extend_an_interface_0_Did_you_mean_implements.code];
                registerCodeFix({
                    errorCodes: errorCodes37,
                    getCodeActions(context) {
                        const { sourceFile } = context;
                        const nodes = getNodes2(sourceFile, context.span.start);
                        if (!nodes)
                            return void 0;
                        const { extendsToken, heritageClauses } = nodes;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChanges2(t, sourceFile, extendsToken, heritageClauses));
                        return [createCodeFixAction(fixId30, changes, Diagnostics.Change_extends_to_implements, fixId30, Diagnostics.Change_all_extended_interfaces_to_implements)];
                    },
                    fixIds: [fixId30],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes37, (changes, diag2) => {
                        const nodes = getNodes2(diag2.file, diag2.start);
                        if (nodes)
                            doChanges2(changes, diag2.file, nodes.extendsToken, nodes.heritageClauses);
                    })
                });
            }
        });
        // src/services/codefixes/fixForgottenThisPropertyAccess.ts
        function getInfo13(sourceFile, pos, diagCode) {
            const node = getTokenAtPosition(sourceFile, pos);
            if (isIdentifier(node) || isPrivateIdentifier(node)) {
                return { node, className: diagCode === didYouMeanStaticMemberCode ? getContainingClass(node).name.text : void 0 };
            }
        }
        function doChange25(changes, sourceFile, { node, className }) {
            suppressLeadingAndTrailingTrivia(node);
            changes.replaceNode(sourceFile, node, factory.createPropertyAccessExpression(className ? factory.createIdentifier(className) : factory.createThis(), node));
        }
        var fixId31, didYouMeanStaticMemberCode, errorCodes38;
        var init_fixForgottenThisPropertyAccess = __esm({
            "src/services/codefixes/fixForgottenThisPropertyAccess.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId31 = "forgottenThisPropertyAccess";
                didYouMeanStaticMemberCode = Diagnostics.Cannot_find_name_0_Did_you_mean_the_static_member_1_0.code;
                errorCodes38 = [
                    Diagnostics.Cannot_find_name_0_Did_you_mean_the_instance_member_this_0.code,
                    Diagnostics.Private_identifiers_are_only_allowed_in_class_bodies_and_may_only_be_used_as_part_of_a_class_member_declaration_property_access_or_on_the_left_hand_side_of_an_in_expression.code,
                    didYouMeanStaticMemberCode
                ];
                registerCodeFix({
                    errorCodes: errorCodes38,
                    getCodeActions(context) {
                        const { sourceFile } = context;
                        const info = getInfo13(sourceFile, context.span.start, context.errorCode);
                        if (!info) {
                            return void 0;
                        }
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange25(t, sourceFile, info));
                        return [createCodeFixAction(fixId31, changes, [Diagnostics.Add_0_to_unresolved_variable, info.className || "this"], fixId31, Diagnostics.Add_qualifier_to_all_unresolved_variables_matching_a_member_name)];
                    },
                    fixIds: [fixId31],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes38, (changes, diag2) => {
                        const info = getInfo13(diag2.file, diag2.start, diag2.code);
                        if (info)
                            doChange25(changes, context.sourceFile, info);
                    })
                });
            }
        });
        // src/services/codefixes/fixInvalidJsxCharacters.ts
        function isValidCharacter(character) {
            return hasProperty(htmlEntity, character);
        }
        function doChange26(changes, preferences, sourceFile, start, useHtmlEntity) {
            const character = sourceFile.getText()[start];
            if (!isValidCharacter(character)) {
                return;
            }
            const replacement = useHtmlEntity ? htmlEntity[character] : `{${quote(sourceFile, preferences, character)}}`;
            changes.replaceRangeWithText(sourceFile, { pos: start, end: start + 1 }, replacement);
        }
        var fixIdExpression, fixIdHtmlEntity, errorCodes39, htmlEntity;
        var init_fixInvalidJsxCharacters = __esm({
            "src/services/codefixes/fixInvalidJsxCharacters.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixIdExpression = "fixInvalidJsxCharacters_expression";
                fixIdHtmlEntity = "fixInvalidJsxCharacters_htmlEntity";
                errorCodes39 = [
                    Diagnostics.Unexpected_token_Did_you_mean_or_gt.code,
                    Diagnostics.Unexpected_token_Did_you_mean_or_rbrace.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes39,
                    fixIds: [fixIdExpression, fixIdHtmlEntity],
                    getCodeActions(context) {
                        const { sourceFile, preferences, span } = context;
                        const changeToExpression = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange26(t, preferences, sourceFile, span.start, 
                        /*useHtmlEntity*/
                        false));
                        const changeToHtmlEntity = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange26(t, preferences, sourceFile, span.start, 
                        /*useHtmlEntity*/
                        true));
                        return [
                            createCodeFixAction(fixIdExpression, changeToExpression, Diagnostics.Wrap_invalid_character_in_an_expression_container, fixIdExpression, Diagnostics.Wrap_all_invalid_characters_in_an_expression_container),
                            createCodeFixAction(fixIdHtmlEntity, changeToHtmlEntity, Diagnostics.Convert_invalid_character_to_its_html_entity_code, fixIdHtmlEntity, Diagnostics.Convert_all_invalid_characters_to_HTML_entity_code)
                        ];
                    },
                    getAllCodeActions(context) {
                        return codeFixAll(context, errorCodes39, (changes, diagnostic) => doChange26(changes, context.preferences, diagnostic.file, diagnostic.start, context.fixId === fixIdHtmlEntity));
                    }
                });
                htmlEntity = {
                    ">": "&gt;",
                    "}": "&rbrace;"
                };
            }
        });
        // src/services/codefixes/fixUnmatchedParameter.ts
        function getDeleteAction(context, { name, jsDocHost, jsDocParameterTag }) {
            const changes = ts_textChanges_exports.ChangeTracker.with(context, (changeTracker) => changeTracker.filterJSDocTags(context.sourceFile, jsDocHost, (t) => t !== jsDocParameterTag));
            return createCodeFixAction(deleteUnmatchedParameter, changes, [Diagnostics.Delete_unused_param_tag_0, name.getText(context.sourceFile)], deleteUnmatchedParameter, Diagnostics.Delete_all_unused_param_tags);
        }
        function getRenameAction(context, { name, jsDocHost, signature, jsDocParameterTag }) {
            if (!length(signature.parameters))
                return void 0;
            const sourceFile = context.sourceFile;
            const tags = getJSDocTags(signature);
            const names = /* @__PURE__ */ new Set();
            for (const tag of tags) {
                if (isJSDocParameterTag(tag) && isIdentifier(tag.name)) {
                    names.add(tag.name.escapedText);
                }
            }
            const parameterName = firstDefined(signature.parameters, (p) => isIdentifier(p.name) && !names.has(p.name.escapedText) ? p.name.getText(sourceFile) : void 0);
            if (parameterName === void 0)
                return void 0;
            const newJSDocParameterTag = factory.updateJSDocParameterTag(jsDocParameterTag, jsDocParameterTag.tagName, factory.createIdentifier(parameterName), jsDocParameterTag.isBracketed, jsDocParameterTag.typeExpression, jsDocParameterTag.isNameFirst, jsDocParameterTag.comment);
            const changes = ts_textChanges_exports.ChangeTracker.with(context, (changeTracker) => changeTracker.replaceJSDocComment(sourceFile, jsDocHost, map(tags, (t) => t === jsDocParameterTag ? newJSDocParameterTag : t)));
            return createCodeFixActionWithoutFixAll(renameUnmatchedParameter, changes, [Diagnostics.Rename_param_tag_name_0_to_1, name.getText(sourceFile), parameterName]);
        }
        function getInfo14(sourceFile, pos) {
            const token = getTokenAtPosition(sourceFile, pos);
            if (token.parent && isJSDocParameterTag(token.parent) && isIdentifier(token.parent.name)) {
                const jsDocParameterTag = token.parent;
                const jsDocHost = getJSDocHost(jsDocParameterTag);
                const signature = getHostSignatureFromJSDoc(jsDocParameterTag);
                if (jsDocHost && signature) {
                    return { jsDocHost, signature, name: token.parent.name, jsDocParameterTag };
                }
            }
            return void 0;
        }
        var deleteUnmatchedParameter, renameUnmatchedParameter, errorCodes40;
        var init_fixUnmatchedParameter = __esm({
            "src/services/codefixes/fixUnmatchedParameter.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                deleteUnmatchedParameter = "deleteUnmatchedParameter";
                renameUnmatchedParameter = "renameUnmatchedParameter";
                errorCodes40 = [
                    Diagnostics.JSDoc_param_tag_has_name_0_but_there_is_no_parameter_with_that_name.code
                ];
                registerCodeFix({
                    fixIds: [deleteUnmatchedParameter, renameUnmatchedParameter],
                    errorCodes: errorCodes40,
                    getCodeActions: function getCodeActionsToFixUnmatchedParameter(context) {
                        const { sourceFile, span } = context;
                        const actions2 = [];
                        const info = getInfo14(sourceFile, span.start);
                        if (info) {
                            append(actions2, getDeleteAction(context, info));
                            append(actions2, getRenameAction(context, info));
                            return actions2;
                        }
                        return void 0;
                    },
                    getAllCodeActions: function getAllCodeActionsToFixUnmatchedParameter(context) {
                        const tagsToSignature = /* @__PURE__ */ new Map();
                        return createCombinedCodeActions(ts_textChanges_exports.ChangeTracker.with(context, (changes) => {
                            eachDiagnostic(context, errorCodes40, ({ file, start }) => {
                                const info = getInfo14(file, start);
                                if (info) {
                                    tagsToSignature.set(info.signature, append(tagsToSignature.get(info.signature), info.jsDocParameterTag));
                                }
                            });
                            tagsToSignature.forEach((tags, signature) => {
                                if (context.fixId === deleteUnmatchedParameter) {
                                    const tagsSet = new Set(tags);
                                    changes.filterJSDocTags(signature.getSourceFile(), signature, (t) => !tagsSet.has(t));
                                }
                            });
                        }));
                    }
                });
            }
        });
        // src/services/codefixes/fixUnreferenceableDecoratorMetadata.ts
        function getImportDeclaration(sourceFile, program, start) {
            const identifier = tryCast(getTokenAtPosition(sourceFile, start), isIdentifier);
            if (!identifier || identifier.parent.kind !== 183 /* TypeReference */)
                return;
            const checker = program.getTypeChecker();
            const symbol = checker.getSymbolAtLocation(identifier);
            return find((symbol == null ? void 0 : symbol.declarations) || emptyArray, or(isImportClause, isImportSpecifier, isImportEqualsDeclaration));
        }
        function doTypeOnlyImportChange(changes, sourceFile, importDeclaration, program) {
            if (importDeclaration.kind === 271 /* ImportEqualsDeclaration */) {
                changes.insertModifierBefore(sourceFile, 156 /* TypeKeyword */, importDeclaration.name);
                return;
            }
            const importClause = importDeclaration.kind === 273 /* ImportClause */ ? importDeclaration : importDeclaration.parent.parent;
            if (importClause.name && importClause.namedBindings) {
                return;
            }
            const checker = program.getTypeChecker();
            const importsValue = !!forEachImportClauseDeclaration(importClause, (decl) => {
                if (skipAlias(decl.symbol, checker).flags & 111551 /* Value */)
                    return true;
            });
            if (importsValue) {
                return;
            }
            changes.insertModifierBefore(sourceFile, 156 /* TypeKeyword */, importClause);
        }
        function doNamespaceImportChange(changes, sourceFile, importDeclaration, program) {
            ts_refactor_exports.doChangeNamedToNamespaceOrDefault(sourceFile, program, changes, importDeclaration.parent);
        }
        var fixId32, errorCodes41;
        var init_fixUnreferenceableDecoratorMetadata = __esm({
            "src/services/codefixes/fixUnreferenceableDecoratorMetadata.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId32 = "fixUnreferenceableDecoratorMetadata";
                errorCodes41 = [Diagnostics.A_type_referenced_in_a_decorated_signature_must_be_imported_with_import_type_or_a_namespace_import_when_isolatedModules_and_emitDecoratorMetadata_are_enabled.code];
                registerCodeFix({
                    errorCodes: errorCodes41,
                    getCodeActions: (context) => {
                        const importDeclaration = getImportDeclaration(context.sourceFile, context.program, context.span.start);
                        if (!importDeclaration)
                            return;
                        const namespaceChanges = ts_textChanges_exports.ChangeTracker.with(context, (t) => importDeclaration.kind === 276 /* ImportSpecifier */ && doNamespaceImportChange(t, context.sourceFile, importDeclaration, context.program));
                        const typeOnlyChanges = ts_textChanges_exports.ChangeTracker.with(context, (t) => doTypeOnlyImportChange(t, context.sourceFile, importDeclaration, context.program));
                        let actions2;
                        if (namespaceChanges.length) {
                            actions2 = append(actions2, createCodeFixActionWithoutFixAll(fixId32, namespaceChanges, Diagnostics.Convert_named_imports_to_namespace_import));
                        }
                        if (typeOnlyChanges.length) {
                            actions2 = append(actions2, createCodeFixActionWithoutFixAll(fixId32, typeOnlyChanges, Diagnostics.Use_import_type));
                        }
                        return actions2;
                    },
                    fixIds: [fixId32]
                });
            }
        });
        // src/services/codefixes/fixUnusedIdentifier.ts
        function changeInferToUnknown(changes, sourceFile, token) {
            changes.replaceNode(sourceFile, token.parent, factory.createKeywordTypeNode(159 /* UnknownKeyword */));
        }
        function createDeleteFix(changes, diag2) {
            return createCodeFixAction(fixName3, changes, diag2, fixIdDelete, Diagnostics.Delete_all_unused_declarations);
        }
        function deleteTypeParameters(changes, sourceFile, token) {
            changes.delete(sourceFile, Debug.checkDefined(cast(token.parent, isDeclarationWithTypeParameterChildren).typeParameters, "The type parameter to delete should exist"));
        }
        function isImport(token) {
            return token.kind === 102 /* ImportKeyword */ || token.kind === 80 /* Identifier */ && (token.parent.kind === 276 /* ImportSpecifier */ || token.parent.kind === 273 /* ImportClause */);
        }
        function tryGetFullImport(token) {
            return token.kind === 102 /* ImportKeyword */ ? tryCast(token.parent, isImportDeclaration) : void 0;
        }
        function canDeleteEntireVariableStatement(sourceFile, token) {
            return isVariableDeclarationList(token.parent) && first(token.parent.getChildren(sourceFile)) === token;
        }
        function deleteEntireVariableStatement(changes, sourceFile, node) {
            changes.delete(sourceFile, node.parent.kind === 243 /* VariableStatement */ ? node.parent : node);
        }
        function deleteDestructuringElements(changes, sourceFile, node) {
            forEach(node.elements, (n) => changes.delete(sourceFile, n));
        }
        function deleteDestructuring(context, changes, sourceFile, { parent: parent2 }) {
            if (isVariableDeclaration(parent2) && parent2.initializer && isCallLikeExpression(parent2.initializer)) {
                if (isVariableDeclarationList(parent2.parent) && length(parent2.parent.declarations) > 1) {
                    const varStatement = parent2.parent.parent;
                    const pos = varStatement.getStart(sourceFile);
                    const end = varStatement.end;
                    changes.delete(sourceFile, parent2);
                    changes.insertNodeAt(sourceFile, end, parent2.initializer, {
                        prefix: getNewLineOrDefaultFromHost(context.host, context.formatContext.options) + sourceFile.text.slice(getPrecedingNonSpaceCharacterPosition(sourceFile.text, pos - 1), pos),
                        suffix: probablyUsesSemicolons(sourceFile) ? ";" : ""
                    });
                }
                else {
                    changes.replaceNode(sourceFile, parent2.parent, parent2.initializer);
                }
            }
            else {
                changes.delete(sourceFile, parent2);
            }
        }
        function tryPrefixDeclaration(changes, errorCode, sourceFile, token) {
            if (errorCode === Diagnostics.Property_0_is_declared_but_its_value_is_never_read.code)
                return;
            if (token.kind === 140 /* InferKeyword */) {
                token = cast(token.parent, isInferTypeNode).typeParameter.name;
            }
            if (isIdentifier(token) && canPrefix(token)) {
                changes.replaceNode(sourceFile, token, factory.createIdentifier(`_${token.text}`));
                if (isParameter(token.parent)) {
                    getJSDocParameterTags(token.parent).forEach((tag) => {
                        if (isIdentifier(tag.name)) {
                            changes.replaceNode(sourceFile, tag.name, factory.createIdentifier(`_${tag.name.text}`));
                        }
                    });
                }
            }
        }
        function canPrefix(token) {
            switch (token.parent.kind) {
                case 169 /* Parameter */:
                case 168 /* TypeParameter */:
                    return true;
                case 260 /* VariableDeclaration */: {
                    const varDecl = token.parent;
                    switch (varDecl.parent.parent.kind) {
                        case 250 /* ForOfStatement */:
                        case 249 /* ForInStatement */:
                            return true;
                    }
                }
            }
            return false;
        }
        function tryDeleteDeclaration(sourceFile, token, changes, checker, sourceFiles, program, cancellationToken, isFixAll) {
            tryDeleteDeclarationWorker(token, changes, sourceFile, checker, sourceFiles, program, cancellationToken, isFixAll);
            if (isIdentifier(token)) {
                ts_FindAllReferences_exports.Core.eachSymbolReferenceInFile(token, checker, sourceFile, (ref) => {
                    if (isPropertyAccessExpression(ref.parent) && ref.parent.name === ref)
                        ref = ref.parent;
                    if (!isFixAll && mayDeleteExpression(ref)) {
                        changes.delete(sourceFile, ref.parent.parent);
                    }
                });
            }
        }
        function tryDeleteDeclarationWorker(token, changes, sourceFile, checker, sourceFiles, program, cancellationToken, isFixAll) {
            const { parent: parent2 } = token;
            if (isParameter(parent2)) {
                tryDeleteParameter(changes, sourceFile, parent2, checker, sourceFiles, program, cancellationToken, isFixAll);
            }
            else if (!(isFixAll && isIdentifier(token) && ts_FindAllReferences_exports.Core.isSymbolReferencedInFile(token, checker, sourceFile))) {
                const node = isImportClause(parent2) ? token : isComputedPropertyName(parent2) ? parent2.parent : parent2;
                Debug.assert(node !== sourceFile, "should not delete whole source file");
                changes.delete(sourceFile, node);
            }
        }
        function tryDeleteParameter(changes, sourceFile, parameter, checker, sourceFiles, program, cancellationToken, isFixAll = false) {
            if (mayDeleteParameter(checker, sourceFile, parameter, sourceFiles, program, cancellationToken, isFixAll)) {
                if (parameter.modifiers && parameter.modifiers.length > 0 && (!isIdentifier(parameter.name) || ts_FindAllReferences_exports.Core.isSymbolReferencedInFile(parameter.name, checker, sourceFile))) {
                    for (const modifier of parameter.modifiers) {
                        if (isModifier(modifier)) {
                            changes.deleteModifier(sourceFile, modifier);
                        }
                    }
                }
                else if (!parameter.initializer && isNotProvidedArguments(parameter, checker, sourceFiles)) {
                    changes.delete(sourceFile, parameter);
                }
            }
        }
        function isNotProvidedArguments(parameter, checker, sourceFiles) {
            const index = parameter.parent.parameters.indexOf(parameter);
            return !ts_FindAllReferences_exports.Core.someSignatureUsage(parameter.parent, sourceFiles, checker, (_, call) => !call || call.arguments.length > index);
        }
        function mayDeleteParameter(checker, sourceFile, parameter, sourceFiles, program, cancellationToken, isFixAll) {
            const { parent: parent2 } = parameter;
            switch (parent2.kind) {
                case 174 /* MethodDeclaration */:
                case 176 /* Constructor */:
                    const index = parent2.parameters.indexOf(parameter);
                    const referent = isMethodDeclaration(parent2) ? parent2.name : parent2;
                    const entries = ts_FindAllReferences_exports.Core.getReferencedSymbolsForNode(parent2.pos, referent, program, sourceFiles, cancellationToken);
                    if (entries) {
                        for (const entry of entries) {
                            for (const reference of entry.references) {
                                if (reference.kind === ts_FindAllReferences_exports.EntryKind.Node) {
                                    const isSuperCall2 = isSuperKeyword(reference.node) && isCallExpression(reference.node.parent) && reference.node.parent.arguments.length > index;
                                    const isSuperMethodCall = isPropertyAccessExpression(reference.node.parent) && isSuperKeyword(reference.node.parent.expression) && isCallExpression(reference.node.parent.parent) && reference.node.parent.parent.arguments.length > index;
                                    const isOverriddenMethod = (isMethodDeclaration(reference.node.parent) || isMethodSignature(reference.node.parent)) && reference.node.parent !== parameter.parent && reference.node.parent.parameters.length > index;
                                    if (isSuperCall2 || isSuperMethodCall || isOverriddenMethod)
                                        return false;
                                }
                            }
                        }
                    }
                    return true;
                case 262 /* FunctionDeclaration */: {
                    if (parent2.name && isCallbackLike(checker, sourceFile, parent2.name)) {
                        return isLastParameter(parent2, parameter, isFixAll);
                    }
                    return true;
                }
                case 218 /* FunctionExpression */:
                case 219 /* ArrowFunction */:
                    return isLastParameter(parent2, parameter, isFixAll);
                case 178 /* SetAccessor */:
                    return false;
                case 177 /* GetAccessor */:
                    return true;
                default:
                    return Debug.failBadSyntaxKind(parent2);
            }
        }
        function isCallbackLike(checker, sourceFile, name) {
            return !!ts_FindAllReferences_exports.Core.eachSymbolReferenceInFile(name, checker, sourceFile, (reference) => isIdentifier(reference) && isCallExpression(reference.parent) && reference.parent.arguments.includes(reference));
        }
        function isLastParameter(func, parameter, isFixAll) {
            const parameters = func.parameters;
            const index = parameters.indexOf(parameter);
            Debug.assert(index !== -1, "The parameter should already be in the list");
            return isFixAll ? parameters.slice(index + 1).every((p) => isIdentifier(p.name) && !p.symbol.isReferenced) : index === parameters.length - 1;
        }
        function mayDeleteExpression(node) {
            return (isBinaryExpression(node.parent) && node.parent.left === node || (isPostfixUnaryExpression(node.parent) || isPrefixUnaryExpression(node.parent)) && node.parent.operand === node) && isExpressionStatement(node.parent.parent);
        }
        var fixName3, fixIdPrefix, fixIdDelete, fixIdDeleteImports, fixIdInfer, errorCodes42;
        var init_fixUnusedIdentifier = __esm({
            "src/services/codefixes/fixUnusedIdentifier.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixName3 = "unusedIdentifier";
                fixIdPrefix = "unusedIdentifier_prefix";
                fixIdDelete = "unusedIdentifier_delete";
                fixIdDeleteImports = "unusedIdentifier_deleteImports";
                fixIdInfer = "unusedIdentifier_infer";
                errorCodes42 = [
                    Diagnostics._0_is_declared_but_its_value_is_never_read.code,
                    Diagnostics._0_is_declared_but_never_used.code,
                    Diagnostics.Property_0_is_declared_but_its_value_is_never_read.code,
                    Diagnostics.All_imports_in_import_declaration_are_unused.code,
                    Diagnostics.All_destructured_elements_are_unused.code,
                    Diagnostics.All_variables_are_unused.code,
                    Diagnostics.All_type_parameters_are_unused.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes42,
                    getCodeActions(context) {
                        const { errorCode, sourceFile, program, cancellationToken } = context;
                        const checker = program.getTypeChecker();
                        const sourceFiles = program.getSourceFiles();
                        const token = getTokenAtPosition(sourceFile, context.span.start);
                        if (isJSDocTemplateTag(token)) {
                            return [createDeleteFix(ts_textChanges_exports.ChangeTracker.with(context, (t) => t.delete(sourceFile, token)), Diagnostics.Remove_template_tag)];
                        }
                        if (token.kind === 30 /* LessThanToken */) {
                            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => deleteTypeParameters(t, sourceFile, token));
                            return [createDeleteFix(changes, Diagnostics.Remove_type_parameters)];
                        }
                        const importDecl = tryGetFullImport(token);
                        if (importDecl) {
                            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => t.delete(sourceFile, importDecl));
                            return [createCodeFixAction(fixName3, changes, [Diagnostics.Remove_import_from_0, showModuleSpecifier(importDecl)], fixIdDeleteImports, Diagnostics.Delete_all_unused_imports)];
                        }
                        else if (isImport(token)) {
                            const deletion = ts_textChanges_exports.ChangeTracker.with(context, (t) => tryDeleteDeclaration(sourceFile, token, t, checker, sourceFiles, program, cancellationToken, 
                            /*isFixAll*/
                            false));
                            if (deletion.length) {
                                return [createCodeFixAction(fixName3, deletion, [Diagnostics.Remove_unused_declaration_for_Colon_0, token.getText(sourceFile)], fixIdDeleteImports, Diagnostics.Delete_all_unused_imports)];
                            }
                        }
                        if (isObjectBindingPattern(token.parent) || isArrayBindingPattern(token.parent)) {
                            if (isParameter(token.parent.parent)) {
                                const elements = token.parent.elements;
                                const diagnostic = [
                                    elements.length > 1 ? Diagnostics.Remove_unused_declarations_for_Colon_0 : Diagnostics.Remove_unused_declaration_for_Colon_0,
                                    map(elements, (e) => e.getText(sourceFile)).join(", ")
                                ];
                                return [
                                    createDeleteFix(ts_textChanges_exports.ChangeTracker.with(context, (t) => deleteDestructuringElements(t, sourceFile, token.parent)), diagnostic)
                                ];
                            }
                            return [
                                createDeleteFix(ts_textChanges_exports.ChangeTracker.with(context, (t) => deleteDestructuring(context, t, sourceFile, token.parent)), Diagnostics.Remove_unused_destructuring_declaration)
                            ];
                        }
                        if (canDeleteEntireVariableStatement(sourceFile, token)) {
                            return [
                                createDeleteFix(ts_textChanges_exports.ChangeTracker.with(context, (t) => deleteEntireVariableStatement(t, sourceFile, token.parent)), Diagnostics.Remove_variable_statement)
                            ];
                        }
                        const result = [];
                        if (token.kind === 140 /* InferKeyword */) {
                            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => changeInferToUnknown(t, sourceFile, token));
                            const name = cast(token.parent, isInferTypeNode).typeParameter.name.text;
                            result.push(createCodeFixAction(fixName3, changes, [Diagnostics.Replace_infer_0_with_unknown, name], fixIdInfer, Diagnostics.Replace_all_unused_infer_with_unknown));
                        }
                        else {
                            const deletion = ts_textChanges_exports.ChangeTracker.with(context, (t) => tryDeleteDeclaration(sourceFile, token, t, checker, sourceFiles, program, cancellationToken, 
                            /*isFixAll*/
                            false));
                            if (deletion.length) {
                                const name = isComputedPropertyName(token.parent) ? token.parent : token;
                                result.push(createDeleteFix(deletion, [Diagnostics.Remove_unused_declaration_for_Colon_0, name.getText(sourceFile)]));
                            }
                        }
                        const prefix = ts_textChanges_exports.ChangeTracker.with(context, (t) => tryPrefixDeclaration(t, errorCode, sourceFile, token));
                        if (prefix.length) {
                            result.push(createCodeFixAction(fixName3, prefix, [Diagnostics.Prefix_0_with_an_underscore, token.getText(sourceFile)], fixIdPrefix, Diagnostics.Prefix_all_unused_declarations_with_where_possible));
                        }
                        return result;
                    },
                    fixIds: [fixIdPrefix, fixIdDelete, fixIdDeleteImports, fixIdInfer],
                    getAllCodeActions: (context) => {
                        const { sourceFile, program, cancellationToken } = context;
                        const checker = program.getTypeChecker();
                        const sourceFiles = program.getSourceFiles();
                        return codeFixAll(context, errorCodes42, (changes, diag2) => {
                            const token = getTokenAtPosition(sourceFile, diag2.start);
                            switch (context.fixId) {
                                case fixIdPrefix:
                                    tryPrefixDeclaration(changes, diag2.code, sourceFile, token);
                                    break;
                                case fixIdDeleteImports: {
                                    const importDecl = tryGetFullImport(token);
                                    if (importDecl) {
                                        changes.delete(sourceFile, importDecl);
                                    }
                                    else if (isImport(token)) {
                                        tryDeleteDeclaration(sourceFile, token, changes, checker, sourceFiles, program, cancellationToken, 
                                        /*isFixAll*/
                                        true);
                                    }
                                    break;
                                }
                                case fixIdDelete: {
                                    if (token.kind === 140 /* InferKeyword */ || isImport(token)) {
                                        break;
                                    }
                                    else if (isJSDocTemplateTag(token)) {
                                        changes.delete(sourceFile, token);
                                    }
                                    else if (token.kind === 30 /* LessThanToken */) {
                                        deleteTypeParameters(changes, sourceFile, token);
                                    }
                                    else if (isObjectBindingPattern(token.parent)) {
                                        if (token.parent.parent.initializer) {
                                            break;
                                        }
                                        else if (!isParameter(token.parent.parent) || isNotProvidedArguments(token.parent.parent, checker, sourceFiles)) {
                                            changes.delete(sourceFile, token.parent.parent);
                                        }
                                    }
                                    else if (isArrayBindingPattern(token.parent.parent) && token.parent.parent.parent.initializer) {
                                        break;
                                    }
                                    else if (canDeleteEntireVariableStatement(sourceFile, token)) {
                                        deleteEntireVariableStatement(changes, sourceFile, token.parent);
                                    }
                                    else {
                                        tryDeleteDeclaration(sourceFile, token, changes, checker, sourceFiles, program, cancellationToken, 
                                        /*isFixAll*/
                                        true);
                                    }
                                    break;
                                }
                                case fixIdInfer:
                                    if (token.kind === 140 /* InferKeyword */) {
                                        changeInferToUnknown(changes, sourceFile, token);
                                    }
                                    break;
                                default:
                                    Debug.fail(JSON.stringify(context.fixId));
                            }
                        });
                    }
                });
            }
        });
        // src/services/codefixes/fixUnreachableCode.ts
        function doChange27(changes, sourceFile, start, length2, errorCode) {
            const token = getTokenAtPosition(sourceFile, start);
            const statement = findAncestor(token, isStatement);
            if (statement.getStart(sourceFile) !== token.getStart(sourceFile)) {
                const logData = JSON.stringify({
                    statementKind: Debug.formatSyntaxKind(statement.kind),
                    tokenKind: Debug.formatSyntaxKind(token.kind),
                    errorCode,
                    start,
                    length: length2
                });
                Debug.fail("Token and statement should start at the same point. " + logData);
            }
            const container = (isBlock(statement.parent) ? statement.parent : statement).parent;
            if (!isBlock(statement.parent) || statement === first(statement.parent.statements)) {
                switch (container.kind) {
                    case 245 /* IfStatement */:
                        if (container.elseStatement) {
                            if (isBlock(statement.parent)) {
                                break;
                            }
                            else {
                                changes.replaceNode(sourceFile, statement, factory.createBlock(emptyArray));
                            }
                            return;
                        }
                    case 247 /* WhileStatement */:
                    case 248 /* ForStatement */:
                        changes.delete(sourceFile, container);
                        return;
                }
            }
            if (isBlock(statement.parent)) {
                const end = start + length2;
                const lastStatement = Debug.checkDefined(lastWhere(sliceAfter(statement.parent.statements, statement), (s) => s.pos < end), "Some statement should be last");
                changes.deleteNodeRange(sourceFile, statement, lastStatement);
            }
            else {
                changes.delete(sourceFile, statement);
            }
        }
        function lastWhere(a, pred) {
            let last2;
            for (const value of a) {
                if (!pred(value))
                    break;
                last2 = value;
            }
            return last2;
        }
        var fixId33, errorCodes43;
        var init_fixUnreachableCode = __esm({
            "src/services/codefixes/fixUnreachableCode.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId33 = "fixUnreachableCode";
                errorCodes43 = [Diagnostics.Unreachable_code_detected.code];
                registerCodeFix({
                    errorCodes: errorCodes43,
                    getCodeActions(context) {
                        const syntacticDiagnostics = context.program.getSyntacticDiagnostics(context.sourceFile, context.cancellationToken);
                        if (syntacticDiagnostics.length)
                            return;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange27(t, context.sourceFile, context.span.start, context.span.length, context.errorCode));
                        return [createCodeFixAction(fixId33, changes, Diagnostics.Remove_unreachable_code, fixId33, Diagnostics.Remove_all_unreachable_code)];
                    },
                    fixIds: [fixId33],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes43, (changes, diag2) => doChange27(changes, diag2.file, diag2.start, diag2.length, diag2.code))
                });
            }
        });
        // src/services/codefixes/fixUnusedLabel.ts
        function doChange28(changes, sourceFile, start) {
            const token = getTokenAtPosition(sourceFile, start);
            const labeledStatement = cast(token.parent, isLabeledStatement);
            const pos = token.getStart(sourceFile);
            const statementPos = labeledStatement.statement.getStart(sourceFile);
            const end = positionsAreOnSameLine(pos, statementPos, sourceFile) ? statementPos : skipTrivia(sourceFile.text, findChildOfKind(labeledStatement, 59 /* ColonToken */, sourceFile).end, 
            /*stopAfterLineBreak*/
            true);
            changes.deleteRange(sourceFile, { pos, end });
        }
        var fixId34, errorCodes44;
        var init_fixUnusedLabel = __esm({
            "src/services/codefixes/fixUnusedLabel.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId34 = "fixUnusedLabel";
                errorCodes44 = [Diagnostics.Unused_label.code];
                registerCodeFix({
                    errorCodes: errorCodes44,
                    getCodeActions(context) {
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange28(t, context.sourceFile, context.span.start));
                        return [createCodeFixAction(fixId34, changes, Diagnostics.Remove_unused_label, fixId34, Diagnostics.Remove_all_unused_labels)];
                    },
                    fixIds: [fixId34],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes44, (changes, diag2) => doChange28(changes, diag2.file, diag2.start))
                });
            }
        });
        // src/services/codefixes/fixJSDocTypes.ts
        function doChange29(changes, sourceFile, oldTypeNode, newType, checker) {
            changes.replaceNode(sourceFile, oldTypeNode, checker.typeToTypeNode(newType, 
            /*enclosingDeclaration*/
            oldTypeNode, 
            /*flags*/
            void 0));
        }
        function getInfo15(sourceFile, pos, checker) {
            const decl = findAncestor(getTokenAtPosition(sourceFile, pos), isTypeContainer);
            const typeNode = decl && decl.type;
            return typeNode && { typeNode, type: getType(checker, typeNode) };
        }
        function isTypeContainer(node) {
            switch (node.kind) {
                case 234 /* AsExpression */:
                case 179 /* CallSignature */:
                case 180 /* ConstructSignature */:
                case 262 /* FunctionDeclaration */:
                case 177 /* GetAccessor */:
                case 181 /* IndexSignature */:
                case 200 /* MappedType */:
                case 174 /* MethodDeclaration */:
                case 173 /* MethodSignature */:
                case 169 /* Parameter */:
                case 172 /* PropertyDeclaration */:
                case 171 /* PropertySignature */:
                case 178 /* SetAccessor */:
                case 265 /* TypeAliasDeclaration */:
                case 216 /* TypeAssertionExpression */:
                case 260 /* VariableDeclaration */:
                    return true;
                default:
                    return false;
            }
        }
        function getType(checker, node) {
            if (isJSDocNullableType(node)) {
                const type = checker.getTypeFromTypeNode(node.type);
                if (type === checker.getNeverType() || type === checker.getVoidType()) {
                    return type;
                }
                return checker.getUnionType(append([type, checker.getUndefinedType()], node.postfix ? void 0 : checker.getNullType()));
            }
            return checker.getTypeFromTypeNode(node);
        }
        var fixIdPlain, fixIdNullable, errorCodes45;
        var init_fixJSDocTypes = __esm({
            "src/services/codefixes/fixJSDocTypes.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixIdPlain = "fixJSDocTypes_plain";
                fixIdNullable = "fixJSDocTypes_nullable";
                errorCodes45 = [
                    Diagnostics.JSDoc_types_can_only_be_used_inside_documentation_comments.code,
                    Diagnostics._0_at_the_end_of_a_type_is_not_valid_TypeScript_syntax_Did_you_mean_to_write_1.code,
                    Diagnostics._0_at_the_start_of_a_type_is_not_valid_TypeScript_syntax_Did_you_mean_to_write_1.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes45,
                    getCodeActions(context) {
                        const { sourceFile } = context;
                        const checker = context.program.getTypeChecker();
                        const info = getInfo15(sourceFile, context.span.start, checker);
                        if (!info)
                            return void 0;
                        const { typeNode, type } = info;
                        const original = typeNode.getText(sourceFile);
                        const actions2 = [fix(type, fixIdPlain, Diagnostics.Change_all_jsdoc_style_types_to_TypeScript)];
                        if (typeNode.kind === 321 /* JSDocNullableType */) {
                            actions2.push(fix(type, fixIdNullable, Diagnostics.Change_all_jsdoc_style_types_to_TypeScript_and_add_undefined_to_nullable_types));
                        }
                        return actions2;
                        function fix(type2, fixId52, fixAllDescription) {
                            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange29(t, sourceFile, typeNode, type2, checker));
                            return createCodeFixAction("jdocTypes", changes, [Diagnostics.Change_0_to_1, original, checker.typeToString(type2)], fixId52, fixAllDescription);
                        }
                    },
                    fixIds: [fixIdPlain, fixIdNullable],
                    getAllCodeActions(context) {
                        const { fixId: fixId52, program, sourceFile } = context;
                        const checker = program.getTypeChecker();
                        return codeFixAll(context, errorCodes45, (changes, err) => {
                            const info = getInfo15(err.file, err.start, checker);
                            if (!info)
                                return;
                            const { typeNode, type } = info;
                            const fixedType = typeNode.kind === 321 /* JSDocNullableType */ && fixId52 === fixIdNullable ? checker.getNullableType(type, 32768 /* Undefined */) : type;
                            doChange29(changes, sourceFile, typeNode, fixedType, checker);
                        });
                    }
                });
            }
        });
        // src/services/codefixes/fixMissingCallParentheses.ts
        function doChange30(changes, sourceFile, name) {
            changes.replaceNodeWithText(sourceFile, name, `${name.text}()`);
        }
        function getCallName(sourceFile, start) {
            const token = getTokenAtPosition(sourceFile, start);
            if (isPropertyAccessExpression(token.parent)) {
                let current = token.parent;
                while (isPropertyAccessExpression(current.parent)) {
                    current = current.parent;
                }
                return current.name;
            }
            if (isIdentifier(token)) {
                return token;
            }
            return void 0;
        }
        var fixId35, errorCodes46;
        var init_fixMissingCallParentheses = __esm({
            "src/services/codefixes/fixMissingCallParentheses.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId35 = "fixMissingCallParentheses";
                errorCodes46 = [
                    Diagnostics.This_condition_will_always_return_true_since_this_function_is_always_defined_Did_you_mean_to_call_it_instead.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes46,
                    fixIds: [fixId35],
                    getCodeActions(context) {
                        const { sourceFile, span } = context;
                        const callName = getCallName(sourceFile, span.start);
                        if (!callName)
                            return;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange30(t, context.sourceFile, callName));
                        return [createCodeFixAction(fixId35, changes, Diagnostics.Add_missing_call_parentheses, fixId35, Diagnostics.Add_all_missing_call_parentheses)];
                    },
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes46, (changes, diag2) => {
                        const callName = getCallName(diag2.file, diag2.start);
                        if (callName)
                            doChange30(changes, diag2.file, callName);
                    })
                });
            }
        });
        // src/services/codefixes/fixAwaitInSyncFunction.ts
        function getReturnType(expr) {
            if (expr.type) {
                return expr.type;
            }
            if (isVariableDeclaration(expr.parent) && expr.parent.type && isFunctionTypeNode(expr.parent.type)) {
                return expr.parent.type.type;
            }
        }
        function getNodes3(sourceFile, start) {
            const token = getTokenAtPosition(sourceFile, start);
            const containingFunction = getContainingFunction(token);
            if (!containingFunction) {
                return;
            }
            let insertBefore;
            switch (containingFunction.kind) {
                case 174 /* MethodDeclaration */:
                    insertBefore = containingFunction.name;
                    break;
                case 262 /* FunctionDeclaration */:
                case 218 /* FunctionExpression */:
                    insertBefore = findChildOfKind(containingFunction, 100 /* FunctionKeyword */, sourceFile);
                    break;
                case 219 /* ArrowFunction */:
                    const kind = containingFunction.typeParameters ? 30 /* LessThanToken */ : 21 /* OpenParenToken */;
                    insertBefore = findChildOfKind(containingFunction, kind, sourceFile) || first(containingFunction.parameters);
                    break;
                default:
                    return;
            }
            return insertBefore && {
                insertBefore,
                returnType: getReturnType(containingFunction)
            };
        }
        function doChange31(changes, sourceFile, { insertBefore, returnType }) {
            if (returnType) {
                const entityName = getEntityNameFromTypeNode(returnType);
                if (!entityName || entityName.kind !== 80 /* Identifier */ || entityName.text !== "Promise") {
                    changes.replaceNode(sourceFile, returnType, factory.createTypeReferenceNode("Promise", factory.createNodeArray([returnType])));
                }
            }
            changes.insertModifierBefore(sourceFile, 134 /* AsyncKeyword */, insertBefore);
        }
        var fixId36, errorCodes47;
        var init_fixAwaitInSyncFunction = __esm({
            "src/services/codefixes/fixAwaitInSyncFunction.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId36 = "fixAwaitInSyncFunction";
                errorCodes47 = [
                    Diagnostics.await_expressions_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules.code,
                    Diagnostics.await_using_statements_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules.code,
                    Diagnostics.for_await_loops_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules.code,
                    Diagnostics.Cannot_find_name_0_Did_you_mean_to_write_this_in_an_async_function.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes47,
                    getCodeActions(context) {
                        const { sourceFile, span } = context;
                        const nodes = getNodes3(sourceFile, span.start);
                        if (!nodes)
                            return void 0;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange31(t, sourceFile, nodes));
                        return [createCodeFixAction(fixId36, changes, Diagnostics.Add_async_modifier_to_containing_function, fixId36, Diagnostics.Add_all_missing_async_modifiers)];
                    },
                    fixIds: [fixId36],
                    getAllCodeActions: function getAllCodeActionsToFixAwaitInSyncFunction(context) {
                        const seen = /* @__PURE__ */ new Map();
                        return codeFixAll(context, errorCodes47, (changes, diag2) => {
                            const nodes = getNodes3(diag2.file, diag2.start);
                            if (!nodes || !addToSeen(seen, getNodeId(nodes.insertBefore)))
                                return;
                            doChange31(changes, context.sourceFile, nodes);
                        });
                    }
                });
            }
        });
        // src/services/codefixes/fixPropertyOverrideAccessor.ts
        function doChange32(file, start, length2, code, context) {
            let startPosition;
            let endPosition;
            if (code === Diagnostics._0_is_defined_as_an_accessor_in_class_1_but_is_overridden_here_in_2_as_an_instance_property.code) {
                startPosition = start;
                endPosition = start + length2;
            }
            else if (code === Diagnostics._0_is_defined_as_a_property_in_class_1_but_is_overridden_here_in_2_as_an_accessor.code) {
                const checker = context.program.getTypeChecker();
                const node = getTokenAtPosition(file, start).parent;
                Debug.assert(isAccessor(node), "error span of fixPropertyOverrideAccessor should only be on an accessor");
                const containingClass = node.parent;
                Debug.assert(isClassLike(containingClass), "erroneous accessors should only be inside classes");
                const base = singleOrUndefined(getAllSupers(containingClass, checker));
                if (!base)
                    return [];
                const name = unescapeLeadingUnderscores(getTextOfPropertyName(node.name));
                const baseProp = checker.getPropertyOfType(checker.getTypeAtLocation(base), name);
                if (!baseProp || !baseProp.valueDeclaration)
                    return [];
                startPosition = baseProp.valueDeclaration.pos;
                endPosition = baseProp.valueDeclaration.end;
                file = getSourceFileOfNode(baseProp.valueDeclaration);
            }
            else {
                Debug.fail("fixPropertyOverrideAccessor codefix got unexpected error code " + code);
            }
            return generateAccessorFromProperty(file, context.program, startPosition, endPosition, context, Diagnostics.Generate_get_and_set_accessors.message);
        }
        var errorCodes48, fixId37;
        var init_fixPropertyOverrideAccessor = __esm({
            "src/services/codefixes/fixPropertyOverrideAccessor.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                errorCodes48 = [
                    Diagnostics._0_is_defined_as_an_accessor_in_class_1_but_is_overridden_here_in_2_as_an_instance_property.code,
                    Diagnostics._0_is_defined_as_a_property_in_class_1_but_is_overridden_here_in_2_as_an_accessor.code
                ];
                fixId37 = "fixPropertyOverrideAccessor";
                registerCodeFix({
                    errorCodes: errorCodes48,
                    getCodeActions(context) {
                        const edits = doChange32(context.sourceFile, context.span.start, context.span.length, context.errorCode, context);
                        if (edits) {
                            return [createCodeFixAction(fixId37, edits, Diagnostics.Generate_get_and_set_accessors, fixId37, Diagnostics.Generate_get_and_set_accessors_for_all_overriding_properties)];
                        }
                    },
                    fixIds: [fixId37],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes48, (changes, diag2) => {
                        const edits = doChange32(diag2.file, diag2.start, diag2.length, diag2.code, context);
                        if (edits) {
                            for (const edit of edits) {
                                changes.pushRaw(context.sourceFile, edit);
                            }
                        }
                    })
                });
            }
        });
        // src/services/codefixes/inferFromUsage.ts
        function getDiagnostic(errorCode, token) {
            switch (errorCode) {
                case Diagnostics.Parameter_0_implicitly_has_an_1_type.code:
                case Diagnostics.Parameter_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage.code:
                    return isSetAccessorDeclaration(getContainingFunction(token)) ? Diagnostics.Infer_type_of_0_from_usage : Diagnostics.Infer_parameter_types_from_usage;
                case Diagnostics.Rest_parameter_0_implicitly_has_an_any_type.code:
                case Diagnostics.Rest_parameter_0_implicitly_has_an_any_type_but_a_better_type_may_be_inferred_from_usage.code:
                    return Diagnostics.Infer_parameter_types_from_usage;
                case Diagnostics.this_implicitly_has_type_any_because_it_does_not_have_a_type_annotation.code:
                    return Diagnostics.Infer_this_type_of_0_from_usage;
                default:
                    return Diagnostics.Infer_type_of_0_from_usage;
            }
        }
        function mapSuggestionDiagnostic(errorCode) {
            switch (errorCode) {
                case Diagnostics.Variable_0_implicitly_has_type_1_in_some_locations_but_a_better_type_may_be_inferred_from_usage.code:
                    return Diagnostics.Variable_0_implicitly_has_type_1_in_some_locations_where_its_type_cannot_be_determined.code;
                case Diagnostics.Variable_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage.code:
                    return Diagnostics.Variable_0_implicitly_has_an_1_type.code;
                case Diagnostics.Parameter_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage.code:
                    return Diagnostics.Parameter_0_implicitly_has_an_1_type.code;
                case Diagnostics.Rest_parameter_0_implicitly_has_an_any_type_but_a_better_type_may_be_inferred_from_usage.code:
                    return Diagnostics.Rest_parameter_0_implicitly_has_an_any_type.code;
                case Diagnostics.Property_0_implicitly_has_type_any_but_a_better_type_for_its_get_accessor_may_be_inferred_from_usage.code:
                    return Diagnostics.Property_0_implicitly_has_type_any_because_its_get_accessor_lacks_a_return_type_annotation.code;
                case Diagnostics._0_implicitly_has_an_1_return_type_but_a_better_type_may_be_inferred_from_usage.code:
                    return Diagnostics._0_which_lacks_return_type_annotation_implicitly_has_an_1_return_type.code;
                case Diagnostics.Property_0_implicitly_has_type_any_but_a_better_type_for_its_set_accessor_may_be_inferred_from_usage.code:
                    return Diagnostics.Property_0_implicitly_has_type_any_because_its_set_accessor_lacks_a_parameter_type_annotation.code;
                case Diagnostics.Member_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage.code:
                    return Diagnostics.Member_0_implicitly_has_an_1_type.code;
            }
            return errorCode;
        }
        function doChange33(changes, sourceFile, token, errorCode, program, cancellationToken, markSeen, host, preferences) {
            if (!isParameterPropertyModifier(token.kind) && token.kind !== 80 /* Identifier */ && token.kind !== 26 /* DotDotDotToken */ && token.kind !== 110 /* ThisKeyword */) {
                return void 0;
            }
            const { parent: parent2 } = token;
            const importAdder = createImportAdder(sourceFile, program, preferences, host);
            errorCode = mapSuggestionDiagnostic(errorCode);
            switch (errorCode) {
                case Diagnostics.Member_0_implicitly_has_an_1_type.code:
                case Diagnostics.Variable_0_implicitly_has_type_1_in_some_locations_where_its_type_cannot_be_determined.code:
                    if (isVariableDeclaration(parent2) && markSeen(parent2) || isPropertyDeclaration(parent2) || isPropertySignature(parent2)) {
                        annotateVariableDeclaration(changes, importAdder, sourceFile, parent2, program, host, cancellationToken);
                        importAdder.writeFixes(changes);
                        return parent2;
                    }
                    if (isPropertyAccessExpression(parent2)) {
                        const type = inferTypeForVariableFromUsage(parent2.name, program, cancellationToken);
                        const typeNode = getTypeNodeIfAccessible(type, parent2, program, host);
                        if (typeNode) {
                            const typeTag = factory.createJSDocTypeTag(
                            /*tagName*/
                            void 0, factory.createJSDocTypeExpression(typeNode), 
                            /*comment*/
                            void 0);
                            changes.addJSDocTags(sourceFile, cast(parent2.parent.parent, isExpressionStatement), [typeTag]);
                        }
                        importAdder.writeFixes(changes);
                        return parent2;
                    }
                    return void 0;
                case Diagnostics.Variable_0_implicitly_has_an_1_type.code: {
                    const symbol = program.getTypeChecker().getSymbolAtLocation(token);
                    if (symbol && symbol.valueDeclaration && isVariableDeclaration(symbol.valueDeclaration) && markSeen(symbol.valueDeclaration)) {
                        annotateVariableDeclaration(changes, importAdder, getSourceFileOfNode(symbol.valueDeclaration), symbol.valueDeclaration, program, host, cancellationToken);
                        importAdder.writeFixes(changes);
                        return symbol.valueDeclaration;
                    }
                    return void 0;
                }
            }
            const containingFunction = getContainingFunction(token);
            if (containingFunction === void 0) {
                return void 0;
            }
            let declaration;
            switch (errorCode) {
                case Diagnostics.Parameter_0_implicitly_has_an_1_type.code:
                    if (isSetAccessorDeclaration(containingFunction)) {
                        annotateSetAccessor(changes, importAdder, sourceFile, containingFunction, program, host, cancellationToken);
                        declaration = containingFunction;
                        break;
                    }
                case Diagnostics.Rest_parameter_0_implicitly_has_an_any_type.code:
                    if (markSeen(containingFunction)) {
                        const param = cast(parent2, isParameter);
                        annotateParameters(changes, importAdder, sourceFile, param, containingFunction, program, host, cancellationToken);
                        declaration = param;
                    }
                    break;
                case Diagnostics.Property_0_implicitly_has_type_any_because_its_get_accessor_lacks_a_return_type_annotation.code:
                case Diagnostics._0_which_lacks_return_type_annotation_implicitly_has_an_1_return_type.code:
                    if (isGetAccessorDeclaration(containingFunction) && isIdentifier(containingFunction.name)) {
                        annotate(changes, importAdder, sourceFile, containingFunction, inferTypeForVariableFromUsage(containingFunction.name, program, cancellationToken), program, host);
                        declaration = containingFunction;
                    }
                    break;
                case Diagnostics.Property_0_implicitly_has_type_any_because_its_set_accessor_lacks_a_parameter_type_annotation.code:
                    if (isSetAccessorDeclaration(containingFunction)) {
                        annotateSetAccessor(changes, importAdder, sourceFile, containingFunction, program, host, cancellationToken);
                        declaration = containingFunction;
                    }
                    break;
                case Diagnostics.this_implicitly_has_type_any_because_it_does_not_have_a_type_annotation.code:
                    if (ts_textChanges_exports.isThisTypeAnnotatable(containingFunction) && markSeen(containingFunction)) {
                        annotateThis(changes, sourceFile, containingFunction, program, host, cancellationToken);
                        declaration = containingFunction;
                    }
                    break;
                default:
                    return Debug.fail(String(errorCode));
            }
            importAdder.writeFixes(changes);
            return declaration;
        }
        function annotateVariableDeclaration(changes, importAdder, sourceFile, declaration, program, host, cancellationToken) {
            if (isIdentifier(declaration.name)) {
                annotate(changes, importAdder, sourceFile, declaration, inferTypeForVariableFromUsage(declaration.name, program, cancellationToken), program, host);
            }
        }
        function annotateParameters(changes, importAdder, sourceFile, parameterDeclaration, containingFunction, program, host, cancellationToken) {
            if (!isIdentifier(parameterDeclaration.name)) {
                return;
            }
            const parameterInferences = inferTypeForParametersFromUsage(containingFunction, sourceFile, program, cancellationToken);
            Debug.assert(containingFunction.parameters.length === parameterInferences.length, "Parameter count and inference count should match");
            if (isInJSFile(containingFunction)) {
                annotateJSDocParameters(changes, sourceFile, parameterInferences, program, host);
            }
            else {
                const needParens = isArrowFunction(containingFunction) && !findChildOfKind(containingFunction, 21 /* OpenParenToken */, sourceFile);
                if (needParens)
                    changes.insertNodeBefore(sourceFile, first(containingFunction.parameters), factory.createToken(21 /* OpenParenToken */));
                for (const { declaration, type } of parameterInferences) {
                    if (declaration && !declaration.type && !declaration.initializer) {
                        annotate(changes, importAdder, sourceFile, declaration, type, program, host);
                    }
                }
                if (needParens)
                    changes.insertNodeAfter(sourceFile, last(containingFunction.parameters), factory.createToken(22 /* CloseParenToken */));
            }
        }
        function annotateThis(changes, sourceFile, containingFunction, program, host, cancellationToken) {
            const references = getFunctionReferences(containingFunction, sourceFile, program, cancellationToken);
            if (!references || !references.length) {
                return;
            }
            const thisInference = inferTypeFromReferences(program, references, cancellationToken).thisParameter();
            const typeNode = getTypeNodeIfAccessible(thisInference, containingFunction, program, host);
            if (!typeNode) {
                return;
            }
            if (isInJSFile(containingFunction)) {
                annotateJSDocThis(changes, sourceFile, containingFunction, typeNode);
            }
            else {
                changes.tryInsertThisTypeAnnotation(sourceFile, containingFunction, typeNode);
            }
        }
        function annotateJSDocThis(changes, sourceFile, containingFunction, typeNode) {
            changes.addJSDocTags(sourceFile, containingFunction, [
                factory.createJSDocThisTag(
                /*tagName*/
                void 0, factory.createJSDocTypeExpression(typeNode))
            ]);
        }
        function annotateSetAccessor(changes, importAdder, sourceFile, setAccessorDeclaration, program, host, cancellationToken) {
            const param = firstOrUndefined(setAccessorDeclaration.parameters);
            if (param && isIdentifier(setAccessorDeclaration.name) && isIdentifier(param.name)) {
                let type = inferTypeForVariableFromUsage(setAccessorDeclaration.name, program, cancellationToken);
                if (type === program.getTypeChecker().getAnyType()) {
                    type = inferTypeForVariableFromUsage(param.name, program, cancellationToken);
                }
                if (isInJSFile(setAccessorDeclaration)) {
                    annotateJSDocParameters(changes, sourceFile, [{ declaration: param, type }], program, host);
                }
                else {
                    annotate(changes, importAdder, sourceFile, param, type, program, host);
                }
            }
        }
        function annotate(changes, importAdder, sourceFile, declaration, type, program, host) {
            const typeNode = getTypeNodeIfAccessible(type, declaration, program, host);
            if (typeNode) {
                if (isInJSFile(sourceFile) && declaration.kind !== 171 /* PropertySignature */) {
                    const parent2 = isVariableDeclaration(declaration) ? tryCast(declaration.parent.parent, isVariableStatement) : declaration;
                    if (!parent2) {
                        return;
                    }
                    const typeExpression = factory.createJSDocTypeExpression(typeNode);
                    const typeTag = isGetAccessorDeclaration(declaration) ? factory.createJSDocReturnTag(
                    /*tagName*/
                    void 0, typeExpression, 
                    /*comment*/
                    void 0) : factory.createJSDocTypeTag(
                    /*tagName*/
                    void 0, typeExpression, 
                    /*comment*/
                    void 0);
                    changes.addJSDocTags(sourceFile, parent2, [typeTag]);
                }
                else if (!tryReplaceImportTypeNodeWithAutoImport(typeNode, declaration, sourceFile, changes, importAdder, getEmitScriptTarget(program.getCompilerOptions()))) {
                    changes.tryInsertTypeAnnotation(sourceFile, declaration, typeNode);
                }
            }
        }
        function tryReplaceImportTypeNodeWithAutoImport(typeNode, declaration, sourceFile, changes, importAdder, scriptTarget) {
            const importableReference = tryGetAutoImportableReferenceFromTypeNode(typeNode, scriptTarget);
            if (importableReference && changes.tryInsertTypeAnnotation(sourceFile, declaration, importableReference.typeNode)) {
                forEach(importableReference.symbols, (s) => importAdder.addImportFromExportedSymbol(s, 
                /*isValidTypeOnlyUseSite*/
                true));
                return true;
            }
            return false;
        }
        function annotateJSDocParameters(changes, sourceFile, parameterInferences, program, host) {
            const signature = parameterInferences.length && parameterInferences[0].declaration.parent;
            if (!signature) {
                return;
            }
            const inferences = mapDefined(parameterInferences, (inference) => {
                const param = inference.declaration;
                if (param.initializer || getJSDocType(param) || !isIdentifier(param.name)) {
                    return;
                }
                const typeNode = inference.type && getTypeNodeIfAccessible(inference.type, param, program, host);
                if (typeNode) {
                    const name = factory.cloneNode(param.name);
                    setEmitFlags(name, 3072 /* NoComments */ | 4096 /* NoNestedComments */);
                    return { name: factory.cloneNode(param.name), param, isOptional: !!inference.isOptional, typeNode };
                }
            });
            if (!inferences.length) {
                return;
            }
            if (isArrowFunction(signature) || isFunctionExpression(signature)) {
                const needParens = isArrowFunction(signature) && !findChildOfKind(signature, 21 /* OpenParenToken */, sourceFile);
                if (needParens) {
                    changes.insertNodeBefore(sourceFile, first(signature.parameters), factory.createToken(21 /* OpenParenToken */));
                }
                forEach(inferences, ({ typeNode, param }) => {
                    const typeTag = factory.createJSDocTypeTag(
                    /*tagName*/
                    void 0, factory.createJSDocTypeExpression(typeNode));
                    const jsDoc = factory.createJSDocComment(
                    /*comment*/
                    void 0, [typeTag]);
                    changes.insertNodeAt(sourceFile, param.getStart(sourceFile), jsDoc, { suffix: " " });
                });
                if (needParens) {
                    changes.insertNodeAfter(sourceFile, last(signature.parameters), factory.createToken(22 /* CloseParenToken */));
                }
            }
            else {
                const paramTags = map(inferences, ({ name, typeNode, isOptional }) => factory.createJSDocParameterTag(
                /*tagName*/
                void 0, name, 
                /*isBracketed*/
                !!isOptional, factory.createJSDocTypeExpression(typeNode), 
                /*isNameFirst*/
                false, 
                /*comment*/
                void 0));
                changes.addJSDocTags(sourceFile, signature, paramTags);
            }
        }
        function getReferences(token, program, cancellationToken) {
            return mapDefined(ts_FindAllReferences_exports.getReferenceEntriesForNode(-1, token, program, program.getSourceFiles(), cancellationToken), (entry) => entry.kind !== ts_FindAllReferences_exports.EntryKind.Span ? tryCast(entry.node, isIdentifier) : void 0);
        }
        function inferTypeForVariableFromUsage(token, program, cancellationToken) {
            const references = getReferences(token, program, cancellationToken);
            return inferTypeFromReferences(program, references, cancellationToken).single();
        }
        function inferTypeForParametersFromUsage(func, sourceFile, program, cancellationToken) {
            const references = getFunctionReferences(func, sourceFile, program, cancellationToken);
            return references && inferTypeFromReferences(program, references, cancellationToken).parameters(func) || func.parameters.map((p) => ({
                declaration: p,
                type: isIdentifier(p.name) ? inferTypeForVariableFromUsage(p.name, program, cancellationToken) : program.getTypeChecker().getAnyType()
            }));
        }
        function getFunctionReferences(containingFunction, sourceFile, program, cancellationToken) {
            let searchToken;
            switch (containingFunction.kind) {
                case 176 /* Constructor */:
                    searchToken = findChildOfKind(containingFunction, 137 /* ConstructorKeyword */, sourceFile);
                    break;
                case 219 /* ArrowFunction */:
                case 218 /* FunctionExpression */:
                    const parent2 = containingFunction.parent;
                    searchToken = (isVariableDeclaration(parent2) || isPropertyDeclaration(parent2)) && isIdentifier(parent2.name) ? parent2.name : containingFunction.name;
                    break;
                case 262 /* FunctionDeclaration */:
                case 174 /* MethodDeclaration */:
                case 173 /* MethodSignature */:
                    searchToken = containingFunction.name;
                    break;
            }
            if (!searchToken) {
                return void 0;
            }
            return getReferences(searchToken, program, cancellationToken);
        }
        function inferTypeFromReferences(program, references, cancellationToken) {
            const checker = program.getTypeChecker();
            const builtinConstructors = {
                string: () => checker.getStringType(),
                number: () => checker.getNumberType(),
                Array: (t) => checker.createArrayType(t),
                Promise: (t) => checker.createPromiseType(t)
            };
            const builtins = [
                checker.getStringType(),
                checker.getNumberType(),
                checker.createArrayType(checker.getAnyType()),
                checker.createPromiseType(checker.getAnyType())
            ];
            return {
                single: single2,
                parameters,
                thisParameter
            };
            function createEmptyUsage() {
                return {
                    isNumber: void 0,
                    isString: void 0,
                    isNumberOrString: void 0,
                    candidateTypes: void 0,
                    properties: void 0,
                    calls: void 0,
                    constructs: void 0,
                    numberIndex: void 0,
                    stringIndex: void 0,
                    candidateThisTypes: void 0,
                    inferredTypes: void 0
                };
            }
            function combineUsages(usages) {
                const combinedProperties = /* @__PURE__ */ new Map();
                for (const u of usages) {
                    if (u.properties) {
                        u.properties.forEach((p, name) => {
                            if (!combinedProperties.has(name)) {
                                combinedProperties.set(name, []);
                            }
                            combinedProperties.get(name).push(p);
                        });
                    }
                }
                const properties = /* @__PURE__ */ new Map();
                combinedProperties.forEach((ps, name) => {
                    properties.set(name, combineUsages(ps));
                });
                return {
                    isNumber: usages.some((u) => u.isNumber),
                    isString: usages.some((u) => u.isString),
                    isNumberOrString: usages.some((u) => u.isNumberOrString),
                    candidateTypes: flatMap(usages, (u) => u.candidateTypes),
                    properties,
                    calls: flatMap(usages, (u) => u.calls),
                    constructs: flatMap(usages, (u) => u.constructs),
                    numberIndex: forEach(usages, (u) => u.numberIndex),
                    stringIndex: forEach(usages, (u) => u.stringIndex),
                    candidateThisTypes: flatMap(usages, (u) => u.candidateThisTypes),
                    inferredTypes: void 0
                    // clear type cache
                };
            }
            function single2() {
                return combineTypes(inferTypesFromReferencesSingle(references));
            }
            function parameters(declaration) {
                if (references.length === 0 || !declaration.parameters) {
                    return void 0;
                }
                const usage = createEmptyUsage();
                for (const reference of references) {
                    cancellationToken.throwIfCancellationRequested();
                    calculateUsageOfNode(reference, usage);
                }
                const calls = [...usage.constructs || [], ...usage.calls || []];
                return declaration.parameters.map((parameter, parameterIndex) => {
                    const types = [];
                    const isRest = isRestParameter(parameter);
                    let isOptional = false;
                    for (const call of calls) {
                        if (call.argumentTypes.length <= parameterIndex) {
                            isOptional = isInJSFile(declaration);
                            types.push(checker.getUndefinedType());
                        }
                        else if (isRest) {
                            for (let i = parameterIndex; i < call.argumentTypes.length; i++) {
                                types.push(checker.getBaseTypeOfLiteralType(call.argumentTypes[i]));
                            }
                        }
                        else {
                            types.push(checker.getBaseTypeOfLiteralType(call.argumentTypes[parameterIndex]));
                        }
                    }
                    if (isIdentifier(parameter.name)) {
                        const inferred = inferTypesFromReferencesSingle(getReferences(parameter.name, program, cancellationToken));
                        types.push(...isRest ? mapDefined(inferred, checker.getElementTypeOfArrayType) : inferred);
                    }
                    const type = combineTypes(types);
                    return {
                        type: isRest ? checker.createArrayType(type) : type,
                        isOptional: isOptional && !isRest,
                        declaration: parameter
                    };
                });
            }
            function thisParameter() {
                const usage = createEmptyUsage();
                for (const reference of references) {
                    cancellationToken.throwIfCancellationRequested();
                    calculateUsageOfNode(reference, usage);
                }
                return combineTypes(usage.candidateThisTypes || emptyArray);
            }
            function inferTypesFromReferencesSingle(references2) {
                const usage = createEmptyUsage();
                for (const reference of references2) {
                    cancellationToken.throwIfCancellationRequested();
                    calculateUsageOfNode(reference, usage);
                }
                return inferTypes(usage);
            }
            function calculateUsageOfNode(node, usage) {
                while (isRightSideOfQualifiedNameOrPropertyAccess(node)) {
                    node = node.parent;
                }
                switch (node.parent.kind) {
                    case 244 /* ExpressionStatement */:
                        inferTypeFromExpressionStatement(node, usage);
                        break;
                    case 225 /* PostfixUnaryExpression */:
                        usage.isNumber = true;
                        break;
                    case 224 /* PrefixUnaryExpression */:
                        inferTypeFromPrefixUnaryExpression(node.parent, usage);
                        break;
                    case 226 /* BinaryExpression */:
                        inferTypeFromBinaryExpression(node, node.parent, usage);
                        break;
                    case 296 /* CaseClause */:
                    case 297 /* DefaultClause */:
                        inferTypeFromSwitchStatementLabel(node.parent, usage);
                        break;
                    case 213 /* CallExpression */:
                    case 214 /* NewExpression */:
                        if (node.parent.expression === node) {
                            inferTypeFromCallExpression(node.parent, usage);
                        }
                        else {
                            inferTypeFromContextualType(node, usage);
                        }
                        break;
                    case 211 /* PropertyAccessExpression */:
                        inferTypeFromPropertyAccessExpression(node.parent, usage);
                        break;
                    case 212 /* ElementAccessExpression */:
                        inferTypeFromPropertyElementExpression(node.parent, node, usage);
                        break;
                    case 303 /* PropertyAssignment */:
                    case 304 /* ShorthandPropertyAssignment */:
                        inferTypeFromPropertyAssignment(node.parent, usage);
                        break;
                    case 172 /* PropertyDeclaration */:
                        inferTypeFromPropertyDeclaration(node.parent, usage);
                        break;
                    case 260 /* VariableDeclaration */: {
                        const { name, initializer } = node.parent;
                        if (node === name) {
                            if (initializer) {
                                addCandidateType(usage, checker.getTypeAtLocation(initializer));
                            }
                            break;
                        }
                    }
                    default:
                        return inferTypeFromContextualType(node, usage);
                }
            }
            function inferTypeFromContextualType(node, usage) {
                if (isExpressionNode(node)) {
                    addCandidateType(usage, checker.getContextualType(node));
                }
            }
            function inferTypeFromExpressionStatement(node, usage) {
                addCandidateType(usage, isCallExpression(node) ? checker.getVoidType() : checker.getAnyType());
            }
            function inferTypeFromPrefixUnaryExpression(node, usage) {
                switch (node.operator) {
                    case 46 /* PlusPlusToken */:
                    case 47 /* MinusMinusToken */:
                    case 41 /* MinusToken */:
                    case 55 /* TildeToken */:
                        usage.isNumber = true;
                        break;
                    case 40 /* PlusToken */:
                        usage.isNumberOrString = true;
                        break;
                }
            }
            function inferTypeFromBinaryExpression(node, parent2, usage) {
                switch (parent2.operatorToken.kind) {
                    case 43 /* AsteriskAsteriskToken */:
                    case 42 /* AsteriskToken */:
                    case 44 /* SlashToken */:
                    case 45 /* PercentToken */:
                    case 48 /* LessThanLessThanToken */:
                    case 49 /* GreaterThanGreaterThanToken */:
                    case 50 /* GreaterThanGreaterThanGreaterThanToken */:
                    case 51 /* AmpersandToken */:
                    case 52 /* BarToken */:
                    case 53 /* CaretToken */:
                    case 66 /* MinusEqualsToken */:
                    case 68 /* AsteriskAsteriskEqualsToken */:
                    case 67 /* AsteriskEqualsToken */:
                    case 69 /* SlashEqualsToken */:
                    case 70 /* PercentEqualsToken */:
                    case 74 /* AmpersandEqualsToken */:
                    case 75 /* BarEqualsToken */:
                    case 79 /* CaretEqualsToken */:
                    case 71 /* LessThanLessThanEqualsToken */:
                    case 73 /* GreaterThanGreaterThanGreaterThanEqualsToken */:
                    case 72 /* GreaterThanGreaterThanEqualsToken */:
                    case 41 /* MinusToken */:
                    case 30 /* LessThanToken */:
                    case 33 /* LessThanEqualsToken */:
                    case 32 /* GreaterThanToken */:
                    case 34 /* GreaterThanEqualsToken */:
                        const operandType = checker.getTypeAtLocation(parent2.left === node ? parent2.right : parent2.left);
                        if (operandType.flags & 1056 /* EnumLike */) {
                            addCandidateType(usage, operandType);
                        }
                        else {
                            usage.isNumber = true;
                        }
                        break;
                    case 65 /* PlusEqualsToken */:
                    case 40 /* PlusToken */:
                        const otherOperandType = checker.getTypeAtLocation(parent2.left === node ? parent2.right : parent2.left);
                        if (otherOperandType.flags & 1056 /* EnumLike */) {
                            addCandidateType(usage, otherOperandType);
                        }
                        else if (otherOperandType.flags & 296 /* NumberLike */) {
                            usage.isNumber = true;
                        }
                        else if (otherOperandType.flags & 402653316 /* StringLike */) {
                            usage.isString = true;
                        }
                        else if (otherOperandType.flags & 1 /* Any */) {
                        }
                        else {
                            usage.isNumberOrString = true;
                        }
                        break;
                    case 64 /* EqualsToken */:
                    case 35 /* EqualsEqualsToken */:
                    case 37 /* EqualsEqualsEqualsToken */:
                    case 38 /* ExclamationEqualsEqualsToken */:
                    case 36 /* ExclamationEqualsToken */:
                    case 77 /* AmpersandAmpersandEqualsToken */:
                    case 78 /* QuestionQuestionEqualsToken */:
                    case 76 /* BarBarEqualsToken */:
                        addCandidateType(usage, checker.getTypeAtLocation(parent2.left === node ? parent2.right : parent2.left));
                        break;
                    case 103 /* InKeyword */:
                        if (node === parent2.left) {
                            usage.isString = true;
                        }
                        break;
                    case 57 /* BarBarToken */:
                    case 61 /* QuestionQuestionToken */:
                        if (node === parent2.left && (node.parent.parent.kind === 260 /* VariableDeclaration */ || isAssignmentExpression(node.parent.parent, 
                        /*excludeCompoundAssignment*/
                        true))) {
                            addCandidateType(usage, checker.getTypeAtLocation(parent2.right));
                        }
                        break;
                    case 56 /* AmpersandAmpersandToken */:
                    case 28 /* CommaToken */:
                    case 104 /* InstanceOfKeyword */:
                        break;
                }
            }
            function inferTypeFromSwitchStatementLabel(parent2, usage) {
                addCandidateType(usage, checker.getTypeAtLocation(parent2.parent.parent.expression));
            }
            function inferTypeFromCallExpression(parent2, usage) {
                const call = {
                    argumentTypes: [],
                    return_: createEmptyUsage()
                };
                if (parent2.arguments) {
                    for (const argument of parent2.arguments) {
                        call.argumentTypes.push(checker.getTypeAtLocation(argument));
                    }
                }
                calculateUsageOfNode(parent2, call.return_);
                if (parent2.kind === 213 /* CallExpression */) {
                    (usage.calls || (usage.calls = [])).push(call);
                }
                else {
                    (usage.constructs || (usage.constructs = [])).push(call);
                }
            }
            function inferTypeFromPropertyAccessExpression(parent2, usage) {
                const name = escapeLeadingUnderscores(parent2.name.text);
                if (!usage.properties) {
                    usage.properties = /* @__PURE__ */ new Map();
                }
                const propertyUsage = usage.properties.get(name) || createEmptyUsage();
                calculateUsageOfNode(parent2, propertyUsage);
                usage.properties.set(name, propertyUsage);
            }
            function inferTypeFromPropertyElementExpression(parent2, node, usage) {
                if (node === parent2.argumentExpression) {
                    usage.isNumberOrString = true;
                    return;
                }
                else {
                    const indexType = checker.getTypeAtLocation(parent2.argumentExpression);
                    const indexUsage = createEmptyUsage();
                    calculateUsageOfNode(parent2, indexUsage);
                    if (indexType.flags & 296 /* NumberLike */) {
                        usage.numberIndex = indexUsage;
                    }
                    else {
                        usage.stringIndex = indexUsage;
                    }
                }
            }
            function inferTypeFromPropertyAssignment(assignment, usage) {
                const nodeWithRealType = isVariableDeclaration(assignment.parent.parent) ? assignment.parent.parent : assignment.parent;
                addCandidateThisType(usage, checker.getTypeAtLocation(nodeWithRealType));
            }
            function inferTypeFromPropertyDeclaration(declaration, usage) {
                addCandidateThisType(usage, checker.getTypeAtLocation(declaration.parent));
            }
            function removeLowPriorityInferences(inferences, priorities) {
                const toRemove = [];
                for (const i of inferences) {
                    for (const { high, low } of priorities) {
                        if (high(i)) {
                            Debug.assert(!low(i), "Priority can't have both low and high");
                            toRemove.push(low);
                        }
                    }
                }
                return inferences.filter((i) => toRemove.every((f) => !f(i)));
            }
            function combineFromUsage(usage) {
                return combineTypes(inferTypes(usage));
            }
            function combineTypes(inferences) {
                if (!inferences.length)
                    return checker.getAnyType();
                const stringNumber = checker.getUnionType([checker.getStringType(), checker.getNumberType()]);
                const priorities = [
                    {
                        high: (t) => t === checker.getStringType() || t === checker.getNumberType(),
                        low: (t) => t === stringNumber
                    },
                    {
                        high: (t) => !(t.flags & (1 /* Any */ | 16384 /* Void */)),
                        low: (t) => !!(t.flags & (1 /* Any */ | 16384 /* Void */))
                    },
                    {
                        high: (t) => !(t.flags & (98304 /* Nullable */ | 1 /* Any */ | 16384 /* Void */)) && !(getObjectFlags(t) & 16 /* Anonymous */),
                        low: (t) => !!(getObjectFlags(t) & 16 /* Anonymous */)
                    }
                ];
                let good = removeLowPriorityInferences(inferences, priorities);
                const anons = good.filter((i) => getObjectFlags(i) & 16 /* Anonymous */);
                if (anons.length) {
                    good = good.filter((i) => !(getObjectFlags(i) & 16 /* Anonymous */));
                    good.push(combineAnonymousTypes(anons));
                }
                return checker.getWidenedType(checker.getUnionType(good.map(checker.getBaseTypeOfLiteralType), 2 /* Subtype */));
            }
            function combineAnonymousTypes(anons) {
                if (anons.length === 1) {
                    return anons[0];
                }
                const calls = [];
                const constructs = [];
                const stringIndices = [];
                const numberIndices = [];
                let stringIndexReadonly = false;
                let numberIndexReadonly = false;
                const props = createMultiMap();
                for (const anon2 of anons) {
                    for (const p of checker.getPropertiesOfType(anon2)) {
                        props.add(p.escapedName, p.valueDeclaration ? checker.getTypeOfSymbolAtLocation(p, p.valueDeclaration) : checker.getAnyType());
                    }
                    calls.push(...checker.getSignaturesOfType(anon2, 0 /* Call */));
                    constructs.push(...checker.getSignaturesOfType(anon2, 1 /* Construct */));
                    const stringIndexInfo = checker.getIndexInfoOfType(anon2, 0 /* String */);
                    if (stringIndexInfo) {
                        stringIndices.push(stringIndexInfo.type);
                        stringIndexReadonly = stringIndexReadonly || stringIndexInfo.isReadonly;
                    }
                    const numberIndexInfo = checker.getIndexInfoOfType(anon2, 1 /* Number */);
                    if (numberIndexInfo) {
                        numberIndices.push(numberIndexInfo.type);
                        numberIndexReadonly = numberIndexReadonly || numberIndexInfo.isReadonly;
                    }
                }
                const members = mapEntries(props, (name, types) => {
                    const isOptional = types.length < anons.length ? 16777216 /* Optional */ : 0;
                    const s = checker.createSymbol(4 /* Property */ | isOptional, name);
                    s.links.type = checker.getUnionType(types);
                    return [name, s];
                });
                const indexInfos = [];
                if (stringIndices.length)
                    indexInfos.push(checker.createIndexInfo(checker.getStringType(), checker.getUnionType(stringIndices), stringIndexReadonly));
                if (numberIndices.length)
                    indexInfos.push(checker.createIndexInfo(checker.getNumberType(), checker.getUnionType(numberIndices), numberIndexReadonly));
                return checker.createAnonymousType(anons[0].symbol, members, calls, constructs, indexInfos);
            }
            function inferTypes(usage) {
                var _a, _b, _c;
                const types = [];
                if (usage.isNumber) {
                    types.push(checker.getNumberType());
                }
                if (usage.isString) {
                    types.push(checker.getStringType());
                }
                if (usage.isNumberOrString) {
                    types.push(checker.getUnionType([checker.getStringType(), checker.getNumberType()]));
                }
                if (usage.numberIndex) {
                    types.push(checker.createArrayType(combineFromUsage(usage.numberIndex)));
                }
                if (((_a = usage.properties) == null ? void 0 : _a.size) || ((_b = usage.constructs) == null ? void 0 : _b.length) || usage.stringIndex) {
                    types.push(inferStructuralType(usage));
                }
                const candidateTypes = (usage.candidateTypes || []).map((t) => checker.getBaseTypeOfLiteralType(t));
                const callsType = ((_c = usage.calls) == null ? void 0 : _c.length) ? inferStructuralType(usage) : void 0;
                if (callsType && candidateTypes) {
                    types.push(checker.getUnionType([callsType, ...candidateTypes], 2 /* Subtype */));
                }
                else {
                    if (callsType) {
                        types.push(callsType);
                    }
                    if (length(candidateTypes)) {
                        types.push(...candidateTypes);
                    }
                }
                types.push(...inferNamedTypesFromProperties(usage));
                return types;
            }
            function inferStructuralType(usage) {
                const members = /* @__PURE__ */ new Map();
                if (usage.properties) {
                    usage.properties.forEach((u, name) => {
                        const symbol = checker.createSymbol(4 /* Property */, name);
                        symbol.links.type = combineFromUsage(u);
                        members.set(name, symbol);
                    });
                }
                const callSignatures = usage.calls ? [getSignatureFromCalls(usage.calls)] : [];
                const constructSignatures = usage.constructs ? [getSignatureFromCalls(usage.constructs)] : [];
                const indexInfos = usage.stringIndex ? [checker.createIndexInfo(checker.getStringType(), combineFromUsage(usage.stringIndex), 
                    /*isReadonly*/
                    false)] : [];
                return checker.createAnonymousType(
                /*symbol*/
                void 0, members, callSignatures, constructSignatures, indexInfos);
            }
            function inferNamedTypesFromProperties(usage) {
                if (!usage.properties || !usage.properties.size)
                    return [];
                const types = builtins.filter((t) => allPropertiesAreAssignableToUsage(t, usage));
                if (0 < types.length && types.length < 3) {
                    return types.map((t) => inferInstantiationFromUsage(t, usage));
                }
                return [];
            }
            function allPropertiesAreAssignableToUsage(type, usage) {
                if (!usage.properties)
                    return false;
                return !forEachEntry(usage.properties, (propUsage, name) => {
                    const source = checker.getTypeOfPropertyOfType(type, name);
                    if (!source) {
                        return true;
                    }
                    if (propUsage.calls) {
                        const sigs = checker.getSignaturesOfType(source, 0 /* Call */);
                        return !sigs.length || !checker.isTypeAssignableTo(source, getFunctionFromCalls(propUsage.calls));
                    }
                    else {
                        return !checker.isTypeAssignableTo(source, combineFromUsage(propUsage));
                    }
                });
            }
            function inferInstantiationFromUsage(type, usage) {
                if (!(getObjectFlags(type) & 4 /* Reference */) || !usage.properties) {
                    return type;
                }
                const generic = type.target;
                const singleTypeParameter = singleOrUndefined(generic.typeParameters);
                if (!singleTypeParameter)
                    return type;
                const types = [];
                usage.properties.forEach((propUsage, name) => {
                    const genericPropertyType = checker.getTypeOfPropertyOfType(generic, name);
                    Debug.assert(!!genericPropertyType, "generic should have all the properties of its reference.");
                    types.push(...inferTypeParameters(genericPropertyType, combineFromUsage(propUsage), singleTypeParameter));
                });
                return builtinConstructors[type.symbol.escapedName](combineTypes(types));
            }
            function inferTypeParameters(genericType, usageType, typeParameter) {
                if (genericType === typeParameter) {
                    return [usageType];
                }
                else if (genericType.flags & 3145728 /* UnionOrIntersection */) {
                    return flatMap(genericType.types, (t) => inferTypeParameters(t, usageType, typeParameter));
                }
                else if (getObjectFlags(genericType) & 4 /* Reference */ && getObjectFlags(usageType) & 4 /* Reference */) {
                    const genericArgs = checker.getTypeArguments(genericType);
                    const usageArgs = checker.getTypeArguments(usageType);
                    const types = [];
                    if (genericArgs && usageArgs) {
                        for (let i = 0; i < genericArgs.length; i++) {
                            if (usageArgs[i]) {
                                types.push(...inferTypeParameters(genericArgs[i], usageArgs[i], typeParameter));
                            }
                        }
                    }
                    return types;
                }
                const genericSigs = checker.getSignaturesOfType(genericType, 0 /* Call */);
                const usageSigs = checker.getSignaturesOfType(usageType, 0 /* Call */);
                if (genericSigs.length === 1 && usageSigs.length === 1) {
                    return inferFromSignatures(genericSigs[0], usageSigs[0], typeParameter);
                }
                return [];
            }
            function inferFromSignatures(genericSig, usageSig, typeParameter) {
                var _a;
                const types = [];
                for (let i = 0; i < genericSig.parameters.length; i++) {
                    const genericParam = genericSig.parameters[i];
                    const usageParam = usageSig.parameters[i];
                    const isRest = genericSig.declaration && isRestParameter(genericSig.declaration.parameters[i]);
                    if (!usageParam) {
                        break;
                    }
                    let genericParamType = genericParam.valueDeclaration ? checker.getTypeOfSymbolAtLocation(genericParam, genericParam.valueDeclaration) : checker.getAnyType();
                    const elementType = isRest && checker.getElementTypeOfArrayType(genericParamType);
                    if (elementType) {
                        genericParamType = elementType;
                    }
                    const targetType = ((_a = tryCast(usageParam, isTransientSymbol)) == null ? void 0 : _a.links.type) || (usageParam.valueDeclaration ? checker.getTypeOfSymbolAtLocation(usageParam, usageParam.valueDeclaration) : checker.getAnyType());
                    types.push(...inferTypeParameters(genericParamType, targetType, typeParameter));
                }
                const genericReturn = checker.getReturnTypeOfSignature(genericSig);
                const usageReturn = checker.getReturnTypeOfSignature(usageSig);
                types.push(...inferTypeParameters(genericReturn, usageReturn, typeParameter));
                return types;
            }
            function getFunctionFromCalls(calls) {
                return checker.createAnonymousType(
                /*symbol*/
                void 0, createSymbolTable(), [getSignatureFromCalls(calls)], emptyArray, emptyArray);
            }
            function getSignatureFromCalls(calls) {
                const parameters2 = [];
                const length2 = Math.max(...calls.map((c) => c.argumentTypes.length));
                for (let i = 0; i < length2; i++) {
                    const symbol = checker.createSymbol(1 /* FunctionScopedVariable */, escapeLeadingUnderscores(`arg${i}`));
                    symbol.links.type = combineTypes(calls.map((call) => call.argumentTypes[i] || checker.getUndefinedType()));
                    if (calls.some((call) => call.argumentTypes[i] === void 0)) {
                        symbol.flags |= 16777216 /* Optional */;
                    }
                    parameters2.push(symbol);
                }
                const returnType = combineFromUsage(combineUsages(calls.map((call) => call.return_)));
                return checker.createSignature(
                /*declaration*/
                void 0, 
                /*typeParameters*/
                void 0, 
                /*thisParameter*/
                void 0, parameters2, returnType, 
                /*typePredicate*/
                void 0, length2, 0 /* None */);
            }
            function addCandidateType(usage, type) {
                if (type && !(type.flags & 1 /* Any */) && !(type.flags & 131072 /* Never */)) {
                    (usage.candidateTypes || (usage.candidateTypes = [])).push(type);
                }
            }
            function addCandidateThisType(usage, type) {
                if (type && !(type.flags & 1 /* Any */) && !(type.flags & 131072 /* Never */)) {
                    (usage.candidateThisTypes || (usage.candidateThisTypes = [])).push(type);
                }
            }
        }
        var fixId38, errorCodes49;
        var init_inferFromUsage = __esm({
            "src/services/codefixes/inferFromUsage.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId38 = "inferFromUsage";
                errorCodes49 = [
                    // Variable declarations
                    Diagnostics.Variable_0_implicitly_has_type_1_in_some_locations_where_its_type_cannot_be_determined.code,
                    // Variable uses
                    Diagnostics.Variable_0_implicitly_has_an_1_type.code,
                    // Parameter declarations
                    Diagnostics.Parameter_0_implicitly_has_an_1_type.code,
                    Diagnostics.Rest_parameter_0_implicitly_has_an_any_type.code,
                    // Get Accessor declarations
                    Diagnostics.Property_0_implicitly_has_type_any_because_its_get_accessor_lacks_a_return_type_annotation.code,
                    Diagnostics._0_which_lacks_return_type_annotation_implicitly_has_an_1_return_type.code,
                    // Set Accessor declarations
                    Diagnostics.Property_0_implicitly_has_type_any_because_its_set_accessor_lacks_a_parameter_type_annotation.code,
                    // Property declarations
                    Diagnostics.Member_0_implicitly_has_an_1_type.code,
                    //// Suggestions
                    // Variable declarations
                    Diagnostics.Variable_0_implicitly_has_type_1_in_some_locations_but_a_better_type_may_be_inferred_from_usage.code,
                    // Variable uses
                    Diagnostics.Variable_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage.code,
                    // Parameter declarations
                    Diagnostics.Parameter_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage.code,
                    Diagnostics.Rest_parameter_0_implicitly_has_an_any_type_but_a_better_type_may_be_inferred_from_usage.code,
                    // Get Accessor declarations
                    Diagnostics.Property_0_implicitly_has_type_any_but_a_better_type_for_its_get_accessor_may_be_inferred_from_usage.code,
                    Diagnostics._0_implicitly_has_an_1_return_type_but_a_better_type_may_be_inferred_from_usage.code,
                    // Set Accessor declarations
                    Diagnostics.Property_0_implicitly_has_type_any_but_a_better_type_for_its_set_accessor_may_be_inferred_from_usage.code,
                    // Property declarations
                    Diagnostics.Member_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage.code,
                    // Function expressions and declarations
                    Diagnostics.this_implicitly_has_type_any_because_it_does_not_have_a_type_annotation.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes49,
                    getCodeActions(context) {
                        const { sourceFile, program, span: { start }, errorCode, cancellationToken, host, preferences } = context;
                        const token = getTokenAtPosition(sourceFile, start);
                        let declaration;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (changes2) => {
                            declaration = doChange33(changes2, sourceFile, token, errorCode, program, cancellationToken, 
                            /*markSeen*/
                            returnTrue, host, preferences);
                        });
                        const name = declaration && getNameOfDeclaration(declaration);
                        return !name || changes.length === 0 ? void 0 : [createCodeFixAction(fixId38, changes, [getDiagnostic(errorCode, token), getTextOfNode(name)], fixId38, Diagnostics.Infer_all_types_from_usage)];
                    },
                    fixIds: [fixId38],
                    getAllCodeActions(context) {
                        const { sourceFile, program, cancellationToken, host, preferences } = context;
                        const markSeen = nodeSeenTracker();
                        return codeFixAll(context, errorCodes49, (changes, err) => {
                            doChange33(changes, sourceFile, getTokenAtPosition(err.file, err.start), err.code, program, cancellationToken, markSeen, host, preferences);
                        });
                    }
                });
            }
        });
        // src/services/codefixes/fixReturnTypeInAsyncFunction.ts
        function getInfo16(sourceFile, checker, pos) {
            if (isInJSFile(sourceFile)) {
                return void 0;
            }
            const token = getTokenAtPosition(sourceFile, pos);
            const func = findAncestor(token, isFunctionLikeDeclaration);
            const returnTypeNode = func == null ? void 0 : func.type;
            if (!returnTypeNode) {
                return void 0;
            }
            const returnType = checker.getTypeFromTypeNode(returnTypeNode);
            const promisedType = checker.getAwaitedType(returnType) || checker.getVoidType();
            const promisedTypeNode = checker.typeToTypeNode(promisedType, 
            /*enclosingDeclaration*/
            returnTypeNode, 
            /*flags*/
            void 0);
            if (promisedTypeNode) {
                return { returnTypeNode, returnType, promisedTypeNode, promisedType };
            }
        }
        function doChange34(changes, sourceFile, returnTypeNode, promisedTypeNode) {
            changes.replaceNode(sourceFile, returnTypeNode, factory.createTypeReferenceNode("Promise", [promisedTypeNode]));
        }
        var fixId39, errorCodes50;
        var init_fixReturnTypeInAsyncFunction = __esm({
            "src/services/codefixes/fixReturnTypeInAsyncFunction.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId39 = "fixReturnTypeInAsyncFunction";
                errorCodes50 = [
                    Diagnostics.The_return_type_of_an_async_function_or_method_must_be_the_global_Promise_T_type_Did_you_mean_to_write_Promise_0.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes50,
                    fixIds: [fixId39],
                    getCodeActions: function getCodeActionsToFixReturnTypeInAsyncFunction(context) {
                        const { sourceFile, program, span } = context;
                        const checker = program.getTypeChecker();
                        const info = getInfo16(sourceFile, program.getTypeChecker(), span.start);
                        if (!info) {
                            return void 0;
                        }
                        const { returnTypeNode, returnType, promisedTypeNode, promisedType } = info;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange34(t, sourceFile, returnTypeNode, promisedTypeNode));
                        return [createCodeFixAction(fixId39, changes, [Diagnostics.Replace_0_with_Promise_1, checker.typeToString(returnType), checker.typeToString(promisedType)], fixId39, Diagnostics.Fix_all_incorrect_return_type_of_an_async_functions)];
                    },
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes50, (changes, diag2) => {
                        const info = getInfo16(diag2.file, context.program.getTypeChecker(), diag2.start);
                        if (info) {
                            doChange34(changes, diag2.file, info.returnTypeNode, info.promisedTypeNode);
                        }
                    })
                });
            }
        });
        // src/services/codefixes/disableJsDiagnostics.ts
        function makeChange8(changes, sourceFile, position, seenLines) {
            const { line: lineNumber } = getLineAndCharacterOfPosition(sourceFile, position);
            if (!seenLines || tryAddToSet(seenLines, lineNumber)) {
                changes.insertCommentBeforeLine(sourceFile, lineNumber, position, " @ts-ignore");
            }
        }
        var fixName4, fixId40, errorCodes51;
        var init_disableJsDiagnostics = __esm({
            "src/services/codefixes/disableJsDiagnostics.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixName4 = "disableJsDiagnostics";
                fixId40 = "disableJsDiagnostics";
                errorCodes51 = mapDefined(Object.keys(Diagnostics), (key) => {
                    const diag2 = Diagnostics[key];
                    return diag2.category === 1 /* Error */ ? diag2.code : void 0;
                });
                registerCodeFix({
                    errorCodes: errorCodes51,
                    getCodeActions: function getCodeActionsToDisableJsDiagnostics(context) {
                        const { sourceFile, program, span, host, formatContext } = context;
                        if (!isInJSFile(sourceFile) || !isCheckJsEnabledForFile(sourceFile, program.getCompilerOptions())) {
                            return void 0;
                        }
                        const newLineCharacter = sourceFile.checkJsDirective ? "" : getNewLineOrDefaultFromHost(host, formatContext.options);
                        const fixes = [
                            // fixId unnecessary because adding `// @ts-nocheck` even once will ignore every error in the file.
                            createCodeFixActionWithoutFixAll(fixName4, [createFileTextChanges(sourceFile.fileName, [
                                    createTextChange(sourceFile.checkJsDirective ? createTextSpanFromBounds(sourceFile.checkJsDirective.pos, sourceFile.checkJsDirective.end) : createTextSpan(0, 0), `// @ts-nocheck${newLineCharacter}`)
                                ])], Diagnostics.Disable_checking_for_this_file)
                        ];
                        if (ts_textChanges_exports.isValidLocationToAddComment(sourceFile, span.start)) {
                            fixes.unshift(createCodeFixAction(fixName4, ts_textChanges_exports.ChangeTracker.with(context, (t) => makeChange8(t, sourceFile, span.start)), Diagnostics.Ignore_this_error_message, fixId40, Diagnostics.Add_ts_ignore_to_all_error_messages));
                        }
                        return fixes;
                    },
                    fixIds: [fixId40],
                    getAllCodeActions: (context) => {
                        const seenLines = /* @__PURE__ */ new Set();
                        return codeFixAll(context, errorCodes51, (changes, diag2) => {
                            if (ts_textChanges_exports.isValidLocationToAddComment(diag2.file, diag2.start)) {
                                makeChange8(changes, diag2.file, diag2.start, seenLines);
                            }
                        });
                    }
                });
            }
        });
        // src/services/codefixes/helpers.ts
        function createMissingMemberNodes(classDeclaration, possiblyMissingSymbols, sourceFile, context, preferences, importAdder, addClassElement) {
            const classMembers = classDeclaration.symbol.members;
            for (const symbol of possiblyMissingSymbols) {
                if (!classMembers.has(symbol.escapedName)) {
                    addNewNodeForMemberSymbol(symbol, classDeclaration, sourceFile, context, preferences, importAdder, addClassElement, 
                    /*body*/
                    void 0);
                }
            }
        }
        function getNoopSymbolTrackerWithResolver(context) {
            return {
                trackSymbol: () => false,
                moduleResolverHost: getModuleSpecifierResolverHost(context.program, context.host)
            };
        }
        function addNewNodeForMemberSymbol(symbol, enclosingDeclaration, sourceFile, context, preferences, importAdder, addClassElement, body, preserveOptional = 3 /* All */, isAmbient = false) {
            const declarations = symbol.getDeclarations();
            const declaration = firstOrUndefined(declarations);
            const checker = context.program.getTypeChecker();
            const scriptTarget = getEmitScriptTarget(context.program.getCompilerOptions());
            const kind = (declaration == null ? void 0 : declaration.kind) ?? 171 /* PropertySignature */;
            const declarationName = createDeclarationName(symbol, declaration);
            const effectiveModifierFlags = declaration ? getEffectiveModifierFlags(declaration) : 0 /* None */;
            let modifierFlags = effectiveModifierFlags & 256 /* Static */;
            modifierFlags |= effectiveModifierFlags & 1 /* Public */ ? 1 /* Public */ : effectiveModifierFlags & 4 /* Protected */ ? 4 /* Protected */ : 0 /* None */;
            if (declaration && isAutoAccessorPropertyDeclaration(declaration)) {
                modifierFlags |= 512 /* Accessor */;
            }
            const modifiers = createModifiers();
            const type = checker.getWidenedType(checker.getTypeOfSymbolAtLocation(symbol, enclosingDeclaration));
            const optional = !!(symbol.flags & 16777216 /* Optional */);
            const ambient = !!(enclosingDeclaration.flags & 33554432 /* Ambient */) || isAmbient;
            const quotePreference = getQuotePreference(sourceFile, preferences);
            switch (kind) {
                case 171 /* PropertySignature */:
                case 172 /* PropertyDeclaration */:
                    const flags = quotePreference === 0 /* Single */ ? 268435456 /* UseSingleQuotesForStringLiteralType */ : void 0;
                    let typeNode = checker.typeToTypeNode(type, enclosingDeclaration, flags, getNoopSymbolTrackerWithResolver(context));
                    if (importAdder) {
                        const importableReference = tryGetAutoImportableReferenceFromTypeNode(typeNode, scriptTarget);
                        if (importableReference) {
                            typeNode = importableReference.typeNode;
                            importSymbols(importAdder, importableReference.symbols);
                        }
                    }
                    addClassElement(factory.createPropertyDeclaration(modifiers, declaration ? createName(declarationName) : symbol.getName(), optional && preserveOptional & 2 /* Property */ ? factory.createToken(58 /* QuestionToken */) : void 0, typeNode, 
                    /*initializer*/
                    void 0));
                    break;
                case 177 /* GetAccessor */:
                case 178 /* SetAccessor */: {
                    Debug.assertIsDefined(declarations);
                    let typeNode2 = checker.typeToTypeNode(type, enclosingDeclaration, 
                    /*flags*/
                    void 0, getNoopSymbolTrackerWithResolver(context));
                    const allAccessors = getAllAccessorDeclarations(declarations, declaration);
                    const orderedAccessors = allAccessors.secondAccessor ? [allAccessors.firstAccessor, allAccessors.secondAccessor] : [allAccessors.firstAccessor];
                    if (importAdder) {
                        const importableReference = tryGetAutoImportableReferenceFromTypeNode(typeNode2, scriptTarget);
                        if (importableReference) {
                            typeNode2 = importableReference.typeNode;
                            importSymbols(importAdder, importableReference.symbols);
                        }
                    }
                    for (const accessor of orderedAccessors) {
                        if (isGetAccessorDeclaration(accessor)) {
                            addClassElement(factory.createGetAccessorDeclaration(modifiers, createName(declarationName), emptyArray, createTypeNode(typeNode2), createBody(body, quotePreference, ambient)));
                        }
                        else {
                            Debug.assertNode(accessor, isSetAccessorDeclaration, "The counterpart to a getter should be a setter");
                            const parameter = getSetAccessorValueParameter(accessor);
                            const parameterName = parameter && isIdentifier(parameter.name) ? idText(parameter.name) : void 0;
                            addClassElement(factory.createSetAccessorDeclaration(modifiers, createName(declarationName), createDummyParameters(1, [parameterName], [createTypeNode(typeNode2)], 1, 
                            /*inJs*/
                            false), createBody(body, quotePreference, ambient)));
                        }
                    }
                    break;
                }
                case 173 /* MethodSignature */:
                case 174 /* MethodDeclaration */:
                    Debug.assertIsDefined(declarations);
                    const signatures = type.isUnion() ? flatMap(type.types, (t) => t.getCallSignatures()) : type.getCallSignatures();
                    if (!some(signatures)) {
                        break;
                    }
                    if (declarations.length === 1) {
                        Debug.assert(signatures.length === 1, "One declaration implies one signature");
                        const signature = signatures[0];
                        outputMethod(quotePreference, signature, modifiers, createName(declarationName), createBody(body, quotePreference, ambient));
                        break;
                    }
                    for (const signature of signatures) {
                        outputMethod(quotePreference, signature, modifiers, createName(declarationName));
                    }
                    if (!ambient) {
                        if (declarations.length > signatures.length) {
                            const signature = checker.getSignatureFromDeclaration(declarations[declarations.length - 1]);
                            outputMethod(quotePreference, signature, modifiers, createName(declarationName), createBody(body, quotePreference));
                        }
                        else {
                            Debug.assert(declarations.length === signatures.length, "Declarations and signatures should match count");
                            addClassElement(createMethodImplementingSignatures(checker, context, enclosingDeclaration, signatures, createName(declarationName), optional && !!(preserveOptional & 1 /* Method */), modifiers, quotePreference, body));
                        }
                    }
                    break;
            }
            function outputMethod(quotePreference2, signature, modifiers2, name, body2) {
                const method = createSignatureDeclarationFromSignature(174 /* MethodDeclaration */, context, quotePreference2, signature, body2, name, modifiers2, optional && !!(preserveOptional & 1 /* Method */), enclosingDeclaration, importAdder);
                if (method)
                    addClassElement(method);
            }
            function createModifiers() {
                let modifiers2;
                if (modifierFlags) {
                    modifiers2 = combine(modifiers2, factory.createModifiersFromModifierFlags(modifierFlags));
                }
                if (shouldAddOverrideKeyword()) {
                    modifiers2 = append(modifiers2, factory.createToken(164 /* OverrideKeyword */));
                }
                return modifiers2 && factory.createNodeArray(modifiers2);
            }
            function shouldAddOverrideKeyword() {
                return !!(context.program.getCompilerOptions().noImplicitOverride && declaration && hasAbstractModifier(declaration));
            }
            function createName(node) {
                if (isIdentifier(node) && node.escapedText === "constructor") {
                    return factory.createComputedPropertyName(factory.createStringLiteral(idText(node), quotePreference === 0 /* Single */));
                }
                return getSynthesizedDeepClone(node, 
                /*includeTrivia*/
                false);
            }
            function createBody(block, quotePreference2, ambient2) {
                return ambient2 ? void 0 : getSynthesizedDeepClone(block, 
                /*includeTrivia*/
                false) || createStubbedMethodBody(quotePreference2);
            }
            function createTypeNode(typeNode) {
                return getSynthesizedDeepClone(typeNode, 
                /*includeTrivia*/
                false);
            }
            function createDeclarationName(symbol2, declaration2) {
                if (getCheckFlags(symbol2) & 262144 /* Mapped */) {
                    const nameType = symbol2.links.nameType;
                    if (nameType && isTypeUsableAsPropertyName(nameType)) {
                        return factory.createIdentifier(unescapeLeadingUnderscores(getPropertyNameFromType(nameType)));
                    }
                }
                return getSynthesizedDeepClone(getNameOfDeclaration(declaration2), 
                /*includeTrivia*/
                false);
            }
        }
        function createSignatureDeclarationFromSignature(kind, context, quotePreference, signature, body, name, modifiers, optional, enclosingDeclaration, importAdder) {
            const program = context.program;
            const checker = program.getTypeChecker();
            const scriptTarget = getEmitScriptTarget(program.getCompilerOptions());
            const isJs = isInJSFile(enclosingDeclaration);
            const flags = 1 /* NoTruncation */ | 256 /* SuppressAnyReturnType */ | 524288 /* AllowEmptyTuple */ | (quotePreference === 0 /* Single */ ? 268435456 /* UseSingleQuotesForStringLiteralType */ : 0 /* None */);
            const signatureDeclaration = checker.signatureToSignatureDeclaration(signature, kind, enclosingDeclaration, flags, getNoopSymbolTrackerWithResolver(context));
            if (!signatureDeclaration) {
                return void 0;
            }
            let typeParameters = isJs ? void 0 : signatureDeclaration.typeParameters;
            let parameters = signatureDeclaration.parameters;
            let type = isJs ? void 0 : signatureDeclaration.type;
            if (importAdder) {
                if (typeParameters) {
                    const newTypeParameters = sameMap(typeParameters, (typeParameterDecl) => {
                        let constraint = typeParameterDecl.constraint;
                        let defaultType = typeParameterDecl.default;
                        if (constraint) {
                            const importableReference = tryGetAutoImportableReferenceFromTypeNode(constraint, scriptTarget);
                            if (importableReference) {
                                constraint = importableReference.typeNode;
                                importSymbols(importAdder, importableReference.symbols);
                            }
                        }
                        if (defaultType) {
                            const importableReference = tryGetAutoImportableReferenceFromTypeNode(defaultType, scriptTarget);
                            if (importableReference) {
                                defaultType = importableReference.typeNode;
                                importSymbols(importAdder, importableReference.symbols);
                            }
                        }
                        return factory.updateTypeParameterDeclaration(typeParameterDecl, typeParameterDecl.modifiers, typeParameterDecl.name, constraint, defaultType);
                    });
                    if (typeParameters !== newTypeParameters) {
                        typeParameters = setTextRange(factory.createNodeArray(newTypeParameters, typeParameters.hasTrailingComma), typeParameters);
                    }
                }
                const newParameters = sameMap(parameters, (parameterDecl) => {
                    let type2 = isJs ? void 0 : parameterDecl.type;
                    if (type2) {
                        const importableReference = tryGetAutoImportableReferenceFromTypeNode(type2, scriptTarget);
                        if (importableReference) {
                            type2 = importableReference.typeNode;
                            importSymbols(importAdder, importableReference.symbols);
                        }
                    }
                    return factory.updateParameterDeclaration(parameterDecl, parameterDecl.modifiers, parameterDecl.dotDotDotToken, parameterDecl.name, isJs ? void 0 : parameterDecl.questionToken, type2, parameterDecl.initializer);
                });
                if (parameters !== newParameters) {
                    parameters = setTextRange(factory.createNodeArray(newParameters, parameters.hasTrailingComma), parameters);
                }
                if (type) {
                    const importableReference = tryGetAutoImportableReferenceFromTypeNode(type, scriptTarget);
                    if (importableReference) {
                        type = importableReference.typeNode;
                        importSymbols(importAdder, importableReference.symbols);
                    }
                }
            }
            const questionToken = optional ? factory.createToken(58 /* QuestionToken */) : void 0;
            const asteriskToken = signatureDeclaration.asteriskToken;
            if (isFunctionExpression(signatureDeclaration)) {
                return factory.updateFunctionExpression(signatureDeclaration, modifiers, signatureDeclaration.asteriskToken, tryCast(name, isIdentifier), typeParameters, parameters, type, body ?? signatureDeclaration.body);
            }
            if (isArrowFunction(signatureDeclaration)) {
                return factory.updateArrowFunction(signatureDeclaration, modifiers, typeParameters, parameters, type, signatureDeclaration.equalsGreaterThanToken, body ?? signatureDeclaration.body);
            }
            if (isMethodDeclaration(signatureDeclaration)) {
                return factory.updateMethodDeclaration(signatureDeclaration, modifiers, asteriskToken, name ?? factory.createIdentifier(""), questionToken, typeParameters, parameters, type, body);
            }
            if (isFunctionDeclaration(signatureDeclaration)) {
                return factory.updateFunctionDeclaration(signatureDeclaration, modifiers, signatureDeclaration.asteriskToken, tryCast(name, isIdentifier), typeParameters, parameters, type, body ?? signatureDeclaration.body);
            }
            return void 0;
        }
        function createSignatureDeclarationFromCallExpression(kind, context, importAdder, call, name, modifierFlags, contextNode) {
            const quotePreference = getQuotePreference(context.sourceFile, context.preferences);
            const scriptTarget = getEmitScriptTarget(context.program.getCompilerOptions());
            const tracker = getNoopSymbolTrackerWithResolver(context);
            const checker = context.program.getTypeChecker();
            const isJs = isInJSFile(contextNode);
            const { typeArguments, arguments: args, parent: parent2 } = call;
            const contextualType = isJs ? void 0 : checker.getContextualType(call);
            const names = map(args, (arg) => isIdentifier(arg) ? arg.text : isPropertyAccessExpression(arg) && isIdentifier(arg.name) ? arg.name.text : void 0);
            const instanceTypes = isJs ? [] : map(args, (arg) => checker.getTypeAtLocation(arg));
            const { argumentTypeNodes, argumentTypeParameters } = getArgumentTypesAndTypeParameters(checker, importAdder, instanceTypes, contextNode, scriptTarget, 1 /* NoTruncation */, tracker);
            const modifiers = modifierFlags ? factory.createNodeArray(factory.createModifiersFromModifierFlags(modifierFlags)) : void 0;
            const asteriskToken = isYieldExpression(parent2) ? factory.createToken(42 /* AsteriskToken */) : void 0;
            const typeParameters = isJs ? void 0 : createTypeParametersForArguments(checker, argumentTypeParameters, typeArguments);
            const parameters = createDummyParameters(args.length, names, argumentTypeNodes, 
            /*minArgumentCount*/
            void 0, isJs);
            const type = isJs || contextualType === void 0 ? void 0 : checker.typeToTypeNode(contextualType, contextNode, 
            /*flags*/
            void 0, tracker);
            switch (kind) {
                case 174 /* MethodDeclaration */:
                    return factory.createMethodDeclaration(modifiers, asteriskToken, name, 
                    /*questionToken*/
                    void 0, typeParameters, parameters, type, createStubbedMethodBody(quotePreference));
                case 173 /* MethodSignature */:
                    return factory.createMethodSignature(modifiers, name, 
                    /*questionToken*/
                    void 0, typeParameters, parameters, type === void 0 ? factory.createKeywordTypeNode(159 /* UnknownKeyword */) : type);
                case 262 /* FunctionDeclaration */:
                    Debug.assert(typeof name === "string" || isIdentifier(name), "Unexpected name");
                    return factory.createFunctionDeclaration(modifiers, asteriskToken, name, typeParameters, parameters, type, createStubbedBody(Diagnostics.Function_not_implemented.message, quotePreference));
                default:
                    Debug.fail("Unexpected kind");
            }
        }
        function createTypeParametersForArguments(checker, argumentTypeParameters, typeArguments) {
            const usedNames = new Set(argumentTypeParameters.map((pair) => pair[0]));
            const constraintsByName = new Map(argumentTypeParameters);
            if (typeArguments) {
                const typeArgumentsWithNewTypes = typeArguments.filter((typeArgument) => !argumentTypeParameters.some((pair) => {
                    var _a;
                    return checker.getTypeAtLocation(typeArgument) === ((_a = pair[1]) == null ? void 0 : _a.argumentType);
                }));
                const targetSize = usedNames.size + typeArgumentsWithNewTypes.length;
                for (let i = 0; usedNames.size < targetSize; i += 1) {
                    usedNames.add(createTypeParameterName(i));
                }
            }
            return arrayFrom(usedNames.values(), (usedName) => {
                var _a;
                return factory.createTypeParameterDeclaration(
                /*modifiers*/
                void 0, usedName, (_a = constraintsByName.get(usedName)) == null ? void 0 : _a.constraint);
            });
        }
        function createTypeParameterName(index) {
            return 84 /* T */ + index <= 90 /* Z */ ? String.fromCharCode(84 /* T */ + index) : `T${index}`;
        }
        function typeToAutoImportableTypeNode(checker, importAdder, type, contextNode, scriptTarget, flags, tracker) {
            let typeNode = checker.typeToTypeNode(type, contextNode, flags, tracker);
            if (typeNode && isImportTypeNode(typeNode)) {
                const importableReference = tryGetAutoImportableReferenceFromTypeNode(typeNode, scriptTarget);
                if (importableReference) {
                    importSymbols(importAdder, importableReference.symbols);
                    typeNode = importableReference.typeNode;
                }
            }
            return getSynthesizedDeepClone(typeNode);
        }
        function typeContainsTypeParameter(type) {
            if (type.isUnionOrIntersection()) {
                return type.types.some(typeContainsTypeParameter);
            }
            return type.flags & 262144 /* TypeParameter */;
        }
        function getArgumentTypesAndTypeParameters(checker, importAdder, instanceTypes, contextNode, scriptTarget, flags, tracker) {
            const argumentTypeNodes = [];
            const argumentTypeParameters = /* @__PURE__ */ new Map();
            for (let i = 0; i < instanceTypes.length; i += 1) {
                const instanceType = instanceTypes[i];
                if (instanceType.isUnionOrIntersection() && instanceType.types.some(typeContainsTypeParameter)) {
                    const synthesizedTypeParameterName = createTypeParameterName(i);
                    argumentTypeNodes.push(factory.createTypeReferenceNode(synthesizedTypeParameterName));
                    argumentTypeParameters.set(synthesizedTypeParameterName, void 0);
                    continue;
                }
                const widenedInstanceType = checker.getBaseTypeOfLiteralType(instanceType);
                const argumentTypeNode = typeToAutoImportableTypeNode(checker, importAdder, widenedInstanceType, contextNode, scriptTarget, flags, tracker);
                if (!argumentTypeNode) {
                    continue;
                }
                argumentTypeNodes.push(argumentTypeNode);
                const argumentTypeParameter = getFirstTypeParameterName(instanceType);
                const instanceTypeConstraint = instanceType.isTypeParameter() && instanceType.constraint && !isAnonymousObjectConstraintType(instanceType.constraint) ? typeToAutoImportableTypeNode(checker, importAdder, instanceType.constraint, contextNode, scriptTarget, flags, tracker) : void 0;
                if (argumentTypeParameter) {
                    argumentTypeParameters.set(argumentTypeParameter, { argumentType: instanceType, constraint: instanceTypeConstraint });
                }
            }
            return { argumentTypeNodes, argumentTypeParameters: arrayFrom(argumentTypeParameters.entries()) };
        }
        function isAnonymousObjectConstraintType(type) {
            return type.flags & 524288 /* Object */ && type.objectFlags === 16 /* Anonymous */;
        }
        function getFirstTypeParameterName(type) {
            var _a;
            if (type.flags & (1048576 /* Union */ | 2097152 /* Intersection */)) {
                for (const subType of type.types) {
                    const subTypeName = getFirstTypeParameterName(subType);
                    if (subTypeName) {
                        return subTypeName;
                    }
                }
            }
            return type.flags & 262144 /* TypeParameter */ ? (_a = type.getSymbol()) == null ? void 0 : _a.getName() : void 0;
        }
        function createDummyParameters(argCount, names, types, minArgumentCount, inJs) {
            const parameters = [];
            const parameterNameCounts = /* @__PURE__ */ new Map();
            for (let i = 0; i < argCount; i++) {
                const parameterName = (names == null ? void 0 : names[i]) || `arg${i}`;
                const parameterNameCount = parameterNameCounts.get(parameterName);
                parameterNameCounts.set(parameterName, (parameterNameCount || 0) + 1);
                const newParameter = factory.createParameterDeclaration(
                /*modifiers*/
                void 0, 
                /*dotDotDotToken*/
                void 0, 
                /*name*/
                parameterName + (parameterNameCount || ""), 
                /*questionToken*/
                minArgumentCount !== void 0 && i >= minArgumentCount ? factory.createToken(58 /* QuestionToken */) : void 0, 
                /*type*/
                inJs ? void 0 : (types == null ? void 0 : types[i]) || factory.createKeywordTypeNode(159 /* UnknownKeyword */), 
                /*initializer*/
                void 0);
                parameters.push(newParameter);
            }
            return parameters;
        }
        function createMethodImplementingSignatures(checker, context, enclosingDeclaration, signatures, name, optional, modifiers, quotePreference, body) {
            let maxArgsSignature = signatures[0];
            let minArgumentCount = signatures[0].minArgumentCount;
            let someSigHasRestParameter = false;
            for (const sig of signatures) {
                minArgumentCount = Math.min(sig.minArgumentCount, minArgumentCount);
                if (signatureHasRestParameter(sig)) {
                    someSigHasRestParameter = true;
                }
                if (sig.parameters.length >= maxArgsSignature.parameters.length && (!signatureHasRestParameter(sig) || signatureHasRestParameter(maxArgsSignature))) {
                    maxArgsSignature = sig;
                }
            }
            const maxNonRestArgs = maxArgsSignature.parameters.length - (signatureHasRestParameter(maxArgsSignature) ? 1 : 0);
            const maxArgsParameterSymbolNames = maxArgsSignature.parameters.map((symbol) => symbol.name);
            const parameters = createDummyParameters(maxNonRestArgs, maxArgsParameterSymbolNames, 
            /*types*/
            void 0, minArgumentCount, 
            /*inJs*/
            false);
            if (someSigHasRestParameter) {
                const restParameter = factory.createParameterDeclaration(
                /*modifiers*/
                void 0, factory.createToken(26 /* DotDotDotToken */), maxArgsParameterSymbolNames[maxNonRestArgs] || "rest", 
                /*questionToken*/
                maxNonRestArgs >= minArgumentCount ? factory.createToken(58 /* QuestionToken */) : void 0, factory.createArrayTypeNode(factory.createKeywordTypeNode(159 /* UnknownKeyword */)), 
                /*initializer*/
                void 0);
                parameters.push(restParameter);
            }
            return createStubbedMethod(modifiers, name, optional, 
            /*typeParameters*/
            void 0, parameters, getReturnTypeFromSignatures(signatures, checker, context, enclosingDeclaration), quotePreference, body);
        }
        function getReturnTypeFromSignatures(signatures, checker, context, enclosingDeclaration) {
            if (length(signatures)) {
                const type = checker.getUnionType(map(signatures, checker.getReturnTypeOfSignature));
                return checker.typeToTypeNode(type, enclosingDeclaration, 1 /* NoTruncation */, getNoopSymbolTrackerWithResolver(context));
            }
        }
        function createStubbedMethod(modifiers, name, optional, typeParameters, parameters, returnType, quotePreference, body) {
            return factory.createMethodDeclaration(modifiers, 
            /*asteriskToken*/
            void 0, name, optional ? factory.createToken(58 /* QuestionToken */) : void 0, typeParameters, parameters, returnType, body || createStubbedMethodBody(quotePreference));
        }
        function createStubbedMethodBody(quotePreference) {
            return createStubbedBody(Diagnostics.Method_not_implemented.message, quotePreference);
        }
        function createStubbedBody(text, quotePreference) {
            return factory.createBlock([factory.createThrowStatement(factory.createNewExpression(factory.createIdentifier("Error"), 
                /*typeArguments*/
                void 0, 
                // TODO Handle auto quote preference.
                [factory.createStringLiteral(text, 
                    /*isSingleQuote*/
                    quotePreference === 0 /* Single */)]))], 
            /*multiLine*/
            true);
        }
        function setJsonCompilerOptionValues(changeTracker, configFile, options) {
            const tsconfigObjectLiteral = getTsConfigObjectLiteralExpression(configFile);
            if (!tsconfigObjectLiteral)
                return void 0;
            const compilerOptionsProperty = findJsonProperty(tsconfigObjectLiteral, "compilerOptions");
            if (compilerOptionsProperty === void 0) {
                changeTracker.insertNodeAtObjectStart(configFile, tsconfigObjectLiteral, createJsonPropertyAssignment("compilerOptions", factory.createObjectLiteralExpression(options.map(([optionName, optionValue]) => createJsonPropertyAssignment(optionName, optionValue)), 
                /*multiLine*/
                true)));
                return;
            }
            const compilerOptions = compilerOptionsProperty.initializer;
            if (!isObjectLiteralExpression(compilerOptions)) {
                return;
            }
            for (const [optionName, optionValue] of options) {
                const optionProperty = findJsonProperty(compilerOptions, optionName);
                if (optionProperty === void 0) {
                    changeTracker.insertNodeAtObjectStart(configFile, compilerOptions, createJsonPropertyAssignment(optionName, optionValue));
                }
                else {
                    changeTracker.replaceNode(configFile, optionProperty.initializer, optionValue);
                }
            }
        }
        function setJsonCompilerOptionValue(changeTracker, configFile, optionName, optionValue) {
            setJsonCompilerOptionValues(changeTracker, configFile, [[optionName, optionValue]]);
        }
        function createJsonPropertyAssignment(name, initializer) {
            return factory.createPropertyAssignment(factory.createStringLiteral(name), initializer);
        }
        function findJsonProperty(obj, name) {
            return find(obj.properties, (p) => isPropertyAssignment(p) && !!p.name && isStringLiteral(p.name) && p.name.text === name);
        }
        function tryGetAutoImportableReferenceFromTypeNode(importTypeNode, scriptTarget) {
            let symbols;
            const typeNode = visitNode(importTypeNode, visit, isTypeNode);
            if (symbols && typeNode) {
                return { typeNode, symbols };
            }
            function visit(node) {
                if (isLiteralImportTypeNode(node) && node.qualifier) {
                    const firstIdentifier = getFirstIdentifier(node.qualifier);
                    const name = getNameForExportedSymbol(firstIdentifier.symbol, scriptTarget);
                    const qualifier = name !== firstIdentifier.text ? replaceFirstIdentifierOfEntityName(node.qualifier, factory.createIdentifier(name)) : node.qualifier;
                    symbols = append(symbols, firstIdentifier.symbol);
                    const typeArguments = visitNodes2(node.typeArguments, visit, isTypeNode);
                    return factory.createTypeReferenceNode(qualifier, typeArguments);
                }
                return visitEachChild(node, visit, 
                /*context*/
                void 0);
            }
        }
        function replaceFirstIdentifierOfEntityName(name, newIdentifier) {
            if (name.kind === 80 /* Identifier */) {
                return newIdentifier;
            }
            return factory.createQualifiedName(replaceFirstIdentifierOfEntityName(name.left, newIdentifier), name.right);
        }
        function importSymbols(importAdder, symbols) {
            symbols.forEach((s) => importAdder.addImportFromExportedSymbol(s, 
            /*isValidTypeOnlyUseSite*/
            true));
        }
        function findAncestorMatchingSpan(sourceFile, span) {
            const end = textSpanEnd(span);
            let token = getTokenAtPosition(sourceFile, span.start);
            while (token.end < end) {
                token = token.parent;
            }
            return token;
        }
        var PreserveOptionalFlags;
        var init_helpers2 = __esm({
            "src/services/codefixes/helpers.ts"() {
                "use strict";
                init_ts4();
                PreserveOptionalFlags = /* @__PURE__ */ ((PreserveOptionalFlags2) => {
                    PreserveOptionalFlags2[PreserveOptionalFlags2["Method"] = 1] = "Method";
                    PreserveOptionalFlags2[PreserveOptionalFlags2["Property"] = 2] = "Property";
                    PreserveOptionalFlags2[PreserveOptionalFlags2["All"] = 3] = "All";
                    return PreserveOptionalFlags2;
                })(PreserveOptionalFlags || {});
            }
        });
        // src/services/codefixes/generateAccessors.ts
        function generateAccessorFromProperty(file, program, start, end, context, _actionName) {
            const fieldInfo = getAccessorConvertiblePropertyAtPosition(file, program, start, end);
            if (!fieldInfo || ts_refactor_exports.isRefactorErrorInfo(fieldInfo))
                return void 0;
            const changeTracker = ts_textChanges_exports.ChangeTracker.fromContext(context);
            const { isStatic: isStatic2, isReadonly, fieldName, accessorName, originalName, type, container, declaration } = fieldInfo;
            suppressLeadingAndTrailingTrivia(fieldName);
            suppressLeadingAndTrailingTrivia(accessorName);
            suppressLeadingAndTrailingTrivia(declaration);
            suppressLeadingAndTrailingTrivia(container);
            let accessorModifiers;
            let fieldModifiers;
            if (isClassLike(container)) {
                const modifierFlags = getEffectiveModifierFlags(declaration);
                if (isSourceFileJS(file)) {
                    const modifiers = factory.createModifiersFromModifierFlags(modifierFlags);
                    accessorModifiers = modifiers;
                    fieldModifiers = modifiers;
                }
                else {
                    accessorModifiers = factory.createModifiersFromModifierFlags(prepareModifierFlagsForAccessor(modifierFlags));
                    fieldModifiers = factory.createModifiersFromModifierFlags(prepareModifierFlagsForField(modifierFlags));
                }
                if (canHaveDecorators(declaration)) {
                    fieldModifiers = concatenate(getDecorators(declaration), fieldModifiers);
                }
            }
            updateFieldDeclaration(changeTracker, file, declaration, type, fieldName, fieldModifiers);
            const getAccessor = generateGetAccessor(fieldName, accessorName, type, accessorModifiers, isStatic2, container);
            suppressLeadingAndTrailingTrivia(getAccessor);
            insertAccessor(changeTracker, file, getAccessor, declaration, container);
            if (isReadonly) {
                const constructor = getFirstConstructorWithBody(container);
                if (constructor) {
                    updateReadonlyPropertyInitializerStatementConstructor(changeTracker, file, constructor, fieldName.text, originalName);
                }
            }
            else {
                const setAccessor = generateSetAccessor(fieldName, accessorName, type, accessorModifiers, isStatic2, container);
                suppressLeadingAndTrailingTrivia(setAccessor);
                insertAccessor(changeTracker, file, setAccessor, declaration, container);
            }
            return changeTracker.getChanges();
        }
        function isConvertibleName(name) {
            return isIdentifier(name) || isStringLiteral(name);
        }
        function isAcceptedDeclaration(node) {
            return isParameterPropertyDeclaration(node, node.parent) || isPropertyDeclaration(node) || isPropertyAssignment(node);
        }
        function createPropertyName(name, originalName) {
            return isIdentifier(originalName) ? factory.createIdentifier(name) : factory.createStringLiteral(name);
        }
        function createAccessorAccessExpression(fieldName, isStatic2, container) {
            const leftHead = isStatic2 ? container.name : factory.createThis();
            return isIdentifier(fieldName) ? factory.createPropertyAccessExpression(leftHead, fieldName) : factory.createElementAccessExpression(leftHead, factory.createStringLiteralFromNode(fieldName));
        }
        function prepareModifierFlagsForAccessor(modifierFlags) {
            modifierFlags &= ~8 /* Readonly */;
            modifierFlags &= ~2 /* Private */;
            if (!(modifierFlags & 4 /* Protected */)) {
                modifierFlags |= 1 /* Public */;
            }
            return modifierFlags;
        }
        function prepareModifierFlagsForField(modifierFlags) {
            modifierFlags &= ~1 /* Public */;
            modifierFlags &= ~4 /* Protected */;
            modifierFlags |= 2 /* Private */;
            return modifierFlags;
        }
        function getAccessorConvertiblePropertyAtPosition(file, program, start, end, considerEmptySpans = true) {
            const node = getTokenAtPosition(file, start);
            const cursorRequest = start === end && considerEmptySpans;
            const declaration = findAncestor(node.parent, isAcceptedDeclaration);
            const meaning = 7 /* AccessibilityModifier */ | 256 /* Static */ | 8 /* Readonly */;
            if (!declaration || !(nodeOverlapsWithStartEnd(declaration.name, file, start, end) || cursorRequest)) {
                return {
                    error: getLocaleSpecificMessage(Diagnostics.Could_not_find_property_for_which_to_generate_accessor)
                };
            }
            if (!isConvertibleName(declaration.name)) {
                return {
                    error: getLocaleSpecificMessage(Diagnostics.Name_is_not_valid)
                };
            }
            if ((getEffectiveModifierFlags(declaration) & 98303 /* Modifier */ | meaning) !== meaning) {
                return {
                    error: getLocaleSpecificMessage(Diagnostics.Can_only_convert_property_with_modifier)
                };
            }
            const name = declaration.name.text;
            const startWithUnderscore = startsWithUnderscore(name);
            const fieldName = createPropertyName(startWithUnderscore ? name : getUniqueName(`_${name}`, file), declaration.name);
            const accessorName = createPropertyName(startWithUnderscore ? getUniqueName(name.substring(1), file) : name, declaration.name);
            return {
                isStatic: hasStaticModifier(declaration),
                isReadonly: hasEffectiveReadonlyModifier(declaration),
                type: getDeclarationType(declaration, program),
                container: declaration.kind === 169 /* Parameter */ ? declaration.parent.parent : declaration.parent,
                originalName: declaration.name.text,
                declaration,
                fieldName,
                accessorName,
                renameAccessor: startWithUnderscore
            };
        }
        function generateGetAccessor(fieldName, accessorName, type, modifiers, isStatic2, container) {
            return factory.createGetAccessorDeclaration(modifiers, accessorName, [], type, factory.createBlock([
                factory.createReturnStatement(createAccessorAccessExpression(fieldName, isStatic2, container))
            ], 
            /*multiLine*/
            true));
        }
        function generateSetAccessor(fieldName, accessorName, type, modifiers, isStatic2, container) {
            return factory.createSetAccessorDeclaration(modifiers, accessorName, [factory.createParameterDeclaration(
                /*modifiers*/
                void 0, 
                /*dotDotDotToken*/
                void 0, factory.createIdentifier("value"), 
                /*questionToken*/
                void 0, type)], factory.createBlock([
                factory.createExpressionStatement(factory.createAssignment(createAccessorAccessExpression(fieldName, isStatic2, container), factory.createIdentifier("value")))
            ], 
            /*multiLine*/
            true));
        }
        function updatePropertyDeclaration(changeTracker, file, declaration, type, fieldName, modifiers) {
            const property = factory.updatePropertyDeclaration(declaration, modifiers, fieldName, declaration.questionToken || declaration.exclamationToken, type, declaration.initializer);
            changeTracker.replaceNode(file, declaration, property);
        }
        function updatePropertyAssignmentDeclaration(changeTracker, file, declaration, fieldName) {
            let assignment = factory.updatePropertyAssignment(declaration, fieldName, declaration.initializer);
            if (assignment.modifiers || assignment.questionToken || assignment.exclamationToken) {
                if (assignment === declaration)
                    assignment = factory.cloneNode(assignment);
                assignment.modifiers = void 0;
                assignment.questionToken = void 0;
                assignment.exclamationToken = void 0;
            }
            changeTracker.replacePropertyAssignment(file, declaration, assignment);
        }
        function updateFieldDeclaration(changeTracker, file, declaration, type, fieldName, modifiers) {
            if (isPropertyDeclaration(declaration)) {
                updatePropertyDeclaration(changeTracker, file, declaration, type, fieldName, modifiers);
            }
            else if (isPropertyAssignment(declaration)) {
                updatePropertyAssignmentDeclaration(changeTracker, file, declaration, fieldName);
            }
            else {
                changeTracker.replaceNode(file, declaration, factory.updateParameterDeclaration(declaration, modifiers, declaration.dotDotDotToken, cast(fieldName, isIdentifier), declaration.questionToken, declaration.type, declaration.initializer));
            }
        }
        function insertAccessor(changeTracker, file, accessor, declaration, container) {
            isParameterPropertyDeclaration(declaration, declaration.parent) ? changeTracker.insertMemberAtStart(file, container, accessor) : isPropertyAssignment(declaration) ? changeTracker.insertNodeAfterComma(file, declaration, accessor) : changeTracker.insertNodeAfter(file, declaration, accessor);
        }
        function updateReadonlyPropertyInitializerStatementConstructor(changeTracker, file, constructor, fieldName, originalName) {
            if (!constructor.body)
                return;
            constructor.body.forEachChild(function recur(node) {
                if (isElementAccessExpression(node) && node.expression.kind === 110 /* ThisKeyword */ && isStringLiteral(node.argumentExpression) && node.argumentExpression.text === originalName && isWriteAccess(node)) {
                    changeTracker.replaceNode(file, node.argumentExpression, factory.createStringLiteral(fieldName));
                }
                if (isPropertyAccessExpression(node) && node.expression.kind === 110 /* ThisKeyword */ && node.name.text === originalName && isWriteAccess(node)) {
                    changeTracker.replaceNode(file, node.name, factory.createIdentifier(fieldName));
                }
                if (!isFunctionLike(node) && !isClassLike(node)) {
                    node.forEachChild(recur);
                }
            });
        }
        function getDeclarationType(declaration, program) {
            const typeNode = getTypeAnnotationNode(declaration);
            if (isPropertyDeclaration(declaration) && typeNode && declaration.questionToken) {
                const typeChecker = program.getTypeChecker();
                const type = typeChecker.getTypeFromTypeNode(typeNode);
                if (!typeChecker.isTypeAssignableTo(typeChecker.getUndefinedType(), type)) {
                    const types = isUnionTypeNode(typeNode) ? typeNode.types : [typeNode];
                    return factory.createUnionTypeNode([...types, factory.createKeywordTypeNode(157 /* UndefinedKeyword */)]);
                }
            }
            return typeNode;
        }
        function getAllSupers(decl, checker) {
            const res = [];
            while (decl) {
                const superElement = getClassExtendsHeritageElement(decl);
                const superSymbol = superElement && checker.getSymbolAtLocation(superElement.expression);
                if (!superSymbol)
                    break;
                const symbol = superSymbol.flags & 2097152 /* Alias */ ? checker.getAliasedSymbol(superSymbol) : superSymbol;
                const superDecl = symbol.declarations && find(symbol.declarations, isClassLike);
                if (!superDecl)
                    break;
                res.push(superDecl);
                decl = superDecl;
            }
            return res;
        }
        var init_generateAccessors = __esm({
            "src/services/codefixes/generateAccessors.ts"() {
                "use strict";
                init_ts4();
            }
        });
        // src/services/codefixes/fixInvalidImportSyntax.ts
        function getCodeFixesForImportDeclaration(context, node) {
            const sourceFile = getSourceFileOfNode(node);
            const namespace = getNamespaceDeclarationNode(node);
            const opts = context.program.getCompilerOptions();
            const variations = [];
            variations.push(createAction(context, sourceFile, node, makeImport(namespace.name, 
            /*namedImports*/
            void 0, node.moduleSpecifier, getQuotePreference(sourceFile, context.preferences))));
            if (getEmitModuleKind(opts) === 1 /* CommonJS */) {
                variations.push(createAction(context, sourceFile, node, factory.createImportEqualsDeclaration(
                /*modifiers*/
                void 0, 
                /*isTypeOnly*/
                false, namespace.name, factory.createExternalModuleReference(node.moduleSpecifier))));
            }
            return variations;
        }
        function createAction(context, sourceFile, node, replacement) {
            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => t.replaceNode(sourceFile, node, replacement));
            return createCodeFixActionWithoutFixAll(fixName5, changes, [Diagnostics.Replace_import_with_0, changes[0].textChanges[0].newText]);
        }
        function getActionsForUsageOfInvalidImport(context) {
            const sourceFile = context.sourceFile;
            const targetKind = Diagnostics.This_expression_is_not_callable.code === context.errorCode ? 213 /* CallExpression */ : 214 /* NewExpression */;
            const node = findAncestor(getTokenAtPosition(sourceFile, context.span.start), (a) => a.kind === targetKind);
            if (!node) {
                return [];
            }
            const expr = node.expression;
            return getImportCodeFixesForExpression(context, expr);
        }
        function getActionsForInvalidImportLocation(context) {
            const sourceFile = context.sourceFile;
            const node = findAncestor(getTokenAtPosition(sourceFile, context.span.start), (a) => a.getStart() === context.span.start && a.getEnd() === context.span.start + context.span.length);
            if (!node) {
                return [];
            }
            return getImportCodeFixesForExpression(context, node);
        }
        function getImportCodeFixesForExpression(context, expr) {
            const type = context.program.getTypeChecker().getTypeAtLocation(expr);
            if (!(type.symbol && isTransientSymbol(type.symbol) && type.symbol.links.originatingImport)) {
                return [];
            }
            const fixes = [];
            const relatedImport = type.symbol.links.originatingImport;
            if (!isImportCall(relatedImport)) {
                addRange(fixes, getCodeFixesForImportDeclaration(context, relatedImport));
            }
            if (isExpression(expr) && !(isNamedDeclaration(expr.parent) && expr.parent.name === expr)) {
                const sourceFile = context.sourceFile;
                const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => t.replaceNode(sourceFile, expr, factory.createPropertyAccessExpression(expr, "default"), {}));
                fixes.push(createCodeFixActionWithoutFixAll(fixName5, changes, Diagnostics.Use_synthetic_default_member));
            }
            return fixes;
        }
        var fixName5;
        var init_fixInvalidImportSyntax = __esm({
            "src/services/codefixes/fixInvalidImportSyntax.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixName5 = "invalidImportSyntax";
                registerCodeFix({
                    errorCodes: [
                        Diagnostics.This_expression_is_not_callable.code,
                        Diagnostics.This_expression_is_not_constructable.code
                    ],
                    getCodeActions: getActionsForUsageOfInvalidImport
                });
                registerCodeFix({
                    errorCodes: [
                        // The following error codes cover pretty much all assignability errors that could involve an expression
                        Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1.code,
                        Diagnostics.Type_0_does_not_satisfy_the_constraint_1.code,
                        Diagnostics.Type_0_is_not_assignable_to_type_1.code,
                        Diagnostics.Type_0_is_not_assignable_to_type_1_Two_different_types_with_this_name_exist_but_they_are_unrelated.code,
                        Diagnostics.Type_predicate_0_is_not_assignable_to_1.code,
                        Diagnostics.Property_0_of_type_1_is_not_assignable_to_2_index_type_3.code,
                        Diagnostics._0_index_type_1_is_not_assignable_to_2_index_type_3.code,
                        Diagnostics.Property_0_in_type_1_is_not_assignable_to_the_same_property_in_base_type_2.code,
                        Diagnostics.Property_0_in_type_1_is_not_assignable_to_type_2.code,
                        Diagnostics.Property_0_of_JSX_spread_attribute_is_not_assignable_to_target_property.code,
                        Diagnostics.The_this_context_of_type_0_is_not_assignable_to_method_s_this_of_type_1.code
                    ],
                    getCodeActions: getActionsForInvalidImportLocation
                });
            }
        });
        // src/services/codefixes/fixStrictClassInitialization.ts
        function getInfo17(sourceFile, pos) {
            const token = getTokenAtPosition(sourceFile, pos);
            if (isIdentifier(token) && isPropertyDeclaration(token.parent)) {
                const type = getEffectiveTypeAnnotationNode(token.parent);
                if (type) {
                    return { type, prop: token.parent, isJs: isInJSFile(token.parent) };
                }
            }
            return void 0;
        }
        function getActionForAddMissingDefiniteAssignmentAssertion(context, info) {
            if (info.isJs)
                return void 0;
            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => addDefiniteAssignmentAssertion(t, context.sourceFile, info.prop));
            return createCodeFixAction(fixName6, changes, [Diagnostics.Add_definite_assignment_assertion_to_property_0, info.prop.getText()], fixIdAddDefiniteAssignmentAssertions, Diagnostics.Add_definite_assignment_assertions_to_all_uninitialized_properties);
        }
        function addDefiniteAssignmentAssertion(changeTracker, propertyDeclarationSourceFile, propertyDeclaration) {
            suppressLeadingAndTrailingTrivia(propertyDeclaration);
            const property = factory.updatePropertyDeclaration(propertyDeclaration, propertyDeclaration.modifiers, propertyDeclaration.name, factory.createToken(54 /* ExclamationToken */), propertyDeclaration.type, propertyDeclaration.initializer);
            changeTracker.replaceNode(propertyDeclarationSourceFile, propertyDeclaration, property);
        }
        function getActionForAddMissingUndefinedType(context, info) {
            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => addUndefinedType(t, context.sourceFile, info));
            return createCodeFixAction(fixName6, changes, [Diagnostics.Add_undefined_type_to_property_0, info.prop.name.getText()], fixIdAddUndefinedType, Diagnostics.Add_undefined_type_to_all_uninitialized_properties);
        }
        function addUndefinedType(changeTracker, sourceFile, info) {
            const undefinedTypeNode = factory.createKeywordTypeNode(157 /* UndefinedKeyword */);
            const types = isUnionTypeNode(info.type) ? info.type.types.concat(undefinedTypeNode) : [info.type, undefinedTypeNode];
            const unionTypeNode = factory.createUnionTypeNode(types);
            if (info.isJs) {
                changeTracker.addJSDocTags(sourceFile, info.prop, [factory.createJSDocTypeTag(
                    /*tagName*/
                    void 0, factory.createJSDocTypeExpression(unionTypeNode))]);
            }
            else {
                changeTracker.replaceNode(sourceFile, info.type, unionTypeNode);
            }
        }
        function getActionForAddMissingInitializer(context, info) {
            if (info.isJs)
                return void 0;
            const checker = context.program.getTypeChecker();
            const initializer = getInitializer(checker, info.prop);
            if (!initializer)
                return void 0;
            const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => addInitializer(t, context.sourceFile, info.prop, initializer));
            return createCodeFixAction(fixName6, changes, [Diagnostics.Add_initializer_to_property_0, info.prop.name.getText()], fixIdAddInitializer, Diagnostics.Add_initializers_to_all_uninitialized_properties);
        }
        function addInitializer(changeTracker, propertyDeclarationSourceFile, propertyDeclaration, initializer) {
            suppressLeadingAndTrailingTrivia(propertyDeclaration);
            const property = factory.updatePropertyDeclaration(propertyDeclaration, propertyDeclaration.modifiers, propertyDeclaration.name, propertyDeclaration.questionToken, propertyDeclaration.type, initializer);
            changeTracker.replaceNode(propertyDeclarationSourceFile, propertyDeclaration, property);
        }
        function getInitializer(checker, propertyDeclaration) {
            return getDefaultValueFromType(checker, checker.getTypeFromTypeNode(propertyDeclaration.type));
        }
        function getDefaultValueFromType(checker, type) {
            if (type.flags & 512 /* BooleanLiteral */) {
                return type === checker.getFalseType() || type === checker.getFalseType(
                /*fresh*/
                true) ? factory.createFalse() : factory.createTrue();
            }
            else if (type.isStringLiteral()) {
                return factory.createStringLiteral(type.value);
            }
            else if (type.isNumberLiteral()) {
                return factory.createNumericLiteral(type.value);
            }
            else if (type.flags & 2048 /* BigIntLiteral */) {
                return factory.createBigIntLiteral(type.value);
            }
            else if (type.isUnion()) {
                return firstDefined(type.types, (t) => getDefaultValueFromType(checker, t));
            }
            else if (type.isClass()) {
                const classDeclaration = getClassLikeDeclarationOfSymbol(type.symbol);
                if (!classDeclaration || hasSyntacticModifier(classDeclaration, 64 /* Abstract */))
                    return void 0;
                const constructorDeclaration = getFirstConstructorWithBody(classDeclaration);
                if (constructorDeclaration && constructorDeclaration.parameters.length)
                    return void 0;
                return factory.createNewExpression(factory.createIdentifier(type.symbol.name), 
                /*typeArguments*/
                void 0, 
                /*argumentsArray*/
                void 0);
            }
            else if (checker.isArrayLikeType(type)) {
                return factory.createArrayLiteralExpression();
            }
            return void 0;
        }
        var fixName6, fixIdAddDefiniteAssignmentAssertions, fixIdAddUndefinedType, fixIdAddInitializer, errorCodes52;
        var init_fixStrictClassInitialization = __esm({
            "src/services/codefixes/fixStrictClassInitialization.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixName6 = "strictClassInitialization";
                fixIdAddDefiniteAssignmentAssertions = "addMissingPropertyDefiniteAssignmentAssertions";
                fixIdAddUndefinedType = "addMissingPropertyUndefinedType";
                fixIdAddInitializer = "addMissingPropertyInitializer";
                errorCodes52 = [Diagnostics.Property_0_has_no_initializer_and_is_not_definitely_assigned_in_the_constructor.code];
                registerCodeFix({
                    errorCodes: errorCodes52,
                    getCodeActions: function getCodeActionsForStrictClassInitializationErrors(context) {
                        const info = getInfo17(context.sourceFile, context.span.start);
                        if (!info)
                            return;
                        const result = [];
                        append(result, getActionForAddMissingUndefinedType(context, info));
                        append(result, getActionForAddMissingDefiniteAssignmentAssertion(context, info));
                        append(result, getActionForAddMissingInitializer(context, info));
                        return result;
                    },
                    fixIds: [fixIdAddDefiniteAssignmentAssertions, fixIdAddUndefinedType, fixIdAddInitializer],
                    getAllCodeActions: (context) => {
                        return codeFixAll(context, errorCodes52, (changes, diag2) => {
                            const info = getInfo17(diag2.file, diag2.start);
                            if (!info)
                                return;
                            switch (context.fixId) {
                                case fixIdAddDefiniteAssignmentAssertions:
                                    addDefiniteAssignmentAssertion(changes, diag2.file, info.prop);
                                    break;
                                case fixIdAddUndefinedType:
                                    addUndefinedType(changes, diag2.file, info);
                                    break;
                                case fixIdAddInitializer:
                                    const checker = context.program.getTypeChecker();
                                    const initializer = getInitializer(checker, info.prop);
                                    if (!initializer)
                                        return;
                                    addInitializer(changes, diag2.file, info.prop, initializer);
                                    break;
                                default:
                                    Debug.fail(JSON.stringify(context.fixId));
                            }
                        });
                    }
                });
            }
        });
        // src/services/codefixes/requireInTs.ts
        function doChange35(changes, sourceFile, info) {
            const { allowSyntheticDefaults, defaultImportName, namedImports, statement, required } = info;
            changes.replaceNode(sourceFile, statement, defaultImportName && !allowSyntheticDefaults ? factory.createImportEqualsDeclaration(
            /*modifiers*/
            void 0, 
            /*isTypeOnly*/
            false, defaultImportName, factory.createExternalModuleReference(required)) : factory.createImportDeclaration(
            /*modifiers*/
            void 0, factory.createImportClause(
            /*isTypeOnly*/
            false, defaultImportName, namedImports), required, 
            /*attributes*/
            void 0));
        }
        function getInfo18(sourceFile, program, pos) {
            const { parent: parent2 } = getTokenAtPosition(sourceFile, pos);
            if (!isRequireCall(parent2, 
            /*requireStringLiteralLikeArgument*/
            true)) {
                Debug.failBadSyntaxKind(parent2);
            }
            const decl = cast(parent2.parent, isVariableDeclaration);
            const defaultImportName = tryCast(decl.name, isIdentifier);
            const namedImports = isObjectBindingPattern(decl.name) ? tryCreateNamedImportsFromObjectBindingPattern(decl.name) : void 0;
            if (defaultImportName || namedImports) {
                return {
                    allowSyntheticDefaults: getAllowSyntheticDefaultImports(program.getCompilerOptions()),
                    defaultImportName,
                    namedImports,
                    statement: cast(decl.parent.parent, isVariableStatement),
                    required: first(parent2.arguments)
                };
            }
        }
        function tryCreateNamedImportsFromObjectBindingPattern(node) {
            const importSpecifiers = [];
            for (const element of node.elements) {
                if (!isIdentifier(element.name) || element.initializer) {
                    return void 0;
                }
                importSpecifiers.push(factory.createImportSpecifier(
                /*isTypeOnly*/
                false, tryCast(element.propertyName, isIdentifier), element.name));
            }
            if (importSpecifiers.length) {
                return factory.createNamedImports(importSpecifiers);
            }
        }
        var fixId41, errorCodes53;
        var init_requireInTs = __esm({
            "src/services/codefixes/requireInTs.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId41 = "requireInTs";
                errorCodes53 = [Diagnostics.require_call_may_be_converted_to_an_import.code];
                registerCodeFix({
                    errorCodes: errorCodes53,
                    getCodeActions(context) {
                        const info = getInfo18(context.sourceFile, context.program, context.span.start);
                        if (!info) {
                            return void 0;
                        }
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange35(t, context.sourceFile, info));
                        return [createCodeFixAction(fixId41, changes, Diagnostics.Convert_require_to_import, fixId41, Diagnostics.Convert_all_require_to_import)];
                    },
                    fixIds: [fixId41],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes53, (changes, diag2) => {
                        const info = getInfo18(diag2.file, context.program, diag2.start);
                        if (info) {
                            doChange35(changes, context.sourceFile, info);
                        }
                    })
                });
            }
        });
        // src/services/codefixes/useDefaultImport.ts
        function getInfo19(sourceFile, pos) {
            const name = getTokenAtPosition(sourceFile, pos);
            if (!isIdentifier(name))
                return void 0;
            const { parent: parent2 } = name;
            if (isImportEqualsDeclaration(parent2) && isExternalModuleReference(parent2.moduleReference)) {
                return { importNode: parent2, name, moduleSpecifier: parent2.moduleReference.expression };
            }
            else if (isNamespaceImport(parent2)) {
                const importNode = parent2.parent.parent;
                return { importNode, name, moduleSpecifier: importNode.moduleSpecifier };
            }
        }
        function doChange36(changes, sourceFile, info, preferences) {
            changes.replaceNode(sourceFile, info.importNode, makeImport(info.name, 
            /*namedImports*/
            void 0, info.moduleSpecifier, getQuotePreference(sourceFile, preferences)));
        }
        var fixId42, errorCodes54;
        var init_useDefaultImport = __esm({
            "src/services/codefixes/useDefaultImport.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId42 = "useDefaultImport";
                errorCodes54 = [Diagnostics.Import_may_be_converted_to_a_default_import.code];
                registerCodeFix({
                    errorCodes: errorCodes54,
                    getCodeActions(context) {
                        const { sourceFile, span: { start } } = context;
                        const info = getInfo19(sourceFile, start);
                        if (!info)
                            return void 0;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange36(t, sourceFile, info, context.preferences));
                        return [createCodeFixAction(fixId42, changes, Diagnostics.Convert_to_default_import, fixId42, Diagnostics.Convert_all_to_default_imports)];
                    },
                    fixIds: [fixId42],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes54, (changes, diag2) => {
                        const info = getInfo19(diag2.file, diag2.start);
                        if (info)
                            doChange36(changes, diag2.file, info, context.preferences);
                    })
                });
            }
        });
        // src/services/codefixes/useBigintLiteral.ts
        function makeChange9(changeTracker, sourceFile, span) {
            const numericLiteral = tryCast(getTokenAtPosition(sourceFile, span.start), isNumericLiteral);
            if (!numericLiteral) {
                return;
            }
            const newText = numericLiteral.getText(sourceFile) + "n";
            changeTracker.replaceNode(sourceFile, numericLiteral, factory.createBigIntLiteral(newText));
        }
        var fixId43, errorCodes55;
        var init_useBigintLiteral = __esm({
            "src/services/codefixes/useBigintLiteral.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId43 = "useBigintLiteral";
                errorCodes55 = [
                    Diagnostics.Numeric_literals_with_absolute_values_equal_to_2_53_or_greater_are_too_large_to_be_represented_accurately_as_integers.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes55,
                    getCodeActions: function getCodeActionsToUseBigintLiteral(context) {
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => makeChange9(t, context.sourceFile, context.span));
                        if (changes.length > 0) {
                            return [createCodeFixAction(fixId43, changes, Diagnostics.Convert_to_a_bigint_numeric_literal, fixId43, Diagnostics.Convert_all_to_bigint_numeric_literals)];
                        }
                    },
                    fixIds: [fixId43],
                    getAllCodeActions: (context) => {
                        return codeFixAll(context, errorCodes55, (changes, diag2) => makeChange9(changes, diag2.file, diag2));
                    }
                });
            }
        });
        // src/services/codefixes/fixAddModuleReferTypeMissingTypeof.ts
        function getImportTypeNode(sourceFile, pos) {
            const token = getTokenAtPosition(sourceFile, pos);
            Debug.assert(token.kind === 102 /* ImportKeyword */, "This token should be an ImportKeyword");
            Debug.assert(token.parent.kind === 205 /* ImportType */, "Token parent should be an ImportType");
            return token.parent;
        }
        function doChange37(changes, sourceFile, importType) {
            const newTypeNode = factory.updateImportTypeNode(importType, importType.argument, importType.attributes, importType.qualifier, importType.typeArguments, 
            /*isTypeOf*/
            true);
            changes.replaceNode(sourceFile, importType, newTypeNode);
        }
        var fixIdAddMissingTypeof, fixId44, errorCodes56;
        var init_fixAddModuleReferTypeMissingTypeof = __esm({
            "src/services/codefixes/fixAddModuleReferTypeMissingTypeof.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixIdAddMissingTypeof = "fixAddModuleReferTypeMissingTypeof";
                fixId44 = fixIdAddMissingTypeof;
                errorCodes56 = [Diagnostics.Module_0_does_not_refer_to_a_type_but_is_used_as_a_type_here_Did_you_mean_typeof_import_0.code];
                registerCodeFix({
                    errorCodes: errorCodes56,
                    getCodeActions: function getCodeActionsToAddMissingTypeof(context) {
                        const { sourceFile, span } = context;
                        const importType = getImportTypeNode(sourceFile, span.start);
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange37(t, sourceFile, importType));
                        return [createCodeFixAction(fixId44, changes, Diagnostics.Add_missing_typeof, fixId44, Diagnostics.Add_missing_typeof)];
                    },
                    fixIds: [fixId44],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes56, (changes, diag2) => doChange37(changes, context.sourceFile, getImportTypeNode(diag2.file, diag2.start)))
                });
            }
        });
        // src/services/codefixes/wrapJsxInFragment.ts
        function findNodeToFix(sourceFile, pos) {
            const lessThanToken = getTokenAtPosition(sourceFile, pos);
            const firstJsxElementOrOpenElement = lessThanToken.parent;
            let binaryExpr = firstJsxElementOrOpenElement.parent;
            if (!isBinaryExpression(binaryExpr)) {
                binaryExpr = binaryExpr.parent;
                if (!isBinaryExpression(binaryExpr))
                    return void 0;
            }
            if (!nodeIsMissing(binaryExpr.operatorToken))
                return void 0;
            return binaryExpr;
        }
        function doChange38(changeTracker, sf, node) {
            const jsx = flattenInvalidBinaryExpr(node);
            if (jsx)
                changeTracker.replaceNode(sf, node, factory.createJsxFragment(factory.createJsxOpeningFragment(), jsx, factory.createJsxJsxClosingFragment()));
        }
        function flattenInvalidBinaryExpr(node) {
            const children = [];
            let current = node;
            while (true) {
                if (isBinaryExpression(current) && nodeIsMissing(current.operatorToken) && current.operatorToken.kind === 28 /* CommaToken */) {
                    children.push(current.left);
                    if (isJsxChild(current.right)) {
                        children.push(current.right);
                        return children;
                    }
                    else if (isBinaryExpression(current.right)) {
                        current = current.right;
                        continue;
                    }
                    else
                        return void 0;
                }
                else
                    return void 0;
            }
        }
        var fixID2, errorCodes57;
        var init_wrapJsxInFragment = __esm({
            "src/services/codefixes/wrapJsxInFragment.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixID2 = "wrapJsxInFragment";
                errorCodes57 = [Diagnostics.JSX_expressions_must_have_one_parent_element.code];
                registerCodeFix({
                    errorCodes: errorCodes57,
                    getCodeActions: function getCodeActionsToWrapJsxInFragment(context) {
                        const { sourceFile, span } = context;
                        const node = findNodeToFix(sourceFile, span.start);
                        if (!node)
                            return void 0;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange38(t, sourceFile, node));
                        return [createCodeFixAction(fixID2, changes, Diagnostics.Wrap_in_JSX_fragment, fixID2, Diagnostics.Wrap_all_unparented_JSX_in_JSX_fragment)];
                    },
                    fixIds: [fixID2],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes57, (changes, diag2) => {
                        const node = findNodeToFix(context.sourceFile, diag2.start);
                        if (!node)
                            return void 0;
                        doChange38(changes, context.sourceFile, node);
                    })
                });
            }
        });
        // src/services/codefixes/convertToMappedObjectType.ts
        function getInfo20(sourceFile, pos) {
            const token = getTokenAtPosition(sourceFile, pos);
            const indexSignature = tryCast(token.parent.parent, isIndexSignatureDeclaration);
            if (!indexSignature)
                return void 0;
            const container = isInterfaceDeclaration(indexSignature.parent) ? indexSignature.parent : tryCast(indexSignature.parent.parent, isTypeAliasDeclaration);
            if (!container)
                return void 0;
            return { indexSignature, container };
        }
        function createTypeAliasFromInterface(declaration, type) {
            return factory.createTypeAliasDeclaration(declaration.modifiers, declaration.name, declaration.typeParameters, type);
        }
        function doChange39(changes, sourceFile, { indexSignature, container }) {
            const members = isInterfaceDeclaration(container) ? container.members : container.type.members;
            const otherMembers = members.filter((member) => !isIndexSignatureDeclaration(member));
            const parameter = first(indexSignature.parameters);
            const mappedTypeParameter = factory.createTypeParameterDeclaration(
            /*modifiers*/
            void 0, cast(parameter.name, isIdentifier), parameter.type);
            const mappedIntersectionType = factory.createMappedTypeNode(hasEffectiveReadonlyModifier(indexSignature) ? factory.createModifier(148 /* ReadonlyKeyword */) : void 0, mappedTypeParameter, 
            /*nameType*/
            void 0, indexSignature.questionToken, indexSignature.type, 
            /*members*/
            void 0);
            const intersectionType = factory.createIntersectionTypeNode([
                ...getAllSuperTypeNodes(container),
                mappedIntersectionType,
                ...otherMembers.length ? [factory.createTypeLiteralNode(otherMembers)] : emptyArray
            ]);
            changes.replaceNode(sourceFile, container, createTypeAliasFromInterface(container, intersectionType));
        }
        var fixId45, errorCodes58;
        var init_convertToMappedObjectType = __esm({
            "src/services/codefixes/convertToMappedObjectType.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId45 = "fixConvertToMappedObjectType";
                errorCodes58 = [Diagnostics.An_index_signature_parameter_type_cannot_be_a_literal_type_or_generic_type_Consider_using_a_mapped_object_type_instead.code];
                registerCodeFix({
                    errorCodes: errorCodes58,
                    getCodeActions: function getCodeActionsToConvertToMappedTypeObject(context) {
                        const { sourceFile, span } = context;
                        const info = getInfo20(sourceFile, span.start);
                        if (!info)
                            return void 0;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange39(t, sourceFile, info));
                        const name = idText(info.container.name);
                        return [createCodeFixAction(fixId45, changes, [Diagnostics.Convert_0_to_mapped_object_type, name], fixId45, [Diagnostics.Convert_0_to_mapped_object_type, name])];
                    },
                    fixIds: [fixId45],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes58, (changes, diag2) => {
                        const info = getInfo20(diag2.file, diag2.start);
                        if (info)
                            doChange39(changes, diag2.file, info);
                    })
                });
            }
        });
        // src/services/codefixes/removeAccidentalCallParentheses.ts
        var fixId46, errorCodes59;
        var init_removeAccidentalCallParentheses = __esm({
            "src/services/codefixes/removeAccidentalCallParentheses.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId46 = "removeAccidentalCallParentheses";
                errorCodes59 = [
                    Diagnostics.This_expression_is_not_callable_because_it_is_a_get_accessor_Did_you_mean_to_use_it_without.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes59,
                    getCodeActions(context) {
                        const callExpression = findAncestor(getTokenAtPosition(context.sourceFile, context.span.start), isCallExpression);
                        if (!callExpression) {
                            return void 0;
                        }
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => {
                            t.deleteRange(context.sourceFile, { pos: callExpression.expression.end, end: callExpression.end });
                        });
                        return [createCodeFixActionWithoutFixAll(fixId46, changes, Diagnostics.Remove_parentheses)];
                    },
                    fixIds: [fixId46]
                });
            }
        });
        // src/services/codefixes/removeUnnecessaryAwait.ts
        function makeChange10(changeTracker, sourceFile, span) {
            const awaitKeyword = tryCast(getTokenAtPosition(sourceFile, span.start), (node) => node.kind === 135 /* AwaitKeyword */);
            const awaitExpression = awaitKeyword && tryCast(awaitKeyword.parent, isAwaitExpression);
            if (!awaitExpression) {
                return;
            }
            let expressionToReplace = awaitExpression;
            const hasSurroundingParens = isParenthesizedExpression(awaitExpression.parent);
            if (hasSurroundingParens) {
                const leftMostExpression = getLeftmostExpression(awaitExpression.expression, 
                /*stopAtCallExpressions*/
                false);
                if (isIdentifier(leftMostExpression)) {
                    const precedingToken = findPrecedingToken(awaitExpression.parent.pos, sourceFile);
                    if (precedingToken && precedingToken.kind !== 105 /* NewKeyword */) {
                        expressionToReplace = awaitExpression.parent;
                    }
                }
            }
            changeTracker.replaceNode(sourceFile, expressionToReplace, awaitExpression.expression);
        }
        var fixId47, errorCodes60;
        var init_removeUnnecessaryAwait = __esm({
            "src/services/codefixes/removeUnnecessaryAwait.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId47 = "removeUnnecessaryAwait";
                errorCodes60 = [
                    Diagnostics.await_has_no_effect_on_the_type_of_this_expression.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes60,
                    getCodeActions: function getCodeActionsToRemoveUnnecessaryAwait(context) {
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => makeChange10(t, context.sourceFile, context.span));
                        if (changes.length > 0) {
                            return [createCodeFixAction(fixId47, changes, Diagnostics.Remove_unnecessary_await, fixId47, Diagnostics.Remove_all_unnecessary_uses_of_await)];
                        }
                    },
                    fixIds: [fixId47],
                    getAllCodeActions: (context) => {
                        return codeFixAll(context, errorCodes60, (changes, diag2) => makeChange10(changes, diag2.file, diag2));
                    }
                });
            }
        });
        // src/services/codefixes/splitTypeOnlyImport.ts
        function getImportDeclaration2(sourceFile, span) {
            return findAncestor(getTokenAtPosition(sourceFile, span.start), isImportDeclaration);
        }
        function splitTypeOnlyImport(changes, importDeclaration, context) {
            if (!importDeclaration) {
                return;
            }
            const importClause = Debug.checkDefined(importDeclaration.importClause);
            changes.replaceNode(context.sourceFile, importDeclaration, factory.updateImportDeclaration(importDeclaration, importDeclaration.modifiers, factory.updateImportClause(importClause, importClause.isTypeOnly, importClause.name, 
            /*namedBindings*/
            void 0), importDeclaration.moduleSpecifier, importDeclaration.attributes));
            changes.insertNodeAfter(context.sourceFile, importDeclaration, factory.createImportDeclaration(
            /*modifiers*/
            void 0, factory.updateImportClause(importClause, importClause.isTypeOnly, 
            /*name*/
            void 0, importClause.namedBindings), importDeclaration.moduleSpecifier, importDeclaration.attributes));
        }
        var errorCodes61, fixId48;
        var init_splitTypeOnlyImport = __esm({
            "src/services/codefixes/splitTypeOnlyImport.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                errorCodes61 = [Diagnostics.A_type_only_import_can_specify_a_default_import_or_named_bindings_but_not_both.code];
                fixId48 = "splitTypeOnlyImport";
                registerCodeFix({
                    errorCodes: errorCodes61,
                    fixIds: [fixId48],
                    getCodeActions: function getCodeActionsToSplitTypeOnlyImport(context) {
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => {
                            return splitTypeOnlyImport(t, getImportDeclaration2(context.sourceFile, context.span), context);
                        });
                        if (changes.length) {
                            return [createCodeFixAction(fixId48, changes, Diagnostics.Split_into_two_separate_import_declarations, fixId48, Diagnostics.Split_all_invalid_type_only_imports)];
                        }
                    },
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes61, (changes, error2) => {
                        splitTypeOnlyImport(changes, getImportDeclaration2(context.sourceFile, error2), context);
                    })
                });
            }
        });
        // src/services/codefixes/convertConstToLet.ts
        function getInfo21(sourceFile, pos, program) {
            var _a;
            const checker = program.getTypeChecker();
            const symbol = checker.getSymbolAtLocation(getTokenAtPosition(sourceFile, pos));
            if (symbol === void 0)
                return;
            const declaration = tryCast((_a = symbol == null ? void 0 : symbol.valueDeclaration) == null ? void 0 : _a.parent, isVariableDeclarationList);
            if (declaration === void 0)
                return;
            const constToken = findChildOfKind(declaration, 87 /* ConstKeyword */, sourceFile);
            if (constToken === void 0)
                return;
            return { symbol, token: constToken };
        }
        function doChange40(changes, sourceFile, token) {
            changes.replaceNode(sourceFile, token, factory.createToken(121 /* LetKeyword */));
        }
        var fixId49, errorCodes62;
        var init_convertConstToLet = __esm({
            "src/services/codefixes/convertConstToLet.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId49 = "fixConvertConstToLet";
                errorCodes62 = [Diagnostics.Cannot_assign_to_0_because_it_is_a_constant.code];
                registerCodeFix({
                    errorCodes: errorCodes62,
                    getCodeActions: function getCodeActionsToConvertConstToLet(context) {
                        const { sourceFile, span, program } = context;
                        const info = getInfo21(sourceFile, span.start, program);
                        if (info === void 0)
                            return;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange40(t, sourceFile, info.token));
                        return [createCodeFixActionMaybeFixAll(fixId49, changes, Diagnostics.Convert_const_to_let, fixId49, Diagnostics.Convert_all_const_to_let)];
                    },
                    getAllCodeActions: (context) => {
                        const { program } = context;
                        const seen = /* @__PURE__ */ new Map();
                        return createCombinedCodeActions(ts_textChanges_exports.ChangeTracker.with(context, (changes) => {
                            eachDiagnostic(context, errorCodes62, (diag2) => {
                                const info = getInfo21(diag2.file, diag2.start, program);
                                if (info) {
                                    if (addToSeen(seen, getSymbolId(info.symbol))) {
                                        return doChange40(changes, diag2.file, info.token);
                                    }
                                }
                                return void 0;
                            });
                        }));
                    },
                    fixIds: [fixId49]
                });
            }
        });
        // src/services/codefixes/fixExpectedComma.ts
        function getInfo22(sourceFile, pos, _) {
            const node = getTokenAtPosition(sourceFile, pos);
            return node.kind === 27 /* SemicolonToken */ && node.parent && (isObjectLiteralExpression(node.parent) || isArrayLiteralExpression(node.parent)) ? { node } : void 0;
        }
        function doChange41(changes, sourceFile, { node }) {
            const newNode = factory.createToken(28 /* CommaToken */);
            changes.replaceNode(sourceFile, node, newNode);
        }
        var fixId50, expectedErrorCode, errorCodes63;
        var init_fixExpectedComma = __esm({
            "src/services/codefixes/fixExpectedComma.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixId50 = "fixExpectedComma";
                expectedErrorCode = Diagnostics._0_expected.code;
                errorCodes63 = [expectedErrorCode];
                registerCodeFix({
                    errorCodes: errorCodes63,
                    getCodeActions(context) {
                        const { sourceFile } = context;
                        const info = getInfo22(sourceFile, context.span.start, context.errorCode);
                        if (!info)
                            return void 0;
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => doChange41(t, sourceFile, info));
                        return [createCodeFixAction(fixId50, changes, [Diagnostics.Change_0_to_1, ";", ","], fixId50, [Diagnostics.Change_0_to_1, ";", ","])];
                    },
                    fixIds: [fixId50],
                    getAllCodeActions: (context) => codeFixAll(context, errorCodes63, (changes, diag2) => {
                        const info = getInfo22(diag2.file, diag2.start, diag2.code);
                        if (info)
                            doChange41(changes, context.sourceFile, info);
                    })
                });
            }
        });
        // src/services/codefixes/fixAddVoidToPromise.ts
        function makeChange11(changes, sourceFile, span, program, seen) {
            const node = getTokenAtPosition(sourceFile, span.start);
            if (!isIdentifier(node) || !isCallExpression(node.parent) || node.parent.expression !== node || node.parent.arguments.length !== 0)
                return;
            const checker = program.getTypeChecker();
            const symbol = checker.getSymbolAtLocation(node);
            const decl = symbol == null ? void 0 : symbol.valueDeclaration;
            if (!decl || !isParameter(decl) || !isNewExpression(decl.parent.parent))
                return;
            if (seen == null ? void 0 : seen.has(decl))
                return;
            seen == null ? void 0 : seen.add(decl);
            const typeArguments = getEffectiveTypeArguments(decl.parent.parent);
            if (some(typeArguments)) {
                const typeArgument = typeArguments[0];
                const needsParens = !isUnionTypeNode(typeArgument) && !isParenthesizedTypeNode(typeArgument) && isParenthesizedTypeNode(factory.createUnionTypeNode([typeArgument, factory.createKeywordTypeNode(116 /* VoidKeyword */)]).types[0]);
                if (needsParens) {
                    changes.insertText(sourceFile, typeArgument.pos, "(");
                }
                changes.insertText(sourceFile, typeArgument.end, needsParens ? ") | void" : " | void");
            }
            else {
                const signature = checker.getResolvedSignature(node.parent);
                const parameter = signature == null ? void 0 : signature.parameters[0];
                const parameterType = parameter && checker.getTypeOfSymbolAtLocation(parameter, decl.parent.parent);
                if (isInJSFile(decl)) {
                    if (!parameterType || parameterType.flags & 3 /* AnyOrUnknown */) {
                        changes.insertText(sourceFile, decl.parent.parent.end, `)`);
                        changes.insertText(sourceFile, skipTrivia(sourceFile.text, decl.parent.parent.pos), `/** @type {Promise<void>} */(`);
                    }
                }
                else {
                    if (!parameterType || parameterType.flags & 2 /* Unknown */) {
                        changes.insertText(sourceFile, decl.parent.parent.expression.end, "<void>");
                    }
                }
            }
        }
        function getEffectiveTypeArguments(node) {
            var _a;
            if (isInJSFile(node)) {
                if (isParenthesizedExpression(node.parent)) {
                    const jsDocType = (_a = getJSDocTypeTag(node.parent)) == null ? void 0 : _a.typeExpression.type;
                    if (jsDocType && isTypeReferenceNode(jsDocType) && isIdentifier(jsDocType.typeName) && idText(jsDocType.typeName) === "Promise") {
                        return jsDocType.typeArguments;
                    }
                }
            }
            else {
                return node.typeArguments;
            }
        }
        var fixName7, fixId51, errorCodes64;
        var init_fixAddVoidToPromise = __esm({
            "src/services/codefixes/fixAddVoidToPromise.ts"() {
                "use strict";
                init_ts4();
                init_ts_codefix();
                fixName7 = "addVoidToPromise";
                fixId51 = "addVoidToPromise";
                errorCodes64 = [
                    Diagnostics.Expected_1_argument_but_got_0_new_Promise_needs_a_JSDoc_hint_to_produce_a_resolve_that_can_be_called_without_arguments.code,
                    Diagnostics.Expected_0_arguments_but_got_1_Did_you_forget_to_include_void_in_your_type_argument_to_Promise.code
                ];
                registerCodeFix({
                    errorCodes: errorCodes64,
                    fixIds: [fixId51],
                    getCodeActions(context) {
                        const changes = ts_textChanges_exports.ChangeTracker.with(context, (t) => makeChange11(t, context.sourceFile, context.span, context.program));
                        if (changes.length > 0) {
                            return [createCodeFixAction(fixName7, changes, Diagnostics.Add_void_to_Promise_resolved_without_a_value, fixId51, Diagnostics.Add_void_to_all_Promises_resolved_without_a_value)];
                        }
                    },
                    getAllCodeActions(context) {
                        return codeFixAll(context, errorCodes64, (changes, diag2) => makeChange11(changes, diag2.file, diag2, context.program, /* @__PURE__ */ new Set()));
                    }
                });
            }
        });
        // src/services/_namespaces/ts.codefix.ts
        var ts_codefix_exports = {};
        __export(ts_codefix_exports, {
            PreserveOptionalFlags: () => PreserveOptionalFlags,
            addNewNodeForMemberSymbol: () => addNewNodeForMemberSymbol,
            codeFixAll: () => codeFixAll,
            createCodeFixAction: () => createCodeFixAction,
            createCodeFixActionMaybeFixAll: () => createCodeFixActionMaybeFixAll,
            createCodeFixActionWithoutFixAll: () => createCodeFixActionWithoutFixAll,
            createCombinedCodeActions: () => createCombinedCodeActions,
            createFileTextChanges: () => createFileTextChanges,
            createImportAdder: () => createImportAdder,
            createImportSpecifierResolver: () => createImportSpecifierResolver,
            createJsonPropertyAssignment: () => createJsonPropertyAssignment,
            createMissingMemberNodes: () => createMissingMemberNodes,
            createSignatureDeclarationFromCallExpression: () => createSignatureDeclarationFromCallExpression,
            createSignatureDeclarationFromSignature: () => createSignatureDeclarationFromSignature,
            createStubbedBody: () => createStubbedBody,
            eachDiagnostic: () => eachDiagnostic,
            findAncestorMatchingSpan: () => findAncestorMatchingSpan,
            findJsonProperty: () => findJsonProperty,
            generateAccessorFromProperty: () => generateAccessorFromProperty,
            getAccessorConvertiblePropertyAtPosition: () => getAccessorConvertiblePropertyAtPosition,
            getAllFixes: () => getAllFixes,
            getAllSupers: () => getAllSupers,
            getArgumentTypesAndTypeParameters: () => getArgumentTypesAndTypeParameters,
            getFixes: () => getFixes,
            getImportCompletionAction: () => getImportCompletionAction,
            getImportKind: () => getImportKind,
            getJSDocTypedefNodes: () => getJSDocTypedefNodes,
            getNoopSymbolTrackerWithResolver: () => getNoopSymbolTrackerWithResolver,
            getPromoteTypeOnlyCompletionAction: () => getPromoteTypeOnlyCompletionAction,
            getSupportedErrorCodes: () => getSupportedErrorCodes,
            importFixName: () => importFixName,
            importSymbols: () => importSymbols,
            moduleSpecifierToValidIdentifier: () => moduleSpecifierToValidIdentifier,
            moduleSymbolToValidIdentifier: () => moduleSymbolToValidIdentifier,
            parameterShouldGetTypeFromJSDoc: () => parameterShouldGetTypeFromJSDoc,
            registerCodeFix: () => registerCodeFix,
            setJsonCompilerOptionValue: () => setJsonCompilerOptionValue,
            setJsonCompilerOptionValues: () => setJsonCompilerOptionValues,
            tryGetAutoImportableReferenceFromTypeNode: () => tryGetAutoImportableReferenceFromTypeNode,
            typeToAutoImportableTypeNode: () => typeToAutoImportableTypeNode
        });
        var init_ts_codefix = __esm({
            "src/services/_namespaces/ts.codefix.ts"() {
                "use strict";
                init_codeFixProvider();
                init_addConvertToUnknownForNonOverlappingTypes();
                init_addEmptyExportDeclaration();
                init_addMissingAsync();
                init_addMissingAwait();
                init_addMissingConst();
                init_addMissingDeclareProperty();
                init_addMissingInvocationForDecorator();
                init_addNameToNamelessParameter();
                init_addOptionalPropertyUndefined();
                init_annotateWithTypeFromJSDoc();
                init_convertFunctionToEs6Class();
                init_convertToAsyncFunction();
                init_convertToEsModule();
                init_correctQualifiedNameToIndexedAccessType();
                init_convertToTypeOnlyExport();
                init_convertToTypeOnlyImport();
                init_convertTypedefToType();
                init_convertLiteralTypeToMappedType();
                init_fixClassIncorrectlyImplementsInterface();
                init_importFixes();
                init_fixAddMissingConstraint();
                init_fixOverrideModifier();
                init_fixNoPropertyAccessFromIndexSignature();
                init_fixImplicitThis();
                init_fixImportNonExportedMember();
                init_fixIncorrectNamedTupleSyntax();
                init_fixSpelling();
                init_returnValueCorrect();
                init_fixAddMissingMember();
                init_fixAddMissingNewOperator();
                init_fixAddMissingParam();
                init_fixCannotFindModule();
                init_fixClassDoesntImplementInheritedAbstractMember();
                init_fixClassSuperMustPrecedeThisAccess();
                init_fixConstructorForDerivedNeedSuperCall();
                init_fixEnableJsxFlag();
                init_fixNaNEquality();
                init_fixModuleAndTargetOptions();
                init_fixPropertyAssignment();
                init_fixExtendsInterfaceBecomesImplements();
                init_fixForgottenThisPropertyAccess();
                init_fixInvalidJsxCharacters();
                init_fixUnmatchedParameter();
                init_fixUnreferenceableDecoratorMetadata();
                init_fixUnusedIdentifier();
                init_fixUnreachableCode();
                init_fixUnusedLabel();
                init_fixJSDocTypes();
                init_fixMissingCallParentheses();
                init_fixAwaitInSyncFunction();
                init_fixPropertyOverrideAccessor();
                init_inferFromUsage();
                init_fixReturnTypeInAsyncFunction();
                init_disableJsDiagnostics();
                init_helpers2();
                init_generateAccessors();
                init_fixInvalidImportSyntax();
                init_fixStrictClassInitialization();
                init_requireInTs();
                init_useDefaultImport();
                init_useBigintLiteral();
                init_fixAddModuleReferTypeMissingTypeof();
                init_wrapJsxInFragment();
                init_convertToMappedObjectType();
                init_removeAccidentalCallParentheses();
                init_removeUnnecessaryAwait();
                init_splitTypeOnlyImport();
                init_convertConstToLet();
                init_fixExpectedComma();
                init_fixAddVoidToPromise();
            }
        });
        // src/services/completions.ts
        function originIsThisType(origin) {
            return !!(origin.kind & 1 /* ThisType */);
        }
        function originIsSymbolMember(origin) {
            return !!(origin.kind & 2 /* SymbolMember */);
        }
        function originIsExport(origin) {
            return !!(origin && origin.kind & 4 /* Export */);
        }
        function originIsResolvedExport(origin) {
            return !!(origin && origin.kind === 32 /* ResolvedExport */);
        }
        function originIncludesSymbolName(origin) {
            return originIsExport(origin) || originIsResolvedExport(origin) || originIsComputedPropertyName(origin);
        }
        function originIsPackageJsonImport(origin) {
            return (originIsExport(origin) || originIsResolvedExport(origin)) && !!origin.isFromPackageJson;
        }
        function originIsPromise(origin) {
            return !!(origin.kind & 8 /* Promise */);
        }
        function originIsNullableMember(origin) {
            return !!(origin.kind & 16 /* Nullable */);
        }
        function originIsTypeOnlyAlias(origin) {
            return !!(origin && origin.kind & 64 /* TypeOnlyAlias */);
        }
        function originIsObjectLiteralMethod(origin) {
            return !!(origin && origin.kind & 128 /* ObjectLiteralMethod */);
        }
        function originIsIgnore(origin) {
            return !!(origin && origin.kind & 256 /* Ignore */);
        }
        function originIsComputedPropertyName(origin) {
            return !!(origin && origin.kind & 512 /* ComputedPropertyName */);
        }
        function resolvingModuleSpecifiers(logPrefix, host, resolver, program, position, preferences, isForImportStatementCompletion, isValidTypeOnlyUseSite, cb) {
            var _a, _b, _c;
            const start = timestamp();
            const needsFullResolution = isForImportStatementCompletion || moduleResolutionSupportsPackageJsonExportsAndImports(getEmitModuleResolutionKind(program.getCompilerOptions()));
            let skippedAny = false;
            let ambientCount = 0;
            let resolvedCount = 0;
            let resolvedFromCacheCount = 0;
            let cacheAttemptCount = 0;
            const result = cb({
                tryResolve,
                skippedAny: () => skippedAny,
                resolvedAny: () => resolvedCount > 0,
                resolvedBeyondLimit: () => resolvedCount > moduleSpecifierResolutionLimit
            });
            const hitRateMessage = cacheAttemptCount ? ` (${(resolvedFromCacheCount / cacheAttemptCount * 100).toFixed(1)}% hit rate)` : "";
            (_a = host.log) == null ? void 0 : _a.call(host, `${logPrefix}: resolved ${resolvedCount} module specifiers, plus ${ambientCount} ambient and ${resolvedFromCacheCount} from cache${hitRateMessage}`);
            (_b = host.log) == null ? void 0 : _b.call(host, `${logPrefix}: response is ${skippedAny ? "incomplete" : "complete"}`);
            (_c = host.log) == null ? void 0 : _c.call(host, `${logPrefix}: ${timestamp() - start}`);
            return result;
            function tryResolve(exportInfo, isFromAmbientModule) {
                if (isFromAmbientModule) {
                    const result3 = resolver.getModuleSpecifierForBestExportInfo(exportInfo, position, isValidTypeOnlyUseSite);
                    if (result3) {
                        ambientCount++;
                    }
                    return result3 || "failed";
                }
                const shouldResolveModuleSpecifier = needsFullResolution || preferences.allowIncompleteCompletions && resolvedCount < moduleSpecifierResolutionLimit;
                const shouldGetModuleSpecifierFromCache = !shouldResolveModuleSpecifier && preferences.allowIncompleteCompletions && cacheAttemptCount < moduleSpecifierResolutionCacheAttemptLimit;
                const result2 = shouldResolveModuleSpecifier || shouldGetModuleSpecifierFromCache ? resolver.getModuleSpecifierForBestExportInfo(exportInfo, position, isValidTypeOnlyUseSite, shouldGetModuleSpecifierFromCache) : void 0;
                if (!shouldResolveModuleSpecifier && !shouldGetModuleSpecifierFromCache || shouldGetModuleSpecifierFromCache && !result2) {
                    skippedAny = true;
                }
                resolvedCount += (result2 == null ? void 0 : result2.computedWithoutCacheCount) || 0;
                resolvedFromCacheCount += exportInfo.length - ((result2 == null ? void 0 : result2.computedWithoutCacheCount) || 0);
                if (shouldGetModuleSpecifierFromCache) {
                    cacheAttemptCount++;
                }
                return result2 || (needsFullResolution ? "failed" : "skipped");
            }
        }
        function getCompletionsAtPosition(host, program, log, sourceFile, position, preferences, triggerCharacter, completionKind, cancellationToken, formatContext, includeSymbol = false) {
            var _a;
            const { previousToken } = getRelevantTokens(position, sourceFile);
            if (triggerCharacter && !isInString(sourceFile, position, previousToken) && !isValidTrigger(sourceFile, triggerCharacter, previousToken, position)) {
                return void 0;
            }
            if (triggerCharacter === " ") {
                if (preferences.includeCompletionsForImportStatements && preferences.includeCompletionsWithInsertText) {
                    return { isGlobalCompletion: true, isMemberCompletion: false, isNewIdentifierLocation: true, isIncomplete: true, entries: [] };
                }
                return void 0;
            }
            const compilerOptions = program.getCompilerOptions();
            const checker = program.getTypeChecker();
            const incompleteCompletionsCache = preferences.allowIncompleteCompletions ? (_a = host.getIncompleteCompletionsCache) == null ? void 0 : _a.call(host) : void 0;
            if (incompleteCompletionsCache && completionKind === 3 /* TriggerForIncompleteCompletions */ && previousToken && isIdentifier(previousToken)) {
                const incompleteContinuation = continuePreviousIncompleteResponse(incompleteCompletionsCache, sourceFile, previousToken, program, host, preferences, cancellationToken, position);
                if (incompleteContinuation) {
                    return incompleteContinuation;
                }
            }
            else {
                incompleteCompletionsCache == null ? void 0 : incompleteCompletionsCache.clear();
            }
            const stringCompletions = ts_Completions_StringCompletions_exports.getStringLiteralCompletions(sourceFile, position, previousToken, compilerOptions, host, program, log, preferences, includeSymbol);
            if (stringCompletions) {
                return stringCompletions;
            }
            if (previousToken && isBreakOrContinueStatement(previousToken.parent) && (previousToken.kind === 83 /* BreakKeyword */ || previousToken.kind === 88 /* ContinueKeyword */ || previousToken.kind === 80 /* Identifier */)) {
                return getLabelCompletionAtPosition(previousToken.parent);
            }
            const completionData = getCompletionData(program, log, sourceFile, compilerOptions, position, preferences, 
            /*detailsEntryId*/
            void 0, host, formatContext, cancellationToken);
            if (!completionData) {
                return void 0;
            }
            switch (completionData.kind) {
                case 0 /* Data */:
                    const response = completionInfoFromData(sourceFile, host, program, compilerOptions, log, completionData, preferences, formatContext, position, includeSymbol);
                    if (response == null ? void 0 : response.isIncomplete) {
                        incompleteCompletionsCache == null ? void 0 : incompleteCompletionsCache.set(response);
                    }
                    return response;
                case 1 /* JsDocTagName */:
                    return jsdocCompletionInfo([
                        ...ts_JsDoc_exports.getJSDocTagNameCompletions(),
                        ...getJSDocParameterCompletions(sourceFile, position, checker, compilerOptions, preferences, 
                        /*tagNameOnly*/
                        true)
                    ]);
                case 2 /* JsDocTag */:
                    return jsdocCompletionInfo([
                        ...ts_JsDoc_exports.getJSDocTagCompletions(),
                        ...getJSDocParameterCompletions(sourceFile, position, checker, compilerOptions, preferences, 
                        /*tagNameOnly*/
                        false)
                    ]);
                case 3 /* JsDocParameterName */:
                    return jsdocCompletionInfo(ts_JsDoc_exports.getJSDocParameterNameCompletions(completionData.tag));
                case 4 /* Keywords */:
                    return specificKeywordCompletionInfo(completionData.keywordCompletions, completionData.isNewIdentifierLocation);
                default:
                    return Debug.assertNever(completionData);
            }
        }
        function compareCompletionEntries(entryInArray, entryToInsert) {
            var _a, _b;
            let result = compareStringsCaseSensitiveUI(entryInArray.sortText, entryToInsert.sortText);
            if (result === 0 /* EqualTo */) {
                result = compareStringsCaseSensitiveUI(entryInArray.name, entryToInsert.name);
            }
            if (result === 0 /* EqualTo */ && ((_a = entryInArray.data) == null ? void 0 : _a.moduleSpecifier) && ((_b = entryToInsert.data) == null ? void 0 : _b.moduleSpecifier)) {
                result = compareNumberOfDirectorySeparators(entryInArray.data.moduleSpecifier, entryToInsert.data.moduleSpecifier);
            }
            if (result === 0 /* EqualTo */) {
                return -1 /* LessThan */;
            }
            return result;
        }
        function completionEntryDataIsResolved(data) {
            return !!(data == null ? void 0 : data.moduleSpecifier);
        }
        function continuePreviousIncompleteResponse(cache, file, location, program, host, preferences, cancellationToken, position) {
            const previousResponse = cache.get();
            if (!previousResponse)
                return void 0;
            const touchNode = getTouchingPropertyName(file, position);
            const lowerCaseTokenText = location.text.toLowerCase();
            const exportMap = getExportInfoMap(file, host, program, preferences, cancellationToken);
            const newEntries = resolvingModuleSpecifiers("continuePreviousIncompleteResponse", host, ts_codefix_exports.createImportSpecifierResolver(file, program, host, preferences), program, location.getStart(), preferences, 
            /*isForImportStatementCompletion*/
            false, isValidTypeOnlyAliasUseSite(location), (context) => {
                const entries = mapDefined(previousResponse.entries, (entry) => {
                    var _a;
                    if (!entry.hasAction || !entry.source || !entry.data || completionEntryDataIsResolved(entry.data)) {
                        return entry;
                    }
                    if (!charactersFuzzyMatchInString(entry.name, lowerCaseTokenText)) {
                        return void 0;
                    }
                    const { origin } = Debug.checkDefined(getAutoImportSymbolFromCompletionEntryData(entry.name, entry.data, program, host));
                    const info = exportMap.get(file.path, entry.data.exportMapKey);
                    const result = info && context.tryResolve(info, !isExternalModuleNameRelative(stripQuotes(origin.moduleSymbol.name)));
                    if (result === "skipped")
                        return entry;
                    if (!result || result === "failed") {
                        (_a = host.log) == null ? void 0 : _a.call(host, `Unexpected failure resolving auto import for '${entry.name}' from '${entry.source}'`);
                        return void 0;
                    }
                    const newOrigin = {
                        ...origin,
                        kind: 32 /* ResolvedExport */,
                        moduleSpecifier: result.moduleSpecifier
                    };
                    entry.data = originToCompletionEntryData(newOrigin);
                    entry.source = getSourceFromOrigin(newOrigin);
                    entry.sourceDisplay = [textPart(newOrigin.moduleSpecifier)];
                    return entry;
                });
                if (!context.skippedAny()) {
                    previousResponse.isIncomplete = void 0;
                }
                return entries;
            });
            previousResponse.entries = newEntries;
            previousResponse.flags = (previousResponse.flags || 0) | 4 /* IsContinuation */;
            previousResponse.optionalReplacementSpan = getOptionalReplacementSpan(touchNode);
            return previousResponse;
        }
        function jsdocCompletionInfo(entries) {
            return { isGlobalCompletion: false, isMemberCompletion: false, isNewIdentifierLocation: false, entries };
        }
        function getJSDocParameterCompletions(sourceFile, position, checker, options, preferences, tagNameOnly) {
            const currentToken = getTokenAtPosition(sourceFile, position);
            if (!isJSDocTag(currentToken) && !isJSDoc(currentToken)) {
                return [];
            }
            const jsDoc = isJSDoc(currentToken) ? currentToken : currentToken.parent;
            if (!isJSDoc(jsDoc)) {
                return [];
            }
            const func = jsDoc.parent;
            if (!isFunctionLike(func)) {
                return [];
            }
            const isJs = isSourceFileJS(sourceFile);
            const isSnippet = preferences.includeCompletionsWithSnippetText || void 0;
            const paramTagCount = countWhere(jsDoc.tags, (tag) => isJSDocParameterTag(tag) && tag.getEnd() <= position);
            return mapDefined(func.parameters, (param) => {
                if (getJSDocParameterTags(param).length) {
                    return void 0;
                }
                if (isIdentifier(param.name)) {
                    const tabstopCounter = { tabstop: 1 };
                    const paramName = param.name.text;
                    let displayText = getJSDocParamAnnotation(paramName, param.initializer, param.dotDotDotToken, isJs, 
                    /*isObject*/
                    false, 
                    /*isSnippet*/
                    false, checker, options, preferences);
                    let snippetText = isSnippet ? getJSDocParamAnnotation(paramName, param.initializer, param.dotDotDotToken, isJs, 
                    /*isObject*/
                    false, 
                    /*isSnippet*/
                    true, checker, options, preferences, tabstopCounter) : void 0;
                    if (tagNameOnly) {
                        displayText = displayText.slice(1);
                        if (snippetText)
                            snippetText = snippetText.slice(1);
                    }
                    return {
                        name: displayText,
                        kind: "parameter" /* parameterElement */,
                        sortText: SortText.LocationPriority,
                        insertText: isSnippet ? snippetText : void 0,
                        isSnippet
                    };
                }
                else if (param.parent.parameters.indexOf(param) === paramTagCount) {
                    const paramPath = `param${paramTagCount}`;
                    const displayTextResult = generateJSDocParamTagsForDestructuring(paramPath, param.name, param.initializer, param.dotDotDotToken, isJs, 
                    /*isSnippet*/
                    false, checker, options, preferences);
                    const snippetTextResult = isSnippet ? generateJSDocParamTagsForDestructuring(paramPath, param.name, param.initializer, param.dotDotDotToken, isJs, 
                    /*isSnippet*/
                    true, checker, options, preferences) : void 0;
                    let displayText = displayTextResult.join(getNewLineCharacter(options) + "* ");
                    let snippetText = snippetTextResult == null ? void 0 : snippetTextResult.join(getNewLineCharacter(options) + "* ");
                    if (tagNameOnly) {
                        displayText = displayText.slice(1);
                        if (snippetText)
                            snippetText = snippetText.slice(1);
                    }
                    return {
                        name: displayText,
                        kind: "parameter" /* parameterElement */,
                        sortText: SortText.LocationPriority,
                        insertText: isSnippet ? snippetText : void 0,
                        isSnippet
                    };
                }
            });
        }
        function generateJSDocParamTagsForDestructuring(path, pattern, initializer, dotDotDotToken, isJs, isSnippet, checker, options, preferences) {
            if (!isJs) {
                return [
                    getJSDocParamAnnotation(path, initializer, dotDotDotToken, isJs, 
                    /*isObject*/
                    false, isSnippet, checker, options, preferences, { tabstop: 1 })
                ];
            }
            return patternWorker(path, pattern, initializer, dotDotDotToken, { tabstop: 1 });
            function patternWorker(path2, pattern2, initializer2, dotDotDotToken2, counter) {
                if (isObjectBindingPattern(pattern2) && !dotDotDotToken2) {
                    const oldTabstop = counter.tabstop;
                    const childCounter = { tabstop: oldTabstop };
                    const rootParam = getJSDocParamAnnotation(path2, initializer2, dotDotDotToken2, isJs, 
                    /*isObject*/
                    true, isSnippet, checker, options, preferences, childCounter);
                    let childTags = [];
                    for (const element of pattern2.elements) {
                        const elementTags = elementWorker(path2, element, childCounter);
                        if (!elementTags) {
                            childTags = void 0;
                            break;
                        }
                        else {
                            childTags.push(...elementTags);
                        }
                    }
                    if (childTags) {
                        counter.tabstop = childCounter.tabstop;
                        return [rootParam, ...childTags];
                    }
                }
                return [
                    getJSDocParamAnnotation(path2, initializer2, dotDotDotToken2, isJs, 
                    /*isObject*/
                    false, isSnippet, checker, options, preferences, counter)
                ];
            }
            function elementWorker(path2, element, counter) {
                if (!element.propertyName && isIdentifier(element.name) || isIdentifier(element.name)) {
                    const propertyName = element.propertyName ? tryGetTextOfPropertyName(element.propertyName) : element.name.text;
                    if (!propertyName) {
                        return void 0;
                    }
                    const paramName = `${path2}.${propertyName}`;
                    return [
                        getJSDocParamAnnotation(paramName, element.initializer, element.dotDotDotToken, isJs, 
                        /*isObject*/
                        false, isSnippet, checker, options, preferences, counter)
                    ];
                }
                else if (element.propertyName) {
                    const propertyName = tryGetTextOfPropertyName(element.propertyName);
                    return propertyName && patternWorker(`${path2}.${propertyName}`, element.name, element.initializer, element.dotDotDotToken, counter);
                }
                return void 0;
            }
        }
        function getJSDocParamAnnotation(paramName, initializer, dotDotDotToken, isJs, isObject, isSnippet, checker, options, preferences, tabstopCounter) {
            if (isSnippet) {
                Debug.assertIsDefined(tabstopCounter);
            }
            if (initializer) {
                paramName = getJSDocParamNameWithInitializer(paramName, initializer);
            }
            if (isSnippet) {
                paramName = escapeSnippetText(paramName);
            }
            if (isJs) {
                let type = "*";
                if (isObject) {
                    Debug.assert(!dotDotDotToken, `Cannot annotate a rest parameter with type 'Object'.`);
                    type = "Object";
                }
                else {
                    if (initializer) {
                        const inferredType = checker.getTypeAtLocation(initializer.parent);
                        if (!(inferredType.flags & (1 /* Any */ | 16384 /* Void */))) {
                            const sourceFile = initializer.getSourceFile();
                            const quotePreference = getQuotePreference(sourceFile, preferences);
                            const builderFlags = quotePreference === 0 /* Single */ ? 268435456 /* UseSingleQuotesForStringLiteralType */ : 0 /* None */;
                            const typeNode = checker.typeToTypeNode(inferredType, findAncestor(initializer, isFunctionLike), builderFlags);
                            if (typeNode) {
                                const printer = isSnippet ? createSnippetPrinter({
                                    removeComments: true,
                                    module: options.module,
                                    target: options.target
                                }) : createPrinter({
                                    removeComments: true,
                                    module: options.module,
                                    target: options.target
                                });
                                setEmitFlags(typeNode, 1 /* SingleLine */);
                                type = printer.printNode(4 /* Unspecified */, typeNode, sourceFile);
                            }
                        }
                    }
                    if (isSnippet && type === "*") {
                        type = `\${${tabstopCounter.tabstop++}:${type}}`;
                    }
                }
                const dotDotDot = !isObject && dotDotDotToken ? "..." : "";
                const description3 = isSnippet ? `\${${tabstopCounter.tabstop++}}` : "";
                return `@param {${dotDotDot}${type}} ${paramName} ${description3}`;
            }
            else {
                const description3 = isSnippet ? `\${${tabstopCounter.tabstop++}}` : "";
                return `@param ${paramName} ${description3}`;
            }
        }
        function getJSDocParamNameWithInitializer(paramName, initializer) {
            const initializerText = initializer.getText().trim();
            if (initializerText.includes("\n") || initializerText.length > 80) {
                return `[${paramName}]`;
            }
            return `[${paramName}=${initializerText}]`;
        }
        function keywordToCompletionEntry(keyword) {
            return {
                name: tokenToString(keyword),
                kind: "keyword" /* keyword */,
                kindModifiers: "" /* none */,
                sortText: SortText.GlobalsOrKeywords
            };
        }
        function specificKeywordCompletionInfo(entries, isNewIdentifierLocation) {
            return {
                isGlobalCompletion: false,
                isMemberCompletion: false,
                isNewIdentifierLocation,
                entries: entries.slice()
            };
        }
        function keywordCompletionData(keywordFilters, filterOutTsOnlyKeywords, isNewIdentifierLocation) {
            return {
                kind: 4 /* Keywords */,
                keywordCompletions: getKeywordCompletions(keywordFilters, filterOutTsOnlyKeywords),
                isNewIdentifierLocation
            };
        }
        function keywordFiltersFromSyntaxKind(keywordCompletion) {
            switch (keywordCompletion) {
                case 156 /* TypeKeyword */:
                    return 8 /* TypeKeyword */;
                default:
                    Debug.fail("Unknown mapping from SyntaxKind to KeywordCompletionFilters");
            }
        }
        function getOptionalReplacementSpan(location) {
            return (location == null ? void 0 : location.kind) === 80 /* Identifier */ ? createTextSpanFromNode(location) : void 0;
        }
        function completionInfoFromData(sourceFile, host, program, compilerOptions, log, completionData, preferences, formatContext, position, includeSymbol) {
            const { symbols, contextToken, completionKind, isInSnippetScope, isNewIdentifierLocation, location, propertyAccessToConvert, keywordFilters, symbolToOriginInfoMap, recommendedCompletion, isJsxInitializer, isTypeOnlyLocation, isJsxIdentifierExpected, isRightOfOpenTag, isRightOfDotOrQuestionDot, importStatementCompletion, insideJsDocTagTypeExpression, symbolToSortTextMap, hasUnresolvedAutoImports } = completionData;
            let literals = completionData.literals;
            const checker = program.getTypeChecker();
            if (getLanguageVariant(sourceFile.scriptKind) === 1 /* JSX */) {
                const completionInfo = getJsxClosingTagCompletion(location, sourceFile);
                if (completionInfo) {
                    return completionInfo;
                }
            }
            const caseClause = findAncestor(contextToken, isCaseClause);
            if (caseClause && (isCaseKeyword(contextToken) || isNodeDescendantOf(contextToken, caseClause.expression))) {
                const tracker = newCaseClauseTracker(checker, caseClause.parent.clauses);
                literals = literals.filter((literal) => !tracker.hasValue(literal));
                symbols.forEach((symbol, i) => {
                    if (symbol.valueDeclaration && isEnumMember(symbol.valueDeclaration)) {
                        const value = checker.getConstantValue(symbol.valueDeclaration);
                        if (value !== void 0 && tracker.hasValue(value)) {
                            symbolToOriginInfoMap[i] = { kind: 256 /* Ignore */ };
                        }
                    }
                });
            }
            const entries = createSortedArray();
            const isChecked = isCheckedFile(sourceFile, compilerOptions);
            if (isChecked && !isNewIdentifierLocation && (!symbols || symbols.length === 0) && keywordFilters === 0 /* None */) {
                return void 0;
            }
            const uniqueNames = getCompletionEntriesFromSymbols(symbols, entries, 
            /*replacementToken*/
            void 0, contextToken, location, position, sourceFile, host, program, getEmitScriptTarget(compilerOptions), log, completionKind, preferences, compilerOptions, formatContext, isTypeOnlyLocation, propertyAccessToConvert, isJsxIdentifierExpected, isJsxInitializer, importStatementCompletion, recommendedCompletion, symbolToOriginInfoMap, symbolToSortTextMap, isJsxIdentifierExpected, isRightOfOpenTag, includeSymbol);
            if (keywordFilters !== 0 /* None */) {
                for (const keywordEntry of getKeywordCompletions(keywordFilters, !insideJsDocTagTypeExpression && isSourceFileJS(sourceFile))) {
                    if (isTypeOnlyLocation && isTypeKeyword(stringToToken(keywordEntry.name)) || !isTypeOnlyLocation && isContextualKeywordInAutoImportableExpressionSpace(keywordEntry.name) || !uniqueNames.has(keywordEntry.name)) {
                        uniqueNames.add(keywordEntry.name);
                        insertSorted(entries, keywordEntry, compareCompletionEntries, 
                        /*allowDuplicates*/
                        true);
                    }
                }
            }
            for (const keywordEntry of getContextualKeywords(contextToken, position)) {
                if (!uniqueNames.has(keywordEntry.name)) {
                    uniqueNames.add(keywordEntry.name);
                    insertSorted(entries, keywordEntry, compareCompletionEntries, 
                    /*allowDuplicates*/
                    true);
                }
            }
            for (const literal of literals) {
                const literalEntry = createCompletionEntryForLiteral(sourceFile, preferences, literal);
                uniqueNames.add(literalEntry.name);
                insertSorted(entries, literalEntry, compareCompletionEntries, 
                /*allowDuplicates*/
                true);
            }
            if (!isChecked) {
                getJSCompletionEntries(sourceFile, location.pos, uniqueNames, getEmitScriptTarget(compilerOptions), entries);
            }
            let caseBlock;
            if (preferences.includeCompletionsWithInsertText && contextToken && !isRightOfOpenTag && !isRightOfDotOrQuestionDot && (caseBlock = findAncestor(contextToken, isCaseBlock))) {
                const cases = getExhaustiveCaseSnippets(caseBlock, sourceFile, preferences, compilerOptions, host, program, formatContext);
                if (cases) {
                    entries.push(cases.entry);
                }
            }
            return {
                flags: completionData.flags,
                isGlobalCompletion: isInSnippetScope,
                isIncomplete: preferences.allowIncompleteCompletions && hasUnresolvedAutoImports ? true : void 0,
                isMemberCompletion: isMemberCompletionKind(completionKind),
                isNewIdentifierLocation,
                optionalReplacementSpan: getOptionalReplacementSpan(location),
                entries
            };
        }
        function isCheckedFile(sourceFile, compilerOptions) {
            return !isSourceFileJS(sourceFile) || !!isCheckJsEnabledForFile(sourceFile, compilerOptions);
        }
        function getExhaustiveCaseSnippets(caseBlock, sourceFile, preferences, options, host, program, formatContext) {
            const clauses = caseBlock.clauses;
            const checker = program.getTypeChecker();
            const switchType = checker.getTypeAtLocation(caseBlock.parent.expression);
            if (switchType && switchType.isUnion() && every(switchType.types, (type) => type.isLiteral())) {
                const tracker = newCaseClauseTracker(checker, clauses);
                const target = getEmitScriptTarget(options);
                const quotePreference = getQuotePreference(sourceFile, preferences);
                const importAdder = ts_codefix_exports.createImportAdder(sourceFile, program, preferences, host);
                const elements = [];
                for (const type of switchType.types) {
                    if (type.flags & 1024 /* EnumLiteral */) {
                        Debug.assert(type.symbol, "An enum member type should have a symbol");
                        Debug.assert(type.symbol.parent, "An enum member type should have a parent symbol (the enum symbol)");
                        const enumValue = type.symbol.valueDeclaration && checker.getConstantValue(type.symbol.valueDeclaration);
                        if (enumValue !== void 0) {
                            if (tracker.hasValue(enumValue)) {
                                continue;
                            }
                            tracker.addValue(enumValue);
                        }
                        const typeNode = ts_codefix_exports.typeToAutoImportableTypeNode(checker, importAdder, type, caseBlock, target);
                        if (!typeNode) {
                            return void 0;
                        }
                        const expr = typeNodeToExpression(typeNode, target, quotePreference);
                        if (!expr) {
                            return void 0;
                        }
                        elements.push(expr);
                    }
                    else if (!tracker.hasValue(type.value)) {
                        switch (typeof type.value) {
                            case "object":
                                elements.push(type.value.negative ? factory.createPrefixUnaryExpression(41 /* MinusToken */, factory.createBigIntLiteral({ negative: false, base10Value: type.value.base10Value })) : factory.createBigIntLiteral(type.value));
                                break;
                            case "number":
                                elements.push(type.value < 0 ? factory.createPrefixUnaryExpression(41 /* MinusToken */, factory.createNumericLiteral(-type.value)) : factory.createNumericLiteral(type.value));
                                break;
                            case "string":
                                elements.push(factory.createStringLiteral(type.value, quotePreference === 0 /* Single */));
                                break;
                        }
                    }
                }
                if (elements.length === 0) {
                    return void 0;
                }
                const newClauses = map(elements, (element) => factory.createCaseClause(element, []));
                const newLineChar = getNewLineOrDefaultFromHost(host, formatContext == null ? void 0 : formatContext.options);
                const printer = createSnippetPrinter({
                    removeComments: true,
                    module: options.module,
                    target: options.target,
                    newLine: getNewLineKind(newLineChar)
                });
                const printNode = formatContext ? (node) => printer.printAndFormatNode(4 /* Unspecified */, node, sourceFile, formatContext) : (node) => printer.printNode(4 /* Unspecified */, node, sourceFile);
                const insertText = map(newClauses, (clause, i) => {
                    if (preferences.includeCompletionsWithSnippetText) {
                        return `${printNode(clause)}$${i + 1}`;
                    }
                    return `${printNode(clause)}`;
                }).join(newLineChar);
                const firstClause = printer.printNode(4 /* Unspecified */, newClauses[0], sourceFile);
                return {
                    entry: {
                        name: `${firstClause} ...`,
                        kind: "" /* unknown */,
                        sortText: SortText.GlobalsOrKeywords,
                        insertText,
                        hasAction: importAdder.hasFixes() || void 0,
                        source: "SwitchCases/" /* SwitchCases */,
                        isSnippet: preferences.includeCompletionsWithSnippetText ? true : void 0
                    },
                    importAdder
                };
            }
            return void 0;
        }
        function typeNodeToExpression(typeNode, languageVersion, quotePreference) {
            switch (typeNode.kind) {
                case 183 /* TypeReference */:
                    const typeName = typeNode.typeName;
                    return entityNameToExpression(typeName, languageVersion, quotePreference);
                case 199 /* IndexedAccessType */:
                    const objectExpression = typeNodeToExpression(typeNode.objectType, languageVersion, quotePreference);
                    const indexExpression = typeNodeToExpression(typeNode.indexType, languageVersion, quotePreference);
                    return objectExpression && indexExpression && factory.createElementAccessExpression(objectExpression, indexExpression);
                case 201 /* LiteralType */:
                    const literal = typeNode.literal;
                    switch (literal.kind) {
                        case 11 /* StringLiteral */:
                            return factory.createStringLiteral(literal.text, quotePreference === 0 /* Single */);
                        case 9 /* NumericLiteral */:
                            return factory.createNumericLiteral(literal.text, literal.numericLiteralFlags);
                    }
                    return void 0;
                case 196 /* ParenthesizedType */:
                    const exp = typeNodeToExpression(typeNode.type, languageVersion, quotePreference);
                    return exp && (isIdentifier(exp) ? exp : factory.createParenthesizedExpression(exp));
                case 186 /* TypeQuery */:
                    return entityNameToExpression(typeNode.exprName, languageVersion, quotePreference);
                case 205 /* ImportType */:
                    Debug.fail(`We should not get an import type after calling 'codefix.typeToAutoImportableTypeNode'.`);
            }
            return void 0;
        }
        function entityNameToExpression(entityName, languageVersion, quotePreference) {
            if (isIdentifier(entityName)) {
                return entityName;
            }
            const unescapedName = unescapeLeadingUnderscores(entityName.right.escapedText);
            if (canUsePropertyAccess(unescapedName, languageVersion)) {
                return factory.createPropertyAccessExpression(entityNameToExpression(entityName.left, languageVersion, quotePreference), unescapedName);
            }
            else {
                return factory.createElementAccessExpression(entityNameToExpression(entityName.left, languageVersion, quotePreference), factory.createStringLiteral(unescapedName, quotePreference === 0 /* Single */));
            }
        }
        function isMemberCompletionKind(kind) {
            switch (kind) {
                case 0 /* ObjectPropertyDeclaration */:
                case 3 /* MemberLike */:
                case 2 /* PropertyAccess */:
                    return true;
                default:
                    return false;
            }
        }
        function getJsxClosingTagCompletion(location, sourceFile) {
            const jsxClosingElement = findAncestor(location, (node) => {
                switch (node.kind) {
                    case 287 /* JsxClosingElement */:
                        return true;
                    case 44 /* SlashToken */:
                    case 32 /* GreaterThanToken */:
                    case 80 /* Identifier */:
                    case 211 /* PropertyAccessExpression */:
                        return false;
                    default:
                        return "quit";
                }
            });
            if (jsxClosingElement) {
                const hasClosingAngleBracket = !!findChildOfKind(jsxClosingElement, 32 /* GreaterThanToken */, sourceFile);
                const tagName = jsxClosingElement.parent.openingElement.tagName;
                const closingTag = tagName.getText(sourceFile);
                const fullClosingTag = closingTag + (hasClosingAngleBracket ? "" : ">");
                const replacementSpan = createTextSpanFromNode(jsxClosingElement.tagName);
                const entry = {
                    name: fullClosingTag,
                    kind: "class" /* classElement */,
                    kindModifiers: void 0,
                    sortText: SortText.LocationPriority
                };
                return { isGlobalCompletion: false, isMemberCompletion: true, isNewIdentifierLocation: false, optionalReplacementSpan: replacementSpan, entries: [entry] };
            }
            return;
        }
        function getJSCompletionEntries(sourceFile, position, uniqueNames, target, entries) {
            getNameTable(sourceFile).forEach((pos, name) => {
                if (pos === position) {
                    return;
                }
                const realName = unescapeLeadingUnderscores(name);
                if (!uniqueNames.has(realName) && isIdentifierText(realName, target)) {
                    uniqueNames.add(realName);
                    insertSorted(entries, {
                        name: realName,
                        kind: "warning" /* warning */,
                        kindModifiers: "",
                        sortText: SortText.JavascriptIdentifiers,
                        isFromUncheckedFile: true
                    }, compareCompletionEntries);
                }
            });
        }
        function completionNameForLiteral(sourceFile, preferences, literal) {
            return typeof literal === "object" ? pseudoBigIntToString(literal) + "n" : isString(literal) ? quote(sourceFile, preferences, literal) : JSON.stringify(literal);
        }
        function createCompletionEntryForLiteral(sourceFile, preferences, literal) {
            return { name: completionNameForLiteral(sourceFile, preferences, literal), kind: "string" /* string */, kindModifiers: "" /* none */, sortText: SortText.LocationPriority };
        }
        function createCompletionEntry(symbol, sortText, replacementToken, contextToken, location, position, sourceFile, host, program, name, needsConvertPropertyAccess, origin, recommendedCompletion, propertyAccessToConvert, isJsxInitializer, importStatementCompletion, useSemicolons, options, preferences, completionKind, formatContext, isJsxIdentifierExpected, isRightOfOpenTag, includeSymbol) {
            var _a, _b;
            let insertText;
            let filterText;
            let replacementSpan = getReplacementSpanForContextToken(replacementToken);
            let data;
            let isSnippet;
            let source = getSourceFromOrigin(origin);
            let sourceDisplay;
            let hasAction;
            let labelDetails;
            const typeChecker = program.getTypeChecker();
            const insertQuestionDot = origin && originIsNullableMember(origin);
            const useBraces = origin && originIsSymbolMember(origin) || needsConvertPropertyAccess;
            if (origin && originIsThisType(origin)) {
                insertText = needsConvertPropertyAccess ? `this${insertQuestionDot ? "?." : ""}[${quotePropertyName(sourceFile, preferences, name)}]` : `this${insertQuestionDot ? "?." : "."}${name}`;
            }
            else if ((useBraces || insertQuestionDot) && propertyAccessToConvert) {
                insertText = useBraces ? needsConvertPropertyAccess ? `[${quotePropertyName(sourceFile, preferences, name)}]` : `[${name}]` : name;
                if (insertQuestionDot || propertyAccessToConvert.questionDotToken) {
                    insertText = `?.${insertText}`;
                }
                const dot = findChildOfKind(propertyAccessToConvert, 25 /* DotToken */, sourceFile) || findChildOfKind(propertyAccessToConvert, 29 /* QuestionDotToken */, sourceFile);
                if (!dot) {
                    return void 0;
                }
                const end = startsWith(name, propertyAccessToConvert.name.text) ? propertyAccessToConvert.name.end : dot.end;
                replacementSpan = createTextSpanFromBounds(dot.getStart(sourceFile), end);
            }
            if (isJsxInitializer) {
                if (insertText === void 0)
                    insertText = name;
                insertText = `{${insertText}}`;
                if (typeof isJsxInitializer !== "boolean") {
                    replacementSpan = createTextSpanFromNode(isJsxInitializer, sourceFile);
                }
            }
            if (origin && originIsPromise(origin) && propertyAccessToConvert) {
                if (insertText === void 0)
                    insertText = name;
                const precedingToken = findPrecedingToken(propertyAccessToConvert.pos, sourceFile);
                let awaitText = "";
                if (precedingToken && positionIsASICandidate(precedingToken.end, precedingToken.parent, sourceFile)) {
                    awaitText = ";";
                }
                awaitText += `(await ${propertyAccessToConvert.expression.getText()})`;
                insertText = needsConvertPropertyAccess ? `${awaitText}${insertText}` : `${awaitText}${insertQuestionDot ? "?." : "."}${insertText}`;
                const isInAwaitExpression = tryCast(propertyAccessToConvert.parent, isAwaitExpression);
                const wrapNode = isInAwaitExpression ? propertyAccessToConvert.parent : propertyAccessToConvert.expression;
                replacementSpan = createTextSpanFromBounds(wrapNode.getStart(sourceFile), propertyAccessToConvert.end);
            }
            if (originIsResolvedExport(origin)) {
                sourceDisplay = [textPart(origin.moduleSpecifier)];
                if (importStatementCompletion) {
                    ({ insertText, replacementSpan } = getInsertTextAndReplacementSpanForImportCompletion(name, importStatementCompletion, origin, useSemicolons, sourceFile, options, preferences));
                    isSnippet = preferences.includeCompletionsWithSnippetText ? true : void 0;
                }
            }
            if ((origin == null ? void 0 : origin.kind) === 64 /* TypeOnlyAlias */) {
                hasAction = true;
            }
            if (completionKind === 0 /* ObjectPropertyDeclaration */ && contextToken && ((_a = findPrecedingToken(contextToken.pos, sourceFile, contextToken)) == null ? void 0 : _a.kind) !== 28 /* CommaToken */) {
                if (isMethodDeclaration(contextToken.parent.parent) || isGetAccessorDeclaration(contextToken.parent.parent) || isSetAccessorDeclaration(contextToken.parent.parent) || isSpreadAssignment(contextToken.parent) || ((_b = findAncestor(contextToken.parent, isPropertyAssignment)) == null ? void 0 : _b.getLastToken(sourceFile)) === contextToken || isShorthandPropertyAssignment(contextToken.parent) && getLineAndCharacterOfPosition(sourceFile, contextToken.getEnd()).line !== getLineAndCharacterOfPosition(sourceFile, position).line) {
                    source = "ObjectLiteralMemberWithComma/" /* ObjectLiteralMemberWithComma */;
                    hasAction = true;
                }
            }
            if (preferences.includeCompletionsWithClassMemberSnippets && preferences.includeCompletionsWithInsertText && completionKind === 3 /* MemberLike */ && isClassLikeMemberCompletion(symbol, location, sourceFile)) {
                let importAdder;
                const memberCompletionEntry = getEntryForMemberCompletion(host, program, options, preferences, name, symbol, location, position, contextToken, formatContext);
                if (memberCompletionEntry) {
                    ({ insertText, filterText, isSnippet, importAdder } = memberCompletionEntry);
                    if (importAdder == null ? void 0 : importAdder.hasFixes()) {
                        hasAction = true;
                        source = "ClassMemberSnippet/" /* ClassMemberSnippet */;
                    }
                }
                else {
                    return void 0;
                }
            }
            if (origin && originIsObjectLiteralMethod(origin)) {
                ({ insertText, isSnippet, labelDetails } = origin);
                if (!preferences.useLabelDetailsInCompletionEntries) {
                    name = name + labelDetails.detail;
                    labelDetails = void 0;
                }
                source = "ObjectLiteralMethodSnippet/" /* ObjectLiteralMethodSnippet */;
                sortText = SortText.SortBelow(sortText);
            }
            if (isJsxIdentifierExpected && !isRightOfOpenTag && preferences.includeCompletionsWithSnippetText && preferences.jsxAttributeCompletionStyle && preferences.jsxAttributeCompletionStyle !== "none" && !(isJsxAttribute(location.parent) && location.parent.initializer)) {
                let useBraces2 = preferences.jsxAttributeCompletionStyle === "braces";
                const type = typeChecker.getTypeOfSymbolAtLocation(symbol, location);
                if (preferences.jsxAttributeCompletionStyle === "auto" && !(type.flags & 528 /* BooleanLike */) && !(type.flags & 1048576 /* Union */ && find(type.types, (type2) => !!(type2.flags & 528 /* BooleanLike */)))) {
                    if (type.flags & 402653316 /* StringLike */ || type.flags & 1048576 /* Union */ && every(type.types, (type2) => !!(type2.flags & (402653316 /* StringLike */ | 32768 /* Undefined */) || isStringAndEmptyAnonymousObjectIntersection(type2)))) {
                        insertText = `${escapeSnippetText(name)}=${quote(sourceFile, preferences, "$1")}`;
                        isSnippet = true;
                    }
                    else {
                        useBraces2 = true;
                    }
                }
                if (useBraces2) {
                    insertText = `${escapeSnippetText(name)}={$1}`;
                    isSnippet = true;
                }
            }
            if (insertText !== void 0 && !preferences.includeCompletionsWithInsertText) {
                return void 0;
            }
            if (originIsExport(origin) || originIsResolvedExport(origin)) {
                data = originToCompletionEntryData(origin);
                hasAction = !importStatementCompletion;
            }
            const parentNamedImportOrExport = findAncestor(location, isNamedImportsOrExports);
            if ((parentNamedImportOrExport == null ? void 0 : parentNamedImportOrExport.kind) === 275 /* NamedImports */) {
                const possibleToken = stringToToken(name);
                if (parentNamedImportOrExport && possibleToken && (possibleToken === 135 /* AwaitKeyword */ || isNonContextualKeyword(possibleToken))) {
                    insertText = `${name} as ${name}_`;
                }
            }
            return {
                name,
                kind: ts_SymbolDisplay_exports.getSymbolKind(typeChecker, symbol, location),
                kindModifiers: ts_SymbolDisplay_exports.getSymbolModifiers(typeChecker, symbol),
                sortText,
                source,
                hasAction: hasAction ? true : void 0,
                isRecommended: isRecommendedCompletionMatch(symbol, recommendedCompletion, typeChecker) || void 0,
                insertText,
                filterText,
                replacementSpan,
                sourceDisplay,
                labelDetails,
                isSnippet,
                isPackageJsonImport: originIsPackageJsonImport(origin) || void 0,
                isImportStatementCompletion: !!importStatementCompletion || void 0,
                data,
                ...includeSymbol ? { symbol } : void 0
            };
        }
        function isClassLikeMemberCompletion(symbol, location, sourceFile) {
            if (isInJSFile(location)) {
                return false;
            }
            const memberFlags = 106500 /* ClassMember */ & 900095 /* EnumMemberExcludes */;
            return !!(symbol.flags & memberFlags) && (isClassLike(location) || location.parent && location.parent.parent && isClassElement(location.parent) && location === location.parent.name && location.parent.getLastToken(sourceFile) === location.parent.name && isClassLike(location.parent.parent) || location.parent && isSyntaxList(location) && isClassLike(location.parent));
        }
        function getEntryForMemberCompletion(host, program, options, preferences, name, symbol, location, position, contextToken, formatContext) {
            const classLikeDeclaration = findAncestor(location, isClassLike);
            if (!classLikeDeclaration) {
                return void 0;
            }
            let isSnippet;
            let insertText = name;
            const filterText = name;
            const checker = program.getTypeChecker();
            const sourceFile = location.getSourceFile();
            const printer = createSnippetPrinter({
                removeComments: true,
                module: options.module,
                target: options.target,
                omitTrailingSemicolon: false,
                newLine: getNewLineKind(getNewLineOrDefaultFromHost(host, formatContext == null ? void 0 : formatContext.options))
            });
            const importAdder = ts_codefix_exports.createImportAdder(sourceFile, program, preferences, host);
            let body;
            if (preferences.includeCompletionsWithSnippetText) {
                isSnippet = true;
                const emptyStmt = factory.createEmptyStatement();
                body = factory.createBlock([emptyStmt], 
                /*multiLine*/
                true);
                setSnippetElement(emptyStmt, { kind: 0 /* TabStop */, order: 0 });
            }
            else {
                body = factory.createBlock([], 
                /*multiLine*/
                true);
            }
            let modifiers = 0 /* None */;
            const { modifiers: presentModifiers, range: eraseRange, decorators: presentDecorators } = getPresentModifiers(contextToken, sourceFile, position);
            const isAbstract = presentModifiers & 64 /* Abstract */ && classLikeDeclaration.modifierFlagsCache & 64 /* Abstract */;
            let completionNodes = [];
            ts_codefix_exports.addNewNodeForMemberSymbol(symbol, classLikeDeclaration, sourceFile, { program, host }, preferences, importAdder, 
            // `addNewNodeForMemberSymbol` calls this callback function for each new member node
            // it adds for the given member symbol.
            // We store these member nodes in the `completionNodes` array.
            // Note: there might be:
            //  - No nodes if `addNewNodeForMemberSymbol` cannot figure out a node for the member;
            //  - One node;
            //  - More than one node if the member is overloaded (e.g. a method with overload signatures).
            (node) => {
                let requiredModifiers = 0 /* None */;
                if (isAbstract) {
                    requiredModifiers |= 64 /* Abstract */;
                }
                if (isClassElement(node) && checker.getMemberOverrideModifierStatus(classLikeDeclaration, node, symbol) === 1 /* NeedsOverride */) {
                    requiredModifiers |= 16 /* Override */;
                }
                if (!completionNodes.length) {
                    modifiers = node.modifierFlagsCache | requiredModifiers;
                }
                node = factory.replaceModifiers(node, modifiers);
                completionNodes.push(node);
            }, body, ts_codefix_exports.PreserveOptionalFlags.Property, !!isAbstract);
            if (completionNodes.length) {
                const isMethod = symbol.flags & 8192 /* Method */;
                let allowedModifiers = modifiers | 16 /* Override */ | 1 /* Public */;
                if (!isMethod) {
                    allowedModifiers |= 128 /* Ambient */ | 8 /* Readonly */;
                }
                else {
                    allowedModifiers |= 1024 /* Async */;
                }
                const allowedAndPresent = presentModifiers & allowedModifiers;
                if (presentModifiers & ~allowedModifiers) {
                    return void 0;
                }
                if (modifiers & 4 /* Protected */ && allowedAndPresent & 1 /* Public */) {
                    modifiers &= ~4 /* Protected */;
                }
                if (allowedAndPresent !== 0 /* None */ && !(allowedAndPresent & 1 /* Public */)) {
                    modifiers &= ~1 /* Public */;
                }
                modifiers |= allowedAndPresent;
                completionNodes = completionNodes.map((node) => factory.replaceModifiers(node, modifiers));
                if (presentDecorators == null ? void 0 : presentDecorators.length) {
                    const lastNode = completionNodes[completionNodes.length - 1];
                    if (canHaveDecorators(lastNode)) {
                        completionNodes[completionNodes.length - 1] = factory.replaceDecoratorsAndModifiers(lastNode, presentDecorators.concat(getModifiers(lastNode) || []));
                    }
                }
                const format = 1 /* MultiLine */ | 131072 /* NoTrailingNewLine */;
                if (formatContext) {
                    insertText = printer.printAndFormatSnippetList(format, factory.createNodeArray(completionNodes), sourceFile, formatContext);
                }
                else {
                    insertText = printer.printSnippetList(format, factory.createNodeArray(completionNodes), sourceFile);
                }
            }
            return { insertText, filterText, isSnippet, importAdder, eraseRange };
        }
        function getPresentModifiers(contextToken, sourceFile, position) {
            if (!contextToken || getLineAndCharacterOfPosition(sourceFile, position).line > getLineAndCharacterOfPosition(sourceFile, contextToken.getEnd()).line) {
                return { modifiers: 0 /* None */ };
            }
            let modifiers = 0 /* None */;
            let decorators;
            let contextMod;
            const range = { pos: position, end: position };
            if (isPropertyDeclaration(contextToken.parent) && contextToken.parent.modifiers) {
                modifiers |= modifiersToFlags(contextToken.parent.modifiers) & 98303 /* Modifier */;
                decorators = contextToken.parent.modifiers.filter(isDecorator) || [];
                range.pos = Math.min(range.pos, contextToken.parent.modifiers.pos);
            }
            if (contextMod = isModifierLike2(contextToken)) {
                const contextModifierFlag = modifierToFlag(contextMod);
                if (!(modifiers & contextModifierFlag)) {
                    modifiers |= contextModifierFlag;
                    range.pos = Math.min(range.pos, contextToken.pos);
                }
            }
            return { modifiers, decorators, range: range.pos !== position ? range : void 0 };
        }
        function isModifierLike2(node) {
            if (isModifier(node)) {
                return node.kind;
            }
            if (isIdentifier(node)) {
                const originalKeywordKind = identifierToKeywordKind(node);
                if (originalKeywordKind && isModifierKind(originalKeywordKind)) {
                    return originalKeywordKind;
                }
            }
            return void 0;
        }
        function getEntryForObjectLiteralMethodCompletion(symbol, name, enclosingDeclaration, program, host, options, preferences, formatContext) {
            const isSnippet = preferences.includeCompletionsWithSnippetText || void 0;
            let insertText = name;
            const sourceFile = enclosingDeclaration.getSourceFile();
            const method = createObjectLiteralMethod(symbol, enclosingDeclaration, sourceFile, program, host, preferences);
            if (!method) {
                return void 0;
            }
            const printer = createSnippetPrinter({
                removeComments: true,
                module: options.module,
                target: options.target,
                omitTrailingSemicolon: false,
                newLine: getNewLineKind(getNewLineOrDefaultFromHost(host, formatContext == null ? void 0 : formatContext.options))
            });
            if (formatContext) {
                insertText = printer.printAndFormatSnippetList(16 /* CommaDelimited */ | 64 /* AllowTrailingComma */, factory.createNodeArray([method], 
                /*hasTrailingComma*/
                true), sourceFile, formatContext);
            }
            else {
                insertText = printer.printSnippetList(16 /* CommaDelimited */ | 64 /* AllowTrailingComma */, factory.createNodeArray([method], 
                /*hasTrailingComma*/
                true), sourceFile);
            }
            const signaturePrinter = createPrinter({
                removeComments: true,
                module: options.module,
                target: options.target,
                omitTrailingSemicolon: true
            });
            const methodSignature = factory.createMethodSignature(
            /*modifiers*/
            void 0, 
            /*name*/
            "", method.questionToken, method.typeParameters, method.parameters, method.type);
            const labelDetails = { detail: signaturePrinter.printNode(4 /* Unspecified */, methodSignature, sourceFile) };
            return { isSnippet, insertText, labelDetails };
        }
        function createObjectLiteralMethod(symbol, enclosingDeclaration, sourceFile, program, host, preferences) {
            const declarations = symbol.getDeclarations();
            if (!(declarations && declarations.length)) {
                return void 0;
            }
            const checker = program.getTypeChecker();
            const declaration = declarations[0];
            const name = getSynthesizedDeepClone(getNameOfDeclaration(declaration), 
            /*includeTrivia*/
            false);
            const type = checker.getWidenedType(checker.getTypeOfSymbolAtLocation(symbol, enclosingDeclaration));
            const quotePreference = getQuotePreference(sourceFile, preferences);
            const builderFlags = 33554432 /* OmitThisParameter */ | (quotePreference === 0 /* Single */ ? 268435456 /* UseSingleQuotesForStringLiteralType */ : 0 /* None */);
            switch (declaration.kind) {
                case 171 /* PropertySignature */:
                case 172 /* PropertyDeclaration */:
                case 173 /* MethodSignature */:
                case 174 /* MethodDeclaration */: {
                    let effectiveType = type.flags & 1048576 /* Union */ && type.types.length < 10 ? checker.getUnionType(type.types, 2 /* Subtype */) : type;
                    if (effectiveType.flags & 1048576 /* Union */) {
                        const functionTypes = filter(effectiveType.types, (type2) => checker.getSignaturesOfType(type2, 0 /* Call */).length > 0);
                        if (functionTypes.length === 1) {
                            effectiveType = functionTypes[0];
                        }
                        else {
                            return void 0;
                        }
                    }
                    const signatures = checker.getSignaturesOfType(effectiveType, 0 /* Call */);
                    if (signatures.length !== 1) {
                        return void 0;
                    }
                    const typeNode = checker.typeToTypeNode(effectiveType, enclosingDeclaration, builderFlags, ts_codefix_exports.getNoopSymbolTrackerWithResolver({ program, host }));
                    if (!typeNode || !isFunctionTypeNode(typeNode)) {
                        return void 0;
                    }
                    let body;
                    if (preferences.includeCompletionsWithSnippetText) {
                        const emptyStmt = factory.createEmptyStatement();
                        body = factory.createBlock([emptyStmt], 
                        /*multiLine*/
                        true);
                        setSnippetElement(emptyStmt, { kind: 0 /* TabStop */, order: 0 });
                    }
                    else {
                        body = factory.createBlock([], 
                        /*multiLine*/
                        true);
                    }
                    const parameters = typeNode.parameters.map((typedParam) => factory.createParameterDeclaration(
                    /*modifiers*/
                    void 0, typedParam.dotDotDotToken, typedParam.name, 
                    /*questionToken*/
                    void 0, 
                    /*type*/
                    void 0, typedParam.initializer));
                    return factory.createMethodDeclaration(
                    /*modifiers*/
                    void 0, 
                    /*asteriskToken*/
                    void 0, name, 
                    /*questionToken*/
                    void 0, 
                    /*typeParameters*/
                    void 0, parameters, 
                    /*type*/
                    void 0, body);
                }
                default:
                    return void 0;
            }
        }
        function createSnippetPrinter(printerOptions) {
            let escapes;
            const baseWriter = ts_textChanges_exports.createWriter(getNewLineCharacter(printerOptions));
            const printer = createPrinter(printerOptions, baseWriter);
            const writer = {
                ...baseWriter,
                write: (s) => escapingWrite(s, () => baseWriter.write(s)),
                nonEscapingWrite: baseWriter.write,
                writeLiteral: (s) => escapingWrite(s, () => baseWriter.writeLiteral(s)),
                writeStringLiteral: (s) => escapingWrite(s, () => baseWriter.writeStringLiteral(s)),
                writeSymbol: (s, symbol) => escapingWrite(s, () => baseWriter.writeSymbol(s, symbol)),
                writeParameter: (s) => escapingWrite(s, () => baseWriter.writeParameter(s)),
                writeComment: (s) => escapingWrite(s, () => baseWriter.writeComment(s)),
                writeProperty: (s) => escapingWrite(s, () => baseWriter.writeProperty(s))
            };
            return {
                printSnippetList,
                printAndFormatSnippetList,
                printNode,
                printAndFormatNode
            };
            function escapingWrite(s, write) {
                const escaped = escapeSnippetText(s);
                if (escaped !== s) {
                    const start = baseWriter.getTextPos();
                    write();
                    const end = baseWriter.getTextPos();
                    escapes = append(escapes || (escapes = []), { newText: escaped, span: { start, length: end - start } });
                }
                else {
                    write();
                }
            }
            function printSnippetList(format, list, sourceFile) {
                const unescaped = printUnescapedSnippetList(format, list, sourceFile);
                return escapes ? ts_textChanges_exports.applyChanges(unescaped, escapes) : unescaped;
            }
            function printUnescapedSnippetList(format, list, sourceFile) {
                escapes = void 0;
                writer.clear();
                printer.writeList(format, list, sourceFile, writer);
                return writer.getText();
            }
            function printAndFormatSnippetList(format, list, sourceFile, formatContext) {
                const syntheticFile = {
                    text: printUnescapedSnippetList(format, list, sourceFile),
                    getLineAndCharacterOfPosition(pos) {
                        return getLineAndCharacterOfPosition(this, pos);
                    }
                };
                const formatOptions = getFormatCodeSettingsForWriting(formatContext, sourceFile);
                const changes = flatMap(list, (node) => {
                    const nodeWithPos = ts_textChanges_exports.assignPositionsToNode(node);
                    return ts_formatting_exports.formatNodeGivenIndentation(nodeWithPos, syntheticFile, sourceFile.languageVariant, 
                    /* indentation */
                    0, 
                    /* delta */
                    0, { ...formatContext, options: formatOptions });
                });
                const allChanges = escapes ? stableSort(concatenate(changes, escapes), (a, b) => compareTextSpans(a.span, b.span)) : changes;
                return ts_textChanges_exports.applyChanges(syntheticFile.text, allChanges);
            }
            function printNode(hint, node, sourceFile) {
                const unescaped = printUnescapedNode(hint, node, sourceFile);
                return escapes ? ts_textChanges_exports.applyChanges(unescaped, escapes) : unescaped;
            }
            function printUnescapedNode(hint, node, sourceFile) {
                escapes = void 0;
                writer.clear();
                printer.writeNode(hint, node, sourceFile, writer);
                return writer.getText();
            }
            function printAndFormatNode(hint, node, sourceFile, formatContext) {
                const syntheticFile = {
                    text: printUnescapedNode(hint, node, sourceFile),
                    getLineAndCharacterOfPosition(pos) {
                        return getLineAndCharacterOfPosition(this, pos);
                    }
                };
                const formatOptions = getFormatCodeSettingsForWriting(formatContext, sourceFile);
                const nodeWithPos = ts_textChanges_exports.assignPositionsToNode(node);
                const changes = ts_formatting_exports.formatNodeGivenIndentation(nodeWithPos, syntheticFile, sourceFile.languageVariant, 
                /* indentation */
                0, 
                /* delta */
                0, { ...formatContext, options: formatOptions });
                const allChanges = escapes ? stableSort(concatenate(changes, escapes), (a, b) => compareTextSpans(a.span, b.span)) : changes;
                return ts_textChanges_exports.applyChanges(syntheticFile.text, allChanges);
            }
        }
        function originToCompletionEntryData(origin) {
            const ambientModuleName = origin.fileName ? void 0 : stripQuotes(origin.moduleSymbol.name);
            const isPackageJsonImport = origin.isFromPackageJson ? true : void 0;
            if (originIsResolvedExport(origin)) {
                const resolvedData = {
                    exportName: origin.exportName,
                    exportMapKey: origin.exportMapKey,
                    moduleSpecifier: origin.moduleSpecifier,
                    ambientModuleName,
                    fileName: origin.fileName,
                    isPackageJsonImport
                };
                return resolvedData;
            }
            const unresolvedData = {
                exportName: origin.exportName,
                exportMapKey: origin.exportMapKey,
                fileName: origin.fileName,
                ambientModuleName: origin.fileName ? void 0 : stripQuotes(origin.moduleSymbol.name),
                isPackageJsonImport: origin.isFromPackageJson ? true : void 0
            };
            return unresolvedData;
        }
        function completionEntryDataToSymbolOriginInfo(data, completionName, moduleSymbol) {
            const isDefaultExport = data.exportName === "default" /* Default */;
            const isFromPackageJson = !!data.isPackageJsonImport;
            if (completionEntryDataIsResolved(data)) {
                const resolvedOrigin = {
                    kind: 32 /* ResolvedExport */,
                    exportName: data.exportName,
                    exportMapKey: data.exportMapKey,
                    moduleSpecifier: data.moduleSpecifier,
                    symbolName: completionName,
                    fileName: data.fileName,
                    moduleSymbol,
                    isDefaultExport,
                    isFromPackageJson
                };
                return resolvedOrigin;
            }
            const unresolvedOrigin = {
                kind: 4 /* Export */,
                exportName: data.exportName,
                exportMapKey: data.exportMapKey,
                symbolName: completionName,
                fileName: data.fileName,
                moduleSymbol,
                isDefaultExport,
                isFromPackageJson
            };
            return unresolvedOrigin;
        }
        function getInsertTextAndReplacementSpanForImportCompletion(name, importStatementCompletion, origin, useSemicolons, sourceFile, options, preferences) {
            const replacementSpan = importStatementCompletion.replacementSpan;
            const quotedModuleSpecifier = escapeSnippetText(quote(sourceFile, preferences, origin.moduleSpecifier));
            const exportKind = origin.isDefaultExport ? 1 /* Default */ : origin.exportName === "export=" /* ExportEquals */ ? 2 /* ExportEquals */ : 0 /* Named */;
            const tabStop = preferences.includeCompletionsWithSnippetText ? "$1" : "";
            const importKind = ts_codefix_exports.getImportKind(sourceFile, exportKind, options, 
            /*forceImportKeyword*/
            true);
            const isImportSpecifierTypeOnly = importStatementCompletion.couldBeTypeOnlyImportSpecifier;
            const topLevelTypeOnlyText = importStatementCompletion.isTopLevelTypeOnly ? ` ${tokenToString(156 /* TypeKeyword */)} ` : " ";
            const importSpecifierTypeOnlyText = isImportSpecifierTypeOnly ? `${tokenToString(156 /* TypeKeyword */)} ` : "";
            const suffix = useSemicolons ? ";" : "";
            switch (importKind) {
                case 3 /* CommonJS */:
                    return { replacementSpan, insertText: `import${topLevelTypeOnlyText}${escapeSnippetText(name)}${tabStop} = require(${quotedModuleSpecifier})${suffix}` };
                case 1 /* Default */:
                    return { replacementSpan, insertText: `import${topLevelTypeOnlyText}${escapeSnippetText(name)}${tabStop} from ${quotedModuleSpecifier}${suffix}` };
                case 2 /* Namespace */:
                    return { replacementSpan, insertText: `import${topLevelTypeOnlyText}* as ${escapeSnippetText(name)} from ${quotedModuleSpecifier}${suffix}` };
                case 0 /* Named */:
                    return { replacementSpan, insertText: `import${topLevelTypeOnlyText}{ ${importSpecifierTypeOnlyText}${escapeSnippetText(name)}${tabStop} } from ${quotedModuleSpecifier}${suffix}` };
            }
        }
        function quotePropertyName(sourceFile, preferences, name) {
            if (/^\d+$/.test(name)) {
                return name;
            }
            return quote(sourceFile, preferences, name);
        }
        function isRecommendedCompletionMatch(localSymbol, recommendedCompletion, checker) {
            return localSymbol === recommendedCompletion || !!(localSymbol.flags & 1048576 /* ExportValue */) && checker.getExportSymbolOfSymbol(localSymbol) === recommendedCompletion;
        }
        function getSourceFromOrigin(origin) {
            if (originIsExport(origin)) {
                return stripQuotes(origin.moduleSymbol.name);
            }
            if (originIsResolvedExport(origin)) {
                return origin.moduleSpecifier;
            }
            if ((origin == null ? void 0 : origin.kind) === 1 /* ThisType */) {
                return "ThisProperty/" /* ThisProperty */;
            }
            if ((origin == null ? void 0 : origin.kind) === 64 /* TypeOnlyAlias */) {
                return "TypeOnlyAlias/" /* TypeOnlyAlias */;
            }
        }
        function getCompletionEntriesFromSymbols(symbols, entries, replacementToken, contextToken, location, position, sourceFile, host, program, target, log, kind, preferences, compilerOptions, formatContext, isTypeOnlyLocation, propertyAccessToConvert, jsxIdentifierExpected, isJsxInitializer, importStatementCompletion, recommendedCompletion, symbolToOriginInfoMap, symbolToSortTextMap, isJsxIdentifierExpected, isRightOfOpenTag, includeSymbol = false) {
            const start = timestamp();
            const variableOrParameterDeclaration = getVariableOrParameterDeclaration(contextToken, location);
            const useSemicolons = probablyUsesSemicolons(sourceFile);
            const typeChecker = program.getTypeChecker();
            const uniques = /* @__PURE__ */ new Map();
            for (let i = 0; i < symbols.length; i++) {
                const symbol = symbols[i];
                const origin = symbolToOriginInfoMap == null ? void 0 : symbolToOriginInfoMap[i];
                const info = getCompletionEntryDisplayNameForSymbol(symbol, target, origin, kind, !!jsxIdentifierExpected);
                if (!info || uniques.get(info.name) && (!origin || !originIsObjectLiteralMethod(origin)) || kind === 1 /* Global */ && symbolToSortTextMap && !shouldIncludeSymbol(symbol, symbolToSortTextMap)) {
                    continue;
                }
                if (!isTypeOnlyLocation && isInJSFile(sourceFile) && symbolAppearsToBeTypeOnly(symbol)) {
                    continue;
                }
                const { name, needsConvertPropertyAccess } = info;
                const originalSortText = (symbolToSortTextMap == null ? void 0 : symbolToSortTextMap[getSymbolId(symbol)]) ?? SortText.LocationPriority;
                const sortText = isDeprecated(symbol, typeChecker) ? SortText.Deprecated(originalSortText) : originalSortText;
                const entry = createCompletionEntry(symbol, sortText, replacementToken, contextToken, location, position, sourceFile, host, program, name, needsConvertPropertyAccess, origin, recommendedCompletion, propertyAccessToConvert, isJsxInitializer, importStatementCompletion, useSemicolons, compilerOptions, preferences, kind, formatContext, isJsxIdentifierExpected, isRightOfOpenTag, includeSymbol);
                if (!entry) {
                    continue;
                }
                const shouldShadowLaterSymbols = (!origin || originIsTypeOnlyAlias(origin)) && !(symbol.parent === void 0 && !some(symbol.declarations, (d) => d.getSourceFile() === location.getSourceFile()));
                uniques.set(name, shouldShadowLaterSymbols);
                insertSorted(entries, entry, compareCompletionEntries, 
                /*allowDuplicates*/
                true);
            }
            log("getCompletionsAtPosition: getCompletionEntriesFromSymbols: " + (timestamp() - start));
            return {
                has: (name) => uniques.has(name),
                add: (name) => uniques.set(name, true)
            };
            function shouldIncludeSymbol(symbol, symbolToSortTextMap2) {
                var _a;
                let allFlags = symbol.flags;
                if (!isSourceFile(location)) {
                    if (isExportAssignment(location.parent)) {
                        return true;
                    }
                    if (tryCast(variableOrParameterDeclaration, isVariableDeclaration) && symbol.valueDeclaration === variableOrParameterDeclaration) {
                        return false;
                    }
                    const symbolDeclaration = symbol.valueDeclaration ?? ((_a = symbol.declarations) == null ? void 0 : _a[0]);
                    if (variableOrParameterDeclaration && symbolDeclaration && (isTypeParameterDeclaration(variableOrParameterDeclaration) && isTypeParameterDeclaration(symbolDeclaration) || isParameter(variableOrParameterDeclaration) && isParameter(symbolDeclaration))) {
                        const symbolDeclarationPos = symbolDeclaration.pos;
                        const parameters = isParameter(variableOrParameterDeclaration) ? variableOrParameterDeclaration.parent.parameters : isInferTypeNode(variableOrParameterDeclaration.parent) ? void 0 : variableOrParameterDeclaration.parent.typeParameters;
                        if (symbolDeclarationPos >= variableOrParameterDeclaration.pos && parameters && symbolDeclarationPos < parameters.end) {
                            return false;
                        }
                    }
                    const symbolOrigin = skipAlias(symbol, typeChecker);
                    if (!!sourceFile.externalModuleIndicator && !compilerOptions.allowUmdGlobalAccess && symbolToSortTextMap2[getSymbolId(symbol)] === SortText.GlobalsOrKeywords && (symbolToSortTextMap2[getSymbolId(symbolOrigin)] === SortText.AutoImportSuggestions || symbolToSortTextMap2[getSymbolId(symbolOrigin)] === SortText.LocationPriority)) {
                        return false;
                    }
                    allFlags |= getCombinedLocalAndExportSymbolFlags(symbolOrigin);
                    if (isInRightSideOfInternalImportEqualsDeclaration(location)) {
                        return !!(allFlags & 1920 /* Namespace */);
                    }
                    if (isTypeOnlyLocation) {
                        return symbolCanBeReferencedAtTypeLocation(symbol, typeChecker);
                    }
                }
                return !!(allFlags & 111551 /* Value */);
            }
            function symbolAppearsToBeTypeOnly(symbol) {
                var _a;
                return !(symbol.flags & 111551 /* Value */) && (!isInJSFile((_a = symbol.declarations) == null ? void 0 : _a[0]) || !!(symbol.flags & 788968 /* Type */));
            }
        }
        function getLabelCompletionAtPosition(node) {
            const entries = getLabelStatementCompletions(node);
            if (entries.length) {
                return { isGlobalCompletion: false, isMemberCompletion: false, isNewIdentifierLocation: false, entries };
            }
        }
        function getLabelStatementCompletions(node) {
            const entries = [];
            const uniques = /* @__PURE__ */ new Map();
            let current = node;
            while (current) {
                if (isFunctionLike(current)) {
                    break;
                }
                if (isLabeledStatement(current)) {
                    const name = current.label.text;
                    if (!uniques.has(name)) {
                        uniques.set(name, true);
                        entries.push({
                            name,
                            kindModifiers: "" /* none */,
                            kind: "label" /* label */,
                            sortText: SortText.LocationPriority
                        });
                    }
                }
                current = current.parent;
            }
            return entries;
        }
        function getSymbolCompletionFromEntryId(program, log, sourceFile, position, entryId, host, preferences) {
            if (entryId.source === "SwitchCases/" /* SwitchCases */) {
                return { type: "cases" };
            }
            if (entryId.data) {
                const autoImport = getAutoImportSymbolFromCompletionEntryData(entryId.name, entryId.data, program, host);
                if (autoImport) {
                    const { contextToken: contextToken2, previousToken: previousToken2 } = getRelevantTokens(position, sourceFile);
                    return {
                        type: "symbol",
                        symbol: autoImport.symbol,
                        location: getTouchingPropertyName(sourceFile, position),
                        previousToken: previousToken2,
                        contextToken: contextToken2,
                        isJsxInitializer: false,
                        isTypeOnlyLocation: false,
                        origin: autoImport.origin
                    };
                }
            }
            const compilerOptions = program.getCompilerOptions();
            const completionData = getCompletionData(program, log, sourceFile, compilerOptions, position, { includeCompletionsForModuleExports: true, includeCompletionsWithInsertText: true }, entryId, host, 
            /*formatContext*/
            void 0);
            if (!completionData) {
                return { type: "none" };
            }
            if (completionData.kind !== 0 /* Data */) {
                return { type: "request", request: completionData };
            }
            const { symbols, literals, location, completionKind, symbolToOriginInfoMap, contextToken, previousToken, isJsxInitializer, isTypeOnlyLocation } = completionData;
            const literal = find(literals, (l) => completionNameForLiteral(sourceFile, preferences, l) === entryId.name);
            if (literal !== void 0)
                return { type: "literal", literal };
            return firstDefined(symbols, (symbol, index) => {
                const origin = symbolToOriginInfoMap[index];
                const info = getCompletionEntryDisplayNameForSymbol(symbol, getEmitScriptTarget(compilerOptions), origin, completionKind, completionData.isJsxIdentifierExpected);
                return info && info.name === entryId.name && (entryId.source === "ClassMemberSnippet/" /* ClassMemberSnippet */ && symbol.flags & 106500 /* ClassMember */ || entryId.source === "ObjectLiteralMethodSnippet/" /* ObjectLiteralMethodSnippet */ && symbol.flags & (4 /* Property */ | 8192 /* Method */) || getSourceFromOrigin(origin) === entryId.source || entryId.source === "ObjectLiteralMemberWithComma/" /* ObjectLiteralMemberWithComma */) ? { type: "symbol", symbol, location, origin, contextToken, previousToken, isJsxInitializer, isTypeOnlyLocation } : void 0;
            }) || { type: "none" };
        }
        function getCompletionEntryDetails(program, log, sourceFile, position, entryId, host, formatContext, preferences, cancellationToken) {
            const typeChecker = program.getTypeChecker();
            const compilerOptions = program.getCompilerOptions();
            const { name, source, data } = entryId;
            const { previousToken, contextToken } = getRelevantTokens(position, sourceFile);
            if (isInString(sourceFile, position, previousToken)) {
                return ts_Completions_StringCompletions_exports.getStringLiteralCompletionDetails(name, sourceFile, position, previousToken, program, host, cancellationToken, preferences);
            }
            const symbolCompletion = getSymbolCompletionFromEntryId(program, log, sourceFile, position, entryId, host, preferences);
            switch (symbolCompletion.type) {
                case "request": {
                    const { request } = symbolCompletion;
                    switch (request.kind) {
                        case 1 /* JsDocTagName */:
                            return ts_JsDoc_exports.getJSDocTagNameCompletionDetails(name);
                        case 2 /* JsDocTag */:
                            return ts_JsDoc_exports.getJSDocTagCompletionDetails(name);
                        case 3 /* JsDocParameterName */:
                            return ts_JsDoc_exports.getJSDocParameterNameCompletionDetails(name);
                        case 4 /* Keywords */:
                            return some(request.keywordCompletions, (c) => c.name === name) ? createSimpleDetails(name, "keyword" /* keyword */, 5 /* keyword */) : void 0;
                        default:
                            return Debug.assertNever(request);
                    }
                }
                case "symbol": {
                    const { symbol, location, contextToken: contextToken2, origin, previousToken: previousToken2 } = symbolCompletion;
                    const { codeActions, sourceDisplay } = getCompletionEntryCodeActionsAndSourceDisplay(name, location, contextToken2, origin, symbol, program, host, compilerOptions, sourceFile, position, previousToken2, formatContext, preferences, data, source, cancellationToken);
                    const symbolName2 = originIsComputedPropertyName(origin) ? origin.symbolName : symbol.name;
                    return createCompletionDetailsForSymbol(symbol, symbolName2, typeChecker, sourceFile, location, cancellationToken, codeActions, sourceDisplay);
                }
                case "literal": {
                    const { literal } = symbolCompletion;
                    return createSimpleDetails(completionNameForLiteral(sourceFile, preferences, literal), "string" /* string */, typeof literal === "string" ? 8 /* stringLiteral */ : 7 /* numericLiteral */);
                }
                case "cases": {
                    const snippets = getExhaustiveCaseSnippets(contextToken.parent, sourceFile, preferences, program.getCompilerOptions(), host, program, 
                    /*formatContext*/
                    void 0);
                    if (snippets == null ? void 0 : snippets.importAdder.hasFixes()) {
                        const { entry, importAdder } = snippets;
                        const changes = ts_textChanges_exports.ChangeTracker.with({ host, formatContext, preferences }, importAdder.writeFixes);
                        return {
                            name: entry.name,
                            kind: "" /* unknown */,
                            kindModifiers: "",
                            displayParts: [],
                            sourceDisplay: void 0,
                            codeActions: [{
                                    changes,
                                    description: diagnosticToString([Diagnostics.Includes_imports_of_types_referenced_by_0, name])
                                }]
                        };
                    }
                    return {
                        name,
                        kind: "" /* unknown */,
                        kindModifiers: "",
                        displayParts: [],
                        sourceDisplay: void 0
                    };
                }
                case "none":
                    return allKeywordsCompletions().some((c) => c.name === name) ? createSimpleDetails(name, "keyword" /* keyword */, 5 /* keyword */) : void 0;
                default:
                    Debug.assertNever(symbolCompletion);
            }
        }
        function createSimpleDetails(name, kind, kind2) {
            return createCompletionDetails(name, "" /* none */, kind, [displayPart(name, kind2)]);
        }
        function createCompletionDetailsForSymbol(symbol, name, checker, sourceFile, location, cancellationToken, codeActions, sourceDisplay) {
            const { displayParts, documentation, symbolKind, tags } = checker.runWithCancellationToken(cancellationToken, (checker2) => ts_SymbolDisplay_exports.getSymbolDisplayPartsDocumentationAndSymbolKind(checker2, symbol, sourceFile, location, location, 7 /* All */));
            return createCompletionDetails(name, ts_SymbolDisplay_exports.getSymbolModifiers(checker, symbol), symbolKind, displayParts, documentation, tags, codeActions, sourceDisplay);
        }
        function createCompletionDetails(name, kindModifiers, kind, displayParts, documentation, tags, codeActions, source) {
            return { name, kindModifiers, kind, displayParts, documentation, tags, codeActions, source, sourceDisplay: source };
        }
        function getCompletionEntryCodeActionsAndSourceDisplay(name, location, contextToken, origin, symbol, program, host, compilerOptions, sourceFile, position, previousToken, formatContext, preferences, data, source, cancellationToken) {
            if (data == null ? void 0 : data.moduleSpecifier) {
                if (previousToken && getImportStatementCompletionInfo(contextToken || previousToken, sourceFile).replacementSpan) {
                    return { codeActions: void 0, sourceDisplay: [textPart(data.moduleSpecifier)] };
                }
            }
            if (source === "ClassMemberSnippet/" /* ClassMemberSnippet */) {
                const { importAdder, eraseRange } = getEntryForMemberCompletion(host, program, compilerOptions, preferences, name, symbol, location, position, contextToken, formatContext);
                if (importAdder || eraseRange) {
                    const changes = ts_textChanges_exports.ChangeTracker.with({ host, formatContext, preferences }, (tracker) => {
                        if (importAdder) {
                            importAdder.writeFixes(tracker);
                        }
                        if (eraseRange) {
                            tracker.deleteRange(sourceFile, eraseRange);
                        }
                    });
                    return {
                        sourceDisplay: void 0,
                        codeActions: [{
                                changes,
                                description: diagnosticToString([Diagnostics.Includes_imports_of_types_referenced_by_0, name])
                            }]
                    };
                }
            }
            if (originIsTypeOnlyAlias(origin)) {
                const codeAction2 = ts_codefix_exports.getPromoteTypeOnlyCompletionAction(sourceFile, origin.declaration.name, program, host, formatContext, preferences);
                Debug.assertIsDefined(codeAction2, "Expected to have a code action for promoting type-only alias");
                return { codeActions: [codeAction2], sourceDisplay: void 0 };
            }
            if (source === "ObjectLiteralMemberWithComma/" /* ObjectLiteralMemberWithComma */ && contextToken) {
                const changes = ts_textChanges_exports.ChangeTracker.with({ host, formatContext, preferences }, (tracker) => tracker.insertText(sourceFile, contextToken.end, ","));
                if (changes) {
                    return {
                        sourceDisplay: void 0,
                        codeActions: [{
                                changes,
                                description: diagnosticToString([Diagnostics.Add_missing_comma_for_object_member_completion_0, name])
                            }]
                    };
                }
            }
            if (!origin || !(originIsExport(origin) || originIsResolvedExport(origin))) {
                return { codeActions: void 0, sourceDisplay: void 0 };
            }
            const checker = origin.isFromPackageJson ? host.getPackageJsonAutoImportProvider().getTypeChecker() : program.getTypeChecker();
            const { moduleSymbol } = origin;
            const targetSymbol = checker.getMergedSymbol(skipAlias(symbol.exportSymbol || symbol, checker));
            const isJsxOpeningTagName = (contextToken == null ? void 0 : contextToken.kind) === 30 /* LessThanToken */ && isJsxOpeningLikeElement(contextToken.parent);
            const { moduleSpecifier, codeAction } = ts_codefix_exports.getImportCompletionAction(targetSymbol, moduleSymbol, data == null ? void 0 : data.exportMapKey, sourceFile, name, isJsxOpeningTagName, host, program, formatContext, previousToken && isIdentifier(previousToken) ? previousToken.getStart(sourceFile) : position, preferences, cancellationToken);
            Debug.assert(!(data == null ? void 0 : data.moduleSpecifier) || moduleSpecifier === data.moduleSpecifier);
            return { sourceDisplay: [textPart(moduleSpecifier)], codeActions: [codeAction] };
        }
        function getCompletionEntrySymbol(program, log, sourceFile, position, entryId, host, preferences) {
            const completion = getSymbolCompletionFromEntryId(program, log, sourceFile, position, entryId, host, preferences);
            return completion.type === "symbol" ? completion.symbol : void 0;
        }
        function getRecommendedCompletion(previousToken, contextualType, checker) {
            return firstDefined(contextualType && (contextualType.isUnion() ? contextualType.types : [contextualType]), (type) => {
                const symbol = type && type.symbol;
                return symbol && (symbol.flags & (8 /* EnumMember */ | 384 /* Enum */ | 32 /* Class */) && !isAbstractConstructorSymbol(symbol)) ? getFirstSymbolInChain(symbol, previousToken, checker) : void 0;
            });
        }
        function getContextualType(previousToken, position, sourceFile, checker) {
            const { parent: parent2 } = previousToken;
            switch (previousToken.kind) {
                case 80 /* Identifier */:
                    return getContextualTypeFromParent(previousToken, checker);
                case 64 /* EqualsToken */:
                    switch (parent2.kind) {
                        case 260 /* VariableDeclaration */:
                            return checker.getContextualType(parent2.initializer);
                        case 226 /* BinaryExpression */:
                            return checker.getTypeAtLocation(parent2.left);
                        case 291 /* JsxAttribute */:
                            return checker.getContextualTypeForJsxAttribute(parent2);
                        default:
                            return void 0;
                    }
                case 105 /* NewKeyword */:
                    return checker.getContextualType(parent2);
                case 84 /* CaseKeyword */:
                    const caseClause = tryCast(parent2, isCaseClause);
                    return caseClause ? getSwitchedType(caseClause, checker) : void 0;
                case 19 /* OpenBraceToken */:
                    return isJsxExpression(parent2) && !isJsxElement(parent2.parent) && !isJsxFragment(parent2.parent) ? checker.getContextualTypeForJsxAttribute(parent2.parent) : void 0;
                default:
                    const argInfo = ts_SignatureHelp_exports.getArgumentInfoForCompletions(previousToken, position, sourceFile, checker);
                    return argInfo ? (
                    // At `,`, treat this as the next argument after the comma.
                    checker.getContextualTypeForArgumentAtIndex(argInfo.invocation, argInfo.argumentIndex + (previousToken.kind === 28 /* CommaToken */ ? 1 : 0))) : isEqualityOperatorKind(previousToken.kind) && isBinaryExpression(parent2) && isEqualityOperatorKind(parent2.operatorToken.kind) ? (
                    // completion at `x ===/**/` should be for the right side
                    checker.getTypeAtLocation(parent2.left)) : checker.getContextualType(previousToken, 4 /* Completions */) || checker.getContextualType(previousToken);
            }
        }
        function getFirstSymbolInChain(symbol, enclosingDeclaration, checker) {
            const chain = checker.getAccessibleSymbolChain(symbol, enclosingDeclaration, 
            /*meaning*/
            -1 /* All */, 
            /*useOnlyExternalAliasing*/
            false);
            if (chain)
                return first(chain);
            return symbol.parent && (isModuleSymbol(symbol.parent) ? symbol : getFirstSymbolInChain(symbol.parent, enclosingDeclaration, checker));
        }
        function isModuleSymbol(symbol) {
            var _a;
            return !!((_a = symbol.declarations) == null ? void 0 : _a.some((d) => d.kind === 312 /* SourceFile */));
        }
        function getCompletionData(program, log, sourceFile, compilerOptions, position, preferences, detailsEntryId, host, formatContext, cancellationToken) {
            const typeChecker = program.getTypeChecker();
            const inCheckedFile = isCheckedFile(sourceFile, compilerOptions);
            let start = timestamp();
            let currentToken = getTokenAtPosition(sourceFile, position);
            log("getCompletionData: Get current token: " + (timestamp() - start));
            start = timestamp();
            const insideComment = isInComment(sourceFile, position, currentToken);
            log("getCompletionData: Is inside comment: " + (timestamp() - start));
            let insideJsDocTagTypeExpression = false;
            let isInSnippetScope = false;
            if (insideComment) {
                if (hasDocComment(sourceFile, position)) {
                    if (sourceFile.text.charCodeAt(position - 1) === 64 /* at */) {
                        return { kind: 1 /* JsDocTagName */ };
                    }
                    else {
                        const lineStart = getLineStartPositionForPosition(position, sourceFile);
                        if (!/[^*|\s(/)]/.test(sourceFile.text.substring(lineStart, position))) {
                            return { kind: 2 /* JsDocTag */ };
                        }
                    }
                }
                const tag = getJsDocTagAtPosition(currentToken, position);
                if (tag) {
                    if (tag.tagName.pos <= position && position <= tag.tagName.end) {
                        return { kind: 1 /* JsDocTagName */ };
                    }
                    const typeExpression = tryGetTypeExpressionFromTag(tag);
                    if (typeExpression) {
                        currentToken = getTokenAtPosition(sourceFile, position);
                        if (!currentToken || !isDeclarationName(currentToken) && (currentToken.parent.kind !== 355 /* JSDocPropertyTag */ || currentToken.parent.name !== currentToken)) {
                            insideJsDocTagTypeExpression = isCurrentlyEditingNode(typeExpression);
                        }
                    }
                    if (!insideJsDocTagTypeExpression && isJSDocParameterTag(tag) && (nodeIsMissing(tag.name) || tag.name.pos <= position && position <= tag.name.end)) {
                        return { kind: 3 /* JsDocParameterName */, tag };
                    }
                }
                if (!insideJsDocTagTypeExpression) {
                    log("Returning an empty list because completion was inside a regular comment or plain text part of a JsDoc comment.");
                    return void 0;
                }
            }
            start = timestamp();
            const isJsOnlyLocation = !insideJsDocTagTypeExpression && isSourceFileJS(sourceFile);
            const tokens = getRelevantTokens(position, sourceFile);
            const previousToken = tokens.previousToken;
            let contextToken = tokens.contextToken;
            log("getCompletionData: Get previous token: " + (timestamp() - start));
            let node = currentToken;
            let propertyAccessToConvert;
            let isRightOfDot = false;
            let isRightOfQuestionDot = false;
            let isRightOfOpenTag = false;
            let isStartingCloseTag = false;
            let isJsxInitializer = false;
            let isJsxIdentifierExpected = false;
            let importStatementCompletion;
            let location = getTouchingPropertyName(sourceFile, position);
            let keywordFilters = 0 /* None */;
            let isNewIdentifierLocation = false;
            let flags = 0 /* None */;
            if (contextToken) {
                const importStatementCompletionInfo = getImportStatementCompletionInfo(contextToken, sourceFile);
                if (importStatementCompletionInfo.keywordCompletion) {
                    if (importStatementCompletionInfo.isKeywordOnlyCompletion) {
                        return {
                            kind: 4 /* Keywords */,
                            keywordCompletions: [keywordToCompletionEntry(importStatementCompletionInfo.keywordCompletion)],
                            isNewIdentifierLocation: importStatementCompletionInfo.isNewIdentifierLocation
                        };
                    }
                    keywordFilters = keywordFiltersFromSyntaxKind(importStatementCompletionInfo.keywordCompletion);
                }
                if (importStatementCompletionInfo.replacementSpan && preferences.includeCompletionsForImportStatements && preferences.includeCompletionsWithInsertText) {
                    flags |= 2 /* IsImportStatementCompletion */;
                    importStatementCompletion = importStatementCompletionInfo;
                    isNewIdentifierLocation = importStatementCompletionInfo.isNewIdentifierLocation;
                }
                if (!importStatementCompletionInfo.replacementSpan && isCompletionListBlocker(contextToken)) {
                    log("Returning an empty list because completion was requested in an invalid position.");
                    return keywordFilters ? keywordCompletionData(keywordFilters, isJsOnlyLocation, isNewIdentifierDefinitionLocation()) : void 0;
                }
                let parent2 = contextToken.parent;
                if (contextToken.kind === 25 /* DotToken */ || contextToken.kind === 29 /* QuestionDotToken */) {
                    isRightOfDot = contextToken.kind === 25 /* DotToken */;
                    isRightOfQuestionDot = contextToken.kind === 29 /* QuestionDotToken */;
                    switch (parent2.kind) {
                        case 211 /* PropertyAccessExpression */:
                            propertyAccessToConvert = parent2;
                            node = propertyAccessToConvert.expression;
                            const leftmostAccessExpression = getLeftmostAccessExpression(propertyAccessToConvert);
                            if (nodeIsMissing(leftmostAccessExpression) || (isCallExpression(node) || isFunctionLike(node)) && node.end === contextToken.pos && node.getChildCount(sourceFile) && last(node.getChildren(sourceFile)).kind !== 22 /* CloseParenToken */) {
                                return void 0;
                            }
                            break;
                        case 166 /* QualifiedName */:
                            node = parent2.left;
                            break;
                        case 267 /* ModuleDeclaration */:
                            node = parent2.name;
                            break;
                        case 205 /* ImportType */:
                            node = parent2;
                            break;
                        case 236 /* MetaProperty */:
                            node = parent2.getFirstToken(sourceFile);
                            Debug.assert(node.kind === 102 /* ImportKeyword */ || node.kind === 105 /* NewKeyword */);
                            break;
                        default:
                            return void 0;
                    }
                }
                else if (!importStatementCompletion) {
                    if (parent2 && parent2.kind === 211 /* PropertyAccessExpression */) {
                        contextToken = parent2;
                        parent2 = parent2.parent;
                    }
                    if (currentToken.parent === location) {
                        switch (currentToken.kind) {
                            case 32 /* GreaterThanToken */:
                                if (currentToken.parent.kind === 284 /* JsxElement */ || currentToken.parent.kind === 286 /* JsxOpeningElement */) {
                                    location = currentToken;
                                }
                                break;
                            case 44 /* SlashToken */:
                                if (currentToken.parent.kind === 285 /* JsxSelfClosingElement */) {
                                    location = currentToken;
                                }
                                break;
                        }
                    }
                    switch (parent2.kind) {
                        case 287 /* JsxClosingElement */:
                            if (contextToken.kind === 44 /* SlashToken */) {
                                isStartingCloseTag = true;
                                location = contextToken;
                            }
                            break;
                        case 226 /* BinaryExpression */:
                            if (!binaryExpressionMayBeOpenTag(parent2)) {
                                break;
                            }
                        case 285 /* JsxSelfClosingElement */:
                        case 284 /* JsxElement */:
                        case 286 /* JsxOpeningElement */:
                            isJsxIdentifierExpected = true;
                            if (contextToken.kind === 30 /* LessThanToken */) {
                                isRightOfOpenTag = true;
                                location = contextToken;
                            }
                            break;
                        case 294 /* JsxExpression */:
                        case 293 /* JsxSpreadAttribute */:
                            if (previousToken.kind === 20 /* CloseBraceToken */ || previousToken.kind === 80 /* Identifier */ && previousToken.parent.kind === 291 /* JsxAttribute */) {
                                isJsxIdentifierExpected = true;
                            }
                            break;
                        case 291 /* JsxAttribute */:
                            if (parent2.initializer === previousToken && previousToken.end < position) {
                                isJsxIdentifierExpected = true;
                                break;
                            }
                            switch (previousToken.kind) {
                                case 64 /* EqualsToken */:
                                    isJsxInitializer = true;
                                    break;
                                case 80 /* Identifier */:
                                    isJsxIdentifierExpected = true;
                                    if (parent2 !== previousToken.parent && !parent2.initializer && findChildOfKind(parent2, 64 /* EqualsToken */, sourceFile)) {
                                        isJsxInitializer = previousToken;
                                    }
                            }
                            break;
                    }
                }
            }
            const semanticStart = timestamp();
            let completionKind = 5 /* None */;
            let hasUnresolvedAutoImports = false;
            let symbols = [];
            let importSpecifierResolver;
            const symbolToOriginInfoMap = [];
            const symbolToSortTextMap = [];
            const seenPropertySymbols = /* @__PURE__ */ new Map();
            const isTypeOnlyLocation = isTypeOnlyCompletion();
            const getModuleSpecifierResolutionHost = memoizeOne((isFromPackageJson) => {
                return createModuleSpecifierResolutionHost(isFromPackageJson ? host.getPackageJsonAutoImportProvider() : program, host);
            });
            if (isRightOfDot || isRightOfQuestionDot) {
                getTypeScriptMemberSymbols();
            }
            else if (isRightOfOpenTag) {
                symbols = typeChecker.getJsxIntrinsicTagNamesAt(location);
                Debug.assertEachIsDefined(symbols, "getJsxIntrinsicTagNames() should all be defined");
                tryGetGlobalSymbols();
                completionKind = 1 /* Global */;
                keywordFilters = 0 /* None */;
            }
            else if (isStartingCloseTag) {
                const tagName = contextToken.parent.parent.openingElement.tagName;
                const tagSymbol = typeChecker.getSymbolAtLocation(tagName);
                if (tagSymbol) {
                    symbols = [tagSymbol];
                }
                completionKind = 1 /* Global */;
                keywordFilters = 0 /* None */;
            }
            else {
                if (!tryGetGlobalSymbols()) {
                    return keywordFilters ? keywordCompletionData(keywordFilters, isJsOnlyLocation, isNewIdentifierLocation) : void 0;
                }
            }
            log("getCompletionData: Semantic work: " + (timestamp() - semanticStart));
            const contextualType = previousToken && getContextualType(previousToken, position, sourceFile, typeChecker);
            const isLiteralExpected = !tryCast(previousToken, isStringLiteralLike) && !isJsxIdentifierExpected;
            const literals = !isLiteralExpected ? [] : mapDefined(contextualType && (contextualType.isUnion() ? contextualType.types : [contextualType]), (t) => t.isLiteral() && !(t.flags & 1024 /* EnumLiteral */) ? t.value : void 0);
            const recommendedCompletion = previousToken && contextualType && getRecommendedCompletion(previousToken, contextualType, typeChecker);
            return {
                kind: 0 /* Data */,
                symbols,
                completionKind,
                isInSnippetScope,
                propertyAccessToConvert,
                isNewIdentifierLocation,
                location,
                keywordFilters,
                literals,
                symbolToOriginInfoMap,
                recommendedCompletion,
                previousToken,
                contextToken,
                isJsxInitializer,
                insideJsDocTagTypeExpression,
                symbolToSortTextMap,
                isTypeOnlyLocation,
                isJsxIdentifierExpected,
                isRightOfOpenTag,
                isRightOfDotOrQuestionDot: isRightOfDot || isRightOfQuestionDot,
                importStatementCompletion,
                hasUnresolvedAutoImports,
                flags
            };
            function isTagWithTypeExpression(tag) {
                switch (tag.kind) {
                    case 348 /* JSDocParameterTag */:
                    case 355 /* JSDocPropertyTag */:
                    case 349 /* JSDocReturnTag */:
                    case 351 /* JSDocTypeTag */:
                    case 353 /* JSDocTypedefTag */:
                    case 356 /* JSDocThrowsTag */:
                    case 357 /* JSDocSatisfiesTag */:
                        return true;
                    case 352 /* JSDocTemplateTag */:
                        return !!tag.constraint;
                    default:
                        return false;
                }
            }
            function tryGetTypeExpressionFromTag(tag) {
                if (isTagWithTypeExpression(tag)) {
                    const typeExpression = isJSDocTemplateTag(tag) ? tag.constraint : tag.typeExpression;
                    return typeExpression && typeExpression.kind === 316 /* JSDocTypeExpression */ ? typeExpression : void 0;
                }
                if (isJSDocAugmentsTag(tag) || isJSDocImplementsTag(tag)) {
                    return tag.class;
                }
                return void 0;
            }
            function getTypeScriptMemberSymbols() {
                completionKind = 2 /* PropertyAccess */;
                const isImportType = isLiteralImportTypeNode(node);
                const isTypeLocation = isImportType && !node.isTypeOf || isPartOfTypeNode(node.parent) || isPossiblyTypeArgumentPosition(contextToken, sourceFile, typeChecker);
                const isRhsOfImportDeclaration = isInRightSideOfInternalImportEqualsDeclaration(node);
                if (isEntityName(node) || isImportType || isPropertyAccessExpression(node)) {
                    const isNamespaceName = isModuleDeclaration(node.parent);
                    if (isNamespaceName)
                        isNewIdentifierLocation = true;
                    let symbol = typeChecker.getSymbolAtLocation(node);
                    if (symbol) {
                        symbol = skipAlias(symbol, typeChecker);
                        if (symbol.flags & (1536 /* Module */ | 384 /* Enum */)) {
                            const exportedSymbols = typeChecker.getExportsOfModule(symbol);
                            Debug.assertEachIsDefined(exportedSymbols, "getExportsOfModule() should all be defined");
                            const isValidValueAccess = (symbol2) => typeChecker.isValidPropertyAccess(isImportType ? node : node.parent, symbol2.name);
                            const isValidTypeAccess = (symbol2) => symbolCanBeReferencedAtTypeLocation(symbol2, typeChecker);
                            const isValidAccess = isNamespaceName ? (symbol2) => {
                                var _a;
                                return !!(symbol2.flags & 1920 /* Namespace */) && !((_a = symbol2.declarations) == null ? void 0 : _a.every((d) => d.parent === node.parent));
                            } : isRhsOfImportDeclaration ? (
                            // Any kind is allowed when dotting off namespace in internal import equals declaration
                            (symbol2) => isValidTypeAccess(symbol2) || isValidValueAccess(symbol2)) : isTypeLocation || insideJsDocTagTypeExpression ? isValidTypeAccess : isValidValueAccess;
                            for (const exportedSymbol of exportedSymbols) {
                                if (isValidAccess(exportedSymbol)) {
                                    symbols.push(exportedSymbol);
                                }
                            }
                            if (!isTypeLocation && !insideJsDocTagTypeExpression && symbol.declarations && symbol.declarations.some((d) => d.kind !== 312 /* SourceFile */ && d.kind !== 267 /* ModuleDeclaration */ && d.kind !== 266 /* EnumDeclaration */)) {
                                let type = typeChecker.getTypeOfSymbolAtLocation(symbol, node).getNonOptionalType();
                                let insertQuestionDot = false;
                                if (type.isNullableType()) {
                                    const canCorrectToQuestionDot = isRightOfDot && !isRightOfQuestionDot && preferences.includeAutomaticOptionalChainCompletions !== false;
                                    if (canCorrectToQuestionDot || isRightOfQuestionDot) {
                                        type = type.getNonNullableType();
                                        if (canCorrectToQuestionDot) {
                                            insertQuestionDot = true;
                                        }
                                    }
                                }
                                addTypeProperties(type, !!(node.flags & 65536 /* AwaitContext */), insertQuestionDot);
                            }
                            return;
                        }
                    }
                }
                if (!isTypeLocation || isInTypeQuery(node)) {
                    typeChecker.tryGetThisTypeAt(node, 
                    /*includeGlobalThis*/
                    false);
                    let type = typeChecker.getTypeAtLocation(node).getNonOptionalType();
                    if (!isTypeLocation) {
                        let insertQuestionDot = false;
                        if (type.isNullableType()) {
                            const canCorrectToQuestionDot = isRightOfDot && !isRightOfQuestionDot && preferences.includeAutomaticOptionalChainCompletions !== false;
                            if (canCorrectToQuestionDot || isRightOfQuestionDot) {
                                type = type.getNonNullableType();
                                if (canCorrectToQuestionDot) {
                                    insertQuestionDot = true;
                                }
                            }
                        }
                        addTypeProperties(type, !!(node.flags & 65536 /* AwaitContext */), insertQuestionDot);
                    }
                    else {
                        addTypeProperties(type.getNonNullableType(), 
                        /*insertAwait*/
                        false, 
                        /*insertQuestionDot*/
                        false);
                    }
                }
            }
            function addTypeProperties(type, insertAwait, insertQuestionDot) {
                isNewIdentifierLocation = !!type.getStringIndexType();
                if (isRightOfQuestionDot && some(type.getCallSignatures())) {
                    isNewIdentifierLocation = true;
                }
                const propertyAccess = node.kind === 205 /* ImportType */ ? node : node.parent;
                if (inCheckedFile) {
                    for (const symbol of type.getApparentProperties()) {
                        if (typeChecker.isValidPropertyAccessForCompletions(propertyAccess, type, symbol)) {
                            addPropertySymbol(symbol, 
                            /*insertAwait*/
                            false, insertQuestionDot);
                        }
                    }
                }
                else {
                    symbols.push(...filter(getPropertiesForCompletion(type, typeChecker), (s) => typeChecker.isValidPropertyAccessForCompletions(propertyAccess, type, s)));
                }
                if (insertAwait && preferences.includeCompletionsWithInsertText) {
                    const promiseType = typeChecker.getPromisedTypeOfPromise(type);
                    if (promiseType) {
                        for (const symbol of promiseType.getApparentProperties()) {
                            if (typeChecker.isValidPropertyAccessForCompletions(propertyAccess, promiseType, symbol)) {
                                addPropertySymbol(symbol, 
                                /*insertAwait*/
                                true, insertQuestionDot);
                            }
                        }
                    }
                }
            }
            function addPropertySymbol(symbol, insertAwait, insertQuestionDot) {
                var _a;
                const computedPropertyName = firstDefined(symbol.declarations, (decl) => tryCast(getNameOfDeclaration(decl), isComputedPropertyName));
                if (computedPropertyName) {
                    const leftMostName = getLeftMostName(computedPropertyName.expression);
                    const nameSymbol = leftMostName && typeChecker.getSymbolAtLocation(leftMostName);
                    const firstAccessibleSymbol = nameSymbol && getFirstSymbolInChain(nameSymbol, contextToken, typeChecker);
                    const firstAccessibleSymbolId = firstAccessibleSymbol && getSymbolId(firstAccessibleSymbol);
                    if (firstAccessibleSymbolId && addToSeen(seenPropertySymbols, firstAccessibleSymbolId)) {
                        const index = symbols.length;
                        symbols.push(firstAccessibleSymbol);
                        const moduleSymbol = firstAccessibleSymbol.parent;
                        if (!moduleSymbol || !isExternalModuleSymbol(moduleSymbol) || typeChecker.tryGetMemberInModuleExportsAndProperties(firstAccessibleSymbol.name, moduleSymbol) !== firstAccessibleSymbol) {
                            symbolToOriginInfoMap[index] = { kind: getNullableSymbolOriginInfoKind(2 /* SymbolMemberNoExport */) };
                        }
                        else {
                            const fileName = isExternalModuleNameRelative(stripQuotes(moduleSymbol.name)) ? (_a = getSourceFileOfModule(moduleSymbol)) == null ? void 0 : _a.fileName : void 0;
                            const { moduleSpecifier } = (importSpecifierResolver || (importSpecifierResolver = ts_codefix_exports.createImportSpecifierResolver(sourceFile, program, host, preferences))).getModuleSpecifierForBestExportInfo([{
                                    exportKind: 0 /* Named */,
                                    moduleFileName: fileName,
                                    isFromPackageJson: false,
                                    moduleSymbol,
                                    symbol: firstAccessibleSymbol,
                                    targetFlags: skipAlias(firstAccessibleSymbol, typeChecker).flags
                                }], position, isValidTypeOnlyAliasUseSite(location)) || {};
                            if (moduleSpecifier) {
                                const origin = {
                                    kind: getNullableSymbolOriginInfoKind(6 /* SymbolMemberExport */),
                                    moduleSymbol,
                                    isDefaultExport: false,
                                    symbolName: firstAccessibleSymbol.name,
                                    exportName: firstAccessibleSymbol.name,
                                    fileName,
                                    moduleSpecifier
                                };
                                symbolToOriginInfoMap[index] = origin;
                            }
                        }
                    }
                    else if (preferences.includeCompletionsWithInsertText) {
                        if (firstAccessibleSymbolId && seenPropertySymbols.has(firstAccessibleSymbolId)) {
                            return;
                        }
                        addSymbolOriginInfo(symbol);
                        addSymbolSortInfo(symbol);
                        symbols.push(symbol);
                    }
                }
                else {
                    addSymbolOriginInfo(symbol);
                    addSymbolSortInfo(symbol);
                    symbols.push(symbol);
                }
                function addSymbolSortInfo(symbol2) {
                    if (isStaticProperty(symbol2)) {
                        symbolToSortTextMap[getSymbolId(symbol2)] = SortText.LocalDeclarationPriority;
                    }
                }
                function addSymbolOriginInfo(symbol2) {
                    if (preferences.includeCompletionsWithInsertText) {
                        if (insertAwait && addToSeen(seenPropertySymbols, getSymbolId(symbol2))) {
                            symbolToOriginInfoMap[symbols.length] = { kind: getNullableSymbolOriginInfoKind(8 /* Promise */) };
                        }
                        else if (insertQuestionDot) {
                            symbolToOriginInfoMap[symbols.length] = { kind: 16 /* Nullable */ };
                        }
                    }
                }
                function getNullableSymbolOriginInfoKind(kind) {
                    return insertQuestionDot ? kind | 16 /* Nullable */ : kind;
                }
            }
            function getLeftMostName(e) {
                return isIdentifier(e) ? e : isPropertyAccessExpression(e) ? getLeftMostName(e.expression) : void 0;
            }
            function tryGetGlobalSymbols() {
                const result = tryGetObjectTypeLiteralInTypeArgumentCompletionSymbols() || tryGetObjectLikeCompletionSymbols() || tryGetImportCompletionSymbols() || tryGetImportOrExportClauseCompletionSymbols() || tryGetImportAttributesCompletionSymbols() || tryGetLocalNamedExportCompletionSymbols() || tryGetConstructorCompletion() || tryGetClassLikeCompletionSymbols() || tryGetJsxCompletionSymbols() || (getGlobalCompletions(), 1 /* Success */);
                return result === 1 /* Success */;
            }
            function tryGetConstructorCompletion() {
                if (!tryGetConstructorLikeCompletionContainer(contextToken))
                    return 0 /* Continue */;
                completionKind = 5 /* None */;
                isNewIdentifierLocation = true;
                keywordFilters = 4 /* ConstructorParameterKeywords */;
                return 1 /* Success */;
            }
            function tryGetJsxCompletionSymbols() {
                const jsxContainer = tryGetContainingJsxElement(contextToken);
                const attrsType = jsxContainer && typeChecker.getContextualType(jsxContainer.attributes);
                if (!attrsType)
                    return 0 /* Continue */;
                const completionsType = jsxContainer && typeChecker.getContextualType(jsxContainer.attributes, 4 /* Completions */);
                symbols = concatenate(symbols, filterJsxAttributes(getPropertiesForObjectExpression(attrsType, completionsType, jsxContainer.attributes, typeChecker), jsxContainer.attributes.properties));
                setSortTextToOptionalMember();
                completionKind = 3 /* MemberLike */;
                isNewIdentifierLocation = false;
                return 1 /* Success */;
            }
            function tryGetImportCompletionSymbols() {
                if (!importStatementCompletion)
                    return 0 /* Continue */;
                isNewIdentifierLocation = true;
                collectAutoImports();
                return 1 /* Success */;
            }
            function getGlobalCompletions() {
                keywordFilters = tryGetFunctionLikeBodyCompletionContainer(contextToken) ? 5 /* FunctionLikeBodyKeywords */ : 1 /* All */;
                completionKind = 1 /* Global */;
                isNewIdentifierLocation = isNewIdentifierDefinitionLocation();
                if (previousToken !== contextToken) {
                    Debug.assert(!!previousToken, "Expected 'contextToken' to be defined when different from 'previousToken'.");
                }
                const adjustedPosition = previousToken !== contextToken ? previousToken.getStart() : position;
                const scopeNode = getScopeNode(contextToken, adjustedPosition, sourceFile) || sourceFile;
                isInSnippetScope = isSnippetScope(scopeNode);
                const symbolMeanings = (isTypeOnlyLocation ? 0 /* None */ : 111551 /* Value */) | 788968 /* Type */ | 1920 /* Namespace */ | 2097152 /* Alias */;
                const typeOnlyAliasNeedsPromotion = previousToken && !isValidTypeOnlyAliasUseSite(previousToken);
                symbols = concatenate(symbols, typeChecker.getSymbolsInScope(scopeNode, symbolMeanings));
                Debug.assertEachIsDefined(symbols, "getSymbolsInScope() should all be defined");
                for (let i = 0; i < symbols.length; i++) {
                    const symbol = symbols[i];
                    if (!typeChecker.isArgumentsSymbol(symbol) && !some(symbol.declarations, (d) => d.getSourceFile() === sourceFile)) {
                        symbolToSortTextMap[getSymbolId(symbol)] = SortText.GlobalsOrKeywords;
                    }
                    if (typeOnlyAliasNeedsPromotion && !(symbol.flags & 111551 /* Value */)) {
                        const typeOnlyAliasDeclaration = symbol.declarations && find(symbol.declarations, isTypeOnlyImportDeclaration);
                        if (typeOnlyAliasDeclaration) {
                            const origin = { kind: 64 /* TypeOnlyAlias */, declaration: typeOnlyAliasDeclaration };
                            symbolToOriginInfoMap[i] = origin;
                        }
                    }
                }
                if (preferences.includeCompletionsWithInsertText && scopeNode.kind !== 312 /* SourceFile */) {
                    const thisType = typeChecker.tryGetThisTypeAt(scopeNode, 
                    /*includeGlobalThis*/
                    false, isClassLike(scopeNode.parent) ? scopeNode : void 0);
                    if (thisType && !isProbablyGlobalType(thisType, sourceFile, typeChecker)) {
                        for (const symbol of getPropertiesForCompletion(thisType, typeChecker)) {
                            symbolToOriginInfoMap[symbols.length] = { kind: 1 /* ThisType */ };
                            symbols.push(symbol);
                            symbolToSortTextMap[getSymbolId(symbol)] = SortText.SuggestedClassMembers;
                        }
                    }
                }
                collectAutoImports();
                if (isTypeOnlyLocation) {
                    keywordFilters = contextToken && isAssertionExpression(contextToken.parent) ? 6 /* TypeAssertionKeywords */ : 7 /* TypeKeywords */;
                }
            }
            function shouldOfferImportCompletions() {
                if (importStatementCompletion)
                    return true;
                if (!preferences.includeCompletionsForModuleExports)
                    return false;
                if (sourceFile.externalModuleIndicator || sourceFile.commonJsModuleIndicator)
                    return true;
                if (compilerOptionsIndicateEsModules(program.getCompilerOptions()))
                    return true;
                return programContainsModules(program);
            }
            function isSnippetScope(scopeNode) {
                switch (scopeNode.kind) {
                    case 312 /* SourceFile */:
                    case 228 /* TemplateExpression */:
                    case 294 /* JsxExpression */:
                    case 241 /* Block */:
                        return true;
                    default:
                        return isStatement(scopeNode);
                }
            }
            function isTypeOnlyCompletion() {
                return insideJsDocTagTypeExpression || !!importStatementCompletion && isTypeOnlyImportOrExportDeclaration(location.parent) || !isContextTokenValueLocation(contextToken) && (isPossiblyTypeArgumentPosition(contextToken, sourceFile, typeChecker) || isPartOfTypeNode(location) || isContextTokenTypeLocation(contextToken));
            }
            function isContextTokenValueLocation(contextToken2) {
                return contextToken2 && (contextToken2.kind === 114 /* TypeOfKeyword */ && (contextToken2.parent.kind === 186 /* TypeQuery */ || isTypeOfExpression(contextToken2.parent)) || contextToken2.kind === 131 /* AssertsKeyword */ && contextToken2.parent.kind === 182 /* TypePredicate */);
            }
            function isContextTokenTypeLocation(contextToken2) {
                if (contextToken2) {
                    const parentKind = contextToken2.parent.kind;
                    switch (contextToken2.kind) {
                        case 59 /* ColonToken */:
                            return parentKind === 172 /* PropertyDeclaration */ || parentKind === 171 /* PropertySignature */ || parentKind === 169 /* Parameter */ || parentKind === 260 /* VariableDeclaration */ || isFunctionLikeKind(parentKind);
                        case 64 /* EqualsToken */:
                            return parentKind === 265 /* TypeAliasDeclaration */ || parentKind === 168 /* TypeParameter */;
                        case 130 /* AsKeyword */:
                            return parentKind === 234 /* AsExpression */;
                        case 30 /* LessThanToken */:
                            return parentKind === 183 /* TypeReference */ || parentKind === 216 /* TypeAssertionExpression */;
                        case 96 /* ExtendsKeyword */:
                            return parentKind === 168 /* TypeParameter */;
                        case 152 /* SatisfiesKeyword */:
                            return parentKind === 238 /* SatisfiesExpression */;
                    }
                }
                return false;
            }
            function collectAutoImports() {
                var _a, _b;
                if (!shouldOfferImportCompletions())
                    return;
                Debug.assert(!(detailsEntryId == null ? void 0 : detailsEntryId.data), "Should not run 'collectAutoImports' when faster path is available via `data`");
                if (detailsEntryId && !detailsEntryId.source) {
                    return;
                }
                flags |= 1 /* MayIncludeAutoImports */;
                const isAfterTypeOnlyImportSpecifierModifier = previousToken === contextToken && importStatementCompletion;
                const lowerCaseTokenText = isAfterTypeOnlyImportSpecifierModifier ? "" : previousToken && isIdentifier(previousToken) ? previousToken.text.toLowerCase() : "";
                const moduleSpecifierCache = (_a = host.getModuleSpecifierCache) == null ? void 0 : _a.call(host);
                const exportInfo = getExportInfoMap(sourceFile, host, program, preferences, cancellationToken);
                const packageJsonAutoImportProvider = (_b = host.getPackageJsonAutoImportProvider) == null ? void 0 : _b.call(host);
                const packageJsonFilter = detailsEntryId ? void 0 : createPackageJsonImportFilter(sourceFile, preferences, host);
                resolvingModuleSpecifiers("collectAutoImports", host, importSpecifierResolver || (importSpecifierResolver = ts_codefix_exports.createImportSpecifierResolver(sourceFile, program, host, preferences)), program, position, preferences, !!importStatementCompletion, isValidTypeOnlyAliasUseSite(location), (context) => {
                    exportInfo.search(sourceFile.path, 
                    /*preferCapitalized*/
                    isRightOfOpenTag, (symbolName2, targetFlags) => {
                        if (!isIdentifierText(symbolName2, getEmitScriptTarget(host.getCompilationSettings())))
                            return false;
                        if (!detailsEntryId && isStringANonContextualKeyword(symbolName2))
                            return false;
                        if (!isTypeOnlyLocation && !importStatementCompletion && !(targetFlags & 111551 /* Value */))
                            return false;
                        if (isTypeOnlyLocation && !(targetFlags & (1536 /* Module */ | 788968 /* Type */)))
                            return false;
                        const firstChar = symbolName2.charCodeAt(0);
                        if (isRightOfOpenTag && (firstChar < 65 /* A */ || firstChar > 90 /* Z */))
                            return false;
                        if (detailsEntryId)
                            return true;
                        return charactersFuzzyMatchInString(symbolName2, lowerCaseTokenText);
                    }, (info, symbolName2, isFromAmbientModule, exportMapKey) => {
                        if (detailsEntryId && !some(info, (i) => detailsEntryId.source === stripQuotes(i.moduleSymbol.name))) {
                            return;
                        }
                        info = filter(info, isImportableExportInfo);
                        if (!info.length) {
                            return;
                        }
                        const result = context.tryResolve(info, isFromAmbientModule) || {};
                        if (result === "failed")
                            return;
                        let exportInfo2 = info[0], moduleSpecifier;
                        if (result !== "skipped") {
                            ({ exportInfo: exportInfo2 = info[0], moduleSpecifier } = result);
                        }
                        const isDefaultExport = exportInfo2.exportKind === 1 /* Default */;
                        const symbol = isDefaultExport && getLocalSymbolForExportDefault(exportInfo2.symbol) || exportInfo2.symbol;
                        pushAutoImportSymbol(symbol, {
                            kind: moduleSpecifier ? 32 /* ResolvedExport */ : 4 /* Export */,
                            moduleSpecifier,
                            symbolName: symbolName2,
                            exportMapKey,
                            exportName: exportInfo2.exportKind === 2 /* ExportEquals */ ? "export=" /* ExportEquals */ : exportInfo2.symbol.name,
                            fileName: exportInfo2.moduleFileName,
                            isDefaultExport,
                            moduleSymbol: exportInfo2.moduleSymbol,
                            isFromPackageJson: exportInfo2.isFromPackageJson
                        });
                    });
                    hasUnresolvedAutoImports = context.skippedAny();
                    flags |= context.resolvedAny() ? 8 /* ResolvedModuleSpecifiers */ : 0;
                    flags |= context.resolvedBeyondLimit() ? 16 /* ResolvedModuleSpecifiersBeyondLimit */ : 0;
                });
                function isImportableExportInfo(info) {
                    const moduleFile = tryCast(info.moduleSymbol.valueDeclaration, isSourceFile);
                    if (!moduleFile) {
                        const moduleName = stripQuotes(info.moduleSymbol.name);
                        if (ts_JsTyping_exports.nodeCoreModules.has(moduleName) && startsWith(moduleName, "node:") !== shouldUseUriStyleNodeCoreModules(sourceFile, program)) {
                            return false;
                        }
                        return packageJsonFilter ? packageJsonFilter.allowsImportingAmbientModule(info.moduleSymbol, getModuleSpecifierResolutionHost(info.isFromPackageJson)) : true;
                    }
                    return isImportableFile(info.isFromPackageJson ? packageJsonAutoImportProvider : program, sourceFile, moduleFile, preferences, packageJsonFilter, getModuleSpecifierResolutionHost(info.isFromPackageJson), moduleSpecifierCache);
                }
            }
            function pushAutoImportSymbol(symbol, origin) {
                const symbolId = getSymbolId(symbol);
                if (symbolToSortTextMap[symbolId] === SortText.GlobalsOrKeywords) {
                    return;
                }
                symbolToOriginInfoMap[symbols.length] = origin;
                symbolToSortTextMap[symbolId] = importStatementCompletion ? SortText.LocationPriority : SortText.AutoImportSuggestions;
                symbols.push(symbol);
            }
            function collectObjectLiteralMethodSymbols(members, enclosingDeclaration) {
                if (isInJSFile(location)) {
                    return;
                }
                members.forEach((member) => {
                    if (!isObjectLiteralMethodSymbol(member)) {
                        return;
                    }
                    const displayName = getCompletionEntryDisplayNameForSymbol(member, getEmitScriptTarget(compilerOptions), 
                    /*origin*/
                    void 0, 0 /* ObjectPropertyDeclaration */, 
                    /*jsxIdentifierExpected*/
                    false);
                    if (!displayName) {
                        return;
                    }
                    const { name } = displayName;
                    const entryProps = getEntryForObjectLiteralMethodCompletion(member, name, enclosingDeclaration, program, host, compilerOptions, preferences, formatContext);
                    if (!entryProps) {
                        return;
                    }
                    const origin = { kind: 128 /* ObjectLiteralMethod */, ...entryProps };
                    flags |= 32 /* MayIncludeMethodSnippets */;
                    symbolToOriginInfoMap[symbols.length] = origin;
                    symbols.push(member);
                });
            }
            function isObjectLiteralMethodSymbol(symbol) {
                if (!(symbol.flags & (4 /* Property */ | 8192 /* Method */))) {
                    return false;
                }
                return true;
            }
            function getScopeNode(initialToken, position2, sourceFile2) {
                let scope = initialToken;
                while (scope && !positionBelongsToNode(scope, position2, sourceFile2)) {
                    scope = scope.parent;
                }
                return scope;
            }
            function isCompletionListBlocker(contextToken2) {
                const start2 = timestamp();
                const result = isInStringOrRegularExpressionOrTemplateLiteral(contextToken2) || isSolelyIdentifierDefinitionLocation(contextToken2) || isDotOfNumericLiteral(contextToken2) || isInJsxText(contextToken2) || isBigIntLiteral(contextToken2);
                log("getCompletionsAtPosition: isCompletionListBlocker: " + (timestamp() - start2));
                return result;
            }
            function isInJsxText(contextToken2) {
                if (contextToken2.kind === 12 /* JsxText */) {
                    return true;
                }
                if (contextToken2.kind === 32 /* GreaterThanToken */ && contextToken2.parent) {
                    if (location === contextToken2.parent && (location.kind === 286 /* JsxOpeningElement */ || location.kind === 285 /* JsxSelfClosingElement */)) {
                        return false;
                    }
                    if (contextToken2.parent.kind === 286 /* JsxOpeningElement */) {
                        return location.parent.kind !== 286 /* JsxOpeningElement */;
                    }
                    if (contextToken2.parent.kind === 287 /* JsxClosingElement */ || contextToken2.parent.kind === 285 /* JsxSelfClosingElement */) {
                        return !!contextToken2.parent.parent && contextToken2.parent.parent.kind === 284 /* JsxElement */;
                    }
                }
                return false;
            }
            function isNewIdentifierDefinitionLocation() {
                if (contextToken) {
                    const containingNodeKind = contextToken.parent.kind;
                    const tokenKind = keywordForNode(contextToken);
                    switch (tokenKind) {
                        case 28 /* CommaToken */:
                            return containingNodeKind === 213 /* CallExpression */ || containingNodeKind === 176 /* Constructor */ || containingNodeKind === 214 /* NewExpression */ || containingNodeKind === 209 /* ArrayLiteralExpression */ || containingNodeKind === 226 /* BinaryExpression */ || containingNodeKind === 184 /* FunctionType */ || containingNodeKind === 210 /* ObjectLiteralExpression */;
                        case 21 /* OpenParenToken */:
                            return containingNodeKind === 213 /* CallExpression */ || containingNodeKind === 176 /* Constructor */ || containingNodeKind === 214 /* NewExpression */ || containingNodeKind === 217 /* ParenthesizedExpression */ || containingNodeKind === 196 /* ParenthesizedType */;
                        case 23 /* OpenBracketToken */:
                            return containingNodeKind === 209 /* ArrayLiteralExpression */ || containingNodeKind === 181 /* IndexSignature */ || containingNodeKind === 167 /* ComputedPropertyName */;
                        case 144 /* ModuleKeyword */:
                        case 145 /* NamespaceKeyword */:
                        case 102 /* ImportKeyword */:
                            return true;
                        case 25 /* DotToken */:
                            return containingNodeKind === 267 /* ModuleDeclaration */;
                        case 19 /* OpenBraceToken */:
                            return containingNodeKind === 263 /* ClassDeclaration */ || containingNodeKind === 210 /* ObjectLiteralExpression */;
                        case 64 /* EqualsToken */:
                            return containingNodeKind === 260 /* VariableDeclaration */ || containingNodeKind === 226 /* BinaryExpression */;
                        case 16 /* TemplateHead */:
                            return containingNodeKind === 228 /* TemplateExpression */;
                        case 17 /* TemplateMiddle */:
                            return containingNodeKind === 239 /* TemplateSpan */;
                        case 134 /* AsyncKeyword */:
                            return containingNodeKind === 174 /* MethodDeclaration */ || containingNodeKind === 304 /* ShorthandPropertyAssignment */;
                        case 42 /* AsteriskToken */:
                            return containingNodeKind === 174 /* MethodDeclaration */;
                    }
                    if (isClassMemberCompletionKeyword(tokenKind)) {
                        return true;
                    }
                }
                return false;
            }
            function isInStringOrRegularExpressionOrTemplateLiteral(contextToken2) {
                return (isRegularExpressionLiteral(contextToken2) || isStringTextContainingNode(contextToken2)) && (rangeContainsPositionExclusive(contextToken2, position) || position === contextToken2.end && (!!contextToken2.isUnterminated || isRegularExpressionLiteral(contextToken2)));
            }
            function tryGetObjectTypeLiteralInTypeArgumentCompletionSymbols() {
                const typeLiteralNode = tryGetTypeLiteralNode(contextToken);
                if (!typeLiteralNode)
                    return 0 /* Continue */;
                const intersectionTypeNode = isIntersectionTypeNode(typeLiteralNode.parent) ? typeLiteralNode.parent : void 0;
                const containerTypeNode = intersectionTypeNode || typeLiteralNode;
                const containerExpectedType = getConstraintOfTypeArgumentProperty(containerTypeNode, typeChecker);
                if (!containerExpectedType)
                    return 0 /* Continue */;
                const containerActualType = typeChecker.getTypeFromTypeNode(containerTypeNode);
                const members = getPropertiesForCompletion(containerExpectedType, typeChecker);
                const existingMembers = getPropertiesForCompletion(containerActualType, typeChecker);
                const existingMemberEscapedNames = /* @__PURE__ */ new Set();
                existingMembers.forEach((s) => existingMemberEscapedNames.add(s.escapedName));
                symbols = concatenate(symbols, filter(members, (s) => !existingMemberEscapedNames.has(s.escapedName)));
                completionKind = 0 /* ObjectPropertyDeclaration */;
                isNewIdentifierLocation = true;
                return 1 /* Success */;
            }
            function tryGetObjectLikeCompletionSymbols() {
                const symbolsStartIndex = symbols.length;
                const objectLikeContainer = tryGetObjectLikeCompletionContainer(contextToken, position, sourceFile);
                if (!objectLikeContainer)
                    return 0 /* Continue */;
                completionKind = 0 /* ObjectPropertyDeclaration */;
                let typeMembers;
                let existingMembers;
                if (objectLikeContainer.kind === 210 /* ObjectLiteralExpression */) {
                    const instantiatedType = tryGetObjectLiteralContextualType(objectLikeContainer, typeChecker);
                    if (instantiatedType === void 0) {
                        if (objectLikeContainer.flags & 67108864 /* InWithStatement */) {
                            return 2 /* Fail */;
                        }
                        return 0 /* Continue */;
                    }
                    const completionsType = typeChecker.getContextualType(objectLikeContainer, 4 /* Completions */);
                    const hasStringIndexType = (completionsType || instantiatedType).getStringIndexType();
                    const hasNumberIndextype = (completionsType || instantiatedType).getNumberIndexType();
                    isNewIdentifierLocation = !!hasStringIndexType || !!hasNumberIndextype;
                    typeMembers = getPropertiesForObjectExpression(instantiatedType, completionsType, objectLikeContainer, typeChecker);
                    existingMembers = objectLikeContainer.properties;
                    if (typeMembers.length === 0) {
                        if (!hasNumberIndextype) {
                            return 0 /* Continue */;
                        }
                    }
                }
                else {
                    Debug.assert(objectLikeContainer.kind === 206 /* ObjectBindingPattern */);
                    isNewIdentifierLocation = false;
                    const rootDeclaration = getRootDeclaration(objectLikeContainer.parent);
                    if (!isVariableLike(rootDeclaration))
                        return Debug.fail("Root declaration is not variable-like.");
                    let canGetType = hasInitializer(rootDeclaration) || !!getEffectiveTypeAnnotationNode(rootDeclaration) || rootDeclaration.parent.parent.kind === 250 /* ForOfStatement */;
                    if (!canGetType && rootDeclaration.kind === 169 /* Parameter */) {
                        if (isExpression(rootDeclaration.parent)) {
                            canGetType = !!typeChecker.getContextualType(rootDeclaration.parent);
                        }
                        else if (rootDeclaration.parent.kind === 174 /* MethodDeclaration */ || rootDeclaration.parent.kind === 178 /* SetAccessor */) {
                            canGetType = isExpression(rootDeclaration.parent.parent) && !!typeChecker.getContextualType(rootDeclaration.parent.parent);
                        }
                    }
                    if (canGetType) {
                        const typeForObject = typeChecker.getTypeAtLocation(objectLikeContainer);
                        if (!typeForObject)
                            return 2 /* Fail */;
                        typeMembers = typeChecker.getPropertiesOfType(typeForObject).filter((propertySymbol) => {
                            return typeChecker.isPropertyAccessible(objectLikeContainer, 
                            /*isSuper*/
                            false, 
                            /*isWrite*/
                            false, typeForObject, propertySymbol);
                        });
                        existingMembers = objectLikeContainer.elements;
                    }
                }
                if (typeMembers && typeMembers.length > 0) {
                    const filteredMembers = filterObjectMembersList(typeMembers, Debug.checkDefined(existingMembers));
                    symbols = concatenate(symbols, filteredMembers);
                    setSortTextToOptionalMember();
                    if (objectLikeContainer.kind === 210 /* ObjectLiteralExpression */ && preferences.includeCompletionsWithObjectLiteralMethodSnippets && preferences.includeCompletionsWithInsertText) {
                        transformObjectLiteralMembersSortText(symbolsStartIndex);
                        collectObjectLiteralMethodSymbols(filteredMembers, objectLikeContainer);
                    }
                }
                return 1 /* Success */;
            }
            function tryGetImportOrExportClauseCompletionSymbols() {
                if (!contextToken)
                    return 0 /* Continue */;
                const namedImportsOrExports = contextToken.kind === 19 /* OpenBraceToken */ || contextToken.kind === 28 /* CommaToken */ ? tryCast(contextToken.parent, isNamedImportsOrExports) : isTypeKeywordTokenOrIdentifier(contextToken) ? tryCast(contextToken.parent.parent, isNamedImportsOrExports) : void 0;
                if (!namedImportsOrExports)
                    return 0 /* Continue */;
                if (!isTypeKeywordTokenOrIdentifier(contextToken)) {
                    keywordFilters = 8 /* TypeKeyword */;
                }
                const { moduleSpecifier } = namedImportsOrExports.kind === 275 /* NamedImports */ ? namedImportsOrExports.parent.parent : namedImportsOrExports.parent;
                if (!moduleSpecifier) {
                    isNewIdentifierLocation = true;
                    return namedImportsOrExports.kind === 275 /* NamedImports */ ? 2 /* Fail */ : 0 /* Continue */;
                }
                const moduleSpecifierSymbol = typeChecker.getSymbolAtLocation(moduleSpecifier);
                if (!moduleSpecifierSymbol) {
                    isNewIdentifierLocation = true;
                    return 2 /* Fail */;
                }
                completionKind = 3 /* MemberLike */;
                isNewIdentifierLocation = false;
                const exports = typeChecker.getExportsAndPropertiesOfModule(moduleSpecifierSymbol);
                const existing = new Set(namedImportsOrExports.elements.filter((n) => !isCurrentlyEditingNode(n)).map((n) => (n.propertyName || n.name).escapedText));
                const uniques = exports.filter((e) => e.escapedName !== "default" /* Default */ && !existing.has(e.escapedName));
                symbols = concatenate(symbols, uniques);
                if (!uniques.length) {
                    keywordFilters = 0 /* None */;
                }
                return 1 /* Success */;
            }
            function tryGetImportAttributesCompletionSymbols() {
                if (contextToken === void 0)
                    return 0 /* Continue */;
                const importAttributes = contextToken.kind === 19 /* OpenBraceToken */ || contextToken.kind === 28 /* CommaToken */ ? tryCast(contextToken.parent, isImportAttributes) : contextToken.kind === 59 /* ColonToken */ ? tryCast(contextToken.parent.parent, isImportAttributes) : void 0;
                if (importAttributes === void 0)
                    return 0 /* Continue */;
                const existing = new Set(importAttributes.elements.map(getNameFromImportAttribute));
                symbols = filter(typeChecker.getTypeAtLocation(importAttributes).getApparentProperties(), (attr) => !existing.has(attr.escapedName));
                return 1 /* Success */;
            }
            function tryGetLocalNamedExportCompletionSymbols() {
                var _a;
                const namedExports = contextToken && (contextToken.kind === 19 /* OpenBraceToken */ || contextToken.kind === 28 /* CommaToken */) ? tryCast(contextToken.parent, isNamedExports) : void 0;
                if (!namedExports) {
                    return 0 /* Continue */;
                }
                const localsContainer = findAncestor(namedExports, or(isSourceFile, isModuleDeclaration));
                completionKind = 5 /* None */;
                isNewIdentifierLocation = false;
                (_a = localsContainer.locals) == null ? void 0 : _a.forEach((symbol, name) => {
                    var _a2, _b;
                    symbols.push(symbol);
                    if ((_b = (_a2 = localsContainer.symbol) == null ? void 0 : _a2.exports) == null ? void 0 : _b.has(name)) {
                        symbolToSortTextMap[getSymbolId(symbol)] = SortText.OptionalMember;
                    }
                });
                return 1 /* Success */;
            }
            function tryGetClassLikeCompletionSymbols() {
                const decl = tryGetObjectTypeDeclarationCompletionContainer(sourceFile, contextToken, location, position);
                if (!decl)
                    return 0 /* Continue */;
                completionKind = 3 /* MemberLike */;
                isNewIdentifierLocation = true;
                keywordFilters = contextToken.kind === 42 /* AsteriskToken */ ? 0 /* None */ : isClassLike(decl) ? 2 /* ClassElementKeywords */ : 3 /* InterfaceElementKeywords */;
                if (!isClassLike(decl))
                    return 1 /* Success */;
                const classElement = contextToken.kind === 27 /* SemicolonToken */ ? contextToken.parent.parent : contextToken.parent;
                let classElementModifierFlags = isClassElement(classElement) ? getEffectiveModifierFlags(classElement) : 0 /* None */;
                if (contextToken.kind === 80 /* Identifier */ && !isCurrentlyEditingNode(contextToken)) {
                    switch (contextToken.getText()) {
                        case "private":
                            classElementModifierFlags = classElementModifierFlags | 2 /* Private */;
                            break;
                        case "static":
                            classElementModifierFlags = classElementModifierFlags | 256 /* Static */;
                            break;
                        case "override":
                            classElementModifierFlags = classElementModifierFlags | 16 /* Override */;
                            break;
                    }
                }
                if (isClassStaticBlockDeclaration(classElement)) {
                    classElementModifierFlags |= 256 /* Static */;
                }
                if (!(classElementModifierFlags & 2 /* Private */)) {
                    const baseTypeNodes = isClassLike(decl) && classElementModifierFlags & 16 /* Override */ ? singleElementArray(getEffectiveBaseTypeNode(decl)) : getAllSuperTypeNodes(decl);
                    const baseSymbols = flatMap(baseTypeNodes, (baseTypeNode) => {
                        const type = typeChecker.getTypeAtLocation(baseTypeNode);
                        return classElementModifierFlags & 256 /* Static */ ? (type == null ? void 0 : type.symbol) && typeChecker.getPropertiesOfType(typeChecker.getTypeOfSymbolAtLocation(type.symbol, decl)) : type && typeChecker.getPropertiesOfType(type);
                    });
                    symbols = concatenate(symbols, filterClassMembersList(baseSymbols, decl.members, classElementModifierFlags));
                    forEach(symbols, (symbol, index) => {
                        const declaration = symbol == null ? void 0 : symbol.valueDeclaration;
                        if (declaration && isClassElement(declaration) && declaration.name && isComputedPropertyName(declaration.name)) {
                            const origin = {
                                kind: 512 /* ComputedPropertyName */,
                                symbolName: typeChecker.symbolToString(symbol)
                            };
                            symbolToOriginInfoMap[index] = origin;
                        }
                    });
                }
                return 1 /* Success */;
            }
            function isConstructorParameterCompletion(node2) {
                return !!node2.parent && isParameter(node2.parent) && isConstructorDeclaration(node2.parent.parent) && (isParameterPropertyModifier(node2.kind) || isDeclarationName(node2));
            }
            function tryGetConstructorLikeCompletionContainer(contextToken2) {
                if (contextToken2) {
                    const parent2 = contextToken2.parent;
                    switch (contextToken2.kind) {
                        case 21 /* OpenParenToken */:
                        case 28 /* CommaToken */:
                            return isConstructorDeclaration(contextToken2.parent) ? contextToken2.parent : void 0;
                        default:
                            if (isConstructorParameterCompletion(contextToken2)) {
                                return parent2.parent;
                            }
                    }
                }
                return void 0;
            }
            function tryGetFunctionLikeBodyCompletionContainer(contextToken2) {
                if (contextToken2) {
                    let prev;
                    const container = findAncestor(contextToken2.parent, (node2) => {
                        if (isClassLike(node2)) {
                            return "quit";
                        }
                        if (isFunctionLikeDeclaration(node2) && prev === node2.body) {
                            return true;
                        }
                        prev = node2;
                        return false;
                    });
                    return container && container;
                }
            }
            function tryGetContainingJsxElement(contextToken2) {
                if (contextToken2) {
                    const parent2 = contextToken2.parent;
                    switch (contextToken2.kind) {
                        case 32 /* GreaterThanToken */:
                        case 31 /* LessThanSlashToken */:
                        case 44 /* SlashToken */:
                        case 80 /* Identifier */:
                        case 211 /* PropertyAccessExpression */:
                        case 292 /* JsxAttributes */:
                        case 291 /* JsxAttribute */:
                        case 293 /* JsxSpreadAttribute */:
                            if (parent2 && (parent2.kind === 285 /* JsxSelfClosingElement */ || parent2.kind === 286 /* JsxOpeningElement */)) {
                                if (contextToken2.kind === 32 /* GreaterThanToken */) {
                                    const precedingToken = findPrecedingToken(contextToken2.pos, sourceFile, 
                                    /*startNode*/
                                    void 0);
                                    if (!parent2.typeArguments || precedingToken && precedingToken.kind === 44 /* SlashToken */)
                                        break;
                                }
                                return parent2;
                            }
                            else if (parent2.kind === 291 /* JsxAttribute */) {
                                return parent2.parent.parent;
                            }
                            break;
                        case 11 /* StringLiteral */:
                            if (parent2 && (parent2.kind === 291 /* JsxAttribute */ || parent2.kind === 293 /* JsxSpreadAttribute */)) {
                                return parent2.parent.parent;
                            }
                            break;
                        case 20 /* CloseBraceToken */:
                            if (parent2 && parent2.kind === 294 /* JsxExpression */ && parent2.parent && parent2.parent.kind === 291 /* JsxAttribute */) {
                                return parent2.parent.parent.parent;
                            }
                            if (parent2 && parent2.kind === 293 /* JsxSpreadAttribute */) {
                                return parent2.parent.parent;
                            }
                            break;
                    }
                }
                return void 0;
            }
            function isInDifferentLineThanContextToken(contextToken2, position2) {
                return sourceFile.getLineEndOfPosition(contextToken2.getEnd()) < position2;
            }
            function isSolelyIdentifierDefinitionLocation(contextToken2) {
                const parent2 = contextToken2.parent;
                const containingNodeKind = parent2.kind;
                switch (contextToken2.kind) {
                    case 28 /* CommaToken */:
                        return containingNodeKind === 260 /* VariableDeclaration */ || isVariableDeclarationListButNotTypeArgument(contextToken2) || containingNodeKind === 243 /* VariableStatement */ || containingNodeKind === 266 /* EnumDeclaration */ || // enum a { foo, |
                            isFunctionLikeButNotConstructor(containingNodeKind) || containingNodeKind === 264 /* InterfaceDeclaration */ || // interface A<T, |
                            containingNodeKind === 207 /* ArrayBindingPattern */ || // var [x, y|
                            containingNodeKind === 265 /* TypeAliasDeclaration */ || // type Map, K, |
                            // class A<T, |
                            // var C = class D<T, |
                            isClassLike(parent2) && !!parent2.typeParameters && parent2.typeParameters.end >= contextToken2.pos;
                    case 25 /* DotToken */:
                        return containingNodeKind === 207 /* ArrayBindingPattern */;
                    case 59 /* ColonToken */:
                        return containingNodeKind === 208 /* BindingElement */;
                    case 23 /* OpenBracketToken */:
                        return containingNodeKind === 207 /* ArrayBindingPattern */;
                    case 21 /* OpenParenToken */:
                        return containingNodeKind === 299 /* CatchClause */ || isFunctionLikeButNotConstructor(containingNodeKind);
                    case 19 /* OpenBraceToken */:
                        return containingNodeKind === 266 /* EnumDeclaration */;
                    case 30 /* LessThanToken */:
                        return containingNodeKind === 263 /* ClassDeclaration */ || // class A< |
                            containingNodeKind === 231 /* ClassExpression */ || // var C = class D< |
                            containingNodeKind === 264 /* InterfaceDeclaration */ || // interface A< |
                            containingNodeKind === 265 /* TypeAliasDeclaration */ || // type List< |
                            isFunctionLikeKind(containingNodeKind);
                    case 126 /* StaticKeyword */:
                        return containingNodeKind === 172 /* PropertyDeclaration */ && !isClassLike(parent2.parent);
                    case 26 /* DotDotDotToken */:
                        return containingNodeKind === 169 /* Parameter */ || !!parent2.parent && parent2.parent.kind === 207 /* ArrayBindingPattern */;
                    case 125 /* PublicKeyword */:
                    case 123 /* PrivateKeyword */:
                    case 124 /* ProtectedKeyword */:
                        return containingNodeKind === 169 /* Parameter */ && !isConstructorDeclaration(parent2.parent);
                    case 130 /* AsKeyword */:
                        return containingNodeKind === 276 /* ImportSpecifier */ || containingNodeKind === 281 /* ExportSpecifier */ || containingNodeKind === 274 /* NamespaceImport */;
                    case 139 /* GetKeyword */:
                    case 153 /* SetKeyword */:
                        return !isFromObjectTypeDeclaration(contextToken2);
                    case 80 /* Identifier */: {
                        if (containingNodeKind === 276 /* ImportSpecifier */ && contextToken2 === parent2.name && contextToken2.text === "type") {
                            return false;
                        }
                        const ancestorVariableDeclaration = findAncestor(contextToken2.parent, isVariableDeclaration);
                        if (ancestorVariableDeclaration && isInDifferentLineThanContextToken(contextToken2, position)) {
                            return false;
                        }
                        break;
                    }
                    case 86 /* ClassKeyword */:
                    case 94 /* EnumKeyword */:
                    case 120 /* InterfaceKeyword */:
                    case 100 /* FunctionKeyword */:
                    case 115 /* VarKeyword */:
                    case 102 /* ImportKeyword */:
                    case 121 /* LetKeyword */:
                    case 87 /* ConstKeyword */:
                    case 140 /* InferKeyword */:
                        return true;
                    case 156 /* TypeKeyword */:
                        return containingNodeKind !== 276 /* ImportSpecifier */;
                    case 42 /* AsteriskToken */:
                        return isFunctionLike(contextToken2.parent) && !isMethodDeclaration(contextToken2.parent);
                }
                if (isClassMemberCompletionKeyword(keywordForNode(contextToken2)) && isFromObjectTypeDeclaration(contextToken2)) {
                    return false;
                }
                if (isConstructorParameterCompletion(contextToken2)) {
                    if (!isIdentifier(contextToken2) || isParameterPropertyModifier(keywordForNode(contextToken2)) || isCurrentlyEditingNode(contextToken2)) {
                        return false;
                    }
                }
                switch (keywordForNode(contextToken2)) {
                    case 128 /* AbstractKeyword */:
                    case 86 /* ClassKeyword */:
                    case 87 /* ConstKeyword */:
                    case 138 /* DeclareKeyword */:
                    case 94 /* EnumKeyword */:
                    case 100 /* FunctionKeyword */:
                    case 120 /* InterfaceKeyword */:
                    case 121 /* LetKeyword */:
                    case 123 /* PrivateKeyword */:
                    case 124 /* ProtectedKeyword */:
                    case 125 /* PublicKeyword */:
                    case 126 /* StaticKeyword */:
                    case 115 /* VarKeyword */:
                        return true;
                    case 134 /* AsyncKeyword */:
                        return isPropertyDeclaration(contextToken2.parent);
                }
                const ancestorClassLike = findAncestor(contextToken2.parent, isClassLike);
                if (ancestorClassLike && contextToken2 === previousToken && isPreviousPropertyDeclarationTerminated(contextToken2, position)) {
                    return false;
                }
                const ancestorPropertyDeclaraion = getAncestor(contextToken2.parent, 172 /* PropertyDeclaration */);
                if (ancestorPropertyDeclaraion && contextToken2 !== previousToken && isClassLike(previousToken.parent.parent) && position <= previousToken.end) {
                    if (isPreviousPropertyDeclarationTerminated(contextToken2, previousToken.end)) {
                        return false;
                    }
                    else if (contextToken2.kind !== 64 /* EqualsToken */ && (isInitializedProperty(ancestorPropertyDeclaraion) || hasType(ancestorPropertyDeclaraion))) {
                        return true;
                    }
                }
                return isDeclarationName(contextToken2) && !isShorthandPropertyAssignment(contextToken2.parent) && !isJsxAttribute(contextToken2.parent) && !((isClassLike(contextToken2.parent) || isInterfaceDeclaration(contextToken2.parent) || isTypeParameterDeclaration(contextToken2.parent)) && (contextToken2 !== previousToken || position > previousToken.end));
            }
            function isPreviousPropertyDeclarationTerminated(contextToken2, position2) {
                return contextToken2.kind !== 64 /* EqualsToken */ && (contextToken2.kind === 27 /* SemicolonToken */ || !positionsAreOnSameLine(contextToken2.end, position2, sourceFile));
            }
            function isFunctionLikeButNotConstructor(kind) {
                return isFunctionLikeKind(kind) && kind !== 176 /* Constructor */;
            }
            function isDotOfNumericLiteral(contextToken2) {
                if (contextToken2.kind === 9 /* NumericLiteral */) {
                    const text = contextToken2.getFullText();
                    return text.charAt(text.length - 1) === ".";
                }
                return false;
            }
            function isVariableDeclarationListButNotTypeArgument(node2) {
                return node2.parent.kind === 261 /* VariableDeclarationList */ && !isPossiblyTypeArgumentPosition(node2, sourceFile, typeChecker);
            }
            function filterObjectMembersList(contextualMemberSymbols, existingMembers) {
                if (existingMembers.length === 0) {
                    return contextualMemberSymbols;
                }
                const membersDeclaredBySpreadAssignment = /* @__PURE__ */ new Set();
                const existingMemberNames = /* @__PURE__ */ new Set();
                for (const m of existingMembers) {
                    if (m.kind !== 303 /* PropertyAssignment */ && m.kind !== 304 /* ShorthandPropertyAssignment */ && m.kind !== 208 /* BindingElement */ && m.kind !== 174 /* MethodDeclaration */ && m.kind !== 177 /* GetAccessor */ && m.kind !== 178 /* SetAccessor */ && m.kind !== 305 /* SpreadAssignment */) {
                        continue;
                    }
                    if (isCurrentlyEditingNode(m)) {
                        continue;
                    }
                    let existingName;
                    if (isSpreadAssignment(m)) {
                        setMembersDeclaredBySpreadAssignment(m, membersDeclaredBySpreadAssignment);
                    }
                    else if (isBindingElement(m) && m.propertyName) {
                        if (m.propertyName.kind === 80 /* Identifier */) {
                            existingName = m.propertyName.escapedText;
                        }
                    }
                    else {
                        const name = getNameOfDeclaration(m);
                        existingName = name && isPropertyNameLiteral(name) ? getEscapedTextOfIdentifierOrLiteral(name) : void 0;
                    }
                    if (existingName !== void 0) {
                        existingMemberNames.add(existingName);
                    }
                }
                const filteredSymbols = contextualMemberSymbols.filter((m) => !existingMemberNames.has(m.escapedName));
                setSortTextToMemberDeclaredBySpreadAssignment(membersDeclaredBySpreadAssignment, filteredSymbols);
                return filteredSymbols;
            }
            function setMembersDeclaredBySpreadAssignment(declaration, membersDeclaredBySpreadAssignment) {
                const expression = declaration.expression;
                const symbol = typeChecker.getSymbolAtLocation(expression);
                const type = symbol && typeChecker.getTypeOfSymbolAtLocation(symbol, expression);
                const properties = type && type.properties;
                if (properties) {
                    properties.forEach((property) => {
                        membersDeclaredBySpreadAssignment.add(property.name);
                    });
                }
            }
            function setSortTextToOptionalMember() {
                symbols.forEach((m) => {
                    if (m.flags & 16777216 /* Optional */) {
                        const symbolId = getSymbolId(m);
                        symbolToSortTextMap[symbolId] = symbolToSortTextMap[symbolId] ?? SortText.OptionalMember;
                    }
                });
            }
            function setSortTextToMemberDeclaredBySpreadAssignment(membersDeclaredBySpreadAssignment, contextualMemberSymbols) {
                if (membersDeclaredBySpreadAssignment.size === 0) {
                    return;
                }
                for (const contextualMemberSymbol of contextualMemberSymbols) {
                    if (membersDeclaredBySpreadAssignment.has(contextualMemberSymbol.name)) {
                        symbolToSortTextMap[getSymbolId(contextualMemberSymbol)] = SortText.MemberDeclaredBySpreadAssignment;
                    }
                }
            }
            function transformObjectLiteralMembersSortText(start2) {
                for (let i = start2; i < symbols.length; i++) {
                    const symbol = symbols[i];
                    const symbolId = getSymbolId(symbol);
                    const origin = symbolToOriginInfoMap == null ? void 0 : symbolToOriginInfoMap[i];
                    const target = getEmitScriptTarget(compilerOptions);
                    const displayName = getCompletionEntryDisplayNameForSymbol(symbol, target, origin, 0 /* ObjectPropertyDeclaration */, 
                    /*jsxIdentifierExpected*/
                    false);
                    if (displayName) {
                        const originalSortText = symbolToSortTextMap[symbolId] ?? SortText.LocationPriority;
                        const { name } = displayName;
                        symbolToSortTextMap[symbolId] = SortText.ObjectLiteralProperty(originalSortText, name);
                    }
                }
            }
            function filterClassMembersList(baseSymbols, existingMembers, currentClassElementModifierFlags) {
                const existingMemberNames = /* @__PURE__ */ new Set();
                for (const m of existingMembers) {
                    if (m.kind !== 172 /* PropertyDeclaration */ && m.kind !== 174 /* MethodDeclaration */ && m.kind !== 177 /* GetAccessor */ && m.kind !== 178 /* SetAccessor */) {
                        continue;
                    }
                    if (isCurrentlyEditingNode(m)) {
                        continue;
                    }
                    if (hasEffectiveModifier(m, 2 /* Private */)) {
                        continue;
                    }
                    if (isStatic(m) !== !!(currentClassElementModifierFlags & 256 /* Static */)) {
                        continue;
                    }
                    const existingName = getPropertyNameForPropertyNameNode(m.name);
                    if (existingName) {
                        existingMemberNames.add(existingName);
                    }
                }
                return baseSymbols.filter((propertySymbol) => !existingMemberNames.has(propertySymbol.escapedName) && !!propertySymbol.declarations && !(getDeclarationModifierFlagsFromSymbol(propertySymbol) & 2 /* Private */) && !(propertySymbol.valueDeclaration && isPrivateIdentifierClassElementDeclaration(propertySymbol.valueDeclaration)));
            }
            function filterJsxAttributes(symbols2, attributes) {
                const seenNames = /* @__PURE__ */ new Set();
                const membersDeclaredBySpreadAssignment = /* @__PURE__ */ new Set();
                for (const attr of attributes) {
                    if (isCurrentlyEditingNode(attr)) {
                        continue;
                    }
                    if (attr.kind === 291 /* JsxAttribute */) {
                        seenNames.add(getEscapedTextOfJsxAttributeName(attr.name));
                    }
                    else if (isJsxSpreadAttribute(attr)) {
                        setMembersDeclaredBySpreadAssignment(attr, membersDeclaredBySpreadAssignment);
                    }
                }
                const filteredSymbols = symbols2.filter((a) => !seenNames.has(a.escapedName));
                setSortTextToMemberDeclaredBySpreadAssignment(membersDeclaredBySpreadAssignment, filteredSymbols);
                return filteredSymbols;
            }
            function isCurrentlyEditingNode(node2) {
                return node2.getStart(sourceFile) <= position && position <= node2.getEnd();
            }
        }
        function tryGetObjectLikeCompletionContainer(contextToken, position, sourceFile) {
            var _a;
            if (contextToken) {
                const { parent: parent2 } = contextToken;
                switch (contextToken.kind) {
                    case 19 /* OpenBraceToken */:
                    case 28 /* CommaToken */:
                        if (isObjectLiteralExpression(parent2) || isObjectBindingPattern(parent2)) {
                            return parent2;
                        }
                        break;
                    case 42 /* AsteriskToken */:
                        return isMethodDeclaration(parent2) ? tryCast(parent2.parent, isObjectLiteralExpression) : void 0;
                    case 134 /* AsyncKeyword */:
                        return tryCast(parent2.parent, isObjectLiteralExpression);
                    case 80 /* Identifier */:
                        if (contextToken.text === "async" && isShorthandPropertyAssignment(contextToken.parent)) {
                            return contextToken.parent.parent;
                        }
                        else {
                            if (isObjectLiteralExpression(contextToken.parent.parent) && (isSpreadAssignment(contextToken.parent) || isShorthandPropertyAssignment(contextToken.parent) && getLineAndCharacterOfPosition(sourceFile, contextToken.getEnd()).line !== getLineAndCharacterOfPosition(sourceFile, position).line)) {
                                return contextToken.parent.parent;
                            }
                            const ancestorNode2 = findAncestor(parent2, isPropertyAssignment);
                            if ((ancestorNode2 == null ? void 0 : ancestorNode2.getLastToken(sourceFile)) === contextToken && isObjectLiteralExpression(ancestorNode2.parent)) {
                                return ancestorNode2.parent;
                            }
                        }
                        break;
                    default:
                        if (((_a = parent2.parent) == null ? void 0 : _a.parent) && (isMethodDeclaration(parent2.parent) || isGetAccessorDeclaration(parent2.parent) || isSetAccessorDeclaration(parent2.parent)) && isObjectLiteralExpression(parent2.parent.parent)) {
                            return parent2.parent.parent;
                        }
                        if (isSpreadAssignment(parent2) && isObjectLiteralExpression(parent2.parent)) {
                            return parent2.parent;
                        }
                        const ancestorNode = findAncestor(parent2, isPropertyAssignment);
                        if (contextToken.kind !== 59 /* ColonToken */ && (ancestorNode == null ? void 0 : ancestorNode.getLastToken(sourceFile)) === contextToken && isObjectLiteralExpression(ancestorNode.parent)) {
                            return ancestorNode.parent;
                        }
                }
            }
            return void 0;
        }
        function getRelevantTokens(position, sourceFile) {
            const previousToken = findPrecedingToken(position, sourceFile);
            if (previousToken && position <= previousToken.end && (isMemberName(previousToken) || isKeyword(previousToken.kind))) {
                const contextToken = findPrecedingToken(previousToken.getFullStart(), sourceFile, 
                /*startNode*/
                void 0);
                return { contextToken, previousToken };
            }
            return { contextToken: previousToken, previousToken };
        }
        function getAutoImportSymbolFromCompletionEntryData(name, data, program, host) {
            const containingProgram = data.isPackageJsonImport ? host.getPackageJsonAutoImportProvider() : program;
            const checker = containingProgram.getTypeChecker();
            const moduleSymbol = data.ambientModuleName ? checker.tryFindAmbientModule(data.ambientModuleName) : data.fileName ? checker.getMergedSymbol(Debug.checkDefined(containingProgram.getSourceFile(data.fileName)).symbol) : void 0;
            if (!moduleSymbol)
                return void 0;
            let symbol = data.exportName === "export=" /* ExportEquals */ ? checker.resolveExternalModuleSymbol(moduleSymbol) : checker.tryGetMemberInModuleExportsAndProperties(data.exportName, moduleSymbol);
            if (!symbol)
                return void 0;
            const isDefaultExport = data.exportName === "default" /* Default */;
            symbol = isDefaultExport && getLocalSymbolForExportDefault(symbol) || symbol;
            return { symbol, origin: completionEntryDataToSymbolOriginInfo(data, name, moduleSymbol) };
        }
        function getCompletionEntryDisplayNameForSymbol(symbol, target, origin, kind, jsxIdentifierExpected) {
            if (originIsIgnore(origin)) {
                return void 0;
            }
            const name = originIncludesSymbolName(origin) ? origin.symbolName : symbol.name;
            if (name === void 0 || symbol.flags & 1536 /* Module */ && isSingleOrDoubleQuote(name.charCodeAt(0)) || isKnownSymbol(symbol)) {
                return void 0;
            }
            const validNameResult = { name, needsConvertPropertyAccess: false };
            if (isIdentifierText(name, target, jsxIdentifierExpected ? 1 /* JSX */ : 0 /* Standard */) || symbol.valueDeclaration && isPrivateIdentifierClassElementDeclaration(symbol.valueDeclaration)) {
                return validNameResult;
            }
            switch (kind) {
                case 3 /* MemberLike */:
                    return originIsComputedPropertyName(origin) ? { name: origin.symbolName, needsConvertPropertyAccess: false } : void 0;
                case 0 /* ObjectPropertyDeclaration */:
                    return { name: JSON.stringify(name), needsConvertPropertyAccess: false };
                case 2 /* PropertyAccess */:
                case 1 /* Global */:
                    return name.charCodeAt(0) === 32 /* space */ ? void 0 : { name, needsConvertPropertyAccess: true };
                case 5 /* None */:
                case 4 /* String */:
                    return validNameResult;
                default:
                    Debug.assertNever(kind);
            }
        }
        function getKeywordCompletions(keywordFilter, filterOutTsOnlyKeywords) {
            if (!filterOutTsOnlyKeywords)
                return getTypescriptKeywordCompletions(keywordFilter);
            const index = keywordFilter + 8 /* Last */ + 1;
            return _keywordCompletions[index] || (_keywordCompletions[index] = getTypescriptKeywordCompletions(keywordFilter).filter((entry) => !isTypeScriptOnlyKeyword(stringToToken(entry.name))));
        }
        function getTypescriptKeywordCompletions(keywordFilter) {
            return _keywordCompletions[keywordFilter] || (_keywordCompletions[keywordFilter] = allKeywordsCompletions().filter((entry) => {
                const kind = stringToToken(entry.name);
                switch (keywordFilter) {
                    case 0 /* None */:
                        return false;
                    case 1 /* All */:
                        return isFunctionLikeBodyKeyword(kind) || kind === 138 /* DeclareKeyword */ || kind === 144 /* ModuleKeyword */ || kind === 156 /* TypeKeyword */ || kind === 145 /* NamespaceKeyword */ || kind === 128 /* AbstractKeyword */ || isTypeKeyword(kind) && kind !== 157 /* UndefinedKeyword */;
                    case 5 /* FunctionLikeBodyKeywords */:
                        return isFunctionLikeBodyKeyword(kind);
                    case 2 /* ClassElementKeywords */:
                        return isClassMemberCompletionKeyword(kind);
                    case 3 /* InterfaceElementKeywords */:
                        return isInterfaceOrTypeLiteralCompletionKeyword(kind);
                    case 4 /* ConstructorParameterKeywords */:
                        return isParameterPropertyModifier(kind);
                    case 6 /* TypeAssertionKeywords */:
                        return isTypeKeyword(kind) || kind === 87 /* ConstKeyword */;
                    case 7 /* TypeKeywords */:
                        return isTypeKeyword(kind);
                    case 8 /* TypeKeyword */:
                        return kind === 156 /* TypeKeyword */;
                    default:
                        return Debug.assertNever(keywordFilter);
                }
            }));
        }
        function isTypeScriptOnlyKeyword(kind) {
            switch (kind) {
                case 128 /* AbstractKeyword */:
                case 133 /* AnyKeyword */:
                case 163 /* BigIntKeyword */:
                case 136 /* BooleanKeyword */:
                case 138 /* DeclareKeyword */:
                case 94 /* EnumKeyword */:
                case 162 /* GlobalKeyword */:
                case 119 /* ImplementsKeyword */:
                case 140 /* InferKeyword */:
                case 120 /* InterfaceKeyword */:
                case 142 /* IsKeyword */:
                case 143 /* KeyOfKeyword */:
                case 144 /* ModuleKeyword */:
                case 145 /* NamespaceKeyword */:
                case 146 /* NeverKeyword */:
                case 150 /* NumberKeyword */:
                case 151 /* ObjectKeyword */:
                case 164 /* OverrideKeyword */:
                case 123 /* PrivateKeyword */:
                case 124 /* ProtectedKeyword */:
                case 125 /* PublicKeyword */:
                case 148 /* ReadonlyKeyword */:
                case 154 /* StringKeyword */:
                case 155 /* SymbolKeyword */:
                case 156 /* TypeKeyword */:
                case 158 /* UniqueKeyword */:
                case 159 /* UnknownKeyword */:
                    return true;
                default:
                    return false;
            }
        }
        function isInterfaceOrTypeLiteralCompletionKeyword(kind) {
            return kind === 148 /* ReadonlyKeyword */;
        }
        function isClassMemberCompletionKeyword(kind) {
            switch (kind) {
                case 128 /* AbstractKeyword */:
                case 129 /* AccessorKeyword */:
                case 137 /* ConstructorKeyword */:
                case 139 /* GetKeyword */:
                case 153 /* SetKeyword */:
                case 134 /* AsyncKeyword */:
                case 138 /* DeclareKeyword */:
                case 164 /* OverrideKeyword */:
                    return true;
                default:
                    return isClassMemberModifier(kind);
            }
        }
        function isFunctionLikeBodyKeyword(kind) {
            return kind === 134 /* AsyncKeyword */ || kind === 135 /* AwaitKeyword */ || kind === 160 /* UsingKeyword */ || kind === 130 /* AsKeyword */ || kind === 152 /* SatisfiesKeyword */ || kind === 156 /* TypeKeyword */ || !isContextualKeyword(kind) && !isClassMemberCompletionKeyword(kind);
        }
        function keywordForNode(node) {
            return isIdentifier(node) ? identifierToKeywordKind(node) ?? 0 /* Unknown */ : node.kind;
        }
        function getContextualKeywords(contextToken, position) {
            const entries = [];
            if (contextToken) {
                const file = contextToken.getSourceFile();
                const parent2 = contextToken.parent;
                const tokenLine = file.getLineAndCharacterOfPosition(contextToken.end).line;
                const currentLine = file.getLineAndCharacterOfPosition(position).line;
                if ((isImportDeclaration(parent2) || isExportDeclaration(parent2) && parent2.moduleSpecifier) && contextToken === parent2.moduleSpecifier && tokenLine === currentLine) {
                    entries.push({
                        name: tokenToString(132 /* AssertKeyword */),
                        kind: "keyword" /* keyword */,
                        kindModifiers: "" /* none */,
                        sortText: SortText.GlobalsOrKeywords
                    });
                }
            }
            return entries;
        }
        function getJsDocTagAtPosition(node, position) {
            return findAncestor(node, (n) => isJSDocTag(n) && rangeContainsPosition(n, position) ? true : isJSDoc(n) ? "quit" : false);
        }
        function getPropertiesForObjectExpression(contextualType, completionsType, obj, checker) {
            const hasCompletionsType = completionsType && completionsType !== contextualType;
            const type = hasCompletionsType && !(completionsType.flags & 3 /* AnyOrUnknown */) ? checker.getUnionType([contextualType, completionsType]) : contextualType;
            const properties = getApparentProperties(type, obj, checker);
            return type.isClass() && containsNonPublicProperties(properties) ? [] : hasCompletionsType ? filter(properties, hasDeclarationOtherThanSelf) : properties;
            function hasDeclarationOtherThanSelf(member) {
                if (!length(member.declarations))
                    return true;
                return some(member.declarations, (decl) => decl.parent !== obj);
            }
        }
        function getApparentProperties(type, node, checker) {
            if (!type.isUnion())
                return type.getApparentProperties();
            return checker.getAllPossiblePropertiesOfTypes(filter(type.types, (memberType) => !(memberType.flags & 402784252 /* Primitive */ || checker.isArrayLikeType(memberType) || checker.isTypeInvalidDueToUnionDiscriminant(memberType, node) || checker.typeHasCallOrConstructSignatures(memberType) || memberType.isClass() && containsNonPublicProperties(memberType.getApparentProperties()))));
        }
        function containsNonPublicProperties(props) {
            return some(props, (p) => !!(getDeclarationModifierFlagsFromSymbol(p) & 6 /* NonPublicAccessibilityModifier */));
        }
        function getPropertiesForCompletion(type, checker) {
            return type.isUnion() ? Debug.checkEachDefined(checker.getAllPossiblePropertiesOfTypes(type.types), "getAllPossiblePropertiesOfTypes() should all be defined") : Debug.checkEachDefined(type.getApparentProperties(), "getApparentProperties() should all be defined");
        }
        function tryGetObjectTypeDeclarationCompletionContainer(sourceFile, contextToken, location, position) {
            switch (location.kind) {
                case 358 /* SyntaxList */:
                    return tryCast(location.parent, isObjectTypeDeclaration);
                case 1 /* EndOfFileToken */:
                    const cls = tryCast(lastOrUndefined(cast(location.parent, isSourceFile).statements), isObjectTypeDeclaration);
                    if (cls && !findChildOfKind(cls, 20 /* CloseBraceToken */, sourceFile)) {
                        return cls;
                    }
                    break;
                case 81 /* PrivateIdentifier */:
                    if (tryCast(location.parent, isPropertyDeclaration)) {
                        return findAncestor(location, isClassLike);
                    }
                    break;
                case 80 /* Identifier */: {
                    const originalKeywordKind = identifierToKeywordKind(location);
                    if (originalKeywordKind) {
                        return void 0;
                    }
                    if (isPropertyDeclaration(location.parent) && location.parent.initializer === location) {
                        return void 0;
                    }
                    if (isFromObjectTypeDeclaration(location)) {
                        return findAncestor(location, isObjectTypeDeclaration);
                    }
                }
            }
            if (!contextToken)
                return void 0;
            if (location.kind === 137 /* ConstructorKeyword */ || isIdentifier(contextToken) && isPropertyDeclaration(contextToken.parent) && isClassLike(location)) {
                return findAncestor(contextToken, isClassLike);
            }
            switch (contextToken.kind) {
                case 64 /* EqualsToken */:
                    return void 0;
                case 27 /* SemicolonToken */:
                case 20 /* CloseBraceToken */:
                    return isFromObjectTypeDeclaration(location) && location.parent.name === location ? location.parent.parent : tryCast(location, isObjectTypeDeclaration);
                case 19 /* OpenBraceToken */:
                case 28 /* CommaToken */:
                    return tryCast(contextToken.parent, isObjectTypeDeclaration);
                default:
                    if (isObjectTypeDeclaration(location)) {
                        if (getLineAndCharacterOfPosition(sourceFile, contextToken.getEnd()).line !== getLineAndCharacterOfPosition(sourceFile, position).line) {
                            return location;
                        }
                        const isValidKeyword = isClassLike(contextToken.parent.parent) ? isClassMemberCompletionKeyword : isInterfaceOrTypeLiteralCompletionKeyword;
                        return isValidKeyword(contextToken.kind) || contextToken.kind === 42 /* AsteriskToken */ || isIdentifier(contextToken) && isValidKeyword(identifierToKeywordKind(contextToken) ?? 0 /* Unknown */) ? contextToken.parent.parent : void 0;
                    }
                    return void 0;
            }
        }
        function tryGetTypeLiteralNode(node) {
            if (!node)
                return void 0;
            const parent2 = node.parent;
            switch (node.kind) {
                case 19 /* OpenBraceToken */:
                    if (isTypeLiteralNode(parent2)) {
                        return parent2;
                    }
                    break;
                case 27 /* SemicolonToken */:
                case 28 /* CommaToken */:
                case 80 /* Identifier */:
                    if (parent2.kind === 171 /* PropertySignature */ && isTypeLiteralNode(parent2.parent)) {
                        return parent2.parent;
                    }
                    break;
            }
            return void 0;
        }
        function getConstraintOfTypeArgumentProperty(node, checker) {
            if (!node)
                return void 0;
            if (isTypeNode(node) && isTypeReferenceType(node.parent)) {
                return checker.getTypeArgumentConstraint(node);
            }
            const t = getConstraintOfTypeArgumentProperty(node.parent, checker);
            if (!t)
                return void 0;
            switch (node.kind) {
                case 171 /* PropertySignature */:
                    return checker.getTypeOfPropertyOfContextualType(t, node.symbol.escapedName);
                case 193 /* IntersectionType */:
                case 187 /* TypeLiteral */:
                case 192 /* UnionType */:
                    return t;
            }
        }
        function isFromObjectTypeDeclaration(node) {
            return node.parent && isClassOrTypeElement(node.parent) && isObjectTypeDeclaration(node.parent.parent);
        }
        function isValidTrigger(sourceFile, triggerCharacter, contextToken, position) {
            switch (triggerCharacter) {
                case ".":
                case "@":
                    return true;
                case '"':
                case "'":
                case "`":
                    return !!contextToken && isStringLiteralOrTemplate(contextToken) && position === contextToken.getStart(sourceFile) + 1;
                case "#":
                    return !!contextToken && isPrivateIdentifier(contextToken) && !!getContainingClass(contextToken);
                case "<":
                    return !!contextToken && contextToken.kind === 30 /* LessThanToken */ && (!isBinaryExpression(contextToken.parent) || binaryExpressionMayBeOpenTag(contextToken.parent));
                case "/":
                    return !!contextToken && (isStringLiteralLike(contextToken) ? !!tryGetImportFromModuleSpecifier(contextToken) : contextToken.kind === 44 /* SlashToken */ && isJsxClosingElement(contextToken.parent));
                case " ":
                    return !!contextToken && isImportKeyword(contextToken) && contextToken.parent.kind === 312 /* SourceFile */;
                default:
                    return Debug.assertNever(triggerCharacter);
            }
        }
        function binaryExpressionMayBeOpenTag({ left }) {
            return nodeIsMissing(left);
        }
        function isProbablyGlobalType(type, sourceFile, checker) {
            const selfSymbol = checker.resolveName("self", 
            /*location*/
            void 0, 111551 /* Value */, 
            /*excludeGlobals*/
            false);
            if (selfSymbol && checker.getTypeOfSymbolAtLocation(selfSymbol, sourceFile) === type) {
                return true;
            }
            const globalSymbol = checker.resolveName("global", 
            /*location*/
            void 0, 111551 /* Value */, 
            /*excludeGlobals*/
            false);
            if (globalSymbol && checker.getTypeOfSymbolAtLocation(globalSymbol, sourceFile) === type) {
                return true;
            }
            const globalThisSymbol = checker.resolveName("globalThis", 
            /*location*/
            void 0, 111551 /* Value */, 
            /*excludeGlobals*/
            false);
            if (globalThisSymbol && checker.getTypeOfSymbolAtLocation(globalThisSymbol, sourceFile) === type) {
                return true;
            }
            return false;
        }
        function isStaticProperty(symbol) {
            return !!(symbol.valueDeclaration && getEffectiveModifierFlags(symbol.valueDeclaration) & 256 /* Static */ && isClassLike(symbol.valueDeclaration.parent));
        }
        function tryGetObjectLiteralContextualType(node, typeChecker) {
            const type = typeChecker.getContextualType(node);
            if (type) {
                return type;
            }
            const parent2 = walkUpParenthesizedExpressions(node.parent);
            if (isBinaryExpression(parent2) && parent2.operatorToken.kind === 64 /* EqualsToken */ && node === parent2.left) {
                return typeChecker.getTypeAtLocation(parent2);
            }
            if (isExpression(parent2)) {
                return typeChecker.getContextualType(parent2);
            }
            return void 0;
        }
        function getImportStatementCompletionInfo(contextToken, sourceFile) {
            var _a, _b, _c;
            let keywordCompletion;
            let isKeywordOnlyCompletion = false;
            const candidate = getCandidate();
            return {
                isKeywordOnlyCompletion,
                keywordCompletion,
                isNewIdentifierLocation: !!(candidate || keywordCompletion === 156 /* TypeKeyword */),
                isTopLevelTypeOnly: !!((_b = (_a = tryCast(candidate, isImportDeclaration)) == null ? void 0 : _a.importClause) == null ? void 0 : _b.isTypeOnly) || !!((_c = tryCast(candidate, isImportEqualsDeclaration)) == null ? void 0 : _c.isTypeOnly),
                couldBeTypeOnlyImportSpecifier: !!candidate && couldBeTypeOnlyImportSpecifier(candidate, contextToken),
                replacementSpan: getSingleLineReplacementSpanForImportCompletionNode(candidate)
            };
            function getCandidate() {
                const parent2 = contextToken.parent;
                if (isImportEqualsDeclaration(parent2)) {
                    const lastToken = parent2.getLastToken(sourceFile);
                    if (isIdentifier(contextToken) && lastToken !== contextToken) {
                        keywordCompletion = 161 /* FromKeyword */;
                        isKeywordOnlyCompletion = true;
                        return void 0;
                    }
                    keywordCompletion = contextToken.kind === 156 /* TypeKeyword */ ? void 0 : 156 /* TypeKeyword */;
                    return isModuleSpecifierMissingOrEmpty(parent2.moduleReference) ? parent2 : void 0;
                }
                if (couldBeTypeOnlyImportSpecifier(parent2, contextToken) && canCompleteFromNamedBindings(parent2.parent)) {
                    return parent2;
                }
                if (isNamedImports(parent2) || isNamespaceImport(parent2)) {
                    if (!parent2.parent.isTypeOnly && (contextToken.kind === 19 /* OpenBraceToken */ || contextToken.kind === 102 /* ImportKeyword */ || contextToken.kind === 28 /* CommaToken */)) {
                        keywordCompletion = 156 /* TypeKeyword */;
                    }
                    if (canCompleteFromNamedBindings(parent2)) {
                        if (contextToken.kind === 20 /* CloseBraceToken */ || contextToken.kind === 80 /* Identifier */) {
                            isKeywordOnlyCompletion = true;
                            keywordCompletion = 161 /* FromKeyword */;
                        }
                        else {
                            return parent2.parent.parent;
                        }
                    }
                    return void 0;
                }
                if (isExportDeclaration(parent2) && contextToken.kind === 42 /* AsteriskToken */ || isNamedExports(parent2) && contextToken.kind === 20 /* CloseBraceToken */) {
                    isKeywordOnlyCompletion = true;
                    keywordCompletion = 161 /* FromKeyword */;
                    return void 0;
                }
                if (isImportKeyword(contextToken) && isSourceFile(parent2)) {
                    keywordCompletion = 156 /* TypeKeyword */;
                    return contextToken;
                }
                if (isImportKeyword(contextToken) && isImportDeclaration(parent2)) {
                    keywordCompletion = 156 /* TypeKeyword */;
                    return isModuleSpecifierMissingOrEmpty(parent2.moduleSpecifier) ? parent2 : void 0;
                }
                return void 0;
            }
        }
        function getSingleLineReplacementSpanForImportCompletionNode(node) {
            var _a;
            if (!node)
                return void 0;
            const top = findAncestor(node, or(isImportDeclaration, isImportEqualsDeclaration)) ?? node;
            const sourceFile = top.getSourceFile();
            if (rangeIsOnSingleLine(top, sourceFile)) {
                return createTextSpanFromNode(top, sourceFile);
            }
            Debug.assert(top.kind !== 102 /* ImportKeyword */ && top.kind !== 276 /* ImportSpecifier */);
            const potentialSplitPoint = top.kind === 272 /* ImportDeclaration */ ? getPotentiallyInvalidImportSpecifier((_a = top.importClause) == null ? void 0 : _a.namedBindings) ?? top.moduleSpecifier : top.moduleReference;
            const withoutModuleSpecifier = {
                pos: top.getFirstToken().getStart(),
                end: potentialSplitPoint.pos
            };
            if (rangeIsOnSingleLine(withoutModuleSpecifier, sourceFile)) {
                return createTextSpanFromRange(withoutModuleSpecifier);
            }
        }
        function getPotentiallyInvalidImportSpecifier(namedBindings) {
            var _a;
            return find((_a = tryCast(namedBindings, isNamedImports)) == null ? void 0 : _a.elements, (e) => {
                var _a2;
                return !e.propertyName && isStringANonContextualKeyword(e.name.text) && ((_a2 = findPrecedingToken(e.name.pos, namedBindings.getSourceFile(), namedBindings)) == null ? void 0 : _a2.kind) !== 28 /* CommaToken */;
            });
        }
        function couldBeTypeOnlyImportSpecifier(importSpecifier, contextToken) {
            return isImportSpecifier(importSpecifier) && (importSpecifier.isTypeOnly || contextToken === importSpecifier.name && isTypeKeywordTokenOrIdentifier(contextToken));
        }
        function canCompleteFromNamedBindings(namedBindings) {
            if (!isModuleSpecifierMissingOrEmpty(namedBindings.parent.parent.moduleSpecifier) || namedBindings.parent.name) {
                return false;
            }
            if (isNamedImports(namedBindings)) {
                const invalidNamedImport = getPotentiallyInvalidImportSpecifier(namedBindings);
                const validImports = invalidNamedImport ? namedBindings.elements.indexOf(invalidNamedImport) : namedBindings.elements.length;
                return validImports < 2;
            }
            return true;
        }
        function isModuleSpecifierMissingOrEmpty(specifier) {
            var _a;
            if (nodeIsMissing(specifier))
                return true;
            return !((_a = tryCast(isExternalModuleReference(specifier) ? specifier.expression : specifier, isStringLiteralLike)) == null ? void 0 : _a.text);
        }
        function getVariableOrParameterDeclaration(contextToken, location) {
            if (!contextToken)
                return;
            const possiblyParameterDeclaration = findAncestor(contextToken, (node) => isFunctionBlock(node) || isArrowFunctionBody(node) || isBindingPattern(node) ? "quit" : (isParameter(node) || isTypeParameterDeclaration(node)) && !isIndexSignatureDeclaration(node.parent));
            const possiblyVariableDeclaration = findAncestor(location, (node) => isFunctionBlock(node) || isArrowFunctionBody(node) || isBindingPattern(node) ? "quit" : isVariableDeclaration(node));
            return possiblyParameterDeclaration || possiblyVariableDeclaration;
        }
        function isArrowFunctionBody(node) {
            return node.parent && isArrowFunction(node.parent) && (node.parent.body === node || // const a = () => /**/;
                node.kind === 39 /* EqualsGreaterThanToken */);
        }
        function symbolCanBeReferencedAtTypeLocation(symbol, checker, seenModules = /* @__PURE__ */ new Map()) {
            return nonAliasCanBeReferencedAtTypeLocation(symbol) || nonAliasCanBeReferencedAtTypeLocation(skipAlias(symbol.exportSymbol || symbol, checker));
            function nonAliasCanBeReferencedAtTypeLocation(symbol2) {
                return !!(symbol2.flags & 788968 /* Type */) || checker.isUnknownSymbol(symbol2) || !!(symbol2.flags & 1536 /* Module */) && addToSeen(seenModules, getSymbolId(symbol2)) && checker.getExportsOfModule(symbol2).some((e) => symbolCanBeReferencedAtTypeLocation(e, checker, seenModules));
            }
        }
        function isDeprecated(symbol, checker) {
            const declarations = skipAlias(symbol, checker).declarations;
            return !!length(declarations) && every(declarations, isDeprecatedDeclaration);
        }
        function charactersFuzzyMatchInString(identifierString, lowercaseCharacters) {
            if (lowercaseCharacters.length === 0) {
                return true;
            }
            let matchedFirstCharacter = false;
            let prevChar;
            let characterIndex = 0;
            const len = identifierString.length;
            for (let strIndex = 0; strIndex < len; strIndex++) {
                const strChar = identifierString.charCodeAt(strIndex);
                const testChar = lowercaseCharacters.charCodeAt(characterIndex);
                if (strChar === testChar || strChar === toUpperCharCode(testChar)) {
                    matchedFirstCharacter || (matchedFirstCharacter = prevChar === void 0 || // Beginning of word
                        97 /* a */ <= prevChar && prevChar <= 122 /* z */ && 65 /* A */ <= strChar && strChar <= 90 /* Z */ || // camelCase transition
                        prevChar === 95 /* _ */ && strChar !== 95 /* _ */);
                    if (matchedFirstCharacter) {
                        characterIndex++;
                    }
                    if (characterIndex === lowercaseCharacters.length) {
                        return true;
                    }
                }
                prevChar = strChar;
            }
            return false;
        }
        function toUpperCharCode(charCode) {
            if (97 /* a */ <= charCode && charCode <= 122 /* z */) {
                return charCode - 32;
            }
            return charCode;
        }
        function isContextualKeywordInAutoImportableExpressionSpace(keyword) {
            return keyword === "abstract" || keyword === "async" || keyword === "await" || keyword === "declare" || keyword === "module" || keyword === "namespace" || keyword === "type";
        }
        var moduleSpecifierResolutionLimit, moduleSpecifierResolutionCacheAttemptLimit, SortText, CompletionSource, SymbolOriginInfoKind, CompletionKind, _keywordCompletions, allKeywordsCompletions;
        var init_completions = __esm({
            "src/services/completions.ts"() {
                "use strict";
                init_ts4();
                init_ts_Completions();
                moduleSpecifierResolutionLimit = 100;
                moduleSpecifierResolutionCacheAttemptLimit = 1e3;
                SortText = {
                    // Presets
                    LocalDeclarationPriority: "10",
                    LocationPriority: "11",
                    OptionalMember: "12",
                    MemberDeclaredBySpreadAssignment: "13",
                    SuggestedClassMembers: "14",
                    GlobalsOrKeywords: "15",
                    AutoImportSuggestions: "16",
                    ClassMemberSnippets: "17",
                    JavascriptIdentifiers: "18",
                    // Transformations
                    Deprecated(sortText) {
                        return "z" + sortText;
                    },
                    ObjectLiteralProperty(presetSortText, symbolDisplayName) {
                        return `${presetSortText}\0${symbolDisplayName}\0`;
                    },
                    SortBelow(sortText) {
                        return sortText + "1";
                    }
                };
                CompletionSource = /* @__PURE__ */ ((CompletionSource2) => {
                    CompletionSource2["ThisProperty"] = "ThisProperty/";
                    CompletionSource2["ClassMemberSnippet"] = "ClassMemberSnippet/";
                    CompletionSource2["TypeOnlyAlias"] = "TypeOnlyAlias/";
                    CompletionSource2["ObjectLiteralMethodSnippet"] = "ObjectLiteralMethodSnippet/";
                    CompletionSource2["SwitchCases"] = "SwitchCases/";
                    CompletionSource2["ObjectLiteralMemberWithComma"] = "ObjectLiteralMemberWithComma/";
                    return CompletionSource2;
                })(CompletionSource || {});
                SymbolOriginInfoKind = /* @__PURE__ */ ((SymbolOriginInfoKind2) => {
                    SymbolOriginInfoKind2[SymbolOriginInfoKind2["ThisType"] = 1] = "ThisType";
                    SymbolOriginInfoKind2[SymbolOriginInfoKind2["SymbolMember"] = 2] = "SymbolMember";
                    SymbolOriginInfoKind2[SymbolOriginInfoKind2["Export"] = 4] = "Export";
                    SymbolOriginInfoKind2[SymbolOriginInfoKind2["Promise"] = 8] = "Promise";
                    SymbolOriginInfoKind2[SymbolOriginInfoKind2["Nullable"] = 16] = "Nullable";
                    SymbolOriginInfoKind2[SymbolOriginInfoKind2["ResolvedExport"] = 32] = "ResolvedExport";
                    SymbolOriginInfoKind2[SymbolOriginInfoKind2["TypeOnlyAlias"] = 64] = "TypeOnlyAlias";
                    SymbolOriginInfoKind2[SymbolOriginInfoKind2["ObjectLiteralMethod"] = 128] = "ObjectLiteralMethod";
                    SymbolOriginInfoKind2[SymbolOriginInfoKind2["Ignore"] = 256] = "Ignore";
                    SymbolOriginInfoKind2[SymbolOriginInfoKind2["ComputedPropertyName"] = 512] = "ComputedPropertyName";
                    SymbolOriginInfoKind2[SymbolOriginInfoKind2["SymbolMemberNoExport"] = 2 /* SymbolMember */] = "SymbolMemberNoExport";
                    SymbolOriginInfoKind2[SymbolOriginInfoKind2["SymbolMemberExport"] = 6] = "SymbolMemberExport";
                    return SymbolOriginInfoKind2;
                })(SymbolOriginInfoKind || {});
                CompletionKind = /* @__PURE__ */ ((CompletionKind2) => {
                    CompletionKind2[CompletionKind2["ObjectPropertyDeclaration"] = 0] = "ObjectPropertyDeclaration";
                    CompletionKind2[CompletionKind2["Global"] = 1] = "Global";
                    CompletionKind2[CompletionKind2["PropertyAccess"] = 2] = "PropertyAccess";
                    CompletionKind2[CompletionKind2["MemberLike"] = 3] = "MemberLike";
                    CompletionKind2[CompletionKind2["String"] = 4] = "String";
                    CompletionKind2[CompletionKind2["None"] = 5] = "None";
                    return CompletionKind2;
                })(CompletionKind || {});
                _keywordCompletions = [];
                allKeywordsCompletions = memoize(() => {
                    const res = [];
                    for (let i = 83 /* FirstKeyword */; i <= 165 /* LastKeyword */; i++) {
                        res.push({
                            name: tokenToString(i),
                            kind: "keyword" /* keyword */,
                            kindModifiers: "" /* none */,
                            sortText: SortText.GlobalsOrKeywords
                        });
                    }
                    return res;
                });
            }
        });
        // src/services/stringCompletions.ts
        function createNameAndKindSet() {
            const map2 = /* @__PURE__ */ new Map();
            function add(value) {
                const existing = map2.get(value.name);
                if (!existing || kindPrecedence[existing.kind] < kindPrecedence[value.kind]) {
                    map2.set(value.name, value);
                }
            }
            return {
                add,
                has: map2.has.bind(map2),
                values: map2.values.bind(map2)
            };
        }
        function getStringLiteralCompletions(sourceFile, position, contextToken, options, host, program, log, preferences, includeSymbol) {
            if (isInReferenceComment(sourceFile, position)) {
                const entries = getTripleSlashReferenceCompletion(sourceFile, position, options, host);
                return entries && convertPathCompletions(entries);
            }
            if (isInString(sourceFile, position, contextToken)) {
                if (!contextToken || !isStringLiteralLike(contextToken))
                    return void 0;
                const entries = getStringLiteralCompletionEntries(sourceFile, contextToken, position, program, host, preferences);
                return convertStringLiteralCompletions(entries, contextToken, sourceFile, host, program, log, options, preferences, position, includeSymbol);
            }
        }
        function convertStringLiteralCompletions(completion, contextToken, sourceFile, host, program, log, options, preferences, position, includeSymbol) {
            if (completion === void 0) {
                return void 0;
            }
            const optionalReplacementSpan = createTextSpanFromStringLiteralLikeContent(contextToken);
            switch (completion.kind) {
                case 0 /* Paths */:
                    return convertPathCompletions(completion.paths);
                case 1 /* Properties */: {
                    const entries = createSortedArray();
                    getCompletionEntriesFromSymbols(completion.symbols, entries, contextToken, contextToken, sourceFile, position, sourceFile, host, program, 99 /* ESNext */, log, 4 /* String */, preferences, options, 
                    /*formatContext*/
                    void 0, 
                    /*isTypeOnlyLocation*/
                    void 0, 
                    /*propertyAccessToConvert*/
                    void 0, 
                    /*jsxIdentifierExpected*/
                    void 0, 
                    /*isJsxInitializer*/
                    void 0, 
                    /*importStatementCompletion*/
                    void 0, 
                    /*recommendedCompletion*/
                    void 0, 
                    /*symbolToOriginInfoMap*/
                    void 0, 
                    /*symbolToSortTextMap*/
                    void 0, 
                    /*isJsxIdentifierExpected*/
                    void 0, 
                    /*isRightOfOpenTag*/
                    void 0, includeSymbol);
                    return { isGlobalCompletion: false, isMemberCompletion: true, isNewIdentifierLocation: completion.hasIndexSignature, optionalReplacementSpan, entries };
                }
                case 2 /* Types */: {
                    const quoteChar = contextToken.kind === 15 /* NoSubstitutionTemplateLiteral */ ? 96 /* backtick */ : startsWith(getTextOfNode(contextToken), "'") ? 39 /* singleQuote */ : 34 /* doubleQuote */;
                    const entries = completion.types.map((type) => ({
                        name: escapeString(type.value, quoteChar),
                        kindModifiers: "" /* none */,
                        kind: "string" /* string */,
                        sortText: SortText.LocationPriority,
                        replacementSpan: getReplacementSpanForContextToken(contextToken)
                    }));
                    return { isGlobalCompletion: false, isMemberCompletion: false, isNewIdentifierLocation: completion.isNewIdentifier, optionalReplacementSpan, entries };
                }
                default:
                    return Debug.assertNever(completion);
            }
        }
        function getStringLiteralCompletionDetails(name, sourceFile, position, contextToken, program, host, cancellationToken, preferences) {
            if (!contextToken || !isStringLiteralLike(contextToken))
                return void 0;
            const completions = getStringLiteralCompletionEntries(sourceFile, contextToken, position, program, host, preferences);
            return completions && stringLiteralCompletionDetails(name, contextToken, completions, sourceFile, program.getTypeChecker(), cancellationToken);
        }
        function stringLiteralCompletionDetails(name, location, completion, sourceFile, checker, cancellationToken) {
            switch (completion.kind) {
                case 0 /* Paths */: {
                    const match = find(completion.paths, (p) => p.name === name);
                    return match && createCompletionDetails(name, kindModifiersFromExtension(match.extension), match.kind, [textPart(name)]);
                }
                case 1 /* Properties */: {
                    const match = find(completion.symbols, (s) => s.name === name);
                    return match && createCompletionDetailsForSymbol(match, match.name, checker, sourceFile, location, cancellationToken);
                }
                case 2 /* Types */:
                    return find(completion.types, (t) => t.value === name) ? createCompletionDetails(name, "" /* none */, "string" /* string */, [textPart(name)]) : void 0;
                default:
                    return Debug.assertNever(completion);
            }
        }
        function convertPathCompletions(pathCompletions) {
            const isGlobalCompletion = false;
            const isNewIdentifierLocation = true;
            const entries = pathCompletions.map(({ name, kind, span, extension }) => ({ name, kind, kindModifiers: kindModifiersFromExtension(extension), sortText: SortText.LocationPriority, replacementSpan: span }));
            return { isGlobalCompletion, isMemberCompletion: false, isNewIdentifierLocation, entries };
        }
        function kindModifiersFromExtension(extension) {
            switch (extension) {
                case ".d.ts" /* Dts */:
                    return ".d.ts" /* dtsModifier */;
                case ".js" /* Js */:
                    return ".js" /* jsModifier */;
                case ".json" /* Json */:
                    return ".json" /* jsonModifier */;
                case ".jsx" /* Jsx */:
                    return ".jsx" /* jsxModifier */;
                case ".ts" /* Ts */:
                    return ".ts" /* tsModifier */;
                case ".tsx" /* Tsx */:
                    return ".tsx" /* tsxModifier */;
                case ".d.mts" /* Dmts */:
                    return ".d.mts" /* dmtsModifier */;
                case ".mjs" /* Mjs */:
                    return ".mjs" /* mjsModifier */;
                case ".mts" /* Mts */:
                    return ".mts" /* mtsModifier */;
                case ".d.cts" /* Dcts */:
                    return ".d.cts" /* dctsModifier */;
                case ".cjs" /* Cjs */:
                    return ".cjs" /* cjsModifier */;
                case ".cts" /* Cts */:
                    return ".cts" /* ctsModifier */;
                case ".tsbuildinfo" /* TsBuildInfo */:
                    return Debug.fail(`Extension ${".tsbuildinfo" /* TsBuildInfo */} is unsupported.`);
                case void 0:
                    return "" /* none */;
                default:
                    return Debug.assertNever(extension);
            }
        }
        function getStringLiteralCompletionEntries(sourceFile, node, position, program, host, preferences) {
            const typeChecker = program.getTypeChecker();
            const parent2 = walkUpParentheses(node.parent);
            switch (parent2.kind) {
                case 201 /* LiteralType */: {
                    const grandParent = walkUpParentheses(parent2.parent);
                    if (grandParent.kind === 205 /* ImportType */) {
                        return { kind: 0 /* Paths */, paths: getStringLiteralCompletionsFromModuleNames(sourceFile, node, program, host, preferences) };
                    }
                    return fromUnionableLiteralType(grandParent);
                }
                case 303 /* PropertyAssignment */:
                    if (isObjectLiteralExpression(parent2.parent) && parent2.name === node) {
                        return stringLiteralCompletionsForObjectLiteral(typeChecker, parent2.parent);
                    }
                    return fromContextualType() || fromContextualType(0 /* None */);
                case 212 /* ElementAccessExpression */: {
                    const { expression, argumentExpression } = parent2;
                    if (node === skipParentheses(argumentExpression)) {
                        return stringLiteralCompletionsFromProperties(typeChecker.getTypeAtLocation(expression));
                    }
                    return void 0;
                }
                case 213 /* CallExpression */:
                case 214 /* NewExpression */:
                case 291 /* JsxAttribute */:
                    if (!isRequireCallArgument(node) && !isImportCall(parent2)) {
                        const argumentInfo = ts_SignatureHelp_exports.getArgumentInfoForCompletions(parent2.kind === 291 /* JsxAttribute */ ? parent2.parent : node, position, sourceFile, typeChecker);
                        return argumentInfo && getStringLiteralCompletionsFromSignature(argumentInfo.invocation, node, argumentInfo, typeChecker) || fromContextualType(0 /* None */);
                    }
                case 272 /* ImportDeclaration */:
                case 278 /* ExportDeclaration */:
                case 283 /* ExternalModuleReference */:
                    return { kind: 0 /* Paths */, paths: getStringLiteralCompletionsFromModuleNames(sourceFile, node, program, host, preferences) };
                case 296 /* CaseClause */:
                    const tracker = newCaseClauseTracker(typeChecker, parent2.parent.clauses);
                    const contextualTypes = fromContextualType();
                    if (!contextualTypes) {
                        return;
                    }
                    const literals = contextualTypes.types.filter((literal) => !tracker.hasValue(literal.value));
                    return { kind: 2 /* Types */, types: literals, isNewIdentifier: false };
                default:
                    return fromContextualType() || fromContextualType(0 /* None */);
            }
            function fromUnionableLiteralType(grandParent) {
                switch (grandParent.kind) {
                    case 233 /* ExpressionWithTypeArguments */:
                    case 183 /* TypeReference */: {
                        const typeArgument = findAncestor(parent2, (n) => n.parent === grandParent);
                        if (typeArgument) {
                            return { kind: 2 /* Types */, types: getStringLiteralTypes(typeChecker.getTypeArgumentConstraint(typeArgument)), isNewIdentifier: false };
                        }
                        return void 0;
                    }
                    case 199 /* IndexedAccessType */:
                        const { indexType, objectType } = grandParent;
                        if (!rangeContainsPosition(indexType, position)) {
                            return void 0;
                        }
                        return stringLiteralCompletionsFromProperties(typeChecker.getTypeFromTypeNode(objectType));
                    case 192 /* UnionType */: {
                        const result = fromUnionableLiteralType(walkUpParentheses(grandParent.parent));
                        if (!result) {
                            return void 0;
                        }
                        const alreadyUsedTypes = getAlreadyUsedTypesInStringLiteralUnion(grandParent, parent2);
                        if (result.kind === 1 /* Properties */) {
                            return { kind: 1 /* Properties */, symbols: result.symbols.filter((sym) => !contains(alreadyUsedTypes, sym.name)), hasIndexSignature: result.hasIndexSignature };
                        }
                        return { kind: 2 /* Types */, types: result.types.filter((t) => !contains(alreadyUsedTypes, t.value)), isNewIdentifier: false };
                    }
                    default:
                        return void 0;
                }
            }
            function fromContextualType(contextFlags = 4 /* Completions */) {
                const types = getStringLiteralTypes(getContextualTypeFromParent(node, typeChecker, contextFlags));
                if (!types.length) {
                    return;
                }
                return { kind: 2 /* Types */, types, isNewIdentifier: false };
            }
        }
        function walkUpParentheses(node) {
            switch (node.kind) {
                case 196 /* ParenthesizedType */:
                    return walkUpParenthesizedTypes(node);
                case 217 /* ParenthesizedExpression */:
                    return walkUpParenthesizedExpressions(node);
                default:
                    return node;
            }
        }
        function getAlreadyUsedTypesInStringLiteralUnion(union, current) {
            return mapDefined(union.types, (type) => type !== current && isLiteralTypeNode(type) && isStringLiteral(type.literal) ? type.literal.text : void 0);
        }
        function getStringLiteralCompletionsFromSignature(call, arg, argumentInfo, checker) {
            let isNewIdentifier = false;
            const uniques = /* @__PURE__ */ new Map();
            const editingArgument = isJsxOpeningLikeElement(call) ? Debug.checkDefined(findAncestor(arg.parent, isJsxAttribute)) : arg;
            const candidates = checker.getCandidateSignaturesForStringLiteralCompletions(call, editingArgument);
            const types = flatMap(candidates, (candidate) => {
                if (!signatureHasRestParameter(candidate) && argumentInfo.argumentCount > candidate.parameters.length)
                    return;
                let type = candidate.getTypeParameterAtPosition(argumentInfo.argumentIndex);
                if (isJsxOpeningLikeElement(call)) {
                    const propType = checker.getTypeOfPropertyOfType(type, getTextOfJsxAttributeName(editingArgument.name));
                    if (propType) {
                        type = propType;
                    }
                }
                isNewIdentifier = isNewIdentifier || !!(type.flags & 4 /* String */);
                return getStringLiteralTypes(type, uniques);
            });
            return length(types) ? { kind: 2 /* Types */, types, isNewIdentifier } : void 0;
        }
        function stringLiteralCompletionsFromProperties(type) {
            return type && {
                kind: 1 /* Properties */,
                symbols: filter(type.getApparentProperties(), (prop) => !(prop.valueDeclaration && isPrivateIdentifierClassElementDeclaration(prop.valueDeclaration))),
                hasIndexSignature: hasIndexSignature(type)
            };
        }
        function stringLiteralCompletionsForObjectLiteral(checker, objectLiteralExpression) {
            const contextualType = checker.getContextualType(objectLiteralExpression);
            if (!contextualType)
                return void 0;
            const completionsType = checker.getContextualType(objectLiteralExpression, 4 /* Completions */);
            const symbols = getPropertiesForObjectExpression(contextualType, completionsType, objectLiteralExpression, checker);
            return {
                kind: 1 /* Properties */,
                symbols,
                hasIndexSignature: hasIndexSignature(contextualType)
            };
        }
        function getStringLiteralTypes(type, uniques = /* @__PURE__ */ new Map()) {
            if (!type)
                return emptyArray;
            type = skipConstraint(type);
            return type.isUnion() ? flatMap(type.types, (t) => getStringLiteralTypes(t, uniques)) : type.isStringLiteral() && !(type.flags & 1024 /* EnumLiteral */) && addToSeen(uniques, type.value) ? [type] : emptyArray;
        }
        function nameAndKind(name, kind, extension) {
            return { name, kind, extension };
        }
        function directoryResult(name) {
            return nameAndKind(name, "directory" /* directory */, 
            /*extension*/
            void 0);
        }
        function addReplacementSpans(text, textStart, names) {
            const span = getDirectoryFragmentTextSpan(text, textStart);
            const wholeSpan = text.length === 0 ? void 0 : createTextSpan(textStart, text.length);
            return names.map(({ name, kind, extension }) => name.includes(directorySeparator) || name.includes(altDirectorySeparator) ? { name, kind, extension, span: wholeSpan } : { name, kind, extension, span });
        }
        function getStringLiteralCompletionsFromModuleNames(sourceFile, node, program, host, preferences) {
            return addReplacementSpans(node.text, node.getStart(sourceFile) + 1, getStringLiteralCompletionsFromModuleNamesWorker(sourceFile, node, program, host, preferences));
        }
        function getStringLiteralCompletionsFromModuleNamesWorker(sourceFile, node, program, host, preferences) {
            const literalValue = normalizeSlashes(node.text);
            const mode = isStringLiteralLike(node) ? program.getModeForUsageLocation(sourceFile, node) : void 0;
            const scriptPath = sourceFile.path;
            const scriptDirectory = getDirectoryPath(scriptPath);
            const compilerOptions = program.getCompilerOptions();
            const typeChecker = program.getTypeChecker();
            const extensionOptions = getExtensionOptions(compilerOptions, 1 /* ModuleSpecifier */, sourceFile, typeChecker, preferences, mode);
            return isPathRelativeToScript(literalValue) || !compilerOptions.baseUrl && !compilerOptions.paths && (isRootedDiskPath(literalValue) || isUrl(literalValue)) ? getCompletionEntriesForRelativeModules(literalValue, scriptDirectory, compilerOptions, host, scriptPath, extensionOptions) : getCompletionEntriesForNonRelativeModules(literalValue, scriptDirectory, mode, compilerOptions, host, extensionOptions, typeChecker);
        }
        function getExtensionOptions(compilerOptions, referenceKind, importingSourceFile, typeChecker, preferences, resolutionMode) {
            return {
                extensionsToSearch: flatten(getSupportedExtensionsForModuleResolution(compilerOptions, typeChecker)),
                referenceKind,
                importingSourceFile,
                endingPreference: preferences == null ? void 0 : preferences.importModuleSpecifierEnding,
                resolutionMode
            };
        }
        function getCompletionEntriesForRelativeModules(literalValue, scriptDirectory, compilerOptions, host, scriptPath, extensionOptions) {
            if (compilerOptions.rootDirs) {
                return getCompletionEntriesForDirectoryFragmentWithRootDirs(compilerOptions.rootDirs, literalValue, scriptDirectory, extensionOptions, compilerOptions, host, scriptPath);
            }
            else {
                return arrayFrom(getCompletionEntriesForDirectoryFragment(literalValue, scriptDirectory, extensionOptions, host, 
                /*moduleSpecifierIsRelative*/
                true, scriptPath).values());
            }
        }
        function getSupportedExtensionsForModuleResolution(compilerOptions, typeChecker) {
            const ambientModulesExtensions = !typeChecker ? [] : mapDefined(typeChecker.getAmbientModules(), (module2) => {
                const name = module2.name.slice(1, -1);
                if (!name.startsWith("*.") || name.includes("/"))
                    return;
                return name.slice(1);
            });
            const extensions = [...getSupportedExtensions(compilerOptions), ambientModulesExtensions];
            const moduleResolution = getEmitModuleResolutionKind(compilerOptions);
            return moduleResolutionUsesNodeModules(moduleResolution) ? getSupportedExtensionsWithJsonIfResolveJsonModule(compilerOptions, extensions) : extensions;
        }
        function getBaseDirectoriesFromRootDirs(rootDirs, basePath, scriptDirectory, ignoreCase) {
            rootDirs = rootDirs.map((rootDirectory) => ensureTrailingDirectorySeparator(normalizePath(isRootedDiskPath(rootDirectory) ? rootDirectory : combinePaths(basePath, rootDirectory))));
            const relativeDirectory = firstDefined(rootDirs, (rootDirectory) => containsPath(rootDirectory, scriptDirectory, basePath, ignoreCase) ? scriptDirectory.substr(rootDirectory.length) : void 0);
            return deduplicate([...rootDirs.map((rootDirectory) => combinePaths(rootDirectory, relativeDirectory)), scriptDirectory].map((baseDir) => removeTrailingDirectorySeparator(baseDir)), equateStringsCaseSensitive, compareStringsCaseSensitive);
        }
        function getCompletionEntriesForDirectoryFragmentWithRootDirs(rootDirs, fragment, scriptDirectory, extensionOptions, compilerOptions, host, exclude) {
            const basePath = compilerOptions.project || host.getCurrentDirectory();
            const ignoreCase = !(host.useCaseSensitiveFileNames && host.useCaseSensitiveFileNames());
            const baseDirectories = getBaseDirectoriesFromRootDirs(rootDirs, basePath, scriptDirectory, ignoreCase);
            return deduplicate(flatMap(baseDirectories, (baseDirectory) => arrayFrom(getCompletionEntriesForDirectoryFragment(fragment, baseDirectory, extensionOptions, host, 
            /*moduleSpecifierIsRelative*/
            true, exclude).values())), (itemA, itemB) => itemA.name === itemB.name && itemA.kind === itemB.kind && itemA.extension === itemB.extension);
        }
        function getCompletionEntriesForDirectoryFragment(fragment, scriptDirectory, extensionOptions, host, moduleSpecifierIsRelative, exclude, result = createNameAndKindSet()) {
            var _a;
            if (fragment === void 0) {
                fragment = "";
            }
            fragment = normalizeSlashes(fragment);
            if (!hasTrailingDirectorySeparator(fragment)) {
                fragment = getDirectoryPath(fragment);
            }
            if (fragment === "") {
                fragment = "." + directorySeparator;
            }
            fragment = ensureTrailingDirectorySeparator(fragment);
            const absolutePath = resolvePath(scriptDirectory, fragment);
            const baseDirectory = hasTrailingDirectorySeparator(absolutePath) ? absolutePath : getDirectoryPath(absolutePath);
            if (!moduleSpecifierIsRelative) {
                const packageJsonPath = findPackageJson(baseDirectory, host);
                if (packageJsonPath) {
                    const packageJson = readJson(packageJsonPath, host);
                    const typesVersions = packageJson.typesVersions;
                    if (typeof typesVersions === "object") {
                        const versionPaths = (_a = getPackageJsonTypesVersionsPaths(typesVersions)) == null ? void 0 : _a.paths;
                        if (versionPaths) {
                            const packageDirectory = getDirectoryPath(packageJsonPath);
                            const pathInPackage = absolutePath.slice(ensureTrailingDirectorySeparator(packageDirectory).length);
                            if (addCompletionEntriesFromPaths(result, pathInPackage, packageDirectory, extensionOptions, host, versionPaths)) {
                                return result;
                            }
                        }
                    }
                }
            }
            const ignoreCase = !(host.useCaseSensitiveFileNames && host.useCaseSensitiveFileNames());
            if (!tryDirectoryExists(host, baseDirectory))
                return result;
            const files = tryReadDirectory(host, baseDirectory, extensionOptions.extensionsToSearch, 
            /*exclude*/
            void 0, 
            /*include*/
            ["./*"]);
            if (files) {
                for (let filePath of files) {
                    filePath = normalizePath(filePath);
                    if (exclude && comparePaths(filePath, exclude, scriptDirectory, ignoreCase) === 0 /* EqualTo */) {
                        continue;
                    }
                    const { name, extension } = getFilenameWithExtensionOption(getBaseFileName(filePath), host.getCompilationSettings(), extensionOptions, 
                    /*isExportsWildcard*/
                    false);
                    result.add(nameAndKind(name, "script" /* scriptElement */, extension));
                }
            }
            const directories = tryGetDirectories(host, baseDirectory);
            if (directories) {
                for (const directory of directories) {
                    const directoryName = getBaseFileName(normalizePath(directory));
                    if (directoryName !== "@types") {
                        result.add(directoryResult(directoryName));
                    }
                }
            }
            return result;
        }
        function getFilenameWithExtensionOption(name, compilerOptions, extensionOptions, isExportsWildcard) {
            const nonJsResult = ts_moduleSpecifiers_exports.tryGetRealFileNameForNonJsDeclarationFileName(name);
            if (nonJsResult) {
                return { name: nonJsResult, extension: tryGetExtensionFromPath2(nonJsResult) };
            }
            if (extensionOptions.referenceKind === 0 /* Filename */) {
                return { name, extension: tryGetExtensionFromPath2(name) };
            }
            let allowedEndings = getModuleSpecifierPreferences({ importModuleSpecifierEnding: extensionOptions.endingPreference }, compilerOptions, extensionOptions.importingSourceFile).getAllowedEndingsInPreferredOrder(extensionOptions.resolutionMode);
            if (isExportsWildcard) {
                allowedEndings = allowedEndings.filter((e) => e !== 0 /* Minimal */ && e !== 1 /* Index */);
            }
            if (allowedEndings[0] === 3 /* TsExtension */) {
                if (fileExtensionIsOneOf(name, supportedTSImplementationExtensions)) {
                    return { name, extension: tryGetExtensionFromPath2(name) };
                }
                const outputExtension2 = ts_moduleSpecifiers_exports.tryGetJSExtensionForFile(name, compilerOptions);
                return outputExtension2 ? { name: changeExtension(name, outputExtension2), extension: outputExtension2 } : { name, extension: tryGetExtensionFromPath2(name) };
            }
            if (!isExportsWildcard && (allowedEndings[0] === 0 /* Minimal */ || allowedEndings[0] === 1 /* Index */) && fileExtensionIsOneOf(name, [".js" /* Js */, ".jsx" /* Jsx */, ".ts" /* Ts */, ".tsx" /* Tsx */, ".d.ts" /* Dts */])) {
                return { name: removeFileExtension(name), extension: tryGetExtensionFromPath2(name) };
            }
            const outputExtension = ts_moduleSpecifiers_exports.tryGetJSExtensionForFile(name, compilerOptions);
            return outputExtension ? { name: changeExtension(name, outputExtension), extension: outputExtension } : { name, extension: tryGetExtensionFromPath2(name) };
        }
        function addCompletionEntriesFromPaths(result, fragment, baseDirectory, extensionOptions, host, paths) {
            const getPatternsForKey = (key) => paths[key];
            const comparePaths2 = (a, b) => {
                const patternA = tryParsePattern(a);
                const patternB = tryParsePattern(b);
                const lengthA = typeof patternA === "object" ? patternA.prefix.length : a.length;
                const lengthB = typeof patternB === "object" ? patternB.prefix.length : b.length;
                return compareValues(lengthB, lengthA);
            };
            return addCompletionEntriesFromPathsOrExports(result, 
            /*isExports*/
            false, fragment, baseDirectory, extensionOptions, host, getOwnKeys(paths), getPatternsForKey, comparePaths2);
        }
        function addCompletionEntriesFromPathsOrExports(result, isExports, fragment, baseDirectory, extensionOptions, host, keys, getPatternsForKey, comparePaths2) {
            let pathResults = [];
            let matchedPath;
            for (const key of keys) {
                if (key === ".")
                    continue;
                const keyWithoutLeadingDotSlash = key.replace(/^\.\//, "");
                const patterns = getPatternsForKey(key);
                if (patterns) {
                    const pathPattern = tryParsePattern(keyWithoutLeadingDotSlash);
                    if (!pathPattern)
                        continue;
                    const isMatch = typeof pathPattern === "object" && isPatternMatch(pathPattern, fragment);
                    const isLongestMatch = isMatch && (matchedPath === void 0 || comparePaths2(key, matchedPath) === -1 /* LessThan */);
                    if (isLongestMatch) {
                        matchedPath = key;
                        pathResults = pathResults.filter((r) => !r.matchedPattern);
                    }
                    if (typeof pathPattern === "string" || matchedPath === void 0 || comparePaths2(key, matchedPath) !== 1 /* GreaterThan */) {
                        pathResults.push({
                            matchedPattern: isMatch,
                            results: getCompletionsForPathMapping(keyWithoutLeadingDotSlash, patterns, fragment, baseDirectory, extensionOptions, isExports && isMatch, host).map(({ name, kind, extension }) => nameAndKind(name, kind, extension))
                        });
                    }
                }
            }
            pathResults.forEach((pathResult) => pathResult.results.forEach((r) => result.add(r)));
            return matchedPath !== void 0;
        }
        function getCompletionEntriesForNonRelativeModules(fragment, scriptPath, mode, compilerOptions, host, extensionOptions, typeChecker) {
            const { baseUrl, paths } = compilerOptions;
            const result = createNameAndKindSet();
            const moduleResolution = getEmitModuleResolutionKind(compilerOptions);
            if (baseUrl) {
                const absolute = normalizePath(combinePaths(host.getCurrentDirectory(), baseUrl));
                getCompletionEntriesForDirectoryFragment(fragment, absolute, extensionOptions, host, 
                /*moduleSpecifierIsRelative*/
                false, 
                /*exclude*/
                void 0, result);
            }
            if (paths) {
                const absolute = getPathsBasePath(compilerOptions, host);
                addCompletionEntriesFromPaths(result, fragment, absolute, extensionOptions, host, paths);
            }
            const fragmentDirectory = getFragmentDirectory(fragment);
            for (const ambientName of getAmbientModuleCompletions(fragment, fragmentDirectory, typeChecker)) {
                result.add(nameAndKind(ambientName, "external module name" /* externalModuleName */, 
                /*extension*/
                void 0));
            }
            getCompletionEntriesFromTypings(host, compilerOptions, scriptPath, fragmentDirectory, extensionOptions, result);
            if (moduleResolutionUsesNodeModules(moduleResolution)) {
                let foundGlobal = false;
                if (fragmentDirectory === void 0) {
                    for (const moduleName of enumerateNodeModulesVisibleToScript(host, scriptPath)) {
                        const moduleResult = nameAndKind(moduleName, "external module name" /* externalModuleName */, 
                        /*extension*/
                        void 0);
                        if (!result.has(moduleResult.name)) {
                            foundGlobal = true;
                            result.add(moduleResult);
                        }
                    }
                }
                if (!foundGlobal) {
                    let ancestorLookup = (ancestor) => {
                        const nodeModules = combinePaths(ancestor, "node_modules");
                        if (tryDirectoryExists(host, nodeModules)) {
                            getCompletionEntriesForDirectoryFragment(fragment, nodeModules, extensionOptions, host, 
                            /*moduleSpecifierIsRelative*/
                            false, 
                            /*exclude*/
                            void 0, result);
                        }
                    };
                    if (fragmentDirectory && getResolvePackageJsonExports(compilerOptions)) {
                        const nodeModulesDirectoryLookup = ancestorLookup;
                        ancestorLookup = (ancestor) => {
                            const components = getPathComponents(fragment);
                            components.shift();
                            let packagePath = components.shift();
                            if (!packagePath) {
                                return nodeModulesDirectoryLookup(ancestor);
                            }
                            if (startsWith(packagePath, "@")) {
                                const subName = components.shift();
                                if (!subName) {
                                    return nodeModulesDirectoryLookup(ancestor);
                                }
                                packagePath = combinePaths(packagePath, subName);
                            }
                            const packageDirectory = combinePaths(ancestor, "node_modules", packagePath);
                            const packageFile = combinePaths(packageDirectory, "package.json");
                            if (tryFileExists(host, packageFile)) {
                                const packageJson = readJson(packageFile, host);
                                const exports = packageJson.exports;
                                if (exports) {
                                    if (typeof exports !== "object" || exports === null) {
                                        return;
                                    }
                                    const keys = getOwnKeys(exports);
                                    const fragmentSubpath = components.join("/") + (components.length && hasTrailingDirectorySeparator(fragment) ? "/" : "");
                                    const conditions = getConditions(compilerOptions, mode);
                                    addCompletionEntriesFromPathsOrExports(result, 
                                    /*isExports*/
                                    true, fragmentSubpath, packageDirectory, extensionOptions, host, keys, (key) => singleElementArray(getPatternFromFirstMatchingCondition(exports[key], conditions)), comparePatternKeys);
                                    return;
                                }
                            }
                            return nodeModulesDirectoryLookup(ancestor);
                        };
                    }
                    forEachAncestorDirectory(scriptPath, ancestorLookup);
                }
            }
            return arrayFrom(result.values());
        }
        function getPatternFromFirstMatchingCondition(target, conditions) {
            if (typeof target === "string") {
                return target;
            }
            if (target && typeof target === "object" && !isArray(target)) {
                for (const condition in target) {
                    if (condition === "default" || conditions.includes(condition) || isApplicableVersionedTypesKey(conditions, condition)) {
                        const pattern = target[condition];
                        return getPatternFromFirstMatchingCondition(pattern, conditions);
                    }
                }
            }
        }
        function getFragmentDirectory(fragment) {
            return containsSlash(fragment) ? hasTrailingDirectorySeparator(fragment) ? fragment : getDirectoryPath(fragment) : void 0;
        }
        function getCompletionsForPathMapping(path, patterns, fragment, packageDirectory, extensionOptions, isExportsWildcard, host) {
            if (!endsWith(path, "*")) {
                return !path.includes("*") ? justPathMappingName(path, "script" /* scriptElement */) : emptyArray;
            }
            const pathPrefix = path.slice(0, path.length - 1);
            const remainingFragment = tryRemovePrefix(fragment, pathPrefix);
            if (remainingFragment === void 0) {
                const starIsFullPathComponent = path[path.length - 2] === "/";
                return starIsFullPathComponent ? justPathMappingName(pathPrefix, "directory" /* directory */) : flatMap(patterns, (pattern) => {
                    var _a;
                    return (_a = getModulesForPathsPattern("", packageDirectory, pattern, extensionOptions, isExportsWildcard, host)) == null ? void 0 : _a.map(({ name, ...rest }) => ({ name: pathPrefix + name, ...rest }));
                });
            }
            return flatMap(patterns, (pattern) => getModulesForPathsPattern(remainingFragment, packageDirectory, pattern, extensionOptions, isExportsWildcard, host));
            function justPathMappingName(name, kind) {
                return startsWith(name, fragment) ? [{ name: removeTrailingDirectorySeparator(name), kind, extension: void 0 }] : emptyArray;
            }
        }
        function getModulesForPathsPattern(fragment, packageDirectory, pattern, extensionOptions, isExportsWildcard, host) {
            if (!host.readDirectory) {
                return void 0;
            }
            const parsed = tryParsePattern(pattern);
            if (parsed === void 0 || isString(parsed)) {
                return void 0;
            }
            const normalizedPrefix = resolvePath(parsed.prefix);
            const normalizedPrefixDirectory = hasTrailingDirectorySeparator(parsed.prefix) ? normalizedPrefix : getDirectoryPath(normalizedPrefix);
            const normalizedPrefixBase = hasTrailingDirectorySeparator(parsed.prefix) ? "" : getBaseFileName(normalizedPrefix);
            const fragmentHasPath = containsSlash(fragment);
            const fragmentDirectory = fragmentHasPath ? hasTrailingDirectorySeparator(fragment) ? fragment : getDirectoryPath(fragment) : void 0;
            const expandedPrefixDirectory = fragmentHasPath ? combinePaths(normalizedPrefixDirectory, normalizedPrefixBase + fragmentDirectory) : normalizedPrefixDirectory;
            const normalizedSuffix = normalizePath(parsed.suffix);
            const declarationExtension = normalizedSuffix && getDeclarationEmitExtensionForPath("_" + normalizedSuffix);
            const matchingSuffixes = declarationExtension ? [changeExtension(normalizedSuffix, declarationExtension), normalizedSuffix] : [normalizedSuffix];
            const baseDirectory = normalizePath(combinePaths(packageDirectory, expandedPrefixDirectory));
            const completePrefix = fragmentHasPath ? baseDirectory : ensureTrailingDirectorySeparator(baseDirectory) + normalizedPrefixBase;
            const includeGlobs = normalizedSuffix ? matchingSuffixes.map((suffix) => "**/*" + suffix) : ["./*"];
            const matches = mapDefined(tryReadDirectory(host, baseDirectory, extensionOptions.extensionsToSearch, 
            /*exclude*/
            void 0, includeGlobs), (match) => {
                const trimmedWithPattern = trimPrefixAndSuffix(match);
                if (trimmedWithPattern) {
                    if (containsSlash(trimmedWithPattern)) {
                        return directoryResult(getPathComponents(removeLeadingDirectorySeparator(trimmedWithPattern))[1]);
                    }
                    const { name, extension } = getFilenameWithExtensionOption(trimmedWithPattern, host.getCompilationSettings(), extensionOptions, isExportsWildcard);
                    return nameAndKind(name, "script" /* scriptElement */, extension);
                }
            });
            const directories = normalizedSuffix ? emptyArray : mapDefined(tryGetDirectories(host, baseDirectory), (dir) => dir === "node_modules" ? void 0 : directoryResult(dir));
            return [...matches, ...directories];
            function trimPrefixAndSuffix(path) {
                return firstDefined(matchingSuffixes, (suffix) => {
                    const inner = withoutStartAndEnd(normalizePath(path), completePrefix, suffix);
                    return inner === void 0 ? void 0 : removeLeadingDirectorySeparator(inner);
                });
            }
        }
        function withoutStartAndEnd(s, start, end) {
            return startsWith(s, start) && endsWith(s, end) ? s.slice(start.length, s.length - end.length) : void 0;
        }
        function removeLeadingDirectorySeparator(path) {
            return path[0] === directorySeparator ? path.slice(1) : path;
        }
        function getAmbientModuleCompletions(fragment, fragmentDirectory, checker) {
            const ambientModules = checker.getAmbientModules().map((sym) => stripQuotes(sym.name));
            const nonRelativeModuleNames = ambientModules.filter((moduleName) => startsWith(moduleName, fragment) && !moduleName.includes("*"));
            if (fragmentDirectory !== void 0) {
                const moduleNameWithSeparator = ensureTrailingDirectorySeparator(fragmentDirectory);
                return nonRelativeModuleNames.map((nonRelativeModuleName) => removePrefix(nonRelativeModuleName, moduleNameWithSeparator));
            }
            return nonRelativeModuleNames;
        }
        function getTripleSlashReferenceCompletion(sourceFile, position, compilerOptions, host) {
            const token = getTokenAtPosition(sourceFile, position);
            const commentRanges = getLeadingCommentRanges(sourceFile.text, token.pos);
            const range = commentRanges && find(commentRanges, (commentRange) => position >= commentRange.pos && position <= commentRange.end);
            if (!range) {
                return void 0;
            }
            const text = sourceFile.text.slice(range.pos, position);
            const match = tripleSlashDirectiveFragmentRegex.exec(text);
            if (!match) {
                return void 0;
            }
            const [, prefix, kind, toComplete] = match;
            const scriptPath = getDirectoryPath(sourceFile.path);
            const names = kind === "path" ? getCompletionEntriesForDirectoryFragment(toComplete, scriptPath, getExtensionOptions(compilerOptions, 0 /* Filename */, sourceFile), host, 
            /*moduleSpecifierIsRelative*/
            true, sourceFile.path) : kind === "types" ? getCompletionEntriesFromTypings(host, compilerOptions, scriptPath, getFragmentDirectory(toComplete), getExtensionOptions(compilerOptions, 1 /* ModuleSpecifier */, sourceFile)) : Debug.fail();
            return addReplacementSpans(toComplete, range.pos + prefix.length, arrayFrom(names.values()));
        }
        function getCompletionEntriesFromTypings(host, options, scriptPath, fragmentDirectory, extensionOptions, result = createNameAndKindSet()) {
            const seen = /* @__PURE__ */ new Map();
            const typeRoots = tryAndIgnoreErrors(() => getEffectiveTypeRoots(options, host)) || emptyArray;
            for (const root of typeRoots) {
                getCompletionEntriesFromDirectories(root);
            }
            for (const packageJson of findPackageJsons(scriptPath, host)) {
                const typesDir = combinePaths(getDirectoryPath(packageJson), "node_modules/@types");
                getCompletionEntriesFromDirectories(typesDir);
            }
            return result;
            function getCompletionEntriesFromDirectories(directory) {
                if (!tryDirectoryExists(host, directory))
                    return;
                for (const typeDirectoryName of tryGetDirectories(host, directory)) {
                    const packageName = unmangleScopedPackageName(typeDirectoryName);
                    if (options.types && !contains(options.types, packageName))
                        continue;
                    if (fragmentDirectory === void 0) {
                        if (!seen.has(packageName)) {
                            result.add(nameAndKind(packageName, "external module name" /* externalModuleName */, 
                            /*extension*/
                            void 0));
                            seen.set(packageName, true);
                        }
                    }
                    else {
                        const baseDirectory = combinePaths(directory, typeDirectoryName);
                        const remainingFragment = tryRemoveDirectoryPrefix(fragmentDirectory, packageName, hostGetCanonicalFileName(host));
                        if (remainingFragment !== void 0) {
                            getCompletionEntriesForDirectoryFragment(remainingFragment, baseDirectory, extensionOptions, host, 
                            /*moduleSpecifierIsRelative*/
                            false, 
                            /*exclude*/
                            void 0, result);
                        }
                    }
                }
            }
        }
        function enumerateNodeModulesVisibleToScript(host, scriptPath) {
            if (!host.readFile || !host.fileExists)
                return emptyArray;
            const result = [];
            for (const packageJson of findPackageJsons(scriptPath, host)) {
                const contents = readJson(packageJson, host);
                for (const key of nodeModulesDependencyKeys) {
                    const dependencies = contents[key];
                    if (!dependencies)
                        continue;
                    for (const dep in dependencies) {
                        if (hasProperty(dependencies, dep) && !startsWith(dep, "@types/")) {
                            result.push(dep);
                        }
                    }
                }
            }
            return result;
        }
        function getDirectoryFragmentTextSpan(text, textStart) {
            const index = Math.max(text.lastIndexOf(directorySeparator), text.lastIndexOf(altDirectorySeparator));
            const offset = index !== -1 ? index + 1 : 0;
            const length2 = text.length - offset;
            return length2 === 0 || isIdentifierText(text.substr(offset, length2), 99 /* ESNext */) ? void 0 : createTextSpan(textStart + offset, length2);
        }
        function isPathRelativeToScript(path) {
            if (path && path.length >= 2 && path.charCodeAt(0) === 46 /* dot */) {
                const slashIndex = path.length >= 3 && path.charCodeAt(1) === 46 /* dot */ ? 2 : 1;
                const slashCharCode = path.charCodeAt(slashIndex);
                return slashCharCode === 47 /* slash */ || slashCharCode === 92 /* backslash */;
            }
            return false;
        }
        function containsSlash(fragment) {
            return fragment.includes(directorySeparator);
        }
        function isRequireCallArgument(node) {
            return isCallExpression(node.parent) && firstOrUndefined(node.parent.arguments) === node && isIdentifier(node.parent.expression) && node.parent.expression.escapedText === "require";
        }
        var kindPrecedence, tripleSlashDirectiveFragmentRegex, nodeModulesDependencyKeys;
        var init_stringCompletions = __esm({
            "src/services/stringCompletions.ts"() {
                "use strict";
                init_moduleSpecifiers();
                init_ts4();
                init_ts_Completions();
                kindPrecedence = {
                    ["directory" /* directory */]: 0,
                    ["script" /* scriptElement */]: 1,
                    ["external module name" /* externalModuleName */]: 2
                };
                tripleSlashDirectiveFragmentRegex = /^(\/\/\/\s*<reference\s+(path|types)\s*=\s*(?:'|"))([^\3"]*)$/;
                nodeModulesDependencyKeys = ["dependencies", "devDependencies", "peerDependencies", "optionalDependencies"];
            }
        });
        // src/services/_namespaces/ts.Completions.StringCompletions.ts
        var ts_Completions_StringCompletions_exports = {};
        __export(ts_Completions_StringCompletions_exports, {
            getStringLiteralCompletionDetails: () => getStringLiteralCompletionDetails,
            getStringLiteralCompletions: () => getStringLiteralCompletions
        });
        var init_ts_Completions_StringCompletions = __esm({
            "src/services/_namespaces/ts.Completions.StringCompletions.ts"() {
                "use strict";
                init_stringCompletions();
            }
        });
        // src/services/_namespaces/ts.Completions.ts
        var ts_Completions_exports = {};
        __export(ts_Completions_exports, {
            CompletionKind: () => CompletionKind,
            CompletionSource: () => CompletionSource,
            SortText: () => SortText,
            StringCompletions: () => ts_Completions_StringCompletions_exports,
            SymbolOriginInfoKind: () => SymbolOriginInfoKind,
            createCompletionDetails: () => createCompletionDetails,
            createCompletionDetailsForSymbol: () => createCompletionDetailsForSymbol,
            getCompletionEntriesFromSymbols: () => getCompletionEntriesFromSymbols,
            getCompletionEntryDetails: () => getCompletionEntryDetails,
            getCompletionEntrySymbol: () => getCompletionEntrySymbol,
            getCompletionsAtPosition: () => getCompletionsAtPosition,
            getPropertiesForObjectExpression: () => getPropertiesForObjectExpression,
            moduleSpecifierResolutionCacheAttemptLimit: () => moduleSpecifierResolutionCacheAttemptLimit,
            moduleSpecifierResolutionLimit: () => moduleSpecifierResolutionLimit
        });
        var init_ts_Completions = __esm({
            "src/services/_namespaces/ts.Completions.ts"() {
                "use strict";
                init_completions();
                init_ts_Completions_StringCompletions();
            }
        });
        // src/services/importTracker.ts
        function createImportTracker(sourceFiles, sourceFilesSet, checker, cancellationToken) {
            const allDirectImports = getDirectImportsMap(sourceFiles, checker, cancellationToken);
            return (exportSymbol, exportInfo, isForRename) => {
                const { directImports, indirectUsers } = getImportersForExport(sourceFiles, sourceFilesSet, allDirectImports, exportInfo, checker, cancellationToken);
                return { indirectUsers, ...getSearchesFromDirectImports(directImports, exportSymbol, exportInfo.exportKind, checker, isForRename) };
            };
        }
        function getImportersForExport(sourceFiles, sourceFilesSet, allDirectImports, { exportingModuleSymbol, exportKind }, checker, cancellationToken) {
            const markSeenDirectImport = nodeSeenTracker();
            const markSeenIndirectUser = nodeSeenTracker();
            const directImports = [];
            const isAvailableThroughGlobal = !!exportingModuleSymbol.globalExports;
            const indirectUserDeclarations = isAvailableThroughGlobal ? void 0 : [];
            handleDirectImports(exportingModuleSymbol);
            return { directImports, indirectUsers: getIndirectUsers() };
            function getIndirectUsers() {
                if (isAvailableThroughGlobal) {
                    return sourceFiles;
                }
                if (exportingModuleSymbol.declarations) {
                    for (const decl of exportingModuleSymbol.declarations) {
                        if (isExternalModuleAugmentation(decl) && sourceFilesSet.has(decl.getSourceFile().fileName)) {
                            addIndirectUser(decl);
                        }
                    }
                }
                return indirectUserDeclarations.map(getSourceFileOfNode);
            }
            function handleDirectImports(exportingModuleSymbol2) {
                const theseDirectImports = getDirectImports(exportingModuleSymbol2);
                if (theseDirectImports) {
                    for (const direct of theseDirectImports) {
                        if (!markSeenDirectImport(direct)) {
                            continue;
                        }
                        if (cancellationToken)
                            cancellationToken.throwIfCancellationRequested();
                        switch (direct.kind) {
                            case 213 /* CallExpression */:
                                if (isImportCall(direct)) {
                                    handleImportCall(direct);
                                    break;
                                }
                                if (!isAvailableThroughGlobal) {
                                    const parent2 = direct.parent;
                                    if (exportKind === 2 /* ExportEquals */ && parent2.kind === 260 /* VariableDeclaration */) {
                                        const { name } = parent2;
                                        if (name.kind === 80 /* Identifier */) {
                                            directImports.push(name);
                                            break;
                                        }
                                    }
                                }
                                break;
                            case 80 /* Identifier */:
                                break;
                            case 271 /* ImportEqualsDeclaration */:
                                handleNamespaceImport(direct, direct.name, hasSyntacticModifier(direct, 32 /* Export */), 
                                /*alreadyAddedDirect*/
                                false);
                                break;
                            case 272 /* ImportDeclaration */:
                                directImports.push(direct);
                                const namedBindings = direct.importClause && direct.importClause.namedBindings;
                                if (namedBindings && namedBindings.kind === 274 /* NamespaceImport */) {
                                    handleNamespaceImport(direct, namedBindings.name, 
                                    /*isReExport*/
                                    false, 
                                    /*alreadyAddedDirect*/
                                    true);
                                }
                                else if (!isAvailableThroughGlobal && isDefaultImport(direct)) {
                                    addIndirectUser(getSourceFileLikeForImportDeclaration(direct));
                                }
                                break;
                            case 278 /* ExportDeclaration */:
                                if (!direct.exportClause) {
                                    handleDirectImports(getContainingModuleSymbol(direct, checker));
                                }
                                else if (direct.exportClause.kind === 280 /* NamespaceExport */) {
                                    addIndirectUser(getSourceFileLikeForImportDeclaration(direct), 
                                    /*addTransitiveDependencies*/
                                    true);
                                }
                                else {
                                    directImports.push(direct);
                                }
                                break;
                            case 205 /* ImportType */:
                                if (!isAvailableThroughGlobal && direct.isTypeOf && !direct.qualifier && isExported2(direct)) {
                                    addIndirectUser(direct.getSourceFile(), 
                                    /*addTransitiveDependencies*/
                                    true);
                                }
                                directImports.push(direct);
                                break;
                            default:
                                Debug.failBadSyntaxKind(direct, "Unexpected import kind.");
                        }
                    }
                }
            }
            function handleImportCall(importCall) {
                const top = findAncestor(importCall, isAmbientModuleDeclaration) || importCall.getSourceFile();
                addIndirectUser(top, 
                /** addTransitiveDependencies */
                !!isExported2(importCall, 
                /*stopAtAmbientModule*/
                true));
            }
            function isExported2(node, stopAtAmbientModule = false) {
                return findAncestor(node, (node2) => {
                    if (stopAtAmbientModule && isAmbientModuleDeclaration(node2))
                        return "quit";
                    return canHaveModifiers(node2) && some(node2.modifiers, isExportModifier);
                });
            }
            function handleNamespaceImport(importDeclaration, name, isReExport, alreadyAddedDirect) {
                if (exportKind === 2 /* ExportEquals */) {
                    if (!alreadyAddedDirect)
                        directImports.push(importDeclaration);
                }
                else if (!isAvailableThroughGlobal) {
                    const sourceFileLike = getSourceFileLikeForImportDeclaration(importDeclaration);
                    Debug.assert(sourceFileLike.kind === 312 /* SourceFile */ || sourceFileLike.kind === 267 /* ModuleDeclaration */);
                    if (isReExport || findNamespaceReExports(sourceFileLike, name, checker)) {
                        addIndirectUser(sourceFileLike, 
                        /*addTransitiveDependencies*/
                        true);
                    }
                    else {
                        addIndirectUser(sourceFileLike);
                    }
                }
            }
            function addIndirectUser(sourceFileLike, addTransitiveDependencies = false) {
                Debug.assert(!isAvailableThroughGlobal);
                const isNew = markSeenIndirectUser(sourceFileLike);
                if (!isNew)
                    return;
                indirectUserDeclarations.push(sourceFileLike);
                if (!addTransitiveDependencies)
                    return;
                const moduleSymbol = checker.getMergedSymbol(sourceFileLike.symbol);
                if (!moduleSymbol)
                    return;
                Debug.assert(!!(moduleSymbol.flags & 1536 /* Module */));
                const directImports2 = getDirectImports(moduleSymbol);
                if (directImports2) {
                    for (const directImport of directImports2) {
                        if (!isImportTypeNode(directImport)) {
                            addIndirectUser(getSourceFileLikeForImportDeclaration(directImport), 
                            /*addTransitiveDependencies*/
                            true);
                        }
                    }
                }
            }
            function getDirectImports(moduleSymbol) {
                return allDirectImports.get(getSymbolId(moduleSymbol).toString());
            }
        }
        function getSearchesFromDirectImports(directImports, exportSymbol, exportKind, checker, isForRename) {
            const importSearches = [];
            const singleReferences = [];
            function addSearch(location, symbol) {
                importSearches.push([location, symbol]);
            }
            if (directImports) {
                for (const decl of directImports) {
                    handleImport(decl);
                }
            }
            return { importSearches, singleReferences };
            function handleImport(decl) {
                if (decl.kind === 271 /* ImportEqualsDeclaration */) {
                    if (isExternalModuleImportEquals(decl)) {
                        handleNamespaceImportLike(decl.name);
                    }
                    return;
                }
                if (decl.kind === 80 /* Identifier */) {
                    handleNamespaceImportLike(decl);
                    return;
                }
                if (decl.kind === 205 /* ImportType */) {
                    if (decl.qualifier) {
                        const firstIdentifier = getFirstIdentifier(decl.qualifier);
                        if (firstIdentifier.escapedText === symbolName(exportSymbol)) {
                            singleReferences.push(firstIdentifier);
                        }
                    }
                    else if (exportKind === 2 /* ExportEquals */) {
                        singleReferences.push(decl.argument.literal);
                    }
                    return;
                }
                if (decl.moduleSpecifier.kind !== 11 /* StringLiteral */) {
                    return;
                }
                if (decl.kind === 278 /* ExportDeclaration */) {
                    if (decl.exportClause && isNamedExports(decl.exportClause)) {
                        searchForNamedImport(decl.exportClause);
                    }
                    return;
                }
                const { name, namedBindings } = decl.importClause || { name: void 0, namedBindings: void 0 };
                if (namedBindings) {
                    switch (namedBindings.kind) {
                        case 274 /* NamespaceImport */:
                            handleNamespaceImportLike(namedBindings.name);
                            break;
                        case 275 /* NamedImports */:
                            if (exportKind === 0 /* Named */ || exportKind === 1 /* Default */) {
                                searchForNamedImport(namedBindings);
                            }
                            break;
                        default:
                            Debug.assertNever(namedBindings);
                    }
                }
                if (name && (exportKind === 1 /* Default */ || exportKind === 2 /* ExportEquals */) && (!isForRename || name.escapedText === symbolEscapedNameNoDefault(exportSymbol))) {
                    const defaultImportAlias = checker.getSymbolAtLocation(name);
                    addSearch(name, defaultImportAlias);
                }
            }
            function handleNamespaceImportLike(importName) {
                if (exportKind === 2 /* ExportEquals */ && (!isForRename || isNameMatch(importName.escapedText))) {
                    addSearch(importName, checker.getSymbolAtLocation(importName));
                }
            }
            function searchForNamedImport(namedBindings) {
                if (!namedBindings) {
                    return;
                }
                for (const element of namedBindings.elements) {
                    const { name, propertyName } = element;
                    if (!isNameMatch((propertyName || name).escapedText)) {
                        continue;
                    }
                    if (propertyName) {
                        singleReferences.push(propertyName);
                        if (!isForRename || name.escapedText === exportSymbol.escapedName) {
                            addSearch(name, checker.getSymbolAtLocation(name));
                        }
                    }
                    else {
                        const localSymbol = element.kind === 281 /* ExportSpecifier */ && element.propertyName ? checker.getExportSpecifierLocalTargetSymbol(element) : checker.getSymbolAtLocation(name);
                        addSearch(name, localSymbol);
                    }
                }
            }
            function isNameMatch(name) {
                return name === exportSymbol.escapedName || exportKind !== 0 /* Named */ && name === "default" /* Default */;
            }
        }
        function findNamespaceReExports(sourceFileLike, name, checker) {
            const namespaceImportSymbol = checker.getSymbolAtLocation(name);
            return !!forEachPossibleImportOrExportStatement(sourceFileLike, (statement) => {
                if (!isExportDeclaration(statement))
                    return;
                const { exportClause, moduleSpecifier } = statement;
                return !moduleSpecifier && exportClause && isNamedExports(exportClause) && exportClause.elements.some((element) => checker.getExportSpecifierLocalTargetSymbol(element) === namespaceImportSymbol);
            });
        }
        function findModuleReferences(program, sourceFiles, searchModuleSymbol) {
            var _a;
            const refs = [];
            const checker = program.getTypeChecker();
            for (const referencingFile of sourceFiles) {
                const searchSourceFile = searchModuleSymbol.valueDeclaration;
                if ((searchSourceFile == null ? void 0 : searchSourceFile.kind) === 312 /* SourceFile */) {
                    for (const ref of referencingFile.referencedFiles) {
                        if (program.getSourceFileFromReference(referencingFile, ref) === searchSourceFile) {
                            refs.push({ kind: "reference", referencingFile, ref });
                        }
                    }
                    for (const ref of referencingFile.typeReferenceDirectives) {
                        const referenced = (_a = program.getResolvedTypeReferenceDirectives().get(ref.fileName, ref.resolutionMode || referencingFile.impliedNodeFormat)) == null ? void 0 : _a.resolvedTypeReferenceDirective;
                        if (referenced !== void 0 && referenced.resolvedFileName === searchSourceFile.fileName) {
                            refs.push({ kind: "reference", referencingFile, ref });
                        }
                    }
                }
                forEachImport(referencingFile, (importDecl, moduleSpecifier) => {
                    const moduleSymbol = checker.getSymbolAtLocation(moduleSpecifier);
                    if (moduleSymbol === searchModuleSymbol) {
                        refs.push(nodeIsSynthesized(importDecl) ? { kind: "implicit", literal: moduleSpecifier, referencingFile } : { kind: "import", literal: moduleSpecifier });
                    }
                });
            }
            return refs;
        }
        function getDirectImportsMap(sourceFiles, checker, cancellationToken) {
            const map2 = /* @__PURE__ */ new Map();
            for (const sourceFile of sourceFiles) {
                if (cancellationToken)
                    cancellationToken.throwIfCancellationRequested();
                forEachImport(sourceFile, (importDecl, moduleSpecifier) => {
                    const moduleSymbol = checker.getSymbolAtLocation(moduleSpecifier);
                    if (moduleSymbol) {
                        const id = getSymbolId(moduleSymbol).toString();
                        let imports = map2.get(id);
                        if (!imports) {
                            map2.set(id, imports = []);
                        }
                        imports.push(importDecl);
                    }
                });
            }
            return map2;
        }
        function forEachPossibleImportOrExportStatement(sourceFileLike, action) {
            return forEach(sourceFileLike.kind === 312 /* SourceFile */ ? sourceFileLike.statements : sourceFileLike.body.statements, (statement) => (
            // TODO: GH#18217
            action(statement) || isAmbientModuleDeclaration(statement) && forEach(statement.body && statement.body.statements, action)));
        }
        function forEachImport(sourceFile, action) {
            if (sourceFile.externalModuleIndicator || sourceFile.imports !== void 0) {
                for (const i of sourceFile.imports) {
                    action(importFromModuleSpecifier(i), i);
                }
            }
            else {
                forEachPossibleImportOrExportStatement(sourceFile, (statement) => {
                    switch (statement.kind) {
                        case 278 /* ExportDeclaration */:
                        case 272 /* ImportDeclaration */: {
                            const decl = statement;
                            if (decl.moduleSpecifier && isStringLiteral(decl.moduleSpecifier)) {
                                action(decl, decl.moduleSpecifier);
                            }
                            break;
                        }
                        case 271 /* ImportEqualsDeclaration */: {
                            const decl = statement;
                            if (isExternalModuleImportEquals(decl)) {
                                action(decl, decl.moduleReference.expression);
                            }
                            break;
                        }
                    }
                });
            }
        }
        function getImportOrExportSymbol(node, symbol, checker, comingFromExport) {
            return comingFromExport ? getExport() : getExport() || getImport();
            function getExport() {
                var _a;
                const { parent: parent2 } = node;
                const grandparent = parent2.parent;
                if (symbol.exportSymbol) {
                    if (parent2.kind === 211 /* PropertyAccessExpression */) {
                        return ((_a = symbol.declarations) == null ? void 0 : _a.some((d) => d === parent2)) && isBinaryExpression(grandparent) ? getSpecialPropertyExport(grandparent, 
                        /*useLhsSymbol*/
                        false) : void 0;
                    }
                    else {
                        return exportInfo(symbol.exportSymbol, getExportKindForDeclaration(parent2));
                    }
                }
                else {
                    const exportNode = getExportNode(parent2, node);
                    if (exportNode && hasSyntacticModifier(exportNode, 32 /* Export */)) {
                        if (isImportEqualsDeclaration(exportNode) && exportNode.moduleReference === node) {
                            if (comingFromExport) {
                                return void 0;
                            }
                            const lhsSymbol = checker.getSymbolAtLocation(exportNode.name);
                            return { kind: 0 /* Import */, symbol: lhsSymbol };
                        }
                        else {
                            return exportInfo(symbol, getExportKindForDeclaration(exportNode));
                        }
                    }
                    else if (isNamespaceExport(parent2)) {
                        return exportInfo(symbol, 0 /* Named */);
                    }
                    else if (isExportAssignment(parent2)) {
                        return getExportAssignmentExport(parent2);
                    }
                    else if (isExportAssignment(grandparent)) {
                        return getExportAssignmentExport(grandparent);
                    }
                    else if (isBinaryExpression(parent2)) {
                        return getSpecialPropertyExport(parent2, 
                        /*useLhsSymbol*/
                        true);
                    }
                    else if (isBinaryExpression(grandparent)) {
                        return getSpecialPropertyExport(grandparent, 
                        /*useLhsSymbol*/
                        true);
                    }
                    else if (isJSDocTypedefTag(parent2) || isJSDocCallbackTag(parent2)) {
                        return exportInfo(symbol, 0 /* Named */);
                    }
                }
                function getExportAssignmentExport(ex) {
                    if (!ex.symbol.parent)
                        return void 0;
                    const exportKind = ex.isExportEquals ? 2 /* ExportEquals */ : 1 /* Default */;
                    return { kind: 1 /* Export */, symbol, exportInfo: { exportingModuleSymbol: ex.symbol.parent, exportKind } };
                }
                function getSpecialPropertyExport(node2, useLhsSymbol) {
                    let kind;
                    switch (getAssignmentDeclarationKind(node2)) {
                        case 1 /* ExportsProperty */:
                            kind = 0 /* Named */;
                            break;
                        case 2 /* ModuleExports */:
                            kind = 2 /* ExportEquals */;
                            break;
                        default:
                            return void 0;
                    }
                    const sym = useLhsSymbol ? checker.getSymbolAtLocation(getNameOfAccessExpression(cast(node2.left, isAccessExpression))) : symbol;
                    return sym && exportInfo(sym, kind);
                }
            }
            function getImport() {
                const isImport3 = isNodeImport(node);
                if (!isImport3)
                    return void 0;
                let importedSymbol = checker.getImmediateAliasedSymbol(symbol);
                if (!importedSymbol)
                    return void 0;
                importedSymbol = skipExportSpecifierSymbol(importedSymbol, checker);
                if (importedSymbol.escapedName === "export=") {
                    importedSymbol = getExportEqualsLocalSymbol(importedSymbol, checker);
                    if (importedSymbol === void 0)
                        return void 0;
                }
                const importedName = symbolEscapedNameNoDefault(importedSymbol);
                if (importedName === void 0 || importedName === "default" /* Default */ || importedName === symbol.escapedName) {
                    return { kind: 0 /* Import */, symbol: importedSymbol };
                }
            }
            function exportInfo(symbol2, kind) {
                const exportInfo2 = getExportInfo(symbol2, kind, checker);
                return exportInfo2 && { kind: 1 /* Export */, symbol: symbol2, exportInfo: exportInfo2 };
            }
            function getExportKindForDeclaration(node2) {
                return hasSyntacticModifier(node2, 2048 /* Default */) ? 1 /* Default */ : 0 /* Named */;
            }
        }
        function getExportEqualsLocalSymbol(importedSymbol, checker) {
            var _a, _b;
            if (importedSymbol.flags & 2097152 /* Alias */) {
                return checker.getImmediateAliasedSymbol(importedSymbol);
            }
            const decl = Debug.checkDefined(importedSymbol.valueDeclaration);
            if (isExportAssignment(decl)) {
                return (_a = tryCast(decl.expression, canHaveSymbol)) == null ? void 0 : _a.symbol;
            }
            else if (isBinaryExpression(decl)) {
                return (_b = tryCast(decl.right, canHaveSymbol)) == null ? void 0 : _b.symbol;
            }
            else if (isSourceFile(decl)) {
                return decl.symbol;
            }
            return void 0;
        }
        function getExportNode(parent2, node) {
            const declaration = isVariableDeclaration(parent2) ? parent2 : isBindingElement(parent2) ? walkUpBindingElementsAndPatterns(parent2) : void 0;
            if (declaration) {
                return parent2.name !== node ? void 0 : isCatchClause(declaration.parent) ? void 0 : isVariableStatement(declaration.parent.parent) ? declaration.parent.parent : void 0;
            }
            else {
                return parent2;
            }
        }
        function isNodeImport(node) {
            const { parent: parent2 } = node;
            switch (parent2.kind) {
                case 271 /* ImportEqualsDeclaration */:
                    return parent2.name === node && isExternalModuleImportEquals(parent2);
                case 276 /* ImportSpecifier */:
                    return !parent2.propertyName;
                case 273 /* ImportClause */:
                case 274 /* NamespaceImport */:
                    Debug.assert(parent2.name === node);
                    return true;
                case 208 /* BindingElement */:
                    return isInJSFile(node) && isVariableDeclarationInitializedToBareOrAccessedRequire(parent2.parent.parent);
                default:
                    return false;
            }
        }
        function getExportInfo(exportSymbol, exportKind, checker) {
            const moduleSymbol = exportSymbol.parent;
            if (!moduleSymbol)
                return void 0;
            const exportingModuleSymbol = checker.getMergedSymbol(moduleSymbol);
            return isExternalModuleSymbol(exportingModuleSymbol) ? { exportingModuleSymbol, exportKind } : void 0;
        }
        function skipExportSpecifierSymbol(symbol, checker) {
            if (symbol.declarations) {
                for (const declaration of symbol.declarations) {
                    if (isExportSpecifier(declaration) && !declaration.propertyName && !declaration.parent.parent.moduleSpecifier) {
                        return checker.getExportSpecifierLocalTargetSymbol(declaration) || symbol;
                    }
                    else if (isPropertyAccessExpression(declaration) && isModuleExportsAccessExpression(declaration.expression) && !isPrivateIdentifier(declaration.name)) {
                        return checker.getSymbolAtLocation(declaration);
                    }
                    else if (isShorthandPropertyAssignment(declaration) && isBinaryExpression(declaration.parent.parent) && getAssignmentDeclarationKind(declaration.parent.parent) === 2 /* ModuleExports */) {
                        return checker.getExportSpecifierLocalTargetSymbol(declaration.name);
                    }
                }
            }
            return symbol;
        }
        function getContainingModuleSymbol(importer, checker) {
            return checker.getMergedSymbol(getSourceFileLikeForImportDeclaration(importer).symbol);
        }
        function getSourceFileLikeForImportDeclaration(node) {
            if (node.kind === 213 /* CallExpression */) {
                return node.getSourceFile();
            }
            const { parent: parent2 } = node;
            if (parent2.kind === 312 /* SourceFile */) {
                return parent2;
            }
            Debug.assert(parent2.kind === 268 /* ModuleBlock */);
            return cast(parent2.parent, isAmbientModuleDeclaration);
        }
        function isAmbientModuleDeclaration(node) {
            return node.kind === 267 /* ModuleDeclaration */ && node.name.kind === 11 /* StringLiteral */;
        }
        function isExternalModuleImportEquals(eq) {
            return eq.moduleReference.kind === 283 /* ExternalModuleReference */ && eq.moduleReference.expression.kind === 11 /* StringLiteral */;
        }
        var ExportKind2, ImportExport;
        var init_importTracker = __esm({
            "src/services/importTracker.ts"() {
                "use strict";
                init_ts4();
                ExportKind2 = /* @__PURE__ */ ((ExportKind3) => {
                    ExportKind3[ExportKind3["Named"] = 0] = "Named";
                    ExportKind3[ExportKind3["Default"] = 1] = "Default";
                    ExportKind3[ExportKind3["ExportEquals"] = 2] = "ExportEquals";
                    return ExportKind3;
                })(ExportKind2 || {});
                ImportExport = /* @__PURE__ */ ((ImportExport2) => {
                    ImportExport2[ImportExport2["Import"] = 0] = "Import";
                    ImportExport2[ImportExport2["Export"] = 1] = "Export";
                    return ImportExport2;
                })(ImportExport || {});
            }
        });
        // src/services/findAllReferences.ts
        function nodeEntry(node, kind = 1 /* Node */) {
            return {
                kind,
                node: node.name || node,
                context: getContextNodeForNodeEntry(node)
            };
        }
        function isContextWithStartAndEndNode(node) {
            return node && node.kind === void 0;
        }
        function getContextNodeForNodeEntry(node) {
            if (isDeclaration(node)) {
                return getContextNode(node);
            }
            if (!node.parent)
                return void 0;
            if (!isDeclaration(node.parent) && !isExportAssignment(node.parent)) {
                if (isInJSFile(node)) {
                    const binaryExpression = isBinaryExpression(node.parent) ? node.parent : isAccessExpression(node.parent) && isBinaryExpression(node.parent.parent) && node.parent.parent.left === node.parent ? node.parent.parent : void 0;
                    if (binaryExpression && getAssignmentDeclarationKind(binaryExpression) !== 0 /* None */) {
                        return getContextNode(binaryExpression);
                    }
                }
                if (isJsxOpeningElement(node.parent) || isJsxClosingElement(node.parent)) {
                    return node.parent.parent;
                }
                else if (isJsxSelfClosingElement(node.parent) || isLabeledStatement(node.parent) || isBreakOrContinueStatement(node.parent)) {
                    return node.parent;
                }
                else if (isStringLiteralLike(node)) {
                    const validImport = tryGetImportFromModuleSpecifier(node);
                    if (validImport) {
                        const declOrStatement = findAncestor(validImport, (node2) => isDeclaration(node2) || isStatement(node2) || isJSDocTag(node2));
                        return isDeclaration(declOrStatement) ? getContextNode(declOrStatement) : declOrStatement;
                    }
                }
                const propertyName = findAncestor(node, isComputedPropertyName);
                return propertyName ? getContextNode(propertyName.parent) : void 0;
            }
            if (node.parent.name === node || // node is name of declaration, use parent
                isConstructorDeclaration(node.parent) || isExportAssignment(node.parent) || // Property name of the import export specifier or binding pattern, use parent
                (isImportOrExportSpecifier(node.parent) || isBindingElement(node.parent)) && node.parent.propertyName === node || // Is default export
                node.kind === 90 /* DefaultKeyword */ && hasSyntacticModifier(node.parent, 2080 /* ExportDefault */)) {
                return getContextNode(node.parent);
            }
            return void 0;
        }
        function getContextNode(node) {
            if (!node)
                return void 0;
            switch (node.kind) {
                case 260 /* VariableDeclaration */:
                    return !isVariableDeclarationList(node.parent) || node.parent.declarations.length !== 1 ? node : isVariableStatement(node.parent.parent) ? node.parent.parent : isForInOrOfStatement(node.parent.parent) ? getContextNode(node.parent.parent) : node.parent;
                case 208 /* BindingElement */:
                    return getContextNode(node.parent.parent);
                case 276 /* ImportSpecifier */:
                    return node.parent.parent.parent;
                case 281 /* ExportSpecifier */:
                case 274 /* NamespaceImport */:
                    return node.parent.parent;
                case 273 /* ImportClause */:
                case 280 /* NamespaceExport */:
                    return node.parent;
                case 226 /* BinaryExpression */:
                    return isExpressionStatement(node.parent) ? node.parent : node;
                case 250 /* ForOfStatement */:
                case 249 /* ForInStatement */:
                    return {
                        start: node.initializer,
                        end: node.expression
                    };
                case 303 /* PropertyAssignment */:
                case 304 /* ShorthandPropertyAssignment */:
                    return isArrayLiteralOrObjectLiteralDestructuringPattern(node.parent) ? getContextNode(findAncestor(node.parent, (node2) => isBinaryExpression(node2) || isForInOrOfStatement(node2))) : node;
                case 255 /* SwitchStatement */:
                    return {
                        start: find(node.getChildren(node.getSourceFile()), (node2) => node2.kind === 109 /* SwitchKeyword */),
                        end: node.caseBlock
                    };
                default:
                    return node;
            }
        }
        function toContextSpan(textSpan, sourceFile, context) {
            if (!context)
                return void 0;
            const contextSpan = isContextWithStartAndEndNode(context) ? getTextSpan(context.start, sourceFile, context.end) : getTextSpan(context, sourceFile);
            return contextSpan.start !== textSpan.start || contextSpan.length !== textSpan.length ? { contextSpan } : void 0;
        }
        function findReferencedSymbols(program, cancellationToken, sourceFiles, sourceFile, position) {
            const node = getTouchingPropertyName(sourceFile, position);
            const options = { use: 1 /* References */ };
            const referencedSymbols = Core.getReferencedSymbolsForNode(position, node, program, sourceFiles, cancellationToken, options);
            const checker = program.getTypeChecker();
            const adjustedNode = Core.getAdjustedNode(node, options);
            const symbol = isDefinitionForReference(adjustedNode) ? checker.getSymbolAtLocation(adjustedNode) : void 0;
            return !referencedSymbols || !referencedSymbols.length ? void 0 : mapDefined(referencedSymbols, ({ definition, references }) => (
            // Only include referenced symbols that have a valid definition.
            definition && {
                definition: checker.runWithCancellationToken(cancellationToken, (checker2) => definitionToReferencedSymbolDefinitionInfo(definition, checker2, node)),
                references: references.map((r) => toReferencedSymbolEntry(r, symbol))
            }));
        }
        function isDefinitionForReference(node) {
            return node.kind === 90 /* DefaultKeyword */ || !!getDeclarationFromName(node) || isLiteralComputedPropertyDeclarationName(node) || node.kind === 137 /* ConstructorKeyword */ && isConstructorDeclaration(node.parent);
        }
        function getImplementationsAtPosition(program, cancellationToken, sourceFiles, sourceFile, position) {
            const node = getTouchingPropertyName(sourceFile, position);
            let referenceEntries;
            const entries = getImplementationReferenceEntries(program, cancellationToken, sourceFiles, node, position);
            if (node.parent.kind === 211 /* PropertyAccessExpression */ || node.parent.kind === 208 /* BindingElement */ || node.parent.kind === 212 /* ElementAccessExpression */ || node.kind === 108 /* SuperKeyword */) {
                referenceEntries = entries && [...entries];
            }
            else if (entries) {
                const queue = createQueue(entries);
                const seenNodes = /* @__PURE__ */ new Map();
                while (!queue.isEmpty()) {
                    const entry = queue.dequeue();
                    if (!addToSeen(seenNodes, getNodeId(entry.node))) {
                        continue;
                    }
                    referenceEntries = append(referenceEntries, entry);
                    const entries2 = getImplementationReferenceEntries(program, cancellationToken, sourceFiles, entry.node, entry.node.pos);
                    if (entries2) {
                        queue.enqueue(...entries2);
                    }
                }
            }
            const checker = program.getTypeChecker();
            return map(referenceEntries, (entry) => toImplementationLocation(entry, checker));
        }
        function getImplementationReferenceEntries(program, cancellationToken, sourceFiles, node, position) {
            if (node.kind === 312 /* SourceFile */) {
                return void 0;
            }
            const checker = program.getTypeChecker();
            if (node.parent.kind === 304 /* ShorthandPropertyAssignment */) {
                const result = [];
                Core.getReferenceEntriesForShorthandPropertyAssignment(node, checker, (node2) => result.push(nodeEntry(node2)));
                return result;
            }
            else if (node.kind === 108 /* SuperKeyword */ || isSuperProperty(node.parent)) {
                const symbol = checker.getSymbolAtLocation(node);
                return symbol.valueDeclaration && [nodeEntry(symbol.valueDeclaration)];
            }
            else {
                return getReferenceEntriesForNode(position, node, program, sourceFiles, cancellationToken, { implementations: true, use: 1 /* References */ });
            }
        }
        function findReferenceOrRenameEntries(program, cancellationToken, sourceFiles, node, position, options, convertEntry) {
            return map(flattenEntries(Core.getReferencedSymbolsForNode(position, node, program, sourceFiles, cancellationToken, options)), (entry) => convertEntry(entry, node, program.getTypeChecker()));
        }
        function getReferenceEntriesForNode(position, node, program, sourceFiles, cancellationToken, options = {}, sourceFilesSet = new Set(sourceFiles.map((f) => f.fileName))) {
            return flattenEntries(Core.getReferencedSymbolsForNode(position, node, program, sourceFiles, cancellationToken, options, sourceFilesSet));
        }
        function flattenEntries(referenceSymbols) {
            return referenceSymbols && flatMap(referenceSymbols, (r) => r.references);
        }
        function definitionToReferencedSymbolDefinitionInfo(def, checker, originalNode) {
            const info = (() => {
                switch (def.type) {
                    case 0 /* Symbol */: {
                        const { symbol } = def;
                        const { displayParts: displayParts2, kind: kind2 } = getDefinitionKindAndDisplayParts(symbol, checker, originalNode);
                        const name2 = displayParts2.map((p) => p.text).join("");
                        const declaration = symbol.declarations && firstOrUndefined(symbol.declarations);
                        const node = declaration ? getNameOfDeclaration(declaration) || declaration : originalNode;
                        return {
                            ...getFileAndTextSpanFromNode(node),
                            name: name2,
                            kind: kind2,
                            displayParts: displayParts2,
                            context: getContextNode(declaration)
                        };
                    }
                    case 1 /* Label */: {
                        const { node } = def;
                        return { ...getFileAndTextSpanFromNode(node), name: node.text, kind: "label" /* label */, displayParts: [displayPart(node.text, 17 /* text */)] };
                    }
                    case 2 /* Keyword */: {
                        const { node } = def;
                        const name2 = tokenToString(node.kind);
                        return { ...getFileAndTextSpanFromNode(node), name: name2, kind: "keyword" /* keyword */, displayParts: [{ text: name2, kind: "keyword" /* keyword */ }] };
                    }
                    case 3 /* This */: {
                        const { node } = def;
                        const symbol = checker.getSymbolAtLocation(node);
                        const displayParts2 = symbol && ts_SymbolDisplay_exports.getSymbolDisplayPartsDocumentationAndSymbolKind(checker, symbol, node.getSourceFile(), getContainerNode(node), node).displayParts || [textPart("this")];
                        return { ...getFileAndTextSpanFromNode(node), name: "this", kind: "var" /* variableElement */, displayParts: displayParts2 };
                    }
                    case 4 /* String */: {
                        const { node } = def;
                        return {
                            ...getFileAndTextSpanFromNode(node),
                            name: node.text,
                            kind: "var" /* variableElement */,
                            displayParts: [displayPart(getTextOfNode(node), 8 /* stringLiteral */)]
                        };
                    }
                    case 5 /* TripleSlashReference */: {
                        return {
                            textSpan: createTextSpanFromRange(def.reference),
                            sourceFile: def.file,
                            name: def.reference.fileName,
                            kind: "string" /* string */,
                            displayParts: [displayPart(`"${def.reference.fileName}"`, 8 /* stringLiteral */)]
                        };
                    }
                    default:
                        return Debug.assertNever(def);
                }
            })();
            const { sourceFile, textSpan, name, kind, displayParts, context } = info;
            return {
                containerKind: "" /* unknown */,
                containerName: "",
                fileName: sourceFile.fileName,
                kind,
                name,
                textSpan,
                displayParts,
                ...toContextSpan(textSpan, sourceFile, context)
            };
        }
        function getFileAndTextSpanFromNode(node) {
            const sourceFile = node.getSourceFile();
            return {
                sourceFile,
                textSpan: getTextSpan(isComputedPropertyName(node) ? node.expression : node, sourceFile)
            };
        }
        function getDefinitionKindAndDisplayParts(symbol, checker, node) {
            const meaning = Core.getIntersectingMeaningFromDeclarations(node, symbol);
            const enclosingDeclaration = symbol.declarations && firstOrUndefined(symbol.declarations) || node;
            const { displayParts, symbolKind } = ts_SymbolDisplay_exports.getSymbolDisplayPartsDocumentationAndSymbolKind(checker, symbol, enclosingDeclaration.getSourceFile(), enclosingDeclaration, enclosingDeclaration, meaning);
            return { displayParts, kind: symbolKind };
        }
        function toRenameLocation(entry, originalNode, checker, providePrefixAndSuffixText, quotePreference) {
            return { ...entryToDocumentSpan(entry), ...providePrefixAndSuffixText && getPrefixAndSuffixText(entry, originalNode, checker, quotePreference) };
        }
        function toReferencedSymbolEntry(entry, symbol) {
            const referenceEntry = toReferenceEntry(entry);
            if (!symbol)
                return referenceEntry;
            return {
                ...referenceEntry,
                isDefinition: entry.kind !== 0 /* Span */ && isDeclarationOfSymbol(entry.node, symbol)
            };
        }
        function toReferenceEntry(entry) {
            const documentSpan = entryToDocumentSpan(entry);
            if (entry.kind === 0 /* Span */) {
                return { ...documentSpan, isWriteAccess: false };
            }
            const { kind, node } = entry;
            return {
                ...documentSpan,
                isWriteAccess: isWriteAccessForReference(node),
                isInString: kind === 2 /* StringLiteral */ ? true : void 0
            };
        }
        function entryToDocumentSpan(entry) {
            if (entry.kind === 0 /* Span */) {
                return { textSpan: entry.textSpan, fileName: entry.fileName };
            }
            else {
                const sourceFile = entry.node.getSourceFile();
                const textSpan = getTextSpan(entry.node, sourceFile);
                return {
                    textSpan,
                    fileName: sourceFile.fileName,
                    ...toContextSpan(textSpan, sourceFile, entry.context)
                };
            }
        }
        function getPrefixAndSuffixText(entry, originalNode, checker, quotePreference) {
            if (entry.kind !== 0 /* Span */ && isIdentifier(originalNode)) {
                const { node, kind } = entry;
                const parent2 = node.parent;
                const name = originalNode.text;
                const isShorthandAssignment = isShorthandPropertyAssignment(parent2);
                if (isShorthandAssignment || isObjectBindingElementWithoutPropertyName(parent2) && parent2.name === node && parent2.dotDotDotToken === void 0) {
                    const prefixColon = { prefixText: name + ": " };
                    const suffixColon = { suffixText: ": " + name };
                    if (kind === 3 /* SearchedLocalFoundProperty */) {
                        return prefixColon;
                    }
                    if (kind === 4 /* SearchedPropertyFoundLocal */) {
                        return suffixColon;
                    }
                    if (isShorthandAssignment) {
                        const grandParent = parent2.parent;
                        if (isObjectLiteralExpression(grandParent) && isBinaryExpression(grandParent.parent) && isModuleExportsAccessExpression(grandParent.parent.left)) {
                            return prefixColon;
                        }
                        return suffixColon;
                    }
                    else {
                        return prefixColon;
                    }
                }
                else if (isImportSpecifier(parent2) && !parent2.propertyName) {
                    const originalSymbol = isExportSpecifier(originalNode.parent) ? checker.getExportSpecifierLocalTargetSymbol(originalNode.parent) : checker.getSymbolAtLocation(originalNode);
                    return contains(originalSymbol.declarations, parent2) ? { prefixText: name + " as " } : emptyOptions;
                }
                else if (isExportSpecifier(parent2) && !parent2.propertyName) {
                    return originalNode === entry.node || checker.getSymbolAtLocation(originalNode) === checker.getSymbolAtLocation(entry.node) ? { prefixText: name + " as " } : { suffixText: " as " + name };
                }
            }
            if (entry.kind !== 0 /* Span */ && isNumericLiteral(entry.node) && isAccessExpression(entry.node.parent)) {
                const quote2 = getQuoteFromPreference(quotePreference);
                return { prefixText: quote2, suffixText: quote2 };
            }
            return emptyOptions;
        }
        function toImplementationLocation(entry, checker) {
            const documentSpan = entryToDocumentSpan(entry);
            if (entry.kind !== 0 /* Span */) {
                const { node } = entry;
                return {
                    ...documentSpan,
                    ...implementationKindDisplayParts(node, checker)
                };
            }
            else {
                return { ...documentSpan, kind: "" /* unknown */, displayParts: [] };
            }
        }
        function implementationKindDisplayParts(node, checker) {
            const symbol = checker.getSymbolAtLocation(isDeclaration(node) && node.name ? node.name : node);
            if (symbol) {
                return getDefinitionKindAndDisplayParts(symbol, checker, node);
            }
            else if (node.kind === 210 /* ObjectLiteralExpression */) {
                return {
                    kind: "interface" /* interfaceElement */,
                    displayParts: [punctuationPart(21 /* OpenParenToken */), textPart("object literal"), punctuationPart(22 /* CloseParenToken */)]
                };
            }
            else if (node.kind === 231 /* ClassExpression */) {
                return {
                    kind: "local class" /* localClassElement */,
                    displayParts: [punctuationPart(21 /* OpenParenToken */), textPart("anonymous local class"), punctuationPart(22 /* CloseParenToken */)]
                };
            }
            else {
                return { kind: getNodeKind(node), displayParts: [] };
            }
        }
        function toHighlightSpan(entry) {
            const documentSpan = entryToDocumentSpan(entry);
            if (entry.kind === 0 /* Span */) {
                return {
                    fileName: documentSpan.fileName,
                    span: {
                        textSpan: documentSpan.textSpan,
                        kind: "reference" /* reference */
                    }
                };
            }
            const writeAccess = isWriteAccessForReference(entry.node);
            const span = {
                textSpan: documentSpan.textSpan,
                kind: writeAccess ? "writtenReference" /* writtenReference */ : "reference" /* reference */,
                isInString: entry.kind === 2 /* StringLiteral */ ? true : void 0,
                ...documentSpan.contextSpan && { contextSpan: documentSpan.contextSpan }
            };
            return { fileName: documentSpan.fileName, span };
        }
        function getTextSpan(node, sourceFile, endNode2) {
            let start = node.getStart(sourceFile);
            let end = (endNode2 || node).getEnd();
            if (isStringLiteralLike(node) && end - start > 2) {
                Debug.assert(endNode2 === void 0);
                start += 1;
                end -= 1;
            }
            if ((endNode2 == null ? void 0 : endNode2.kind) === 269 /* CaseBlock */) {
                end = endNode2.getFullStart();
            }
            return createTextSpanFromBounds(start, end);
        }
        function getTextSpanOfEntry(entry) {
            return entry.kind === 0 /* Span */ ? entry.textSpan : getTextSpan(entry.node, entry.node.getSourceFile());
        }
        function isWriteAccessForReference(node) {
            const decl = getDeclarationFromName(node);
            return !!decl && declarationIsWriteAccess(decl) || node.kind === 90 /* DefaultKeyword */ || isWriteAccess(node);
        }
        function isDeclarationOfSymbol(node, target) {
            var _a;
            if (!target)
                return false;
            const source = getDeclarationFromName(node) || (node.kind === 90 /* DefaultKeyword */ ? node.parent : isLiteralComputedPropertyDeclarationName(node) ? node.parent.parent : node.kind === 137 /* ConstructorKeyword */ && isConstructorDeclaration(node.parent) ? node.parent.parent : void 0);
            const commonjsSource = source && isBinaryExpression(source) ? source.left : void 0;
            return !!(source && ((_a = target.declarations) == null ? void 0 : _a.some((d) => d === source || d === commonjsSource)));
        }
        function declarationIsWriteAccess(decl) {
            if (!!(decl.flags & 33554432 /* Ambient */))
                return true;
            switch (decl.kind) {
                case 226 /* BinaryExpression */:
                case 208 /* BindingElement */:
                case 263 /* ClassDeclaration */:
                case 231 /* ClassExpression */:
                case 90 /* DefaultKeyword */:
                case 266 /* EnumDeclaration */:
                case 306 /* EnumMember */:
                case 281 /* ExportSpecifier */:
                case 273 /* ImportClause */:
                case 271 /* ImportEqualsDeclaration */:
                case 276 /* ImportSpecifier */:
                case 264 /* InterfaceDeclaration */:
                case 345 /* JSDocCallbackTag */:
                case 353 /* JSDocTypedefTag */:
                case 291 /* JsxAttribute */:
                case 267 /* ModuleDeclaration */:
                case 270 /* NamespaceExportDeclaration */:
                case 274 /* NamespaceImport */:
                case 280 /* NamespaceExport */:
                case 169 /* Parameter */:
                case 304 /* ShorthandPropertyAssignment */:
                case 265 /* TypeAliasDeclaration */:
                case 168 /* TypeParameter */:
                    return true;
                case 303 /* PropertyAssignment */:
                    return !isArrayLiteralOrObjectLiteralDestructuringPattern(decl.parent);
                case 262 /* FunctionDeclaration */:
                case 218 /* FunctionExpression */:
                case 176 /* Constructor */:
                case 174 /* MethodDeclaration */:
                case 177 /* GetAccessor */:
                case 178 /* SetAccessor */:
                    return !!decl.body;
                case 260 /* VariableDeclaration */:
                case 172 /* PropertyDeclaration */:
                    return !!decl.initializer || isCatchClause(decl.parent);
                case 173 /* MethodSignature */:
                case 171 /* PropertySignature */:
                case 355 /* JSDocPropertyTag */:
                case 348 /* JSDocParameterTag */:
                    return false;
                default:
                    return Debug.failBadSyntaxKind(decl);
            }
        }
        var DefinitionKind, EntryKind, FindReferencesUse, Core;
        var init_findAllReferences = __esm({
            "src/services/findAllReferences.ts"() {
                "use strict";
                init_ts4();
                init_ts_FindAllReferences();
                DefinitionKind = /* @__PURE__ */ ((DefinitionKind2) => {
                    DefinitionKind2[DefinitionKind2["Symbol"] = 0] = "Symbol";
                    DefinitionKind2[DefinitionKind2["Label"] = 1] = "Label";
                    DefinitionKind2[DefinitionKind2["Keyword"] = 2] = "Keyword";
                    DefinitionKind2[DefinitionKind2["This"] = 3] = "This";
                    DefinitionKind2[DefinitionKind2["String"] = 4] = "String";
                    DefinitionKind2[DefinitionKind2["TripleSlashReference"] = 5] = "TripleSlashReference";
                    return DefinitionKind2;
                })(DefinitionKind || {});
                EntryKind = /* @__PURE__ */ ((EntryKind2) => {
                    EntryKind2[EntryKind2["Span"] = 0] = "Span";
                    EntryKind2[EntryKind2["Node"] = 1] = "Node";
                    EntryKind2[EntryKind2["StringLiteral"] = 2] = "StringLiteral";
                    EntryKind2[EntryKind2["SearchedLocalFoundProperty"] = 3] = "SearchedLocalFoundProperty";
                    EntryKind2[EntryKind2["SearchedPropertyFoundLocal"] = 4] = "SearchedPropertyFoundLocal";
                    return EntryKind2;
                })(EntryKind || {});
                FindReferencesUse = /* @__PURE__ */ ((FindReferencesUse2) => {
                    FindReferencesUse2[FindReferencesUse2["Other"] = 0] = "Other";
                    FindReferencesUse2[FindReferencesUse2["References"] = 1] = "References";
                    FindReferencesUse2[FindReferencesUse2["Rename"] = 2] = "Rename";
                    return FindReferencesUse2;
                })(FindReferencesUse || {});
                ((Core2) => {
                    function getReferencedSymbolsForNode(position, node, program, sourceFiles, cancellationToken, options = {}, sourceFilesSet = new Set(sourceFiles.map((f) => f.fileName))) {
                        var _a, _b;
                        node = getAdjustedNode2(node, options);
                        if (isSourceFile(node)) {
                            const resolvedRef = ts_GoToDefinition_exports.getReferenceAtPosition(node, position, program);
                            if (!(resolvedRef == null ? void 0 : resolvedRef.file)) {
                                return void 0;
                            }
                            const moduleSymbol = program.getTypeChecker().getMergedSymbol(resolvedRef.file.symbol);
                            if (moduleSymbol) {
                                return getReferencedSymbolsForModule(program, moduleSymbol, 
                                /*excludeImportTypeOfExportEquals*/
                                false, sourceFiles, sourceFilesSet);
                            }
                            const fileIncludeReasons = program.getFileIncludeReasons();
                            if (!fileIncludeReasons) {
                                return void 0;
                            }
                            return [{
                                    definition: { type: 5 /* TripleSlashReference */, reference: resolvedRef.reference, file: node },
                                    references: getReferencesForNonModule(resolvedRef.file, fileIncludeReasons, program) || emptyArray
                                }];
                        }
                        if (!options.implementations) {
                            const special = getReferencedSymbolsSpecial(node, sourceFiles, cancellationToken);
                            if (special) {
                                return special;
                            }
                        }
                        const checker = program.getTypeChecker();
                        const symbol = checker.getSymbolAtLocation(isConstructorDeclaration(node) && node.parent.name || node);
                        if (!symbol) {
                            if (!options.implementations && isStringLiteralLike(node)) {
                                if (isModuleSpecifierLike(node)) {
                                    const fileIncludeReasons = program.getFileIncludeReasons();
                                    const referencedFileName = (_b = (_a = program.getResolvedModuleFromModuleSpecifier(node)) == null ? void 0 : _a.resolvedModule) == null ? void 0 : _b.resolvedFileName;
                                    const referencedFile = referencedFileName ? program.getSourceFile(referencedFileName) : void 0;
                                    if (referencedFile) {
                                        return [{ definition: { type: 4 /* String */, node }, references: getReferencesForNonModule(referencedFile, fileIncludeReasons, program) || emptyArray }];
                                    }
                                }
                                return getReferencesForStringLiteral(node, sourceFiles, checker, cancellationToken);
                            }
                            return void 0;
                        }
                        if (symbol.escapedName === "export=" /* ExportEquals */) {
                            return getReferencedSymbolsForModule(program, symbol.parent, 
                            /*excludeImportTypeOfExportEquals*/
                            false, sourceFiles, sourceFilesSet);
                        }
                        const moduleReferences = getReferencedSymbolsForModuleIfDeclaredBySourceFile(symbol, program, sourceFiles, cancellationToken, options, sourceFilesSet);
                        if (moduleReferences && !(symbol.flags & 33554432 /* Transient */)) {
                            return moduleReferences;
                        }
                        const aliasedSymbol = getMergedAliasedSymbolOfNamespaceExportDeclaration(node, symbol, checker);
                        const moduleReferencesOfExportTarget = aliasedSymbol && getReferencedSymbolsForModuleIfDeclaredBySourceFile(aliasedSymbol, program, sourceFiles, cancellationToken, options, sourceFilesSet);
                        const references = getReferencedSymbolsForSymbol(symbol, node, sourceFiles, sourceFilesSet, checker, cancellationToken, options);
                        return mergeReferences(program, moduleReferences, references, moduleReferencesOfExportTarget);
                    }
                    Core2.getReferencedSymbolsForNode = getReferencedSymbolsForNode;
                    function getAdjustedNode2(node, options) {
                        if (options.use === 1 /* References */) {
                            node = getAdjustedReferenceLocation(node);
                        }
                        else if (options.use === 2 /* Rename */) {
                            node = getAdjustedRenameLocation(node);
                        }
                        return node;
                    }
                    Core2.getAdjustedNode = getAdjustedNode2;
                    function getReferencesForFileName(fileName, program, sourceFiles, sourceFilesSet = new Set(sourceFiles.map((f) => f.fileName))) {
                        var _a, _b;
                        const moduleSymbol = (_a = program.getSourceFile(fileName)) == null ? void 0 : _a.symbol;
                        if (moduleSymbol) {
                            return ((_b = getReferencedSymbolsForModule(program, moduleSymbol, 
                            /*excludeImportTypeOfExportEquals*/
                            false, sourceFiles, sourceFilesSet)[0]) == null ? void 0 : _b.references) || emptyArray;
                        }
                        const fileIncludeReasons = program.getFileIncludeReasons();
                        const referencedFile = program.getSourceFile(fileName);
                        return referencedFile && fileIncludeReasons && getReferencesForNonModule(referencedFile, fileIncludeReasons, program) || emptyArray;
                    }
                    Core2.getReferencesForFileName = getReferencesForFileName;
                    function getReferencesForNonModule(referencedFile, refFileMap, program) {
                        let entries;
                        const references = refFileMap.get(referencedFile.path) || emptyArray;
                        for (const ref of references) {
                            if (isReferencedFile(ref)) {
                                const referencingFile = program.getSourceFileByPath(ref.file);
                                const location = getReferencedFileLocation(program, ref);
                                if (isReferenceFileLocation(location)) {
                                    entries = append(entries, {
                                        kind: 0 /* Span */,
                                        fileName: referencingFile.fileName,
                                        textSpan: createTextSpanFromRange(location)
                                    });
                                }
                            }
                        }
                        return entries;
                    }
                    function getMergedAliasedSymbolOfNamespaceExportDeclaration(node, symbol, checker) {
                        if (node.parent && isNamespaceExportDeclaration(node.parent)) {
                            const aliasedSymbol = checker.getAliasedSymbol(symbol);
                            const targetSymbol = checker.getMergedSymbol(aliasedSymbol);
                            if (aliasedSymbol !== targetSymbol) {
                                return targetSymbol;
                            }
                        }
                        return void 0;
                    }
                    function getReferencedSymbolsForModuleIfDeclaredBySourceFile(symbol, program, sourceFiles, cancellationToken, options, sourceFilesSet) {
                        const moduleSourceFile = symbol.flags & 1536 /* Module */ && symbol.declarations && find(symbol.declarations, isSourceFile);
                        if (!moduleSourceFile)
                            return void 0;
                        const exportEquals = symbol.exports.get("export=" /* ExportEquals */);
                        const moduleReferences = getReferencedSymbolsForModule(program, symbol, !!exportEquals, sourceFiles, sourceFilesSet);
                        if (!exportEquals || !sourceFilesSet.has(moduleSourceFile.fileName))
                            return moduleReferences;
                        const checker = program.getTypeChecker();
                        symbol = skipAlias(exportEquals, checker);
                        return mergeReferences(program, moduleReferences, getReferencedSymbolsForSymbol(symbol, 
                        /*node*/
                        void 0, sourceFiles, sourceFilesSet, checker, cancellationToken, options));
                    }
                    function mergeReferences(program, ...referencesToMerge) {
                        let result;
                        for (const references of referencesToMerge) {
                            if (!references || !references.length)
                                continue;
                            if (!result) {
                                result = references;
                                continue;
                            }
                            for (const entry of references) {
                                if (!entry.definition || entry.definition.type !== 0 /* Symbol */) {
                                    result.push(entry);
                                    continue;
                                }
                                const symbol = entry.definition.symbol;
                                const refIndex = findIndex(result, (ref) => !!ref.definition && ref.definition.type === 0 /* Symbol */ && ref.definition.symbol === symbol);
                                if (refIndex === -1) {
                                    result.push(entry);
                                    continue;
                                }
                                const reference = result[refIndex];
                                result[refIndex] = {
                                    definition: reference.definition,
                                    references: reference.references.concat(entry.references).sort((entry1, entry2) => {
                                        const entry1File = getSourceFileIndexOfEntry(program, entry1);
                                        const entry2File = getSourceFileIndexOfEntry(program, entry2);
                                        if (entry1File !== entry2File) {
                                            return compareValues(entry1File, entry2File);
                                        }
                                        const entry1Span = getTextSpanOfEntry(entry1);
                                        const entry2Span = getTextSpanOfEntry(entry2);
                                        return entry1Span.start !== entry2Span.start ? compareValues(entry1Span.start, entry2Span.start) : compareValues(entry1Span.length, entry2Span.length);
                                    })
                                };
                            }
                        }
                        return result;
                    }
                    function getSourceFileIndexOfEntry(program, entry) {
                        const sourceFile = entry.kind === 0 /* Span */ ? program.getSourceFile(entry.fileName) : entry.node.getSourceFile();
                        return program.getSourceFiles().indexOf(sourceFile);
                    }
                    function getReferencedSymbolsForModule(program, symbol, excludeImportTypeOfExportEquals, sourceFiles, sourceFilesSet) {
                        Debug.assert(!!symbol.valueDeclaration);
                        const references = mapDefined(findModuleReferences(program, sourceFiles, symbol), (reference) => {
                            if (reference.kind === "import") {
                                const parent2 = reference.literal.parent;
                                if (isLiteralTypeNode(parent2)) {
                                    const importType = cast(parent2.parent, isImportTypeNode);
                                    if (excludeImportTypeOfExportEquals && !importType.qualifier) {
                                        return void 0;
                                    }
                                }
                                return nodeEntry(reference.literal);
                            }
                            else if (reference.kind === "implicit") {
                                const range = reference.literal.text !== externalHelpersModuleNameText && forEachChildRecursively(reference.referencingFile, (n) => !(n.transformFlags & 2 /* ContainsJsx */) ? "skip" : isJsxElement(n) || isJsxSelfClosingElement(n) || isJsxFragment(n) ? n : void 0) || reference.referencingFile.statements[0] || reference.referencingFile;
                                return nodeEntry(range);
                            }
                            else {
                                return {
                                    kind: 0 /* Span */,
                                    fileName: reference.referencingFile.fileName,
                                    textSpan: createTextSpanFromRange(reference.ref)
                                };
                            }
                        });
                        if (symbol.declarations) {
                            for (const decl of symbol.declarations) {
                                switch (decl.kind) {
                                    case 312 /* SourceFile */:
                                        break;
                                    case 267 /* ModuleDeclaration */:
                                        if (sourceFilesSet.has(decl.getSourceFile().fileName)) {
                                            references.push(nodeEntry(decl.name));
                                        }
                                        break;
                                    default:
                                        Debug.assert(!!(symbol.flags & 33554432 /* Transient */), "Expected a module symbol to be declared by a SourceFile or ModuleDeclaration.");
                                }
                            }
                        }
                        const exported = symbol.exports.get("export=" /* ExportEquals */);
                        if (exported == null ? void 0 : exported.declarations) {
                            for (const decl of exported.declarations) {
                                const sourceFile = decl.getSourceFile();
                                if (sourceFilesSet.has(sourceFile.fileName)) {
                                    const node = isBinaryExpression(decl) && isPropertyAccessExpression(decl.left) ? decl.left.expression : isExportAssignment(decl) ? Debug.checkDefined(findChildOfKind(decl, 95 /* ExportKeyword */, sourceFile)) : getNameOfDeclaration(decl) || decl;
                                    references.push(nodeEntry(node));
                                }
                            }
                        }
                        return references.length ? [{ definition: { type: 0 /* Symbol */, symbol }, references }] : emptyArray;
                    }
                    function isReadonlyTypeOperator(node) {
                        return node.kind === 148 /* ReadonlyKeyword */ && isTypeOperatorNode(node.parent) && node.parent.operator === 148 /* ReadonlyKeyword */;
                    }
                    function getReferencedSymbolsSpecial(node, sourceFiles, cancellationToken) {
                        if (isTypeKeyword(node.kind)) {
                            if (node.kind === 116 /* VoidKeyword */ && isVoidExpression(node.parent)) {
                                return void 0;
                            }
                            if (node.kind === 148 /* ReadonlyKeyword */ && !isReadonlyTypeOperator(node)) {
                                return void 0;
                            }
                            return getAllReferencesForKeyword(sourceFiles, node.kind, cancellationToken, node.kind === 148 /* ReadonlyKeyword */ ? isReadonlyTypeOperator : void 0);
                        }
                        if (isImportMeta(node.parent) && node.parent.name === node) {
                            return getAllReferencesForImportMeta(sourceFiles, cancellationToken);
                        }
                        if (isStaticModifier(node) && isClassStaticBlockDeclaration(node.parent)) {
                            return [{ definition: { type: 2 /* Keyword */, node }, references: [nodeEntry(node)] }];
                        }
                        if (isJumpStatementTarget(node)) {
                            const labelDefinition = getTargetLabel(node.parent, node.text);
                            return labelDefinition && getLabelReferencesInNode(labelDefinition.parent, labelDefinition);
                        }
                        else if (isLabelOfLabeledStatement(node)) {
                            return getLabelReferencesInNode(node.parent, node);
                        }
                        if (isThis(node)) {
                            return getReferencesForThisKeyword(node, sourceFiles, cancellationToken);
                        }
                        if (node.kind === 108 /* SuperKeyword */) {
                            return getReferencesForSuperKeyword(node);
                        }
                        return void 0;
                    }
                    function getReferencedSymbolsForSymbol(originalSymbol, node, sourceFiles, sourceFilesSet, checker, cancellationToken, options) {
                        const symbol = node && skipPastExportOrImportSpecifierOrUnion(originalSymbol, node, checker, 
                        /*useLocalSymbolForExportSpecifier*/
                        !isForRenameWithPrefixAndSuffixText(options)) || originalSymbol;
                        const searchMeaning = node ? getIntersectingMeaningFromDeclarations(node, symbol) : 7 /* All */;
                        const result = [];
                        const state = new State(sourceFiles, sourceFilesSet, node ? getSpecialSearchKind(node) : 0 /* None */, checker, cancellationToken, searchMeaning, options, result);
                        const exportSpecifier = !isForRenameWithPrefixAndSuffixText(options) || !symbol.declarations ? void 0 : find(symbol.declarations, isExportSpecifier);
                        if (exportSpecifier) {
                            getReferencesAtExportSpecifier(exportSpecifier.name, symbol, exportSpecifier, state.createSearch(node, originalSymbol, 
                            /*comingFrom*/
                            void 0), state, 
                            /*addReferencesHere*/
                            true, 
                            /*alwaysGetReferences*/
                            true);
                        }
                        else if (node && node.kind === 90 /* DefaultKeyword */ && symbol.escapedName === "default" /* Default */ && symbol.parent) {
                            addReference(node, symbol, state);
                            searchForImportsOfExport(node, symbol, { exportingModuleSymbol: symbol.parent, exportKind: 1 /* Default */ }, state);
                        }
                        else {
                            const search = state.createSearch(node, symbol, 
                            /*comingFrom*/
                            void 0, { allSearchSymbols: node ? populateSearchSymbolSet(symbol, node, checker, options.use === 2 /* Rename */, !!options.providePrefixAndSuffixTextForRename, !!options.implementations) : [symbol] });
                            getReferencesInContainerOrFiles(symbol, state, search);
                        }
                        return result;
                    }
                    function getReferencesInContainerOrFiles(symbol, state, search) {
                        const scope = getSymbolScope(symbol);
                        if (scope) {
                            getReferencesInContainer(scope, scope.getSourceFile(), search, state, 
                            /*addReferencesHere*/
                            !(isSourceFile(scope) && !contains(state.sourceFiles, scope)));
                        }
                        else {
                            for (const sourceFile of state.sourceFiles) {
                                state.cancellationToken.throwIfCancellationRequested();
                                searchForName(sourceFile, search, state);
                            }
                        }
                    }
                    function getSpecialSearchKind(node) {
                        switch (node.kind) {
                            case 176 /* Constructor */:
                            case 137 /* ConstructorKeyword */:
                                return 1 /* Constructor */;
                            case 80 /* Identifier */:
                                if (isClassLike(node.parent)) {
                                    Debug.assert(node.parent.name === node);
                                    return 2 /* Class */;
                                }
                            default:
                                return 0 /* None */;
                        }
                    }
                    function skipPastExportOrImportSpecifierOrUnion(symbol, node, checker, useLocalSymbolForExportSpecifier) {
                        const { parent: parent2 } = node;
                        if (isExportSpecifier(parent2) && useLocalSymbolForExportSpecifier) {
                            return getLocalSymbolForExportSpecifier(node, symbol, parent2, checker);
                        }
                        return firstDefined(symbol.declarations, (decl) => {
                            if (!decl.parent) {
                                if (symbol.flags & 33554432 /* Transient */)
                                    return void 0;
                                Debug.fail(`Unexpected symbol at ${Debug.formatSyntaxKind(node.kind)}: ${Debug.formatSymbol(symbol)}`);
                            }
                            return isTypeLiteralNode(decl.parent) && isUnionTypeNode(decl.parent.parent) ? checker.getPropertyOfType(checker.getTypeFromTypeNode(decl.parent.parent), symbol.name) : void 0;
                        });
                    }
                    let SpecialSearchKind;
                    ((SpecialSearchKind2) => {
                        SpecialSearchKind2[SpecialSearchKind2["None"] = 0] = "None";
                        SpecialSearchKind2[SpecialSearchKind2["Constructor"] = 1] = "Constructor";
                        SpecialSearchKind2[SpecialSearchKind2["Class"] = 2] = "Class";
                    })(SpecialSearchKind || (SpecialSearchKind = {}));
                    function getNonModuleSymbolOfMergedModuleSymbol(symbol) {
                        if (!(symbol.flags & (1536 /* Module */ | 33554432 /* Transient */)))
                            return void 0;
                        const decl = symbol.declarations && find(symbol.declarations, (d) => !isSourceFile(d) && !isModuleDeclaration(d));
                        return decl && decl.symbol;
                    }
                    class State {
                        constructor(sourceFiles, sourceFilesSet, specialSearchKind, checker, cancellationToken, searchMeaning, options, result) {
                            this.sourceFiles = sourceFiles;
                            this.sourceFilesSet = sourceFilesSet;
                            this.specialSearchKind = specialSearchKind;
                            this.checker = checker;
                            this.cancellationToken = cancellationToken;
                            this.searchMeaning = searchMeaning;
                            this.options = options;
                            this.result = result;
                            /** Cache for `explicitlyinheritsFrom`. */
                            this.inheritsFromCache = /* @__PURE__ */ new Map();
                            /**
                             * Type nodes can contain multiple references to the same type. For example:
                             *      let x: Foo & (Foo & Bar) = ...
                             * Because we are returning the implementation locations and not the identifier locations,
                             * duplicate entries would be returned here as each of the type references is part of
                             * the same implementation. For that reason, check before we add a new entry.
                             */
                            this.markSeenContainingTypeReference = nodeSeenTracker();
                            /**
                             * It's possible that we will encounter the right side of `export { foo as bar } from "x";` more than once.
                             * For example:
                             *     // b.ts
                             *     export { foo as bar } from "./a";
                             *     import { bar } from "./b";
                             *
                             * Normally at `foo as bar` we directly add `foo` and do not locally search for it (since it doesn't declare a local).
                             * But another reference to it may appear in the same source file.
                             * See `tests/cases/fourslash/transitiveExportImports3.ts`.
                             */
                            this.markSeenReExportRHS = nodeSeenTracker();
                            this.symbolIdToReferences = [];
                            // Source file ID -> symbol ID -> Whether the symbol has been searched for in the source file.
                            this.sourceFileToSeenSymbols = [];
                        }
                        includesSourceFile(sourceFile) {
                            return this.sourceFilesSet.has(sourceFile.fileName);
                        }
                        /** Gets every place to look for references of an exported symbols. See `ImportsResult` in `importTracker.ts` for more documentation. */
                        getImportSearches(exportSymbol, exportInfo) {
                            if (!this.importTracker)
                                this.importTracker = createImportTracker(this.sourceFiles, this.sourceFilesSet, this.checker, this.cancellationToken);
                            return this.importTracker(exportSymbol, exportInfo, this.options.use === 2 /* Rename */);
                        }
                        /** @param allSearchSymbols set of additional symbols for use by `includes`. */
                        createSearch(location, symbol, comingFrom, searchOptions = {}) {
                            const { text = stripQuotes(symbolName(getLocalSymbolForExportDefault(symbol) || getNonModuleSymbolOfMergedModuleSymbol(symbol) || symbol)), allSearchSymbols = [symbol] } = searchOptions;
                            const escapedText = escapeLeadingUnderscores(text);
                            const parents = this.options.implementations && location ? getParentSymbolsOfPropertyAccess(location, symbol, this.checker) : void 0;
                            return { symbol, comingFrom, text, escapedText, parents, allSearchSymbols, includes: (sym) => contains(allSearchSymbols, sym) };
                        }
                        /**
                         * Callback to add references for a particular searched symbol.
                         * This initializes a reference group, so only call this if you will add at least one reference.
                         */
                        referenceAdder(searchSymbol) {
                            const symbolId = getSymbolId(searchSymbol);
                            let references = this.symbolIdToReferences[symbolId];
                            if (!references) {
                                references = this.symbolIdToReferences[symbolId] = [];
                                this.result.push({ definition: { type: 0 /* Symbol */, symbol: searchSymbol }, references });
                            }
                            return (node, kind) => references.push(nodeEntry(node, kind));
                        }
                        /** Add a reference with no associated definition. */
                        addStringOrCommentReference(fileName, textSpan) {
                            this.result.push({
                                definition: void 0,
                                references: [{ kind: 0 /* Span */, fileName, textSpan }]
                            });
                        }
                        /** Returns `true` the first time we search for a symbol in a file and `false` afterwards. */
                        markSearchedSymbols(sourceFile, symbols) {
                            const sourceId = getNodeId(sourceFile);
                            const seenSymbols = this.sourceFileToSeenSymbols[sourceId] || (this.sourceFileToSeenSymbols[sourceId] = /* @__PURE__ */ new Set());
                            let anyNewSymbols = false;
                            for (const sym of symbols) {
                                anyNewSymbols = tryAddToSet(seenSymbols, getSymbolId(sym)) || anyNewSymbols;
                            }
                            return anyNewSymbols;
                        }
                    }
                    function searchForImportsOfExport(exportLocation, exportSymbol, exportInfo, state) {
                        const { importSearches, singleReferences, indirectUsers } = state.getImportSearches(exportSymbol, exportInfo);
                        if (singleReferences.length) {
                            const addRef = state.referenceAdder(exportSymbol);
                            for (const singleRef of singleReferences) {
                                if (shouldAddSingleReference(singleRef, state))
                                    addRef(singleRef);
                            }
                        }
                        for (const [importLocation, importSymbol] of importSearches) {
                            getReferencesInSourceFile(importLocation.getSourceFile(), state.createSearch(importLocation, importSymbol, 1 /* Export */), state);
                        }
                        if (indirectUsers.length) {
                            let indirectSearch;
                            switch (exportInfo.exportKind) {
                                case 0 /* Named */:
                                    indirectSearch = state.createSearch(exportLocation, exportSymbol, 1 /* Export */);
                                    break;
                                case 1 /* Default */:
                                    indirectSearch = state.options.use === 2 /* Rename */ ? void 0 : state.createSearch(exportLocation, exportSymbol, 1 /* Export */, { text: "default" });
                                    break;
                                case 2 /* ExportEquals */:
                                    break;
                            }
                            if (indirectSearch) {
                                for (const indirectUser of indirectUsers) {
                                    searchForName(indirectUser, indirectSearch, state);
                                }
                            }
                        }
                    }
                    function eachExportReference(sourceFiles, checker, cancellationToken, exportSymbol, exportingModuleSymbol, exportName, isDefaultExport, cb) {
                        const importTracker = createImportTracker(sourceFiles, new Set(sourceFiles.map((f) => f.fileName)), checker, cancellationToken);
                        const { importSearches, indirectUsers, singleReferences } = importTracker(exportSymbol, { exportKind: isDefaultExport ? 1 /* Default */ : 0 /* Named */, exportingModuleSymbol }, 
                        /*isForRename*/
                        false);
                        for (const [importLocation] of importSearches) {
                            cb(importLocation);
                        }
                        for (const singleReference of singleReferences) {
                            if (isIdentifier(singleReference) && isImportTypeNode(singleReference.parent)) {
                                cb(singleReference);
                            }
                        }
                        for (const indirectUser of indirectUsers) {
                            for (const node of getPossibleSymbolReferenceNodes(indirectUser, isDefaultExport ? "default" : exportName)) {
                                const symbol = checker.getSymbolAtLocation(node);
                                const hasExportAssignmentDeclaration = some(symbol == null ? void 0 : symbol.declarations, (d) => tryCast(d, isExportAssignment) ? true : false);
                                if (isIdentifier(node) && !isImportOrExportSpecifier(node.parent) && (symbol === exportSymbol || hasExportAssignmentDeclaration)) {
                                    cb(node);
                                }
                            }
                        }
                    }
                    Core2.eachExportReference = eachExportReference;
                    function shouldAddSingleReference(singleRef, state) {
                        if (!hasMatchingMeaning(singleRef, state))
                            return false;
                        if (state.options.use !== 2 /* Rename */)
                            return true;
                        if (!isIdentifier(singleRef))
                            return false;
                        return !(isImportOrExportSpecifier(singleRef.parent) && singleRef.escapedText === "default" /* Default */);
                    }
                    function searchForImportedSymbol(symbol, state) {
                        if (!symbol.declarations)
                            return;
                        for (const declaration of symbol.declarations) {
                            const exportingFile = declaration.getSourceFile();
                            getReferencesInSourceFile(exportingFile, state.createSearch(declaration, symbol, 0 /* Import */), state, state.includesSourceFile(exportingFile));
                        }
                    }
                    function searchForName(sourceFile, search, state) {
                        if (getNameTable(sourceFile).get(search.escapedText) !== void 0) {
                            getReferencesInSourceFile(sourceFile, search, state);
                        }
                    }
                    function getPropertySymbolOfDestructuringAssignment(location, checker) {
                        return isArrayLiteralOrObjectLiteralDestructuringPattern(location.parent.parent) ? checker.getPropertySymbolOfDestructuringAssignment(location) : void 0;
                    }
                    function getSymbolScope(symbol) {
                        const { declarations, flags, parent: parent2, valueDeclaration } = symbol;
                        if (valueDeclaration && (valueDeclaration.kind === 218 /* FunctionExpression */ || valueDeclaration.kind === 231 /* ClassExpression */)) {
                            return valueDeclaration;
                        }
                        if (!declarations) {
                            return void 0;
                        }
                        if (flags & (4 /* Property */ | 8192 /* Method */)) {
                            const privateDeclaration = find(declarations, (d) => hasEffectiveModifier(d, 2 /* Private */) || isPrivateIdentifierClassElementDeclaration(d));
                            if (privateDeclaration) {
                                return getAncestor(privateDeclaration, 263 /* ClassDeclaration */);
                            }
                            return void 0;
                        }
                        if (declarations.some(isObjectBindingElementWithoutPropertyName)) {
                            return void 0;
                        }
                        const exposedByParent = parent2 && !(symbol.flags & 262144 /* TypeParameter */);
                        if (exposedByParent && !(isExternalModuleSymbol(parent2) && !parent2.globalExports)) {
                            return void 0;
                        }
                        let scope;
                        for (const declaration of declarations) {
                            const container = getContainerNode(declaration);
                            if (scope && scope !== container) {
                                return void 0;
                            }
                            if (!container || container.kind === 312 /* SourceFile */ && !isExternalOrCommonJsModule(container)) {
                                return void 0;
                            }
                            scope = container;
                            if (isFunctionExpression(scope)) {
                                let next;
                                while (next = getNextJSDocCommentLocation(scope)) {
                                    scope = next;
                                }
                            }
                        }
                        return exposedByParent ? scope.getSourceFile() : scope;
                    }
                    function isSymbolReferencedInFile(definition, checker, sourceFile, searchContainer = sourceFile) {
                        return eachSymbolReferenceInFile(definition, checker, sourceFile, () => true, searchContainer) || false;
                    }
                    Core2.isSymbolReferencedInFile = isSymbolReferencedInFile;
                    function eachSymbolReferenceInFile(definition, checker, sourceFile, cb, searchContainer = sourceFile) {
                        const symbol = isParameterPropertyDeclaration(definition.parent, definition.parent.parent) ? first(checker.getSymbolsOfParameterPropertyDeclaration(definition.parent, definition.text)) : checker.getSymbolAtLocation(definition);
                        if (!symbol)
                            return void 0;
                        for (const token of getPossibleSymbolReferenceNodes(sourceFile, symbol.name, searchContainer)) {
                            if (!isIdentifier(token) || token === definition || token.escapedText !== definition.escapedText)
                                continue;
                            const referenceSymbol = checker.getSymbolAtLocation(token);
                            if (referenceSymbol === symbol || checker.getShorthandAssignmentValueSymbol(token.parent) === symbol || isExportSpecifier(token.parent) && getLocalSymbolForExportSpecifier(token, referenceSymbol, token.parent, checker) === symbol) {
                                const res = cb(token);
                                if (res)
                                    return res;
                            }
                        }
                    }
                    Core2.eachSymbolReferenceInFile = eachSymbolReferenceInFile;
                    function getTopMostDeclarationNamesInFile(declarationName, sourceFile) {
                        const candidates = filter(getPossibleSymbolReferenceNodes(sourceFile, declarationName), (name) => !!getDeclarationFromName(name));
                        return candidates.reduce((topMost, decl) => {
                            const depth = getDepth(decl);
                            if (!some(topMost.declarationNames) || depth === topMost.depth) {
                                topMost.declarationNames.push(decl);
                                topMost.depth = depth;
                            }
                            else if (depth < topMost.depth) {
                                topMost.declarationNames = [decl];
                                topMost.depth = depth;
                            }
                            return topMost;
                        }, { depth: Infinity, declarationNames: [] }).declarationNames;
                        function getDepth(declaration) {
                            let depth = 0;
                            while (declaration) {
                                declaration = getContainerNode(declaration);
                                depth++;
                            }
                            return depth;
                        }
                    }
                    Core2.getTopMostDeclarationNamesInFile = getTopMostDeclarationNamesInFile;
                    function someSignatureUsage(signature, sourceFiles, checker, cb) {
                        if (!signature.name || !isIdentifier(signature.name))
                            return false;
                        const symbol = Debug.checkDefined(checker.getSymbolAtLocation(signature.name));
                        for (const sourceFile of sourceFiles) {
                            for (const name of getPossibleSymbolReferenceNodes(sourceFile, symbol.name)) {
                                if (!isIdentifier(name) || name === signature.name || name.escapedText !== signature.name.escapedText)
                                    continue;
                                const called = climbPastPropertyAccess(name);
                                const call = isCallExpression(called.parent) && called.parent.expression === called ? called.parent : void 0;
                                const referenceSymbol = checker.getSymbolAtLocation(name);
                                if (referenceSymbol && checker.getRootSymbols(referenceSymbol).some((s) => s === symbol)) {
                                    if (cb(name, call)) {
                                        return true;
                                    }
                                }
                            }
                        }
                        return false;
                    }
                    Core2.someSignatureUsage = someSignatureUsage;
                    function getPossibleSymbolReferenceNodes(sourceFile, symbolName2, container = sourceFile) {
                        return mapDefined(getPossibleSymbolReferencePositions(sourceFile, symbolName2, container), (pos) => {
                            const referenceLocation = getTouchingPropertyName(sourceFile, pos);
                            return referenceLocation === sourceFile ? void 0 : referenceLocation;
                        });
                    }
                    function getPossibleSymbolReferencePositions(sourceFile, symbolName2, container = sourceFile) {
                        const positions = [];
                        if (!symbolName2 || !symbolName2.length) {
                            return positions;
                        }
                        const text = sourceFile.text;
                        const sourceLength = text.length;
                        const symbolNameLength = symbolName2.length;
                        let position = text.indexOf(symbolName2, container.pos);
                        while (position >= 0) {
                            if (position > container.end)
                                break;
                            const endPosition = position + symbolNameLength;
                            if ((position === 0 || !isIdentifierPart(text.charCodeAt(position - 1), 99 /* Latest */)) && (endPosition === sourceLength || !isIdentifierPart(text.charCodeAt(endPosition), 99 /* Latest */))) {
                                positions.push(position);
                            }
                            position = text.indexOf(symbolName2, position + symbolNameLength + 1);
                        }
                        return positions;
                    }
                    function getLabelReferencesInNode(container, targetLabel) {
                        const sourceFile = container.getSourceFile();
                        const labelName = targetLabel.text;
                        const references = mapDefined(getPossibleSymbolReferenceNodes(sourceFile, labelName, container), (node) => (
                        // Only pick labels that are either the target label, or have a target that is the target label
                        node === targetLabel || isJumpStatementTarget(node) && getTargetLabel(node, labelName) === targetLabel ? nodeEntry(node) : void 0));
                        return [{ definition: { type: 1 /* Label */, node: targetLabel }, references }];
                    }
                    function isValidReferencePosition(node, searchSymbolName) {
                        switch (node.kind) {
                            case 81 /* PrivateIdentifier */:
                                if (isJSDocMemberName(node.parent)) {
                                    return true;
                                }
                            case 80 /* Identifier */:
                                return node.text.length === searchSymbolName.length;
                            case 15 /* NoSubstitutionTemplateLiteral */:
                            case 11 /* StringLiteral */: {
                                const str = node;
                                return (isLiteralNameOfPropertyDeclarationOrIndexAccess(str) || isNameOfModuleDeclaration(node) || isExpressionOfExternalModuleImportEqualsDeclaration(node) || isCallExpression(node.parent) && isBindableObjectDefinePropertyCall(node.parent) && node.parent.arguments[1] === node) && str.text.length === searchSymbolName.length;
                            }
                            case 9 /* NumericLiteral */:
                                return isLiteralNameOfPropertyDeclarationOrIndexAccess(node) && node.text.length === searchSymbolName.length;
                            case 90 /* DefaultKeyword */:
                                return "default".length === searchSymbolName.length;
                            default:
                                return false;
                        }
                    }
                    function getAllReferencesForImportMeta(sourceFiles, cancellationToken) {
                        const references = flatMap(sourceFiles, (sourceFile) => {
                            cancellationToken.throwIfCancellationRequested();
                            return mapDefined(getPossibleSymbolReferenceNodes(sourceFile, "meta", sourceFile), (node) => {
                                const parent2 = node.parent;
                                if (isImportMeta(parent2)) {
                                    return nodeEntry(parent2);
                                }
                            });
                        });
                        return references.length ? [{ definition: { type: 2 /* Keyword */, node: references[0].node }, references }] : void 0;
                    }
                    function getAllReferencesForKeyword(sourceFiles, keywordKind, cancellationToken, filter2) {
                        const references = flatMap(sourceFiles, (sourceFile) => {
                            cancellationToken.throwIfCancellationRequested();
                            return mapDefined(getPossibleSymbolReferenceNodes(sourceFile, tokenToString(keywordKind), sourceFile), (referenceLocation) => {
                                if (referenceLocation.kind === keywordKind && (!filter2 || filter2(referenceLocation))) {
                                    return nodeEntry(referenceLocation);
                                }
                            });
                        });
                        return references.length ? [{ definition: { type: 2 /* Keyword */, node: references[0].node }, references }] : void 0;
                    }
                    function getReferencesInSourceFile(sourceFile, search, state, addReferencesHere = true) {
                        state.cancellationToken.throwIfCancellationRequested();
                        return getReferencesInContainer(sourceFile, sourceFile, search, state, addReferencesHere);
                    }
                    function getReferencesInContainer(container, sourceFile, search, state, addReferencesHere) {
                        if (!state.markSearchedSymbols(sourceFile, search.allSearchSymbols)) {
                            return;
                        }
                        for (const position of getPossibleSymbolReferencePositions(sourceFile, search.text, container)) {
                            getReferencesAtLocation(sourceFile, position, search, state, addReferencesHere);
                        }
                    }
                    function hasMatchingMeaning(referenceLocation, state) {
                        return !!(getMeaningFromLocation(referenceLocation) & state.searchMeaning);
                    }
                    function getReferencesAtLocation(sourceFile, position, search, state, addReferencesHere) {
                        const referenceLocation = getTouchingPropertyName(sourceFile, position);
                        if (!isValidReferencePosition(referenceLocation, search.text)) {
                            if (!state.options.implementations && (state.options.findInStrings && isInString(sourceFile, position) || state.options.findInComments && isInNonReferenceComment(sourceFile, position))) {
                                state.addStringOrCommentReference(sourceFile.fileName, createTextSpan(position, search.text.length));
                            }
                            return;
                        }
                        if (!hasMatchingMeaning(referenceLocation, state))
                            return;
                        let referenceSymbol = state.checker.getSymbolAtLocation(referenceLocation);
                        if (!referenceSymbol) {
                            return;
                        }
                        const parent2 = referenceLocation.parent;
                        if (isImportSpecifier(parent2) && parent2.propertyName === referenceLocation) {
                            return;
                        }
                        if (isExportSpecifier(parent2)) {
                            Debug.assert(referenceLocation.kind === 80 /* Identifier */);
                            getReferencesAtExportSpecifier(referenceLocation, referenceSymbol, parent2, search, state, addReferencesHere);
                            return;
                        }
                        if (isJSDocPropertyLikeTag(parent2) && parent2.isNameFirst && parent2.typeExpression && isJSDocTypeLiteral(parent2.typeExpression.type) && parent2.typeExpression.type.jsDocPropertyTags && length(parent2.typeExpression.type.jsDocPropertyTags)) {
                            getReferencesAtJSDocTypeLiteral(parent2.typeExpression.type.jsDocPropertyTags, referenceLocation, search, state);
                            return;
                        }
                        const relatedSymbol = getRelatedSymbol(search, referenceSymbol, referenceLocation, state);
                        if (!relatedSymbol) {
                            getReferenceForShorthandProperty(referenceSymbol, search, state);
                            return;
                        }
                        switch (state.specialSearchKind) {
                            case 0 /* None */:
                                if (addReferencesHere)
                                    addReference(referenceLocation, relatedSymbol, state);
                                break;
                            case 1 /* Constructor */:
                                addConstructorReferences(referenceLocation, sourceFile, search, state);
                                break;
                            case 2 /* Class */:
                                addClassStaticThisReferences(referenceLocation, search, state);
                                break;
                            default:
                                Debug.assertNever(state.specialSearchKind);
                        }
                        if (isInJSFile(referenceLocation) && isBindingElement(referenceLocation.parent) && isVariableDeclarationInitializedToBareOrAccessedRequire(referenceLocation.parent.parent.parent)) {
                            referenceSymbol = referenceLocation.parent.symbol;
                            if (!referenceSymbol)
                                return;
                        }
                        getImportOrExportReferences(referenceLocation, referenceSymbol, search, state);
                    }
                    function getReferencesAtJSDocTypeLiteral(jsDocPropertyTags, referenceLocation, search, state) {
                        const addRef = state.referenceAdder(search.symbol);
                        addReference(referenceLocation, search.symbol, state);
                        forEach(jsDocPropertyTags, (propTag) => {
                            if (isQualifiedName(propTag.name)) {
                                addRef(propTag.name.left);
                            }
                        });
                    }
                    function getReferencesAtExportSpecifier(referenceLocation, referenceSymbol, exportSpecifier, search, state, addReferencesHere, alwaysGetReferences) {
                        Debug.assert(!alwaysGetReferences || !!state.options.providePrefixAndSuffixTextForRename, "If alwaysGetReferences is true, then prefix/suffix text must be enabled");
                        const { parent: parent2, propertyName, name } = exportSpecifier;
                        const exportDeclaration = parent2.parent;
                        const localSymbol = getLocalSymbolForExportSpecifier(referenceLocation, referenceSymbol, exportSpecifier, state.checker);
                        if (!alwaysGetReferences && !search.includes(localSymbol)) {
                            return;
                        }
                        if (!propertyName) {
                            if (!(state.options.use === 2 /* Rename */ && name.escapedText === "default" /* Default */)) {
                                addRef();
                            }
                        }
                        else if (referenceLocation === propertyName) {
                            if (!exportDeclaration.moduleSpecifier) {
                                addRef();
                            }
                            if (addReferencesHere && state.options.use !== 2 /* Rename */ && state.markSeenReExportRHS(name)) {
                                addReference(name, Debug.checkDefined(exportSpecifier.symbol), state);
                            }
                        }
                        else {
                            if (state.markSeenReExportRHS(referenceLocation)) {
                                addRef();
                            }
                        }
                        if (!isForRenameWithPrefixAndSuffixText(state.options) || alwaysGetReferences) {
                            const isDefaultExport = referenceLocation.escapedText === "default" || exportSpecifier.name.escapedText === "default";
                            const exportKind = isDefaultExport ? 1 /* Default */ : 0 /* Named */;
                            const exportSymbol = Debug.checkDefined(exportSpecifier.symbol);
                            const exportInfo = getExportInfo(exportSymbol, exportKind, state.checker);
                            if (exportInfo) {
                                searchForImportsOfExport(referenceLocation, exportSymbol, exportInfo, state);
                            }
                        }
                        if (search.comingFrom !== 1 /* Export */ && exportDeclaration.moduleSpecifier && !propertyName && !isForRenameWithPrefixAndSuffixText(state.options)) {
                            const imported = state.checker.getExportSpecifierLocalTargetSymbol(exportSpecifier);
                            if (imported)
                                searchForImportedSymbol(imported, state);
                        }
                        function addRef() {
                            if (addReferencesHere)
                                addReference(referenceLocation, localSymbol, state);
                        }
                    }
                    function getLocalSymbolForExportSpecifier(referenceLocation, referenceSymbol, exportSpecifier, checker) {
                        return isExportSpecifierAlias(referenceLocation, exportSpecifier) && checker.getExportSpecifierLocalTargetSymbol(exportSpecifier) || referenceSymbol;
                    }
                    function isExportSpecifierAlias(referenceLocation, exportSpecifier) {
                        const { parent: parent2, propertyName, name } = exportSpecifier;
                        Debug.assert(propertyName === referenceLocation || name === referenceLocation);
                        if (propertyName) {
                            return propertyName === referenceLocation;
                        }
                        else {
                            return !parent2.parent.moduleSpecifier;
                        }
                    }
                    function getImportOrExportReferences(referenceLocation, referenceSymbol, search, state) {
                        const importOrExport = getImportOrExportSymbol(referenceLocation, referenceSymbol, state.checker, search.comingFrom === 1 /* Export */);
                        if (!importOrExport)
                            return;
                        const { symbol } = importOrExport;
                        if (importOrExport.kind === 0 /* Import */) {
                            if (!isForRenameWithPrefixAndSuffixText(state.options)) {
                                searchForImportedSymbol(symbol, state);
                            }
                        }
                        else {
                            searchForImportsOfExport(referenceLocation, symbol, importOrExport.exportInfo, state);
                        }
                    }
                    function getReferenceForShorthandProperty({ flags, valueDeclaration }, search, state) {
                        const shorthandValueSymbol = state.checker.getShorthandAssignmentValueSymbol(valueDeclaration);
                        const name = valueDeclaration && getNameOfDeclaration(valueDeclaration);
                        if (!(flags & 33554432 /* Transient */) && name && search.includes(shorthandValueSymbol)) {
                            addReference(name, shorthandValueSymbol, state);
                        }
                    }
                    function addReference(referenceLocation, relatedSymbol, state) {
                        const { kind, symbol } = "kind" in relatedSymbol ? relatedSymbol : { kind: void 0, symbol: relatedSymbol };
                        if (state.options.use === 2 /* Rename */ && referenceLocation.kind === 90 /* DefaultKeyword */) {
                            return;
                        }
                        const addRef = state.referenceAdder(symbol);
                        if (state.options.implementations) {
                            addImplementationReferences(referenceLocation, addRef, state);
                        }
                        else {
                            addRef(referenceLocation, kind);
                        }
                    }
                    function addConstructorReferences(referenceLocation, sourceFile, search, state) {
                        if (isNewExpressionTarget(referenceLocation)) {
                            addReference(referenceLocation, search.symbol, state);
                        }
                        const pusher = () => state.referenceAdder(search.symbol);
                        if (isClassLike(referenceLocation.parent)) {
                            Debug.assert(referenceLocation.kind === 90 /* DefaultKeyword */ || referenceLocation.parent.name === referenceLocation);
                            findOwnConstructorReferences(search.symbol, sourceFile, pusher());
                        }
                        else {
                            const classExtending = tryGetClassByExtendingIdentifier(referenceLocation);
                            if (classExtending) {
                                findSuperConstructorAccesses(classExtending, pusher());
                                findInheritedConstructorReferences(classExtending, state);
                            }
                        }
                    }
                    function addClassStaticThisReferences(referenceLocation, search, state) {
                        addReference(referenceLocation, search.symbol, state);
                        const classLike = referenceLocation.parent;
                        if (state.options.use === 2 /* Rename */ || !isClassLike(classLike))
                            return;
                        Debug.assert(classLike.name === referenceLocation);
                        const addRef = state.referenceAdder(search.symbol);
                        for (const member of classLike.members) {
                            if (!(isMethodOrAccessor(member) && isStatic(member))) {
                                continue;
                            }
                            if (member.body) {
                                member.body.forEachChild(function cb(node) {
                                    if (node.kind === 110 /* ThisKeyword */) {
                                        addRef(node);
                                    }
                                    else if (!isFunctionLike(node) && !isClassLike(node)) {
                                        node.forEachChild(cb);
                                    }
                                });
                            }
                        }
                    }
                    function findOwnConstructorReferences(classSymbol, sourceFile, addNode) {
                        const constructorSymbol = getClassConstructorSymbol(classSymbol);
                        if (constructorSymbol && constructorSymbol.declarations) {
                            for (const decl of constructorSymbol.declarations) {
                                const ctrKeyword = findChildOfKind(decl, 137 /* ConstructorKeyword */, sourceFile);
                                Debug.assert(decl.kind === 176 /* Constructor */ && !!ctrKeyword);
                                addNode(ctrKeyword);
                            }
                        }
                        if (classSymbol.exports) {
                            classSymbol.exports.forEach((member) => {
                                const decl = member.valueDeclaration;
                                if (decl && decl.kind === 174 /* MethodDeclaration */) {
                                    const body = decl.body;
                                    if (body) {
                                        forEachDescendantOfKind(body, 110 /* ThisKeyword */, (thisKeyword) => {
                                            if (isNewExpressionTarget(thisKeyword)) {
                                                addNode(thisKeyword);
                                            }
                                        });
                                    }
                                }
                            });
                        }
                    }
                    function getClassConstructorSymbol(classSymbol) {
                        return classSymbol.members && classSymbol.members.get("__constructor" /* Constructor */);
                    }
                    function findSuperConstructorAccesses(classDeclaration, addNode) {
                        const constructor = getClassConstructorSymbol(classDeclaration.symbol);
                        if (!(constructor && constructor.declarations)) {
                            return;
                        }
                        for (const decl of constructor.declarations) {
                            Debug.assert(decl.kind === 176 /* Constructor */);
                            const body = decl.body;
                            if (body) {
                                forEachDescendantOfKind(body, 108 /* SuperKeyword */, (node) => {
                                    if (isCallExpressionTarget(node)) {
                                        addNode(node);
                                    }
                                });
                            }
                        }
                    }
                    function hasOwnConstructor(classDeclaration) {
                        return !!getClassConstructorSymbol(classDeclaration.symbol);
                    }
                    function findInheritedConstructorReferences(classDeclaration, state) {
                        if (hasOwnConstructor(classDeclaration))
                            return;
                        const classSymbol = classDeclaration.symbol;
                        const search = state.createSearch(
                        /*location*/
                        void 0, classSymbol, 
                        /*comingFrom*/
                        void 0);
                        getReferencesInContainerOrFiles(classSymbol, state, search);
                    }
                    function addImplementationReferences(refNode, addReference2, state) {
                        if (isDeclarationName(refNode) && isImplementation(refNode.parent)) {
                            addReference2(refNode);
                            return;
                        }
                        if (refNode.kind !== 80 /* Identifier */) {
                            return;
                        }
                        if (refNode.parent.kind === 304 /* ShorthandPropertyAssignment */) {
                            getReferenceEntriesForShorthandPropertyAssignment(refNode, state.checker, addReference2);
                        }
                        const containingNode = getContainingNodeIfInHeritageClause(refNode);
                        if (containingNode) {
                            addReference2(containingNode);
                            return;
                        }
                        const typeNode = findAncestor(refNode, (a) => !isQualifiedName(a.parent) && !isTypeNode(a.parent) && !isTypeElement(a.parent));
                        const typeHavingNode = typeNode.parent;
                        if (hasType(typeHavingNode) && typeHavingNode.type === typeNode && state.markSeenContainingTypeReference(typeHavingNode)) {
                            if (hasInitializer(typeHavingNode)) {
                                addIfImplementation(typeHavingNode.initializer);
                            }
                            else if (isFunctionLike(typeHavingNode) && typeHavingNode.body) {
                                const body = typeHavingNode.body;
                                if (body.kind === 241 /* Block */) {
                                    forEachReturnStatement(body, (returnStatement) => {
                                        if (returnStatement.expression)
                                            addIfImplementation(returnStatement.expression);
                                    });
                                }
                                else {
                                    addIfImplementation(body);
                                }
                            }
                            else if (isAssertionExpression(typeHavingNode)) {
                                addIfImplementation(typeHavingNode.expression);
                            }
                        }
                        function addIfImplementation(e) {
                            if (isImplementationExpression(e))
                                addReference2(e);
                        }
                    }
                    function getContainingNodeIfInHeritageClause(node) {
                        return isIdentifier(node) || isPropertyAccessExpression(node) ? getContainingNodeIfInHeritageClause(node.parent) : isExpressionWithTypeArguments(node) ? tryCast(node.parent.parent, or(isClassLike, isInterfaceDeclaration)) : void 0;
                    }
                    function isImplementationExpression(node) {
                        switch (node.kind) {
                            case 217 /* ParenthesizedExpression */:
                                return isImplementationExpression(node.expression);
                            case 219 /* ArrowFunction */:
                            case 218 /* FunctionExpression */:
                            case 210 /* ObjectLiteralExpression */:
                            case 231 /* ClassExpression */:
                            case 209 /* ArrayLiteralExpression */:
                                return true;
                            default:
                                return false;
                        }
                    }
                    function explicitlyInheritsFrom(symbol, parent2, cachedResults, checker) {
                        if (symbol === parent2) {
                            return true;
                        }
                        const key = getSymbolId(symbol) + "," + getSymbolId(parent2);
                        const cached = cachedResults.get(key);
                        if (cached !== void 0) {
                            return cached;
                        }
                        cachedResults.set(key, false);
                        const inherits = !!symbol.declarations && symbol.declarations.some((declaration) => getAllSuperTypeNodes(declaration).some((typeReference) => {
                            const type = checker.getTypeAtLocation(typeReference);
                            return !!type && !!type.symbol && explicitlyInheritsFrom(type.symbol, parent2, cachedResults, checker);
                        }));
                        cachedResults.set(key, inherits);
                        return inherits;
                    }
                    function getReferencesForSuperKeyword(superKeyword) {
                        let searchSpaceNode = getSuperContainer(superKeyword, 
                        /*stopOnFunctions*/
                        false);
                        if (!searchSpaceNode) {
                            return void 0;
                        }
                        let staticFlag = 256 /* Static */;
                        switch (searchSpaceNode.kind) {
                            case 172 /* PropertyDeclaration */:
                            case 171 /* PropertySignature */:
                            case 174 /* MethodDeclaration */:
                            case 173 /* MethodSignature */:
                            case 176 /* Constructor */:
                            case 177 /* GetAccessor */:
                            case 178 /* SetAccessor */:
                                staticFlag &= getSyntacticModifierFlags(searchSpaceNode);
                                searchSpaceNode = searchSpaceNode.parent;
                                break;
                            default:
                                return void 0;
                        }
                        const sourceFile = searchSpaceNode.getSourceFile();
                        const references = mapDefined(getPossibleSymbolReferenceNodes(sourceFile, "super", searchSpaceNode), (node) => {
                            if (node.kind !== 108 /* SuperKeyword */) {
                                return;
                            }
                            const container = getSuperContainer(node, 
                            /*stopOnFunctions*/
                            false);
                            return container && isStatic(container) === !!staticFlag && container.parent.symbol === searchSpaceNode.symbol ? nodeEntry(node) : void 0;
                        });
                        return [{ definition: { type: 0 /* Symbol */, symbol: searchSpaceNode.symbol }, references }];
                    }
                    function isParameterName(node) {
                        return node.kind === 80 /* Identifier */ && node.parent.kind === 169 /* Parameter */ && node.parent.name === node;
                    }
                    function getReferencesForThisKeyword(thisOrSuperKeyword, sourceFiles, cancellationToken) {
                        let searchSpaceNode = getThisContainer(thisOrSuperKeyword, 
                        /*includeArrowFunctions*/
                        false, 
                        /*includeClassComputedPropertyName*/
                        false);
                        let staticFlag = 256 /* Static */;
                        switch (searchSpaceNode.kind) {
                            case 174 /* MethodDeclaration */:
                            case 173 /* MethodSignature */:
                                if (isObjectLiteralMethod(searchSpaceNode)) {
                                    staticFlag &= getSyntacticModifierFlags(searchSpaceNode);
                                    searchSpaceNode = searchSpaceNode.parent;
                                    break;
                                }
                            case 172 /* PropertyDeclaration */:
                            case 171 /* PropertySignature */:
                            case 176 /* Constructor */:
                            case 177 /* GetAccessor */:
                            case 178 /* SetAccessor */:
                                staticFlag &= getSyntacticModifierFlags(searchSpaceNode);
                                searchSpaceNode = searchSpaceNode.parent;
                                break;
                            case 312 /* SourceFile */:
                                if (isExternalModule(searchSpaceNode) || isParameterName(thisOrSuperKeyword)) {
                                    return void 0;
                                }
                            case 262 /* FunctionDeclaration */:
                            case 218 /* FunctionExpression */:
                                break;
                            default:
                                return void 0;
                        }
                        const references = flatMap(searchSpaceNode.kind === 312 /* SourceFile */ ? sourceFiles : [searchSpaceNode.getSourceFile()], (sourceFile) => {
                            cancellationToken.throwIfCancellationRequested();
                            return getPossibleSymbolReferenceNodes(sourceFile, "this", isSourceFile(searchSpaceNode) ? sourceFile : searchSpaceNode).filter((node) => {
                                if (!isThis(node)) {
                                    return false;
                                }
                                const container = getThisContainer(node, 
                                /*includeArrowFunctions*/
                                false, 
                                /*includeClassComputedPropertyName*/
                                false);
                                if (!canHaveSymbol(container))
                                    return false;
                                switch (searchSpaceNode.kind) {
                                    case 218 /* FunctionExpression */:
                                    case 262 /* FunctionDeclaration */:
                                        return searchSpaceNode.symbol === container.symbol;
                                    case 174 /* MethodDeclaration */:
                                    case 173 /* MethodSignature */:
                                        return isObjectLiteralMethod(searchSpaceNode) && searchSpaceNode.symbol === container.symbol;
                                    case 231 /* ClassExpression */:
                                    case 263 /* ClassDeclaration */:
                                    case 210 /* ObjectLiteralExpression */:
                                        return container.parent && canHaveSymbol(container.parent) && searchSpaceNode.symbol === container.parent.symbol && isStatic(container) === !!staticFlag;
                                    case 312 /* SourceFile */:
                                        return container.kind === 312 /* SourceFile */ && !isExternalModule(container) && !isParameterName(node);
                                }
                            });
                        }).map((n) => nodeEntry(n));
                        const thisParameter = firstDefined(references, (r) => isParameter(r.node.parent) ? r.node : void 0);
                        return [{
                                definition: { type: 3 /* This */, node: thisParameter || thisOrSuperKeyword },
                                references
                            }];
                    }
                    function getReferencesForStringLiteral(node, sourceFiles, checker, cancellationToken) {
                        const type = getContextualTypeFromParentOrAncestorTypeNode(node, checker);
                        const references = flatMap(sourceFiles, (sourceFile) => {
                            cancellationToken.throwIfCancellationRequested();
                            return mapDefined(getPossibleSymbolReferenceNodes(sourceFile, node.text), (ref) => {
                                if (isStringLiteralLike(ref) && ref.text === node.text) {
                                    if (type) {
                                        const refType = getContextualTypeFromParentOrAncestorTypeNode(ref, checker);
                                        if (type !== checker.getStringType() && (type === refType || isStringLiteralPropertyReference(ref, checker))) {
                                            return nodeEntry(ref, 2 /* StringLiteral */);
                                        }
                                    }
                                    else {
                                        return isNoSubstitutionTemplateLiteral(ref) && !rangeIsOnSingleLine(ref, sourceFile) ? void 0 : nodeEntry(ref, 2 /* StringLiteral */);
                                    }
                                }
                            });
                        });
                        return [{
                                definition: { type: 4 /* String */, node },
                                references
                            }];
                    }
                    function isStringLiteralPropertyReference(node, checker) {
                        if (isPropertySignature(node.parent)) {
                            return checker.getPropertyOfType(checker.getTypeAtLocation(node.parent.parent), node.text);
                        }
                    }
                    function populateSearchSymbolSet(symbol, location, checker, isForRename, providePrefixAndSuffixText, implementations) {
                        const result = [];
                        forEachRelatedSymbol(symbol, location, checker, isForRename, !(isForRename && providePrefixAndSuffixText), (sym, root, base) => {
                            if (base) {
                                if (isStaticSymbol(symbol) !== isStaticSymbol(base)) {
                                    base = void 0;
                                }
                            }
                            result.push(base || root || sym);
                        }, 
                        // when try to find implementation, implementations is true, and not allowed to find base class
                        /*allowBaseTypes*/
                        () => !implementations);
                        return result;
                    }
                    function forEachRelatedSymbol(symbol, location, checker, isForRenamePopulateSearchSymbolSet, onlyIncludeBindingElementAtReferenceLocation, cbSymbol, allowBaseTypes) {
                        const containingObjectLiteralElement = getContainingObjectLiteralElement(location);
                        if (containingObjectLiteralElement) {
                            const shorthandValueSymbol = checker.getShorthandAssignmentValueSymbol(location.parent);
                            if (shorthandValueSymbol && isForRenamePopulateSearchSymbolSet) {
                                return cbSymbol(shorthandValueSymbol, 
                                /*rootSymbol*/
                                void 0, 
                                /*baseSymbol*/
                                void 0, 3 /* SearchedLocalFoundProperty */);
                            }
                            const contextualType = checker.getContextualType(containingObjectLiteralElement.parent);
                            const res2 = contextualType && firstDefined(getPropertySymbolsFromContextualType(containingObjectLiteralElement, checker, contextualType, 
                            /*unionSymbolOk*/
                            true), (sym) => fromRoot(sym, 4 /* SearchedPropertyFoundLocal */));
                            if (res2)
                                return res2;
                            const propertySymbol = getPropertySymbolOfDestructuringAssignment(location, checker);
                            const res1 = propertySymbol && cbSymbol(propertySymbol, 
                            /*rootSymbol*/
                            void 0, 
                            /*baseSymbol*/
                            void 0, 4 /* SearchedPropertyFoundLocal */);
                            if (res1)
                                return res1;
                            const res22 = shorthandValueSymbol && cbSymbol(shorthandValueSymbol, 
                            /*rootSymbol*/
                            void 0, 
                            /*baseSymbol*/
                            void 0, 3 /* SearchedLocalFoundProperty */);
                            if (res22)
                                return res22;
                        }
                        const aliasedSymbol = getMergedAliasedSymbolOfNamespaceExportDeclaration(location, symbol, checker);
                        if (aliasedSymbol) {
                            const res2 = cbSymbol(aliasedSymbol, 
                            /*rootSymbol*/
                            void 0, 
                            /*baseSymbol*/
                            void 0, 1 /* Node */);
                            if (res2)
                                return res2;
                        }
                        const res = fromRoot(symbol);
                        if (res)
                            return res;
                        if (symbol.valueDeclaration && isParameterPropertyDeclaration(symbol.valueDeclaration, symbol.valueDeclaration.parent)) {
                            const paramProps = checker.getSymbolsOfParameterPropertyDeclaration(cast(symbol.valueDeclaration, isParameter), symbol.name);
                            Debug.assert(paramProps.length === 2 && !!(paramProps[0].flags & 1 /* FunctionScopedVariable */) && !!(paramProps[1].flags & 4 /* Property */));
                            return fromRoot(symbol.flags & 1 /* FunctionScopedVariable */ ? paramProps[1] : paramProps[0]);
                        }
                        const exportSpecifier = getDeclarationOfKind(symbol, 281 /* ExportSpecifier */);
                        if (!isForRenamePopulateSearchSymbolSet || exportSpecifier && !exportSpecifier.propertyName) {
                            const localSymbol = exportSpecifier && checker.getExportSpecifierLocalTargetSymbol(exportSpecifier);
                            if (localSymbol) {
                                const res2 = cbSymbol(localSymbol, 
                                /*rootSymbol*/
                                void 0, 
                                /*baseSymbol*/
                                void 0, 1 /* Node */);
                                if (res2)
                                    return res2;
                            }
                        }
                        if (!isForRenamePopulateSearchSymbolSet) {
                            let bindingElementPropertySymbol;
                            if (onlyIncludeBindingElementAtReferenceLocation) {
                                bindingElementPropertySymbol = isObjectBindingElementWithoutPropertyName(location.parent) ? getPropertySymbolFromBindingElement(checker, location.parent) : void 0;
                            }
                            else {
                                bindingElementPropertySymbol = getPropertySymbolOfObjectBindingPatternWithoutPropertyName(symbol, checker);
                            }
                            return bindingElementPropertySymbol && fromRoot(bindingElementPropertySymbol, 4 /* SearchedPropertyFoundLocal */);
                        }
                        Debug.assert(isForRenamePopulateSearchSymbolSet);
                        const includeOriginalSymbolOfBindingElement = onlyIncludeBindingElementAtReferenceLocation;
                        if (includeOriginalSymbolOfBindingElement) {
                            const bindingElementPropertySymbol = getPropertySymbolOfObjectBindingPatternWithoutPropertyName(symbol, checker);
                            return bindingElementPropertySymbol && fromRoot(bindingElementPropertySymbol, 4 /* SearchedPropertyFoundLocal */);
                        }
                        function fromRoot(sym, kind) {
                            return firstDefined(checker.getRootSymbols(sym), (rootSymbol) => cbSymbol(sym, rootSymbol, 
                            /*baseSymbol*/
                            void 0, kind) || (rootSymbol.parent && rootSymbol.parent.flags & (32 /* Class */ | 64 /* Interface */) && allowBaseTypes(rootSymbol) ? getPropertySymbolsFromBaseTypes(rootSymbol.parent, rootSymbol.name, checker, (base) => cbSymbol(sym, rootSymbol, base, kind)) : void 0));
                        }
                        function getPropertySymbolOfObjectBindingPatternWithoutPropertyName(symbol2, checker2) {
                            const bindingElement = getDeclarationOfKind(symbol2, 208 /* BindingElement */);
                            if (bindingElement && isObjectBindingElementWithoutPropertyName(bindingElement)) {
                                return getPropertySymbolFromBindingElement(checker2, bindingElement);
                            }
                        }
                    }
                    function getPropertySymbolsFromBaseTypes(symbol, propertyName, checker, cb) {
                        const seen = /* @__PURE__ */ new Map();
                        return recur(symbol);
                        function recur(symbol2) {
                            if (!(symbol2.flags & (32 /* Class */ | 64 /* Interface */)) || !addToSeen(seen, getSymbolId(symbol2)))
                                return;
                            return firstDefined(symbol2.declarations, (declaration) => firstDefined(getAllSuperTypeNodes(declaration), (typeReference) => {
                                const type = checker.getTypeAtLocation(typeReference);
                                const propertySymbol = type && type.symbol && checker.getPropertyOfType(type, propertyName);
                                return type && propertySymbol && (firstDefined(checker.getRootSymbols(propertySymbol), cb) || recur(type.symbol));
                            }));
                        }
                    }
                    function isStaticSymbol(symbol) {
                        if (!symbol.valueDeclaration)
                            return false;
                        const modifierFlags = getEffectiveModifierFlags(symbol.valueDeclaration);
                        return !!(modifierFlags & 256 /* Static */);
                    }
                    function getRelatedSymbol(search, referenceSymbol, referenceLocation, state) {
                        const { checker } = state;
                        return forEachRelatedSymbol(referenceSymbol, referenceLocation, checker, 
                        /*isForRenamePopulateSearchSymbolSet*/
                        false, 
                        /*onlyIncludeBindingElementAtReferenceLocation*/
                        state.options.use !== 2 /* Rename */ || !!state.options.providePrefixAndSuffixTextForRename, (sym, rootSymbol, baseSymbol, kind) => {
                            if (baseSymbol) {
                                if (isStaticSymbol(referenceSymbol) !== isStaticSymbol(baseSymbol)) {
                                    baseSymbol = void 0;
                                }
                            }
                            return search.includes(baseSymbol || rootSymbol || sym) ? { symbol: rootSymbol && !(getCheckFlags(sym) & 6 /* Synthetic */) ? rootSymbol : sym, kind } : void 0;
                        }, 
                        /*allowBaseTypes*/
                        (rootSymbol) => !(search.parents && !search.parents.some((parent2) => explicitlyInheritsFrom(rootSymbol.parent, parent2, state.inheritsFromCache, checker))));
                    }
                    function getIntersectingMeaningFromDeclarations(node, symbol) {
                        let meaning = getMeaningFromLocation(node);
                        const { declarations } = symbol;
                        if (declarations) {
                            let lastIterationMeaning;
                            do {
                                lastIterationMeaning = meaning;
                                for (const declaration of declarations) {
                                    const declarationMeaning = getMeaningFromDeclaration(declaration);
                                    if (declarationMeaning & meaning) {
                                        meaning |= declarationMeaning;
                                    }
                                }
                            } while (meaning !== lastIterationMeaning);
                        }
                        return meaning;
                    }
                    Core2.getIntersectingMeaningFromDeclarations = getIntersectingMeaningFromDeclarations;
                    function isImplementation(node) {
                        return !!(node.flags & 33554432 /* Ambient */) ? !(isInterfaceDeclaration(node) || isTypeAliasDeclaration(node)) : isVariableLike(node) ? hasInitializer(node) : isFunctionLikeDeclaration(node) ? !!node.body : isClassLike(node) || isModuleOrEnumDeclaration(node);
                    }
                    function getReferenceEntriesForShorthandPropertyAssignment(node, checker, addReference2) {
                        const refSymbol = checker.getSymbolAtLocation(node);
                        const shorthandSymbol = checker.getShorthandAssignmentValueSymbol(refSymbol.valueDeclaration);
                        if (shorthandSymbol) {
                            for (const declaration of shorthandSymbol.getDeclarations()) {
                                if (getMeaningFromDeclaration(declaration) & 1 /* Value */) {
                                    addReference2(declaration);
                                }
                            }
                        }
                    }
                    Core2.getReferenceEntriesForShorthandPropertyAssignment = getReferenceEntriesForShorthandPropertyAssignment;
                    function forEachDescendantOfKind(node, kind, action) {
                        forEachChild(node, (child) => {
                            if (child.kind === kind) {
                                action(child);
                            }
                            forEachDescendantOfKind(child, kind, action);
                        });
                    }
                    function tryGetClassByExtendingIdentifier(node) {
                        return tryGetClassExtendingExpressionWithTypeArguments(climbPastPropertyAccess(node).parent);
                    }
                    function getParentSymbolsOfPropertyAccess(location, symbol, checker) {
                        const propertyAccessExpression = isRightSideOfPropertyAccess(location) ? location.parent : void 0;
                        const lhsType = propertyAccessExpression && checker.getTypeAtLocation(propertyAccessExpression.expression);
                        const res = mapDefined(lhsType && (lhsType.isUnionOrIntersection() ? lhsType.types : lhsType.symbol === symbol.parent ? void 0 : [lhsType]), (t) => t.symbol && t.symbol.flags & (32 /* Class */ | 64 /* Interface */) ? t.symbol : void 0);
                        return res.length === 0 ? void 0 : res;
                    }
                    function isForRenameWithPrefixAndSuffixText(options) {
                        return options.use === 2 /* Rename */ && options.providePrefixAndSuffixTextForRename;
                    }
                })(Core || (Core = {}));
            }
        });
        // src/services/_namespaces/ts.FindAllReferences.ts
        var ts_FindAllReferences_exports = {};
        __export(ts_FindAllReferences_exports, {
            Core: () => Core,
            DefinitionKind: () => DefinitionKind,
            EntryKind: () => EntryKind,
            ExportKind: () => ExportKind2,
            FindReferencesUse: () => FindReferencesUse,
            ImportExport: () => ImportExport,
            createImportTracker: () => createImportTracker,
            findModuleReferences: () => findModuleReferences,
            findReferenceOrRenameEntries: () => findReferenceOrRenameEntries,
            findReferencedSymbols: () => findReferencedSymbols,
            getContextNode: () => getContextNode,
            getExportInfo: () => getExportInfo,
            getImplementationsAtPosition: () => getImplementationsAtPosition,
            getImportOrExportSymbol: () => getImportOrExportSymbol,
            getReferenceEntriesForNode: () => getReferenceEntriesForNode,
            getTextSpanOfEntry: () => getTextSpanOfEntry,
            isContextWithStartAndEndNode: () => isContextWithStartAndEndNode,
            isDeclarationOfSymbol: () => isDeclarationOfSymbol,
            isWriteAccessForReference: () => isWriteAccessForReference,
            nodeEntry: () => nodeEntry,
            toContextSpan: () => toContextSpan,
            toHighlightSpan: () => toHighlightSpan,
            toReferenceEntry: () => toReferenceEntry,
            toRenameLocation: () => toRenameLocation
        });
        var init_ts_FindAllReferences = __esm({
            "src/services/_namespaces/ts.FindAllReferences.ts"() {
                "use strict";
                init_importTracker();
                init_findAllReferences();
            }
        });
        // src/services/goToDefinition.ts
        function getDefinitionAtPosition(program, sourceFile, position, searchOtherFilesOnly, stopAtAlias) {
            var _a;
            const resolvedRef = getReferenceAtPosition(sourceFile, position, program);
            const fileReferenceDefinition = resolvedRef && [getDefinitionInfoForFileReference(resolvedRef.reference.fileName, resolvedRef.fileName, resolvedRef.unverified)] || emptyArray;
            if (resolvedRef == null ? void 0 : resolvedRef.file) {
                return fileReferenceDefinition;
            }
            const node = getTouchingPropertyName(sourceFile, position);
            if (node === sourceFile) {
                return void 0;
            }
            const { parent: parent2 } = node;
            const typeChecker = program.getTypeChecker();
            if (node.kind === 164 /* OverrideKeyword */ || isIdentifier(node) && isJSDocOverrideTag(parent2) && parent2.tagName === node) {
                return getDefinitionFromOverriddenMember(typeChecker, node) || emptyArray;
            }
            if (isJumpStatementTarget(node)) {
                const label = getTargetLabel(node.parent, node.text);
                return label ? [createDefinitionInfoFromName(typeChecker, label, "label" /* label */, node.text, 
                    /*containerName*/
                    void 0)] : void 0;
            }
            switch (node.kind) {
                case 107 /* ReturnKeyword */:
                    const functionDeclaration = findAncestor(node.parent, (n) => isClassStaticBlockDeclaration(n) ? "quit" : isFunctionLikeDeclaration(n));
                    return functionDeclaration ? [createDefinitionFromSignatureDeclaration(typeChecker, functionDeclaration)] : void 0;
                case 90 /* DefaultKeyword */:
                    if (!isDefaultClause(node.parent)) {
                        break;
                    }
                case 84 /* CaseKeyword */:
                    const switchStatement = findAncestor(node.parent, isSwitchStatement);
                    if (switchStatement) {
                        return [createDefinitionInfoFromSwitch(switchStatement, sourceFile)];
                    }
                    break;
            }
            if (node.kind === 135 /* AwaitKeyword */) {
                const functionDeclaration = findAncestor(node, (n) => isFunctionLikeDeclaration(n));
                const isAsyncFunction2 = functionDeclaration && some(functionDeclaration.modifiers, (node2) => node2.kind === 134 /* AsyncKeyword */);
                return isAsyncFunction2 ? [createDefinitionFromSignatureDeclaration(typeChecker, functionDeclaration)] : void 0;
            }
            if (node.kind === 127 /* YieldKeyword */) {
                const functionDeclaration = findAncestor(node, (n) => isFunctionLikeDeclaration(n));
                const isGeneratorFunction = functionDeclaration && functionDeclaration.asteriskToken;
                return isGeneratorFunction ? [createDefinitionFromSignatureDeclaration(typeChecker, functionDeclaration)] : void 0;
            }
            if (isStaticModifier(node) && isClassStaticBlockDeclaration(node.parent)) {
                const classDecl = node.parent.parent;
                const { symbol: symbol2, failedAliasResolution: failedAliasResolution2 } = getSymbol(classDecl, typeChecker, stopAtAlias);
                const staticBlocks = filter(classDecl.members, isClassStaticBlockDeclaration);
                const containerName = symbol2 ? typeChecker.symbolToString(symbol2, classDecl) : "";
                const sourceFile2 = node.getSourceFile();
                return map(staticBlocks, (staticBlock) => {
                    let { pos } = moveRangePastModifiers(staticBlock);
                    pos = skipTrivia(sourceFile2.text, pos);
                    return createDefinitionInfoFromName(typeChecker, staticBlock, "constructor" /* constructorImplementationElement */, "static {}", containerName, 
                    /*unverified*/
                    false, failedAliasResolution2, { start: pos, length: "static".length });
                });
            }
            let { symbol, failedAliasResolution } = getSymbol(node, typeChecker, stopAtAlias);
            let fallbackNode = node;
            if (searchOtherFilesOnly && failedAliasResolution) {
                const importDeclaration = forEach([node, ...(symbol == null ? void 0 : symbol.declarations) || emptyArray], (n) => findAncestor(n, isAnyImportOrBareOrAccessedRequire));
                const moduleSpecifier = importDeclaration && tryGetModuleSpecifierFromDeclaration(importDeclaration);
                if (moduleSpecifier) {
                    ({ symbol, failedAliasResolution } = getSymbol(moduleSpecifier, typeChecker, stopAtAlias));
                    fallbackNode = moduleSpecifier;
                }
            }
            if (!symbol && isModuleSpecifierLike(fallbackNode)) {
                const ref = (_a = program.getResolvedModuleFromModuleSpecifier(fallbackNode)) == null ? void 0 : _a.resolvedModule;
                if (ref) {
                    return [{
                            name: fallbackNode.text,
                            fileName: ref.resolvedFileName,
                            containerName: void 0,
                            containerKind: void 0,
                            kind: "script" /* scriptElement */,
                            textSpan: createTextSpan(0, 0),
                            failedAliasResolution,
                            isAmbient: isDeclarationFileName(ref.resolvedFileName),
                            unverified: fallbackNode !== node
                        }];
                }
            }
            if (!symbol) {
                return concatenate(fileReferenceDefinition, getDefinitionInfoForIndexSignatures(node, typeChecker));
            }
            if (searchOtherFilesOnly && every(symbol.declarations, (d) => d.getSourceFile().fileName === sourceFile.fileName))
                return void 0;
            const calledDeclaration = tryGetSignatureDeclaration(typeChecker, node);
            if (calledDeclaration && !(isJsxOpeningLikeElement(node.parent) && isConstructorLike(calledDeclaration))) {
                const sigInfo = createDefinitionFromSignatureDeclaration(typeChecker, calledDeclaration, failedAliasResolution);
                if (typeChecker.getRootSymbols(symbol).some((s) => symbolMatchesSignature(s, calledDeclaration))) {
                    return [sigInfo];
                }
                else {
                    const defs = getDefinitionFromSymbol(typeChecker, symbol, node, failedAliasResolution, calledDeclaration) || emptyArray;
                    return node.kind === 108 /* SuperKeyword */ ? [sigInfo, ...defs] : [...defs, sigInfo];
                }
            }
            if (node.parent.kind === 304 /* ShorthandPropertyAssignment */) {
                const shorthandSymbol = typeChecker.getShorthandAssignmentValueSymbol(symbol.valueDeclaration);
                const definitions = (shorthandSymbol == null ? void 0 : shorthandSymbol.declarations) ? shorthandSymbol.declarations.map((decl) => createDefinitionInfo(decl, typeChecker, shorthandSymbol, node, 
                /*unverified*/
                false, failedAliasResolution)) : emptyArray;
                return concatenate(definitions, getDefinitionFromObjectLiteralElement(typeChecker, node));
            }
            if (isPropertyName(node) && isBindingElement(parent2) && isObjectBindingPattern(parent2.parent) && node === (parent2.propertyName || parent2.name)) {
                const name = getNameFromPropertyName(node);
                const type = typeChecker.getTypeAtLocation(parent2.parent);
                return name === void 0 ? emptyArray : flatMap(type.isUnion() ? type.types : [type], (t) => {
                    const prop = t.getProperty(name);
                    return prop && getDefinitionFromSymbol(typeChecker, prop, node);
                });
            }
            const objectLiteralElementDefinition = getDefinitionFromObjectLiteralElement(typeChecker, node);
            return concatenate(fileReferenceDefinition, objectLiteralElementDefinition.length ? objectLiteralElementDefinition : getDefinitionFromSymbol(typeChecker, symbol, node, failedAliasResolution));
        }
        function symbolMatchesSignature(s, calledDeclaration) {
            var _a;
            return s === calledDeclaration.symbol || s === calledDeclaration.symbol.parent || isAssignmentExpression(calledDeclaration.parent) || !isCallLikeExpression(calledDeclaration.parent) && s === ((_a = tryCast(calledDeclaration.parent, canHaveSymbol)) == null ? void 0 : _a.symbol);
        }
        function getDefinitionFromObjectLiteralElement(typeChecker, node) {
            const element = getContainingObjectLiteralElement(node);
            if (element) {
                const contextualType = element && typeChecker.getContextualType(element.parent);
                if (contextualType) {
                    return flatMap(getPropertySymbolsFromContextualType(element, typeChecker, contextualType, 
                    /*unionSymbolOk*/
                    false), (propertySymbol) => getDefinitionFromSymbol(typeChecker, propertySymbol, node));
                }
            }
            return emptyArray;
        }
        function getDefinitionFromOverriddenMember(typeChecker, node) {
            const classElement = findAncestor(node, isClassElement);
            if (!(classElement && classElement.name))
                return;
            const baseDeclaration = findAncestor(classElement, isClassLike);
            if (!baseDeclaration)
                return;
            const baseTypeNode = getEffectiveBaseTypeNode(baseDeclaration);
            if (!baseTypeNode)
                return;
            const expression = skipParentheses(baseTypeNode.expression);
            const base = isClassExpression(expression) ? expression.symbol : typeChecker.getSymbolAtLocation(expression);
            if (!base)
                return;
            const name = unescapeLeadingUnderscores(getTextOfPropertyName(classElement.name));
            const symbol = hasStaticModifier(classElement) ? typeChecker.getPropertyOfType(typeChecker.getTypeOfSymbol(base), name) : typeChecker.getPropertyOfType(typeChecker.getDeclaredTypeOfSymbol(base), name);
            if (!symbol)
                return;
            return getDefinitionFromSymbol(typeChecker, symbol, node);
        }
        function getReferenceAtPosition(sourceFile, position, program) {
            var _a, _b;
            const referencePath = findReferenceInPosition(sourceFile.referencedFiles, position);
            if (referencePath) {
                const file = program.getSourceFileFromReference(sourceFile, referencePath);
                return file && { reference: referencePath, fileName: file.fileName, file, unverified: false };
            }
            const typeReferenceDirective = findReferenceInPosition(sourceFile.typeReferenceDirectives, position);
            if (typeReferenceDirective) {
                const reference = (_a = program.getResolvedTypeReferenceDirectives().get(typeReferenceDirective.fileName, typeReferenceDirective.resolutionMode || sourceFile.impliedNodeFormat)) == null ? void 0 : _a.resolvedTypeReferenceDirective;
                const file = reference && program.getSourceFile(reference.resolvedFileName);
                return file && { reference: typeReferenceDirective, fileName: file.fileName, file, unverified: false };
            }
            const libReferenceDirective = findReferenceInPosition(sourceFile.libReferenceDirectives, position);
            if (libReferenceDirective) {
                const file = program.getLibFileFromReference(libReferenceDirective);
                return file && { reference: libReferenceDirective, fileName: file.fileName, file, unverified: false };
            }
            if (sourceFile.imports.length || sourceFile.moduleAugmentations.length) {
                const node = getTouchingToken(sourceFile, position);
                let resolution;
                if (isModuleSpecifierLike(node) && isExternalModuleNameRelative(node.text) && (resolution = program.getResolvedModuleFromModuleSpecifier(node))) {
                    const verifiedFileName = (_b = resolution.resolvedModule) == null ? void 0 : _b.resolvedFileName;
                    const fileName = verifiedFileName || resolvePath(getDirectoryPath(sourceFile.fileName), node.text);
                    return {
                        file: program.getSourceFile(fileName),
                        fileName,
                        reference: {
                            pos: node.getStart(),
                            end: node.getEnd(),
                            fileName: node.text
                        },
                        unverified: !verifiedFileName
                    };
                }
            }
            return void 0;
        }
        function shouldUnwrapFirstTypeArgumentTypeDefinitionFromTypeReference(typeChecker, type) {
            const referenceName = type.symbol.name;
            if (!typesWithUnwrappedTypeArguments.has(referenceName)) {
                return false;
            }
            const globalType = typeChecker.resolveName(referenceName, 
            /*location*/
            void 0, 788968 /* Type */, 
            /*excludeGlobals*/
            false);
            return !!globalType && globalType === type.target.symbol;
        }
        function shouldUnwrapFirstTypeArgumentTypeDefinitionFromAlias(typeChecker, type) {
            if (!type.aliasSymbol) {
                return false;
            }
            const referenceName = type.aliasSymbol.name;
            if (!typesWithUnwrappedTypeArguments.has(referenceName)) {
                return false;
            }
            const globalType = typeChecker.resolveName(referenceName, 
            /*location*/
            void 0, 788968 /* Type */, 
            /*excludeGlobals*/
            false);
            return !!globalType && globalType === type.aliasSymbol;
        }
        function getFirstTypeArgumentDefinitions(typeChecker, type, node, failedAliasResolution) {
            var _a, _b;
            if (!!(getObjectFlags(type) & 4 /* Reference */) && shouldUnwrapFirstTypeArgumentTypeDefinitionFromTypeReference(typeChecker, type)) {
                return definitionFromType(typeChecker.getTypeArguments(type)[0], typeChecker, node, failedAliasResolution);
            }
            if (shouldUnwrapFirstTypeArgumentTypeDefinitionFromAlias(typeChecker, type) && type.aliasTypeArguments) {
                return definitionFromType(type.aliasTypeArguments[0], typeChecker, node, failedAliasResolution);
            }
            if (getObjectFlags(type) & 32 /* Mapped */ && type.target && shouldUnwrapFirstTypeArgumentTypeDefinitionFromAlias(typeChecker, type.target)) {
                const declaration = (_b = (_a = type.aliasSymbol) == null ? void 0 : _a.declarations) == null ? void 0 : _b[0];
                if (declaration && isTypeAliasDeclaration(declaration) && isTypeReferenceNode(declaration.type) && declaration.type.typeArguments) {
                    return definitionFromType(typeChecker.getTypeAtLocation(declaration.type.typeArguments[0]), typeChecker, node, failedAliasResolution);
                }
            }
            return [];
        }
        function getTypeDefinitionAtPosition(typeChecker, sourceFile, position) {
            const node = getTouchingPropertyName(sourceFile, position);
            if (node === sourceFile) {
                return void 0;
            }
            if (isImportMeta(node.parent) && node.parent.name === node) {
                return definitionFromType(typeChecker.getTypeAtLocation(node.parent), typeChecker, node.parent, 
                /*failedAliasResolution*/
                false);
            }
            const { symbol, failedAliasResolution } = getSymbol(node, typeChecker, 
            /*stopAtAlias*/
            false);
            if (!symbol)
                return void 0;
            const typeAtLocation = typeChecker.getTypeOfSymbolAtLocation(symbol, node);
            const returnType = tryGetReturnTypeOfFunction(symbol, typeAtLocation, typeChecker);
            const fromReturnType = returnType && definitionFromType(returnType, typeChecker, node, failedAliasResolution);
            const [resolvedType, typeDefinitions] = fromReturnType && fromReturnType.length !== 0 ? [returnType, fromReturnType] : [typeAtLocation, definitionFromType(typeAtLocation, typeChecker, node, failedAliasResolution)];
            return typeDefinitions.length ? [...getFirstTypeArgumentDefinitions(typeChecker, resolvedType, node, failedAliasResolution), ...typeDefinitions] : !(symbol.flags & 111551 /* Value */) && symbol.flags & 788968 /* Type */ ? getDefinitionFromSymbol(typeChecker, skipAlias(symbol, typeChecker), node, failedAliasResolution) : void 0;
        }
        function definitionFromType(type, checker, node, failedAliasResolution) {
            return flatMap(type.isUnion() && !(type.flags & 32 /* Enum */) ? type.types : [type], (t) => t.symbol && getDefinitionFromSymbol(checker, t.symbol, node, failedAliasResolution));
        }
        function tryGetReturnTypeOfFunction(symbol, type, checker) {
            if (type.symbol === symbol || // At `const f = () => {}`, the symbol is `f` and the type symbol is at `() => {}`
                symbol.valueDeclaration && type.symbol && isVariableDeclaration(symbol.valueDeclaration) && symbol.valueDeclaration.initializer === type.symbol.valueDeclaration) {
                const sigs = type.getCallSignatures();
                if (sigs.length === 1)
                    return checker.getReturnTypeOfSignature(first(sigs));
            }
            return void 0;
        }
        function getDefinitionAndBoundSpan(program, sourceFile, position) {
            const definitions = getDefinitionAtPosition(program, sourceFile, position);
            if (!definitions || definitions.length === 0) {
                return void 0;
            }
            const comment = findReferenceInPosition(sourceFile.referencedFiles, position) || findReferenceInPosition(sourceFile.typeReferenceDirectives, position) || findReferenceInPosition(sourceFile.libReferenceDirectives, position);
            if (comment) {
                return { definitions, textSpan: createTextSpanFromRange(comment) };
            }
            const node = getTouchingPropertyName(sourceFile, position);
            const textSpan = createTextSpan(node.getStart(), node.getWidth());
            return { definitions, textSpan };
        }
        function getDefinitionInfoForIndexSignatures(node, checker) {
            return mapDefined(checker.getIndexInfosAtLocation(node), (info) => info.declaration && createDefinitionFromSignatureDeclaration(checker, info.declaration));
        }
        function getSymbol(node, checker, stopAtAlias) {
            const symbol = checker.getSymbolAtLocation(node);
            let failedAliasResolution = false;
            if ((symbol == null ? void 0 : symbol.declarations) && symbol.flags & 2097152 /* Alias */ && !stopAtAlias && shouldSkipAlias(node, symbol.declarations[0])) {
                const aliased = checker.getAliasedSymbol(symbol);
                if (aliased.declarations) {
                    return { symbol: aliased };
                }
                else {
                    failedAliasResolution = true;
                }
            }
            return { symbol, failedAliasResolution };
        }
        function shouldSkipAlias(node, declaration) {
            if (node.kind !== 80 /* Identifier */) {
                return false;
            }
            if (node.parent === declaration) {
                return true;
            }
            if (declaration.kind === 274 /* NamespaceImport */) {
                return false;
            }
            return true;
        }
        function isExpandoDeclaration(node) {
            if (!isAssignmentDeclaration(node))
                return false;
            const containingAssignment = findAncestor(node, (p) => {
                if (isAssignmentExpression(p))
                    return true;
                if (!isAssignmentDeclaration(p))
                    return "quit";
                return false;
            });
            return !!containingAssignment && getAssignmentDeclarationKind(containingAssignment) === 5 /* Property */;
        }
        function getDefinitionFromSymbol(typeChecker, symbol, node, failedAliasResolution, excludeDeclaration) {
            const filteredDeclarations = filter(symbol.declarations, (d) => d !== excludeDeclaration);
            const withoutExpandos = filter(filteredDeclarations, (d) => !isExpandoDeclaration(d));
            const results = some(withoutExpandos) ? withoutExpandos : filteredDeclarations;
            return getConstructSignatureDefinition() || getCallSignatureDefinition() || map(results, (declaration) => createDefinitionInfo(declaration, typeChecker, symbol, node, 
            /*unverified*/
            false, failedAliasResolution));
            function getConstructSignatureDefinition() {
                if (symbol.flags & 32 /* Class */ && !(symbol.flags & (16 /* Function */ | 3 /* Variable */)) && (isNewExpressionTarget(node) || node.kind === 137 /* ConstructorKeyword */)) {
                    const cls = find(filteredDeclarations, isClassLike) || Debug.fail("Expected declaration to have at least one class-like declaration");
                    return getSignatureDefinition(cls.members, 
                    /*selectConstructors*/
                    true);
                }
            }
            function getCallSignatureDefinition() {
                return isCallOrNewExpressionTarget(node) || isNameOfFunctionDeclaration(node) ? getSignatureDefinition(filteredDeclarations, 
                /*selectConstructors*/
                false) : void 0;
            }
            function getSignatureDefinition(signatureDeclarations, selectConstructors) {
                if (!signatureDeclarations) {
                    return void 0;
                }
                const declarations = signatureDeclarations.filter(selectConstructors ? isConstructorDeclaration : isFunctionLike);
                const declarationsWithBody = declarations.filter((d) => !!d.body);
                return declarations.length ? declarationsWithBody.length !== 0 ? declarationsWithBody.map((x) => createDefinitionInfo(x, typeChecker, symbol, node)) : [createDefinitionInfo(last(declarations), typeChecker, symbol, node, 
                    /*unverified*/
                    false, failedAliasResolution)] : void 0;
            }
        }
        function createDefinitionInfo(declaration, checker, symbol, node, unverified, failedAliasResolution) {
            const symbolName2 = checker.symbolToString(symbol);
            const symbolKind = ts_SymbolDisplay_exports.getSymbolKind(checker, symbol, node);
            const containerName = symbol.parent ? checker.symbolToString(symbol.parent, node) : "";
            return createDefinitionInfoFromName(checker, declaration, symbolKind, symbolName2, containerName, unverified, failedAliasResolution);
        }
        function createDefinitionInfoFromName(checker, declaration, symbolKind, symbolName2, containerName, unverified, failedAliasResolution, textSpan) {
            const sourceFile = declaration.getSourceFile();
            if (!textSpan) {
                const name = getNameOfDeclaration(declaration) || declaration;
                textSpan = createTextSpanFromNode(name, sourceFile);
            }
            return {
                fileName: sourceFile.fileName,
                textSpan,
                kind: symbolKind,
                name: symbolName2,
                containerKind: void 0,
                // TODO: GH#18217
                containerName,
                ...ts_FindAllReferences_exports.toContextSpan(textSpan, sourceFile, ts_FindAllReferences_exports.getContextNode(declaration)),
                isLocal: !isDefinitionVisible(checker, declaration),
                isAmbient: !!(declaration.flags & 33554432 /* Ambient */),
                unverified,
                failedAliasResolution
            };
        }
        function createDefinitionInfoFromSwitch(statement, sourceFile) {
            const keyword = ts_FindAllReferences_exports.getContextNode(statement);
            const textSpan = createTextSpanFromNode(isContextWithStartAndEndNode(keyword) ? keyword.start : keyword, sourceFile);
            return {
                fileName: sourceFile.fileName,
                textSpan,
                kind: "keyword" /* keyword */,
                name: "switch",
                containerKind: void 0,
                containerName: "",
                ...ts_FindAllReferences_exports.toContextSpan(textSpan, sourceFile, keyword),
                isLocal: true,
                isAmbient: false,
                unverified: false,
                failedAliasResolution: void 0
            };
        }
        function isDefinitionVisible(checker, declaration) {
            if (checker.isDeclarationVisible(declaration))
                return true;
            if (!declaration.parent)
                return false;
            if (hasInitializer(declaration.parent) && declaration.parent.initializer === declaration)
                return isDefinitionVisible(checker, declaration.parent);
            switch (declaration.kind) {
                case 172 /* PropertyDeclaration */:
                case 177 /* GetAccessor */:
                case 178 /* SetAccessor */:
                case 174 /* MethodDeclaration */:
                    if (hasEffectiveModifier(declaration, 2 /* Private */))
                        return false;
                case 176 /* Constructor */:
                case 303 /* PropertyAssignment */:
                case 304 /* ShorthandPropertyAssignment */:
                case 210 /* ObjectLiteralExpression */:
                case 231 /* ClassExpression */:
                case 219 /* ArrowFunction */:
                case 218 /* FunctionExpression */:
                    return isDefinitionVisible(checker, declaration.parent);
                default:
                    return false;
            }
        }
        function createDefinitionFromSignatureDeclaration(typeChecker, decl, failedAliasResolution) {
            return createDefinitionInfo(decl, typeChecker, decl.symbol, decl, 
            /*unverified*/
            false, failedAliasResolution);
        }
        function findReferenceInPosition(refs, pos) {
            return find(refs, (ref) => textRangeContainsPositionInclusive(ref, pos));
        }
        function getDefinitionInfoForFileReference(name, targetFileName, unverified) {
            return {
                fileName: targetFileName,
                textSpan: createTextSpanFromBounds(0, 0),
                kind: "script" /* scriptElement */,
                name,
                containerName: void 0,
                containerKind: void 0,
                // TODO: GH#18217
                unverified
            };
        }
        function getAncestorCallLikeExpression(node) {
            const target = findAncestor(node, (n) => !isRightSideOfPropertyAccess(n));
            const callLike = target == null ? void 0 : target.parent;
            return callLike && isCallLikeExpression(callLike) && getInvokedExpression(callLike) === target ? callLike : void 0;
        }
        function tryGetSignatureDeclaration(typeChecker, node) {
            const callLike = getAncestorCallLikeExpression(node);
            const signature = callLike && typeChecker.getResolvedSignature(callLike);
            return tryCast(signature && signature.declaration, (d) => isFunctionLike(d) && !isFunctionTypeNode(d));
        }
        function isConstructorLike(node) {
            switch (node.kind) {
                case 176 /* Constructor */:
                case 185 /* ConstructorType */:
                case 180 /* ConstructSignature */:
                    return true;
                default:
                    return false;
            }
        }
        var typesWithUnwrappedTypeArguments;
        var init_goToDefinition = __esm({
            "src/services/goToDefinition.ts"() {
                "use strict";
                init_ts4();
                init_ts_FindAllReferences();
                typesWithUnwrappedTypeArguments = /* @__PURE__ */ new Set([
                    "Array",
                    "ArrayLike",
                    "ReadonlyArray",
                    "Promise",
                    "PromiseLike",
                    "Iterable",
                    "IterableIterator",
                    "AsyncIterable",
                    "Set",
                    "WeakSet",
                    "ReadonlySet",
                    "Map",
                    "WeakMap",
                    "ReadonlyMap",
                    "Partial",
                    "Required",
                    "Readonly",
                    "Pick",
                    "Omit"
                ]);
            }
        });
        // src/services/_namespaces/ts.GoToDefinition.ts
        var ts_GoToDefinition_exports = {};
        __export(ts_GoToDefinition_exports, {
            createDefinitionInfo: () => createDefinitionInfo,
            findReferenceInPosition: () => findReferenceInPosition,
            getDefinitionAndBoundSpan: () => getDefinitionAndBoundSpan,
            getDefinitionAtPosition: () => getDefinitionAtPosition,
            getReferenceAtPosition: () => getReferenceAtPosition,
            getTypeDefinitionAtPosition: () => getTypeDefinitionAtPosition
        });
        var init_ts_GoToDefinition = __esm({
            "src/services/_namespaces/ts.GoToDefinition.ts"() {
                "use strict";
                init_goToDefinition();
            }
        });
        // src/services/inlayHints.ts
        function shouldShowParameterNameHints(preferences) {
            return preferences.includeInlayParameterNameHints === "literals" || preferences.includeInlayParameterNameHints === "all";
        }
        function shouldShowLiteralParameterNameHintsOnly(preferences) {
            return preferences.includeInlayParameterNameHints === "literals";
        }
        function shouldUseInteractiveInlayHints(preferences) {
            return preferences.interactiveInlayHints === true;
        }
        function provideInlayHints(context) {
            const { file, program, span, cancellationToken, preferences } = context;
            const sourceFileText = file.text;
            const compilerOptions = program.getCompilerOptions();
            const quotePreference = getQuotePreference(file, preferences);
            const checker = program.getTypeChecker();
            const result = [];
            visitor(file);
            return result;
            function visitor(node) {
                if (!node || node.getFullWidth() === 0) {
                    return;
                }
                switch (node.kind) {
                    case 267 /* ModuleDeclaration */:
                    case 263 /* ClassDeclaration */:
                    case 264 /* InterfaceDeclaration */:
                    case 262 /* FunctionDeclaration */:
                    case 231 /* ClassExpression */:
                    case 218 /* FunctionExpression */:
                    case 174 /* MethodDeclaration */:
                    case 219 /* ArrowFunction */:
                        cancellationToken.throwIfCancellationRequested();
                }
                if (!textSpanIntersectsWith(span, node.pos, node.getFullWidth())) {
                    return;
                }
                if (isTypeNode(node) && !isExpressionWithTypeArguments(node)) {
                    return;
                }
                if (preferences.includeInlayVariableTypeHints && isVariableDeclaration(node)) {
                    visitVariableLikeDeclaration(node);
                }
                else if (preferences.includeInlayPropertyDeclarationTypeHints && isPropertyDeclaration(node)) {
                    visitVariableLikeDeclaration(node);
                }
                else if (preferences.includeInlayEnumMemberValueHints && isEnumMember(node)) {
                    visitEnumMember(node);
                }
                else if (shouldShowParameterNameHints(preferences) && (isCallExpression(node) || isNewExpression(node))) {
                    visitCallOrNewExpression(node);
                }
                else {
                    if (preferences.includeInlayFunctionParameterTypeHints && isFunctionLikeDeclaration(node) && hasContextSensitiveParameters(node)) {
                        visitFunctionLikeForParameterType(node);
                    }
                    if (preferences.includeInlayFunctionLikeReturnTypeHints && isSignatureSupportingReturnAnnotation(node)) {
                        visitFunctionDeclarationLikeForReturnType(node);
                    }
                }
                return forEachChild(node, visitor);
            }
            function isSignatureSupportingReturnAnnotation(node) {
                return isArrowFunction(node) || isFunctionExpression(node) || isFunctionDeclaration(node) || isMethodDeclaration(node) || isGetAccessorDeclaration(node);
            }
            function addParameterHints(text, parameter, position, isFirstVariadicArgument) {
                let hintText = `${isFirstVariadicArgument ? "..." : ""}${text}`;
                let displayParts;
                if (shouldUseInteractiveInlayHints(preferences)) {
                    displayParts = [getNodeDisplayPart(hintText, parameter), { text: ":" }];
                    hintText = "";
                }
                else {
                    hintText += ":";
                }
                result.push({
                    text: hintText,
                    position,
                    kind: "Parameter" /* Parameter */,
                    whitespaceAfter: true,
                    displayParts
                });
            }
            function addTypeHints(hintText, position) {
                result.push({
                    text: typeof hintText === "string" ? `: ${hintText}` : "",
                    displayParts: typeof hintText === "string" ? void 0 : [{ text: ": " }, ...hintText],
                    position,
                    kind: "Type" /* Type */,
                    whitespaceBefore: true
                });
            }
            function addEnumMemberValueHints(text, position) {
                result.push({
                    text: `= ${text}`,
                    position,
                    kind: "Enum" /* Enum */,
                    whitespaceBefore: true
                });
            }
            function visitEnumMember(member) {
                if (member.initializer) {
                    return;
                }
                const enumValue = checker.getConstantValue(member);
                if (enumValue !== void 0) {
                    addEnumMemberValueHints(enumValue.toString(), member.end);
                }
            }
            function isModuleReferenceType(type) {
                return type.symbol && type.symbol.flags & 1536 /* Module */;
            }
            function visitVariableLikeDeclaration(decl) {
                if (!decl.initializer || isBindingPattern(decl.name) || isVariableDeclaration(decl) && !isHintableDeclaration(decl)) {
                    return;
                }
                const effectiveTypeAnnotation = getEffectiveTypeAnnotationNode(decl);
                if (effectiveTypeAnnotation) {
                    return;
                }
                const declarationType = checker.getTypeAtLocation(decl);
                if (isModuleReferenceType(declarationType)) {
                    return;
                }
                const hintParts = typeToInlayHintParts(declarationType);
                if (hintParts) {
                    const hintText = typeof hintParts === "string" ? hintParts : hintParts.map((part) => part.text).join("");
                    const isVariableNameMatchesType = preferences.includeInlayVariableTypeHintsWhenTypeMatchesName === false && equateStringsCaseInsensitive(decl.name.getText(), hintText);
                    if (isVariableNameMatchesType) {
                        return;
                    }
                    addTypeHints(hintParts, decl.name.end);
                }
            }
            function visitCallOrNewExpression(expr) {
                const args = expr.arguments;
                if (!args || !args.length) {
                    return;
                }
                const candidates = [];
                const signature = checker.getResolvedSignatureForSignatureHelp(expr, candidates);
                if (!signature || !candidates.length) {
                    return;
                }
                let signatureParamPos = 0;
                for (const originalArg of args) {
                    const arg = skipParentheses(originalArg);
                    if (shouldShowLiteralParameterNameHintsOnly(preferences) && !isHintableLiteral(arg)) {
                        signatureParamPos++;
                        continue;
                    }
                    let spreadArgs = 0;
                    if (isSpreadElement(arg)) {
                        const spreadType = checker.getTypeAtLocation(arg.expression);
                        if (checker.isTupleType(spreadType)) {
                            const { elementFlags, fixedLength } = spreadType.target;
                            if (fixedLength === 0) {
                                continue;
                            }
                            const firstOptionalIndex = findIndex(elementFlags, (f) => !(f & 1 /* Required */));
                            const requiredArgs = firstOptionalIndex < 0 ? fixedLength : firstOptionalIndex;
                            if (requiredArgs > 0) {
                                spreadArgs = firstOptionalIndex < 0 ? fixedLength : firstOptionalIndex;
                            }
                        }
                    }
                    const identifierInfo = checker.getParameterIdentifierInfoAtPosition(signature, signatureParamPos);
                    signatureParamPos = signatureParamPos + (spreadArgs || 1);
                    if (identifierInfo) {
                        const { parameter, parameterName, isRestParameter: isFirstVariadicArgument } = identifierInfo;
                        const isParameterNameNotSameAsArgument = preferences.includeInlayParameterNameHintsWhenArgumentMatchesName || !identifierOrAccessExpressionPostfixMatchesParameterName(arg, parameterName);
                        if (!isParameterNameNotSameAsArgument && !isFirstVariadicArgument) {
                            continue;
                        }
                        const name = unescapeLeadingUnderscores(parameterName);
                        if (leadingCommentsContainsParameterName(arg, name)) {
                            continue;
                        }
                        addParameterHints(name, parameter, originalArg.getStart(), isFirstVariadicArgument);
                    }
                }
            }
            function identifierOrAccessExpressionPostfixMatchesParameterName(expr, parameterName) {
                if (isIdentifier(expr)) {
                    return expr.text === parameterName;
                }
                if (isPropertyAccessExpression(expr)) {
                    return expr.name.text === parameterName;
                }
                return false;
            }
            function leadingCommentsContainsParameterName(node, name) {
                if (!isIdentifierText(name, compilerOptions.target, getLanguageVariant(file.scriptKind))) {
                    return false;
                }
                const ranges = getLeadingCommentRanges(sourceFileText, node.pos);
                if (!(ranges == null ? void 0 : ranges.length)) {
                    return false;
                }
                const regex = leadingParameterNameCommentRegexFactory(name);
                return some(ranges, (range) => regex.test(sourceFileText.substring(range.pos, range.end)));
            }
            function isHintableLiteral(node) {
                switch (node.kind) {
                    case 224 /* PrefixUnaryExpression */: {
                        const operand = node.operand;
                        return isLiteralExpression(operand) || isIdentifier(operand) && isInfinityOrNaNString(operand.escapedText);
                    }
                    case 112 /* TrueKeyword */:
                    case 97 /* FalseKeyword */:
                    case 106 /* NullKeyword */:
                    case 15 /* NoSubstitutionTemplateLiteral */:
                    case 228 /* TemplateExpression */:
                        return true;
                    case 80 /* Identifier */: {
                        const name = node.escapedText;
                        return isUndefined(name) || isInfinityOrNaNString(name);
                    }
                }
                return isLiteralExpression(node);
            }
            function visitFunctionDeclarationLikeForReturnType(decl) {
                if (isArrowFunction(decl)) {
                    if (!findChildOfKind(decl, 21 /* OpenParenToken */, file)) {
                        return;
                    }
                }
                const effectiveTypeAnnotation = getEffectiveReturnTypeNode(decl);
                if (effectiveTypeAnnotation || !decl.body) {
                    return;
                }
                const signature = checker.getSignatureFromDeclaration(decl);
                if (!signature) {
                    return;
                }
                const returnType = checker.getReturnTypeOfSignature(signature);
                if (isModuleReferenceType(returnType)) {
                    return;
                }
                const hintParts = typeToInlayHintParts(returnType);
                if (hintParts) {
                    addTypeHints(hintParts, getTypeAnnotationPosition(decl));
                }
            }
            function getTypeAnnotationPosition(decl) {
                const closeParenToken = findChildOfKind(decl, 22 /* CloseParenToken */, file);
                if (closeParenToken) {
                    return closeParenToken.end;
                }
                return decl.parameters.end;
            }
            function visitFunctionLikeForParameterType(node) {
                const signature = checker.getSignatureFromDeclaration(node);
                if (!signature) {
                    return;
                }
                for (let i = 0; i < node.parameters.length && i < signature.parameters.length; ++i) {
                    const param = node.parameters[i];
                    if (!isHintableDeclaration(param)) {
                        continue;
                    }
                    const effectiveTypeAnnotation = getEffectiveTypeAnnotationNode(param);
                    if (effectiveTypeAnnotation) {
                        continue;
                    }
                    const typeHints = getParameterDeclarationTypeHints(signature.parameters[i]);
                    if (!typeHints) {
                        continue;
                    }
                    addTypeHints(typeHints, param.questionToken ? param.questionToken.end : param.name.end);
                }
            }
            function getParameterDeclarationTypeHints(symbol) {
                const valueDeclaration = symbol.valueDeclaration;
                if (!valueDeclaration || !isParameter(valueDeclaration)) {
                    return void 0;
                }
                const signatureParamType = checker.getTypeOfSymbolAtLocation(symbol, valueDeclaration);
                if (isModuleReferenceType(signatureParamType)) {
                    return void 0;
                }
                return typeToInlayHintParts(signatureParamType);
            }
            function printTypeInSingleLine(type) {
                const flags = 70221824 /* IgnoreErrors */ | 1048576 /* AllowUniqueESSymbolType */ | 16384 /* UseAliasDefinedOutsideCurrentScope */;
                const printer = createPrinterWithRemoveComments();
                return usingSingleLineStringWriter((writer) => {
                    const typeNode = checker.typeToTypeNode(type, 
                    /*enclosingDeclaration*/
                    void 0, flags);
                    Debug.assertIsDefined(typeNode, "should always get typenode");
                    printer.writeNode(4 /* Unspecified */, typeNode, 
                    /*sourceFile*/
                    file, writer);
                });
            }
            function typeToInlayHintParts(type) {
                if (!shouldUseInteractiveInlayHints(preferences)) {
                    return printTypeInSingleLine(type);
                }
                const flags = 70221824 /* IgnoreErrors */ | 1048576 /* AllowUniqueESSymbolType */ | 16384 /* UseAliasDefinedOutsideCurrentScope */;
                const typeNode = checker.typeToTypeNode(type, 
                /*enclosingDeclaration*/
                void 0, flags);
                Debug.assertIsDefined(typeNode, "should always get typenode");
                const parts = [];
                visitForDisplayParts(typeNode);
                return parts;
                function visitForDisplayParts(node) {
                    var _a, _b;
                    if (!node) {
                        return;
                    }
                    const tokenString = tokenToString(node.kind);
                    if (tokenString) {
                        parts.push({ text: tokenString });
                        return;
                    }
                    if (isLiteralExpression(node)) {
                        parts.push({ text: getLiteralText2(node) });
                        return;
                    }
                    switch (node.kind) {
                        case 80 /* Identifier */:
                            Debug.assertNode(node, isIdentifier);
                            const identifierText = idText(node);
                            const name = node.symbol && node.symbol.declarations && node.symbol.declarations.length && getNameOfDeclaration(node.symbol.declarations[0]);
                            if (name) {
                                parts.push(getNodeDisplayPart(identifierText, name));
                            }
                            else {
                                parts.push({ text: identifierText });
                            }
                            break;
                        case 166 /* QualifiedName */:
                            Debug.assertNode(node, isQualifiedName);
                            visitForDisplayParts(node.left);
                            parts.push({ text: "." });
                            visitForDisplayParts(node.right);
                            break;
                        case 182 /* TypePredicate */:
                            Debug.assertNode(node, isTypePredicateNode);
                            if (node.assertsModifier) {
                                parts.push({ text: "asserts " });
                            }
                            visitForDisplayParts(node.parameterName);
                            if (node.type) {
                                parts.push({ text: " is " });
                                visitForDisplayParts(node.type);
                            }
                            break;
                        case 183 /* TypeReference */:
                            Debug.assertNode(node, isTypeReferenceNode);
                            visitForDisplayParts(node.typeName);
                            if (node.typeArguments) {
                                parts.push({ text: "<" });
                                visitDisplayPartList(node.typeArguments, ", ");
                                parts.push({ text: ">" });
                            }
                            break;
                        case 168 /* TypeParameter */:
                            Debug.assertNode(node, isTypeParameterDeclaration);
                            if (node.modifiers) {
                                visitDisplayPartList(node.modifiers, " ");
                            }
                            visitForDisplayParts(node.name);
                            if (node.constraint) {
                                parts.push({ text: " extends " });
                                visitForDisplayParts(node.constraint);
                            }
                            if (node.default) {
                                parts.push({ text: " = " });
                                visitForDisplayParts(node.default);
                            }
                            break;
                        case 169 /* Parameter */:
                            Debug.assertNode(node, isParameter);
                            if (node.modifiers) {
                                visitDisplayPartList(node.modifiers, " ");
                            }
                            if (node.dotDotDotToken) {
                                parts.push({ text: "..." });
                            }
                            visitForDisplayParts(node.name);
                            if (node.questionToken) {
                                parts.push({ text: "?" });
                            }
                            if (node.type) {
                                parts.push({ text: ": " });
                                visitForDisplayParts(node.type);
                            }
                            break;
                        case 185 /* ConstructorType */:
                            Debug.assertNode(node, isConstructorTypeNode);
                            parts.push({ text: "new " });
                            visitParametersAndTypeParameters(node);
                            parts.push({ text: " => " });
                            visitForDisplayParts(node.type);
                            break;
                        case 186 /* TypeQuery */:
                            Debug.assertNode(node, isTypeQueryNode);
                            parts.push({ text: "typeof " });
                            visitForDisplayParts(node.exprName);
                            if (node.typeArguments) {
                                parts.push({ text: "<" });
                                visitDisplayPartList(node.typeArguments, ", ");
                                parts.push({ text: ">" });
                            }
                            break;
                        case 187 /* TypeLiteral */:
                            Debug.assertNode(node, isTypeLiteralNode);
                            parts.push({ text: "{" });
                            if (node.members.length) {
                                parts.push({ text: " " });
                                visitDisplayPartList(node.members, "; ");
                                parts.push({ text: " " });
                            }
                            parts.push({ text: "}" });
                            break;
                        case 188 /* ArrayType */:
                            Debug.assertNode(node, isArrayTypeNode);
                            visitForDisplayParts(node.elementType);
                            parts.push({ text: "[]" });
                            break;
                        case 189 /* TupleType */:
                            Debug.assertNode(node, isTupleTypeNode);
                            parts.push({ text: "[" });
                            visitDisplayPartList(node.elements, ", ");
                            parts.push({ text: "]" });
                            break;
                        case 202 /* NamedTupleMember */:
                            Debug.assertNode(node, isNamedTupleMember);
                            if (node.dotDotDotToken) {
                                parts.push({ text: "..." });
                            }
                            visitForDisplayParts(node.name);
                            if (node.questionToken) {
                                parts.push({ text: "?" });
                            }
                            parts.push({ text: ": " });
                            visitForDisplayParts(node.type);
                            break;
                        case 190 /* OptionalType */:
                            Debug.assertNode(node, isOptionalTypeNode);
                            visitForDisplayParts(node.type);
                            parts.push({ text: "?" });
                            break;
                        case 191 /* RestType */:
                            Debug.assertNode(node, isRestTypeNode);
                            parts.push({ text: "..." });
                            visitForDisplayParts(node.type);
                            break;
                        case 192 /* UnionType */:
                            Debug.assertNode(node, isUnionTypeNode);
                            visitDisplayPartList(node.types, " | ");
                            break;
                        case 193 /* IntersectionType */:
                            Debug.assertNode(node, isIntersectionTypeNode);
                            visitDisplayPartList(node.types, " & ");
                            break;
                        case 194 /* ConditionalType */:
                            Debug.assertNode(node, isConditionalTypeNode);
                            visitForDisplayParts(node.checkType);
                            parts.push({ text: " extends " });
                            visitForDisplayParts(node.extendsType);
                            parts.push({ text: " ? " });
                            visitForDisplayParts(node.trueType);
                            parts.push({ text: " : " });
                            visitForDisplayParts(node.falseType);
                            break;
                        case 195 /* InferType */:
                            Debug.assertNode(node, isInferTypeNode);
                            parts.push({ text: "infer " });
                            visitForDisplayParts(node.typeParameter);
                            break;
                        case 196 /* ParenthesizedType */:
                            Debug.assertNode(node, isParenthesizedTypeNode);
                            parts.push({ text: "(" });
                            visitForDisplayParts(node.type);
                            parts.push({ text: ")" });
                            break;
                        case 198 /* TypeOperator */:
                            Debug.assertNode(node, isTypeOperatorNode);
                            parts.push({ text: `${tokenToString(node.operator)} ` });
                            visitForDisplayParts(node.type);
                            break;
                        case 199 /* IndexedAccessType */:
                            Debug.assertNode(node, isIndexedAccessTypeNode);
                            visitForDisplayParts(node.objectType);
                            parts.push({ text: "[" });
                            visitForDisplayParts(node.indexType);
                            parts.push({ text: "]" });
                            break;
                        case 200 /* MappedType */:
                            Debug.assertNode(node, isMappedTypeNode);
                            parts.push({ text: "{ " });
                            if (node.readonlyToken) {
                                if (node.readonlyToken.kind === 40 /* PlusToken */) {
                                    parts.push({ text: "+" });
                                }
                                else if (node.readonlyToken.kind === 41 /* MinusToken */) {
                                    parts.push({ text: "-" });
                                }
                                parts.push({ text: "readonly " });
                            }
                            parts.push({ text: "[" });
                            visitForDisplayParts(node.typeParameter);
                            if (node.nameType) {
                                parts.push({ text: " as " });
                                visitForDisplayParts(node.nameType);
                            }
                            parts.push({ text: "]" });
                            if (node.questionToken) {
                                if (node.questionToken.kind === 40 /* PlusToken */) {
                                    parts.push({ text: "+" });
                                }
                                else if (node.questionToken.kind === 41 /* MinusToken */) {
                                    parts.push({ text: "-" });
                                }
                                parts.push({ text: "?" });
                            }
                            parts.push({ text: ": " });
                            if (node.type) {
                                visitForDisplayParts(node.type);
                            }
                            parts.push({ text: "; }" });
                            break;
                        case 201 /* LiteralType */:
                            Debug.assertNode(node, isLiteralTypeNode);
                            visitForDisplayParts(node.literal);
                            break;
                        case 184 /* FunctionType */:
                            Debug.assertNode(node, isFunctionTypeNode);
                            visitParametersAndTypeParameters(node);
                            parts.push({ text: " => " });
                            visitForDisplayParts(node.type);
                            break;
                        case 205 /* ImportType */:
                            Debug.assertNode(node, isImportTypeNode);
                            if (node.isTypeOf) {
                                parts.push({ text: "typeof " });
                            }
                            parts.push({ text: "import(" });
                            visitForDisplayParts(node.argument);
                            if (node.assertions) {
                                parts.push({ text: ", { assert: " });
                                visitDisplayPartList(node.assertions.assertClause.elements, ", ");
                                parts.push({ text: " }" });
                            }
                            parts.push({ text: ")" });
                            if (node.qualifier) {
                                parts.push({ text: "." });
                                visitForDisplayParts(node.qualifier);
                            }
                            if (node.typeArguments) {
                                parts.push({ text: "<" });
                                visitDisplayPartList(node.typeArguments, ", ");
                                parts.push({ text: ">" });
                            }
                            break;
                        case 171 /* PropertySignature */:
                            Debug.assertNode(node, isPropertySignature);
                            if ((_a = node.modifiers) == null ? void 0 : _a.length) {
                                visitDisplayPartList(node.modifiers, " ");
                                parts.push({ text: " " });
                            }
                            visitForDisplayParts(node.name);
                            if (node.questionToken) {
                                parts.push({ text: "?" });
                            }
                            if (node.type) {
                                parts.push({ text: ": " });
                                visitForDisplayParts(node.type);
                            }
                            break;
                        case 181 /* IndexSignature */:
                            Debug.assertNode(node, isIndexSignatureDeclaration);
                            parts.push({ text: "[" });
                            visitDisplayPartList(node.parameters, ", ");
                            parts.push({ text: "]" });
                            if (node.type) {
                                parts.push({ text: ": " });
                                visitForDisplayParts(node.type);
                            }
                            break;
                        case 173 /* MethodSignature */:
                            Debug.assertNode(node, isMethodSignature);
                            if ((_b = node.modifiers) == null ? void 0 : _b.length) {
                                visitDisplayPartList(node.modifiers, " ");
                                parts.push({ text: " " });
                            }
                            visitForDisplayParts(node.name);
                            if (node.questionToken) {
                                parts.push({ text: "?" });
                            }
                            visitParametersAndTypeParameters(node);
                            if (node.type) {
                                parts.push({ text: ": " });
                                visitForDisplayParts(node.type);
                            }
                            break;
                        case 179 /* CallSignature */:
                            Debug.assertNode(node, isCallSignatureDeclaration);
                            visitParametersAndTypeParameters(node);
                            if (node.type) {
                                parts.push({ text: ": " });
                                visitForDisplayParts(node.type);
                            }
                            break;
                        case 207 /* ArrayBindingPattern */:
                            Debug.assertNode(node, isArrayBindingPattern);
                            parts.push({ text: "[" });
                            visitDisplayPartList(node.elements, ", ");
                            parts.push({ text: "]" });
                            break;
                        case 206 /* ObjectBindingPattern */:
                            Debug.assertNode(node, isObjectBindingPattern);
                            parts.push({ text: "{" });
                            if (node.elements.length) {
                                parts.push({ text: " " });
                                visitDisplayPartList(node.elements, ", ");
                                parts.push({ text: " " });
                            }
                            parts.push({ text: "}" });
                            break;
                        case 208 /* BindingElement */:
                            Debug.assertNode(node, isBindingElement);
                            visitForDisplayParts(node.name);
                            break;
                        case 224 /* PrefixUnaryExpression */:
                            Debug.assertNode(node, isPrefixUnaryExpression);
                            parts.push({ text: tokenToString(node.operator) });
                            visitForDisplayParts(node.operand);
                            break;
                        case 203 /* TemplateLiteralType */:
                            Debug.assertNode(node, isTemplateLiteralTypeNode);
                            visitForDisplayParts(node.head);
                            node.templateSpans.forEach(visitForDisplayParts);
                            break;
                        case 16 /* TemplateHead */:
                            Debug.assertNode(node, isTemplateHead);
                            parts.push({ text: getLiteralText2(node) });
                            break;
                        case 204 /* TemplateLiteralTypeSpan */:
                            Debug.assertNode(node, isTemplateLiteralTypeSpan);
                            visitForDisplayParts(node.type);
                            visitForDisplayParts(node.literal);
                            break;
                        case 17 /* TemplateMiddle */:
                            Debug.assertNode(node, isTemplateMiddle);
                            parts.push({ text: getLiteralText2(node) });
                            break;
                        case 18 /* TemplateTail */:
                            Debug.assertNode(node, isTemplateTail);
                            parts.push({ text: getLiteralText2(node) });
                            break;
                        case 197 /* ThisType */:
                            Debug.assertNode(node, isThisTypeNode);
                            parts.push({ text: "this" });
                            break;
                        default:
                            Debug.failBadSyntaxKind(node);
                    }
                }
                function visitParametersAndTypeParameters(signatureDeclaration) {
                    if (signatureDeclaration.typeParameters) {
                        parts.push({ text: "<" });
                        visitDisplayPartList(signatureDeclaration.typeParameters, ", ");
                        parts.push({ text: ">" });
                    }
                    parts.push({ text: "(" });
                    visitDisplayPartList(signatureDeclaration.parameters, ", ");
                    parts.push({ text: ")" });
                }
                function visitDisplayPartList(nodes, separator) {
                    nodes.forEach((node, index) => {
                        if (index > 0) {
                            parts.push({ text: separator });
                        }
                        visitForDisplayParts(node);
                    });
                }
                function getLiteralText2(node) {
                    switch (node.kind) {
                        case 11 /* StringLiteral */:
                            return quotePreference === 0 /* Single */ ? `'${escapeString(node.text, 39 /* singleQuote */)}'` : `"${escapeString(node.text, 34 /* doubleQuote */)}"`;
                        case 16 /* TemplateHead */:
                        case 17 /* TemplateMiddle */:
                        case 18 /* TemplateTail */: {
                            const rawText = node.rawText ?? escapeTemplateSubstitution(escapeString(node.text, 96 /* backtick */));
                            switch (node.kind) {
                                case 16 /* TemplateHead */:
                                    return "`" + rawText + "${";
                                case 17 /* TemplateMiddle */:
                                    return "}" + rawText + "${";
                                case 18 /* TemplateTail */:
                                    return "}" + rawText + "`";
                            }
                        }
                    }
                    return node.text;
                }
            }
            function isUndefined(name) {
                return name === "undefined";
            }
            function isHintableDeclaration(node) {
                if ((isParameterDeclaration(node) || isVariableDeclaration(node) && isVarConst(node)) && node.initializer) {
                    const initializer = skipParentheses(node.initializer);
                    return !(isHintableLiteral(initializer) || isNewExpression(initializer) || isObjectLiteralExpression(initializer) || isAssertionExpression(initializer));
                }
                return true;
            }
            function getNodeDisplayPart(text, node) {
                const sourceFile = node.getSourceFile();
                return {
                    text,
                    span: createTextSpanFromNode(node, sourceFile),
                    file: sourceFile.fileName
                };
            }
        }
        var leadingParameterNameCommentRegexFactory;
        var init_inlayHints = __esm({
            "src/services/inlayHints.ts"() {
                "use strict";
                init_ts4();
                leadingParameterNameCommentRegexFactory = (name) => {
                    return new RegExp(`^\\s?/\\*\\*?\\s?${name}\\s?\\*\\/\\s?$`);
                };
            }
        });
        // src/services/_namespaces/ts.InlayHints.ts
        var ts_InlayHints_exports = {};
        __export(ts_InlayHints_exports, {
            provideInlayHints: () => provideInlayHints
        });
        var init_ts_InlayHints = __esm({
            "src/services/_namespaces/ts.InlayHints.ts"() {
                "use strict";
                init_inlayHints();
            }
        });
        // src/services/jsDoc.ts
        function getJsDocCommentsFromDeclarations(declarations, checker) {
            const parts = [];
            forEachUnique(declarations, (declaration) => {
                for (const jsdoc of getCommentHavingNodes(declaration)) {
                    const inheritDoc = isJSDoc(jsdoc) && jsdoc.tags && find(jsdoc.tags, (t) => t.kind === 334 /* JSDocTag */ && (t.tagName.escapedText === "inheritDoc" || t.tagName.escapedText === "inheritdoc"));
                    if (jsdoc.comment === void 0 && !inheritDoc || isJSDoc(jsdoc) && declaration.kind !== 353 /* JSDocTypedefTag */ && declaration.kind !== 345 /* JSDocCallbackTag */ && jsdoc.tags && jsdoc.tags.some((t) => t.kind === 353 /* JSDocTypedefTag */ || t.kind === 345 /* JSDocCallbackTag */) && !jsdoc.tags.some((t) => t.kind === 348 /* JSDocParameterTag */ || t.kind === 349 /* JSDocReturnTag */)) {
                        continue;
                    }
                    let newparts = jsdoc.comment ? getDisplayPartsFromComment(jsdoc.comment, checker) : [];
                    if (inheritDoc && inheritDoc.comment) {
                        newparts = newparts.concat(getDisplayPartsFromComment(inheritDoc.comment, checker));
                    }
                    if (!contains(parts, newparts, isIdenticalListOfDisplayParts)) {
                        parts.push(newparts);
                    }
                }
            });
            return flatten(intersperse(parts, [lineBreakPart()]));
        }
        function isIdenticalListOfDisplayParts(parts1, parts2) {
            return arraysEqual(parts1, parts2, (p1, p2) => p1.kind === p2.kind && p1.text === p2.text);
        }
        function getCommentHavingNodes(declaration) {
            switch (declaration.kind) {
                case 348 /* JSDocParameterTag */:
                case 355 /* JSDocPropertyTag */:
                    return [declaration];
                case 345 /* JSDocCallbackTag */:
                case 353 /* JSDocTypedefTag */:
                    return [declaration, declaration.parent];
                case 330 /* JSDocSignature */:
                    if (isJSDocOverloadTag(declaration.parent)) {
                        return [declaration.parent.parent];
                    }
                default:
                    return getJSDocCommentsAndTags(declaration);
            }
        }
        function getJsDocTagsFromDeclarations(declarations, checker) {
            const infos = [];
            forEachUnique(declarations, (declaration) => {
                const tags = getJSDocTags(declaration);
                if (tags.some((t) => t.kind === 353 /* JSDocTypedefTag */ || t.kind === 345 /* JSDocCallbackTag */) && !tags.some((t) => t.kind === 348 /* JSDocParameterTag */ || t.kind === 349 /* JSDocReturnTag */)) {
                    return;
                }
                for (const tag of tags) {
                    infos.push({ name: tag.tagName.text, text: getCommentDisplayParts(tag, checker) });
                    infos.push(...getJSDocPropertyTagsInfo(tryGetJSDocPropertyTags(tag), checker));
                }
            });
            return infos;
        }
        function getJSDocPropertyTagsInfo(nodes, checker) {
            return flatMap(nodes, (propTag) => concatenate([{ name: propTag.tagName.text, text: getCommentDisplayParts(propTag, checker) }], getJSDocPropertyTagsInfo(tryGetJSDocPropertyTags(propTag), checker)));
        }
        function tryGetJSDocPropertyTags(node) {
            return isJSDocPropertyLikeTag(node) && node.isNameFirst && node.typeExpression && isJSDocTypeLiteral(node.typeExpression.type) ? node.typeExpression.type.jsDocPropertyTags : void 0;
        }
        function getDisplayPartsFromComment(comment, checker) {
            if (typeof comment === "string") {
                return [textPart(comment)];
            }
            return flatMap(comment, (node) => node.kind === 328 /* JSDocText */ ? [textPart(node.text)] : buildLinkParts(node, checker));
        }
        function getCommentDisplayParts(tag, checker) {
            const { comment, kind } = tag;
            const namePart = getTagNameDisplayPart(kind);
            switch (kind) {
                case 356 /* JSDocThrowsTag */:
                    const typeExpression = tag.typeExpression;
                    return typeExpression ? withNode(typeExpression) : comment === void 0 ? void 0 : getDisplayPartsFromComment(comment, checker);
                case 336 /* JSDocImplementsTag */:
                    return withNode(tag.class);
                case 335 /* JSDocAugmentsTag */:
                    return withNode(tag.class);
                case 352 /* JSDocTemplateTag */:
                    const templateTag = tag;
                    const displayParts = [];
                    if (templateTag.constraint) {
                        displayParts.push(textPart(templateTag.constraint.getText()));
                    }
                    if (length(templateTag.typeParameters)) {
                        if (length(displayParts)) {
                            displayParts.push(spacePart());
                        }
                        const lastTypeParameter = templateTag.typeParameters[templateTag.typeParameters.length - 1];
                        forEach(templateTag.typeParameters, (tp) => {
                            displayParts.push(namePart(tp.getText()));
                            if (lastTypeParameter !== tp) {
                                displayParts.push(...[punctuationPart(28 /* CommaToken */), spacePart()]);
                            }
                        });
                    }
                    if (comment) {
                        displayParts.push(...[spacePart(), ...getDisplayPartsFromComment(comment, checker)]);
                    }
                    return displayParts;
                case 351 /* JSDocTypeTag */:
                case 357 /* JSDocSatisfiesTag */:
                    return withNode(tag.typeExpression);
                case 353 /* JSDocTypedefTag */:
                case 345 /* JSDocCallbackTag */:
                case 355 /* JSDocPropertyTag */:
                case 348 /* JSDocParameterTag */:
                case 354 /* JSDocSeeTag */:
                    const { name } = tag;
                    return name ? withNode(name) : comment === void 0 ? void 0 : getDisplayPartsFromComment(comment, checker);
                default:
                    return comment === void 0 ? void 0 : getDisplayPartsFromComment(comment, checker);
            }
            function withNode(node) {
                return addComment(node.getText());
            }
            function addComment(s) {
                if (comment) {
                    if (s.match(/^https?$/)) {
                        return [textPart(s), ...getDisplayPartsFromComment(comment, checker)];
                    }
                    else {
                        return [namePart(s), spacePart(), ...getDisplayPartsFromComment(comment, checker)];
                    }
                }
                else {
                    return [textPart(s)];
                }
            }
        }
        function getTagNameDisplayPart(kind) {
            switch (kind) {
                case 348 /* JSDocParameterTag */:
                    return parameterNamePart;
                case 355 /* JSDocPropertyTag */:
                    return propertyNamePart;
                case 352 /* JSDocTemplateTag */:
                    return typeParameterNamePart;
                case 353 /* JSDocTypedefTag */:
                case 345 /* JSDocCallbackTag */:
                    return typeAliasNamePart;
                default:
                    return textPart;
            }
        }
        function getJSDocTagNameCompletions() {
            return jsDocTagNameCompletionEntries || (jsDocTagNameCompletionEntries = map(jsDocTagNames, (tagName) => {
                return {
                    name: tagName,
                    kind: "keyword" /* keyword */,
                    kindModifiers: "",
                    sortText: ts_Completions_exports.SortText.LocationPriority
                };
            }));
        }
        function getJSDocTagCompletions() {
            return jsDocTagCompletionEntries || (jsDocTagCompletionEntries = map(jsDocTagNames, (tagName) => {
                return {
                    name: `@${tagName}`,
                    kind: "keyword" /* keyword */,
                    kindModifiers: "",
                    sortText: ts_Completions_exports.SortText.LocationPriority
                };
            }));
        }
        function getJSDocTagCompletionDetails(name) {
            return {
                name,
                kind: "" /* unknown */,
                // TODO: should have its own kind?
                kindModifiers: "",
                displayParts: [textPart(name)],
                documentation: emptyArray,
                tags: void 0,
                codeActions: void 0
            };
        }
        function getJSDocParameterNameCompletions(tag) {
            if (!isIdentifier(tag.name)) {
                return emptyArray;
            }
            const nameThusFar = tag.name.text;
            const jsdoc = tag.parent;
            const fn = jsdoc.parent;
            if (!isFunctionLike(fn))
                return [];
            return mapDefined(fn.parameters, (param) => {
                if (!isIdentifier(param.name))
                    return void 0;
                const name = param.name.text;
                if (jsdoc.tags.some((t) => t !== tag && isJSDocParameterTag(t) && isIdentifier(t.name) && t.name.escapedText === name) || nameThusFar !== void 0 && !startsWith(name, nameThusFar)) {
                    return void 0;
                }
                return { name, kind: "parameter" /* parameterElement */, kindModifiers: "", sortText: ts_Completions_exports.SortText.LocationPriority };
            });
        }
        function getJSDocParameterNameCompletionDetails(name) {
            return {
                name,
                kind: "parameter" /* parameterElement */,
                kindModifiers: "",
                displayParts: [textPart(name)],
                documentation: emptyArray,
                tags: void 0,
                codeActions: void 0
            };
        }
        function getDocCommentTemplateAtPosition(newLine, sourceFile, position, options) {
            const tokenAtPos = getTokenAtPosition(sourceFile, position);
            const existingDocComment = findAncestor(tokenAtPos, isJSDoc);
            if (existingDocComment && (existingDocComment.comment !== void 0 || length(existingDocComment.tags))) {
                return void 0;
            }
            const tokenStart = tokenAtPos.getStart(sourceFile);
            if (!existingDocComment && tokenStart < position) {
                return void 0;
            }
            const commentOwnerInfo = getCommentOwnerInfo(tokenAtPos, options);
            if (!commentOwnerInfo) {
                return void 0;
            }
            const { commentOwner, parameters, hasReturn: hasReturn2 } = commentOwnerInfo;
            const commentOwnerJsDoc = hasJSDocNodes(commentOwner) && commentOwner.jsDoc ? commentOwner.jsDoc : void 0;
            const lastJsDoc = lastOrUndefined(commentOwnerJsDoc);
            if (commentOwner.getStart(sourceFile) < position || lastJsDoc && existingDocComment && lastJsDoc !== existingDocComment) {
                return void 0;
            }
            const indentationStr = getIndentationStringAtPosition(sourceFile, position);
            const isJavaScriptFile = hasJSFileExtension(sourceFile.fileName);
            const tags = (parameters ? parameterDocComments(parameters || [], isJavaScriptFile, indentationStr, newLine) : "") + (hasReturn2 ? returnsDocComment(indentationStr, newLine) : "");
            const openComment = "/**";
            const closeComment = " */";
            const hasTag = length(getJSDocTags(commentOwner)) > 0;
            if (tags && !hasTag) {
                const preamble = openComment + newLine + indentationStr + " * ";
                const endLine = tokenStart === position ? newLine + indentationStr : "";
                const result = preamble + newLine + tags + indentationStr + closeComment + endLine;
                return { newText: result, caretOffset: preamble.length };
            }
            return { newText: openComment + closeComment, caretOffset: 3 };
        }
        function getIndentationStringAtPosition(sourceFile, position) {
            const { text } = sourceFile;
            const lineStart = getLineStartPositionForPosition(position, sourceFile);
            let pos = lineStart;
            for (; pos <= position && isWhiteSpaceSingleLine(text.charCodeAt(pos)); pos++)
                ;
            return text.slice(lineStart, pos);
        }
        function parameterDocComments(parameters, isJavaScriptFile, indentationStr, newLine) {
            return parameters.map(({ name, dotDotDotToken }, i) => {
                const paramName = name.kind === 80 /* Identifier */ ? name.text : "param" + i;
                const type = isJavaScriptFile ? dotDotDotToken ? "{...any} " : "{any} " : "";
                return `${indentationStr} * @param ${type}${paramName}${newLine}`;
            }).join("");
        }
        function returnsDocComment(indentationStr, newLine) {
            return `${indentationStr} * @returns${newLine}`;
        }
        function getCommentOwnerInfo(tokenAtPos, options) {
            return forEachAncestor(tokenAtPos, (n) => getCommentOwnerInfoWorker(n, options));
        }
        function getCommentOwnerInfoWorker(commentOwner, options) {
            switch (commentOwner.kind) {
                case 262 /* FunctionDeclaration */:
                case 218 /* FunctionExpression */:
                case 174 /* MethodDeclaration */:
                case 176 /* Constructor */:
                case 173 /* MethodSignature */:
                case 219 /* ArrowFunction */:
                    const host = commentOwner;
                    return { commentOwner, parameters: host.parameters, hasReturn: hasReturn(host, options) };
                case 303 /* PropertyAssignment */:
                    return getCommentOwnerInfoWorker(commentOwner.initializer, options);
                case 263 /* ClassDeclaration */:
                case 264 /* InterfaceDeclaration */:
                case 266 /* EnumDeclaration */:
                case 306 /* EnumMember */:
                case 265 /* TypeAliasDeclaration */:
                    return { commentOwner };
                case 171 /* PropertySignature */: {
                    const host2 = commentOwner;
                    return host2.type && isFunctionTypeNode(host2.type) ? { commentOwner, parameters: host2.type.parameters, hasReturn: hasReturn(host2.type, options) } : { commentOwner };
                }
                case 243 /* VariableStatement */: {
                    const varStatement = commentOwner;
                    const varDeclarations = varStatement.declarationList.declarations;
                    const host2 = varDeclarations.length === 1 && varDeclarations[0].initializer ? getRightHandSideOfAssignment(varDeclarations[0].initializer) : void 0;
                    return host2 ? { commentOwner, parameters: host2.parameters, hasReturn: hasReturn(host2, options) } : { commentOwner };
                }
                case 312 /* SourceFile */:
                    return "quit";
                case 267 /* ModuleDeclaration */:
                    return commentOwner.parent.kind === 267 /* ModuleDeclaration */ ? void 0 : { commentOwner };
                case 244 /* ExpressionStatement */:
                    return getCommentOwnerInfoWorker(commentOwner.expression, options);
                case 226 /* BinaryExpression */: {
                    const be = commentOwner;
                    if (getAssignmentDeclarationKind(be) === 0 /* None */) {
                        return "quit";
                    }
                    return isFunctionLike(be.right) ? { commentOwner, parameters: be.right.parameters, hasReturn: hasReturn(be.right, options) } : { commentOwner };
                }
                case 172 /* PropertyDeclaration */:
                    const init = commentOwner.initializer;
                    if (init && (isFunctionExpression(init) || isArrowFunction(init))) {
                        return { commentOwner, parameters: init.parameters, hasReturn: hasReturn(init, options) };
                    }
            }
        }
        function hasReturn(node, options) {
            return !!(options == null ? void 0 : options.generateReturnInDocTemplate) && (isFunctionTypeNode(node) || isArrowFunction(node) && isExpression(node.body) || isFunctionLikeDeclaration(node) && node.body && isBlock(node.body) && !!forEachReturnStatement(node.body, (n) => n));
        }
        function getRightHandSideOfAssignment(rightHandSide) {
            while (rightHandSide.kind === 217 /* ParenthesizedExpression */) {
                rightHandSide = rightHandSide.expression;
            }
            switch (rightHandSide.kind) {
                case 218 /* FunctionExpression */:
                case 219 /* ArrowFunction */:
                    return rightHandSide;
                case 231 /* ClassExpression */:
                    return find(rightHandSide.members, isConstructorDeclaration);
            }
        }
        var jsDocTagNames, jsDocTagNameCompletionEntries, jsDocTagCompletionEntries, getJSDocTagNameCompletionDetails;
        var init_jsDoc = __esm({
            "src/services/jsDoc.ts"() {
                "use strict";
                init_ts4();
                jsDocTagNames = [
                    "abstract",
                    "access",
                    "alias",
                    "argument",
                    "async",
                    "augments",
                    "author",
                    "borrows",
                    "callback",
                    "class",
                    "classdesc",
                    "constant",
                    "constructor",
                    "constructs",
                    "copyright",
                    "default",
                    "deprecated",
                    "description",
                    "emits",
                    "enum",
                    "event",
                    "example",
                    "exports",
                    "extends",
                    "external",
                    "field",
                    "file",
                    "fileoverview",
                    "fires",
                    "function",
                    "generator",
                    "global",
                    "hideconstructor",
                    "host",
                    "ignore",
                    "implements",
                    "inheritdoc",
                    "inner",
                    "instance",
                    "interface",
                    "kind",
                    "lends",
                    "license",
                    "link",
                    "linkcode",
                    "linkplain",
                    "listens",
                    "member",
                    "memberof",
                    "method",
                    "mixes",
                    "module",
                    "name",
                    "namespace",
                    "overload",
                    "override",
                    "package",
                    "param",
                    "private",
                    "prop",
                    "property",
                    "protected",
                    "public",
                    "readonly",
                    "requires",
                    "returns",
                    "satisfies",
                    "see",
                    "since",
                    "static",
                    "summary",
                    "template",
                    "this",
                    "throws",
                    "todo",
                    "tutorial",
                    "type",
                    "typedef",
                    "var",
                    "variation",
                    "version",
                    "virtual",
                    "yields"
                ];
                getJSDocTagNameCompletionDetails = getJSDocTagCompletionDetails;
            }
        });
        // src/services/_namespaces/ts.JsDoc.ts
        var ts_JsDoc_exports = {};
        __export(ts_JsDoc_exports, {
            getDocCommentTemplateAtPosition: () => getDocCommentTemplateAtPosition,
            getJSDocParameterNameCompletionDetails: () => getJSDocParameterNameCompletionDetails,
            getJSDocParameterNameCompletions: () => getJSDocParameterNameCompletions,
            getJSDocTagCompletionDetails: () => getJSDocTagCompletionDetails,
            getJSDocTagCompletions: () => getJSDocTagCompletions,
            getJSDocTagNameCompletionDetails: () => getJSDocTagNameCompletionDetails,
            getJSDocTagNameCompletions: () => getJSDocTagNameCompletions,
            getJsDocCommentsFromDeclarations: () => getJsDocCommentsFromDeclarations,
            getJsDocTagsFromDeclarations: () => getJsDocTagsFromDeclarations
        });
        var init_ts_JsDoc = __esm({
            "src/services/_namespaces/ts.JsDoc.ts"() {
                "use strict";
                init_jsDoc();
            }
        });
        // src/services/organizeImports.ts
        function organizeImports(sourceFile, formatContext, host, program, preferences, mode) {
            const changeTracker = ts_textChanges_exports.ChangeTracker.fromContext({ host, formatContext, preferences });
            const shouldSort = mode === "SortAndCombine" /* SortAndCombine */ || mode === "All" /* All */;
            const shouldCombine = shouldSort;
            const shouldRemove = mode === "RemoveUnused" /* RemoveUnused */ || mode === "All" /* All */;
            const topLevelImportGroupDecls = groupByNewlineContiguous(sourceFile, sourceFile.statements.filter(isImportDeclaration));
            const comparer = getOrganizeImportsComparerWithDetection(preferences, shouldSort ? () => detectSortingWorker(topLevelImportGroupDecls, preferences) === 2 /* CaseInsensitive */ : void 0);
            const processImportsOfSameModuleSpecifier = (importGroup) => {
                if (shouldRemove)
                    importGroup = removeUnusedImports(importGroup, sourceFile, program);
                if (shouldCombine)
                    importGroup = coalesceImportsWorker(importGroup, comparer, sourceFile, preferences);
                if (shouldSort)
                    importGroup = stableSort(importGroup, (s1, s2) => compareImportsOrRequireStatements(s1, s2, comparer));
                return importGroup;
            };
            topLevelImportGroupDecls.forEach((importGroupDecl) => organizeImportsWorker(importGroupDecl, processImportsOfSameModuleSpecifier));
            if (mode !== "RemoveUnused" /* RemoveUnused */) {
                getTopLevelExportGroups(sourceFile).forEach((exportGroupDecl) => organizeImportsWorker(exportGroupDecl, (group2) => coalesceExportsWorker(group2, comparer, preferences)));
            }
            for (const ambientModule of sourceFile.statements.filter(isAmbientModule)) {
                if (!ambientModule.body)
                    continue;
                const ambientModuleImportGroupDecls = groupByNewlineContiguous(sourceFile, ambientModule.body.statements.filter(isImportDeclaration));
                ambientModuleImportGroupDecls.forEach((importGroupDecl) => organizeImportsWorker(importGroupDecl, processImportsOfSameModuleSpecifier));
                if (mode !== "RemoveUnused" /* RemoveUnused */) {
                    const ambientModuleExportDecls = ambientModule.body.statements.filter(isExportDeclaration);
                    organizeImportsWorker(ambientModuleExportDecls, (group2) => coalesceExportsWorker(group2, comparer, preferences));
                }
            }
            return changeTracker.getChanges();
            function organizeImportsWorker(oldImportDecls, coalesce) {
                if (length(oldImportDecls) === 0) {
                    return;
                }
                setEmitFlags(oldImportDecls[0], 1024 /* NoLeadingComments */);
                const oldImportGroups = shouldCombine ? group(oldImportDecls, (importDecl) => getExternalModuleName2(importDecl.moduleSpecifier)) : [oldImportDecls];
                const sortedImportGroups = shouldSort ? stableSort(oldImportGroups, (group1, group2) => compareModuleSpecifiersWorker(group1[0].moduleSpecifier, group2[0].moduleSpecifier, comparer)) : oldImportGroups;
                const newImportDecls = flatMap(sortedImportGroups, (importGroup) => getExternalModuleName2(importGroup[0].moduleSpecifier) || importGroup[0].moduleSpecifier === void 0 ? coalesce(importGroup) : importGroup);
                if (newImportDecls.length === 0) {
                    changeTracker.deleteNodes(sourceFile, oldImportDecls, {
                        leadingTriviaOption: ts_textChanges_exports.LeadingTriviaOption.Exclude,
                        trailingTriviaOption: ts_textChanges_exports.TrailingTriviaOption.Include
                    }, 
                    /*hasTrailingComment*/
                    true);
                }
                else {
                    const replaceOptions = {
                        leadingTriviaOption: ts_textChanges_exports.LeadingTriviaOption.Exclude,
                        // Leave header comment in place
                        trailingTriviaOption: ts_textChanges_exports.TrailingTriviaOption.Include,
                        suffix: getNewLineOrDefaultFromHost(host, formatContext.options)
                    };
                    changeTracker.replaceNodeWithNodes(sourceFile, oldImportDecls[0], newImportDecls, replaceOptions);
                    const hasTrailingComment = changeTracker.nodeHasTrailingComment(sourceFile, oldImportDecls[0], replaceOptions);
                    changeTracker.deleteNodes(sourceFile, oldImportDecls.slice(1), {
                        trailingTriviaOption: ts_textChanges_exports.TrailingTriviaOption.Include
                    }, hasTrailingComment);
                }
            }
        }
        function groupByNewlineContiguous(sourceFile, decls) {
            const scanner2 = createScanner(sourceFile.languageVersion, 
            /*skipTrivia*/
            false, sourceFile.languageVariant);
            const group2 = [];
            let groupIndex = 0;
            for (const decl of decls) {
                if (group2[groupIndex] && isNewGroup(sourceFile, decl, scanner2)) {
                    groupIndex++;
                }
                if (!group2[groupIndex]) {
                    group2[groupIndex] = [];
                }
                group2[groupIndex].push(decl);
            }
            return group2;
        }
        function isNewGroup(sourceFile, decl, scanner2) {
            const startPos = decl.getFullStart();
            const endPos = decl.getStart();
            scanner2.setText(sourceFile.text, startPos, endPos - startPos);
            let numberOfNewLines = 0;
            while (scanner2.getTokenStart() < endPos) {
                const tokenKind = scanner2.scan();
                if (tokenKind === 4 /* NewLineTrivia */) {
                    numberOfNewLines++;
                    if (numberOfNewLines >= 2) {
                        return true;
                    }
                }
            }
            return false;
        }
        function removeUnusedImports(oldImports, sourceFile, program) {
            const typeChecker = program.getTypeChecker();
            const compilerOptions = program.getCompilerOptions();
            const jsxNamespace = typeChecker.getJsxNamespace(sourceFile);
            const jsxFragmentFactory = typeChecker.getJsxFragmentFactory(sourceFile);
            const jsxElementsPresent = !!(sourceFile.transformFlags & 2 /* ContainsJsx */);
            const usedImports = [];
            for (const importDecl of oldImports) {
                const { importClause, moduleSpecifier } = importDecl;
                if (!importClause) {
                    usedImports.push(importDecl);
                    continue;
                }
                let { name, namedBindings } = importClause;
                if (name && !isDeclarationUsed(name)) {
                    name = void 0;
                }
                if (namedBindings) {
                    if (isNamespaceImport(namedBindings)) {
                        if (!isDeclarationUsed(namedBindings.name)) {
                            namedBindings = void 0;
                        }
                    }
                    else {
                        const newElements = namedBindings.elements.filter((e) => isDeclarationUsed(e.name));
                        if (newElements.length < namedBindings.elements.length) {
                            namedBindings = newElements.length ? factory.updateNamedImports(namedBindings, newElements) : void 0;
                        }
                    }
                }
                if (name || namedBindings) {
                    usedImports.push(updateImportDeclarationAndClause(importDecl, name, namedBindings));
                }
                else if (hasModuleDeclarationMatchingSpecifier(sourceFile, moduleSpecifier)) {
                    if (sourceFile.isDeclarationFile) {
                        usedImports.push(factory.createImportDeclaration(importDecl.modifiers, 
                        /*importClause*/
                        void 0, moduleSpecifier, 
                        /*attributes*/
                        void 0));
                    }
                    else {
                        usedImports.push(importDecl);
                    }
                }
            }
            return usedImports;
            function isDeclarationUsed(identifier) {
                return jsxElementsPresent && (identifier.text === jsxNamespace || jsxFragmentFactory && identifier.text === jsxFragmentFactory) && jsxModeNeedsExplicitImport(compilerOptions.jsx) || ts_FindAllReferences_exports.Core.isSymbolReferencedInFile(identifier, typeChecker, sourceFile);
            }
        }
        function hasModuleDeclarationMatchingSpecifier(sourceFile, moduleSpecifier) {
            const moduleSpecifierText = isStringLiteral(moduleSpecifier) && moduleSpecifier.text;
            return isString(moduleSpecifierText) && some(sourceFile.moduleAugmentations, (moduleName) => isStringLiteral(moduleName) && moduleName.text === moduleSpecifierText);
        }
        function getExternalModuleName2(specifier) {
            return specifier !== void 0 && isStringLiteralLike(specifier) ? specifier.text : void 0;
        }
        function coalesceImports(importGroup, ignoreCase, sourceFile, preferences) {
            const comparer = getOrganizeImportsOrdinalStringComparer(ignoreCase);
            return coalesceImportsWorker(importGroup, comparer, sourceFile, preferences);
        }
        function coalesceImportsWorker(importGroup, comparer, sourceFile, preferences) {
            if (importGroup.length === 0) {
                return importGroup;
            }
            const importGroupsByAttributes = groupBy(importGroup, (decl) => {
                if (decl.attributes) {
                    let attrs = decl.attributes.token + " ";
                    for (const x of sort(decl.attributes.elements, (x2, y) => compareStringsCaseSensitive(x2.name.text, y.name.text))) {
                        attrs += x.name.text + ":";
                        attrs += isStringLiteralLike(x.value) ? `"${x.value.text}"` : x.value.getText() + " ";
                    }
                    return attrs;
                }
                return "";
            });
            const coalescedImports = [];
            for (const attribute in importGroupsByAttributes) {
                const importGroupSameAttrs = importGroupsByAttributes[attribute];
                const { importWithoutClause, typeOnlyImports, regularImports } = getCategorizedImports(importGroupSameAttrs);
                if (importWithoutClause) {
                    coalescedImports.push(importWithoutClause);
                }
                for (const group2 of [regularImports, typeOnlyImports]) {
                    const isTypeOnly = group2 === typeOnlyImports;
                    const { defaultImports, namespaceImports, namedImports } = group2;
                    if (!isTypeOnly && defaultImports.length === 1 && namespaceImports.length === 1 && namedImports.length === 0) {
                        const defaultImport = defaultImports[0];
                        coalescedImports.push(updateImportDeclarationAndClause(defaultImport, defaultImport.importClause.name, namespaceImports[0].importClause.namedBindings));
                        continue;
                    }
                    const sortedNamespaceImports = stableSort(namespaceImports, (i1, i2) => comparer(i1.importClause.namedBindings.name.text, i2.importClause.namedBindings.name.text));
                    for (const namespaceImport of sortedNamespaceImports) {
                        coalescedImports.push(updateImportDeclarationAndClause(namespaceImport, 
                        /*name*/
                        void 0, namespaceImport.importClause.namedBindings));
                    }
                    const firstDefaultImport = firstOrUndefined(defaultImports);
                    const firstNamedImport = firstOrUndefined(namedImports);
                    const importDecl = firstDefaultImport ?? firstNamedImport;
                    if (!importDecl) {
                        continue;
                    }
                    let newDefaultImport;
                    const newImportSpecifiers = [];
                    if (defaultImports.length === 1) {
                        newDefaultImport = defaultImports[0].importClause.name;
                    }
                    else {
                        for (const defaultImport of defaultImports) {
                            newImportSpecifiers.push(factory.createImportSpecifier(
                            /*isTypeOnly*/
                            false, factory.createIdentifier("default"), defaultImport.importClause.name));
                        }
                    }
                    newImportSpecifiers.push(...getNewImportSpecifiers(namedImports));
                    const sortedImportSpecifiers = factory.createNodeArray(sortSpecifiers(newImportSpecifiers, comparer, preferences), firstNamedImport == null ? void 0 : firstNamedImport.importClause.namedBindings.elements.hasTrailingComma);
                    const newNamedImports = sortedImportSpecifiers.length === 0 ? newDefaultImport ? void 0 : factory.createNamedImports(emptyArray) : firstNamedImport ? factory.updateNamedImports(firstNamedImport.importClause.namedBindings, sortedImportSpecifiers) : factory.createNamedImports(sortedImportSpecifiers);
                    if (sourceFile && newNamedImports && (firstNamedImport == null ? void 0 : firstNamedImport.importClause.namedBindings) && !rangeIsOnSingleLine(firstNamedImport.importClause.namedBindings, sourceFile)) {
                        setEmitFlags(newNamedImports, 2 /* MultiLine */);
                    }
                    if (isTypeOnly && newDefaultImport && newNamedImports) {
                        coalescedImports.push(updateImportDeclarationAndClause(importDecl, newDefaultImport, 
                        /*namedBindings*/
                        void 0));
                        coalescedImports.push(updateImportDeclarationAndClause(firstNamedImport ?? importDecl, 
                        /*name*/
                        void 0, newNamedImports));
                    }
                    else {
                        coalescedImports.push(updateImportDeclarationAndClause(importDecl, newDefaultImport, newNamedImports));
                    }
                }
            }
            return coalescedImports;
        }
        function getCategorizedImports(importGroup) {
            let importWithoutClause;
            const typeOnlyImports = { defaultImports: [], namespaceImports: [], namedImports: [] };
            const regularImports = { defaultImports: [], namespaceImports: [], namedImports: [] };
            for (const importDeclaration of importGroup) {
                if (importDeclaration.importClause === void 0) {
                    importWithoutClause = importWithoutClause || importDeclaration;
                    continue;
                }
                const group2 = importDeclaration.importClause.isTypeOnly ? typeOnlyImports : regularImports;
                const { name, namedBindings } = importDeclaration.importClause;
                if (name) {
                    group2.defaultImports.push(importDeclaration);
                }
                if (namedBindings) {
                    if (isNamespaceImport(namedBindings)) {
                        group2.namespaceImports.push(importDeclaration);
                    }
                    else {
                        group2.namedImports.push(importDeclaration);
                    }
                }
            }
            return {
                importWithoutClause,
                typeOnlyImports,
                regularImports
            };
        }
        function coalesceExports(exportGroup, ignoreCase, preferences) {
            const comparer = getOrganizeImportsOrdinalStringComparer(ignoreCase);
            return coalesceExportsWorker(exportGroup, comparer, preferences);
        }
        function coalesceExportsWorker(exportGroup, comparer, preferences) {
            if (exportGroup.length === 0) {
                return exportGroup;
            }
            const { exportWithoutClause, namedExports, typeOnlyExports } = getCategorizedExports(exportGroup);
            const coalescedExports = [];
            if (exportWithoutClause) {
                coalescedExports.push(exportWithoutClause);
            }
            for (const exportGroup2 of [namedExports, typeOnlyExports]) {
                if (exportGroup2.length === 0) {
                    continue;
                }
                const newExportSpecifiers = [];
                newExportSpecifiers.push(...flatMap(exportGroup2, (i) => i.exportClause && isNamedExports(i.exportClause) ? i.exportClause.elements : emptyArray));
                const sortedExportSpecifiers = sortSpecifiers(newExportSpecifiers, comparer, preferences);
                const exportDecl = exportGroup2[0];
                coalescedExports.push(factory.updateExportDeclaration(exportDecl, exportDecl.modifiers, exportDecl.isTypeOnly, exportDecl.exportClause && (isNamedExports(exportDecl.exportClause) ? factory.updateNamedExports(exportDecl.exportClause, sortedExportSpecifiers) : factory.updateNamespaceExport(exportDecl.exportClause, exportDecl.exportClause.name)), exportDecl.moduleSpecifier, exportDecl.attributes));
            }
            return coalescedExports;
            function getCategorizedExports(exportGroup2) {
                let exportWithoutClause2;
                const namedExports2 = [];
                const typeOnlyExports2 = [];
                for (const exportDeclaration of exportGroup2) {
                    if (exportDeclaration.exportClause === void 0) {
                        exportWithoutClause2 = exportWithoutClause2 || exportDeclaration;
                    }
                    else if (exportDeclaration.isTypeOnly) {
                        typeOnlyExports2.push(exportDeclaration);
                    }
                    else {
                        namedExports2.push(exportDeclaration);
                    }
                }
                return {
                    exportWithoutClause: exportWithoutClause2,
                    namedExports: namedExports2,
                    typeOnlyExports: typeOnlyExports2
                };
            }
        }
        function updateImportDeclarationAndClause(importDeclaration, name, namedBindings) {
            return factory.updateImportDeclaration(importDeclaration, importDeclaration.modifiers, factory.updateImportClause(importDeclaration.importClause, importDeclaration.importClause.isTypeOnly, name, namedBindings), 
            // TODO: GH#18217
            importDeclaration.moduleSpecifier, importDeclaration.attributes);
        }
        function sortSpecifiers(specifiers, comparer, preferences) {
            return stableSort(specifiers, (s1, s2) => compareImportOrExportSpecifiers(s1, s2, comparer, preferences));
        }
        function compareImportOrExportSpecifiers(s1, s2, comparer, preferences) {
            switch (preferences == null ? void 0 : preferences.organizeImportsTypeOrder) {
                case "first":
                    return compareBooleans(s2.isTypeOnly, s1.isTypeOnly) || comparer(s1.name.text, s2.name.text);
                case "inline":
                    return comparer(s1.name.text, s2.name.text);
                default:
                    return compareBooleans(s1.isTypeOnly, s2.isTypeOnly) || comparer(s1.name.text, s2.name.text);
            }
        }
        function compareModuleSpecifiers2(m1, m2, ignoreCase) {
            const comparer = getOrganizeImportsOrdinalStringComparer(!!ignoreCase);
            return compareModuleSpecifiersWorker(m1, m2, comparer);
        }
        function compareModuleSpecifiersWorker(m1, m2, comparer) {
            const name1 = m1 === void 0 ? void 0 : getExternalModuleName2(m1);
            const name2 = m2 === void 0 ? void 0 : getExternalModuleName2(m2);
            return compareBooleans(name1 === void 0, name2 === void 0) || compareBooleans(isExternalModuleNameRelative(name1), isExternalModuleNameRelative(name2)) || comparer(name1, name2);
        }
        function getModuleSpecifierExpression(declaration) {
            var _a;
            switch (declaration.kind) {
                case 271 /* ImportEqualsDeclaration */:
                    return (_a = tryCast(declaration.moduleReference, isExternalModuleReference)) == null ? void 0 : _a.expression;
                case 272 /* ImportDeclaration */:
                    return declaration.moduleSpecifier;
                case 243 /* VariableStatement */:
                    return declaration.declarationList.declarations[0].initializer.arguments[0];
            }
        }
        function detectSorting(sourceFile, preferences) {
            return detectSortingWorker(groupByNewlineContiguous(sourceFile, sourceFile.statements.filter(isImportDeclaration)), preferences);
        }
        function detectSortingWorker(importGroups, preferences) {
            const collateCaseSensitive = getOrganizeImportsComparer(preferences, 
            /*ignoreCase*/
            false);
            const collateCaseInsensitive = getOrganizeImportsComparer(preferences, 
            /*ignoreCase*/
            true);
            let sortState = 3 /* Both */;
            let seenUnsortedGroup = false;
            for (const importGroup of importGroups) {
                if (importGroup.length > 1) {
                    const moduleSpecifierSort = detectSortCaseSensitivity(importGroup, (i) => {
                        var _a;
                        return ((_a = tryCast(i.moduleSpecifier, isStringLiteral)) == null ? void 0 : _a.text) ?? "";
                    }, collateCaseSensitive, collateCaseInsensitive);
                    if (moduleSpecifierSort) {
                        sortState &= moduleSpecifierSort;
                        seenUnsortedGroup = true;
                    }
                    if (!sortState) {
                        return sortState;
                    }
                }
                const declarationWithNamedImports = find(importGroup, (i) => {
                    var _a, _b;
                    return ((_b = tryCast((_a = i.importClause) == null ? void 0 : _a.namedBindings, isNamedImports)) == null ? void 0 : _b.elements.length) > 1;
                });
                if (declarationWithNamedImports) {
                    const namedImportSort = detectImportSpecifierSorting(declarationWithNamedImports.importClause.namedBindings.elements, preferences);
                    if (namedImportSort) {
                        sortState &= namedImportSort;
                        seenUnsortedGroup = true;
                    }
                    if (!sortState) {
                        return sortState;
                    }
                }
                if (sortState !== 3 /* Both */) {
                    return sortState;
                }
            }
            return seenUnsortedGroup ? 0 /* None */ : sortState;
        }
        function detectImportDeclarationSorting(imports, preferences) {
            const collateCaseSensitive = getOrganizeImportsComparer(preferences, 
            /*ignoreCase*/
            false);
            const collateCaseInsensitive = getOrganizeImportsComparer(preferences, 
            /*ignoreCase*/
            true);
            return detectSortCaseSensitivity(imports, (s) => getExternalModuleName2(getModuleSpecifierExpression(s)) || "", collateCaseSensitive, collateCaseInsensitive);
        }
        function getImportDeclarationInsertionIndex(sortedImports, newImport, comparer) {
            const index = binarySearch(sortedImports, newImport, identity, (a, b) => compareImportsOrRequireStatements(a, b, comparer));
            return index < 0 ? ~index : index;
        }
        function getImportSpecifierInsertionIndex(sortedImports, newImport, comparer, preferences) {
            const index = binarySearch(sortedImports, newImport, identity, (s1, s2) => compareImportOrExportSpecifiers(s1, s2, comparer, preferences));
            return index < 0 ? ~index : index;
        }
        function compareImportsOrRequireStatements(s1, s2, comparer) {
            return compareModuleSpecifiersWorker(getModuleSpecifierExpression(s1), getModuleSpecifierExpression(s2), comparer) || compareImportKind(s1, s2);
        }
        function compareImportKind(s1, s2) {
            return compareValues(getImportKindOrder(s1), getImportKindOrder(s2));
        }
        function getImportKindOrder(s1) {
            var _a;
            switch (s1.kind) {
                case 272 /* ImportDeclaration */:
                    if (!s1.importClause)
                        return 0;
                    if (s1.importClause.isTypeOnly)
                        return 1;
                    if (((_a = s1.importClause.namedBindings) == null ? void 0 : _a.kind) === 274 /* NamespaceImport */)
                        return 2;
                    if (s1.importClause.name)
                        return 3;
                    return 4;
                case 271 /* ImportEqualsDeclaration */:
                    return 5;
                case 243 /* VariableStatement */:
                    return 6;
            }
        }
        function getNewImportSpecifiers(namedImports) {
            return flatMap(namedImports, (namedImport) => map(tryGetNamedBindingElements(namedImport), (importSpecifier) => importSpecifier.name && importSpecifier.propertyName && importSpecifier.name.escapedText === importSpecifier.propertyName.escapedText ? factory.updateImportSpecifier(importSpecifier, importSpecifier.isTypeOnly, 
            /*propertyName*/
            void 0, importSpecifier.name) : importSpecifier));
        }
        function tryGetNamedBindingElements(namedImport) {
            var _a;
            return ((_a = namedImport.importClause) == null ? void 0 : _a.namedBindings) && isNamedImports(namedImport.importClause.namedBindings) ? namedImport.importClause.namedBindings.elements : void 0;
        }
        function getOrganizeImportsOrdinalStringComparer(ignoreCase) {
            return ignoreCase ? compareStringsCaseInsensitiveEslintCompatible : compareStringsCaseSensitive;
        }
        function getOrganizeImportsUnicodeStringComparer(ignoreCase, preferences) {
            const resolvedLocale = getOrganizeImportsLocale(preferences);
            const caseFirst = preferences.organizeImportsCaseFirst ?? false;
            const numeric = preferences.organizeImportsNumericCollation ?? false;
            const accents = preferences.organizeImportsAccentCollation ?? true;
            const sensitivity = ignoreCase ? accents ? "accent" : "base" : accents ? "variant" : "case";
            const collator = new Intl.Collator(resolvedLocale, {
                usage: "sort",
                caseFirst: caseFirst || "false",
                sensitivity,
                numeric
            });
            return collator.compare;
        }
        function getOrganizeImportsLocale(preferences) {
            let locale = preferences.organizeImportsLocale;
            if (locale === "auto")
                locale = getUILocale();
            if (locale === void 0)
                locale = "en";
            const supportedLocales = Intl.Collator.supportedLocalesOf(locale);
            const resolvedLocale = supportedLocales.length ? supportedLocales[0] : "en";
            return resolvedLocale;
        }
        function getOrganizeImportsComparer(preferences, ignoreCase) {
            const collation = preferences.organizeImportsCollation ?? "ordinal";
            return collation === "unicode" ? getOrganizeImportsUnicodeStringComparer(ignoreCase, preferences) : getOrganizeImportsOrdinalStringComparer(ignoreCase);
        }
        function getOrganizeImportsComparerWithDetection(preferences, detectIgnoreCase) {
            const ignoreCase = typeof preferences.organizeImportsIgnoreCase === "boolean" ? preferences.organizeImportsIgnoreCase : (detectIgnoreCase == null ? void 0 : detectIgnoreCase()) ?? false;
            return getOrganizeImportsComparer(preferences, ignoreCase);
        }
        function getTopLevelExportGroups(sourceFile) {
            const topLevelExportGroups = [];
            const statements = sourceFile.statements;
            const len = length(statements);
            let i = 0;
            let groupIndex = 0;
            while (i < len) {
                if (isExportDeclaration(statements[i])) {
                    if (topLevelExportGroups[groupIndex] === void 0) {
                        topLevelExportGroups[groupIndex] = [];
                    }
                    const exportDecl = statements[i];
                    if (exportDecl.moduleSpecifier) {
                        topLevelExportGroups[groupIndex].push(exportDecl);
                        i++;
                    }
                    else {
                        while (i < len && isExportDeclaration(statements[i])) {
                            topLevelExportGroups[groupIndex].push(statements[i++]);
                        }
                        groupIndex++;
                    }
                }
                else {
                    i++;
                }
            }
            return flatMap(topLevelExportGroups, (exportGroupDecls) => groupByNewlineContiguous(sourceFile, exportGroupDecls));
        }
        var ImportSpecifierSortingCache, detectImportSpecifierSorting;
        var init_organizeImports = __esm({
            "src/services/organizeImports.ts"() {
                "use strict";
                init_ts4();
                ImportSpecifierSortingCache = class {
                    has([specifiers, preferences]) {
                        if (this._lastPreferences !== preferences || !this._cache)
                            return false;
                        return this._cache.has(specifiers);
                    }
                    get([specifiers, preferences]) {
                        if (this._lastPreferences !== preferences || !this._cache)
                            return void 0;
                        return this._cache.get(specifiers);
                    }
                    set([specifiers, preferences], value) {
                        if (this._lastPreferences !== preferences) {
                            this._lastPreferences = preferences;
                            this._cache = void 0;
                        }
                        this._cache ?? (this._cache = /* @__PURE__ */ new WeakMap());
                        this._cache.set(specifiers, value);
                    }
                };
                detectImportSpecifierSorting = memoizeCached((specifiers, preferences) => {
                    switch (preferences.organizeImportsTypeOrder) {
                        case "first":
                            if (!arrayIsSorted(specifiers, (s1, s2) => compareBooleans(s2.isTypeOnly, s1.isTypeOnly)))
                                return 0 /* None */;
                            break;
                        case "inline":
                            if (!arrayIsSorted(specifiers, (s1, s2) => {
                                const comparer = getStringComparer(
                                /*ignoreCase*/
                                true);
                                return comparer(s1.name.text, s2.name.text);
                            })) {
                                return 0 /* None */;
                            }
                            break;
                        default:
                            if (!arrayIsSorted(specifiers, (s1, s2) => compareBooleans(s1.isTypeOnly, s2.isTypeOnly)))
                                return 0 /* None */;
                            break;
                    }
                    const collateCaseSensitive = getOrganizeImportsComparer(preferences, 
                    /*ignoreCase*/
                    false);
                    const collateCaseInsensitive = getOrganizeImportsComparer(preferences, 
                    /*ignoreCase*/
                    true);
                    if (preferences.organizeImportsTypeOrder !== "inline") {
                        const { type: regularImports, regular: typeImports } = groupBy(specifiers, (s) => s.isTypeOnly ? "type" : "regular");
                        const regularCaseSensitivity = (regularImports == null ? void 0 : regularImports.length) ? detectSortCaseSensitivity(regularImports, (specifier) => specifier.name.text, collateCaseSensitive, collateCaseInsensitive) : void 0;
                        const typeCaseSensitivity = (typeImports == null ? void 0 : typeImports.length) ? detectSortCaseSensitivity(typeImports, (specifier) => specifier.name.text ?? "", collateCaseSensitive, collateCaseInsensitive) : void 0;
                        if (regularCaseSensitivity === void 0) {
                            return typeCaseSensitivity ?? 0 /* None */;
                        }
                        if (typeCaseSensitivity === void 0) {
                            return regularCaseSensitivity;
                        }
                        if (regularCaseSensitivity === 0 /* None */ || typeCaseSensitivity === 0 /* None */) {
                            return 0 /* None */;
                        }
                        return typeCaseSensitivity & regularCaseSensitivity;
                    }
                    return detectSortCaseSensitivity(specifiers, (specifier) => specifier.name.text, collateCaseSensitive, collateCaseInsensitive);
                }, new ImportSpecifierSortingCache());
            }
        });
        // src/services/_namespaces/ts.OrganizeImports.ts
        var ts_OrganizeImports_exports = {};
        __export(ts_OrganizeImports_exports, {
            coalesceExports: () => coalesceExports,
            coalesceImports: () => coalesceImports,
            compareImportOrExportSpecifiers: () => compareImportOrExportSpecifiers,
            compareImportsOrRequireStatements: () => compareImportsOrRequireStatements,
            compareModuleSpecifiers: () => compareModuleSpecifiers2,
            detectImportDeclarationSorting: () => detectImportDeclarationSorting,
            detectImportSpecifierSorting: () => detectImportSpecifierSorting,
            detectSorting: () => detectSorting,
            getImportDeclarationInsertionIndex: () => getImportDeclarationInsertionIndex,
            getImportSpecifierInsertionIndex: () => getImportSpecifierInsertionIndex,
            getOrganizeImportsComparer: () => getOrganizeImportsComparer,
            organizeImports: () => organizeImports
        });
        var init_ts_OrganizeImports = __esm({
            "src/services/_namespaces/ts.OrganizeImports.ts"() {
                "use strict";
                init_organizeImports();
            }
        });
        // src/services/outliningElementsCollector.ts
        function collectElements(sourceFile, cancellationToken) {
            const res = [];
            addNodeOutliningSpans(sourceFile, cancellationToken, res);
            addRegionOutliningSpans(sourceFile, res);
            return res.sort((span1, span2) => span1.textSpan.start - span2.textSpan.start);
        }
        function addNodeOutliningSpans(sourceFile, cancellationToken, out) {
            let depthRemaining = 40;
            let current = 0;
            const statements = [...sourceFile.statements, sourceFile.endOfFileToken];
            const n = statements.length;
            while (current < n) {
                while (current < n && !isAnyImportSyntax(statements[current])) {
                    visitNode3(statements[current]);
                    current++;
                }
                if (current === n)
                    break;
                const firstImport = current;
                while (current < n && isAnyImportSyntax(statements[current])) {
                    visitNode3(statements[current]);
                    current++;
                }
                const lastImport = current - 1;
                if (lastImport !== firstImport) {
                    out.push(createOutliningSpanFromBounds(findChildOfKind(statements[firstImport], 102 /* ImportKeyword */, sourceFile).getStart(sourceFile), statements[lastImport].getEnd(), "imports" /* Imports */));
                }
            }
            function visitNode3(n2) {
                var _a;
                if (depthRemaining === 0)
                    return;
                cancellationToken.throwIfCancellationRequested();
                if (isDeclaration(n2) || isVariableStatement(n2) || isReturnStatement(n2) || isCallOrNewExpression(n2) || n2.kind === 1 /* EndOfFileToken */) {
                    addOutliningForLeadingCommentsForNode(n2, sourceFile, cancellationToken, out);
                }
                if (isFunctionLike(n2) && isBinaryExpression(n2.parent) && isPropertyAccessExpression(n2.parent.left)) {
                    addOutliningForLeadingCommentsForNode(n2.parent.left, sourceFile, cancellationToken, out);
                }
                if (isBlock(n2) || isModuleBlock(n2)) {
                    addOutliningForLeadingCommentsForPos(n2.statements.end, sourceFile, cancellationToken, out);
                }
                if (isClassLike(n2) || isInterfaceDeclaration(n2)) {
                    addOutliningForLeadingCommentsForPos(n2.members.end, sourceFile, cancellationToken, out);
                }
                const span = getOutliningSpanForNode(n2, sourceFile);
                if (span)
                    out.push(span);
                depthRemaining--;
                if (isCallExpression(n2)) {
                    depthRemaining++;
                    visitNode3(n2.expression);
                    depthRemaining--;
                    n2.arguments.forEach(visitNode3);
                    (_a = n2.typeArguments) == null ? void 0 : _a.forEach(visitNode3);
                }
                else if (isIfStatement(n2) && n2.elseStatement && isIfStatement(n2.elseStatement)) {
                    visitNode3(n2.expression);
                    visitNode3(n2.thenStatement);
                    depthRemaining++;
                    visitNode3(n2.elseStatement);
                    depthRemaining--;
                }
                else {
                    n2.forEachChild(visitNode3);
                }
                depthRemaining++;
            }
        }
        function addRegionOutliningSpans(sourceFile, out) {
            const regions = [];
            const lineStarts = sourceFile.getLineStarts();
            for (const currentLineStart of lineStarts) {
                const lineEnd = sourceFile.getLineEndOfPosition(currentLineStart);
                const lineText = sourceFile.text.substring(currentLineStart, lineEnd);
                const result = isRegionDelimiter(lineText);
                if (!result || isInComment(sourceFile, currentLineStart)) {
                    continue;
                }
                if (!result[1]) {
                    const span = createTextSpanFromBounds(sourceFile.text.indexOf("//", currentLineStart), lineEnd);
                    regions.push(createOutliningSpan(span, "region" /* Region */, span, 
                    /*autoCollapse*/
                    false, result[2] || "#region"));
                }
                else {
                    const region = regions.pop();
                    if (region) {
                        region.textSpan.length = lineEnd - region.textSpan.start;
                        region.hintSpan.length = lineEnd - region.textSpan.start;
                        out.push(region);
                    }
                }
            }
        }
        function isRegionDelimiter(lineText) {
            lineText = lineText.trimStart();
            if (!startsWith(lineText, "//")) {
                return null;
            }
            lineText = lineText.slice(2).trim();
            return regionDelimiterRegExp.exec(lineText);
        }
        function addOutliningForLeadingCommentsForPos(pos, sourceFile, cancellationToken, out) {
            const comments = getLeadingCommentRanges(sourceFile.text, pos);
            if (!comments)
                return;
            let firstSingleLineCommentStart = -1;
            let lastSingleLineCommentEnd = -1;
            let singleLineCommentCount = 0;
            const sourceText = sourceFile.getFullText();
            for (const { kind, pos: pos2, end } of comments) {
                cancellationToken.throwIfCancellationRequested();
                switch (kind) {
                    case 2 /* SingleLineCommentTrivia */:
                        const commentText = sourceText.slice(pos2, end);
                        if (isRegionDelimiter(commentText)) {
                            combineAndAddMultipleSingleLineComments();
                            singleLineCommentCount = 0;
                            break;
                        }
                        if (singleLineCommentCount === 0) {
                            firstSingleLineCommentStart = pos2;
                        }
                        lastSingleLineCommentEnd = end;
                        singleLineCommentCount++;
                        break;
                    case 3 /* MultiLineCommentTrivia */:
                        combineAndAddMultipleSingleLineComments();
                        out.push(createOutliningSpanFromBounds(pos2, end, "comment" /* Comment */));
                        singleLineCommentCount = 0;
                        break;
                    default:
                        Debug.assertNever(kind);
                }
            }
            combineAndAddMultipleSingleLineComments();
            function combineAndAddMultipleSingleLineComments() {
                if (singleLineCommentCount > 1) {
                    out.push(createOutliningSpanFromBounds(firstSingleLineCommentStart, lastSingleLineCommentEnd, "comment" /* Comment */));
                }
            }
        }
        function addOutliningForLeadingCommentsForNode(n, sourceFile, cancellationToken, out) {
            if (isJsxText(n))
                return;
            addOutliningForLeadingCommentsForPos(n.pos, sourceFile, cancellationToken, out);
        }
        function createOutliningSpanFromBounds(pos, end, kind) {
            return createOutliningSpan(createTextSpanFromBounds(pos, end), kind);
        }
        function getOutliningSpanForNode(n, sourceFile) {
            switch (n.kind) {
                case 241 /* Block */:
                    if (isFunctionLike(n.parent)) {
                        return functionSpan(n.parent, n, sourceFile);
                    }
                    switch (n.parent.kind) {
                        case 246 /* DoStatement */:
                        case 249 /* ForInStatement */:
                        case 250 /* ForOfStatement */:
                        case 248 /* ForStatement */:
                        case 245 /* IfStatement */:
                        case 247 /* WhileStatement */:
                        case 254 /* WithStatement */:
                        case 299 /* CatchClause */:
                            return spanForNode(n.parent);
                        case 258 /* TryStatement */:
                            const tryStatement = n.parent;
                            if (tryStatement.tryBlock === n) {
                                return spanForNode(n.parent);
                            }
                            else if (tryStatement.finallyBlock === n) {
                                const node = findChildOfKind(tryStatement, 98 /* FinallyKeyword */, sourceFile);
                                if (node)
                                    return spanForNode(node);
                            }
                        default:
                            return createOutliningSpan(createTextSpanFromNode(n, sourceFile), "code" /* Code */);
                    }
                case 268 /* ModuleBlock */:
                    return spanForNode(n.parent);
                case 263 /* ClassDeclaration */:
                case 231 /* ClassExpression */:
                case 264 /* InterfaceDeclaration */:
                case 266 /* EnumDeclaration */:
                case 269 /* CaseBlock */:
                case 187 /* TypeLiteral */:
                case 206 /* ObjectBindingPattern */:
                    return spanForNode(n);
                case 189 /* TupleType */:
                    return spanForNode(n, 
                    /*autoCollapse*/
                    false, 
                    /*useFullStart*/
                    !isTupleTypeNode(n.parent), 23 /* OpenBracketToken */);
                case 296 /* CaseClause */:
                case 297 /* DefaultClause */:
                    return spanForNodeArray(n.statements);
                case 210 /* ObjectLiteralExpression */:
                    return spanForObjectOrArrayLiteral(n);
                case 209 /* ArrayLiteralExpression */:
                    return spanForObjectOrArrayLiteral(n, 23 /* OpenBracketToken */);
                case 284 /* JsxElement */:
                    return spanForJSXElement(n);
                case 288 /* JsxFragment */:
                    return spanForJSXFragment(n);
                case 285 /* JsxSelfClosingElement */:
                case 286 /* JsxOpeningElement */:
                    return spanForJSXAttributes(n.attributes);
                case 228 /* TemplateExpression */:
                case 15 /* NoSubstitutionTemplateLiteral */:
                    return spanForTemplateLiteral(n);
                case 207 /* ArrayBindingPattern */:
                    return spanForNode(n, 
                    /*autoCollapse*/
                    false, 
                    /*useFullStart*/
                    !isBindingElement(n.parent), 23 /* OpenBracketToken */);
                case 219 /* ArrowFunction */:
                    return spanForArrowFunction(n);
                case 213 /* CallExpression */:
                    return spanForCallExpression(n);
                case 217 /* ParenthesizedExpression */:
                    return spanForParenthesizedExpression(n);
                case 275 /* NamedImports */:
                case 279 /* NamedExports */:
                case 300 /* ImportAttributes */:
                    return spanForImportExportElements(n);
            }
            function spanForImportExportElements(node) {
                if (!node.elements.length) {
                    return void 0;
                }
                const openToken = findChildOfKind(node, 19 /* OpenBraceToken */, sourceFile);
                const closeToken = findChildOfKind(node, 20 /* CloseBraceToken */, sourceFile);
                if (!openToken || !closeToken || positionsAreOnSameLine(openToken.pos, closeToken.pos, sourceFile)) {
                    return void 0;
                }
                return spanBetweenTokens(openToken, closeToken, node, sourceFile, 
                /*autoCollapse*/
                false, 
                /*useFullStart*/
                false);
            }
            function spanForCallExpression(node) {
                if (!node.arguments.length) {
                    return void 0;
                }
                const openToken = findChildOfKind(node, 21 /* OpenParenToken */, sourceFile);
                const closeToken = findChildOfKind(node, 22 /* CloseParenToken */, sourceFile);
                if (!openToken || !closeToken || positionsAreOnSameLine(openToken.pos, closeToken.pos, sourceFile)) {
                    return void 0;
                }
                return spanBetweenTokens(openToken, closeToken, node, sourceFile, 
                /*autoCollapse*/
                false, 
                /*useFullStart*/
                true);
            }
            function spanForArrowFunction(node) {
                if (isBlock(node.body) || isParenthesizedExpression(node.body) || positionsAreOnSameLine(node.body.getFullStart(), node.body.getEnd(), sourceFile)) {
                    return void 0;
                }
                const textSpan = createTextSpanFromBounds(node.body.getFullStart(), node.body.getEnd());
                return createOutliningSpan(textSpan, "code" /* Code */, createTextSpanFromNode(node));
            }
            function spanForJSXElement(node) {
                const textSpan = createTextSpanFromBounds(node.openingElement.getStart(sourceFile), node.closingElement.getEnd());
                const tagName = node.openingElement.tagName.getText(sourceFile);
                const bannerText = "<" + tagName + ">...</" + tagName + ">";
                return createOutliningSpan(textSpan, "code" /* Code */, textSpan, 
                /*autoCollapse*/
                false, bannerText);
            }
            function spanForJSXFragment(node) {
                const textSpan = createTextSpanFromBounds(node.openingFragment.getStart(sourceFile), node.closingFragment.getEnd());
                const bannerText = "<>...</>";
                return createOutliningSpan(textSpan, "code" /* Code */, textSpan, 
                /*autoCollapse*/
                false, bannerText);
            }
            function spanForJSXAttributes(node) {
                if (node.properties.length === 0) {
                    return void 0;
                }
                return createOutliningSpanFromBounds(node.getStart(sourceFile), node.getEnd(), "code" /* Code */);
            }
            function spanForTemplateLiteral(node) {
                if (node.kind === 15 /* NoSubstitutionTemplateLiteral */ && node.text.length === 0) {
                    return void 0;
                }
                return createOutliningSpanFromBounds(node.getStart(sourceFile), node.getEnd(), "code" /* Code */);
            }
            function spanForObjectOrArrayLiteral(node, open = 19 /* OpenBraceToken */) {
                return spanForNode(node, 
                /*autoCollapse*/
                false, 
                /*useFullStart*/
                !isArrayLiteralExpression(node.parent) && !isCallExpression(node.parent), open);
            }
            function spanForNode(hintSpanNode, autoCollapse = false, useFullStart = true, open = 19 /* OpenBraceToken */, close = open === 19 /* OpenBraceToken */ ? 20 /* CloseBraceToken */ : 24 /* CloseBracketToken */) {
                const openToken = findChildOfKind(n, open, sourceFile);
                const closeToken = findChildOfKind(n, close, sourceFile);
                return openToken && closeToken && spanBetweenTokens(openToken, closeToken, hintSpanNode, sourceFile, autoCollapse, useFullStart);
            }
            function spanForNodeArray(nodeArray) {
                return nodeArray.length ? createOutliningSpan(createTextSpanFromRange(nodeArray), "code" /* Code */) : void 0;
            }
            function spanForParenthesizedExpression(node) {
                if (positionsAreOnSameLine(node.getStart(), node.getEnd(), sourceFile))
                    return void 0;
                const textSpan = createTextSpanFromBounds(node.getStart(), node.getEnd());
                return createOutliningSpan(textSpan, "code" /* Code */, createTextSpanFromNode(node));
            }
        }
        function functionSpan(node, body, sourceFile) {
            const openToken = tryGetFunctionOpenToken(node, body, sourceFile);
            const closeToken = findChildOfKind(body, 20 /* CloseBraceToken */, sourceFile);
            return openToken && closeToken && spanBetweenTokens(openToken, closeToken, node, sourceFile, 
            /*autoCollapse*/
            node.kind !== 219 /* ArrowFunction */);
        }
        function spanBetweenTokens(openToken, closeToken, hintSpanNode, sourceFile, autoCollapse = false, useFullStart = true) {
            const textSpan = createTextSpanFromBounds(useFullStart ? openToken.getFullStart() : openToken.getStart(sourceFile), closeToken.getEnd());
            return createOutliningSpan(textSpan, "code" /* Code */, createTextSpanFromNode(hintSpanNode, sourceFile), autoCollapse);
        }
        function createOutliningSpan(textSpan, kind, hintSpan = textSpan, autoCollapse = false, bannerText = "...") {
            return { textSpan, kind, hintSpan, bannerText, autoCollapse };
        }
        function tryGetFunctionOpenToken(node, body, sourceFile) {
            if (isNodeArrayMultiLine(node.parameters, sourceFile)) {
                const openParenToken = findChildOfKind(node, 21 /* OpenParenToken */, sourceFile);
                if (openParenToken) {
                    return openParenToken;
                }
            }
            return findChildOfKind(body, 19 /* OpenBraceToken */, sourceFile);
        }
        var regionDelimiterRegExp;
        var init_outliningElementsCollector = __esm({
            "src/services/outliningElementsCollector.ts"() {
                "use strict";
                init_ts4();
                regionDelimiterRegExp = /^#(end)?region(?:\s+(.*))?(?:\r)?$/;
            }
        });
        // src/services/_namespaces/ts.OutliningElementsCollector.ts
        var ts_OutliningElementsCollector_exports = {};
        __export(ts_OutliningElementsCollector_exports, {
            collectElements: () => collectElements
        });
        var init_ts_OutliningElementsCollector = __esm({
            "src/services/_namespaces/ts.OutliningElementsCollector.ts"() {
                "use strict";
                init_outliningElementsCollector();
            }
        });
        // src/services/rename.ts
        function getRenameInfo(program, sourceFile, position, preferences) {
            const node = getAdjustedRenameLocation(getTouchingPropertyName(sourceFile, position));
            if (nodeIsEligibleForRename(node)) {
                const renameInfo = getRenameInfoForNode(node, program.getTypeChecker(), sourceFile, program, preferences);
                if (renameInfo) {
                    return renameInfo;
                }
            }
            return getRenameInfoError(Diagnostics.You_cannot_rename_this_element);
        }
        function getRenameInfoForNode(node, typeChecker, sourceFile, program, preferences) {
            const symbol = typeChecker.getSymbolAtLocation(node);
            if (!symbol) {
                if (isStringLiteralLike(node)) {
                    const type = getContextualTypeFromParentOrAncestorTypeNode(node, typeChecker);
                    if (type && (type.flags & 128 /* StringLiteral */ || type.flags & 1048576 /* Union */ && every(type.types, (type2) => !!(type2.flags & 128 /* StringLiteral */)))) {
                        return getRenameInfoSuccess(node.text, node.text, "string" /* string */, "", node, sourceFile);
                    }
                }
                else if (isLabelName(node)) {
                    const name = getTextOfNode(node);
                    return getRenameInfoSuccess(name, name, "label" /* label */, "" /* none */, node, sourceFile);
                }
                return void 0;
            }
            const { declarations } = symbol;
            if (!declarations || declarations.length === 0)
                return;
            if (declarations.some((declaration) => isDefinedInLibraryFile(program, declaration))) {
                return getRenameInfoError(Diagnostics.You_cannot_rename_elements_that_are_defined_in_the_standard_TypeScript_library);
            }
            if (isIdentifier(node) && node.escapedText === "default" && symbol.parent && symbol.parent.flags & 1536 /* Module */) {
                return void 0;
            }
            if (isStringLiteralLike(node) && tryGetImportFromModuleSpecifier(node)) {
                return preferences.allowRenameOfImportPath ? getRenameInfoForModule(node, sourceFile, symbol) : void 0;
            }
            const wouldRenameNodeModules = wouldRenameInOtherNodeModules(sourceFile, symbol, typeChecker, preferences);
            if (wouldRenameNodeModules) {
                return getRenameInfoError(wouldRenameNodeModules);
            }
            const kind = ts_SymbolDisplay_exports.getSymbolKind(typeChecker, symbol, node);
            const specifierName = isImportOrExportSpecifierName(node) || isStringOrNumericLiteralLike(node) && node.parent.kind === 167 /* ComputedPropertyName */ ? stripQuotes(getTextOfIdentifierOrLiteral(node)) : void 0;
            const displayName = specifierName || typeChecker.symbolToString(symbol);
            const fullDisplayName = specifierName || typeChecker.getFullyQualifiedName(symbol);
            return getRenameInfoSuccess(displayName, fullDisplayName, kind, ts_SymbolDisplay_exports.getSymbolModifiers(typeChecker, symbol), node, sourceFile);
        }
        function isDefinedInLibraryFile(program, declaration) {
            const sourceFile = declaration.getSourceFile();
            return program.isSourceFileDefaultLibrary(sourceFile) && fileExtensionIs(sourceFile.fileName, ".d.ts" /* Dts */);
        }
        function wouldRenameInOtherNodeModules(originalFile, symbol, checker, preferences) {
            if (!preferences.providePrefixAndSuffixTextForRename && symbol.flags & 2097152 /* Alias */) {
                const importSpecifier = symbol.declarations && find(symbol.declarations, (decl) => isImportSpecifier(decl));
                if (importSpecifier && !importSpecifier.propertyName) {
                    symbol = checker.getAliasedSymbol(symbol);
                }
            }
            const { declarations } = symbol;
            if (!declarations) {
                return void 0;
            }
            const originalPackage = getPackagePathComponents(originalFile.path);
            if (originalPackage === void 0) {
                if (some(declarations, (declaration) => isInsideNodeModules(declaration.getSourceFile().path))) {
                    return Diagnostics.You_cannot_rename_elements_that_are_defined_in_a_node_modules_folder;
                }
                else {
                    return void 0;
                }
            }
            for (const declaration of declarations) {
                const declPackage = getPackagePathComponents(declaration.getSourceFile().path);
                if (declPackage) {
                    const length2 = Math.min(originalPackage.length, declPackage.length);
                    for (let i = 0; i <= length2; i++) {
                        if (compareStringsCaseSensitive(originalPackage[i], declPackage[i]) !== 0 /* EqualTo */) {
                            return Diagnostics.You_cannot_rename_elements_that_are_defined_in_another_node_modules_folder;
                        }
                    }
                }
            }
            return void 0;
        }
        function getPackagePathComponents(filePath) {
            const components = getPathComponents(filePath);
            const nodeModulesIdx = components.lastIndexOf("node_modules");
            if (nodeModulesIdx === -1) {
                return void 0;
            }
            return components.slice(0, nodeModulesIdx + 2);
        }
        function getRenameInfoForModule(node, sourceFile, moduleSymbol) {
            if (!isExternalModuleNameRelative(node.text)) {
                return getRenameInfoError(Diagnostics.You_cannot_rename_a_module_via_a_global_import);
            }
            const moduleSourceFile = moduleSymbol.declarations && find(moduleSymbol.declarations, isSourceFile);
            if (!moduleSourceFile)
                return void 0;
            const withoutIndex = endsWith(node.text, "/index") || endsWith(node.text, "/index.js") ? void 0 : tryRemoveSuffix(removeFileExtension(moduleSourceFile.fileName), "/index");
            const fileName = withoutIndex === void 0 ? moduleSourceFile.fileName : withoutIndex;
            const kind = withoutIndex === void 0 ? "module" /* moduleElement */ : "directory" /* directory */;
            const indexAfterLastSlash = node.text.lastIndexOf("/") + 1;
            const triggerSpan = createTextSpan(node.getStart(sourceFile) + 1 + indexAfterLastSlash, node.text.length - indexAfterLastSlash);
            return {
                canRename: true,
                fileToRename: fileName,
                kind,
                displayName: fileName,
                fullDisplayName: node.text,
                kindModifiers: "" /* none */,
                triggerSpan
            };
        }
        function getRenameInfoSuccess(displayName, fullDisplayName, kind, kindModifiers, node, sourceFile) {
            return {
                canRename: true,
                fileToRename: void 0,
                kind,
                displayName,
                fullDisplayName,
                kindModifiers,
                triggerSpan: createTriggerSpanForNode(node, sourceFile)
            };
        }
        function getRenameInfoError(diagnostic) {
            return { canRename: false, localizedErrorMessage: getLocaleSpecificMessage(diagnostic) };
        }
        function createTriggerSpanForNode(node, sourceFile) {
            let start = node.getStart(sourceFile);
            let width = node.getWidth(sourceFile);
            if (isStringLiteralLike(node)) {
                start += 1;
                width -= 2;
            }
            return createTextSpan(start, width);
        }
        function nodeIsEligibleForRename(node) {
            switch (node.kind) {
                case 80 /* Identifier */:
                case 81 /* PrivateIdentifier */:
                case 11 /* StringLiteral */:
                case 15 /* NoSubstitutionTemplateLiteral */:
                case 110 /* ThisKeyword */:
                    return true;
                case 9 /* NumericLiteral */:
                    return isLiteralNameOfPropertyDeclarationOrIndexAccess(node);
                default:
                    return false;
            }
        }
        var init_rename = __esm({
            "src/services/rename.ts"() {
                "use strict";
                init_ts4();
            }
        });
        // src/services/_namespaces/ts.Rename.ts
        var ts_Rename_exports = {};
        __export(ts_Rename_exports, {
            getRenameInfo: () => getRenameInfo,
            nodeIsEligibleForRename: () => nodeIsEligibleForRename
        });
        var init_ts_Rename = __esm({
            "src/services/_namespaces/ts.Rename.ts"() {
                "use strict";
                init_rename();
            }
        });
        // src/services/signatureHelp.ts
        function getSignatureHelpItems(program, sourceFile, position, triggerReason, cancellationToken) {
            const typeChecker = program.getTypeChecker();
            const startingToken = findTokenOnLeftOfPosition(sourceFile, position);
            if (!startingToken) {
                return void 0;
            }
            const onlyUseSyntacticOwners = !!triggerReason && triggerReason.kind === "characterTyped";
            if (onlyUseSyntacticOwners && (isInString(sourceFile, position, startingToken) || isInComment(sourceFile, position))) {
                return void 0;
            }
            const isManuallyInvoked = !!triggerReason && triggerReason.kind === "invoked";
            const argumentInfo = getContainingArgumentInfo(startingToken, position, sourceFile, typeChecker, isManuallyInvoked);
            if (!argumentInfo)
                return void 0;
            cancellationToken.throwIfCancellationRequested();
            const candidateInfo = getCandidateOrTypeInfo(argumentInfo, typeChecker, sourceFile, startingToken, onlyUseSyntacticOwners);
            cancellationToken.throwIfCancellationRequested();
            if (!candidateInfo) {
                return isSourceFileJS(sourceFile) ? createJSSignatureHelpItems(argumentInfo, program, cancellationToken) : void 0;
            }
            return typeChecker.runWithCancellationToken(cancellationToken, (typeChecker2) => candidateInfo.kind === 0 /* Candidate */ ? createSignatureHelpItems(candidateInfo.candidates, candidateInfo.resolvedSignature, argumentInfo, sourceFile, typeChecker2) : createTypeHelpItems(candidateInfo.symbol, argumentInfo, sourceFile, typeChecker2));
        }
        function getCandidateOrTypeInfo({ invocation, argumentCount }, checker, sourceFile, startingToken, onlyUseSyntacticOwners) {
            switch (invocation.kind) {
                case 0 /* Call */: {
                    if (onlyUseSyntacticOwners && !isSyntacticOwner(startingToken, invocation.node, sourceFile)) {
                        return void 0;
                    }
                    const candidates = [];
                    const resolvedSignature = checker.getResolvedSignatureForSignatureHelp(invocation.node, candidates, argumentCount);
                    return candidates.length === 0 ? void 0 : { kind: 0 /* Candidate */, candidates, resolvedSignature };
                }
                case 1 /* TypeArgs */: {
                    const { called } = invocation;
                    if (onlyUseSyntacticOwners && !containsPrecedingToken(startingToken, sourceFile, isIdentifier(called) ? called.parent : called)) {
                        return void 0;
                    }
                    const candidates = getPossibleGenericSignatures(called, argumentCount, checker);
                    if (candidates.length !== 0)
                        return { kind: 0 /* Candidate */, candidates, resolvedSignature: first(candidates) };
                    const symbol = checker.getSymbolAtLocation(called);
                    return symbol && { kind: 1 /* Type */, symbol };
                }
                case 2 /* Contextual */:
                    return { kind: 0 /* Candidate */, candidates: [invocation.signature], resolvedSignature: invocation.signature };
                default:
                    return Debug.assertNever(invocation);
            }
        }
        function isSyntacticOwner(startingToken, node, sourceFile) {
            if (!isCallOrNewExpression(node))
                return false;
            const invocationChildren = node.getChildren(sourceFile);
            switch (startingToken.kind) {
                case 21 /* OpenParenToken */:
                    return contains(invocationChildren, startingToken);
                case 28 /* CommaToken */: {
                    const containingList = findContainingList(startingToken);
                    return !!containingList && contains(invocationChildren, containingList);
                }
                case 30 /* LessThanToken */:
                    return containsPrecedingToken(startingToken, sourceFile, node.expression);
                default:
                    return false;
            }
        }
        function createJSSignatureHelpItems(argumentInfo, program, cancellationToken) {
            if (argumentInfo.invocation.kind === 2 /* Contextual */)
                return void 0;
            const expression = getExpressionFromInvocation(argumentInfo.invocation);
            const name = isPropertyAccessExpression(expression) ? expression.name.text : void 0;
            const typeChecker = program.getTypeChecker();
            return name === void 0 ? void 0 : firstDefined(program.getSourceFiles(), (sourceFile) => firstDefined(sourceFile.getNamedDeclarations().get(name), (declaration) => {
                const type = declaration.symbol && typeChecker.getTypeOfSymbolAtLocation(declaration.symbol, declaration);
                const callSignatures = type && type.getCallSignatures();
                if (callSignatures && callSignatures.length) {
                    return typeChecker.runWithCancellationToken(cancellationToken, (typeChecker2) => createSignatureHelpItems(callSignatures, callSignatures[0], argumentInfo, sourceFile, typeChecker2, 
                    /*useFullPrefix*/
                    true));
                }
            }));
        }
        function containsPrecedingToken(startingToken, sourceFile, container) {
            const pos = startingToken.getFullStart();
            let currentParent = startingToken.parent;
            while (currentParent) {
                const precedingToken = findPrecedingToken(pos, sourceFile, currentParent, 
                /*excludeJsdoc*/
                true);
                if (precedingToken) {
                    return rangeContainsRange(container, precedingToken);
                }
                currentParent = currentParent.parent;
            }
            return Debug.fail("Could not find preceding token");
        }
        function getArgumentInfoForCompletions(node, position, sourceFile, checker) {
            const info = getImmediatelyContainingArgumentInfo(node, position, sourceFile, checker);
            return !info || info.isTypeParameterList || info.invocation.kind !== 0 /* Call */ ? void 0 : { invocation: info.invocation.node, argumentCount: info.argumentCount, argumentIndex: info.argumentIndex };
        }
        function getArgumentOrParameterListInfo(node, position, sourceFile, checker) {
            const info = getArgumentOrParameterListAndIndex(node, sourceFile, checker);
            if (!info)
                return void 0;
            const { list, argumentIndex } = info;
            const argumentCount = getArgumentCount(list, 
            /*ignoreTrailingComma*/
            isInString(sourceFile, position, node), checker);
            if (argumentIndex !== 0) {
                Debug.assertLessThan(argumentIndex, argumentCount);
            }
            const argumentsSpan = getApplicableSpanForArguments(list, sourceFile);
            return { list, argumentIndex, argumentCount, argumentsSpan };
        }
        function getArgumentOrParameterListAndIndex(node, sourceFile, checker) {
            if (node.kind === 30 /* LessThanToken */ || node.kind === 21 /* OpenParenToken */) {
                return { list: getChildListThatStartsWithOpenerToken(node.parent, node, sourceFile), argumentIndex: 0 };
            }
            else {
                const list = findContainingList(node);
                return list && { list, argumentIndex: getArgumentIndex(list, node, checker) };
            }
        }
        function getImmediatelyContainingArgumentInfo(node, position, sourceFile, checker) {
            const { parent: parent2 } = node;
            if (isCallOrNewExpression(parent2)) {
                const invocation = parent2;
                const info = getArgumentOrParameterListInfo(node, position, sourceFile, checker);
                if (!info)
                    return void 0;
                const { list, argumentIndex, argumentCount, argumentsSpan } = info;
                const isTypeParameterList = !!parent2.typeArguments && parent2.typeArguments.pos === list.pos;
                return { isTypeParameterList, invocation: { kind: 0 /* Call */, node: invocation }, argumentsSpan, argumentIndex, argumentCount };
            }
            else if (isNoSubstitutionTemplateLiteral(node) && isTaggedTemplateExpression(parent2)) {
                if (isInsideTemplateLiteral(node, position, sourceFile)) {
                    return getArgumentListInfoForTemplate(parent2, 
                    /*argumentIndex*/
                    0, sourceFile);
                }
                return void 0;
            }
            else if (isTemplateHead(node) && parent2.parent.kind === 215 /* TaggedTemplateExpression */) {
                const templateExpression = parent2;
                const tagExpression = templateExpression.parent;
                Debug.assert(templateExpression.kind === 228 /* TemplateExpression */);
                const argumentIndex = isInsideTemplateLiteral(node, position, sourceFile) ? 0 : 1;
                return getArgumentListInfoForTemplate(tagExpression, argumentIndex, sourceFile);
            }
            else if (isTemplateSpan(parent2) && isTaggedTemplateExpression(parent2.parent.parent)) {
                const templateSpan = parent2;
                const tagExpression = parent2.parent.parent;
                if (isTemplateTail(node) && !isInsideTemplateLiteral(node, position, sourceFile)) {
                    return void 0;
                }
                const spanIndex = templateSpan.parent.templateSpans.indexOf(templateSpan);
                const argumentIndex = getArgumentIndexForTemplatePiece(spanIndex, node, position, sourceFile);
                return getArgumentListInfoForTemplate(tagExpression, argumentIndex, sourceFile);
            }
            else if (isJsxOpeningLikeElement(parent2)) {
                const attributeSpanStart = parent2.attributes.pos;
                const attributeSpanEnd = skipTrivia(sourceFile.text, parent2.attributes.end, 
                /*stopAfterLineBreak*/
                false);
                return {
                    isTypeParameterList: false,
                    invocation: { kind: 0 /* Call */, node: parent2 },
                    argumentsSpan: createTextSpan(attributeSpanStart, attributeSpanEnd - attributeSpanStart),
                    argumentIndex: 0,
                    argumentCount: 1
                };
            }
            else {
                const typeArgInfo = getPossibleTypeArgumentsInfo(node, sourceFile);
                if (typeArgInfo) {
                    const { called, nTypeArguments } = typeArgInfo;
                    const invocation = { kind: 1 /* TypeArgs */, called };
                    const argumentsSpan = createTextSpanFromBounds(called.getStart(sourceFile), node.end);
                    return { isTypeParameterList: true, invocation, argumentsSpan, argumentIndex: nTypeArguments, argumentCount: nTypeArguments + 1 };
                }
                return void 0;
            }
        }
        function getImmediatelyContainingArgumentOrContextualParameterInfo(node, position, sourceFile, checker) {
            return tryGetParameterInfo(node, position, sourceFile, checker) || getImmediatelyContainingArgumentInfo(node, position, sourceFile, checker);
        }
        function getHighestBinary(b) {
            return isBinaryExpression(b.parent) ? getHighestBinary(b.parent) : b;
        }
        function countBinaryExpressionParameters(b) {
            return isBinaryExpression(b.left) ? countBinaryExpressionParameters(b.left) + 1 : 2;
        }
        function tryGetParameterInfo(startingToken, position, sourceFile, checker) {
            const node = getAdjustedNode(startingToken);
            if (node === void 0)
                return void 0;
            const info = getContextualSignatureLocationInfo(node, sourceFile, position, checker);
            if (info === void 0)
                return void 0;
            const { contextualType, argumentIndex, argumentCount, argumentsSpan } = info;
            const nonNullableContextualType = contextualType.getNonNullableType();
            const symbol = nonNullableContextualType.symbol;
            if (symbol === void 0)
                return void 0;
            const signature = lastOrUndefined(nonNullableContextualType.getCallSignatures());
            if (signature === void 0)
                return void 0;
            const invocation = { kind: 2 /* Contextual */, signature, node: startingToken, symbol: chooseBetterSymbol(symbol) };
            return { isTypeParameterList: false, invocation, argumentsSpan, argumentIndex, argumentCount };
        }
        function getAdjustedNode(node) {
            switch (node.kind) {
                case 21 /* OpenParenToken */:
                case 28 /* CommaToken */:
                    return node;
                default:
                    return findAncestor(node.parent, (n) => isParameter(n) ? true : isBindingElement(n) || isObjectBindingPattern(n) || isArrayBindingPattern(n) ? false : "quit");
            }
        }
        function getContextualSignatureLocationInfo(node, sourceFile, position, checker) {
            const { parent: parent2 } = node;
            switch (parent2.kind) {
                case 217 /* ParenthesizedExpression */:
                case 174 /* MethodDeclaration */:
                case 218 /* FunctionExpression */:
                case 219 /* ArrowFunction */:
                    const info = getArgumentOrParameterListInfo(node, position, sourceFile, checker);
                    if (!info)
                        return void 0;
                    const { argumentIndex, argumentCount, argumentsSpan } = info;
                    const contextualType = isMethodDeclaration(parent2) ? checker.getContextualTypeForObjectLiteralElement(parent2) : checker.getContextualType(parent2);
                    return contextualType && { contextualType, argumentIndex, argumentCount, argumentsSpan };
                case 226 /* BinaryExpression */: {
                    const highestBinary = getHighestBinary(parent2);
                    const contextualType2 = checker.getContextualType(highestBinary);
                    const argumentIndex2 = node.kind === 21 /* OpenParenToken */ ? 0 : countBinaryExpressionParameters(parent2) - 1;
                    const argumentCount2 = countBinaryExpressionParameters(highestBinary);
                    return contextualType2 && { contextualType: contextualType2, argumentIndex: argumentIndex2, argumentCount: argumentCount2, argumentsSpan: createTextSpanFromNode(parent2) };
                }
                default:
                    return void 0;
            }
        }
        function chooseBetterSymbol(s) {
            return s.name === "__type" /* Type */ ? firstDefined(s.declarations, (d) => {
                var _a;
                return isFunctionTypeNode(d) ? (_a = tryCast(d.parent, canHaveSymbol)) == null ? void 0 : _a.symbol : void 0;
            }) || s : s;
        }
        function getArgumentIndex(argumentsList, node, checker) {
            const args = argumentsList.getChildren();
            let argumentIndex = 0;
            for (let pos = 0; pos < length(args); pos++) {
                const child = args[pos];
                if (child === node) {
                    break;
                }
                if (isSpreadElement(child)) {
                    argumentIndex = argumentIndex + getSpreadElementCount(child, checker) + (pos > 0 ? pos : 0);
                }
                else {
                    if (child.kind !== 28 /* CommaToken */) {
                        argumentIndex++;
                    }
                }
            }
            return argumentIndex;
        }
        function getSpreadElementCount(node, checker) {
            const spreadType = checker.getTypeAtLocation(node.expression);
            if (checker.isTupleType(spreadType)) {
                const { elementFlags, fixedLength } = spreadType.target;
                if (fixedLength === 0) {
                    return 0;
                }
                const firstOptionalIndex = findIndex(elementFlags, (f) => !(f & 1 /* Required */));
                return firstOptionalIndex < 0 ? fixedLength : firstOptionalIndex;
            }
            return 0;
        }
        function getArgumentCount(argumentsList, ignoreTrailingComma, checker) {
            const listChildren = argumentsList.getChildren();
            let argumentCount = 0;
            for (const child of listChildren) {
                if (isSpreadElement(child)) {
                    argumentCount = argumentCount + getSpreadElementCount(child, checker);
                }
            }
            argumentCount = argumentCount + countWhere(listChildren, (arg) => arg.kind !== 28 /* CommaToken */);
            if (!ignoreTrailingComma && listChildren.length > 0 && last(listChildren).kind === 28 /* CommaToken */) {
                argumentCount++;
            }
            return argumentCount;
        }
        function getArgumentIndexForTemplatePiece(spanIndex, node, position, sourceFile) {
            Debug.assert(position >= node.getStart(), "Assumed 'position' could not occur before node.");
            if (isTemplateLiteralToken(node)) {
                if (isInsideTemplateLiteral(node, position, sourceFile)) {
                    return 0;
                }
                return spanIndex + 2;
            }
            return spanIndex + 1;
        }
        function getArgumentListInfoForTemplate(tagExpression, argumentIndex, sourceFile) {
            const argumentCount = isNoSubstitutionTemplateLiteral(tagExpression.template) ? 1 : tagExpression.template.templateSpans.length + 1;
            if (argumentIndex !== 0) {
                Debug.assertLessThan(argumentIndex, argumentCount);
            }
            return {
                isTypeParameterList: false,
                invocation: { kind: 0 /* Call */, node: tagExpression },
                argumentsSpan: getApplicableSpanForTaggedTemplate(tagExpression, sourceFile),
                argumentIndex,
                argumentCount
            };
        }
        function getApplicableSpanForArguments(argumentsList, sourceFile) {
            const applicableSpanStart = argumentsList.getFullStart();
            const applicableSpanEnd = skipTrivia(sourceFile.text, argumentsList.getEnd(), 
            /*stopAfterLineBreak*/
            false);
            return createTextSpan(applicableSpanStart, applicableSpanEnd - applicableSpanStart);
        }
        function getApplicableSpanForTaggedTemplate(taggedTemplate, sourceFile) {
            const template = taggedTemplate.template;
            const applicableSpanStart = template.getStart();
            let applicableSpanEnd = template.getEnd();
            if (template.kind === 228 /* TemplateExpression */) {
                const lastSpan = last(template.templateSpans);
                if (lastSpan.literal.getFullWidth() === 0) {
                    applicableSpanEnd = skipTrivia(sourceFile.text, applicableSpanEnd, 
                    /*stopAfterLineBreak*/
                    false);
                }
            }
            return createTextSpan(applicableSpanStart, applicableSpanEnd - applicableSpanStart);
        }
        function getContainingArgumentInfo(node, position, sourceFile, checker, isManuallyInvoked) {
            for (let n = node; !isSourceFile(n) && (isManuallyInvoked || !isBlock(n)); n = n.parent) {
                Debug.assert(rangeContainsRange(n.parent, n), "Not a subspan", () => `Child: ${Debug.formatSyntaxKind(n.kind)}, parent: ${Debug.formatSyntaxKind(n.parent.kind)}`);
                const argumentInfo = getImmediatelyContainingArgumentOrContextualParameterInfo(n, position, sourceFile, checker);
                if (argumentInfo) {
                    return argumentInfo;
                }
            }
            return void 0;
        }
        function getChildListThatStartsWithOpenerToken(parent2, openerToken, sourceFile) {
            const children = parent2.getChildren(sourceFile);
            const indexOfOpenerToken = children.indexOf(openerToken);
            Debug.assert(indexOfOpenerToken >= 0 && children.length > indexOfOpenerToken + 1);
            return children[indexOfOpenerToken + 1];
        }
        function getExpressionFromInvocation(invocation) {
            return invocation.kind === 0 /* Call */ ? getInvokedExpression(invocation.node) : invocation.called;
        }
        function getEnclosingDeclarationFromInvocation(invocation) {
            return invocation.kind === 0 /* Call */ ? invocation.node : invocation.kind === 1 /* TypeArgs */ ? invocation.called : invocation.node;
        }
        function createSignatureHelpItems(candidates, resolvedSignature, { isTypeParameterList, argumentCount, argumentsSpan: applicableSpan, invocation, argumentIndex }, sourceFile, typeChecker, useFullPrefix) {
            var _a;
            const enclosingDeclaration = getEnclosingDeclarationFromInvocation(invocation);
            const callTargetSymbol = invocation.kind === 2 /* Contextual */ ? invocation.symbol : typeChecker.getSymbolAtLocation(getExpressionFromInvocation(invocation)) || useFullPrefix && ((_a = resolvedSignature.declaration) == null ? void 0 : _a.symbol);
            const callTargetDisplayParts = callTargetSymbol ? symbolToDisplayParts(typeChecker, callTargetSymbol, useFullPrefix ? sourceFile : void 0, 
            /*meaning*/
            void 0) : emptyArray;
            const items = map(candidates, (candidateSignature) => getSignatureHelpItem(candidateSignature, callTargetDisplayParts, isTypeParameterList, typeChecker, enclosingDeclaration, sourceFile));
            if (argumentIndex !== 0) {
                Debug.assertLessThan(argumentIndex, argumentCount);
            }
            let selectedItemIndex = 0;
            let itemsSeen = 0;
            for (let i = 0; i < items.length; i++) {
                const item = items[i];
                if (candidates[i] === resolvedSignature) {
                    selectedItemIndex = itemsSeen;
                    if (item.length > 1) {
                        let count = 0;
                        for (const i2 of item) {
                            if (i2.isVariadic || i2.parameters.length >= argumentCount) {
                                selectedItemIndex = itemsSeen + count;
                                break;
                            }
                            count++;
                        }
                    }
                }
                itemsSeen += item.length;
            }
            Debug.assert(selectedItemIndex !== -1);
            const help = { items: flatMapToMutable(items, identity), applicableSpan, selectedItemIndex, argumentIndex, argumentCount };
            const selected = help.items[selectedItemIndex];
            if (selected.isVariadic) {
                const firstRest = findIndex(selected.parameters, (p) => !!p.isRest);
                if (-1 < firstRest && firstRest < selected.parameters.length - 1) {
                    help.argumentIndex = selected.parameters.length;
                }
                else {
                    help.argumentIndex = Math.min(help.argumentIndex, selected.parameters.length - 1);
                }
            }
            return help;
        }
        function createTypeHelpItems(symbol, { argumentCount, argumentsSpan: applicableSpan, invocation, argumentIndex }, sourceFile, checker) {
            const typeParameters = checker.getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(symbol);
            if (!typeParameters)
                return void 0;
            const items = [getTypeHelpItem(symbol, typeParameters, checker, getEnclosingDeclarationFromInvocation(invocation), sourceFile)];
            return { items, applicableSpan, selectedItemIndex: 0, argumentIndex, argumentCount };
        }
        function getTypeHelpItem(symbol, typeParameters, checker, enclosingDeclaration, sourceFile) {
            const typeSymbolDisplay = symbolToDisplayParts(checker, symbol);
            const printer = createPrinterWithRemoveComments();
            const parameters = typeParameters.map((t) => createSignatureHelpParameterForTypeParameter(t, checker, enclosingDeclaration, sourceFile, printer));
            const documentation = symbol.getDocumentationComment(checker);
            const tags = symbol.getJsDocTags(checker);
            const prefixDisplayParts = [...typeSymbolDisplay, punctuationPart(30 /* LessThanToken */)];
            return { isVariadic: false, prefixDisplayParts, suffixDisplayParts: [punctuationPart(32 /* GreaterThanToken */)], separatorDisplayParts, parameters, documentation, tags };
        }
        function getSignatureHelpItem(candidateSignature, callTargetDisplayParts, isTypeParameterList, checker, enclosingDeclaration, sourceFile) {
            const infos = (isTypeParameterList ? itemInfoForTypeParameters : itemInfoForParameters)(candidateSignature, checker, enclosingDeclaration, sourceFile);
            return map(infos, ({ isVariadic, parameters, prefix, suffix }) => {
                const prefixDisplayParts = [...callTargetDisplayParts, ...prefix];
                const suffixDisplayParts = [...suffix, ...returnTypeToDisplayParts(candidateSignature, enclosingDeclaration, checker)];
                const documentation = candidateSignature.getDocumentationComment(checker);
                const tags = candidateSignature.getJsDocTags();
                return { isVariadic, prefixDisplayParts, suffixDisplayParts, separatorDisplayParts, parameters, documentation, tags };
            });
        }
        function returnTypeToDisplayParts(candidateSignature, enclosingDeclaration, checker) {
            return mapToDisplayParts((writer) => {
                writer.writePunctuation(":");
                writer.writeSpace(" ");
                const predicate = checker.getTypePredicateOfSignature(candidateSignature);
                if (predicate) {
                    checker.writeTypePredicate(predicate, enclosingDeclaration, 
                    /*flags*/
                    void 0, writer);
                }
                else {
                    checker.writeType(checker.getReturnTypeOfSignature(candidateSignature), enclosingDeclaration, 
                    /*flags*/
                    void 0, writer);
                }
            });
        }
        function itemInfoForTypeParameters(candidateSignature, checker, enclosingDeclaration, sourceFile) {
            const typeParameters = (candidateSignature.target || candidateSignature).typeParameters;
            const printer = createPrinterWithRemoveComments();
            const parameters = (typeParameters || emptyArray).map((t) => createSignatureHelpParameterForTypeParameter(t, checker, enclosingDeclaration, sourceFile, printer));
            const thisParameter = candidateSignature.thisParameter ? [checker.symbolToParameterDeclaration(candidateSignature.thisParameter, enclosingDeclaration, signatureHelpNodeBuilderFlags)] : [];
            return checker.getExpandedParameters(candidateSignature).map((paramList) => {
                const params = factory.createNodeArray([...thisParameter, ...map(paramList, (param) => checker.symbolToParameterDeclaration(param, enclosingDeclaration, signatureHelpNodeBuilderFlags))]);
                const parameterParts = mapToDisplayParts((writer) => {
                    printer.writeList(2576 /* CallExpressionArguments */, params, sourceFile, writer);
                });
                return { isVariadic: false, parameters, prefix: [punctuationPart(30 /* LessThanToken */)], suffix: [punctuationPart(32 /* GreaterThanToken */), ...parameterParts] };
            });
        }
        function itemInfoForParameters(candidateSignature, checker, enclosingDeclaration, sourceFile) {
            const printer = createPrinterWithRemoveComments();
            const typeParameterParts = mapToDisplayParts((writer) => {
                if (candidateSignature.typeParameters && candidateSignature.typeParameters.length) {
                    const args = factory.createNodeArray(candidateSignature.typeParameters.map((p) => checker.typeParameterToDeclaration(p, enclosingDeclaration, signatureHelpNodeBuilderFlags)));
                    printer.writeList(53776 /* TypeParameters */, args, sourceFile, writer);
                }
            });
            const lists = checker.getExpandedParameters(candidateSignature);
            const isVariadic = !checker.hasEffectiveRestParameter(candidateSignature) ? (_) => false : lists.length === 1 ? (_) => true : (pList) => {
                var _a;
                return !!(pList.length && ((_a = tryCast(pList[pList.length - 1], isTransientSymbol)) == null ? void 0 : _a.links.checkFlags) & 32768 /* RestParameter */);
            };
            return lists.map((parameterList) => ({
                isVariadic: isVariadic(parameterList),
                parameters: parameterList.map((p) => createSignatureHelpParameterForParameter(p, checker, enclosingDeclaration, sourceFile, printer)),
                prefix: [...typeParameterParts, punctuationPart(21 /* OpenParenToken */)],
                suffix: [punctuationPart(22 /* CloseParenToken */)]
            }));
        }
        function createSignatureHelpParameterForParameter(parameter, checker, enclosingDeclaration, sourceFile, printer) {
            const displayParts = mapToDisplayParts((writer) => {
                const param = checker.symbolToParameterDeclaration(parameter, enclosingDeclaration, signatureHelpNodeBuilderFlags);
                printer.writeNode(4 /* Unspecified */, param, sourceFile, writer);
            });
            const isOptional = checker.isOptionalParameter(parameter.valueDeclaration);
            const isRest = isTransientSymbol(parameter) && !!(parameter.links.checkFlags & 32768 /* RestParameter */);
            return { name: parameter.name, documentation: parameter.getDocumentationComment(checker), displayParts, isOptional, isRest };
        }
        function createSignatureHelpParameterForTypeParameter(typeParameter, checker, enclosingDeclaration, sourceFile, printer) {
            const displayParts = mapToDisplayParts((writer) => {
                const param = checker.typeParameterToDeclaration(typeParameter, enclosingDeclaration, signatureHelpNodeBuilderFlags);
                printer.writeNode(4 /* Unspecified */, param, sourceFile, writer);
            });
            return { name: typeParameter.symbol.name, documentation: typeParameter.symbol.getDocumentationComment(checker), displayParts, isOptional: false, isRest: false };
        }
        var signatureHelpNodeBuilderFlags, separatorDisplayParts;
        var init_signatureHelp = __esm({
            "src/services/signatureHelp.ts"() {
                "use strict";
                init_ts4();
                signatureHelpNodeBuilderFlags = 8192 /* OmitParameterModifiers */ | 70221824 /* IgnoreErrors */ | 16384 /* UseAliasDefinedOutsideCurrentScope */;
                separatorDisplayParts = [punctuationPart(28 /* CommaToken */), spacePart()];
            }
        });
        // src/services/_namespaces/ts.SignatureHelp.ts
        var ts_SignatureHelp_exports = {};
        __export(ts_SignatureHelp_exports, {
            getArgumentInfoForCompletions: () => getArgumentInfoForCompletions,
            getSignatureHelpItems: () => getSignatureHelpItems
        });
        var init_ts_SignatureHelp = __esm({
            "src/services/_namespaces/ts.SignatureHelp.ts"() {
                "use strict";
                init_signatureHelp();
            }
        });
        // src/services/smartSelection.ts
        function getSmartSelectionRange(pos, sourceFile) {
            var _a, _b;
            let selectionRange = {
                textSpan: createTextSpanFromBounds(sourceFile.getFullStart(), sourceFile.getEnd())
            };
            let parentNode = sourceFile;
            outer: while (true) {
                const children = getSelectionChildren(parentNode);
                if (!children.length)
                    break;
                for (let i = 0; i < children.length; i++) {
                    const prevNode = children[i - 1];
                    const node = children[i];
                    const nextNode = children[i + 1];
                    if (getTokenPosOfNode(node, sourceFile, 
                    /*includeJsDoc*/
                    true) > pos) {
                        break outer;
                    }
                    const comment = singleOrUndefined(getTrailingCommentRanges(sourceFile.text, node.end));
                    if (comment && comment.kind === 2 /* SingleLineCommentTrivia */) {
                        pushSelectionCommentRange(comment.pos, comment.end);
                    }
                    if (positionShouldSnapToNode(sourceFile, pos, node)) {
                        if (isFunctionBody(node) && isFunctionLikeDeclaration(parentNode) && !positionsAreOnSameLine(node.getStart(sourceFile), node.getEnd(), sourceFile)) {
                            pushSelectionRange(node.getStart(sourceFile), node.getEnd());
                        }
                        if (isBlock(node) || isTemplateSpan(node) || isTemplateHead(node) || isTemplateTail(node) || prevNode && isTemplateHead(prevNode) || isVariableDeclarationList(node) && isVariableStatement(parentNode) || isSyntaxList(node) && isVariableDeclarationList(parentNode) || isVariableDeclaration(node) && isSyntaxList(parentNode) && children.length === 1 || isJSDocTypeExpression(node) || isJSDocSignature(node) || isJSDocTypeLiteral(node)) {
                            parentNode = node;
                            break;
                        }
                        if (isTemplateSpan(parentNode) && nextNode && isTemplateMiddleOrTemplateTail(nextNode)) {
                            const start2 = node.getFullStart() - "${".length;
                            const end2 = nextNode.getStart() + "}".length;
                            pushSelectionRange(start2, end2);
                        }
                        const isBetweenMultiLineBookends = isSyntaxList(node) && isListOpener(prevNode) && isListCloser(nextNode) && !positionsAreOnSameLine(prevNode.getStart(), nextNode.getStart(), sourceFile);
                        let start = isBetweenMultiLineBookends ? prevNode.getEnd() : node.getStart();
                        const end = isBetweenMultiLineBookends ? nextNode.getStart() : getEndPos(sourceFile, node);
                        if (hasJSDocNodes(node) && ((_a = node.jsDoc) == null ? void 0 : _a.length)) {
                            pushSelectionRange(first(node.jsDoc).getStart(), end);
                        }
                        if (isSyntaxList(node)) {
                            const firstChild = node.getChildren()[0];
                            if (firstChild && hasJSDocNodes(firstChild) && ((_b = firstChild.jsDoc) == null ? void 0 : _b.length) && firstChild.getStart() !== node.pos) {
                                start = Math.min(start, first(firstChild.jsDoc).getStart());
                            }
                        }
                        pushSelectionRange(start, end);
                        if (isStringLiteral(node) || isTemplateLiteral(node)) {
                            pushSelectionRange(start + 1, end - 1);
                        }
                        parentNode = node;
                        break;
                    }
                    if (i === children.length - 1) {
                        break outer;
                    }
                }
            }
            return selectionRange;
            function pushSelectionRange(start, end) {
                if (start !== end) {
                    const textSpan = createTextSpanFromBounds(start, end);
                    if (!selectionRange || // Skip ranges that are identical to the parent
                        !textSpansEqual(textSpan, selectionRange.textSpan) && // Skip ranges that don't contain the original position
                            textSpanIntersectsWithPosition(textSpan, pos)) {
                        selectionRange = { textSpan, ...selectionRange && { parent: selectionRange } };
                    }
                }
            }
            function pushSelectionCommentRange(start, end) {
                pushSelectionRange(start, end);
                let pos2 = start;
                while (sourceFile.text.charCodeAt(pos2) === 47 /* slash */) {
                    pos2++;
                }
                pushSelectionRange(pos2, end);
            }
        }
        function positionShouldSnapToNode(sourceFile, pos, node) {
            Debug.assert(node.pos <= pos);
            if (pos < node.end) {
                return true;
            }
            const nodeEnd = node.getEnd();
            if (nodeEnd === pos) {
                return getTouchingPropertyName(sourceFile, pos).pos < node.end;
            }
            return false;
        }
        function getSelectionChildren(node) {
            var _a;
            if (isSourceFile(node)) {
                return groupChildren(node.getChildAt(0).getChildren(), isImport2);
            }
            if (isMappedTypeNode(node)) {
                const [openBraceToken, ...children] = node.getChildren();
                const closeBraceToken = Debug.checkDefined(children.pop());
                Debug.assertEqual(openBraceToken.kind, 19 /* OpenBraceToken */);
                Debug.assertEqual(closeBraceToken.kind, 20 /* CloseBraceToken */);
                const groupedWithPlusMinusTokens = groupChildren(children, (child) => child === node.readonlyToken || child.kind === 148 /* ReadonlyKeyword */ || child === node.questionToken || child.kind === 58 /* QuestionToken */);
                const groupedWithBrackets = groupChildren(groupedWithPlusMinusTokens, ({ kind }) => kind === 23 /* OpenBracketToken */ || kind === 168 /* TypeParameter */ || kind === 24 /* CloseBracketToken */);
                return [
                    openBraceToken,
                    // Pivot on `:`
                    createSyntaxList2(splitChildren(groupedWithBrackets, ({ kind }) => kind === 59 /* ColonToken */)),
                    closeBraceToken
                ];
            }
            if (isPropertySignature(node)) {
                const children = groupChildren(node.getChildren(), (child) => child === node.name || contains(node.modifiers, child));
                const firstJSDocChild = ((_a = children[0]) == null ? void 0 : _a.kind) === 327 /* JSDoc */ ? children[0] : void 0;
                const withJSDocSeparated = firstJSDocChild ? children.slice(1) : children;
                const splittedChildren = splitChildren(withJSDocSeparated, ({ kind }) => kind === 59 /* ColonToken */);
                return firstJSDocChild ? [firstJSDocChild, createSyntaxList2(splittedChildren)] : splittedChildren;
            }
            if (isParameter(node)) {
                const groupedDotDotDotAndName = groupChildren(node.getChildren(), (child) => child === node.dotDotDotToken || child === node.name);
                const groupedWithQuestionToken = groupChildren(groupedDotDotDotAndName, (child) => child === groupedDotDotDotAndName[0] || child === node.questionToken);
                return splitChildren(groupedWithQuestionToken, ({ kind }) => kind === 64 /* EqualsToken */);
            }
            if (isBindingElement(node)) {
                return splitChildren(node.getChildren(), ({ kind }) => kind === 64 /* EqualsToken */);
            }
            return node.getChildren();
        }
        function groupChildren(children, groupOn) {
            const result = [];
            let group2;
            for (const child of children) {
                if (groupOn(child)) {
                    group2 = group2 || [];
                    group2.push(child);
                }
                else {
                    if (group2) {
                        result.push(createSyntaxList2(group2));
                        group2 = void 0;
                    }
                    result.push(child);
                }
            }
            if (group2) {
                result.push(createSyntaxList2(group2));
            }
            return result;
        }
        function splitChildren(children, pivotOn, separateTrailingSemicolon = true) {
            if (children.length < 2) {
                return children;
            }
            const splitTokenIndex = findIndex(children, pivotOn);
            if (splitTokenIndex === -1) {
                return children;
            }
            const leftChildren = children.slice(0, splitTokenIndex);
            const splitToken = children[splitTokenIndex];
            const lastToken = last(children);
            const separateLastToken = separateTrailingSemicolon && lastToken.kind === 27 /* SemicolonToken */;
            const rightChildren = children.slice(splitTokenIndex + 1, separateLastToken ? children.length - 1 : void 0);
            const result = compact([
                leftChildren.length ? createSyntaxList2(leftChildren) : void 0,
                splitToken,
                rightChildren.length ? createSyntaxList2(rightChildren) : void 0
            ]);
            return separateLastToken ? result.concat(lastToken) : result;
        }
        function createSyntaxList2(children) {
            Debug.assertGreaterThanOrEqual(children.length, 1);
            return setTextRangePosEnd(parseNodeFactory.createSyntaxList(children), children[0].pos, last(children).end);
        }
        function isListOpener(token) {
            const kind = token && token.kind;
            return kind === 19 /* OpenBraceToken */ || kind === 23 /* OpenBracketToken */ || kind === 21 /* OpenParenToken */ || kind === 286 /* JsxOpeningElement */;
        }
        function isListCloser(token) {
            const kind = token && token.kind;
            return kind === 20 /* CloseBraceToken */ || kind === 24 /* CloseBracketToken */ || kind === 22 /* CloseParenToken */ || kind === 287 /* JsxClosingElement */;
        }
        function getEndPos(sourceFile, node) {
            switch (node.kind) {
                case 348 /* JSDocParameterTag */:
                case 345 /* JSDocCallbackTag */:
                case 355 /* JSDocPropertyTag */:
                case 353 /* JSDocTypedefTag */:
                case 350 /* JSDocThisTag */:
                    return sourceFile.getLineEndOfPosition(node.getStart());
                default:
                    return node.getEnd();
            }
        }
        var isImport2;
        var init_smartSelection = __esm({
            "src/services/smartSelection.ts"() {
                "use strict";
                init_ts4();
                isImport2 = or(isImportDeclaration, isImportEqualsDeclaration);
            }
        });
        // src/services/_namespaces/ts.SmartSelectionRange.ts
        var ts_SmartSelectionRange_exports = {};
        __export(ts_SmartSelectionRange_exports, {
            getSmartSelectionRange: () => getSmartSelectionRange
        });
        var init_ts_SmartSelectionRange = __esm({
            "src/services/_namespaces/ts.SmartSelectionRange.ts"() {
                "use strict";
                init_smartSelection();
            }
        });
        // src/services/symbolDisplay.ts
        function getSymbolKind(typeChecker, symbol, location) {
            const result = getSymbolKindOfConstructorPropertyMethodAccessorFunctionOrVar(typeChecker, symbol, location);
            if (result !== "" /* unknown */) {
                return result;
            }
            const flags = getCombinedLocalAndExportSymbolFlags(symbol);
            if (flags & 32 /* Class */) {
                return getDeclarationOfKind(symbol, 231 /* ClassExpression */) ? "local class" /* localClassElement */ : "class" /* classElement */;
            }
            if (flags & 384 /* Enum */)
                return "enum" /* enumElement */;
            if (flags & 524288 /* TypeAlias */)
                return "type" /* typeElement */;
            if (flags & 64 /* Interface */)
                return "interface" /* interfaceElement */;
            if (flags & 262144 /* TypeParameter */)
                return "type parameter" /* typeParameterElement */;
            if (flags & 8 /* EnumMember */)
                return "enum member" /* enumMemberElement */;
            if (flags & 2097152 /* Alias */)
                return "alias" /* alias */;
            if (flags & 1536 /* Module */)
                return "module" /* moduleElement */;
            return result;
        }
        function getSymbolKindOfConstructorPropertyMethodAccessorFunctionOrVar(typeChecker, symbol, location) {
            const roots = typeChecker.getRootSymbols(symbol);
            if (roots.length === 1 && first(roots).flags & 8192 /* Method */ && typeChecker.getTypeOfSymbolAtLocation(symbol, location).getNonNullableType().getCallSignatures().length !== 0) {
                return "method" /* memberFunctionElement */;
            }
            if (typeChecker.isUndefinedSymbol(symbol)) {
                return "var" /* variableElement */;
            }
            if (typeChecker.isArgumentsSymbol(symbol)) {
                return "local var" /* localVariableElement */;
            }
            if (location.kind === 110 /* ThisKeyword */ && isExpression(location) || isThisInTypeQuery(location)) {
                return "parameter" /* parameterElement */;
            }
            const flags = getCombinedLocalAndExportSymbolFlags(symbol);
            if (flags & 3 /* Variable */) {
                if (isFirstDeclarationOfSymbolParameter(symbol)) {
                    return "parameter" /* parameterElement */;
                }
                else if (symbol.valueDeclaration && isVarConst(symbol.valueDeclaration)) {
                    return "const" /* constElement */;
                }
                else if (symbol.valueDeclaration && isVarUsing(symbol.valueDeclaration)) {
                    return "using" /* variableUsingElement */;
                }
                else if (symbol.valueDeclaration && isVarAwaitUsing(symbol.valueDeclaration)) {
                    return "await using" /* variableAwaitUsingElement */;
                }
                else if (forEach(symbol.declarations, isLet)) {
                    return "let" /* letElement */;
                }
                return isLocalVariableOrFunction(symbol) ? "local var" /* localVariableElement */ : "var" /* variableElement */;
            }
            if (flags & 16 /* Function */)
                return isLocalVariableOrFunction(symbol) ? "local function" /* localFunctionElement */ : "function" /* functionElement */;
            if (flags & 32768 /* GetAccessor */)
                return "getter" /* memberGetAccessorElement */;
            if (flags & 65536 /* SetAccessor */)
                return "setter" /* memberSetAccessorElement */;
            if (flags & 8192 /* Method */)
                return "method" /* memberFunctionElement */;
            if (flags & 16384 /* Constructor */)
                return "constructor" /* constructorImplementationElement */;
            if (flags & 131072 /* Signature */)
                return "index" /* indexSignatureElement */;
            if (flags & 4 /* Property */) {
                if (flags & 33554432 /* Transient */ && symbol.links.checkFlags & 6 /* Synthetic */) {
                    const unionPropertyKind = forEach(typeChecker.getRootSymbols(symbol), (rootSymbol) => {
                        const rootSymbolFlags = rootSymbol.getFlags();
                        if (rootSymbolFlags & (98308 /* PropertyOrAccessor */ | 3 /* Variable */)) {
                            return "property" /* memberVariableElement */;
                        }
                    });
                    if (!unionPropertyKind) {
                        const typeOfUnionProperty = typeChecker.getTypeOfSymbolAtLocation(symbol, location);
                        if (typeOfUnionProperty.getCallSignatures().length) {
                            return "method" /* memberFunctionElement */;
                        }
                        return "property" /* memberVariableElement */;
                    }
                    return unionPropertyKind;
                }
                return "property" /* memberVariableElement */;
            }
            return "" /* unknown */;
        }
        function getNormalizedSymbolModifiers(symbol) {
            if (symbol.declarations && symbol.declarations.length) {
                const [declaration, ...declarations] = symbol.declarations;
                const excludeFlags = length(declarations) && isDeprecatedDeclaration(declaration) && some(declarations, (d) => !isDeprecatedDeclaration(d)) ? 65536 /* Deprecated */ : 0 /* None */;
                const modifiers = getNodeModifiers(declaration, excludeFlags);
                if (modifiers) {
                    return modifiers.split(",");
                }
            }
            return [];
        }
        function getSymbolModifiers(typeChecker, symbol) {
            if (!symbol) {
                return "" /* none */;
            }
            const modifiers = new Set(getNormalizedSymbolModifiers(symbol));
            if (symbol.flags & 2097152 /* Alias */) {
                const resolvedSymbol = typeChecker.getAliasedSymbol(symbol);
                if (resolvedSymbol !== symbol) {
                    forEach(getNormalizedSymbolModifiers(resolvedSymbol), (modifier) => {
                        modifiers.add(modifier);
                    });
                }
            }
            if (symbol.flags & 16777216 /* Optional */) {
                modifiers.add("optional" /* optionalModifier */);
            }
            return modifiers.size > 0 ? arrayFrom(modifiers.values()).join(",") : "" /* none */;
        }
        function getSymbolDisplayPartsDocumentationAndSymbolKindWorker(typeChecker, symbol, sourceFile, enclosingDeclaration, location, type, semanticMeaning, alias) {
            var _a;
            const displayParts = [];
            let documentation = [];
            let tags = [];
            const symbolFlags = getCombinedLocalAndExportSymbolFlags(symbol);
            let symbolKind = semanticMeaning & 1 /* Value */ ? getSymbolKindOfConstructorPropertyMethodAccessorFunctionOrVar(typeChecker, symbol, location) : "" /* unknown */;
            let hasAddedSymbolInfo = false;
            const isThisExpression = location.kind === 110 /* ThisKeyword */ && isInExpressionContext(location) || isThisInTypeQuery(location);
            let documentationFromAlias;
            let tagsFromAlias;
            let hasMultipleSignatures = false;
            if (location.kind === 110 /* ThisKeyword */ && !isThisExpression) {
                return { displayParts: [keywordPart(110 /* ThisKeyword */)], documentation: [], symbolKind: "primitive type" /* primitiveType */, tags: void 0 };
            }
            if (symbolKind !== "" /* unknown */ || symbolFlags & 32 /* Class */ || symbolFlags & 2097152 /* Alias */) {
                if (symbolKind === "getter" /* memberGetAccessorElement */ || symbolKind === "setter" /* memberSetAccessorElement */) {
                    const declaration = find(symbol.declarations, (declaration2) => declaration2.name === location);
                    if (declaration) {
                        switch (declaration.kind) {
                            case 177 /* GetAccessor */:
                                symbolKind = "getter" /* memberGetAccessorElement */;
                                break;
                            case 178 /* SetAccessor */:
                                symbolKind = "setter" /* memberSetAccessorElement */;
                                break;
                            case 172 /* PropertyDeclaration */:
                                symbolKind = "accessor" /* memberAccessorVariableElement */;
                                break;
                            default:
                                Debug.assertNever(declaration);
                        }
                    }
                    else {
                        symbolKind = "property" /* memberVariableElement */;
                    }
                }
                let signature;
                type ?? (type = isThisExpression ? typeChecker.getTypeAtLocation(location) : typeChecker.getTypeOfSymbolAtLocation(symbol, location));
                if (location.parent && location.parent.kind === 211 /* PropertyAccessExpression */) {
                    const right = location.parent.name;
                    if (right === location || right && right.getFullWidth() === 0) {
                        location = location.parent;
                    }
                }
                let callExpressionLike;
                if (isCallOrNewExpression(location)) {
                    callExpressionLike = location;
                }
                else if (isCallExpressionTarget(location) || isNewExpressionTarget(location)) {
                    callExpressionLike = location.parent;
                }
                else if (location.parent && (isJsxOpeningLikeElement(location.parent) || isTaggedTemplateExpression(location.parent)) && isFunctionLike(symbol.valueDeclaration)) {
                    callExpressionLike = location.parent;
                }
                if (callExpressionLike) {
                    signature = typeChecker.getResolvedSignature(callExpressionLike);
                    const useConstructSignatures = callExpressionLike.kind === 214 /* NewExpression */ || isCallExpression(callExpressionLike) && callExpressionLike.expression.kind === 108 /* SuperKeyword */;
                    const allSignatures = useConstructSignatures ? type.getConstructSignatures() : type.getCallSignatures();
                    if (signature && !contains(allSignatures, signature.target) && !contains(allSignatures, signature)) {
                        signature = allSignatures.length ? allSignatures[0] : void 0;
                    }
                    if (signature) {
                        if (useConstructSignatures && symbolFlags & 32 /* Class */) {
                            symbolKind = "constructor" /* constructorImplementationElement */;
                            addPrefixForAnyFunctionOrVar(type.symbol, symbolKind);
                        }
                        else if (symbolFlags & 2097152 /* Alias */) {
                            symbolKind = "alias" /* alias */;
                            pushSymbolKind(symbolKind);
                            displayParts.push(spacePart());
                            if (useConstructSignatures) {
                                if (signature.flags & 4 /* Abstract */) {
                                    displayParts.push(keywordPart(128 /* AbstractKeyword */));
                                    displayParts.push(spacePart());
                                }
                                displayParts.push(keywordPart(105 /* NewKeyword */));
                                displayParts.push(spacePart());
                            }
                            addFullSymbolName(symbol);
                        }
                        else {
                            addPrefixForAnyFunctionOrVar(symbol, symbolKind);
                        }
                        switch (symbolKind) {
                            case "JSX attribute" /* jsxAttribute */:
                            case "property" /* memberVariableElement */:
                            case "var" /* variableElement */:
                            case "const" /* constElement */:
                            case "let" /* letElement */:
                            case "parameter" /* parameterElement */:
                            case "local var" /* localVariableElement */:
                                displayParts.push(punctuationPart(59 /* ColonToken */));
                                displayParts.push(spacePart());
                                if (!(getObjectFlags(type) & 16 /* Anonymous */) && type.symbol) {
                                    addRange(displayParts, symbolToDisplayParts(typeChecker, type.symbol, enclosingDeclaration, 
                                    /*meaning*/
                                    void 0, 4 /* AllowAnyNodeKind */ | 1 /* WriteTypeParametersOrArguments */));
                                    displayParts.push(lineBreakPart());
                                }
                                if (useConstructSignatures) {
                                    if (signature.flags & 4 /* Abstract */) {
                                        displayParts.push(keywordPart(128 /* AbstractKeyword */));
                                        displayParts.push(spacePart());
                                    }
                                    displayParts.push(keywordPart(105 /* NewKeyword */));
                                    displayParts.push(spacePart());
                                }
                                addSignatureDisplayParts(signature, allSignatures, 262144 /* WriteArrowStyleSignature */);
                                break;
                            default:
                                addSignatureDisplayParts(signature, allSignatures);
                        }
                        hasAddedSymbolInfo = true;
                        hasMultipleSignatures = allSignatures.length > 1;
                    }
                }
                else if (isNameOfFunctionDeclaration(location) && !(symbolFlags & 98304 /* Accessor */) || // name of function declaration
                    location.kind === 137 /* ConstructorKeyword */ && location.parent.kind === 176 /* Constructor */) {
                    const functionDeclaration = location.parent;
                    const locationIsSymbolDeclaration = symbol.declarations && find(symbol.declarations, (declaration) => declaration === (location.kind === 137 /* ConstructorKeyword */ ? functionDeclaration.parent : functionDeclaration));
                    if (locationIsSymbolDeclaration) {
                        const allSignatures = functionDeclaration.kind === 176 /* Constructor */ ? type.getNonNullableType().getConstructSignatures() : type.getNonNullableType().getCallSignatures();
                        if (!typeChecker.isImplementationOfOverload(functionDeclaration)) {
                            signature = typeChecker.getSignatureFromDeclaration(functionDeclaration);
                        }
                        else {
                            signature = allSignatures[0];
                        }
                        if (functionDeclaration.kind === 176 /* Constructor */) {
                            symbolKind = "constructor" /* constructorImplementationElement */;
                            addPrefixForAnyFunctionOrVar(type.symbol, symbolKind);
                        }
                        else {
                            addPrefixForAnyFunctionOrVar(functionDeclaration.kind === 179 /* CallSignature */ && !(type.symbol.flags & 2048 /* TypeLiteral */ || type.symbol.flags & 4096 /* ObjectLiteral */) ? type.symbol : symbol, symbolKind);
                        }
                        if (signature) {
                            addSignatureDisplayParts(signature, allSignatures);
                        }
                        hasAddedSymbolInfo = true;
                        hasMultipleSignatures = allSignatures.length > 1;
                    }
                }
            }
            if (symbolFlags & 32 /* Class */ && !hasAddedSymbolInfo && !isThisExpression) {
                addAliasPrefixIfNecessary();
                if (getDeclarationOfKind(symbol, 231 /* ClassExpression */)) {
                    pushSymbolKind("local class" /* localClassElement */);
                }
                else {
                    displayParts.push(keywordPart(86 /* ClassKeyword */));
                }
                displayParts.push(spacePart());
                addFullSymbolName(symbol);
                writeTypeParametersOfSymbol(symbol, sourceFile);
            }
            if (symbolFlags & 64 /* Interface */ && semanticMeaning & 2 /* Type */) {
                prefixNextMeaning();
                displayParts.push(keywordPart(120 /* InterfaceKeyword */));
                displayParts.push(spacePart());
                addFullSymbolName(symbol);
                writeTypeParametersOfSymbol(symbol, sourceFile);
            }
            if (symbolFlags & 524288 /* TypeAlias */ && semanticMeaning & 2 /* Type */) {
                prefixNextMeaning();
                displayParts.push(keywordPart(156 /* TypeKeyword */));
                displayParts.push(spacePart());
                addFullSymbolName(symbol);
                writeTypeParametersOfSymbol(symbol, sourceFile);
                displayParts.push(spacePart());
                displayParts.push(operatorPart(64 /* EqualsToken */));
                displayParts.push(spacePart());
                addRange(displayParts, typeToDisplayParts(typeChecker, location.parent && isConstTypeReference(location.parent) ? typeChecker.getTypeAtLocation(location.parent) : typeChecker.getDeclaredTypeOfSymbol(symbol), enclosingDeclaration, 8388608 /* InTypeAlias */));
            }
            if (symbolFlags & 384 /* Enum */) {
                prefixNextMeaning();
                if (some(symbol.declarations, (d) => isEnumDeclaration(d) && isEnumConst(d))) {
                    displayParts.push(keywordPart(87 /* ConstKeyword */));
                    displayParts.push(spacePart());
                }
                displayParts.push(keywordPart(94 /* EnumKeyword */));
                displayParts.push(spacePart());
                addFullSymbolName(symbol);
            }
            if (symbolFlags & 1536 /* Module */ && !isThisExpression) {
                prefixNextMeaning();
                const declaration = getDeclarationOfKind(symbol, 267 /* ModuleDeclaration */);
                const isNamespace = declaration && declaration.name && declaration.name.kind === 80 /* Identifier */;
                displayParts.push(keywordPart(isNamespace ? 145 /* NamespaceKeyword */ : 144 /* ModuleKeyword */));
                displayParts.push(spacePart());
                addFullSymbolName(symbol);
            }
            if (symbolFlags & 262144 /* TypeParameter */ && semanticMeaning & 2 /* Type */) {
                prefixNextMeaning();
                displayParts.push(punctuationPart(21 /* OpenParenToken */));
                displayParts.push(textPart("type parameter"));
                displayParts.push(punctuationPart(22 /* CloseParenToken */));
                displayParts.push(spacePart());
                addFullSymbolName(symbol);
                if (symbol.parent) {
                    addInPrefix();
                    addFullSymbolName(symbol.parent, enclosingDeclaration);
                    writeTypeParametersOfSymbol(symbol.parent, enclosingDeclaration);
                }
                else {
                    const decl = getDeclarationOfKind(symbol, 168 /* TypeParameter */);
                    if (decl === void 0)
                        return Debug.fail();
                    const declaration = decl.parent;
                    if (declaration) {
                        if (isFunctionLike(declaration)) {
                            addInPrefix();
                            const signature = typeChecker.getSignatureFromDeclaration(declaration);
                            if (declaration.kind === 180 /* ConstructSignature */) {
                                displayParts.push(keywordPart(105 /* NewKeyword */));
                                displayParts.push(spacePart());
                            }
                            else if (declaration.kind !== 179 /* CallSignature */ && declaration.name) {
                                addFullSymbolName(declaration.symbol);
                            }
                            addRange(displayParts, signatureToDisplayParts(typeChecker, signature, sourceFile, 32 /* WriteTypeArgumentsOfSignature */));
                        }
                        else if (isTypeAliasDeclaration(declaration)) {
                            addInPrefix();
                            displayParts.push(keywordPart(156 /* TypeKeyword */));
                            displayParts.push(spacePart());
                            addFullSymbolName(declaration.symbol);
                            writeTypeParametersOfSymbol(declaration.symbol, sourceFile);
                        }
                    }
                }
            }
            if (symbolFlags & 8 /* EnumMember */) {
                symbolKind = "enum member" /* enumMemberElement */;
                addPrefixForAnyFunctionOrVar(symbol, "enum member");
                const declaration = (_a = symbol.declarations) == null ? void 0 : _a[0];
                if ((declaration == null ? void 0 : declaration.kind) === 306 /* EnumMember */) {
                    const constantValue = typeChecker.getConstantValue(declaration);
                    if (constantValue !== void 0) {
                        displayParts.push(spacePart());
                        displayParts.push(operatorPart(64 /* EqualsToken */));
                        displayParts.push(spacePart());
                        displayParts.push(displayPart(getTextOfConstantValue(constantValue), typeof constantValue === "number" ? 7 /* numericLiteral */ : 8 /* stringLiteral */));
                    }
                }
            }
            if (symbol.flags & 2097152 /* Alias */) {
                prefixNextMeaning();
                if (!hasAddedSymbolInfo || documentation.length === 0 && tags.length === 0) {
                    const resolvedSymbol = typeChecker.getAliasedSymbol(symbol);
                    if (resolvedSymbol !== symbol && resolvedSymbol.declarations && resolvedSymbol.declarations.length > 0) {
                        const resolvedNode = resolvedSymbol.declarations[0];
                        const declarationName = getNameOfDeclaration(resolvedNode);
                        if (declarationName && !hasAddedSymbolInfo) {
                            const isExternalModuleDeclaration = isModuleWithStringLiteralName(resolvedNode) && hasSyntacticModifier(resolvedNode, 128 /* Ambient */);
                            const shouldUseAliasName = symbol.name !== "default" && !isExternalModuleDeclaration;
                            const resolvedInfo = getSymbolDisplayPartsDocumentationAndSymbolKindWorker(typeChecker, resolvedSymbol, getSourceFileOfNode(resolvedNode), resolvedNode, declarationName, type, semanticMeaning, shouldUseAliasName ? symbol : resolvedSymbol);
                            displayParts.push(...resolvedInfo.displayParts);
                            displayParts.push(lineBreakPart());
                            documentationFromAlias = resolvedInfo.documentation;
                            tagsFromAlias = resolvedInfo.tags;
                        }
                        else {
                            documentationFromAlias = resolvedSymbol.getContextualDocumentationComment(resolvedNode, typeChecker);
                            tagsFromAlias = resolvedSymbol.getJsDocTags(typeChecker);
                        }
                    }
                }
                if (symbol.declarations) {
                    switch (symbol.declarations[0].kind) {
                        case 270 /* NamespaceExportDeclaration */:
                            displayParts.push(keywordPart(95 /* ExportKeyword */));
                            displayParts.push(spacePart());
                            displayParts.push(keywordPart(145 /* NamespaceKeyword */));
                            break;
                        case 277 /* ExportAssignment */:
                            displayParts.push(keywordPart(95 /* ExportKeyword */));
                            displayParts.push(spacePart());
                            displayParts.push(keywordPart(symbol.declarations[0].isExportEquals ? 64 /* EqualsToken */ : 90 /* DefaultKeyword */));
                            break;
                        case 281 /* ExportSpecifier */:
                            displayParts.push(keywordPart(95 /* ExportKeyword */));
                            break;
                        default:
                            displayParts.push(keywordPart(102 /* ImportKeyword */));
                    }
                }
                displayParts.push(spacePart());
                addFullSymbolName(symbol);
                forEach(symbol.declarations, (declaration) => {
                    if (declaration.kind === 271 /* ImportEqualsDeclaration */) {
                        const importEqualsDeclaration = declaration;
                        if (isExternalModuleImportEqualsDeclaration(importEqualsDeclaration)) {
                            displayParts.push(spacePart());
                            displayParts.push(operatorPart(64 /* EqualsToken */));
                            displayParts.push(spacePart());
                            displayParts.push(keywordPart(149 /* RequireKeyword */));
                            displayParts.push(punctuationPart(21 /* OpenParenToken */));
                            displayParts.push(displayPart(getTextOfNode(getExternalModuleImportEqualsDeclarationExpression(importEqualsDeclaration)), 8 /* stringLiteral */));
                            displayParts.push(punctuationPart(22 /* CloseParenToken */));
                        }
                        else {
                            const internalAliasSymbol = typeChecker.getSymbolAtLocation(importEqualsDeclaration.moduleReference);
                            if (internalAliasSymbol) {
                                displayParts.push(spacePart());
                                displayParts.push(operatorPart(64 /* EqualsToken */));
                                displayParts.push(spacePart());
                                addFullSymbolName(internalAliasSymbol, enclosingDeclaration);
                            }
                        }
                        return true;
                    }
                });
            }
            if (!hasAddedSymbolInfo) {
                if (symbolKind !== "" /* unknown */) {
                    if (type) {
                        if (isThisExpression) {
                            prefixNextMeaning();
                            displayParts.push(keywordPart(110 /* ThisKeyword */));
                        }
                        else {
                            addPrefixForAnyFunctionOrVar(symbol, symbolKind);
                        }
                        if (symbolKind === "property" /* memberVariableElement */ || symbolKind === "accessor" /* memberAccessorVariableElement */ || symbolKind === "getter" /* memberGetAccessorElement */ || symbolKind === "setter" /* memberSetAccessorElement */ || symbolKind === "JSX attribute" /* jsxAttribute */ || symbolFlags & 3 /* Variable */ || symbolKind === "local var" /* localVariableElement */ || symbolKind === "index" /* indexSignatureElement */ || symbolKind === "using" /* variableUsingElement */ || symbolKind === "await using" /* variableAwaitUsingElement */ || isThisExpression) {
                            displayParts.push(punctuationPart(59 /* ColonToken */));
                            displayParts.push(spacePart());
                            if (type.symbol && type.symbol.flags & 262144 /* TypeParameter */ && symbolKind !== "index" /* indexSignatureElement */) {
                                const typeParameterParts = mapToDisplayParts((writer) => {
                                    const param = typeChecker.typeParameterToDeclaration(type, enclosingDeclaration, symbolDisplayNodeBuilderFlags);
                                    getPrinter().writeNode(4 /* Unspecified */, param, getSourceFileOfNode(getParseTreeNode(enclosingDeclaration)), writer);
                                });
                                addRange(displayParts, typeParameterParts);
                            }
                            else {
                                addRange(displayParts, typeToDisplayParts(typeChecker, type, enclosingDeclaration));
                            }
                            if (isTransientSymbol(symbol) && symbol.links.target && isTransientSymbol(symbol.links.target) && symbol.links.target.links.tupleLabelDeclaration) {
                                const labelDecl = symbol.links.target.links.tupleLabelDeclaration;
                                Debug.assertNode(labelDecl.name, isIdentifier);
                                displayParts.push(spacePart());
                                displayParts.push(punctuationPart(21 /* OpenParenToken */));
                                displayParts.push(textPart(idText(labelDecl.name)));
                                displayParts.push(punctuationPart(22 /* CloseParenToken */));
                            }
                        }
                        else if (symbolFlags & 16 /* Function */ || symbolFlags & 8192 /* Method */ || symbolFlags & 16384 /* Constructor */ || symbolFlags & 131072 /* Signature */ || symbolFlags & 98304 /* Accessor */ || symbolKind === "method" /* memberFunctionElement */) {
                            const allSignatures = type.getNonNullableType().getCallSignatures();
                            if (allSignatures.length) {
                                addSignatureDisplayParts(allSignatures[0], allSignatures);
                                hasMultipleSignatures = allSignatures.length > 1;
                            }
                        }
                    }
                }
                else {
                    symbolKind = getSymbolKind(typeChecker, symbol, location);
                }
            }
            if (documentation.length === 0 && !hasMultipleSignatures) {
                documentation = symbol.getContextualDocumentationComment(enclosingDeclaration, typeChecker);
            }
            if (documentation.length === 0 && symbolFlags & 4 /* Property */) {
                if (symbol.parent && symbol.declarations && forEach(symbol.parent.declarations, (declaration) => declaration.kind === 312 /* SourceFile */)) {
                    for (const declaration of symbol.declarations) {
                        if (!declaration.parent || declaration.parent.kind !== 226 /* BinaryExpression */) {
                            continue;
                        }
                        const rhsSymbol = typeChecker.getSymbolAtLocation(declaration.parent.right);
                        if (!rhsSymbol) {
                            continue;
                        }
                        documentation = rhsSymbol.getDocumentationComment(typeChecker);
                        tags = rhsSymbol.getJsDocTags(typeChecker);
                        if (documentation.length > 0) {
                            break;
                        }
                    }
                }
            }
            if (documentation.length === 0 && isIdentifier(location) && symbol.valueDeclaration && isBindingElement(symbol.valueDeclaration)) {
                const declaration = symbol.valueDeclaration;
                const parent2 = declaration.parent;
                const name = declaration.propertyName || declaration.name;
                if (isIdentifier(name) && isObjectBindingPattern(parent2)) {
                    const propertyName = getTextOfIdentifierOrLiteral(name);
                    const objectType = typeChecker.getTypeAtLocation(parent2);
                    documentation = firstDefined(objectType.isUnion() ? objectType.types : [objectType], (t) => {
                        const prop = t.getProperty(propertyName);
                        return prop ? prop.getDocumentationComment(typeChecker) : void 0;
                    }) || emptyArray;
                }
            }
            if (tags.length === 0 && !hasMultipleSignatures) {
                tags = symbol.getContextualJsDocTags(enclosingDeclaration, typeChecker);
            }
            if (documentation.length === 0 && documentationFromAlias) {
                documentation = documentationFromAlias;
            }
            if (tags.length === 0 && tagsFromAlias) {
                tags = tagsFromAlias;
            }
            return { displayParts, documentation, symbolKind, tags: tags.length === 0 ? void 0 : tags };
            function getPrinter() {
                return createPrinterWithRemoveComments();
            }
            function prefixNextMeaning() {
                if (displayParts.length) {
                    displayParts.push(lineBreakPart());
                }
                addAliasPrefixIfNecessary();
            }
            function addAliasPrefixIfNecessary() {
                if (alias) {
                    pushSymbolKind("alias" /* alias */);
                    displayParts.push(spacePart());
                }
            }
            function addInPrefix() {
                displayParts.push(spacePart());
                displayParts.push(keywordPart(103 /* InKeyword */));
                displayParts.push(spacePart());
            }
            function addFullSymbolName(symbolToDisplay, enclosingDeclaration2) {
                let indexInfos;
                if (alias && symbolToDisplay === symbol) {
                    symbolToDisplay = alias;
                }
                if (symbolKind === "index" /* indexSignatureElement */) {
                    indexInfos = typeChecker.getIndexInfosOfIndexSymbol(symbolToDisplay);
                }
                let fullSymbolDisplayParts = [];
                if (symbolToDisplay.flags & 131072 /* Signature */ && indexInfos) {
                    if (symbolToDisplay.parent) {
                        fullSymbolDisplayParts = symbolToDisplayParts(typeChecker, symbolToDisplay.parent);
                    }
                    fullSymbolDisplayParts.push(punctuationPart(23 /* OpenBracketToken */));
                    indexInfos.forEach((info, i) => {
                        fullSymbolDisplayParts.push(...typeToDisplayParts(typeChecker, info.keyType));
                        if (i !== indexInfos.length - 1) {
                            fullSymbolDisplayParts.push(spacePart());
                            fullSymbolDisplayParts.push(punctuationPart(52 /* BarToken */));
                            fullSymbolDisplayParts.push(spacePart());
                        }
                    });
                    fullSymbolDisplayParts.push(punctuationPart(24 /* CloseBracketToken */));
                }
                else {
                    fullSymbolDisplayParts = symbolToDisplayParts(typeChecker, symbolToDisplay, enclosingDeclaration2 || sourceFile, 
                    /*meaning*/
                    void 0, 1 /* WriteTypeParametersOrArguments */ | 2 /* UseOnlyExternalAliasing */ | 4 /* AllowAnyNodeKind */);
                }
                addRange(displayParts, fullSymbolDisplayParts);
                if (symbol.flags & 16777216 /* Optional */) {
                    displayParts.push(punctuationPart(58 /* QuestionToken */));
                }
            }
            function addPrefixForAnyFunctionOrVar(symbol2, symbolKind2) {
                prefixNextMeaning();
                if (symbolKind2) {
                    pushSymbolKind(symbolKind2);
                    if (symbol2 && !some(symbol2.declarations, (d) => isArrowFunction(d) || (isFunctionExpression(d) || isClassExpression(d)) && !d.name)) {
                        displayParts.push(spacePart());
                        addFullSymbolName(symbol2);
                    }
                }
            }
            function pushSymbolKind(symbolKind2) {
                switch (symbolKind2) {
                    case "var" /* variableElement */:
                    case "function" /* functionElement */:
                    case "let" /* letElement */:
                    case "const" /* constElement */:
                    case "constructor" /* constructorImplementationElement */:
                    case "using" /* variableUsingElement */:
                    case "await using" /* variableAwaitUsingElement */:
                        displayParts.push(textOrKeywordPart(symbolKind2));
                        return;
                    default:
                        displayParts.push(punctuationPart(21 /* OpenParenToken */));
                        displayParts.push(textOrKeywordPart(symbolKind2));
                        displayParts.push(punctuationPart(22 /* CloseParenToken */));
                        return;
                }
            }
            function addSignatureDisplayParts(signature, allSignatures, flags = 0 /* None */) {
                addRange(displayParts, signatureToDisplayParts(typeChecker, signature, enclosingDeclaration, flags | 32 /* WriteTypeArgumentsOfSignature */));
                if (allSignatures.length > 1) {
                    displayParts.push(spacePart());
                    displayParts.push(punctuationPart(21 /* OpenParenToken */));
                    displayParts.push(operatorPart(40 /* PlusToken */));
                    displayParts.push(displayPart((allSignatures.length - 1).toString(), 7 /* numericLiteral */));
                    displayParts.push(spacePart());
                    displayParts.push(textPart(allSignatures.length === 2 ? "overload" : "overloads"));
                    displayParts.push(punctuationPart(22 /* CloseParenToken */));
                }
                documentation = signature.getDocumentationComment(typeChecker);
                tags = signature.getJsDocTags();
                if (allSignatures.length > 1 && documentation.length === 0 && tags.length === 0) {
                    documentation = allSignatures[0].getDocumentationComment(typeChecker);
                    tags = allSignatures[0].getJsDocTags().filter((tag) => tag.name !== "deprecated");
                }
            }
            function writeTypeParametersOfSymbol(symbol2, enclosingDeclaration2) {
                const typeParameterParts = mapToDisplayParts((writer) => {
                    const params = typeChecker.symbolToTypeParameterDeclarations(symbol2, enclosingDeclaration2, symbolDisplayNodeBuilderFlags);
                    getPrinter().writeList(53776 /* TypeParameters */, params, getSourceFileOfNode(getParseTreeNode(enclosingDeclaration2)), writer);
                });
                addRange(displayParts, typeParameterParts);
            }
        }
        function getSymbolDisplayPartsDocumentationAndSymbolKind(typeChecker, symbol, sourceFile, enclosingDeclaration, location, semanticMeaning = getMeaningFromLocation(location), alias) {
            return getSymbolDisplayPartsDocumentationAndSymbolKindWorker(typeChecker, symbol, sourceFile, enclosingDeclaration, location, 
            /*type*/
            void 0, semanticMeaning, alias);
        }
        function isLocalVariableOrFunction(symbol) {
            if (symbol.parent) {
                return false;
            }
            return forEach(symbol.declarations, (declaration) => {
                if (declaration.kind === 218 /* FunctionExpression */) {
                    return true;
                }
                if (declaration.kind !== 260 /* VariableDeclaration */ && declaration.kind !== 262 /* FunctionDeclaration */) {
                    return false;
                }
                for (let parent2 = declaration.parent; !isFunctionBlock(parent2); parent2 = parent2.parent) {
                    if (parent2.kind === 312 /* SourceFile */ || parent2.kind === 268 /* ModuleBlock */) {
                        return false;
                    }
                }
                return true;
            });
        }
        var symbolDisplayNodeBuilderFlags;
        var init_symbolDisplay = __esm({
            "src/services/symbolDisplay.ts"() {
                "use strict";
                init_ts4();
                symbolDisplayNodeBuilderFlags = 8192 /* OmitParameterModifiers */ | 70221824 /* IgnoreErrors */ | 16384 /* UseAliasDefinedOutsideCurrentScope */;
            }
        });
        // src/services/_namespaces/ts.SymbolDisplay.ts
        var ts_SymbolDisplay_exports = {};
        __export(ts_SymbolDisplay_exports, {
            getSymbolDisplayPartsDocumentationAndSymbolKind: () => getSymbolDisplayPartsDocumentationAndSymbolKind,
            getSymbolKind: () => getSymbolKind,
            getSymbolModifiers: () => getSymbolModifiers
        });
        var init_ts_SymbolDisplay = __esm({
            "src/services/_namespaces/ts.SymbolDisplay.ts"() {
                "use strict";
                init_symbolDisplay();
            }
        });
        // src/services/textChanges.ts
        function getPos2(n) {
            const result = n.__pos;
            Debug.assert(typeof result === "number");
            return result;
        }
        function setPos(n, pos) {
            Debug.assert(typeof pos === "number");
            n.__pos = pos;
        }
        function getEnd(n) {
            const result = n.__end;
            Debug.assert(typeof result === "number");
            return result;
        }
        function setEnd(n, end) {
            Debug.assert(typeof end === "number");
            n.__end = end;
        }
        function skipWhitespacesAndLineBreaks(text, start) {
            return skipTrivia(text, start, 
            /*stopAfterLineBreak*/
            false, 
            /*stopAtComments*/
            true);
        }
        function hasCommentsBeforeLineBreak(text, start) {
            let i = start;
            while (i < text.length) {
                const ch = text.charCodeAt(i);
                if (isWhiteSpaceSingleLine(ch)) {
                    i++;
                    continue;
                }
                return ch === 47 /* slash */;
            }
            return false;
        }
        function getAdjustedRange(sourceFile, startNode2, endNode2, options) {
            return { pos: getAdjustedStartPosition(sourceFile, startNode2, options), end: getAdjustedEndPosition(sourceFile, endNode2, options) };
        }
        function getAdjustedStartPosition(sourceFile, node, options, hasTrailingComment = false) {
            var _a, _b;
            const { leadingTriviaOption } = options;
            if (leadingTriviaOption === 0 /* Exclude */) {
                return node.getStart(sourceFile);
            }
            if (leadingTriviaOption === 3 /* StartLine */) {
                const startPos = node.getStart(sourceFile);
                const pos = getLineStartPositionForPosition(startPos, sourceFile);
                return rangeContainsPosition(node, pos) ? pos : startPos;
            }
            if (leadingTriviaOption === 2 /* JSDoc */) {
                const JSDocComments = getJSDocCommentRanges(node, sourceFile.text);
                if (JSDocComments == null ? void 0 : JSDocComments.length) {
                    return getLineStartPositionForPosition(JSDocComments[0].pos, sourceFile);
                }
            }
            const fullStart = node.getFullStart();
            const start = node.getStart(sourceFile);
            if (fullStart === start) {
                return start;
            }
            const fullStartLine = getLineStartPositionForPosition(fullStart, sourceFile);
            const startLine = getLineStartPositionForPosition(start, sourceFile);
            if (startLine === fullStartLine) {
                return leadingTriviaOption === 1 /* IncludeAll */ ? fullStart : start;
            }
            if (hasTrailingComment) {
                const comment = ((_a = getLeadingCommentRanges(sourceFile.text, fullStart)) == null ? void 0 : _a[0]) || ((_b = getTrailingCommentRanges(sourceFile.text, fullStart)) == null ? void 0 : _b[0]);
                if (comment) {
                    return skipTrivia(sourceFile.text, comment.end, 
                    /*stopAfterLineBreak*/
                    true, 
                    /*stopAtComments*/
                    true);
                }
            }
            const nextLineStart = fullStart > 0 ? 1 : 0;
            let adjustedStartPosition = getStartPositionOfLine(getLineOfLocalPosition(sourceFile, fullStartLine) + nextLineStart, sourceFile);
            adjustedStartPosition = skipWhitespacesAndLineBreaks(sourceFile.text, adjustedStartPosition);
            return getStartPositionOfLine(getLineOfLocalPosition(sourceFile, adjustedStartPosition), sourceFile);
        }
        function getEndPositionOfMultilineTrailingComment(sourceFile, node, options) {
            const { end } = node;
            const { trailingTriviaOption } = options;
            if (trailingTriviaOption === 2 /* Include */) {
                const comments = getTrailingCommentRanges(sourceFile.text, end);
                if (comments) {
                    const nodeEndLine = getLineOfLocalPosition(sourceFile, node.end);
                    for (const comment of comments) {
                        if (comment.kind === 2 /* SingleLineCommentTrivia */ || getLineOfLocalPosition(sourceFile, comment.pos) > nodeEndLine) {
                            break;
                        }
                        const commentEndLine = getLineOfLocalPosition(sourceFile, comment.end);
                        if (commentEndLine > nodeEndLine) {
                            return skipTrivia(sourceFile.text, comment.end, 
                            /*stopAfterLineBreak*/
                            true, 
                            /*stopAtComments*/
                            true);
                        }
                    }
                }
            }
            return void 0;
        }
        function getAdjustedEndPosition(sourceFile, node, options) {
            var _a;
            const { end } = node;
            const { trailingTriviaOption } = options;
            if (trailingTriviaOption === 0 /* Exclude */) {
                return end;
            }
            if (trailingTriviaOption === 1 /* ExcludeWhitespace */) {
                const comments = concatenate(getTrailingCommentRanges(sourceFile.text, end), getLeadingCommentRanges(sourceFile.text, end));
                const realEnd = (_a = comments == null ? void 0 : comments[comments.length - 1]) == null ? void 0 : _a.end;
                if (realEnd) {
                    return realEnd;
                }
                return end;
            }
            const multilineEndPosition = getEndPositionOfMultilineTrailingComment(sourceFile, node, options);
            if (multilineEndPosition) {
                return multilineEndPosition;
            }
            const newEnd = skipTrivia(sourceFile.text, end, 
            /*stopAfterLineBreak*/
            true);
            return newEnd !== end && (trailingTriviaOption === 2 /* Include */ || isLineBreak(sourceFile.text.charCodeAt(newEnd - 1))) ? newEnd : end;
        }
        function isSeparator(node, candidate) {
            return !!candidate && !!node.parent && (candidate.kind === 28 /* CommaToken */ || candidate.kind === 27 /* SemicolonToken */ && node.parent.kind === 210 /* ObjectLiteralExpression */);
        }
        function isThisTypeAnnotatable(containingFunction) {
            return isFunctionExpression(containingFunction) || isFunctionDeclaration(containingFunction);
        }
        function updateJSDocHost(parent2) {
            if (parent2.kind !== 219 /* ArrowFunction */) {
                return parent2;
            }
            const jsDocNode = parent2.parent.kind === 172 /* PropertyDeclaration */ ? parent2.parent : parent2.parent.parent;
            jsDocNode.jsDoc = parent2.jsDoc;
            return jsDocNode;
        }
        function tryMergeJsdocTags(oldTag, newTag) {
            if (oldTag.kind !== newTag.kind) {
                return void 0;
            }
            switch (oldTag.kind) {
                case 348 /* JSDocParameterTag */: {
                    const oldParam = oldTag;
                    const newParam = newTag;
                    return isIdentifier(oldParam.name) && isIdentifier(newParam.name) && oldParam.name.escapedText === newParam.name.escapedText ? factory.createJSDocParameterTag(
                    /*tagName*/
                    void 0, newParam.name, 
                    /*isBracketed*/
                    false, newParam.typeExpression, newParam.isNameFirst, oldParam.comment) : void 0;
                }
                case 349 /* JSDocReturnTag */:
                    return factory.createJSDocReturnTag(
                    /*tagName*/
                    void 0, newTag.typeExpression, oldTag.comment);
                case 351 /* JSDocTypeTag */:
                    return factory.createJSDocTypeTag(
                    /*tagName*/
                    void 0, newTag.typeExpression, oldTag.comment);
            }
        }
        function startPositionToDeleteNodeInList(sourceFile, node) {
            return skipTrivia(sourceFile.text, getAdjustedStartPosition(sourceFile, node, { leadingTriviaOption: 1 /* IncludeAll */ }), 
            /*stopAfterLineBreak*/
            false, 
            /*stopAtComments*/
            true);
        }
        function endPositionToDeleteNodeInList(sourceFile, node, prevNode, nextNode) {
            const end = startPositionToDeleteNodeInList(sourceFile, nextNode);
            if (prevNode === void 0 || positionsAreOnSameLine(getAdjustedEndPosition(sourceFile, node, {}), end, sourceFile)) {
                return end;
            }
            const token = findPrecedingToken(nextNode.getStart(sourceFile), sourceFile);
            if (isSeparator(node, token)) {
                const prevToken = findPrecedingToken(node.getStart(sourceFile), sourceFile);
                if (isSeparator(prevNode, prevToken)) {
                    const pos = skipTrivia(sourceFile.text, token.getEnd(), 
                    /*stopAfterLineBreak*/
                    true, 
                    /*stopAtComments*/
                    true);
                    if (positionsAreOnSameLine(prevToken.getStart(sourceFile), token.getStart(sourceFile), sourceFile)) {
                        return isLineBreak(sourceFile.text.charCodeAt(pos - 1)) ? pos - 1 : pos;
                    }
                    if (isLineBreak(sourceFile.text.charCodeAt(pos))) {
                        return pos;
                    }
                }
            }
            return end;
        }
        function getClassOrObjectBraceEnds(cls, sourceFile) {
            const open = findChildOfKind(cls, 19 /* OpenBraceToken */, sourceFile);
            const close = findChildOfKind(cls, 20 /* CloseBraceToken */, sourceFile);
            return [open == null ? void 0 : open.end, close == null ? void 0 : close.end];
        }
        function getMembersOrProperties(node) {
            return isObjectLiteralExpression(node) ? node.properties : node.members;
        }
        function applyChanges(text, changes) {
            for (let i = changes.length - 1; i >= 0; i--) {
                const { span, newText } = changes[i];
                text = `${text.substring(0, span.start)}${newText}${text.substring(textSpanEnd(span))}`;
            }
            return text;
        }
        function isTrivia2(s) {
            return skipTrivia(s, 0) === s.length;
        }
        function assignPositionsToNode(node) {
            const visited = visitEachChild(node, assignPositionsToNode, textChangesTransformationContext, assignPositionsToNodeArray, assignPositionsToNode);
            const newNode = nodeIsSynthesized(visited) ? visited : Object.create(visited);
            setTextRangePosEnd(newNode, getPos2(node), getEnd(node));
            return newNode;
        }
        function assignPositionsToNodeArray(nodes, visitor, test, start, count) {
            const visited = visitNodes2(nodes, visitor, test, start, count);
            if (!visited) {
                return visited;
            }
            Debug.assert(nodes);
            const nodeArray = visited === nodes ? factory.createNodeArray(visited.slice(0)) : visited;
            setTextRangePosEnd(nodeArray, getPos2(nodes), getEnd(nodes));
            return nodeArray;
        }
        function createWriter(newLine) {
            let lastNonTriviaPosition = 0;
            const writer = createTextWriter(newLine);
            const onBeforeEmitNode = (node) => {
                if (node) {
                    setPos(node, lastNonTriviaPosition);
                }
            };
            const onAfterEmitNode = (node) => {
                if (node) {
                    setEnd(node, lastNonTriviaPosition);
                }
            };
            const onBeforeEmitNodeArray = (nodes) => {
                if (nodes) {
                    setPos(nodes, lastNonTriviaPosition);
                }
            };
            const onAfterEmitNodeArray = (nodes) => {
                if (nodes) {
                    setEnd(nodes, lastNonTriviaPosition);
                }
            };
            const onBeforeEmitToken = (node) => {
                if (node) {
                    setPos(node, lastNonTriviaPosition);
                }
            };
            const onAfterEmitToken = (node) => {
                if (node) {
                    setEnd(node, lastNonTriviaPosition);
                }
            };
            function setLastNonTriviaPosition(s, force) {
                if (force || !isTrivia2(s)) {
                    lastNonTriviaPosition = writer.getTextPos();
                    let i = 0;
                    while (isWhiteSpaceLike(s.charCodeAt(s.length - i - 1))) {
                        i++;
                    }
                    lastNonTriviaPosition -= i;
                }
            }
            function write(s) {
                writer.write(s);
                setLastNonTriviaPosition(s, 
                /*force*/
                false);
            }
            function writeComment(s) {
                writer.writeComment(s);
            }
            function writeKeyword(s) {
                writer.writeKeyword(s);
                setLastNonTriviaPosition(s, 
                /*force*/
                false);
            }
            function writeOperator(s) {
                writer.writeOperator(s);
                setLastNonTriviaPosition(s, 
                /*force*/
                false);
            }
            function writePunctuation(s) {
                writer.writePunctuation(s);
                setLastNonTriviaPosition(s, 
                /*force*/
                false);
            }
            function writeTrailingSemicolon(s) {
                writer.writeTrailingSemicolon(s);
                setLastNonTriviaPosition(s, 
                /*force*/
                false);
            }
            function writeParameter(s) {
                writer.writeParameter(s);
                setLastNonTriviaPosition(s, 
                /*force*/
                false);
            }
            function writeProperty(s) {
                writer.writeProperty(s);
                setLastNonTriviaPosition(s, 
                /*force*/
                false);
            }
            function writeSpace(s) {
                writer.writeSpace(s);
                setLastNonTriviaPosition(s, 
                /*force*/
                false);
            }
            function writeStringLiteral(s) {
                writer.writeStringLiteral(s);
                setLastNonTriviaPosition(s, 
                /*force*/
                false);
            }
            function writeSymbol(s, sym) {
                writer.writeSymbol(s, sym);
                setLastNonTriviaPosition(s, 
                /*force*/
                false);
            }
            function writeLine(force) {
                writer.writeLine(force);
            }
            function increaseIndent() {
                writer.increaseIndent();
            }
            function decreaseIndent() {
                writer.decreaseIndent();
            }
            function getText() {
                return writer.getText();
            }
            function rawWrite(s) {
                writer.rawWrite(s);
                setLastNonTriviaPosition(s, 
                /*force*/
                false);
            }
            function writeLiteral(s) {
                writer.writeLiteral(s);
                setLastNonTriviaPosition(s, 
                /*force*/
                true);
            }
            function getTextPos() {
                return writer.getTextPos();
            }
            function getLine() {
                return writer.getLine();
            }
            function getColumn() {
                return writer.getColumn();
            }
            function getIndent() {
                return writer.getIndent();
            }
            function isAtStartOfLine() {
                return writer.isAtStartOfLine();
            }
            function clear2() {
                writer.clear();
                lastNonTriviaPosition = 0;
            }
            return {
                onBeforeEmitNode,
                onAfterEmitNode,
                onBeforeEmitNodeArray,
                onAfterEmitNodeArray,
                onBeforeEmitToken,
                onAfterEmitToken,
                write,
                writeComment,
                writeKeyword,
                writeOperator,
                writePunctuation,
                writeTrailingSemicolon,
                writeParameter,
                writeProperty,
                writeSpace,
                writeStringLiteral,
                writeSymbol,
                writeLine,
                increaseIndent,
                decreaseIndent,
                getText,
                rawWrite,
                writeLiteral,
                getTextPos,
                getLine,
                getColumn,
                getIndent,
                isAtStartOfLine,
                hasTrailingComment: () => writer.hasTrailingComment(),
                hasTrailingWhitespace: () => writer.hasTrailingWhitespace(),
                clear: clear2
            };
        }
        function getInsertionPositionAtSourceFileTop(sourceFile) {
            let lastPrologue;
            for (const node of sourceFile.statements) {
                if (isPrologueDirective(node)) {
                    lastPrologue = node;
                }
                else {
                    break;
                }
            }
            let position = 0;
            const text = sourceFile.text;
            if (lastPrologue) {
                position = lastPrologue.end;
                advancePastLineBreak();
                return position;
            }
            const shebang = getShebang(text);
            if (shebang !== void 0) {
                position = shebang.length;
                advancePastLineBreak();
            }
            const ranges = getLeadingCommentRanges(text, position);
            if (!ranges)
                return position;
            let lastComment;
            let firstNodeLine;
            for (const range of ranges) {
                if (range.kind === 3 /* MultiLineCommentTrivia */) {
                    if (isPinnedComment(text, range.pos)) {
                        lastComment = { range, pinnedOrTripleSlash: true };
                        continue;
                    }
                }
                else if (isRecognizedTripleSlashComment(text, range.pos, range.end)) {
                    lastComment = { range, pinnedOrTripleSlash: true };
                    continue;
                }
                if (lastComment) {
                    if (lastComment.pinnedOrTripleSlash)
                        break;
                    const commentLine = sourceFile.getLineAndCharacterOfPosition(range.pos).line;
                    const lastCommentEndLine = sourceFile.getLineAndCharacterOfPosition(lastComment.range.end).line;
                    if (commentLine >= lastCommentEndLine + 2)
                        break;
                }
                if (sourceFile.statements.length) {
                    if (firstNodeLine === void 0)
                        firstNodeLine = sourceFile.getLineAndCharacterOfPosition(sourceFile.statements[0].getStart()).line;
                    const commentEndLine = sourceFile.getLineAndCharacterOfPosition(range.end).line;
                    if (firstNodeLine < commentEndLine + 2)
                        break;
                }
                lastComment = { range, pinnedOrTripleSlash: false };
            }
            if (lastComment) {
                position = lastComment.range.end;
                advancePastLineBreak();
            }
            return position;
            function advancePastLineBreak() {
                if (position < text.length) {
                    const charCode = text.charCodeAt(position);
                    if (isLineBreak(charCode)) {
                        position++;
                        if (position < text.length && charCode === 13 /* carriageReturn */ && text.charCodeAt(position) === 10 /* lineFeed */) {
                            position++;
                        }
                    }
                }
            }
        }
        function isValidLocationToAddComment(sourceFile, position) {
            return !isInComment(sourceFile, position) && !isInString(sourceFile, position) && !isInTemplateString(sourceFile, position) && !isInJSXText(sourceFile, position);
        }
        function needSemicolonBetween(a, b) {
            return (isPropertySignature(a) || isPropertyDeclaration(a)) && isClassOrTypeElement(b) && b.name.kind === 167 /* ComputedPropertyName */ || isStatementButNotDeclaration(a) && isStatementButNotDeclaration(b);
        }
        function deleteNode(changes, sourceFile, node, options = { leadingTriviaOption: 1 /* IncludeAll */ }) {
            const startPosition = getAdjustedStartPosition(sourceFile, node, options);
            const endPosition = getAdjustedEndPosition(sourceFile, node, options);
            changes.deleteRange(sourceFile, { pos: startPosition, end: endPosition });
        }
        function deleteNodeInList(changes, deletedNodesInLists, sourceFile, node) {
            const containingList = Debug.checkDefined(ts_formatting_exports.SmartIndenter.getContainingList(node, sourceFile));
            const index = indexOfNode(containingList, node);
            Debug.assert(index !== -1);
            if (containingList.length === 1) {
                deleteNode(changes, sourceFile, node);
                return;
            }
            Debug.assert(!deletedNodesInLists.has(node), "Deleting a node twice");
            deletedNodesInLists.add(node);
            changes.deleteRange(sourceFile, {
                pos: startPositionToDeleteNodeInList(sourceFile, node),
                end: index === containingList.length - 1 ? getAdjustedEndPosition(sourceFile, node, {}) : endPositionToDeleteNodeInList(sourceFile, node, containingList[index - 1], containingList[index + 1])
            });
        }
        var LeadingTriviaOption, TrailingTriviaOption, useNonAdjustedPositions, ChangeTracker, changesToText, textChangesTransformationContext, deleteDeclaration;
        var init_textChanges = __esm({
            "src/services/textChanges.ts"() {
                "use strict";
                init_ts4();
                LeadingTriviaOption = /* @__PURE__ */ ((LeadingTriviaOption2) => {
                    LeadingTriviaOption2[LeadingTriviaOption2["Exclude"] = 0] = "Exclude";
                    LeadingTriviaOption2[LeadingTriviaOption2["IncludeAll"] = 1] = "IncludeAll";
                    LeadingTriviaOption2[LeadingTriviaOption2["JSDoc"] = 2] = "JSDoc";
                    LeadingTriviaOption2[LeadingTriviaOption2["StartLine"] = 3] = "StartLine";
                    return LeadingTriviaOption2;
                })(LeadingTriviaOption || {});
                TrailingTriviaOption = /* @__PURE__ */ ((TrailingTriviaOption2) => {
                    TrailingTriviaOption2[TrailingTriviaOption2["Exclude"] = 0] = "Exclude";
                    TrailingTriviaOption2[TrailingTriviaOption2["ExcludeWhitespace"] = 1] = "ExcludeWhitespace";
                    TrailingTriviaOption2[TrailingTriviaOption2["Include"] = 2] = "Include";
                    return TrailingTriviaOption2;
                })(TrailingTriviaOption || {});
                useNonAdjustedPositions = {
                    leadingTriviaOption: 0 /* Exclude */,
                    trailingTriviaOption: 0 /* Exclude */
                };
                ChangeTracker = class _ChangeTracker {
                    /** Public for tests only. Other callers should use `ChangeTracker.with`. */
                    constructor(newLineCharacter, formatContext) {
                        this.newLineCharacter = newLineCharacter;
                        this.formatContext = formatContext;
                        this.changes = [];
                        this.classesWithNodesInsertedAtStart = /* @__PURE__ */ new Map();
                        // Set<ClassDeclaration> implemented as Map<node id, ClassDeclaration>
                        this.deletedNodes = [];
                    }
                    static fromContext(context) {
                        return new _ChangeTracker(getNewLineOrDefaultFromHost(context.host, context.formatContext.options), context.formatContext);
                    }
                    static with(context, cb) {
                        const tracker = _ChangeTracker.fromContext(context);
                        cb(tracker);
                        return tracker.getChanges();
                    }
                    pushRaw(sourceFile, change) {
                        Debug.assertEqual(sourceFile.fileName, change.fileName);
                        for (const c of change.textChanges) {
                            this.changes.push({
                                kind: 3 /* Text */,
                                sourceFile,
                                text: c.newText,
                                range: createTextRangeFromSpan(c.span)
                            });
                        }
                    }
                    deleteRange(sourceFile, range) {
                        this.changes.push({ kind: 0 /* Remove */, sourceFile, range });
                    }
                    delete(sourceFile, node) {
                        this.deletedNodes.push({ sourceFile, node });
                    }
                    /** Stop! Consider using `delete` instead, which has logic for deleting nodes from delimited lists. */
                    deleteNode(sourceFile, node, options = { leadingTriviaOption: 1 /* IncludeAll */ }) {
                        this.deleteRange(sourceFile, getAdjustedRange(sourceFile, node, node, options));
                    }
                    deleteNodes(sourceFile, nodes, options = { leadingTriviaOption: 1 /* IncludeAll */ }, hasTrailingComment) {
                        for (const node of nodes) {
                            const pos = getAdjustedStartPosition(sourceFile, node, options, hasTrailingComment);
                            const end = getAdjustedEndPosition(sourceFile, node, options);
                            this.deleteRange(sourceFile, { pos, end });
                            hasTrailingComment = !!getEndPositionOfMultilineTrailingComment(sourceFile, node, options);
                        }
                    }
                    deleteModifier(sourceFile, modifier) {
                        this.deleteRange(sourceFile, { pos: modifier.getStart(sourceFile), end: skipTrivia(sourceFile.text, modifier.end, 
                            /*stopAfterLineBreak*/
                            true) });
                    }
                    deleteNodeRange(sourceFile, startNode2, endNode2, options = { leadingTriviaOption: 1 /* IncludeAll */ }) {
                        const startPosition = getAdjustedStartPosition(sourceFile, startNode2, options);
                        const endPosition = getAdjustedEndPosition(sourceFile, endNode2, options);
                        this.deleteRange(sourceFile, { pos: startPosition, end: endPosition });
                    }
                    deleteNodeRangeExcludingEnd(sourceFile, startNode2, afterEndNode, options = { leadingTriviaOption: 1 /* IncludeAll */ }) {
                        const startPosition = getAdjustedStartPosition(sourceFile, startNode2, options);
                        const endPosition = afterEndNode === void 0 ? sourceFile.text.length : getAdjustedStartPosition(sourceFile, afterEndNode, options);
                        this.deleteRange(sourceFile, { pos: startPosition, end: endPosition });
                    }
                    replaceRange(sourceFile, range, newNode, options = {}) {
                        this.changes.push({ kind: 1 /* ReplaceWithSingleNode */, sourceFile, range, options, node: newNode });
                    }
                    replaceNode(sourceFile, oldNode, newNode, options = useNonAdjustedPositions) {
                        this.replaceRange(sourceFile, getAdjustedRange(sourceFile, oldNode, oldNode, options), newNode, options);
                    }
                    replaceNodeRange(sourceFile, startNode2, endNode2, newNode, options = useNonAdjustedPositions) {
                        this.replaceRange(sourceFile, getAdjustedRange(sourceFile, startNode2, endNode2, options), newNode, options);
                    }
                    replaceRangeWithNodes(sourceFile, range, newNodes, options = {}) {
                        this.changes.push({ kind: 2 /* ReplaceWithMultipleNodes */, sourceFile, range, options, nodes: newNodes });
                    }
                    replaceNodeWithNodes(sourceFile, oldNode, newNodes, options = useNonAdjustedPositions) {
                        this.replaceRangeWithNodes(sourceFile, getAdjustedRange(sourceFile, oldNode, oldNode, options), newNodes, options);
                    }
                    replaceNodeWithText(sourceFile, oldNode, text) {
                        this.replaceRangeWithText(sourceFile, getAdjustedRange(sourceFile, oldNode, oldNode, useNonAdjustedPositions), text);
                    }
                    replaceNodeRangeWithNodes(sourceFile, startNode2, endNode2, newNodes, options = useNonAdjustedPositions) {
                        this.replaceRangeWithNodes(sourceFile, getAdjustedRange(sourceFile, startNode2, endNode2, options), newNodes, options);
                    }
                    nodeHasTrailingComment(sourceFile, oldNode, configurableEnd = useNonAdjustedPositions) {
                        return !!getEndPositionOfMultilineTrailingComment(sourceFile, oldNode, configurableEnd);
                    }
                    nextCommaToken(sourceFile, node) {
                        const next = findNextToken(node, node.parent, sourceFile);
                        return next && next.kind === 28 /* CommaToken */ ? next : void 0;
                    }
                    replacePropertyAssignment(sourceFile, oldNode, newNode) {
                        const suffix = this.nextCommaToken(sourceFile, oldNode) ? "" : "," + this.newLineCharacter;
                        this.replaceNode(sourceFile, oldNode, newNode, { suffix });
                    }
                    insertNodeAt(sourceFile, pos, newNode, options = {}) {
                        this.replaceRange(sourceFile, createRange(pos), newNode, options);
                    }
                    insertNodesAt(sourceFile, pos, newNodes, options = {}) {
                        this.replaceRangeWithNodes(sourceFile, createRange(pos), newNodes, options);
                    }
                    insertNodeAtTopOfFile(sourceFile, newNode, blankLineBetween) {
                        this.insertAtTopOfFile(sourceFile, newNode, blankLineBetween);
                    }
                    insertNodesAtTopOfFile(sourceFile, newNodes, blankLineBetween) {
                        this.insertAtTopOfFile(sourceFile, newNodes, blankLineBetween);
                    }
                    insertAtTopOfFile(sourceFile, insert, blankLineBetween) {
                        const pos = getInsertionPositionAtSourceFileTop(sourceFile);
                        const options = {
                            prefix: pos === 0 ? void 0 : this.newLineCharacter,
                            suffix: (isLineBreak(sourceFile.text.charCodeAt(pos)) ? "" : this.newLineCharacter) + (blankLineBetween ? this.newLineCharacter : "")
                        };
                        if (isArray(insert)) {
                            this.insertNodesAt(sourceFile, pos, insert, options);
                        }
                        else {
                            this.insertNodeAt(sourceFile, pos, insert, options);
                        }
                    }
                    insertNodesAtEndOfFile(sourceFile, newNodes, blankLineBetween) {
                        this.insertAtEndOfFile(sourceFile, newNodes, blankLineBetween);
                    }
                    insertAtEndOfFile(sourceFile, insert, blankLineBetween) {
                        const pos = sourceFile.end + 1;
                        const options = {
                            prefix: this.newLineCharacter,
                            suffix: this.newLineCharacter + (blankLineBetween ? this.newLineCharacter : "")
                        };
                        this.insertNodesAt(sourceFile, pos, insert, options);
                    }
                    insertStatementsInNewFile(fileName, statements, oldFile) {
                        if (!this.newFileChanges) {
                            this.newFileChanges = createMultiMap();
                        }
                        this.newFileChanges.add(fileName, { oldFile, statements });
                    }
                    insertFirstParameter(sourceFile, parameters, newParam) {
                        const p0 = firstOrUndefined(parameters);
                        if (p0) {
                            this.insertNodeBefore(sourceFile, p0, newParam);
                        }
                        else {
                            this.insertNodeAt(sourceFile, parameters.pos, newParam);
                        }
                    }
                    insertNodeBefore(sourceFile, before, newNode, blankLineBetween = false, options = {}) {
                        this.insertNodeAt(sourceFile, getAdjustedStartPosition(sourceFile, before, options), newNode, this.getOptionsForInsertNodeBefore(before, newNode, blankLineBetween));
                    }
                    insertNodesBefore(sourceFile, before, newNodes, blankLineBetween = false, options = {}) {
                        this.insertNodesAt(sourceFile, getAdjustedStartPosition(sourceFile, before, options), newNodes, this.getOptionsForInsertNodeBefore(before, first(newNodes), blankLineBetween));
                    }
                    insertModifierAt(sourceFile, pos, modifier, options = {}) {
                        this.insertNodeAt(sourceFile, pos, factory.createToken(modifier), options);
                    }
                    insertModifierBefore(sourceFile, modifier, before) {
                        return this.insertModifierAt(sourceFile, before.getStart(sourceFile), modifier, { suffix: " " });
                    }
                    insertCommentBeforeLine(sourceFile, lineNumber, position, commentText) {
                        const lineStartPosition = getStartPositionOfLine(lineNumber, sourceFile);
                        const startPosition = getFirstNonSpaceCharacterPosition(sourceFile.text, lineStartPosition);
                        const insertAtLineStart = isValidLocationToAddComment(sourceFile, startPosition);
                        const token = getTouchingToken(sourceFile, insertAtLineStart ? startPosition : position);
                        const indent3 = sourceFile.text.slice(lineStartPosition, startPosition);
                        const text = `${insertAtLineStart ? "" : this.newLineCharacter}//${commentText}${this.newLineCharacter}${indent3}`;
                        this.insertText(sourceFile, token.getStart(sourceFile), text);
                    }
                    insertJsdocCommentBefore(sourceFile, node, tag) {
                        const fnStart = node.getStart(sourceFile);
                        if (node.jsDoc) {
                            for (const jsdoc of node.jsDoc) {
                                this.deleteRange(sourceFile, {
                                    pos: getLineStartPositionForPosition(jsdoc.getStart(sourceFile), sourceFile),
                                    end: getAdjustedEndPosition(sourceFile, jsdoc, 
                                    /*options*/
                                    {})
                                });
                            }
                        }
                        const startPosition = getPrecedingNonSpaceCharacterPosition(sourceFile.text, fnStart - 1);
                        const indent3 = sourceFile.text.slice(startPosition, fnStart);
                        this.insertNodeAt(sourceFile, fnStart, tag, { suffix: this.newLineCharacter + indent3 });
                    }
                    createJSDocText(sourceFile, node) {
                        const comments = flatMap(node.jsDoc, (jsDoc2) => isString(jsDoc2.comment) ? factory.createJSDocText(jsDoc2.comment) : jsDoc2.comment);
                        const jsDoc = singleOrUndefined(node.jsDoc);
                        return jsDoc && positionsAreOnSameLine(jsDoc.pos, jsDoc.end, sourceFile) && length(comments) === 0 ? void 0 : factory.createNodeArray(intersperse(comments, factory.createJSDocText("\n")));
                    }
                    replaceJSDocComment(sourceFile, node, tags) {
                        this.insertJsdocCommentBefore(sourceFile, updateJSDocHost(node), factory.createJSDocComment(this.createJSDocText(sourceFile, node), factory.createNodeArray(tags)));
                    }
                    addJSDocTags(sourceFile, parent2, newTags) {
                        const oldTags = flatMapToMutable(parent2.jsDoc, (j) => j.tags);
                        const unmergedNewTags = newTags.filter((newTag) => !oldTags.some((tag, i) => {
                            const merged = tryMergeJsdocTags(tag, newTag);
                            if (merged)
                                oldTags[i] = merged;
                            return !!merged;
                        }));
                        this.replaceJSDocComment(sourceFile, parent2, [...oldTags, ...unmergedNewTags]);
                    }
                    filterJSDocTags(sourceFile, parent2, predicate) {
                        this.replaceJSDocComment(sourceFile, parent2, filter(flatMapToMutable(parent2.jsDoc, (j) => j.tags), predicate));
                    }
                    replaceRangeWithText(sourceFile, range, text) {
                        this.changes.push({ kind: 3 /* Text */, sourceFile, range, text });
                    }
                    insertText(sourceFile, pos, text) {
                        this.replaceRangeWithText(sourceFile, createRange(pos), text);
                    }
                    /** Prefer this over replacing a node with another that has a type annotation, as it avoids reformatting the other parts of the node. */
                    tryInsertTypeAnnotation(sourceFile, node, type) {
                        let endNode2;
                        if (isFunctionLike(node)) {
                            endNode2 = findChildOfKind(node, 22 /* CloseParenToken */, sourceFile);
                            if (!endNode2) {
                                if (!isArrowFunction(node))
                                    return false;
                                endNode2 = first(node.parameters);
                            }
                        }
                        else {
                            endNode2 = (node.kind === 260 /* VariableDeclaration */ ? node.exclamationToken : node.questionToken) ?? node.name;
                        }
                        this.insertNodeAt(sourceFile, endNode2.end, type, { prefix: ": " });
                        return true;
                    }
                    tryInsertThisTypeAnnotation(sourceFile, node, type) {
                        const start = findChildOfKind(node, 21 /* OpenParenToken */, sourceFile).getStart(sourceFile) + 1;
                        const suffix = node.parameters.length ? ", " : "";
                        this.insertNodeAt(sourceFile, start, type, { prefix: "this: ", suffix });
                    }
                    insertTypeParameters(sourceFile, node, typeParameters) {
                        const start = (findChildOfKind(node, 21 /* OpenParenToken */, sourceFile) || first(node.parameters)).getStart(sourceFile);
                        this.insertNodesAt(sourceFile, start, typeParameters, { prefix: "<", suffix: ">", joiner: ", " });
                    }
                    getOptionsForInsertNodeBefore(before, inserted, blankLineBetween) {
                        if (isStatement(before) || isClassElement(before)) {
                            return { suffix: blankLineBetween ? this.newLineCharacter + this.newLineCharacter : this.newLineCharacter };
                        }
                        else if (isVariableDeclaration(before)) {
                            return { suffix: ", " };
                        }
                        else if (isParameter(before)) {
                            return isParameter(inserted) ? { suffix: ", " } : {};
                        }
                        else if (isStringLiteral(before) && isImportDeclaration(before.parent) || isNamedImports(before)) {
                            return { suffix: ", " };
                        }
                        else if (isImportSpecifier(before)) {
                            return { suffix: "," + (blankLineBetween ? this.newLineCharacter : " ") };
                        }
                        return Debug.failBadSyntaxKind(before);
                    }
                    insertNodeAtConstructorStart(sourceFile, ctr, newStatement) {
                        const firstStatement = firstOrUndefined(ctr.body.statements);
                        if (!firstStatement || !ctr.body.multiLine) {
                            this.replaceConstructorBody(sourceFile, ctr, [newStatement, ...ctr.body.statements]);
                        }
                        else {
                            this.insertNodeBefore(sourceFile, firstStatement, newStatement);
                        }
                    }
                    insertNodeAtConstructorStartAfterSuperCall(sourceFile, ctr, newStatement) {
                        const superCallStatement = find(ctr.body.statements, (stmt) => isExpressionStatement(stmt) && isSuperCall(stmt.expression));
                        if (!superCallStatement || !ctr.body.multiLine) {
                            this.replaceConstructorBody(sourceFile, ctr, [...ctr.body.statements, newStatement]);
                        }
                        else {
                            this.insertNodeAfter(sourceFile, superCallStatement, newStatement);
                        }
                    }
                    insertNodeAtConstructorEnd(sourceFile, ctr, newStatement) {
                        const lastStatement = lastOrUndefined(ctr.body.statements);
                        if (!lastStatement || !ctr.body.multiLine) {
                            this.replaceConstructorBody(sourceFile, ctr, [...ctr.body.statements, newStatement]);
                        }
                        else {
                            this.insertNodeAfter(sourceFile, lastStatement, newStatement);
                        }
                    }
                    replaceConstructorBody(sourceFile, ctr, statements) {
                        this.replaceNode(sourceFile, ctr.body, factory.createBlock(statements, 
                        /*multiLine*/
                        true));
                    }
                    insertNodeAtEndOfScope(sourceFile, scope, newNode) {
                        const pos = getAdjustedStartPosition(sourceFile, scope.getLastToken(), {});
                        this.insertNodeAt(sourceFile, pos, newNode, {
                            prefix: isLineBreak(sourceFile.text.charCodeAt(scope.getLastToken().pos)) ? this.newLineCharacter : this.newLineCharacter + this.newLineCharacter,
                            suffix: this.newLineCharacter
                        });
                    }
                    insertMemberAtStart(sourceFile, node, newElement) {
                        this.insertNodeAtStartWorker(sourceFile, node, newElement);
                    }
                    insertNodeAtObjectStart(sourceFile, obj, newElement) {
                        this.insertNodeAtStartWorker(sourceFile, obj, newElement);
                    }
                    insertNodeAtStartWorker(sourceFile, node, newElement) {
                        const indentation = this.guessIndentationFromExistingMembers(sourceFile, node) ?? this.computeIndentationForNewMember(sourceFile, node);
                        this.insertNodeAt(sourceFile, getMembersOrProperties(node).pos, newElement, this.getInsertNodeAtStartInsertOptions(sourceFile, node, indentation));
                    }
                    /**
                     * Tries to guess the indentation from the existing members of a class/interface/object. All members must be on
                     * new lines and must share the same indentation.
                     */
                    guessIndentationFromExistingMembers(sourceFile, node) {
                        let indentation;
                        let lastRange = node;
                        for (const member of getMembersOrProperties(node)) {
                            if (rangeStartPositionsAreOnSameLine(lastRange, member, sourceFile)) {
                                return void 0;
                            }
                            const memberStart = member.getStart(sourceFile);
                            const memberIndentation = ts_formatting_exports.SmartIndenter.findFirstNonWhitespaceColumn(getLineStartPositionForPosition(memberStart, sourceFile), memberStart, sourceFile, this.formatContext.options);
                            if (indentation === void 0) {
                                indentation = memberIndentation;
                            }
                            else if (memberIndentation !== indentation) {
                                return void 0;
                            }
                            lastRange = member;
                        }
                        return indentation;
                    }
                    computeIndentationForNewMember(sourceFile, node) {
                        const nodeStart = node.getStart(sourceFile);
                        return ts_formatting_exports.SmartIndenter.findFirstNonWhitespaceColumn(getLineStartPositionForPosition(nodeStart, sourceFile), nodeStart, sourceFile, this.formatContext.options) + (this.formatContext.options.indentSize ?? 4);
                    }
                    getInsertNodeAtStartInsertOptions(sourceFile, node, indentation) {
                        const members = getMembersOrProperties(node);
                        const isEmpty = members.length === 0;
                        const isFirstInsertion = addToSeen(this.classesWithNodesInsertedAtStart, getNodeId(node), { node, sourceFile });
                        const insertTrailingComma = isObjectLiteralExpression(node) && (!isJsonSourceFile(sourceFile) || !isEmpty);
                        const insertLeadingComma = isObjectLiteralExpression(node) && isJsonSourceFile(sourceFile) && isEmpty && !isFirstInsertion;
                        return {
                            indentation,
                            prefix: (insertLeadingComma ? "," : "") + this.newLineCharacter,
                            suffix: insertTrailingComma ? "," : isInterfaceDeclaration(node) && isEmpty ? ";" : ""
                        };
                    }
                    insertNodeAfterComma(sourceFile, after, newNode) {
                        const endPosition = this.insertNodeAfterWorker(sourceFile, this.nextCommaToken(sourceFile, after) || after, newNode);
                        this.insertNodeAt(sourceFile, endPosition, newNode, this.getInsertNodeAfterOptions(sourceFile, after));
                    }
                    insertNodeAfter(sourceFile, after, newNode) {
                        const endPosition = this.insertNodeAfterWorker(sourceFile, after, newNode);
                        this.insertNodeAt(sourceFile, endPosition, newNode, this.getInsertNodeAfterOptions(sourceFile, after));
                    }
                    insertNodeAtEndOfList(sourceFile, list, newNode) {
                        this.insertNodeAt(sourceFile, list.end, newNode, { prefix: ", " });
                    }
                    insertNodesAfter(sourceFile, after, newNodes) {
                        const endPosition = this.insertNodeAfterWorker(sourceFile, after, first(newNodes));
                        this.insertNodesAt(sourceFile, endPosition, newNodes, this.getInsertNodeAfterOptions(sourceFile, after));
                    }
                    insertNodeAfterWorker(sourceFile, after, newNode) {
                        if (needSemicolonBetween(after, newNode)) {
                            if (sourceFile.text.charCodeAt(after.end - 1) !== 59 /* semicolon */) {
                                this.replaceRange(sourceFile, createRange(after.end), factory.createToken(27 /* SemicolonToken */));
                            }
                        }
                        const endPosition = getAdjustedEndPosition(sourceFile, after, {});
                        return endPosition;
                    }
                    getInsertNodeAfterOptions(sourceFile, after) {
                        const options = this.getInsertNodeAfterOptionsWorker(after);
                        return {
                            ...options,
                            prefix: after.end === sourceFile.end && isStatement(after) ? options.prefix ? `
${options.prefix}` : "\n" : options.prefix
                        };
                    }
                    getInsertNodeAfterOptionsWorker(node) {
                        switch (node.kind) {
                            case 263 /* ClassDeclaration */:
                            case 267 /* ModuleDeclaration */:
                                return { prefix: this.newLineCharacter, suffix: this.newLineCharacter };
                            case 260 /* VariableDeclaration */:
                            case 11 /* StringLiteral */:
                            case 80 /* Identifier */:
                                return { prefix: ", " };
                            case 303 /* PropertyAssignment */:
                                return { suffix: "," + this.newLineCharacter };
                            case 95 /* ExportKeyword */:
                                return { prefix: " " };
                            case 169 /* Parameter */:
                                return {};
                            default:
                                Debug.assert(isStatement(node) || isClassOrTypeElement(node));
                                return { suffix: this.newLineCharacter };
                        }
                    }
                    insertName(sourceFile, node, name) {
                        Debug.assert(!node.name);
                        if (node.kind === 219 /* ArrowFunction */) {
                            const arrow = findChildOfKind(node, 39 /* EqualsGreaterThanToken */, sourceFile);
                            const lparen = findChildOfKind(node, 21 /* OpenParenToken */, sourceFile);
                            if (lparen) {
                                this.insertNodesAt(sourceFile, lparen.getStart(sourceFile), [factory.createToken(100 /* FunctionKeyword */), factory.createIdentifier(name)], { joiner: " " });
                                deleteNode(this, sourceFile, arrow);
                            }
                            else {
                                this.insertText(sourceFile, first(node.parameters).getStart(sourceFile), `function ${name}(`);
                                this.replaceRange(sourceFile, arrow, factory.createToken(22 /* CloseParenToken */));
                            }
                            if (node.body.kind !== 241 /* Block */) {
                                this.insertNodesAt(sourceFile, node.body.getStart(sourceFile), [factory.createToken(19 /* OpenBraceToken */), factory.createToken(107 /* ReturnKeyword */)], { joiner: " ", suffix: " " });
                                this.insertNodesAt(sourceFile, node.body.end, [factory.createToken(27 /* SemicolonToken */), factory.createToken(20 /* CloseBraceToken */)], { joiner: " " });
                            }
                        }
                        else {
                            const pos = findChildOfKind(node, node.kind === 218 /* FunctionExpression */ ? 100 /* FunctionKeyword */ : 86 /* ClassKeyword */, sourceFile).end;
                            this.insertNodeAt(sourceFile, pos, factory.createIdentifier(name), { prefix: " " });
                        }
                    }
                    insertExportModifier(sourceFile, node) {
                        this.insertText(sourceFile, node.getStart(sourceFile), "export ");
                    }
                    insertImportSpecifierAtIndex(sourceFile, importSpecifier, namedImports, index) {
                        const prevSpecifier = namedImports.elements[index - 1];
                        if (prevSpecifier) {
                            this.insertNodeInListAfter(sourceFile, prevSpecifier, importSpecifier);
                        }
                        else {
                            this.insertNodeBefore(sourceFile, namedImports.elements[0], importSpecifier, !positionsAreOnSameLine(namedImports.elements[0].getStart(), namedImports.parent.parent.getStart(), sourceFile));
                        }
                    }
                    /**
                     * This function should be used to insert nodes in lists when nodes don't carry separators as the part of the node range,
                     * i.e. arguments in arguments lists, parameters in parameter lists etc.
                     * Note that separators are part of the node in statements and class elements.
                     */
                    insertNodeInListAfter(sourceFile, after, newNode, containingList = ts_formatting_exports.SmartIndenter.getContainingList(after, sourceFile)) {
                        if (!containingList) {
                            Debug.fail("node is not a list element");
                            return;
                        }
                        const index = indexOfNode(containingList, after);
                        if (index < 0) {
                            return;
                        }
                        const end = after.getEnd();
                        if (index !== containingList.length - 1) {
                            const nextToken = getTokenAtPosition(sourceFile, after.end);
                            if (nextToken && isSeparator(after, nextToken)) {
                                const nextNode = containingList[index + 1];
                                const startPos = skipWhitespacesAndLineBreaks(sourceFile.text, nextNode.getFullStart());
                                const suffix = `${tokenToString(nextToken.kind)}${sourceFile.text.substring(nextToken.end, startPos)}`;
                                this.insertNodesAt(sourceFile, startPos, [newNode], { suffix });
                            }
                        }
                        else {
                            const afterStart = after.getStart(sourceFile);
                            const afterStartLinePosition = getLineStartPositionForPosition(afterStart, sourceFile);
                            let separator;
                            let multilineList = false;
                            if (containingList.length === 1) {
                                separator = 28 /* CommaToken */;
                            }
                            else {
                                const tokenBeforeInsertPosition = findPrecedingToken(after.pos, sourceFile);
                                separator = isSeparator(after, tokenBeforeInsertPosition) ? tokenBeforeInsertPosition.kind : 28 /* CommaToken */;
                                const afterMinusOneStartLinePosition = getLineStartPositionForPosition(containingList[index - 1].getStart(sourceFile), sourceFile);
                                multilineList = afterMinusOneStartLinePosition !== afterStartLinePosition;
                            }
                            if (hasCommentsBeforeLineBreak(sourceFile.text, after.end) || !positionsAreOnSameLine(containingList.pos, containingList.end, sourceFile)) {
                                multilineList = true;
                            }
                            if (multilineList) {
                                this.replaceRange(sourceFile, createRange(end), factory.createToken(separator));
                                const indentation = ts_formatting_exports.SmartIndenter.findFirstNonWhitespaceColumn(afterStartLinePosition, afterStart, sourceFile, this.formatContext.options);
                                let insertPos = skipTrivia(sourceFile.text, end, 
                                /*stopAfterLineBreak*/
                                true, 
                                /*stopAtComments*/
                                false);
                                while (insertPos !== end && isLineBreak(sourceFile.text.charCodeAt(insertPos - 1))) {
                                    insertPos--;
                                }
                                this.replaceRange(sourceFile, createRange(insertPos), newNode, { indentation, prefix: this.newLineCharacter });
                            }
                            else {
                                this.replaceRange(sourceFile, createRange(end), newNode, { prefix: `${tokenToString(separator)} ` });
                            }
                        }
                    }
                    parenthesizeExpression(sourceFile, expression) {
                        this.replaceRange(sourceFile, rangeOfNode(expression), factory.createParenthesizedExpression(expression));
                    }
                    finishClassesWithNodesInsertedAtStart() {
                        this.classesWithNodesInsertedAtStart.forEach(({ node, sourceFile }) => {
                            const [openBraceEnd, closeBraceEnd] = getClassOrObjectBraceEnds(node, sourceFile);
                            if (openBraceEnd !== void 0 && closeBraceEnd !== void 0) {
                                const isEmpty = getMembersOrProperties(node).length === 0;
                                const isSingleLine = positionsAreOnSameLine(openBraceEnd, closeBraceEnd, sourceFile);
                                if (isEmpty && isSingleLine && openBraceEnd !== closeBraceEnd - 1) {
                                    this.deleteRange(sourceFile, createRange(openBraceEnd, closeBraceEnd - 1));
                                }
                                if (isSingleLine) {
                                    this.insertText(sourceFile, closeBraceEnd - 1, this.newLineCharacter);
                                }
                            }
                        });
                    }
                    finishDeleteDeclarations() {
                        const deletedNodesInLists = /* @__PURE__ */ new Set();
                        for (const { sourceFile, node } of this.deletedNodes) {
                            if (!this.deletedNodes.some((d) => d.sourceFile === sourceFile && rangeContainsRangeExclusive(d.node, node))) {
                                if (isArray(node)) {
                                    this.deleteRange(sourceFile, rangeOfTypeParameters(sourceFile, node));
                                }
                                else {
                                    deleteDeclaration.deleteDeclaration(this, deletedNodesInLists, sourceFile, node);
                                }
                            }
                        }
                        deletedNodesInLists.forEach((node) => {
                            const sourceFile = node.getSourceFile();
                            const list = ts_formatting_exports.SmartIndenter.getContainingList(node, sourceFile);
                            if (node !== last(list))
                                return;
                            const lastNonDeletedIndex = findLastIndex(list, (n) => !deletedNodesInLists.has(n), list.length - 2);
                            if (lastNonDeletedIndex !== -1) {
                                this.deleteRange(sourceFile, { pos: list[lastNonDeletedIndex].end, end: startPositionToDeleteNodeInList(sourceFile, list[lastNonDeletedIndex + 1]) });
                            }
                        });
                    }
                    /**
                     * Note: after calling this, the TextChanges object must be discarded!
                     * @param validate only for tests
                     *    The reason we must validate as part of this method is that `getNonFormattedText` changes the node's positions,
                     *    so we can only call this once and can't get the non-formatted text separately.
                     */
                    getChanges(validate) {
                        this.finishDeleteDeclarations();
                        this.finishClassesWithNodesInsertedAtStart();
                        const changes = changesToText.getTextChangesFromChanges(this.changes, this.newLineCharacter, this.formatContext, validate);
                        if (this.newFileChanges) {
                            this.newFileChanges.forEach((insertions, fileName) => {
                                changes.push(changesToText.newFileChanges(fileName, insertions, this.newLineCharacter, this.formatContext));
                            });
                        }
                        return changes;
                    }
                    createNewFile(oldFile, fileName, statements) {
                        this.insertStatementsInNewFile(fileName, statements, oldFile);
                    }
                };
                ((changesToText2) => {
                    function getTextChangesFromChanges(changes, newLineCharacter, formatContext, validate) {
                        return mapDefined(group(changes, (c) => c.sourceFile.path), (changesInFile) => {
                            const sourceFile = changesInFile[0].sourceFile;
                            const normalized = stableSort(changesInFile, (a, b) => a.range.pos - b.range.pos || a.range.end - b.range.end);
                            for (let i = 0; i < normalized.length - 1; i++) {
                                Debug.assert(normalized[i].range.end <= normalized[i + 1].range.pos, "Changes overlap", () => `${JSON.stringify(normalized[i].range)} and ${JSON.stringify(normalized[i + 1].range)}`);
                            }
                            const textChanges2 = mapDefined(normalized, (c) => {
                                const span = createTextSpanFromRange(c.range);
                                const targetSourceFile = c.kind === 1 /* ReplaceWithSingleNode */ ? getSourceFileOfNode(getOriginalNode(c.node)) ?? c.sourceFile : c.kind === 2 /* ReplaceWithMultipleNodes */ ? getSourceFileOfNode(getOriginalNode(c.nodes[0])) ?? c.sourceFile : c.sourceFile;
                                const newText = computeNewText(c, targetSourceFile, sourceFile, newLineCharacter, formatContext, validate);
                                if (span.length === newText.length && stringContainsAt(targetSourceFile.text, newText, span.start)) {
                                    return void 0;
                                }
                                return createTextChange(span, newText);
                            });
                            return textChanges2.length > 0 ? { fileName: sourceFile.fileName, textChanges: textChanges2 } : void 0;
                        });
                    }
                    changesToText2.getTextChangesFromChanges = getTextChangesFromChanges;
                    function newFileChanges(fileName, insertions, newLineCharacter, formatContext) {
                        const text = newFileChangesWorker(getScriptKindFromFileName(fileName), insertions, newLineCharacter, formatContext);
                        return { fileName, textChanges: [createTextChange(createTextSpan(0, 0), text)], isNewFile: true };
                    }
                    changesToText2.newFileChanges = newFileChanges;
                    function newFileChangesWorker(scriptKind, insertions, newLineCharacter, formatContext) {
                        const nonFormattedText = flatMap(insertions, (insertion) => insertion.statements.map((s) => s === 4 /* NewLineTrivia */ ? "" : getNonformattedText(s, insertion.oldFile, newLineCharacter).text)).join(newLineCharacter);
                        const sourceFile = createSourceFile("any file name", nonFormattedText, { languageVersion: 99 /* ESNext */, jsDocParsingMode: 1 /* ParseNone */ }, 
                        /*setParentNodes*/
                        true, scriptKind);
                        const changes = ts_formatting_exports.formatDocument(sourceFile, formatContext);
                        return applyChanges(nonFormattedText, changes) + newLineCharacter;
                    }
                    changesToText2.newFileChangesWorker = newFileChangesWorker;
                    function computeNewText(change, targetSourceFile, sourceFile, newLineCharacter, formatContext, validate) {
                        var _a;
                        if (change.kind === 0 /* Remove */) {
                            return "";
                        }
                        if (change.kind === 3 /* Text */) {
                            return change.text;
                        }
                        const { options = {}, range: { pos } } = change;
                        const format = (n) => getFormattedTextOfNode(n, targetSourceFile, sourceFile, pos, options, newLineCharacter, formatContext, validate);
                        const text = change.kind === 2 /* ReplaceWithMultipleNodes */ ? change.nodes.map((n) => removeSuffix(format(n), newLineCharacter)).join(((_a = change.options) == null ? void 0 : _a.joiner) || newLineCharacter) : format(change.node);
                        const noIndent = options.indentation !== void 0 || getLineStartPositionForPosition(pos, targetSourceFile) === pos ? text : text.replace(/^\s+/, "");
                        return (options.prefix || "") + noIndent + (!options.suffix || endsWith(noIndent, options.suffix) ? "" : options.suffix);
                    }
                    function getFormattedTextOfNode(nodeIn, targetSourceFile, sourceFile, pos, { indentation, prefix, delta }, newLineCharacter, formatContext, validate) {
                        const { node, text } = getNonformattedText(nodeIn, targetSourceFile, newLineCharacter);
                        if (validate)
                            validate(node, text);
                        const formatOptions = getFormatCodeSettingsForWriting(formatContext, targetSourceFile);
                        const initialIndentation = indentation !== void 0 ? indentation : ts_formatting_exports.SmartIndenter.getIndentation(pos, sourceFile, formatOptions, prefix === newLineCharacter || getLineStartPositionForPosition(pos, targetSourceFile) === pos);
                        if (delta === void 0) {
                            delta = ts_formatting_exports.SmartIndenter.shouldIndentChildNode(formatOptions, nodeIn) ? formatOptions.indentSize || 0 : 0;
                        }
                        const file = {
                            text,
                            getLineAndCharacterOfPosition(pos2) {
                                return getLineAndCharacterOfPosition(this, pos2);
                            }
                        };
                        const changes = ts_formatting_exports.formatNodeGivenIndentation(node, file, targetSourceFile.languageVariant, initialIndentation, delta, { ...formatContext, options: formatOptions });
                        return applyChanges(text, changes);
                    }
                    function getNonformattedText(node, sourceFile, newLineCharacter) {
                        const writer = createWriter(newLineCharacter);
                        const newLine = getNewLineKind(newLineCharacter);
                        createPrinter({
                            newLine,
                            neverAsciiEscape: true,
                            preserveSourceNewlines: true,
                            terminateUnterminatedLiterals: true
                        }, writer).writeNode(4 /* Unspecified */, node, sourceFile, writer);
                        return { text: writer.getText(), node: assignPositionsToNode(node) };
                    }
                    changesToText2.getNonformattedText = getNonformattedText;
                })(changesToText || (changesToText = {}));
                textChangesTransformationContext = {
                    ...nullTransformationContext,
                    factory: createNodeFactory(nullTransformationContext.factory.flags | 1 /* NoParenthesizerRules */, nullTransformationContext.factory.baseFactory)
                };
                ((_deleteDeclaration) => {
                    function deleteDeclaration2(changes, deletedNodesInLists, sourceFile, node) {
                        switch (node.kind) {
                            case 169 /* Parameter */: {
                                const oldFunction = node.parent;
                                if (isArrowFunction(oldFunction) && oldFunction.parameters.length === 1 && !findChildOfKind(oldFunction, 21 /* OpenParenToken */, sourceFile)) {
                                    changes.replaceNodeWithText(sourceFile, node, "()");
                                }
                                else {
                                    deleteNodeInList(changes, deletedNodesInLists, sourceFile, node);
                                }
                                break;
                            }
                            case 272 /* ImportDeclaration */:
                            case 271 /* ImportEqualsDeclaration */:
                                const isFirstImport = sourceFile.imports.length && node === first(sourceFile.imports).parent || node === find(sourceFile.statements, isAnyImportSyntax);
                                deleteNode(changes, sourceFile, node, {
                                    leadingTriviaOption: isFirstImport ? 0 /* Exclude */ : hasJSDocNodes(node) ? 2 /* JSDoc */ : 3 /* StartLine */
                                });
                                break;
                            case 208 /* BindingElement */:
                                const pattern = node.parent;
                                const preserveComma = pattern.kind === 207 /* ArrayBindingPattern */ && node !== last(pattern.elements);
                                if (preserveComma) {
                                    deleteNode(changes, sourceFile, node);
                                }
                                else {
                                    deleteNodeInList(changes, deletedNodesInLists, sourceFile, node);
                                }
                                break;
                            case 260 /* VariableDeclaration */:
                                deleteVariableDeclaration(changes, deletedNodesInLists, sourceFile, node);
                                break;
                            case 168 /* TypeParameter */:
                                deleteNodeInList(changes, deletedNodesInLists, sourceFile, node);
                                break;
                            case 276 /* ImportSpecifier */:
                                const namedImports = node.parent;
                                if (namedImports.elements.length === 1) {
                                    deleteImportBinding(changes, sourceFile, namedImports);
                                }
                                else {
                                    deleteNodeInList(changes, deletedNodesInLists, sourceFile, node);
                                }
                                break;
                            case 274 /* NamespaceImport */:
                                deleteImportBinding(changes, sourceFile, node);
                                break;
                            case 27 /* SemicolonToken */:
                                deleteNode(changes, sourceFile, node, { trailingTriviaOption: 0 /* Exclude */ });
                                break;
                            case 100 /* FunctionKeyword */:
                                deleteNode(changes, sourceFile, node, { leadingTriviaOption: 0 /* Exclude */ });
                                break;
                            case 263 /* ClassDeclaration */:
                            case 262 /* FunctionDeclaration */:
                                deleteNode(changes, sourceFile, node, { leadingTriviaOption: hasJSDocNodes(node) ? 2 /* JSDoc */ : 3 /* StartLine */ });
                                break;
                            default:
                                if (!node.parent) {
                                    deleteNode(changes, sourceFile, node);
                                }
                                else if (isImportClause(node.parent) && node.parent.name === node) {
                                    deleteDefaultImport(changes, sourceFile, node.parent);
                                }
                                else if (isCallExpression(node.parent) && contains(node.parent.arguments, node)) {
                                    deleteNodeInList(changes, deletedNodesInLists, sourceFile, node);
                                }
                                else {
                                    deleteNode(changes, sourceFile, node);
                                }
                        }
                    }
                    _deleteDeclaration.deleteDeclaration = deleteDeclaration2;
                    function deleteDefaultImport(changes, sourceFile, importClause) {
                        if (!importClause.namedBindings) {
                            deleteNode(changes, sourceFile, importClause.parent);
                        }
                        else {
                            const start = importClause.name.getStart(sourceFile);
                            const nextToken = getTokenAtPosition(sourceFile, importClause.name.end);
                            if (nextToken && nextToken.kind === 28 /* CommaToken */) {
                                const end = skipTrivia(sourceFile.text, nextToken.end, 
                                /*stopAfterLineBreak*/
                                false, 
                                /*stopAtComments*/
                                true);
                                changes.deleteRange(sourceFile, { pos: start, end });
                            }
                            else {
                                deleteNode(changes, sourceFile, importClause.name);
                            }
                        }
                    }
                    function deleteImportBinding(changes, sourceFile, node) {
                        if (node.parent.name) {
                            const previousToken = Debug.checkDefined(getTokenAtPosition(sourceFile, node.pos - 1));
                            changes.deleteRange(sourceFile, { pos: previousToken.getStart(sourceFile), end: node.end });
                        }
                        else {
                            const importDecl = getAncestor(node, 272 /* ImportDeclaration */);
                            deleteNode(changes, sourceFile, importDecl);
                        }
                    }
                    function deleteVariableDeclaration(changes, deletedNodesInLists, sourceFile, node) {
                        const { parent: parent2 } = node;
                        if (parent2.kind === 299 /* CatchClause */) {
                            changes.deleteNodeRange(sourceFile, findChildOfKind(parent2, 21 /* OpenParenToken */, sourceFile), findChildOfKind(parent2, 22 /* CloseParenToken */, sourceFile));
                            return;
                        }
                        if (parent2.declarations.length !== 1) {
                            deleteNodeInList(changes, deletedNodesInLists, sourceFile, node);
                            return;
                        }
                        const gp = parent2.parent;
                        switch (gp.kind) {
                            case 250 /* ForOfStatement */:
                            case 249 /* ForInStatement */:
                                changes.replaceNode(sourceFile, node, factory.createObjectLiteralExpression());
                                break;
                            case 248 /* ForStatement */:
                                deleteNode(changes, sourceFile, parent2);
                                break;
                            case 243 /* VariableStatement */:
                                deleteNode(changes, sourceFile, gp, { leadingTriviaOption: hasJSDocNodes(gp) ? 2 /* JSDoc */ : 3 /* StartLine */ });
                                break;
                            default:
                                Debug.assertNever(gp);
                        }
                    }
                })(deleteDeclaration || (deleteDeclaration = {}));
            }
        });
        // src/services/_namespaces/ts.textChanges.ts
        var ts_textChanges_exports = {};
        __export(ts_textChanges_exports, {
            ChangeTracker: () => ChangeTracker,
            LeadingTriviaOption: () => LeadingTriviaOption,
            TrailingTriviaOption: () => TrailingTriviaOption,
            applyChanges: () => applyChanges,
            assignPositionsToNode: () => assignPositionsToNode,
            createWriter: () => createWriter,
            deleteNode: () => deleteNode,
            isThisTypeAnnotatable: () => isThisTypeAnnotatable,
            isValidLocationToAddComment: () => isValidLocationToAddComment
        });
        var init_ts_textChanges = __esm({
            "src/services/_namespaces/ts.textChanges.ts"() {
                "use strict";
                init_textChanges();
            }
        });
        // src/services/formatting/formattingContext.ts
        var FormattingRequestKind, FormattingContext;
        var init_formattingContext = __esm({
            "src/services/formatting/formattingContext.ts"() {
                "use strict";
                init_ts4();
                FormattingRequestKind = /* @__PURE__ */ ((FormattingRequestKind2) => {
                    FormattingRequestKind2[FormattingRequestKind2["FormatDocument"] = 0] = "FormatDocument";
                    FormattingRequestKind2[FormattingRequestKind2["FormatSelection"] = 1] = "FormatSelection";
                    FormattingRequestKind2[FormattingRequestKind2["FormatOnEnter"] = 2] = "FormatOnEnter";
                    FormattingRequestKind2[FormattingRequestKind2["FormatOnSemicolon"] = 3] = "FormatOnSemicolon";
                    FormattingRequestKind2[FormattingRequestKind2["FormatOnOpeningCurlyBrace"] = 4] = "FormatOnOpeningCurlyBrace";
                    FormattingRequestKind2[FormattingRequestKind2["FormatOnClosingCurlyBrace"] = 5] = "FormatOnClosingCurlyBrace";
                    return FormattingRequestKind2;
                })(FormattingRequestKind || {});
                FormattingContext = class {
                    constructor(sourceFile, formattingRequestKind, options) {
                        this.sourceFile = sourceFile;
                        this.formattingRequestKind = formattingRequestKind;
                        this.options = options;
                    }
                    updateContext(currentRange, currentTokenParent, nextRange, nextTokenParent, commonParent) {
                        this.currentTokenSpan = Debug.checkDefined(currentRange);
                        this.currentTokenParent = Debug.checkDefined(currentTokenParent);
                        this.nextTokenSpan = Debug.checkDefined(nextRange);
                        this.nextTokenParent = Debug.checkDefined(nextTokenParent);
                        this.contextNode = Debug.checkDefined(commonParent);
                        this.contextNodeAllOnSameLine = void 0;
                        this.nextNodeAllOnSameLine = void 0;
                        this.tokensAreOnSameLine = void 0;
                        this.contextNodeBlockIsOnOneLine = void 0;
                        this.nextNodeBlockIsOnOneLine = void 0;
                    }
                    ContextNodeAllOnSameLine() {
                        if (this.contextNodeAllOnSameLine === void 0) {
                            this.contextNodeAllOnSameLine = this.NodeIsOnOneLine(this.contextNode);
                        }
                        return this.contextNodeAllOnSameLine;
                    }
                    NextNodeAllOnSameLine() {
                        if (this.nextNodeAllOnSameLine === void 0) {
                            this.nextNodeAllOnSameLine = this.NodeIsOnOneLine(this.nextTokenParent);
                        }
                        return this.nextNodeAllOnSameLine;
                    }
                    TokensAreOnSameLine() {
                        if (this.tokensAreOnSameLine === void 0) {
                            const startLine = this.sourceFile.getLineAndCharacterOfPosition(this.currentTokenSpan.pos).line;
                            const endLine = this.sourceFile.getLineAndCharacterOfPosition(this.nextTokenSpan.pos).line;
                            this.tokensAreOnSameLine = startLine === endLine;
                        }
                        return this.tokensAreOnSameLine;
                    }
                    ContextNodeBlockIsOnOneLine() {
                        if (this.contextNodeBlockIsOnOneLine === void 0) {
                            this.contextNodeBlockIsOnOneLine = this.BlockIsOnOneLine(this.contextNode);
                        }
                        return this.contextNodeBlockIsOnOneLine;
                    }
                    NextNodeBlockIsOnOneLine() {
                        if (this.nextNodeBlockIsOnOneLine === void 0) {
                            this.nextNodeBlockIsOnOneLine = this.BlockIsOnOneLine(this.nextTokenParent);
                        }
                        return this.nextNodeBlockIsOnOneLine;
                    }
                    NodeIsOnOneLine(node) {
                        const startLine = this.sourceFile.getLineAndCharacterOfPosition(node.getStart(this.sourceFile)).line;
                        const endLine = this.sourceFile.getLineAndCharacterOfPosition(node.getEnd()).line;
                        return startLine === endLine;
                    }
                    BlockIsOnOneLine(node) {
                        const openBrace = findChildOfKind(node, 19 /* OpenBraceToken */, this.sourceFile);
                        const closeBrace = findChildOfKind(node, 20 /* CloseBraceToken */, this.sourceFile);
                        if (openBrace && closeBrace) {
                            const startLine = this.sourceFile.getLineAndCharacterOfPosition(openBrace.getEnd()).line;
                            const endLine = this.sourceFile.getLineAndCharacterOfPosition(closeBrace.getStart(this.sourceFile)).line;
                            return startLine === endLine;
                        }
                        return false;
                    }
                };
            }
        });
        // src/services/formatting/formattingScanner.ts
        function getFormattingScanner(text, languageVariant, startPos, endPos, cb) {
            const scanner2 = languageVariant === 1 /* JSX */ ? jsxScanner : standardScanner;
            scanner2.setText(text);
            scanner2.resetTokenState(startPos);
            let wasNewLine = true;
            let leadingTrivia;
            let trailingTrivia;
            let savedPos;
            let lastScanAction;
            let lastTokenInfo;
            const res = cb({
                advance,
                readTokenInfo,
                readEOFTokenRange,
                isOnToken,
                isOnEOF,
                getCurrentLeadingTrivia: () => leadingTrivia,
                lastTrailingTriviaWasNewLine: () => wasNewLine,
                skipToEndOf,
                skipToStartOf,
                getTokenFullStart: () => (lastTokenInfo == null ? void 0 : lastTokenInfo.token.pos) ?? scanner2.getTokenStart(),
                getStartPos: () => (lastTokenInfo == null ? void 0 : lastTokenInfo.token.pos) ?? scanner2.getTokenStart()
            });
            lastTokenInfo = void 0;
            scanner2.setText(void 0);
            return res;
            function advance() {
                lastTokenInfo = void 0;
                const isStarted = scanner2.getTokenFullStart() !== startPos;
                if (isStarted) {
                    wasNewLine = !!trailingTrivia && last(trailingTrivia).kind === 4 /* NewLineTrivia */;
                }
                else {
                    scanner2.scan();
                }
                leadingTrivia = void 0;
                trailingTrivia = void 0;
                let pos = scanner2.getTokenFullStart();
                while (pos < endPos) {
                    const t = scanner2.getToken();
                    if (!isTrivia(t)) {
                        break;
                    }
                    scanner2.scan();
                    const item = {
                        pos,
                        end: scanner2.getTokenFullStart(),
                        kind: t
                    };
                    pos = scanner2.getTokenFullStart();
                    leadingTrivia = append(leadingTrivia, item);
                }
                savedPos = scanner2.getTokenFullStart();
            }
            function shouldRescanGreaterThanToken(node) {
                switch (node.kind) {
                    case 34 /* GreaterThanEqualsToken */:
                    case 72 /* GreaterThanGreaterThanEqualsToken */:
                    case 73 /* GreaterThanGreaterThanGreaterThanEqualsToken */:
                    case 50 /* GreaterThanGreaterThanGreaterThanToken */:
                    case 49 /* GreaterThanGreaterThanToken */:
                        return true;
                }
                return false;
            }
            function shouldRescanJsxIdentifier(node) {
                if (node.parent) {
                    switch (node.parent.kind) {
                        case 291 /* JsxAttribute */:
                        case 286 /* JsxOpeningElement */:
                        case 287 /* JsxClosingElement */:
                        case 285 /* JsxSelfClosingElement */:
                            return isKeyword(node.kind) || node.kind === 80 /* Identifier */;
                    }
                }
                return false;
            }
            function shouldRescanJsxText(node) {
                return isJsxText(node) || isJsxElement(node) && (lastTokenInfo == null ? void 0 : lastTokenInfo.token.kind) === 12 /* JsxText */;
            }
            function shouldRescanSlashToken(container) {
                return container.kind === 14 /* RegularExpressionLiteral */;
            }
            function shouldRescanTemplateToken(container) {
                return container.kind === 17 /* TemplateMiddle */ || container.kind === 18 /* TemplateTail */;
            }
            function shouldRescanJsxAttributeValue(node) {
                return node.parent && isJsxAttribute(node.parent) && node.parent.initializer === node;
            }
            function startsWithSlashToken(t) {
                return t === 44 /* SlashToken */ || t === 69 /* SlashEqualsToken */;
            }
            function readTokenInfo(n) {
                Debug.assert(isOnToken());
                const expectedScanAction = shouldRescanGreaterThanToken(n) ? 1 /* RescanGreaterThanToken */ : shouldRescanSlashToken(n) ? 2 /* RescanSlashToken */ : shouldRescanTemplateToken(n) ? 3 /* RescanTemplateToken */ : shouldRescanJsxIdentifier(n) ? 4 /* RescanJsxIdentifier */ : shouldRescanJsxText(n) ? 5 /* RescanJsxText */ : shouldRescanJsxAttributeValue(n) ? 6 /* RescanJsxAttributeValue */ : 0 /* Scan */;
                if (lastTokenInfo && expectedScanAction === lastScanAction) {
                    return fixTokenKind(lastTokenInfo, n);
                }
                if (scanner2.getTokenFullStart() !== savedPos) {
                    Debug.assert(lastTokenInfo !== void 0);
                    scanner2.resetTokenState(savedPos);
                    scanner2.scan();
                }
                let currentToken = getNextToken(n, expectedScanAction);
                const token = createTextRangeWithKind(scanner2.getTokenFullStart(), scanner2.getTokenEnd(), currentToken);
                if (trailingTrivia) {
                    trailingTrivia = void 0;
                }
                while (scanner2.getTokenFullStart() < endPos) {
                    currentToken = scanner2.scan();
                    if (!isTrivia(currentToken)) {
                        break;
                    }
                    const trivia = createTextRangeWithKind(scanner2.getTokenFullStart(), scanner2.getTokenEnd(), currentToken);
                    if (!trailingTrivia) {
                        trailingTrivia = [];
                    }
                    trailingTrivia.push(trivia);
                    if (currentToken === 4 /* NewLineTrivia */) {
                        scanner2.scan();
                        break;
                    }
                }
                lastTokenInfo = { leadingTrivia, trailingTrivia, token };
                return fixTokenKind(lastTokenInfo, n);
            }
            function getNextToken(n, expectedScanAction) {
                const token = scanner2.getToken();
                lastScanAction = 0 /* Scan */;
                switch (expectedScanAction) {
                    case 1 /* RescanGreaterThanToken */:
                        if (token === 32 /* GreaterThanToken */) {
                            lastScanAction = 1 /* RescanGreaterThanToken */;
                            const newToken = scanner2.reScanGreaterToken();
                            Debug.assert(n.kind === newToken);
                            return newToken;
                        }
                        break;
                    case 2 /* RescanSlashToken */:
                        if (startsWithSlashToken(token)) {
                            lastScanAction = 2 /* RescanSlashToken */;
                            const newToken = scanner2.reScanSlashToken();
                            Debug.assert(n.kind === newToken);
                            return newToken;
                        }
                        break;
                    case 3 /* RescanTemplateToken */:
                        if (token === 20 /* CloseBraceToken */) {
                            lastScanAction = 3 /* RescanTemplateToken */;
                            return scanner2.reScanTemplateToken(
                            /*isTaggedTemplate*/
                            false);
                        }
                        break;
                    case 4 /* RescanJsxIdentifier */:
                        lastScanAction = 4 /* RescanJsxIdentifier */;
                        return scanner2.scanJsxIdentifier();
                    case 5 /* RescanJsxText */:
                        lastScanAction = 5 /* RescanJsxText */;
                        return scanner2.reScanJsxToken(
                        /*allowMultilineJsxText*/
                        false);
                    case 6 /* RescanJsxAttributeValue */:
                        lastScanAction = 6 /* RescanJsxAttributeValue */;
                        return scanner2.reScanJsxAttributeValue();
                    case 0 /* Scan */:
                        break;
                    default:
                        Debug.assertNever(expectedScanAction);
                }
                return token;
            }
            function readEOFTokenRange() {
                Debug.assert(isOnEOF());
                return createTextRangeWithKind(scanner2.getTokenFullStart(), scanner2.getTokenEnd(), 1 /* EndOfFileToken */);
            }
            function isOnToken() {
                const current = lastTokenInfo ? lastTokenInfo.token.kind : scanner2.getToken();
                return current !== 1 /* EndOfFileToken */ && !isTrivia(current);
            }
            function isOnEOF() {
                const current = lastTokenInfo ? lastTokenInfo.token.kind : scanner2.getToken();
                return current === 1 /* EndOfFileToken */;
            }
            function fixTokenKind(tokenInfo, container) {
                if (isToken(container) && tokenInfo.token.kind !== container.kind) {
                    tokenInfo.token.kind = container.kind;
                }
                return tokenInfo;
            }
            function skipToEndOf(node) {
                scanner2.resetTokenState(node.end);
                savedPos = scanner2.getTokenFullStart();
                lastScanAction = void 0;
                lastTokenInfo = void 0;
                wasNewLine = false;
                leadingTrivia = void 0;
                trailingTrivia = void 0;
            }
            function skipToStartOf(node) {
                scanner2.resetTokenState(node.pos);
                savedPos = scanner2.getTokenFullStart();
                lastScanAction = void 0;
                lastTokenInfo = void 0;
                wasNewLine = false;
                leadingTrivia = void 0;
                trailingTrivia = void 0;
            }
        }
        var standardScanner, jsxScanner;
        var init_formattingScanner = __esm({
            "src/services/formatting/formattingScanner.ts"() {
                "use strict";
                init_ts4();
                init_ts_formatting();
                standardScanner = createScanner(99 /* Latest */, 
                /*skipTrivia*/
                false, 0 /* Standard */);
                jsxScanner = createScanner(99 /* Latest */, 
                /*skipTrivia*/
                false, 1 /* JSX */);
            }
        });
        // src/services/formatting/rule.ts
        var anyContext, RuleAction, RuleFlags;
        var init_rule = __esm({
            "src/services/formatting/rule.ts"() {
                "use strict";
                init_ts4();
                anyContext = emptyArray;
                RuleAction = /* @__PURE__ */ ((RuleAction2) => {
                    RuleAction2[RuleAction2["None"] = 0] = "None";
                    RuleAction2[RuleAction2["StopProcessingSpaceActions"] = 1] = "StopProcessingSpaceActions";
                    RuleAction2[RuleAction2["StopProcessingTokenActions"] = 2] = "StopProcessingTokenActions";
                    RuleAction2[RuleAction2["InsertSpace"] = 4] = "InsertSpace";
                    RuleAction2[RuleAction2["InsertNewLine"] = 8] = "InsertNewLine";
                    RuleAction2[RuleAction2["DeleteSpace"] = 16] = "DeleteSpace";
                    RuleAction2[RuleAction2["DeleteToken"] = 32] = "DeleteToken";
                    RuleAction2[RuleAction2["InsertTrailingSemicolon"] = 64] = "InsertTrailingSemicolon";
                    RuleAction2[RuleAction2["StopAction"] = 3] = "StopAction";
                    RuleAction2[RuleAction2["ModifySpaceAction"] = 28] = "ModifySpaceAction";
                    RuleAction2[RuleAction2["ModifyTokenAction"] = 96] = "ModifyTokenAction";
                    return RuleAction2;
                })(RuleAction || {});
                RuleFlags = /* @__PURE__ */ ((RuleFlags2) => {
                    RuleFlags2[RuleFlags2["None"] = 0] = "None";
                    RuleFlags2[RuleFlags2["CanDeleteNewLines"] = 1] = "CanDeleteNewLines";
                    return RuleFlags2;
                })(RuleFlags || {});
            }
        });
        // src/services/formatting/rules.ts
        function getAllRules() {
            const allTokens = [];
            for (let token = 0 /* FirstToken */; token <= 165 /* LastToken */; token++) {
                if (token !== 1 /* EndOfFileToken */) {
                    allTokens.push(token);
                }
            }
            function anyTokenExcept(...tokens) {
                return { tokens: allTokens.filter((t) => !tokens.some((t2) => t2 === t)), isSpecific: false };
            }
            const anyToken = { tokens: allTokens, isSpecific: false };
            const anyTokenIncludingMultilineComments = tokenRangeFrom([...allTokens, 3 /* MultiLineCommentTrivia */]);
            const anyTokenIncludingEOF = tokenRangeFrom([...allTokens, 1 /* EndOfFileToken */]);
            const keywords = tokenRangeFromRange(83 /* FirstKeyword */, 165 /* LastKeyword */);
            const binaryOperators = tokenRangeFromRange(30 /* FirstBinaryOperator */, 79 /* LastBinaryOperator */);
            const binaryKeywordOperators = [
                103 /* InKeyword */,
                104 /* InstanceOfKeyword */,
                165 /* OfKeyword */,
                130 /* AsKeyword */,
                142 /* IsKeyword */,
                152 /* SatisfiesKeyword */
            ];
            const unaryPrefixOperators = [46 /* PlusPlusToken */, 47 /* MinusMinusToken */, 55 /* TildeToken */, 54 /* ExclamationToken */];
            const unaryPrefixExpressions = [
                9 /* NumericLiteral */,
                10 /* BigIntLiteral */,
                80 /* Identifier */,
                21 /* OpenParenToken */,
                23 /* OpenBracketToken */,
                19 /* OpenBraceToken */,
                110 /* ThisKeyword */,
                105 /* NewKeyword */
            ];
            const unaryPreincrementExpressions = [80 /* Identifier */, 21 /* OpenParenToken */, 110 /* ThisKeyword */, 105 /* NewKeyword */];
            const unaryPostincrementExpressions = [80 /* Identifier */, 22 /* CloseParenToken */, 24 /* CloseBracketToken */, 105 /* NewKeyword */];
            const unaryPredecrementExpressions = [80 /* Identifier */, 21 /* OpenParenToken */, 110 /* ThisKeyword */, 105 /* NewKeyword */];
            const unaryPostdecrementExpressions = [80 /* Identifier */, 22 /* CloseParenToken */, 24 /* CloseBracketToken */, 105 /* NewKeyword */];
            const comments = [2 /* SingleLineCommentTrivia */, 3 /* MultiLineCommentTrivia */];
            const typeNames = [80 /* Identifier */, ...typeKeywords];
            const functionOpenBraceLeftTokenRange = anyTokenIncludingMultilineComments;
            const typeScriptOpenBraceLeftTokenRange = tokenRangeFrom([80 /* Identifier */, 32 /* GreaterThanToken */, 3 /* MultiLineCommentTrivia */, 86 /* ClassKeyword */, 95 /* ExportKeyword */, 102 /* ImportKeyword */]);
            const controlOpenBraceLeftTokenRange = tokenRangeFrom([22 /* CloseParenToken */, 3 /* MultiLineCommentTrivia */, 92 /* DoKeyword */, 113 /* TryKeyword */, 98 /* FinallyKeyword */, 93 /* ElseKeyword */, 85 /* CatchKeyword */]);
            const highPriorityCommonRules = [
                // Leave comments alone
                rule("IgnoreBeforeComment", anyToken, comments, anyContext, 1 /* StopProcessingSpaceActions */),
                rule("IgnoreAfterLineComment", 2 /* SingleLineCommentTrivia */, anyToken, anyContext, 1 /* StopProcessingSpaceActions */),
                rule("NotSpaceBeforeColon", anyToken, 59 /* ColonToken */, [isNonJsxSameLineTokenContext, isNotBinaryOpContext, isNotTypeAnnotationContext], 16 /* DeleteSpace */),
                rule("SpaceAfterColon", 59 /* ColonToken */, anyToken, [isNonJsxSameLineTokenContext, isNotBinaryOpContext, isNextTokenParentNotJsxNamespacedName], 4 /* InsertSpace */),
                rule("NoSpaceBeforeQuestionMark", anyToken, 58 /* QuestionToken */, [isNonJsxSameLineTokenContext, isNotBinaryOpContext, isNotTypeAnnotationContext], 16 /* DeleteSpace */),
                // insert space after '?' only when it is used in conditional operator
                rule("SpaceAfterQuestionMarkInConditionalOperator", 58 /* QuestionToken */, anyToken, [isNonJsxSameLineTokenContext, isConditionalOperatorContext], 4 /* InsertSpace */),
                // in other cases there should be no space between '?' and next token
                rule("NoSpaceAfterQuestionMark", 58 /* QuestionToken */, anyToken, [isNonJsxSameLineTokenContext, isNonOptionalPropertyContext], 16 /* DeleteSpace */),
                rule("NoSpaceBeforeDot", anyToken, [25 /* DotToken */, 29 /* QuestionDotToken */], [isNonJsxSameLineTokenContext, isNotPropertyAccessOnIntegerLiteral], 16 /* DeleteSpace */),
                rule("NoSpaceAfterDot", [25 /* DotToken */, 29 /* QuestionDotToken */], anyToken, [isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("NoSpaceBetweenImportParenInImportType", 102 /* ImportKeyword */, 21 /* OpenParenToken */, [isNonJsxSameLineTokenContext, isImportTypeContext], 16 /* DeleteSpace */),
                // Special handling of unary operators.
                // Prefix operators generally shouldn't have a space between
                // them and their target unary expression.
                rule("NoSpaceAfterUnaryPrefixOperator", unaryPrefixOperators, unaryPrefixExpressions, [isNonJsxSameLineTokenContext, isNotBinaryOpContext], 16 /* DeleteSpace */),
                rule("NoSpaceAfterUnaryPreincrementOperator", 46 /* PlusPlusToken */, unaryPreincrementExpressions, [isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("NoSpaceAfterUnaryPredecrementOperator", 47 /* MinusMinusToken */, unaryPredecrementExpressions, [isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("NoSpaceBeforeUnaryPostincrementOperator", unaryPostincrementExpressions, 46 /* PlusPlusToken */, [isNonJsxSameLineTokenContext, isNotStatementConditionContext], 16 /* DeleteSpace */),
                rule("NoSpaceBeforeUnaryPostdecrementOperator", unaryPostdecrementExpressions, 47 /* MinusMinusToken */, [isNonJsxSameLineTokenContext, isNotStatementConditionContext], 16 /* DeleteSpace */),
                // More unary operator special-casing.
                // DevDiv 181814: Be careful when removing leading whitespace
                // around unary operators.  Examples:
                //      1 - -2  --X--> 1--2
                //      a + ++b --X--> a+++b
                rule("SpaceAfterPostincrementWhenFollowedByAdd", 46 /* PlusPlusToken */, 40 /* PlusToken */, [isNonJsxSameLineTokenContext, isBinaryOpContext], 4 /* InsertSpace */),
                rule("SpaceAfterAddWhenFollowedByUnaryPlus", 40 /* PlusToken */, 40 /* PlusToken */, [isNonJsxSameLineTokenContext, isBinaryOpContext], 4 /* InsertSpace */),
                rule("SpaceAfterAddWhenFollowedByPreincrement", 40 /* PlusToken */, 46 /* PlusPlusToken */, [isNonJsxSameLineTokenContext, isBinaryOpContext], 4 /* InsertSpace */),
                rule("SpaceAfterPostdecrementWhenFollowedBySubtract", 47 /* MinusMinusToken */, 41 /* MinusToken */, [isNonJsxSameLineTokenContext, isBinaryOpContext], 4 /* InsertSpace */),
                rule("SpaceAfterSubtractWhenFollowedByUnaryMinus", 41 /* MinusToken */, 41 /* MinusToken */, [isNonJsxSameLineTokenContext, isBinaryOpContext], 4 /* InsertSpace */),
                rule("SpaceAfterSubtractWhenFollowedByPredecrement", 41 /* MinusToken */, 47 /* MinusMinusToken */, [isNonJsxSameLineTokenContext, isBinaryOpContext], 4 /* InsertSpace */),
                rule("NoSpaceAfterCloseBrace", 20 /* CloseBraceToken */, [28 /* CommaToken */, 27 /* SemicolonToken */], [isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                // For functions and control block place } on a new line [multi-line rule]
                rule("NewLineBeforeCloseBraceInBlockContext", anyTokenIncludingMultilineComments, 20 /* CloseBraceToken */, [isMultilineBlockContext], 8 /* InsertNewLine */),
                // Space/new line after }.
                rule("SpaceAfterCloseBrace", 20 /* CloseBraceToken */, anyTokenExcept(22 /* CloseParenToken */), [isNonJsxSameLineTokenContext, isAfterCodeBlockContext], 4 /* InsertSpace */),
                // Special case for (}, else) and (}, while) since else & while tokens are not part of the tree which makes SpaceAfterCloseBrace rule not applied
                // Also should not apply to })
                rule("SpaceBetweenCloseBraceAndElse", 20 /* CloseBraceToken */, 93 /* ElseKeyword */, [isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("SpaceBetweenCloseBraceAndWhile", 20 /* CloseBraceToken */, 117 /* WhileKeyword */, [isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("NoSpaceBetweenEmptyBraceBrackets", 19 /* OpenBraceToken */, 20 /* CloseBraceToken */, [isNonJsxSameLineTokenContext, isObjectContext], 16 /* DeleteSpace */),
                // Add a space after control dec context if the next character is an open bracket ex: 'if (false)[a, b] = [1, 2];' -> 'if (false) [a, b] = [1, 2];'
                rule("SpaceAfterConditionalClosingParen", 22 /* CloseParenToken */, 23 /* OpenBracketToken */, [isControlDeclContext], 4 /* InsertSpace */),
                rule("NoSpaceBetweenFunctionKeywordAndStar", 100 /* FunctionKeyword */, 42 /* AsteriskToken */, [isFunctionDeclarationOrFunctionExpressionContext], 16 /* DeleteSpace */),
                rule("SpaceAfterStarInGeneratorDeclaration", 42 /* AsteriskToken */, 80 /* Identifier */, [isFunctionDeclarationOrFunctionExpressionContext], 4 /* InsertSpace */),
                rule("SpaceAfterFunctionInFuncDecl", 100 /* FunctionKeyword */, anyToken, [isFunctionDeclContext], 4 /* InsertSpace */),
                // Insert new line after { and before } in multi-line contexts.
                rule("NewLineAfterOpenBraceInBlockContext", 19 /* OpenBraceToken */, anyToken, [isMultilineBlockContext], 8 /* InsertNewLine */),
                // For get/set members, we check for (identifier,identifier) since get/set don't have tokens and they are represented as just an identifier token.
                // Though, we do extra check on the context to make sure we are dealing with get/set node. Example:
                //      get x() {}
                //      set x(val) {}
                rule("SpaceAfterGetSetInMember", [139 /* GetKeyword */, 153 /* SetKeyword */], 80 /* Identifier */, [isFunctionDeclContext], 4 /* InsertSpace */),
                rule("NoSpaceBetweenYieldKeywordAndStar", 127 /* YieldKeyword */, 42 /* AsteriskToken */, [isNonJsxSameLineTokenContext, isYieldOrYieldStarWithOperand], 16 /* DeleteSpace */),
                rule("SpaceBetweenYieldOrYieldStarAndOperand", [127 /* YieldKeyword */, 42 /* AsteriskToken */], anyToken, [isNonJsxSameLineTokenContext, isYieldOrYieldStarWithOperand], 4 /* InsertSpace */),
                rule("NoSpaceBetweenReturnAndSemicolon", 107 /* ReturnKeyword */, 27 /* SemicolonToken */, [isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("SpaceAfterCertainKeywords", [115 /* VarKeyword */, 111 /* ThrowKeyword */, 105 /* NewKeyword */, 91 /* DeleteKeyword */, 107 /* ReturnKeyword */, 114 /* TypeOfKeyword */, 135 /* AwaitKeyword */], anyToken, [isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("SpaceAfterLetConstInVariableDeclaration", [121 /* LetKeyword */, 87 /* ConstKeyword */], anyToken, [isNonJsxSameLineTokenContext, isStartOfVariableDeclarationList], 4 /* InsertSpace */),
                rule("NoSpaceBeforeOpenParenInFuncCall", anyToken, 21 /* OpenParenToken */, [isNonJsxSameLineTokenContext, isFunctionCallOrNewContext, isPreviousTokenNotComma], 16 /* DeleteSpace */),
                // Special case for binary operators (that are keywords). For these we have to add a space and shouldn't follow any user options.
                rule("SpaceBeforeBinaryKeywordOperator", anyToken, binaryKeywordOperators, [isNonJsxSameLineTokenContext, isBinaryOpContext], 4 /* InsertSpace */),
                rule("SpaceAfterBinaryKeywordOperator", binaryKeywordOperators, anyToken, [isNonJsxSameLineTokenContext, isBinaryOpContext], 4 /* InsertSpace */),
                rule("SpaceAfterVoidOperator", 116 /* VoidKeyword */, anyToken, [isNonJsxSameLineTokenContext, isVoidOpContext], 4 /* InsertSpace */),
                // Async-await
                rule("SpaceBetweenAsyncAndOpenParen", 134 /* AsyncKeyword */, 21 /* OpenParenToken */, [isArrowFunctionContext, isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("SpaceBetweenAsyncAndFunctionKeyword", 134 /* AsyncKeyword */, [100 /* FunctionKeyword */, 80 /* Identifier */], [isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                // Template string
                rule("NoSpaceBetweenTagAndTemplateString", [80 /* Identifier */, 22 /* CloseParenToken */], [15 /* NoSubstitutionTemplateLiteral */, 16 /* TemplateHead */], [isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                // JSX opening elements
                rule("SpaceBeforeJsxAttribute", anyToken, 80 /* Identifier */, [isNextTokenParentJsxAttribute, isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("SpaceBeforeSlashInJsxOpeningElement", anyToken, 44 /* SlashToken */, [isJsxSelfClosingElementContext, isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("NoSpaceBeforeGreaterThanTokenInJsxOpeningElement", 44 /* SlashToken */, 32 /* GreaterThanToken */, [isJsxSelfClosingElementContext, isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("NoSpaceBeforeEqualInJsxAttribute", anyToken, 64 /* EqualsToken */, [isJsxAttributeContext, isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("NoSpaceAfterEqualInJsxAttribute", 64 /* EqualsToken */, anyToken, [isJsxAttributeContext, isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("NoSpaceBeforeJsxNamespaceColon", 80 /* Identifier */, 59 /* ColonToken */, [isNextTokenParentJsxNamespacedName], 16 /* DeleteSpace */),
                rule("NoSpaceAfterJsxNamespaceColon", 59 /* ColonToken */, 80 /* Identifier */, [isNextTokenParentJsxNamespacedName], 16 /* DeleteSpace */),
                // TypeScript-specific rules
                // Use of module as a function call. e.g.: import m2 = module("m2");
                rule("NoSpaceAfterModuleImport", [144 /* ModuleKeyword */, 149 /* RequireKeyword */], 21 /* OpenParenToken */, [isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                // Add a space around certain TypeScript keywords
                rule("SpaceAfterCertainTypeScriptKeywords", [
                    128 /* AbstractKeyword */,
                    129 /* AccessorKeyword */,
                    86 /* ClassKeyword */,
                    138 /* DeclareKeyword */,
                    90 /* DefaultKeyword */,
                    94 /* EnumKeyword */,
                    95 /* ExportKeyword */,
                    96 /* ExtendsKeyword */,
                    139 /* GetKeyword */,
                    119 /* ImplementsKeyword */,
                    102 /* ImportKeyword */,
                    120 /* InterfaceKeyword */,
                    144 /* ModuleKeyword */,
                    145 /* NamespaceKeyword */,
                    123 /* PrivateKeyword */,
                    125 /* PublicKeyword */,
                    124 /* ProtectedKeyword */,
                    148 /* ReadonlyKeyword */,
                    153 /* SetKeyword */,
                    126 /* StaticKeyword */,
                    156 /* TypeKeyword */,
                    161 /* FromKeyword */,
                    143 /* KeyOfKeyword */,
                    140 /* InferKeyword */
                ], anyToken, [isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("SpaceBeforeCertainTypeScriptKeywords", anyToken, [96 /* ExtendsKeyword */, 119 /* ImplementsKeyword */, 161 /* FromKeyword */], [isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                // Treat string literals in module names as identifiers, and add a space between the literal and the opening Brace braces, e.g.: module "m2" {
                rule("SpaceAfterModuleName", 11 /* StringLiteral */, 19 /* OpenBraceToken */, [isModuleDeclContext], 4 /* InsertSpace */),
                // Lambda expressions
                rule("SpaceBeforeArrow", anyToken, 39 /* EqualsGreaterThanToken */, [isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("SpaceAfterArrow", 39 /* EqualsGreaterThanToken */, anyToken, [isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                // Optional parameters and let args
                rule("NoSpaceAfterEllipsis", 26 /* DotDotDotToken */, 80 /* Identifier */, [isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("NoSpaceAfterOptionalParameters", 58 /* QuestionToken */, [22 /* CloseParenToken */, 28 /* CommaToken */], [isNonJsxSameLineTokenContext, isNotBinaryOpContext], 16 /* DeleteSpace */),
                // Remove spaces in empty interface literals. e.g.: x: {}
                rule("NoSpaceBetweenEmptyInterfaceBraceBrackets", 19 /* OpenBraceToken */, 20 /* CloseBraceToken */, [isNonJsxSameLineTokenContext, isObjectTypeContext], 16 /* DeleteSpace */),
                // generics and type assertions
                rule("NoSpaceBeforeOpenAngularBracket", typeNames, 30 /* LessThanToken */, [isNonJsxSameLineTokenContext, isTypeArgumentOrParameterOrAssertionContext], 16 /* DeleteSpace */),
                rule("NoSpaceBetweenCloseParenAndAngularBracket", 22 /* CloseParenToken */, 30 /* LessThanToken */, [isNonJsxSameLineTokenContext, isTypeArgumentOrParameterOrAssertionContext], 16 /* DeleteSpace */),
                rule("NoSpaceAfterOpenAngularBracket", 30 /* LessThanToken */, anyToken, [isNonJsxSameLineTokenContext, isTypeArgumentOrParameterOrAssertionContext], 16 /* DeleteSpace */),
                rule("NoSpaceBeforeCloseAngularBracket", anyToken, 32 /* GreaterThanToken */, [isNonJsxSameLineTokenContext, isTypeArgumentOrParameterOrAssertionContext], 16 /* DeleteSpace */),
                rule("NoSpaceAfterCloseAngularBracket", 32 /* GreaterThanToken */, [21 /* OpenParenToken */, 23 /* OpenBracketToken */, 32 /* GreaterThanToken */, 28 /* CommaToken */], [
                    isNonJsxSameLineTokenContext,
                    isTypeArgumentOrParameterOrAssertionContext,
                    isNotFunctionDeclContext,
                    /*To prevent an interference with the SpaceBeforeOpenParenInFuncDecl rule*/
                    isNonTypeAssertionContext
                ], 16 /* DeleteSpace */),
                // decorators
                rule("SpaceBeforeAt", [22 /* CloseParenToken */, 80 /* Identifier */], 60 /* AtToken */, [isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("NoSpaceAfterAt", 60 /* AtToken */, anyToken, [isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                // Insert space after @ in decorator
                rule("SpaceAfterDecorator", anyToken, [
                    128 /* AbstractKeyword */,
                    80 /* Identifier */,
                    95 /* ExportKeyword */,
                    90 /* DefaultKeyword */,
                    86 /* ClassKeyword */,
                    126 /* StaticKeyword */,
                    125 /* PublicKeyword */,
                    123 /* PrivateKeyword */,
                    124 /* ProtectedKeyword */,
                    139 /* GetKeyword */,
                    153 /* SetKeyword */,
                    23 /* OpenBracketToken */,
                    42 /* AsteriskToken */
                ], [isEndOfDecoratorContextOnSameLine], 4 /* InsertSpace */),
                rule("NoSpaceBeforeNonNullAssertionOperator", anyToken, 54 /* ExclamationToken */, [isNonJsxSameLineTokenContext, isNonNullAssertionContext], 16 /* DeleteSpace */),
                rule("NoSpaceAfterNewKeywordOnConstructorSignature", 105 /* NewKeyword */, 21 /* OpenParenToken */, [isNonJsxSameLineTokenContext, isConstructorSignatureContext], 16 /* DeleteSpace */),
                rule("SpaceLessThanAndNonJSXTypeAnnotation", 30 /* LessThanToken */, 30 /* LessThanToken */, [isNonJsxSameLineTokenContext], 4 /* InsertSpace */)
            ];
            const userConfigurableRules = [
                // Treat constructor as an identifier in a function declaration, and remove spaces between constructor and following left parentheses
                rule("SpaceAfterConstructor", 137 /* ConstructorKeyword */, 21 /* OpenParenToken */, [isOptionEnabled("insertSpaceAfterConstructor"), isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("NoSpaceAfterConstructor", 137 /* ConstructorKeyword */, 21 /* OpenParenToken */, [isOptionDisabledOrUndefined("insertSpaceAfterConstructor"), isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("SpaceAfterComma", 28 /* CommaToken */, anyToken, [isOptionEnabled("insertSpaceAfterCommaDelimiter"), isNonJsxSameLineTokenContext, isNonJsxElementOrFragmentContext, isNextTokenNotCloseBracket, isNextTokenNotCloseParen], 4 /* InsertSpace */),
                rule("NoSpaceAfterComma", 28 /* CommaToken */, anyToken, [isOptionDisabledOrUndefined("insertSpaceAfterCommaDelimiter"), isNonJsxSameLineTokenContext, isNonJsxElementOrFragmentContext], 16 /* DeleteSpace */),
                // Insert space after function keyword for anonymous functions
                rule("SpaceAfterAnonymousFunctionKeyword", [100 /* FunctionKeyword */, 42 /* AsteriskToken */], 21 /* OpenParenToken */, [isOptionEnabled("insertSpaceAfterFunctionKeywordForAnonymousFunctions"), isFunctionDeclContext], 4 /* InsertSpace */),
                rule("NoSpaceAfterAnonymousFunctionKeyword", [100 /* FunctionKeyword */, 42 /* AsteriskToken */], 21 /* OpenParenToken */, [isOptionDisabledOrUndefined("insertSpaceAfterFunctionKeywordForAnonymousFunctions"), isFunctionDeclContext], 16 /* DeleteSpace */),
                // Insert space after keywords in control flow statements
                rule("SpaceAfterKeywordInControl", keywords, 21 /* OpenParenToken */, [isOptionEnabled("insertSpaceAfterKeywordsInControlFlowStatements"), isControlDeclContext], 4 /* InsertSpace */),
                rule("NoSpaceAfterKeywordInControl", keywords, 21 /* OpenParenToken */, [isOptionDisabledOrUndefined("insertSpaceAfterKeywordsInControlFlowStatements"), isControlDeclContext], 16 /* DeleteSpace */),
                // Insert space after opening and before closing nonempty parenthesis
                rule("SpaceAfterOpenParen", 21 /* OpenParenToken */, anyToken, [isOptionEnabled("insertSpaceAfterOpeningAndBeforeClosingNonemptyParenthesis"), isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("SpaceBeforeCloseParen", anyToken, 22 /* CloseParenToken */, [isOptionEnabled("insertSpaceAfterOpeningAndBeforeClosingNonemptyParenthesis"), isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("SpaceBetweenOpenParens", 21 /* OpenParenToken */, 21 /* OpenParenToken */, [isOptionEnabled("insertSpaceAfterOpeningAndBeforeClosingNonemptyParenthesis"), isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("NoSpaceBetweenParens", 21 /* OpenParenToken */, 22 /* CloseParenToken */, [isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("NoSpaceAfterOpenParen", 21 /* OpenParenToken */, anyToken, [isOptionDisabledOrUndefined("insertSpaceAfterOpeningAndBeforeClosingNonemptyParenthesis"), isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("NoSpaceBeforeCloseParen", anyToken, 22 /* CloseParenToken */, [isOptionDisabledOrUndefined("insertSpaceAfterOpeningAndBeforeClosingNonemptyParenthesis"), isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                // Insert space after opening and before closing nonempty brackets
                rule("SpaceAfterOpenBracket", 23 /* OpenBracketToken */, anyToken, [isOptionEnabled("insertSpaceAfterOpeningAndBeforeClosingNonemptyBrackets"), isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("SpaceBeforeCloseBracket", anyToken, 24 /* CloseBracketToken */, [isOptionEnabled("insertSpaceAfterOpeningAndBeforeClosingNonemptyBrackets"), isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("NoSpaceBetweenBrackets", 23 /* OpenBracketToken */, 24 /* CloseBracketToken */, [isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("NoSpaceAfterOpenBracket", 23 /* OpenBracketToken */, anyToken, [isOptionDisabledOrUndefined("insertSpaceAfterOpeningAndBeforeClosingNonemptyBrackets"), isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("NoSpaceBeforeCloseBracket", anyToken, 24 /* CloseBracketToken */, [isOptionDisabledOrUndefined("insertSpaceAfterOpeningAndBeforeClosingNonemptyBrackets"), isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                // Insert a space after { and before } in single-line contexts, but remove space from empty object literals {}.
                rule("SpaceAfterOpenBrace", 19 /* OpenBraceToken */, anyToken, [isOptionEnabledOrUndefined("insertSpaceAfterOpeningAndBeforeClosingNonemptyBraces"), isBraceWrappedContext], 4 /* InsertSpace */),
                rule("SpaceBeforeCloseBrace", anyToken, 20 /* CloseBraceToken */, [isOptionEnabledOrUndefined("insertSpaceAfterOpeningAndBeforeClosingNonemptyBraces"), isBraceWrappedContext], 4 /* InsertSpace */),
                rule("NoSpaceBetweenEmptyBraceBrackets", 19 /* OpenBraceToken */, 20 /* CloseBraceToken */, [isNonJsxSameLineTokenContext, isObjectContext], 16 /* DeleteSpace */),
                rule("NoSpaceAfterOpenBrace", 19 /* OpenBraceToken */, anyToken, [isOptionDisabled("insertSpaceAfterOpeningAndBeforeClosingNonemptyBraces"), isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("NoSpaceBeforeCloseBrace", anyToken, 20 /* CloseBraceToken */, [isOptionDisabled("insertSpaceAfterOpeningAndBeforeClosingNonemptyBraces"), isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                // Insert a space after opening and before closing empty brace brackets
                rule("SpaceBetweenEmptyBraceBrackets", 19 /* OpenBraceToken */, 20 /* CloseBraceToken */, [isOptionEnabled("insertSpaceAfterOpeningAndBeforeClosingEmptyBraces")], 4 /* InsertSpace */),
                rule("NoSpaceBetweenEmptyBraceBrackets", 19 /* OpenBraceToken */, 20 /* CloseBraceToken */, [isOptionDisabled("insertSpaceAfterOpeningAndBeforeClosingEmptyBraces"), isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                // Insert space after opening and before closing template string braces
                rule("SpaceAfterTemplateHeadAndMiddle", [16 /* TemplateHead */, 17 /* TemplateMiddle */], anyToken, [isOptionEnabled("insertSpaceAfterOpeningAndBeforeClosingTemplateStringBraces"), isNonJsxTextContext], 4 /* InsertSpace */, 1 /* CanDeleteNewLines */),
                rule("SpaceBeforeTemplateMiddleAndTail", anyToken, [17 /* TemplateMiddle */, 18 /* TemplateTail */], [isOptionEnabled("insertSpaceAfterOpeningAndBeforeClosingTemplateStringBraces"), isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                rule("NoSpaceAfterTemplateHeadAndMiddle", [16 /* TemplateHead */, 17 /* TemplateMiddle */], anyToken, [isOptionDisabledOrUndefined("insertSpaceAfterOpeningAndBeforeClosingTemplateStringBraces"), isNonJsxTextContext], 16 /* DeleteSpace */, 1 /* CanDeleteNewLines */),
                rule("NoSpaceBeforeTemplateMiddleAndTail", anyToken, [17 /* TemplateMiddle */, 18 /* TemplateTail */], [isOptionDisabledOrUndefined("insertSpaceAfterOpeningAndBeforeClosingTemplateStringBraces"), isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                // No space after { and before } in JSX expression
                rule("SpaceAfterOpenBraceInJsxExpression", 19 /* OpenBraceToken */, anyToken, [isOptionEnabled("insertSpaceAfterOpeningAndBeforeClosingJsxExpressionBraces"), isNonJsxSameLineTokenContext, isJsxExpressionContext], 4 /* InsertSpace */),
                rule("SpaceBeforeCloseBraceInJsxExpression", anyToken, 20 /* CloseBraceToken */, [isOptionEnabled("insertSpaceAfterOpeningAndBeforeClosingJsxExpressionBraces"), isNonJsxSameLineTokenContext, isJsxExpressionContext], 4 /* InsertSpace */),
                rule("NoSpaceAfterOpenBraceInJsxExpression", 19 /* OpenBraceToken */, anyToken, [isOptionDisabledOrUndefined("insertSpaceAfterOpeningAndBeforeClosingJsxExpressionBraces"), isNonJsxSameLineTokenContext, isJsxExpressionContext], 16 /* DeleteSpace */),
                rule("NoSpaceBeforeCloseBraceInJsxExpression", anyToken, 20 /* CloseBraceToken */, [isOptionDisabledOrUndefined("insertSpaceAfterOpeningAndBeforeClosingJsxExpressionBraces"), isNonJsxSameLineTokenContext, isJsxExpressionContext], 16 /* DeleteSpace */),
                // Insert space after semicolon in for statement
                rule("SpaceAfterSemicolonInFor", 27 /* SemicolonToken */, anyToken, [isOptionEnabled("insertSpaceAfterSemicolonInForStatements"), isNonJsxSameLineTokenContext, isForContext], 4 /* InsertSpace */),
                rule("NoSpaceAfterSemicolonInFor", 27 /* SemicolonToken */, anyToken, [isOptionDisabledOrUndefined("insertSpaceAfterSemicolonInForStatements"), isNonJsxSameLineTokenContext, isForContext], 16 /* DeleteSpace */),
                // Insert space before and after binary operators
                rule("SpaceBeforeBinaryOperator", anyToken, binaryOperators, [isOptionEnabled("insertSpaceBeforeAndAfterBinaryOperators"), isNonJsxSameLineTokenContext, isBinaryOpContext], 4 /* InsertSpace */),
                rule("SpaceAfterBinaryOperator", binaryOperators, anyToken, [isOptionEnabled("insertSpaceBeforeAndAfterBinaryOperators"), isNonJsxSameLineTokenContext, isBinaryOpContext], 4 /* InsertSpace */),
                rule("NoSpaceBeforeBinaryOperator", anyToken, binaryOperators, [isOptionDisabledOrUndefined("insertSpaceBeforeAndAfterBinaryOperators"), isNonJsxSameLineTokenContext, isBinaryOpContext], 16 /* DeleteSpace */),
                rule("NoSpaceAfterBinaryOperator", binaryOperators, anyToken, [isOptionDisabledOrUndefined("insertSpaceBeforeAndAfterBinaryOperators"), isNonJsxSameLineTokenContext, isBinaryOpContext], 16 /* DeleteSpace */),
                rule("SpaceBeforeOpenParenInFuncDecl", anyToken, 21 /* OpenParenToken */, [isOptionEnabled("insertSpaceBeforeFunctionParenthesis"), isNonJsxSameLineTokenContext, isFunctionDeclContext], 4 /* InsertSpace */),
                rule("NoSpaceBeforeOpenParenInFuncDecl", anyToken, 21 /* OpenParenToken */, [isOptionDisabledOrUndefined("insertSpaceBeforeFunctionParenthesis"), isNonJsxSameLineTokenContext, isFunctionDeclContext], 16 /* DeleteSpace */),
                // Open Brace braces after control block
                rule("NewLineBeforeOpenBraceInControl", controlOpenBraceLeftTokenRange, 19 /* OpenBraceToken */, [isOptionEnabled("placeOpenBraceOnNewLineForControlBlocks"), isControlDeclContext, isBeforeMultilineBlockContext], 8 /* InsertNewLine */, 1 /* CanDeleteNewLines */),
                // Open Brace braces after function
                // TypeScript: Function can have return types, which can be made of tons of different token kinds
                rule("NewLineBeforeOpenBraceInFunction", functionOpenBraceLeftTokenRange, 19 /* OpenBraceToken */, [isOptionEnabled("placeOpenBraceOnNewLineForFunctions"), isFunctionDeclContext, isBeforeMultilineBlockContext], 8 /* InsertNewLine */, 1 /* CanDeleteNewLines */),
                // Open Brace braces after TypeScript module/class/interface
                rule("NewLineBeforeOpenBraceInTypeScriptDeclWithBlock", typeScriptOpenBraceLeftTokenRange, 19 /* OpenBraceToken */, [isOptionEnabled("placeOpenBraceOnNewLineForFunctions"), isTypeScriptDeclWithBlockContext, isBeforeMultilineBlockContext], 8 /* InsertNewLine */, 1 /* CanDeleteNewLines */),
                rule("SpaceAfterTypeAssertion", 32 /* GreaterThanToken */, anyToken, [isOptionEnabled("insertSpaceAfterTypeAssertion"), isNonJsxSameLineTokenContext, isTypeAssertionContext], 4 /* InsertSpace */),
                rule("NoSpaceAfterTypeAssertion", 32 /* GreaterThanToken */, anyToken, [isOptionDisabledOrUndefined("insertSpaceAfterTypeAssertion"), isNonJsxSameLineTokenContext, isTypeAssertionContext], 16 /* DeleteSpace */),
                rule("SpaceBeforeTypeAnnotation", anyToken, [58 /* QuestionToken */, 59 /* ColonToken */], [isOptionEnabled("insertSpaceBeforeTypeAnnotation"), isNonJsxSameLineTokenContext, isTypeAnnotationContext], 4 /* InsertSpace */),
                rule("NoSpaceBeforeTypeAnnotation", anyToken, [58 /* QuestionToken */, 59 /* ColonToken */], [isOptionDisabledOrUndefined("insertSpaceBeforeTypeAnnotation"), isNonJsxSameLineTokenContext, isTypeAnnotationContext], 16 /* DeleteSpace */),
                rule("NoOptionalSemicolon", 27 /* SemicolonToken */, anyTokenIncludingEOF, [optionEquals("semicolons", "remove" /* Remove */), isSemicolonDeletionContext], 32 /* DeleteToken */),
                rule("OptionalSemicolon", anyToken, anyTokenIncludingEOF, [optionEquals("semicolons", "insert" /* Insert */), isSemicolonInsertionContext], 64 /* InsertTrailingSemicolon */)
            ];
            const lowPriorityCommonRules = [
                // Space after keyword but not before ; or : or ?
                rule("NoSpaceBeforeSemicolon", anyToken, 27 /* SemicolonToken */, [isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("SpaceBeforeOpenBraceInControl", controlOpenBraceLeftTokenRange, 19 /* OpenBraceToken */, [isOptionDisabledOrUndefinedOrTokensOnSameLine("placeOpenBraceOnNewLineForControlBlocks"), isControlDeclContext, isNotFormatOnEnter, isSameLineTokenOrBeforeBlockContext], 4 /* InsertSpace */, 1 /* CanDeleteNewLines */),
                rule("SpaceBeforeOpenBraceInFunction", functionOpenBraceLeftTokenRange, 19 /* OpenBraceToken */, [isOptionDisabledOrUndefinedOrTokensOnSameLine("placeOpenBraceOnNewLineForFunctions"), isFunctionDeclContext, isBeforeBlockContext, isNotFormatOnEnter, isSameLineTokenOrBeforeBlockContext], 4 /* InsertSpace */, 1 /* CanDeleteNewLines */),
                rule("SpaceBeforeOpenBraceInTypeScriptDeclWithBlock", typeScriptOpenBraceLeftTokenRange, 19 /* OpenBraceToken */, [isOptionDisabledOrUndefinedOrTokensOnSameLine("placeOpenBraceOnNewLineForFunctions"), isTypeScriptDeclWithBlockContext, isNotFormatOnEnter, isSameLineTokenOrBeforeBlockContext], 4 /* InsertSpace */, 1 /* CanDeleteNewLines */),
                rule("NoSpaceBeforeComma", anyToken, 28 /* CommaToken */, [isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                // No space before and after indexer `x[]`
                rule("NoSpaceBeforeOpenBracket", anyTokenExcept(134 /* AsyncKeyword */, 84 /* CaseKeyword */), 23 /* OpenBracketToken */, [isNonJsxSameLineTokenContext], 16 /* DeleteSpace */),
                rule("NoSpaceAfterCloseBracket", 24 /* CloseBracketToken */, anyToken, [isNonJsxSameLineTokenContext, isNotBeforeBlockInFunctionDeclarationContext], 16 /* DeleteSpace */),
                rule("SpaceAfterSemicolon", 27 /* SemicolonToken */, anyToken, [isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                // Remove extra space between for and await
                rule("SpaceBetweenForAndAwaitKeyword", 99 /* ForKeyword */, 135 /* AwaitKeyword */, [isNonJsxSameLineTokenContext], 4 /* InsertSpace */),
                // Add a space between statements. All keywords except (do,else,case) has open/close parens after them.
                // So, we have a rule to add a space for [),Any], [do,Any], [else,Any], and [case,Any]
                rule("SpaceBetweenStatements", [22 /* CloseParenToken */, 92 /* DoKeyword */, 93 /* ElseKeyword */, 84 /* CaseKeyword */], anyToken, [isNonJsxSameLineTokenContext, isNonJsxElementOrFragmentContext, isNotForContext], 4 /* InsertSpace */),
                // This low-pri rule takes care of "try {", "catch {" and "finally {" in case the rule SpaceBeforeOpenBraceInControl didn't execute on FormatOnEnter.
                rule("SpaceAfterTryCatchFinally", [113 /* TryKeyword */, 85 /* CatchKeyword */, 98 /* FinallyKeyword */], 19 /* OpenBraceToken */, [isNonJsxSameLineTokenContext], 4 /* InsertSpace */)
            ];
            return [
                ...highPriorityCommonRules,
                ...userConfigurableRules,
                ...lowPriorityCommonRules
            ];
        }
        function rule(debugName, left, right, context, action, flags = 0 /* None */) {
            return { leftTokenRange: toTokenRange(left), rightTokenRange: toTokenRange(right), rule: { debugName, context, action, flags } };
        }
        function tokenRangeFrom(tokens) {
            return { tokens, isSpecific: true };
        }
        function toTokenRange(arg) {
            return typeof arg === "number" ? tokenRangeFrom([arg]) : isArray(arg) ? tokenRangeFrom(arg) : arg;
        }
        function tokenRangeFromRange(from, to, except = []) {
            const tokens = [];
            for (let token = from; token <= to; token++) {
                if (!contains(except, token)) {
                    tokens.push(token);
                }
            }
            return tokenRangeFrom(tokens);
        }
        function optionEquals(optionName, optionValue) {
            return (context) => context.options && context.options[optionName] === optionValue;
        }
        function isOptionEnabled(optionName) {
            return (context) => context.options && hasProperty(context.options, optionName) && !!context.options[optionName];
        }
        function isOptionDisabled(optionName) {
            return (context) => context.options && hasProperty(context.options, optionName) && !context.options[optionName];
        }
        function isOptionDisabledOrUndefined(optionName) {
            return (context) => !context.options || !hasProperty(context.options, optionName) || !context.options[optionName];
        }
        function isOptionDisabledOrUndefinedOrTokensOnSameLine(optionName) {
            return (context) => !context.options || !hasProperty(context.options, optionName) || !context.options[optionName] || context.TokensAreOnSameLine();
        }
        function isOptionEnabledOrUndefined(optionName) {
            return (context) => !context.options || !hasProperty(context.options, optionName) || !!context.options[optionName];
        }
        function isForContext(context) {
            return context.contextNode.kind === 248 /* ForStatement */;
        }
        function isNotForContext(context) {
            return !isForContext(context);
        }
        function isBinaryOpContext(context) {
            switch (context.contextNode.kind) {
                case 226 /* BinaryExpression */:
                    return context.contextNode.operatorToken.kind !== 28 /* CommaToken */;
                case 227 /* ConditionalExpression */:
                case 194 /* ConditionalType */:
                case 234 /* AsExpression */:
                case 281 /* ExportSpecifier */:
                case 276 /* ImportSpecifier */:
                case 182 /* TypePredicate */:
                case 192 /* UnionType */:
                case 193 /* IntersectionType */:
                case 238 /* SatisfiesExpression */:
                    return true;
                case 208 /* BindingElement */:
                case 265 /* TypeAliasDeclaration */:
                case 271 /* ImportEqualsDeclaration */:
                case 277 /* ExportAssignment */:
                case 260 /* VariableDeclaration */:
                case 169 /* Parameter */:
                case 306 /* EnumMember */:
                case 172 /* PropertyDeclaration */:
                case 171 /* PropertySignature */:
                    return context.currentTokenSpan.kind === 64 /* EqualsToken */ || context.nextTokenSpan.kind === 64 /* EqualsToken */;
                case 249 /* ForInStatement */:
                case 168 /* TypeParameter */:
                    return context.currentTokenSpan.kind === 103 /* InKeyword */ || context.nextTokenSpan.kind === 103 /* InKeyword */ || context.currentTokenSpan.kind === 64 /* EqualsToken */ || context.nextTokenSpan.kind === 64 /* EqualsToken */;
                case 250 /* ForOfStatement */:
                    return context.currentTokenSpan.kind === 165 /* OfKeyword */ || context.nextTokenSpan.kind === 165 /* OfKeyword */;
            }
            return false;
        }
        function isNotBinaryOpContext(context) {
            return !isBinaryOpContext(context);
        }
        function isNotTypeAnnotationContext(context) {
            return !isTypeAnnotationContext(context);
        }
        function isTypeAnnotationContext(context) {
            const contextKind = context.contextNode.kind;
            return contextKind === 172 /* PropertyDeclaration */ || contextKind === 171 /* PropertySignature */ || contextKind === 169 /* Parameter */ || contextKind === 260 /* VariableDeclaration */ || isFunctionLikeKind(contextKind);
        }
        function isOptionalPropertyContext(context) {
            return isPropertyDeclaration(context.contextNode) && context.contextNode.questionToken;
        }
        function isNonOptionalPropertyContext(context) {
            return !isOptionalPropertyContext(context);
        }
        function isConditionalOperatorContext(context) {
            return context.contextNode.kind === 227 /* ConditionalExpression */ || context.contextNode.kind === 194 /* ConditionalType */;
        }
        function isSameLineTokenOrBeforeBlockContext(context) {
            return context.TokensAreOnSameLine() || isBeforeBlockContext(context);
        }
        function isBraceWrappedContext(context) {
            return context.contextNode.kind === 206 /* ObjectBindingPattern */ || context.contextNode.kind === 200 /* MappedType */ || isSingleLineBlockContext(context);
        }
        function isBeforeMultilineBlockContext(context) {
            return isBeforeBlockContext(context) && !(context.NextNodeAllOnSameLine() || context.NextNodeBlockIsOnOneLine());
        }
        function isMultilineBlockContext(context) {
            return isBlockContext(context) && !(context.ContextNodeAllOnSameLine() || context.ContextNodeBlockIsOnOneLine());
        }
        function isSingleLineBlockContext(context) {
            return isBlockContext(context) && (context.ContextNodeAllOnSameLine() || context.ContextNodeBlockIsOnOneLine());
        }
        function isBlockContext(context) {
            return nodeIsBlockContext(context.contextNode);
        }
        function isBeforeBlockContext(context) {
            return nodeIsBlockContext(context.nextTokenParent);
        }
        function nodeIsBlockContext(node) {
            if (nodeIsTypeScriptDeclWithBlockContext(node)) {
                return true;
            }
            switch (node.kind) {
                case 241 /* Block */:
                case 269 /* CaseBlock */:
                case 210 /* ObjectLiteralExpression */:
                case 268 /* ModuleBlock */:
                    return true;
            }
            return false;
        }
        function isFunctionDeclContext(context) {
            switch (context.contextNode.kind) {
                case 262 /* FunctionDeclaration */:
                case 174 /* MethodDeclaration */:
                case 173 /* MethodSignature */:
                case 177 /* GetAccessor */:
                case 178 /* SetAccessor */:
                case 179 /* CallSignature */:
                case 218 /* FunctionExpression */:
                case 176 /* Constructor */:
                case 219 /* ArrowFunction */:
                case 264 /* InterfaceDeclaration */:
                    return true;
            }
            return false;
        }
        function isNotFunctionDeclContext(context) {
            return !isFunctionDeclContext(context);
        }
        function isFunctionDeclarationOrFunctionExpressionContext(context) {
            return context.contextNode.kind === 262 /* FunctionDeclaration */ || context.contextNode.kind === 218 /* FunctionExpression */;
        }
        function isTypeScriptDeclWithBlockContext(context) {
            return nodeIsTypeScriptDeclWithBlockContext(context.contextNode);
        }
        function nodeIsTypeScriptDeclWithBlockContext(node) {
            switch (node.kind) {
                case 263 /* ClassDeclaration */:
                case 231 /* ClassExpression */:
                case 264 /* InterfaceDeclaration */:
                case 266 /* EnumDeclaration */:
                case 187 /* TypeLiteral */:
                case 267 /* ModuleDeclaration */:
                case 278 /* ExportDeclaration */:
                case 279 /* NamedExports */:
                case 272 /* ImportDeclaration */:
                case 275 /* NamedImports */:
                    return true;
            }
            return false;
        }
        function isAfterCodeBlockContext(context) {
            switch (context.currentTokenParent.kind) {
                case 263 /* ClassDeclaration */:
                case 267 /* ModuleDeclaration */:
                case 266 /* EnumDeclaration */:
                case 299 /* CatchClause */:
                case 268 /* ModuleBlock */:
                case 255 /* SwitchStatement */:
                    return true;
                case 241 /* Block */: {
                    const blockParent = context.currentTokenParent.parent;
                    if (!blockParent || blockParent.kind !== 219 /* ArrowFunction */ && blockParent.kind !== 218 /* FunctionExpression */) {
                        return true;
                    }
                }
            }
            return false;
        }
        function isControlDeclContext(context) {
            switch (context.contextNode.kind) {
                case 245 /* IfStatement */:
                case 255 /* SwitchStatement */:
                case 248 /* ForStatement */:
                case 249 /* ForInStatement */:
                case 250 /* ForOfStatement */:
                case 247 /* WhileStatement */:
                case 258 /* TryStatement */:
                case 246 /* DoStatement */:
                case 254 /* WithStatement */:
                case 299 /* CatchClause */:
                    return true;
                default:
                    return false;
            }
        }
        function isObjectContext(context) {
            return context.contextNode.kind === 210 /* ObjectLiteralExpression */;
        }
        function isFunctionCallContext(context) {
            return context.contextNode.kind === 213 /* CallExpression */;
        }
        function isNewContext(context) {
            return context.contextNode.kind === 214 /* NewExpression */;
        }
        function isFunctionCallOrNewContext(context) {
            return isFunctionCallContext(context) || isNewContext(context);
        }
        function isPreviousTokenNotComma(context) {
            return context.currentTokenSpan.kind !== 28 /* CommaToken */;
        }
        function isNextTokenNotCloseBracket(context) {
            return context.nextTokenSpan.kind !== 24 /* CloseBracketToken */;
        }
        function isNextTokenNotCloseParen(context) {
            return context.nextTokenSpan.kind !== 22 /* CloseParenToken */;
        }
        function isArrowFunctionContext(context) {
            return context.contextNode.kind === 219 /* ArrowFunction */;
        }
        function isImportTypeContext(context) {
            return context.contextNode.kind === 205 /* ImportType */;
        }
        function isNonJsxSameLineTokenContext(context) {
            return context.TokensAreOnSameLine() && context.contextNode.kind !== 12 /* JsxText */;
        }
        function isNonJsxTextContext(context) {
            return context.contextNode.kind !== 12 /* JsxText */;
        }
        function isNonJsxElementOrFragmentContext(context) {
            return context.contextNode.kind !== 284 /* JsxElement */ && context.contextNode.kind !== 288 /* JsxFragment */;
        }
        function isJsxExpressionContext(context) {
            return context.contextNode.kind === 294 /* JsxExpression */ || context.contextNode.kind === 293 /* JsxSpreadAttribute */;
        }
        function isNextTokenParentJsxAttribute(context) {
            return context.nextTokenParent.kind === 291 /* JsxAttribute */ || context.nextTokenParent.kind === 295 /* JsxNamespacedName */ && context.nextTokenParent.parent.kind === 291 /* JsxAttribute */;
        }
        function isJsxAttributeContext(context) {
            return context.contextNode.kind === 291 /* JsxAttribute */;
        }
        function isNextTokenParentNotJsxNamespacedName(context) {
            return context.nextTokenParent.kind !== 295 /* JsxNamespacedName */;
        }
        function isNextTokenParentJsxNamespacedName(context) {
            return context.nextTokenParent.kind === 295 /* JsxNamespacedName */;
        }
        function isJsxSelfClosingElementContext(context) {
            return context.contextNode.kind === 285 /* JsxSelfClosingElement */;
        }
        function isNotBeforeBlockInFunctionDeclarationContext(context) {
            return !isFunctionDeclContext(context) && !isBeforeBlockContext(context);
        }
        function isEndOfDecoratorContextOnSameLine(context) {
            return context.TokensAreOnSameLine() && hasDecorators(context.contextNode) && nodeIsInDecoratorContext(context.currentTokenParent) && !nodeIsInDecoratorContext(context.nextTokenParent);
        }
        function nodeIsInDecoratorContext(node) {
            while (node && isExpression(node)) {
                node = node.parent;
            }
            return node && node.kind === 170 /* Decorator */;
        }
        function isStartOfVariableDeclarationList(context) {
            return context.currentTokenParent.kind === 261 /* VariableDeclarationList */ && context.currentTokenParent.getStart(context.sourceFile) === context.currentTokenSpan.pos;
        }
        function isNotFormatOnEnter(context) {
            return context.formattingRequestKind !== 2 /* FormatOnEnter */;
        }
        function isModuleDeclContext(context) {
            return context.contextNode.kind === 267 /* ModuleDeclaration */;
        }
        function isObjectTypeContext(context) {
            return context.contextNode.kind === 187 /* TypeLiteral */;
        }
        function isConstructorSignatureContext(context) {
            return context.contextNode.kind === 180 /* ConstructSignature */;
        }
        function isTypeArgumentOrParameterOrAssertion(token, parent2) {
            if (token.kind !== 30 /* LessThanToken */ && token.kind !== 32 /* GreaterThanToken */) {
                return false;
            }
            switch (parent2.kind) {
                case 183 /* TypeReference */:
                case 216 /* TypeAssertionExpression */:
                case 265 /* TypeAliasDeclaration */:
                case 263 /* ClassDeclaration */:
                case 231 /* ClassExpression */:
                case 264 /* InterfaceDeclaration */:
                case 262 /* FunctionDeclaration */:
                case 218 /* FunctionExpression */:
                case 219 /* ArrowFunction */:
                case 174 /* MethodDeclaration */:
                case 173 /* MethodSignature */:
                case 179 /* CallSignature */:
                case 180 /* ConstructSignature */:
                case 213 /* CallExpression */:
                case 214 /* NewExpression */:
                case 233 /* ExpressionWithTypeArguments */:
                    return true;
                default:
                    return false;
            }
        }
        function isTypeArgumentOrParameterOrAssertionContext(context) {
            return isTypeArgumentOrParameterOrAssertion(context.currentTokenSpan, context.currentTokenParent) || isTypeArgumentOrParameterOrAssertion(context.nextTokenSpan, context.nextTokenParent);
        }
        function isTypeAssertionContext(context) {
            return context.contextNode.kind === 216 /* TypeAssertionExpression */;
        }
        function isNonTypeAssertionContext(context) {
            return !isTypeAssertionContext(context);
        }
        function isVoidOpContext(context) {
            return context.currentTokenSpan.kind === 116 /* VoidKeyword */ && context.currentTokenParent.kind === 222 /* VoidExpression */;
        }
        function isYieldOrYieldStarWithOperand(context) {
            return context.contextNode.kind === 229 /* YieldExpression */ && context.contextNode.expression !== void 0;
        }
        function isNonNullAssertionContext(context) {
            return context.contextNode.kind === 235 /* NonNullExpression */;
        }
        function isNotStatementConditionContext(context) {
            return !isStatementConditionContext(context);
        }
        function isStatementConditionContext(context) {
            switch (context.contextNode.kind) {
                case 245 /* IfStatement */:
                case 248 /* ForStatement */:
                case 249 /* ForInStatement */:
                case 250 /* ForOfStatement */:
                case 246 /* DoStatement */:
                case 247 /* WhileStatement */:
                    return true;
                default:
                    return false;
            }
        }
        function isSemicolonDeletionContext(context) {
            let nextTokenKind = context.nextTokenSpan.kind;
            let nextTokenStart = context.nextTokenSpan.pos;
            if (isTrivia(nextTokenKind)) {
                const nextRealToken = context.nextTokenParent === context.currentTokenParent ? findNextToken(context.currentTokenParent, findAncestor(context.currentTokenParent, (a) => !a.parent), context.sourceFile) : context.nextTokenParent.getFirstToken(context.sourceFile);
                if (!nextRealToken) {
                    return true;
                }
                nextTokenKind = nextRealToken.kind;
                nextTokenStart = nextRealToken.getStart(context.sourceFile);
            }
            const startLine = context.sourceFile.getLineAndCharacterOfPosition(context.currentTokenSpan.pos).line;
            const endLine = context.sourceFile.getLineAndCharacterOfPosition(nextTokenStart).line;
            if (startLine === endLine) {
                return nextTokenKind === 20 /* CloseBraceToken */ || nextTokenKind === 1 /* EndOfFileToken */;
            }
            if (nextTokenKind === 240 /* SemicolonClassElement */ || nextTokenKind === 27 /* SemicolonToken */) {
                return false;
            }
            if (context.contextNode.kind === 264 /* InterfaceDeclaration */ || context.contextNode.kind === 265 /* TypeAliasDeclaration */) {
                return !isPropertySignature(context.currentTokenParent) || !!context.currentTokenParent.type || nextTokenKind !== 21 /* OpenParenToken */;
            }
            if (isPropertyDeclaration(context.currentTokenParent)) {
                return !context.currentTokenParent.initializer;
            }
            return context.currentTokenParent.kind !== 248 /* ForStatement */ && context.currentTokenParent.kind !== 242 /* EmptyStatement */ && context.currentTokenParent.kind !== 240 /* SemicolonClassElement */ && nextTokenKind !== 23 /* OpenBracketToken */ && nextTokenKind !== 21 /* OpenParenToken */ && nextTokenKind !== 40 /* PlusToken */ && nextTokenKind !== 41 /* MinusToken */ && nextTokenKind !== 44 /* SlashToken */ && nextTokenKind !== 14 /* RegularExpressionLiteral */ && nextTokenKind !== 28 /* CommaToken */ && nextTokenKind !== 228 /* TemplateExpression */ && nextTokenKind !== 16 /* TemplateHead */ && nextTokenKind !== 15 /* NoSubstitutionTemplateLiteral */ && nextTokenKind !== 25 /* DotToken */;
        }
        function isSemicolonInsertionContext(context) {
            return positionIsASICandidate(context.currentTokenSpan.end, context.currentTokenParent, context.sourceFile);
        }
        function isNotPropertyAccessOnIntegerLiteral(context) {
            return !isPropertyAccessExpression(context.contextNode) || !isNumericLiteral(context.contextNode.expression) || context.contextNode.expression.getText().includes(".");
        }
        var init_rules = __esm({
            "src/services/formatting/rules.ts"() {
                "use strict";
                init_ts4();
                init_ts_formatting();
            }
        });
        // src/services/formatting/rulesMap.ts
        function getFormatContext(options, host) {
            return { options, getRules: getRulesMap(), host };
        }
        function getRulesMap() {
            if (rulesMapCache === void 0) {
                rulesMapCache = createRulesMap(getAllRules());
            }
            return rulesMapCache;
        }
        function getRuleActionExclusion(ruleAction) {
            let mask2 = 0 /* None */;
            if (ruleAction & 1 /* StopProcessingSpaceActions */) {
                mask2 |= 28 /* ModifySpaceAction */;
            }
            if (ruleAction & 2 /* StopProcessingTokenActions */) {
                mask2 |= 96 /* ModifyTokenAction */;
            }
            if (ruleAction & 28 /* ModifySpaceAction */) {
                mask2 |= 28 /* ModifySpaceAction */;
            }
            if (ruleAction & 96 /* ModifyTokenAction */) {
                mask2 |= 96 /* ModifyTokenAction */;
            }
            return mask2;
        }
        function createRulesMap(rules) {
            const map2 = buildMap(rules);
            return (context) => {
                const bucket = map2[getRuleBucketIndex(context.currentTokenSpan.kind, context.nextTokenSpan.kind)];
                if (bucket) {
                    const rules2 = [];
                    let ruleActionMask = 0;
                    for (const rule2 of bucket) {
                        const acceptRuleActions = ~getRuleActionExclusion(ruleActionMask);
                        if (rule2.action & acceptRuleActions && every(rule2.context, (c) => c(context))) {
                            rules2.push(rule2);
                            ruleActionMask |= rule2.action;
                        }
                    }
                    if (rules2.length) {
                        return rules2;
                    }
                }
            };
        }
        function buildMap(rules) {
            const map2 = new Array(mapRowLength * mapRowLength);
            const rulesBucketConstructionStateList = new Array(map2.length);
            for (const rule2 of rules) {
                const specificRule = rule2.leftTokenRange.isSpecific && rule2.rightTokenRange.isSpecific;
                for (const left of rule2.leftTokenRange.tokens) {
                    for (const right of rule2.rightTokenRange.tokens) {
                        const index = getRuleBucketIndex(left, right);
                        let rulesBucket = map2[index];
                        if (rulesBucket === void 0) {
                            rulesBucket = map2[index] = [];
                        }
                        addRule(rulesBucket, rule2.rule, specificRule, rulesBucketConstructionStateList, index);
                    }
                }
            }
            return map2;
        }
        function getRuleBucketIndex(row, column) {
            Debug.assert(row <= 165 /* LastKeyword */ && column <= 165 /* LastKeyword */, "Must compute formatting context from tokens");
            return row * mapRowLength + column;
        }
        function addRule(rules, rule2, specificTokens, constructionState, rulesBucketIndex) {
            const position = rule2.action & 3 /* StopAction */ ? specificTokens ? 0 /* StopRulesSpecific */ : RulesPosition.StopRulesAny : rule2.context !== anyContext ? specificTokens ? RulesPosition.ContextRulesSpecific : RulesPosition.ContextRulesAny : specificTokens ? RulesPosition.NoContextRulesSpecific : RulesPosition.NoContextRulesAny;
            const state = constructionState[rulesBucketIndex] || 0;
            rules.splice(getInsertionIndex(state, position), 0, rule2);
            constructionState[rulesBucketIndex] = increaseInsertionIndex(state, position);
        }
        function getInsertionIndex(indexBitmap, maskPosition) {
            let index = 0;
            for (let pos = 0; pos <= maskPosition; pos += maskBitSize) {
                index += indexBitmap & mask;
                indexBitmap >>= maskBitSize;
            }
            return index;
        }
        function increaseInsertionIndex(indexBitmap, maskPosition) {
            const value = (indexBitmap >> maskPosition & mask) + 1;
            Debug.assert((value & mask) === value, "Adding more rules into the sub-bucket than allowed. Maximum allowed is 32 rules.");
            return indexBitmap & ~(mask << maskPosition) | value << maskPosition;
        }
        var rulesMapCache, maskBitSize, mask, mapRowLength, RulesPosition;
        var init_rulesMap = __esm({
            "src/services/formatting/rulesMap.ts"() {
                "use strict";
                init_ts4();
                init_ts_formatting();
                maskBitSize = 5;
                mask = 31;
                mapRowLength = 165 /* LastToken */ + 1;
                RulesPosition = ((RulesPosition2) => {
                    RulesPosition2[RulesPosition2["StopRulesSpecific"] = 0] = "StopRulesSpecific";
                    RulesPosition2[RulesPosition2["StopRulesAny"] = maskBitSize * 1] = "StopRulesAny";
                    RulesPosition2[RulesPosition2["ContextRulesSpecific"] = maskBitSize * 2] = "ContextRulesSpecific";
                    RulesPosition2[RulesPosition2["ContextRulesAny"] = maskBitSize * 3] = "ContextRulesAny";
                    RulesPosition2[RulesPosition2["NoContextRulesSpecific"] = maskBitSize * 4] = "NoContextRulesSpecific";
                    RulesPosition2[RulesPosition2["NoContextRulesAny"] = maskBitSize * 5] = "NoContextRulesAny";
                    return RulesPosition2;
                })(RulesPosition || {});
            }
        });
        // src/services/formatting/formatting.ts
        function createTextRangeWithKind(pos, end, kind) {
            const textRangeWithKind = { pos, end, kind };
            if (Debug.isDebugging) {
                Object.defineProperty(textRangeWithKind, "__debugKind", {
                    get: () => Debug.formatSyntaxKind(kind)
                });
            }
            return textRangeWithKind;
        }
        function formatOnEnter(position, sourceFile, formatContext) {
            const line = sourceFile.getLineAndCharacterOfPosition(position).line;
            if (line === 0) {
                return [];
            }
            let endOfFormatSpan = getEndLinePosition(line, sourceFile);
            while (isWhiteSpaceSingleLine(sourceFile.text.charCodeAt(endOfFormatSpan))) {
                endOfFormatSpan--;
            }
            if (isLineBreak(sourceFile.text.charCodeAt(endOfFormatSpan))) {
                endOfFormatSpan--;
            }
            const span = {
                // get start position for the previous line
                pos: getStartPositionOfLine(line - 1, sourceFile),
                // end value is exclusive so add 1 to the result
                end: endOfFormatSpan + 1
            };
            return formatSpan(span, sourceFile, formatContext, 2 /* FormatOnEnter */);
        }
        function formatOnSemicolon(position, sourceFile, formatContext) {
            const semicolon = findImmediatelyPrecedingTokenOfKind(position, 27 /* SemicolonToken */, sourceFile);
            return formatNodeLines(findOutermostNodeWithinListLevel(semicolon), sourceFile, formatContext, 3 /* FormatOnSemicolon */);
        }
        function formatOnOpeningCurly(position, sourceFile, formatContext) {
            const openingCurly = findImmediatelyPrecedingTokenOfKind(position, 19 /* OpenBraceToken */, sourceFile);
            if (!openingCurly) {
                return [];
            }
            const curlyBraceRange = openingCurly.parent;
            const outermostNode = findOutermostNodeWithinListLevel(curlyBraceRange);
            const textRange = {
                pos: getLineStartPositionForPosition(outermostNode.getStart(sourceFile), sourceFile),
                // TODO: GH#18217
                end: position
            };
            return formatSpan(textRange, sourceFile, formatContext, 4 /* FormatOnOpeningCurlyBrace */);
        }
        function formatOnClosingCurly(position, sourceFile, formatContext) {
            const precedingToken = findImmediatelyPrecedingTokenOfKind(position, 20 /* CloseBraceToken */, sourceFile);
            return formatNodeLines(findOutermostNodeWithinListLevel(precedingToken), sourceFile, formatContext, 5 /* FormatOnClosingCurlyBrace */);
        }
        function formatDocument(sourceFile, formatContext) {
            const span = {
                pos: 0,
                end: sourceFile.text.length
            };
            return formatSpan(span, sourceFile, formatContext, 0 /* FormatDocument */);
        }
        function formatSelection(start, end, sourceFile, formatContext) {
            const span = {
                pos: getLineStartPositionForPosition(start, sourceFile),
                end
            };
            return formatSpan(span, sourceFile, formatContext, 1 /* FormatSelection */);
        }
        function findImmediatelyPrecedingTokenOfKind(end, expectedTokenKind, sourceFile) {
            const precedingToken = findPrecedingToken(end, sourceFile);
            return precedingToken && precedingToken.kind === expectedTokenKind && end === precedingToken.getEnd() ? precedingToken : void 0;
        }
        function findOutermostNodeWithinListLevel(node) {
            let current = node;
            while (current && current.parent && current.parent.end === node.end && !isListElement(current.parent, current)) {
                current = current.parent;
            }
            return current;
        }
        function isListElement(parent2, node) {
            switch (parent2.kind) {
                case 263 /* ClassDeclaration */:
                case 264 /* InterfaceDeclaration */:
                    return rangeContainsRange(parent2.members, node);
                case 267 /* ModuleDeclaration */:
                    const body = parent2.body;
                    return !!body && body.kind === 268 /* ModuleBlock */ && rangeContainsRange(body.statements, node);
                case 312 /* SourceFile */:
                case 241 /* Block */:
                case 268 /* ModuleBlock */:
                    return rangeContainsRange(parent2.statements, node);
                case 299 /* CatchClause */:
                    return rangeContainsRange(parent2.block.statements, node);
            }
            return false;
        }
        function findEnclosingNode(range, sourceFile) {
            return find2(sourceFile);
            function find2(n) {
                const candidate = forEachChild(n, (c) => startEndContainsRange(c.getStart(sourceFile), c.end, range) && c);
                if (candidate) {
                    const result = find2(candidate);
                    if (result) {
                        return result;
                    }
                }
                return n;
            }
        }
        function prepareRangeContainsErrorFunction(errors, originalRange) {
            if (!errors.length) {
                return rangeHasNoErrors;
            }
            const sorted = errors.filter((d) => rangeOverlapsWithStartEnd(originalRange, d.start, d.start + d.length)).sort((e1, e2) => e1.start - e2.start);
            if (!sorted.length) {
                return rangeHasNoErrors;
            }
            let index = 0;
            return (r) => {
                while (true) {
                    if (index >= sorted.length) {
                        return false;
                    }
                    const error2 = sorted[index];
                    if (r.end <= error2.start) {
                        return false;
                    }
                    if (startEndOverlapsWithStartEnd(r.pos, r.end, error2.start, error2.start + error2.length)) {
                        return true;
                    }
                    index++;
                }
            };
            function rangeHasNoErrors() {
                return false;
            }
        }
        function getScanStartPosition(enclosingNode, originalRange, sourceFile) {
            const start = enclosingNode.getStart(sourceFile);
            if (start === originalRange.pos && enclosingNode.end === originalRange.end) {
                return start;
            }
            const precedingToken = findPrecedingToken(originalRange.pos, sourceFile);
            if (!precedingToken) {
                return enclosingNode.pos;
            }
            if (precedingToken.end >= originalRange.pos) {
                return enclosingNode.pos;
            }
            return precedingToken.end;
        }
        function getOwnOrInheritedDelta(n, options, sourceFile) {
            let previousLine = -1 /* Unknown */;
            let child;
            while (n) {
                const line = sourceFile.getLineAndCharacterOfPosition(n.getStart(sourceFile)).line;
                if (previousLine !== -1 /* Unknown */ && line !== previousLine) {
                    break;
                }
                if (SmartIndenter.shouldIndentChildNode(options, n, child, sourceFile)) {
                    return options.indentSize;
                }
                previousLine = line;
                child = n;
                n = n.parent;
            }
            return 0;
        }
        function formatNodeGivenIndentation(node, sourceFileLike, languageVariant, initialIndentation, delta, formatContext) {
            const range = { pos: node.pos, end: node.end };
            return getFormattingScanner(sourceFileLike.text, languageVariant, range.pos, range.end, (scanner2) => formatSpanWorker(range, node, initialIndentation, delta, scanner2, formatContext, 1 /* FormatSelection */, (_) => false, 
            // assume that node does not have any errors
            sourceFileLike));
        }
        function formatNodeLines(node, sourceFile, formatContext, requestKind) {
            if (!node) {
                return [];
            }
            const span = {
                pos: getLineStartPositionForPosition(node.getStart(sourceFile), sourceFile),
                end: node.end
            };
            return formatSpan(span, sourceFile, formatContext, requestKind);
        }
        function formatSpan(originalRange, sourceFile, formatContext, requestKind) {
            const enclosingNode = findEnclosingNode(originalRange, sourceFile);
            return getFormattingScanner(sourceFile.text, sourceFile.languageVariant, getScanStartPosition(enclosingNode, originalRange, sourceFile), originalRange.end, (scanner2) => formatSpanWorker(originalRange, enclosingNode, SmartIndenter.getIndentationForNode(enclosingNode, originalRange, sourceFile, formatContext.options), getOwnOrInheritedDelta(enclosingNode, formatContext.options, sourceFile), scanner2, formatContext, requestKind, prepareRangeContainsErrorFunction(sourceFile.parseDiagnostics, originalRange), sourceFile));
        }
        function formatSpanWorker(originalRange, enclosingNode, initialIndentation, delta, formattingScanner, { options, getRules, host }, requestKind, rangeContainsError, sourceFile) {
            var _a;
            const formattingContext = new FormattingContext(sourceFile, requestKind, options);
            let previousRangeTriviaEnd;
            let previousRange;
            let previousParent;
            let previousRangeStartLine;
            let lastIndentedLine;
            let indentationOnLastIndentedLine = -1 /* Unknown */;
            const edits = [];
            formattingScanner.advance();
            if (formattingScanner.isOnToken()) {
                const startLine = sourceFile.getLineAndCharacterOfPosition(enclosingNode.getStart(sourceFile)).line;
                let undecoratedStartLine = startLine;
                if (hasDecorators(enclosingNode)) {
                    undecoratedStartLine = sourceFile.getLineAndCharacterOfPosition(getNonDecoratorTokenPosOfNode(enclosingNode, sourceFile)).line;
                }
                processNode(enclosingNode, enclosingNode, startLine, undecoratedStartLine, initialIndentation, delta);
            }
            const remainingTrivia = formattingScanner.getCurrentLeadingTrivia();
            if (remainingTrivia) {
                const indentation = SmartIndenter.nodeWillIndentChild(options, enclosingNode, 
                /*child*/
                void 0, sourceFile, 
                /*indentByDefault*/
                false) ? initialIndentation + options.indentSize : initialIndentation;
                indentTriviaItems(remainingTrivia, indentation, 
                /*indentNextTokenOrTrivia*/
                true, (item) => {
                    processRange(item, sourceFile.getLineAndCharacterOfPosition(item.pos), enclosingNode, enclosingNode, 
                    /*dynamicIndentation*/
                    void 0);
                    insertIndentation(item.pos, indentation, 
                    /*lineAdded*/
                    false);
                });
                if (options.trimTrailingWhitespace !== false) {
                    trimTrailingWhitespacesForRemainingRange(remainingTrivia);
                }
            }
            if (previousRange && formattingScanner.getTokenFullStart() >= originalRange.end) {
                const tokenInfo = formattingScanner.isOnEOF() ? formattingScanner.readEOFTokenRange() : formattingScanner.isOnToken() ? formattingScanner.readTokenInfo(enclosingNode).token : void 0;
                if (tokenInfo && tokenInfo.pos === previousRangeTriviaEnd) {
                    const parent2 = ((_a = findPrecedingToken(tokenInfo.end, sourceFile, enclosingNode)) == null ? void 0 : _a.parent) || previousParent;
                    processPair(tokenInfo, sourceFile.getLineAndCharacterOfPosition(tokenInfo.pos).line, parent2, previousRange, previousRangeStartLine, previousParent, parent2, 
                    /*dynamicIndentation*/
                    void 0);
                }
            }
            return edits;
            function tryComputeIndentationForListItem(startPos, endPos, parentStartLine, range, inheritedIndentation) {
                if (rangeOverlapsWithStartEnd(range, startPos, endPos) || rangeContainsStartEnd(range, startPos, endPos)) {
                    if (inheritedIndentation !== -1 /* Unknown */) {
                        return inheritedIndentation;
                    }
                }
                else {
                    const startLine = sourceFile.getLineAndCharacterOfPosition(startPos).line;
                    const startLinePosition = getLineStartPositionForPosition(startPos, sourceFile);
                    const column = SmartIndenter.findFirstNonWhitespaceColumn(startLinePosition, startPos, sourceFile, options);
                    if (startLine !== parentStartLine || startPos === column) {
                        const baseIndentSize = SmartIndenter.getBaseIndentation(options);
                        return baseIndentSize > column ? baseIndentSize : column;
                    }
                }
                return -1 /* Unknown */;
            }
            function computeIndentation(node, startLine, inheritedIndentation, parent2, parentDynamicIndentation, effectiveParentStartLine) {
                const delta2 = SmartIndenter.shouldIndentChildNode(options, node) ? options.indentSize : 0;
                if (effectiveParentStartLine === startLine) {
                    return {
                        indentation: startLine === lastIndentedLine ? indentationOnLastIndentedLine : parentDynamicIndentation.getIndentation(),
                        delta: Math.min(options.indentSize, parentDynamicIndentation.getDelta(node) + delta2)
                    };
                }
                else if (inheritedIndentation === -1 /* Unknown */) {
                    if (node.kind === 21 /* OpenParenToken */ && startLine === lastIndentedLine) {
                        return { indentation: indentationOnLastIndentedLine, delta: parentDynamicIndentation.getDelta(node) };
                    }
                    else if (SmartIndenter.childStartsOnTheSameLineWithElseInIfStatement(parent2, node, startLine, sourceFile) || SmartIndenter.childIsUnindentedBranchOfConditionalExpression(parent2, node, startLine, sourceFile) || SmartIndenter.argumentStartsOnSameLineAsPreviousArgument(parent2, node, startLine, sourceFile)) {
                        return { indentation: parentDynamicIndentation.getIndentation(), delta: delta2 };
                    }
                    else {
                        return { indentation: parentDynamicIndentation.getIndentation() + parentDynamicIndentation.getDelta(node), delta: delta2 };
                    }
                }
                else {
                    return { indentation: inheritedIndentation, delta: delta2 };
                }
            }
            function getFirstNonDecoratorTokenOfNode(node) {
                if (canHaveModifiers(node)) {
                    const modifier = find(node.modifiers, isModifier, findIndex(node.modifiers, isDecorator));
                    if (modifier)
                        return modifier.kind;
                }
                switch (node.kind) {
                    case 263 /* ClassDeclaration */:
                        return 86 /* ClassKeyword */;
                    case 264 /* InterfaceDeclaration */:
                        return 120 /* InterfaceKeyword */;
                    case 262 /* FunctionDeclaration */:
                        return 100 /* FunctionKeyword */;
                    case 266 /* EnumDeclaration */:
                        return 266 /* EnumDeclaration */;
                    case 177 /* GetAccessor */:
                        return 139 /* GetKeyword */;
                    case 178 /* SetAccessor */:
                        return 153 /* SetKeyword */;
                    case 174 /* MethodDeclaration */:
                        if (node.asteriskToken) {
                            return 42 /* AsteriskToken */;
                        }
                    case 172 /* PropertyDeclaration */:
                    case 169 /* Parameter */:
                        const name = getNameOfDeclaration(node);
                        if (name) {
                            return name.kind;
                        }
                }
            }
            function getDynamicIndentation(node, nodeStartLine, indentation, delta2) {
                return {
                    getIndentationForComment: (kind, tokenIndentation, container) => {
                        switch (kind) {
                            case 20 /* CloseBraceToken */:
                            case 24 /* CloseBracketToken */:
                            case 22 /* CloseParenToken */:
                                return indentation + getDelta(container);
                        }
                        return tokenIndentation !== -1 /* Unknown */ ? tokenIndentation : indentation;
                    },
                    // if list end token is LessThanToken '>' then its delta should be explicitly suppressed
                    // so that LessThanToken as a binary operator can still be indented.
                    // foo.then
                    //     <
                    //         number,
                    //         string,
                    //     >();
                    // vs
                    // var a = xValue
                    //     > yValue;
                    getIndentationForToken: (line, kind, container, suppressDelta) => !suppressDelta && shouldAddDelta(line, kind, container) ? indentation + getDelta(container) : indentation,
                    getIndentation: () => indentation,
                    getDelta,
                    recomputeIndentation: (lineAdded, parent2) => {
                        if (SmartIndenter.shouldIndentChildNode(options, parent2, node, sourceFile)) {
                            indentation += lineAdded ? options.indentSize : -options.indentSize;
                            delta2 = SmartIndenter.shouldIndentChildNode(options, node) ? options.indentSize : 0;
                        }
                    }
                };
                function shouldAddDelta(line, kind, container) {
                    switch (kind) {
                        case 19 /* OpenBraceToken */:
                        case 20 /* CloseBraceToken */:
                        case 22 /* CloseParenToken */:
                        case 93 /* ElseKeyword */:
                        case 117 /* WhileKeyword */:
                        case 60 /* AtToken */:
                            return false;
                        case 44 /* SlashToken */:
                        case 32 /* GreaterThanToken */:
                            switch (container.kind) {
                                case 286 /* JsxOpeningElement */:
                                case 287 /* JsxClosingElement */:
                                case 285 /* JsxSelfClosingElement */:
                                    return false;
                            }
                            break;
                        case 23 /* OpenBracketToken */:
                        case 24 /* CloseBracketToken */:
                            if (container.kind !== 200 /* MappedType */) {
                                return false;
                            }
                            break;
                    }
                    return nodeStartLine !== line && !(hasDecorators(node) && kind === getFirstNonDecoratorTokenOfNode(node));
                }
                function getDelta(child) {
                    return SmartIndenter.nodeWillIndentChild(options, node, child, sourceFile, 
                    /*indentByDefault*/
                    true) ? delta2 : 0;
                }
            }
            function processNode(node, contextNode, nodeStartLine, undecoratedNodeStartLine, indentation, delta2) {
                if (!rangeOverlapsWithStartEnd(originalRange, node.getStart(sourceFile), node.getEnd())) {
                    return;
                }
                const nodeDynamicIndentation = getDynamicIndentation(node, nodeStartLine, indentation, delta2);
                let childContextNode = contextNode;
                forEachChild(node, (child) => {
                    processChildNode(child, 
                    /*inheritedIndentation*/
                    -1 /* Unknown */, node, nodeDynamicIndentation, nodeStartLine, undecoratedNodeStartLine, 
                    /*isListItem*/
                    false);
                }, (nodes) => {
                    processChildNodes(nodes, node, nodeStartLine, nodeDynamicIndentation);
                });
                while (formattingScanner.isOnToken() && formattingScanner.getTokenFullStart() < originalRange.end) {
                    const tokenInfo = formattingScanner.readTokenInfo(node);
                    if (tokenInfo.token.end > Math.min(node.end, originalRange.end)) {
                        break;
                    }
                    consumeTokenAndAdvanceScanner(tokenInfo, node, nodeDynamicIndentation, node);
                }
                function processChildNode(child, inheritedIndentation, parent2, parentDynamicIndentation, parentStartLine, undecoratedParentStartLine, isListItem, isFirstListItem) {
                    Debug.assert(!nodeIsSynthesized(child));
                    if (nodeIsMissing(child) || isGrammarError(parent2, child)) {
                        return inheritedIndentation;
                    }
                    const childStartPos = child.getStart(sourceFile);
                    const childStartLine = sourceFile.getLineAndCharacterOfPosition(childStartPos).line;
                    let undecoratedChildStartLine = childStartLine;
                    if (hasDecorators(child)) {
                        undecoratedChildStartLine = sourceFile.getLineAndCharacterOfPosition(getNonDecoratorTokenPosOfNode(child, sourceFile)).line;
                    }
                    let childIndentationAmount = -1 /* Unknown */;
                    if (isListItem && rangeContainsRange(originalRange, parent2)) {
                        childIndentationAmount = tryComputeIndentationForListItem(childStartPos, child.end, parentStartLine, originalRange, inheritedIndentation);
                        if (childIndentationAmount !== -1 /* Unknown */) {
                            inheritedIndentation = childIndentationAmount;
                        }
                    }
                    if (!rangeOverlapsWithStartEnd(originalRange, child.pos, child.end)) {
                        if (child.end < originalRange.pos) {
                            formattingScanner.skipToEndOf(child);
                        }
                        return inheritedIndentation;
                    }
                    if (child.getFullWidth() === 0) {
                        return inheritedIndentation;
                    }
                    while (formattingScanner.isOnToken() && formattingScanner.getTokenFullStart() < originalRange.end) {
                        const tokenInfo = formattingScanner.readTokenInfo(node);
                        if (tokenInfo.token.end > originalRange.end) {
                            return inheritedIndentation;
                        }
                        if (tokenInfo.token.end > childStartPos) {
                            if (tokenInfo.token.pos > childStartPos) {
                                formattingScanner.skipToStartOf(child);
                            }
                            break;
                        }
                        consumeTokenAndAdvanceScanner(tokenInfo, node, parentDynamicIndentation, node);
                    }
                    if (!formattingScanner.isOnToken() || formattingScanner.getTokenFullStart() >= originalRange.end) {
                        return inheritedIndentation;
                    }
                    if (isToken(child)) {
                        const tokenInfo = formattingScanner.readTokenInfo(child);
                        if (child.kind !== 12 /* JsxText */) {
                            Debug.assert(tokenInfo.token.end === child.end, "Token end is child end");
                            consumeTokenAndAdvanceScanner(tokenInfo, node, parentDynamicIndentation, child);
                            return inheritedIndentation;
                        }
                    }
                    const effectiveParentStartLine = child.kind === 170 /* Decorator */ ? childStartLine : undecoratedParentStartLine;
                    const childIndentation = computeIndentation(child, childStartLine, childIndentationAmount, node, parentDynamicIndentation, effectiveParentStartLine);
                    processNode(child, childContextNode, childStartLine, undecoratedChildStartLine, childIndentation.indentation, childIndentation.delta);
                    childContextNode = node;
                    if (isFirstListItem && parent2.kind === 209 /* ArrayLiteralExpression */ && inheritedIndentation === -1 /* Unknown */) {
                        inheritedIndentation = childIndentation.indentation;
                    }
                    return inheritedIndentation;
                }
                function processChildNodes(nodes, parent2, parentStartLine, parentDynamicIndentation) {
                    Debug.assert(isNodeArray(nodes));
                    Debug.assert(!nodeIsSynthesized(nodes));
                    const listStartToken = getOpenTokenForList(parent2, nodes);
                    let listDynamicIndentation = parentDynamicIndentation;
                    let startLine = parentStartLine;
                    if (!rangeOverlapsWithStartEnd(originalRange, nodes.pos, nodes.end)) {
                        if (nodes.end < originalRange.pos) {
                            formattingScanner.skipToEndOf(nodes);
                        }
                        return;
                    }
                    if (listStartToken !== 0 /* Unknown */) {
                        while (formattingScanner.isOnToken() && formattingScanner.getTokenFullStart() < originalRange.end) {
                            const tokenInfo = formattingScanner.readTokenInfo(parent2);
                            if (tokenInfo.token.end > nodes.pos) {
                                break;
                            }
                            else if (tokenInfo.token.kind === listStartToken) {
                                startLine = sourceFile.getLineAndCharacterOfPosition(tokenInfo.token.pos).line;
                                consumeTokenAndAdvanceScanner(tokenInfo, parent2, parentDynamicIndentation, parent2);
                                let indentationOnListStartToken;
                                if (indentationOnLastIndentedLine !== -1 /* Unknown */) {
                                    indentationOnListStartToken = indentationOnLastIndentedLine;
                                }
                                else {
                                    const startLinePosition = getLineStartPositionForPosition(tokenInfo.token.pos, sourceFile);
                                    indentationOnListStartToken = SmartIndenter.findFirstNonWhitespaceColumn(startLinePosition, tokenInfo.token.pos, sourceFile, options);
                                }
                                listDynamicIndentation = getDynamicIndentation(parent2, parentStartLine, indentationOnListStartToken, options.indentSize);
                            }
                            else {
                                consumeTokenAndAdvanceScanner(tokenInfo, parent2, parentDynamicIndentation, parent2);
                            }
                        }
                    }
                    let inheritedIndentation = -1 /* Unknown */;
                    for (let i = 0; i < nodes.length; i++) {
                        const child = nodes[i];
                        inheritedIndentation = processChildNode(child, inheritedIndentation, node, listDynamicIndentation, startLine, startLine, 
                        /*isListItem*/
                        true, 
                        /*isFirstListItem*/
                        i === 0);
                    }
                    const listEndToken = getCloseTokenForOpenToken(listStartToken);
                    if (listEndToken !== 0 /* Unknown */ && formattingScanner.isOnToken() && formattingScanner.getTokenFullStart() < originalRange.end) {
                        let tokenInfo = formattingScanner.readTokenInfo(parent2);
                        if (tokenInfo.token.kind === 28 /* CommaToken */) {
                            consumeTokenAndAdvanceScanner(tokenInfo, parent2, listDynamicIndentation, parent2);
                            tokenInfo = formattingScanner.isOnToken() ? formattingScanner.readTokenInfo(parent2) : void 0;
                        }
                        if (tokenInfo && tokenInfo.token.kind === listEndToken && rangeContainsRange(parent2, tokenInfo.token)) {
                            consumeTokenAndAdvanceScanner(tokenInfo, parent2, listDynamicIndentation, parent2, 
                            /*isListEndToken*/
                            true);
                        }
                    }
                }
                function consumeTokenAndAdvanceScanner(currentTokenInfo, parent2, dynamicIndentation, container, isListEndToken) {
                    Debug.assert(rangeContainsRange(parent2, currentTokenInfo.token));
                    const lastTriviaWasNewLine = formattingScanner.lastTrailingTriviaWasNewLine();
                    let indentToken = false;
                    if (currentTokenInfo.leadingTrivia) {
                        processTrivia(currentTokenInfo.leadingTrivia, parent2, childContextNode, dynamicIndentation);
                    }
                    let lineAction = 0 /* None */;
                    const isTokenInRange = rangeContainsRange(originalRange, currentTokenInfo.token);
                    const tokenStart = sourceFile.getLineAndCharacterOfPosition(currentTokenInfo.token.pos);
                    if (isTokenInRange) {
                        const rangeHasError = rangeContainsError(currentTokenInfo.token);
                        const savePreviousRange = previousRange;
                        lineAction = processRange(currentTokenInfo.token, tokenStart, parent2, childContextNode, dynamicIndentation);
                        if (!rangeHasError) {
                            if (lineAction === 0 /* None */) {
                                const prevEndLine = savePreviousRange && sourceFile.getLineAndCharacterOfPosition(savePreviousRange.end).line;
                                indentToken = lastTriviaWasNewLine && tokenStart.line !== prevEndLine;
                            }
                            else {
                                indentToken = lineAction === 1 /* LineAdded */;
                            }
                        }
                    }
                    if (currentTokenInfo.trailingTrivia) {
                        previousRangeTriviaEnd = last(currentTokenInfo.trailingTrivia).end;
                        processTrivia(currentTokenInfo.trailingTrivia, parent2, childContextNode, dynamicIndentation);
                    }
                    if (indentToken) {
                        const tokenIndentation = isTokenInRange && !rangeContainsError(currentTokenInfo.token) ? dynamicIndentation.getIndentationForToken(tokenStart.line, currentTokenInfo.token.kind, container, !!isListEndToken) : -1 /* Unknown */;
                        let indentNextTokenOrTrivia = true;
                        if (currentTokenInfo.leadingTrivia) {
                            const commentIndentation = dynamicIndentation.getIndentationForComment(currentTokenInfo.token.kind, tokenIndentation, container);
                            indentNextTokenOrTrivia = indentTriviaItems(currentTokenInfo.leadingTrivia, commentIndentation, indentNextTokenOrTrivia, (item) => insertIndentation(item.pos, commentIndentation, 
                            /*lineAdded*/
                            false));
                        }
                        if (tokenIndentation !== -1 /* Unknown */ && indentNextTokenOrTrivia) {
                            insertIndentation(currentTokenInfo.token.pos, tokenIndentation, lineAction === 1 /* LineAdded */);
                            lastIndentedLine = tokenStart.line;
                            indentationOnLastIndentedLine = tokenIndentation;
                        }
                    }
                    formattingScanner.advance();
                    childContextNode = parent2;
                }
            }
            function indentTriviaItems(trivia, commentIndentation, indentNextTokenOrTrivia, indentSingleLine) {
                for (const triviaItem of trivia) {
                    const triviaInRange = rangeContainsRange(originalRange, triviaItem);
                    switch (triviaItem.kind) {
                        case 3 /* MultiLineCommentTrivia */:
                            if (triviaInRange) {
                                indentMultilineComment(triviaItem, commentIndentation, 
                                /*firstLineIsIndented*/
                                !indentNextTokenOrTrivia);
                            }
                            indentNextTokenOrTrivia = false;
                            break;
                        case 2 /* SingleLineCommentTrivia */:
                            if (indentNextTokenOrTrivia && triviaInRange) {
                                indentSingleLine(triviaItem);
                            }
                            indentNextTokenOrTrivia = false;
                            break;
                        case 4 /* NewLineTrivia */:
                            indentNextTokenOrTrivia = true;
                            break;
                    }
                }
                return indentNextTokenOrTrivia;
            }
            function processTrivia(trivia, parent2, contextNode, dynamicIndentation) {
                for (const triviaItem of trivia) {
                    if (isComment(triviaItem.kind) && rangeContainsRange(originalRange, triviaItem)) {
                        const triviaItemStart = sourceFile.getLineAndCharacterOfPosition(triviaItem.pos);
                        processRange(triviaItem, triviaItemStart, parent2, contextNode, dynamicIndentation);
                    }
                }
            }
            function processRange(range, rangeStart, parent2, contextNode, dynamicIndentation) {
                const rangeHasError = rangeContainsError(range);
                let lineAction = 0 /* None */;
                if (!rangeHasError) {
                    if (!previousRange) {
                        const originalStart = sourceFile.getLineAndCharacterOfPosition(originalRange.pos);
                        trimTrailingWhitespacesForLines(originalStart.line, rangeStart.line);
                    }
                    else {
                        lineAction = processPair(range, rangeStart.line, parent2, previousRange, previousRangeStartLine, previousParent, contextNode, dynamicIndentation);
                    }
                }
                previousRange = range;
                previousRangeTriviaEnd = range.end;
                previousParent = parent2;
                previousRangeStartLine = rangeStart.line;
                return lineAction;
            }
            function processPair(currentItem, currentStartLine, currentParent, previousItem, previousStartLine, previousParent2, contextNode, dynamicIndentation) {
                formattingContext.updateContext(previousItem, previousParent2, currentItem, currentParent, contextNode);
                const rules = getRules(formattingContext);
                let trimTrailingWhitespaces = formattingContext.options.trimTrailingWhitespace !== false;
                let lineAction = 0 /* None */;
                if (rules) {
                    forEachRight(rules, (rule2) => {
                        lineAction = applyRuleEdits(rule2, previousItem, previousStartLine, currentItem, currentStartLine);
                        if (dynamicIndentation) {
                            switch (lineAction) {
                                case 2 /* LineRemoved */:
                                    if (currentParent.getStart(sourceFile) === currentItem.pos) {
                                        dynamicIndentation.recomputeIndentation(
                                        /*lineAddedByFormatting*/
                                        false, contextNode);
                                    }
                                    break;
                                case 1 /* LineAdded */:
                                    if (currentParent.getStart(sourceFile) === currentItem.pos) {
                                        dynamicIndentation.recomputeIndentation(
                                        /*lineAddedByFormatting*/
                                        true, contextNode);
                                    }
                                    break;
                                default:
                                    Debug.assert(lineAction === 0 /* None */);
                            }
                        }
                        trimTrailingWhitespaces = trimTrailingWhitespaces && !(rule2.action & 16 /* DeleteSpace */) && rule2.flags !== 1 /* CanDeleteNewLines */;
                    });
                }
                else {
                    trimTrailingWhitespaces = trimTrailingWhitespaces && currentItem.kind !== 1 /* EndOfFileToken */;
                }
                if (currentStartLine !== previousStartLine && trimTrailingWhitespaces) {
                    trimTrailingWhitespacesForLines(previousStartLine, currentStartLine, previousItem);
                }
                return lineAction;
            }
            function insertIndentation(pos, indentation, lineAdded) {
                const indentationString = getIndentationString(indentation, options);
                if (lineAdded) {
                    recordReplace(pos, 0, indentationString);
                }
                else {
                    const tokenStart = sourceFile.getLineAndCharacterOfPosition(pos);
                    const startLinePosition = getStartPositionOfLine(tokenStart.line, sourceFile);
                    if (indentation !== characterToColumn(startLinePosition, tokenStart.character) || indentationIsDifferent(indentationString, startLinePosition)) {
                        recordReplace(startLinePosition, tokenStart.character, indentationString);
                    }
                }
            }
            function characterToColumn(startLinePosition, characterInLine) {
                let column = 0;
                for (let i = 0; i < characterInLine; i++) {
                    if (sourceFile.text.charCodeAt(startLinePosition + i) === 9 /* tab */) {
                        column += options.tabSize - column % options.tabSize;
                    }
                    else {
                        column++;
                    }
                }
                return column;
            }
            function indentationIsDifferent(indentationString, startLinePosition) {
                return indentationString !== sourceFile.text.substr(startLinePosition, indentationString.length);
            }
            function indentMultilineComment(commentRange, indentation, firstLineIsIndented, indentFinalLine = true) {
                let startLine = sourceFile.getLineAndCharacterOfPosition(commentRange.pos).line;
                const endLine = sourceFile.getLineAndCharacterOfPosition(commentRange.end).line;
                if (startLine === endLine) {
                    if (!firstLineIsIndented) {
                        insertIndentation(commentRange.pos, indentation, 
                        /*lineAdded*/
                        false);
                    }
                    return;
                }
                const parts = [];
                let startPos = commentRange.pos;
                for (let line = startLine; line < endLine; line++) {
                    const endOfLine = getEndLinePosition(line, sourceFile);
                    parts.push({ pos: startPos, end: endOfLine });
                    startPos = getStartPositionOfLine(line + 1, sourceFile);
                }
                if (indentFinalLine) {
                    parts.push({ pos: startPos, end: commentRange.end });
                }
                if (parts.length === 0)
                    return;
                const startLinePos = getStartPositionOfLine(startLine, sourceFile);
                const nonWhitespaceColumnInFirstPart = SmartIndenter.findFirstNonWhitespaceCharacterAndColumn(startLinePos, parts[0].pos, sourceFile, options);
                let startIndex = 0;
                if (firstLineIsIndented) {
                    startIndex = 1;
                    startLine++;
                }
                const delta2 = indentation - nonWhitespaceColumnInFirstPart.column;
                for (let i = startIndex; i < parts.length; i++, startLine++) {
                    const startLinePos2 = getStartPositionOfLine(startLine, sourceFile);
                    const nonWhitespaceCharacterAndColumn = i === 0 ? nonWhitespaceColumnInFirstPart : SmartIndenter.findFirstNonWhitespaceCharacterAndColumn(parts[i].pos, parts[i].end, sourceFile, options);
                    const newIndentation = nonWhitespaceCharacterAndColumn.column + delta2;
                    if (newIndentation > 0) {
                        const indentationString = getIndentationString(newIndentation, options);
                        recordReplace(startLinePos2, nonWhitespaceCharacterAndColumn.character, indentationString);
                    }
                    else {
                        recordDelete(startLinePos2, nonWhitespaceCharacterAndColumn.character);
                    }
                }
            }
            function trimTrailingWhitespacesForLines(line1, line2, range) {
                for (let line = line1; line < line2; line++) {
                    const lineStartPosition = getStartPositionOfLine(line, sourceFile);
                    const lineEndPosition = getEndLinePosition(line, sourceFile);
                    if (range && (isComment(range.kind) || isStringOrRegularExpressionOrTemplateLiteral(range.kind)) && range.pos <= lineEndPosition && range.end > lineEndPosition) {
                        continue;
                    }
                    const whitespaceStart = getTrailingWhitespaceStartPosition(lineStartPosition, lineEndPosition);
                    if (whitespaceStart !== -1) {
                        Debug.assert(whitespaceStart === lineStartPosition || !isWhiteSpaceSingleLine(sourceFile.text.charCodeAt(whitespaceStart - 1)));
                        recordDelete(whitespaceStart, lineEndPosition + 1 - whitespaceStart);
                    }
                }
            }
            function getTrailingWhitespaceStartPosition(start, end) {
                let pos = end;
                while (pos >= start && isWhiteSpaceSingleLine(sourceFile.text.charCodeAt(pos))) {
                    pos--;
                }
                if (pos !== end) {
                    return pos + 1;
                }
                return -1;
            }
            function trimTrailingWhitespacesForRemainingRange(trivias) {
                let startPos = previousRange ? previousRange.end : originalRange.pos;
                for (const trivia of trivias) {
                    if (isComment(trivia.kind)) {
                        if (startPos < trivia.pos) {
                            trimTrailingWitespacesForPositions(startPos, trivia.pos - 1, previousRange);
                        }
                        startPos = trivia.end + 1;
                    }
                }
                if (startPos < originalRange.end) {
                    trimTrailingWitespacesForPositions(startPos, originalRange.end, previousRange);
                }
            }
            function trimTrailingWitespacesForPositions(startPos, endPos, previousRange2) {
                const startLine = sourceFile.getLineAndCharacterOfPosition(startPos).line;
                const endLine = sourceFile.getLineAndCharacterOfPosition(endPos).line;
                trimTrailingWhitespacesForLines(startLine, endLine + 1, previousRange2);
            }
            function recordDelete(start, len) {
                if (len) {
                    edits.push(createTextChangeFromStartLength(start, len, ""));
                }
            }
            function recordReplace(start, len, newText) {
                if (len || newText) {
                    edits.push(createTextChangeFromStartLength(start, len, newText));
                }
            }
            function recordInsert(start, text) {
                if (text) {
                    edits.push(createTextChangeFromStartLength(start, 0, text));
                }
            }
            function applyRuleEdits(rule2, previousRange2, previousStartLine, currentRange, currentStartLine) {
                const onLaterLine = currentStartLine !== previousStartLine;
                switch (rule2.action) {
                    case 1 /* StopProcessingSpaceActions */:
                        return 0 /* None */;
                    case 16 /* DeleteSpace */:
                        if (previousRange2.end !== currentRange.pos) {
                            recordDelete(previousRange2.end, currentRange.pos - previousRange2.end);
                            return onLaterLine ? 2 /* LineRemoved */ : 0 /* None */;
                        }
                        break;
                    case 32 /* DeleteToken */:
                        recordDelete(previousRange2.pos, previousRange2.end - previousRange2.pos);
                        break;
                    case 8 /* InsertNewLine */:
                        if (rule2.flags !== 1 /* CanDeleteNewLines */ && previousStartLine !== currentStartLine) {
                            return 0 /* None */;
                        }
                        const lineDelta = currentStartLine - previousStartLine;
                        if (lineDelta !== 1) {
                            recordReplace(previousRange2.end, currentRange.pos - previousRange2.end, getNewLineOrDefaultFromHost(host, options));
                            return onLaterLine ? 0 /* None */ : 1 /* LineAdded */;
                        }
                        break;
                    case 4 /* InsertSpace */:
                        if (rule2.flags !== 1 /* CanDeleteNewLines */ && previousStartLine !== currentStartLine) {
                            return 0 /* None */;
                        }
                        const posDelta = currentRange.pos - previousRange2.end;
                        if (posDelta !== 1 || sourceFile.text.charCodeAt(previousRange2.end) !== 32 /* space */) {
                            recordReplace(previousRange2.end, currentRange.pos - previousRange2.end, " ");
                            return onLaterLine ? 2 /* LineRemoved */ : 0 /* None */;
                        }
                        break;
                    case 64 /* InsertTrailingSemicolon */:
                        recordInsert(previousRange2.end, ";");
                }
                return 0 /* None */;
            }
        }
        function getRangeOfEnclosingComment(sourceFile, position, precedingToken, tokenAtPosition = getTokenAtPosition(sourceFile, position)) {
            const jsdoc = findAncestor(tokenAtPosition, isJSDoc);
            if (jsdoc)
                tokenAtPosition = jsdoc.parent;
            const tokenStart = tokenAtPosition.getStart(sourceFile);
            if (tokenStart <= position && position < tokenAtPosition.getEnd()) {
                return void 0;
            }
            precedingToken = precedingToken === null ? void 0 : precedingToken === void 0 ? findPrecedingToken(position, sourceFile) : precedingToken;
            const trailingRangesOfPreviousToken = precedingToken && getTrailingCommentRanges(sourceFile.text, precedingToken.end);
            const leadingCommentRangesOfNextToken = getLeadingCommentRangesOfNode(tokenAtPosition, sourceFile);
            const commentRanges = concatenate(trailingRangesOfPreviousToken, leadingCommentRangesOfNextToken);
            return commentRanges && find(commentRanges, (range) => rangeContainsPositionExclusive(range, position) || // The end marker of a single-line comment does not include the newline character.
                // With caret at `^`, in the following case, we are inside a comment (^ denotes the cursor position):
                //
                //    // asdf   ^\n
                //
                // But for closed multi-line comments, we don't want to be inside the comment in the following case:
                //
                //    /* asdf */^
                //
                // However, unterminated multi-line comments *do* contain their end.
                //
                // Internally, we represent the end of the comment at the newline and closing '/', respectively.
                //
                position === range.end && (range.kind === 2 /* SingleLineCommentTrivia */ || position === sourceFile.getFullWidth()));
        }
        function getOpenTokenForList(node, list) {
            switch (node.kind) {
                case 176 /* Constructor */:
                case 262 /* FunctionDeclaration */:
                case 218 /* FunctionExpression */:
                case 174 /* MethodDeclaration */:
                case 173 /* MethodSignature */:
                case 219 /* ArrowFunction */:
                case 179 /* CallSignature */:
                case 180 /* ConstructSignature */:
                case 184 /* FunctionType */:
                case 185 /* ConstructorType */:
                case 177 /* GetAccessor */:
                case 178 /* SetAccessor */:
                    if (node.typeParameters === list) {
                        return 30 /* LessThanToken */;
                    }
                    else if (node.parameters === list) {
                        return 21 /* OpenParenToken */;
                    }
                    break;
                case 213 /* CallExpression */:
                case 214 /* NewExpression */:
                    if (node.typeArguments === list) {
                        return 30 /* LessThanToken */;
                    }
                    else if (node.arguments === list) {
                        return 21 /* OpenParenToken */;
                    }
                    break;
                case 263 /* ClassDeclaration */:
                case 231 /* ClassExpression */:
                case 264 /* InterfaceDeclaration */:
                case 265 /* TypeAliasDeclaration */:
                    if (node.typeParameters === list) {
                        return 30 /* LessThanToken */;
                    }
                    break;
                case 183 /* TypeReference */:
                case 215 /* TaggedTemplateExpression */:
                case 186 /* TypeQuery */:
                case 233 /* ExpressionWithTypeArguments */:
                case 205 /* ImportType */:
                    if (node.typeArguments === list) {
                        return 30 /* LessThanToken */;
                    }
                    break;
                case 187 /* TypeLiteral */:
                    return 19 /* OpenBraceToken */;
            }
            return 0 /* Unknown */;
        }
        function getCloseTokenForOpenToken(kind) {
            switch (kind) {
                case 21 /* OpenParenToken */:
                    return 22 /* CloseParenToken */;
                case 30 /* LessThanToken */:
                    return 32 /* GreaterThanToken */;
                case 19 /* OpenBraceToken */:
                    return 20 /* CloseBraceToken */;
            }
            return 0 /* Unknown */;
        }
        function getIndentationString(indentation, options) {
            const resetInternedStrings = !internedSizes || (internedSizes.tabSize !== options.tabSize || internedSizes.indentSize !== options.indentSize);
            if (resetInternedStrings) {
                internedSizes = { tabSize: options.tabSize, indentSize: options.indentSize };
                internedTabsIndentation = internedSpacesIndentation = void 0;
            }
            if (!options.convertTabsToSpaces) {
                const tabs = Math.floor(indentation / options.tabSize);
                const spaces = indentation - tabs * options.tabSize;
                let tabString;
                if (!internedTabsIndentation) {
                    internedTabsIndentation = [];
                }
                if (internedTabsIndentation[tabs] === void 0) {
                    internedTabsIndentation[tabs] = tabString = repeatString("	", tabs);
                }
                else {
                    tabString = internedTabsIndentation[tabs];
                }
                return spaces ? tabString + repeatString(" ", spaces) : tabString;
            }
            else {
                let spacesString;
                const quotient = Math.floor(indentation / options.indentSize);
                const remainder = indentation % options.indentSize;
                if (!internedSpacesIndentation) {
                    internedSpacesIndentation = [];
                }
                if (internedSpacesIndentation[quotient] === void 0) {
                    spacesString = repeatString(" ", options.indentSize * quotient);
                    internedSpacesIndentation[quotient] = spacesString;
                }
                else {
                    spacesString = internedSpacesIndentation[quotient];
                }
                return remainder ? spacesString + repeatString(" ", remainder) : spacesString;
            }
        }
        var internedSizes, internedTabsIndentation, internedSpacesIndentation;
        var init_formatting = __esm({
            "src/services/formatting/formatting.ts"() {
                "use strict";
                init_ts4();
                init_ts_formatting();
            }
        });
        // src/services/formatting/smartIndenter.ts
        var SmartIndenter;
        var init_smartIndenter = __esm({
            "src/services/formatting/smartIndenter.ts"() {
                "use strict";
                init_ts4();
                init_ts_formatting();
                ((SmartIndenter2) => {
                    let Value;
                    ((Value2) => {
                        Value2[Value2["Unknown"] = -1] = "Unknown";
                    })(Value || (Value = {}));
                    function getIndentation(position, sourceFile, options, assumeNewLineBeforeCloseBrace = false) {
                        if (position > sourceFile.text.length) {
                            return getBaseIndentation(options);
                        }
                        if (options.indentStyle === 0 /* None */) {
                            return 0;
                        }
                        const precedingToken = findPrecedingToken(position, sourceFile, 
                        /*startNode*/
                        void 0, 
                        /*excludeJsdoc*/
                        true);
                        const enclosingCommentRange = getRangeOfEnclosingComment(sourceFile, position, precedingToken || null);
                        if (enclosingCommentRange && enclosingCommentRange.kind === 3 /* MultiLineCommentTrivia */) {
                            return getCommentIndent(sourceFile, position, options, enclosingCommentRange);
                        }
                        if (!precedingToken) {
                            return getBaseIndentation(options);
                        }
                        const precedingTokenIsLiteral = isStringOrRegularExpressionOrTemplateLiteral(precedingToken.kind);
                        if (precedingTokenIsLiteral && precedingToken.getStart(sourceFile) <= position && position < precedingToken.end) {
                            return 0;
                        }
                        const lineAtPosition = sourceFile.getLineAndCharacterOfPosition(position).line;
                        const currentToken = getTokenAtPosition(sourceFile, position);
                        const isObjectLiteral = currentToken.kind === 19 /* OpenBraceToken */ && currentToken.parent.kind === 210 /* ObjectLiteralExpression */;
                        if (options.indentStyle === 1 /* Block */ || isObjectLiteral) {
                            return getBlockIndent(sourceFile, position, options);
                        }
                        if (precedingToken.kind === 28 /* CommaToken */ && precedingToken.parent.kind !== 226 /* BinaryExpression */) {
                            const actualIndentation = getActualIndentationForListItemBeforeComma(precedingToken, sourceFile, options);
                            if (actualIndentation !== -1 /* Unknown */) {
                                return actualIndentation;
                            }
                        }
                        const containerList = getListByPosition(position, precedingToken.parent, sourceFile);
                        if (containerList && !rangeContainsRange(containerList, precedingToken)) {
                            const useTheSameBaseIndentation = [218 /* FunctionExpression */, 219 /* ArrowFunction */].includes(currentToken.parent.kind);
                            const indentSize = useTheSameBaseIndentation ? 0 : options.indentSize;
                            return getActualIndentationForListStartLine(containerList, sourceFile, options) + indentSize;
                        }
                        return getSmartIndent(sourceFile, position, precedingToken, lineAtPosition, assumeNewLineBeforeCloseBrace, options);
                    }
                    SmartIndenter2.getIndentation = getIndentation;
                    function getCommentIndent(sourceFile, position, options, enclosingCommentRange) {
                        const previousLine = getLineAndCharacterOfPosition(sourceFile, position).line - 1;
                        const commentStartLine = getLineAndCharacterOfPosition(sourceFile, enclosingCommentRange.pos).line;
                        Debug.assert(commentStartLine >= 0);
                        if (previousLine <= commentStartLine) {
                            return findFirstNonWhitespaceColumn(getStartPositionOfLine(commentStartLine, sourceFile), position, sourceFile, options);
                        }
                        const startPositionOfLine = getStartPositionOfLine(previousLine, sourceFile);
                        const { column, character } = findFirstNonWhitespaceCharacterAndColumn(startPositionOfLine, position, sourceFile, options);
                        if (column === 0) {
                            return column;
                        }
                        const firstNonWhitespaceCharacterCode = sourceFile.text.charCodeAt(startPositionOfLine + character);
                        return firstNonWhitespaceCharacterCode === 42 /* asterisk */ ? column - 1 : column;
                    }
                    function getBlockIndent(sourceFile, position, options) {
                        let current = position;
                        while (current > 0) {
                            const char = sourceFile.text.charCodeAt(current);
                            if (!isWhiteSpaceLike(char)) {
                                break;
                            }
                            current--;
                        }
                        const lineStart = getLineStartPositionForPosition(current, sourceFile);
                        return findFirstNonWhitespaceColumn(lineStart, current, sourceFile, options);
                    }
                    function getSmartIndent(sourceFile, position, precedingToken, lineAtPosition, assumeNewLineBeforeCloseBrace, options) {
                        let previous;
                        let current = precedingToken;
                        while (current) {
                            if (positionBelongsToNode(current, position, sourceFile) && shouldIndentChildNode(options, current, previous, sourceFile, 
                            /*isNextChild*/
                            true)) {
                                const currentStart = getStartLineAndCharacterForNode(current, sourceFile);
                                const nextTokenKind = nextTokenIsCurlyBraceOnSameLineAsCursor(precedingToken, current, lineAtPosition, sourceFile);
                                const indentationDelta = nextTokenKind !== 0 /* Unknown */ ? assumeNewLineBeforeCloseBrace && nextTokenKind === 2 /* CloseBrace */ ? options.indentSize : 0 : lineAtPosition !== currentStart.line ? options.indentSize : 0;
                                return getIndentationForNodeWorker(current, currentStart, 
                                /*ignoreActualIndentationRange*/
                                void 0, indentationDelta, sourceFile, 
                                /*isNextChild*/
                                true, options);
                            }
                            const actualIndentation = getActualIndentationForListItem(current, sourceFile, options, 
                            /*listIndentsChild*/
                            true);
                            if (actualIndentation !== -1 /* Unknown */) {
                                return actualIndentation;
                            }
                            previous = current;
                            current = current.parent;
                        }
                        return getBaseIndentation(options);
                    }
                    function getIndentationForNode(n, ignoreActualIndentationRange, sourceFile, options) {
                        const start = sourceFile.getLineAndCharacterOfPosition(n.getStart(sourceFile));
                        return getIndentationForNodeWorker(n, start, ignoreActualIndentationRange, 
                        /*indentationDelta*/
                        0, sourceFile, 
                        /*isNextChild*/
                        false, options);
                    }
                    SmartIndenter2.getIndentationForNode = getIndentationForNode;
                    function getBaseIndentation(options) {
                        return options.baseIndentSize || 0;
                    }
                    SmartIndenter2.getBaseIndentation = getBaseIndentation;
                    function getIndentationForNodeWorker(current, currentStart, ignoreActualIndentationRange, indentationDelta, sourceFile, isNextChild, options) {
                        var _a;
                        let parent2 = current.parent;
                        while (parent2) {
                            let useActualIndentation = true;
                            if (ignoreActualIndentationRange) {
                                const start = current.getStart(sourceFile);
                                useActualIndentation = start < ignoreActualIndentationRange.pos || start > ignoreActualIndentationRange.end;
                            }
                            const containingListOrParentStart = getContainingListOrParentStart(parent2, current, sourceFile);
                            const parentAndChildShareLine = containingListOrParentStart.line === currentStart.line || childStartsOnTheSameLineWithElseInIfStatement(parent2, current, currentStart.line, sourceFile);
                            if (useActualIndentation) {
                                const firstListChild = (_a = getContainingList(current, sourceFile)) == null ? void 0 : _a[0];
                                const listIndentsChild = !!firstListChild && getStartLineAndCharacterForNode(firstListChild, sourceFile).line > containingListOrParentStart.line;
                                let actualIndentation = getActualIndentationForListItem(current, sourceFile, options, listIndentsChild);
                                if (actualIndentation !== -1 /* Unknown */) {
                                    return actualIndentation + indentationDelta;
                                }
                                actualIndentation = getActualIndentationForNode(current, parent2, currentStart, parentAndChildShareLine, sourceFile, options);
                                if (actualIndentation !== -1 /* Unknown */) {
                                    return actualIndentation + indentationDelta;
                                }
                            }
                            if (shouldIndentChildNode(options, parent2, current, sourceFile, isNextChild) && !parentAndChildShareLine) {
                                indentationDelta += options.indentSize;
                            }
                            const useTrueStart = isArgumentAndStartLineOverlapsExpressionBeingCalled(parent2, current, currentStart.line, sourceFile);
                            current = parent2;
                            parent2 = current.parent;
                            currentStart = useTrueStart ? sourceFile.getLineAndCharacterOfPosition(current.getStart(sourceFile)) : containingListOrParentStart;
                        }
                        return indentationDelta + getBaseIndentation(options);
                    }
                    function getContainingListOrParentStart(parent2, child, sourceFile) {
                        const containingList = getContainingList(child, sourceFile);
                        const startPos = containingList ? containingList.pos : parent2.getStart(sourceFile);
                        return sourceFile.getLineAndCharacterOfPosition(startPos);
                    }
                    function getActualIndentationForListItemBeforeComma(commaToken, sourceFile, options) {
                        const commaItemInfo = findListItemInfo(commaToken);
                        if (commaItemInfo && commaItemInfo.listItemIndex > 0) {
                            return deriveActualIndentationFromList(commaItemInfo.list.getChildren(), commaItemInfo.listItemIndex - 1, sourceFile, options);
                        }
                        else {
                            return -1 /* Unknown */;
                        }
                    }
                    function getActualIndentationForNode(current, parent2, currentLineAndChar, parentAndChildShareLine, sourceFile, options) {
                        const useActualIndentation = (isDeclaration(current) || isStatementButNotDeclaration(current)) && (parent2.kind === 312 /* SourceFile */ || !parentAndChildShareLine);
                        if (!useActualIndentation) {
                            return -1 /* Unknown */;
                        }
                        return findColumnForFirstNonWhitespaceCharacterInLine(currentLineAndChar, sourceFile, options);
                    }
                    let NextTokenKind;
                    ((NextTokenKind2) => {
                        NextTokenKind2[NextTokenKind2["Unknown"] = 0] = "Unknown";
                        NextTokenKind2[NextTokenKind2["OpenBrace"] = 1] = "OpenBrace";
                        NextTokenKind2[NextTokenKind2["CloseBrace"] = 2] = "CloseBrace";
                    })(NextTokenKind || (NextTokenKind = {}));
                    function nextTokenIsCurlyBraceOnSameLineAsCursor(precedingToken, current, lineAtPosition, sourceFile) {
                        const nextToken = findNextToken(precedingToken, current, sourceFile);
                        if (!nextToken) {
                            return 0 /* Unknown */;
                        }
                        if (nextToken.kind === 19 /* OpenBraceToken */) {
                            return 1 /* OpenBrace */;
                        }
                        else if (nextToken.kind === 20 /* CloseBraceToken */) {
                            const nextTokenStartLine = getStartLineAndCharacterForNode(nextToken, sourceFile).line;
                            return lineAtPosition === nextTokenStartLine ? 2 /* CloseBrace */ : 0 /* Unknown */;
                        }
                        return 0 /* Unknown */;
                    }
                    function getStartLineAndCharacterForNode(n, sourceFile) {
                        return sourceFile.getLineAndCharacterOfPosition(n.getStart(sourceFile));
                    }
                    function isArgumentAndStartLineOverlapsExpressionBeingCalled(parent2, child, childStartLine, sourceFile) {
                        if (!(isCallExpression(parent2) && contains(parent2.arguments, child))) {
                            return false;
                        }
                        const expressionOfCallExpressionEnd = parent2.expression.getEnd();
                        const expressionOfCallExpressionEndLine = getLineAndCharacterOfPosition(sourceFile, expressionOfCallExpressionEnd).line;
                        return expressionOfCallExpressionEndLine === childStartLine;
                    }
                    SmartIndenter2.isArgumentAndStartLineOverlapsExpressionBeingCalled = isArgumentAndStartLineOverlapsExpressionBeingCalled;
                    function childStartsOnTheSameLineWithElseInIfStatement(parent2, child, childStartLine, sourceFile) {
                        if (parent2.kind === 245 /* IfStatement */ && parent2.elseStatement === child) {
                            const elseKeyword = findChildOfKind(parent2, 93 /* ElseKeyword */, sourceFile);
                            Debug.assert(elseKeyword !== void 0);
                            const elseKeywordStartLine = getStartLineAndCharacterForNode(elseKeyword, sourceFile).line;
                            return elseKeywordStartLine === childStartLine;
                        }
                        return false;
                    }
                    SmartIndenter2.childStartsOnTheSameLineWithElseInIfStatement = childStartsOnTheSameLineWithElseInIfStatement;
                    function childIsUnindentedBranchOfConditionalExpression(parent2, child, childStartLine, sourceFile) {
                        if (isConditionalExpression(parent2) && (child === parent2.whenTrue || child === parent2.whenFalse)) {
                            const conditionEndLine = getLineAndCharacterOfPosition(sourceFile, parent2.condition.end).line;
                            if (child === parent2.whenTrue) {
                                return childStartLine === conditionEndLine;
                            }
                            else {
                                const trueStartLine = getStartLineAndCharacterForNode(parent2.whenTrue, sourceFile).line;
                                const trueEndLine = getLineAndCharacterOfPosition(sourceFile, parent2.whenTrue.end).line;
                                return conditionEndLine === trueStartLine && trueEndLine === childStartLine;
                            }
                        }
                        return false;
                    }
                    SmartIndenter2.childIsUnindentedBranchOfConditionalExpression = childIsUnindentedBranchOfConditionalExpression;
                    function argumentStartsOnSameLineAsPreviousArgument(parent2, child, childStartLine, sourceFile) {
                        if (isCallOrNewExpression(parent2)) {
                            if (!parent2.arguments)
                                return false;
                            const currentNode = find(parent2.arguments, (arg) => arg.pos === child.pos);
                            if (!currentNode)
                                return false;
                            const currentIndex = parent2.arguments.indexOf(currentNode);
                            if (currentIndex === 0)
                                return false;
                            const previousNode = parent2.arguments[currentIndex - 1];
                            const lineOfPreviousNode = getLineAndCharacterOfPosition(sourceFile, previousNode.getEnd()).line;
                            if (childStartLine === lineOfPreviousNode) {
                                return true;
                            }
                        }
                        return false;
                    }
                    SmartIndenter2.argumentStartsOnSameLineAsPreviousArgument = argumentStartsOnSameLineAsPreviousArgument;
                    function getContainingList(node, sourceFile) {
                        return node.parent && getListByRange(node.getStart(sourceFile), node.getEnd(), node.parent, sourceFile);
                    }
                    SmartIndenter2.getContainingList = getContainingList;
                    function getListByPosition(pos, node, sourceFile) {
                        return node && getListByRange(pos, pos, node, sourceFile);
                    }
                    function getListByRange(start, end, node, sourceFile) {
                        switch (node.kind) {
                            case 183 /* TypeReference */:
                                return getList(node.typeArguments);
                            case 210 /* ObjectLiteralExpression */:
                                return getList(node.properties);
                            case 209 /* ArrayLiteralExpression */:
                                return getList(node.elements);
                            case 187 /* TypeLiteral */:
                                return getList(node.members);
                            case 262 /* FunctionDeclaration */:
                            case 218 /* FunctionExpression */:
                            case 219 /* ArrowFunction */:
                            case 174 /* MethodDeclaration */:
                            case 173 /* MethodSignature */:
                            case 179 /* CallSignature */:
                            case 176 /* Constructor */:
                            case 185 /* ConstructorType */:
                            case 180 /* ConstructSignature */:
                                return getList(node.typeParameters) || getList(node.parameters);
                            case 177 /* GetAccessor */:
                                return getList(node.parameters);
                            case 263 /* ClassDeclaration */:
                            case 231 /* ClassExpression */:
                            case 264 /* InterfaceDeclaration */:
                            case 265 /* TypeAliasDeclaration */:
                            case 352 /* JSDocTemplateTag */:
                                return getList(node.typeParameters);
                            case 214 /* NewExpression */:
                            case 213 /* CallExpression */:
                                return getList(node.typeArguments) || getList(node.arguments);
                            case 261 /* VariableDeclarationList */:
                                return getList(node.declarations);
                            case 275 /* NamedImports */:
                            case 279 /* NamedExports */:
                                return getList(node.elements);
                            case 206 /* ObjectBindingPattern */:
                            case 207 /* ArrayBindingPattern */:
                                return getList(node.elements);
                        }
                        function getList(list) {
                            return list && rangeContainsStartEnd(getVisualListRange(node, list, sourceFile), start, end) ? list : void 0;
                        }
                    }
                    function getVisualListRange(node, list, sourceFile) {
                        const children = node.getChildren(sourceFile);
                        for (let i = 1; i < children.length - 1; i++) {
                            if (children[i].pos === list.pos && children[i].end === list.end) {
                                return { pos: children[i - 1].end, end: children[i + 1].getStart(sourceFile) };
                            }
                        }
                        return list;
                    }
                    function getActualIndentationForListStartLine(list, sourceFile, options) {
                        if (!list) {
                            return -1 /* Unknown */;
                        }
                        return findColumnForFirstNonWhitespaceCharacterInLine(sourceFile.getLineAndCharacterOfPosition(list.pos), sourceFile, options);
                    }
                    function getActualIndentationForListItem(node, sourceFile, options, listIndentsChild) {
                        if (node.parent && node.parent.kind === 261 /* VariableDeclarationList */) {
                            return -1 /* Unknown */;
                        }
                        const containingList = getContainingList(node, sourceFile);
                        if (containingList) {
                            const index = containingList.indexOf(node);
                            if (index !== -1) {
                                const result = deriveActualIndentationFromList(containingList, index, sourceFile, options);
                                if (result !== -1 /* Unknown */) {
                                    return result;
                                }
                            }
                            return getActualIndentationForListStartLine(containingList, sourceFile, options) + (listIndentsChild ? options.indentSize : 0);
                        }
                        return -1 /* Unknown */;
                    }
                    function deriveActualIndentationFromList(list, index, sourceFile, options) {
                        Debug.assert(index >= 0 && index < list.length);
                        const node = list[index];
                        let lineAndCharacter = getStartLineAndCharacterForNode(node, sourceFile);
                        for (let i = index - 1; i >= 0; i--) {
                            if (list[i].kind === 28 /* CommaToken */) {
                                continue;
                            }
                            const prevEndLine = sourceFile.getLineAndCharacterOfPosition(list[i].end).line;
                            if (prevEndLine !== lineAndCharacter.line) {
                                return findColumnForFirstNonWhitespaceCharacterInLine(lineAndCharacter, sourceFile, options);
                            }
                            lineAndCharacter = getStartLineAndCharacterForNode(list[i], sourceFile);
                        }
                        return -1 /* Unknown */;
                    }
                    function findColumnForFirstNonWhitespaceCharacterInLine(lineAndCharacter, sourceFile, options) {
                        const lineStart = sourceFile.getPositionOfLineAndCharacter(lineAndCharacter.line, 0);
                        return findFirstNonWhitespaceColumn(lineStart, lineStart + lineAndCharacter.character, sourceFile, options);
                    }
                    function findFirstNonWhitespaceCharacterAndColumn(startPos, endPos, sourceFile, options) {
                        let character = 0;
                        let column = 0;
                        for (let pos = startPos; pos < endPos; pos++) {
                            const ch = sourceFile.text.charCodeAt(pos);
                            if (!isWhiteSpaceSingleLine(ch)) {
                                break;
                            }
                            if (ch === 9 /* tab */) {
                                column += options.tabSize + column % options.tabSize;
                            }
                            else {
                                column++;
                            }
                            character++;
                        }
                        return { column, character };
                    }
                    SmartIndenter2.findFirstNonWhitespaceCharacterAndColumn = findFirstNonWhitespaceCharacterAndColumn;
                    function findFirstNonWhitespaceColumn(startPos, endPos, sourceFile, options) {
                        return findFirstNonWhitespaceCharacterAndColumn(startPos, endPos, sourceFile, options).column;
                    }
                    SmartIndenter2.findFirstNonWhitespaceColumn = findFirstNonWhitespaceColumn;
                    function nodeWillIndentChild(settings, parent2, child, sourceFile, indentByDefault) {
                        const childKind = child ? child.kind : 0 /* Unknown */;
                        switch (parent2.kind) {
                            case 244 /* ExpressionStatement */:
                            case 263 /* ClassDeclaration */:
                            case 231 /* ClassExpression */:
                            case 264 /* InterfaceDeclaration */:
                            case 266 /* EnumDeclaration */:
                            case 265 /* TypeAliasDeclaration */:
                            case 209 /* ArrayLiteralExpression */:
                            case 241 /* Block */:
                            case 268 /* ModuleBlock */:
                            case 210 /* ObjectLiteralExpression */:
                            case 187 /* TypeLiteral */:
                            case 200 /* MappedType */:
                            case 189 /* TupleType */:
                            case 217 /* ParenthesizedExpression */:
                            case 211 /* PropertyAccessExpression */:
                            case 213 /* CallExpression */:
                            case 214 /* NewExpression */:
                            case 243 /* VariableStatement */:
                            case 277 /* ExportAssignment */:
                            case 253 /* ReturnStatement */:
                            case 227 /* ConditionalExpression */:
                            case 207 /* ArrayBindingPattern */:
                            case 206 /* ObjectBindingPattern */:
                            case 286 /* JsxOpeningElement */:
                            case 289 /* JsxOpeningFragment */:
                            case 285 /* JsxSelfClosingElement */:
                            case 294 /* JsxExpression */:
                            case 173 /* MethodSignature */:
                            case 179 /* CallSignature */:
                            case 180 /* ConstructSignature */:
                            case 169 /* Parameter */:
                            case 184 /* FunctionType */:
                            case 185 /* ConstructorType */:
                            case 196 /* ParenthesizedType */:
                            case 215 /* TaggedTemplateExpression */:
                            case 223 /* AwaitExpression */:
                            case 279 /* NamedExports */:
                            case 275 /* NamedImports */:
                            case 281 /* ExportSpecifier */:
                            case 276 /* ImportSpecifier */:
                            case 172 /* PropertyDeclaration */:
                            case 296 /* CaseClause */:
                            case 297 /* DefaultClause */:
                                return true;
                            case 269 /* CaseBlock */:
                                return settings.indentSwitchCase ?? true;
                            case 260 /* VariableDeclaration */:
                            case 303 /* PropertyAssignment */:
                            case 226 /* BinaryExpression */:
                                if (!settings.indentMultiLineObjectLiteralBeginningOnBlankLine && sourceFile && childKind === 210 /* ObjectLiteralExpression */) {
                                    return rangeIsOnOneLine(sourceFile, child);
                                }
                                if (parent2.kind === 226 /* BinaryExpression */ && sourceFile && child && childKind === 284 /* JsxElement */) {
                                    const parentStartLine = sourceFile.getLineAndCharacterOfPosition(skipTrivia(sourceFile.text, parent2.pos)).line;
                                    const childStartLine = sourceFile.getLineAndCharacterOfPosition(skipTrivia(sourceFile.text, child.pos)).line;
                                    return parentStartLine !== childStartLine;
                                }
                                if (parent2.kind !== 226 /* BinaryExpression */) {
                                    return true;
                                }
                                break;
                            case 246 /* DoStatement */:
                            case 247 /* WhileStatement */:
                            case 249 /* ForInStatement */:
                            case 250 /* ForOfStatement */:
                            case 248 /* ForStatement */:
                            case 245 /* IfStatement */:
                            case 262 /* FunctionDeclaration */:
                            case 218 /* FunctionExpression */:
                            case 174 /* MethodDeclaration */:
                            case 176 /* Constructor */:
                            case 177 /* GetAccessor */:
                            case 178 /* SetAccessor */:
                                return childKind !== 241 /* Block */;
                            case 219 /* ArrowFunction */:
                                if (sourceFile && childKind === 217 /* ParenthesizedExpression */) {
                                    return rangeIsOnOneLine(sourceFile, child);
                                }
                                return childKind !== 241 /* Block */;
                            case 278 /* ExportDeclaration */:
                                return childKind !== 279 /* NamedExports */;
                            case 272 /* ImportDeclaration */:
                                return childKind !== 273 /* ImportClause */ || !!child.namedBindings && child.namedBindings.kind !== 275 /* NamedImports */;
                            case 284 /* JsxElement */:
                                return childKind !== 287 /* JsxClosingElement */;
                            case 288 /* JsxFragment */:
                                return childKind !== 290 /* JsxClosingFragment */;
                            case 193 /* IntersectionType */:
                            case 192 /* UnionType */:
                                if (childKind === 187 /* TypeLiteral */ || childKind === 189 /* TupleType */) {
                                    return false;
                                }
                                break;
                        }
                        return indentByDefault;
                    }
                    SmartIndenter2.nodeWillIndentChild = nodeWillIndentChild;
                    function isControlFlowEndingStatement(kind, parent2) {
                        switch (kind) {
                            case 253 /* ReturnStatement */:
                            case 257 /* ThrowStatement */:
                            case 251 /* ContinueStatement */:
                            case 252 /* BreakStatement */:
                                return parent2.kind !== 241 /* Block */;
                            default:
                                return false;
                        }
                    }
                    function shouldIndentChildNode(settings, parent2, child, sourceFile, isNextChild = false) {
                        return nodeWillIndentChild(settings, parent2, child, sourceFile, 
                        /*indentByDefault*/
                        false) && !(isNextChild && child && isControlFlowEndingStatement(child.kind, parent2));
                    }
                    SmartIndenter2.shouldIndentChildNode = shouldIndentChildNode;
                    function rangeIsOnOneLine(sourceFile, range) {
                        const rangeStart = skipTrivia(sourceFile.text, range.pos);
                        const startLine = sourceFile.getLineAndCharacterOfPosition(rangeStart).line;
                        const endLine = sourceFile.getLineAndCharacterOfPosition(range.end).line;
                        return startLine === endLine;
                    }
                })(SmartIndenter || (SmartIndenter = {}));
            }
        });
        // src/services/_namespaces/ts.formatting.ts
        var ts_formatting_exports = {};
        __export(ts_formatting_exports, {
            FormattingContext: () => FormattingContext,
            FormattingRequestKind: () => FormattingRequestKind,
            RuleAction: () => RuleAction,
            RuleFlags: () => RuleFlags,
            SmartIndenter: () => SmartIndenter,
            anyContext: () => anyContext,
            createTextRangeWithKind: () => createTextRangeWithKind,
            formatDocument: () => formatDocument,
            formatNodeGivenIndentation: () => formatNodeGivenIndentation,
            formatOnClosingCurly: () => formatOnClosingCurly,
            formatOnEnter: () => formatOnEnter,
            formatOnOpeningCurly: () => formatOnOpeningCurly,
            formatOnSemicolon: () => formatOnSemicolon,
            formatSelection: () => formatSelection,
            getAllRules: () => getAllRules,
            getFormatContext: () => getFormatContext,
            getFormattingScanner: () => getFormattingScanner,
            getIndentationString: () => getIndentationString,
            getRangeOfEnclosingComment: () => getRangeOfEnclosingComment
        });
        var init_ts_formatting = __esm({
            "src/services/_namespaces/ts.formatting.ts"() {
                "use strict";
                init_formattingContext();
                init_formattingScanner();
                init_rule();
                init_rules();
                init_rulesMap();
                init_formatting();
                init_smartIndenter();
            }
        });
        // src/services/_namespaces/ts.ts
        var init_ts4 = __esm({
            "src/services/_namespaces/ts.ts"() {
                "use strict";
                init_ts2();
                init_ts3();
                init_types3();
                init_utilities4();
                init_exportInfoMap();
                init_classifier();
                init_documentHighlights();
                init_documentRegistry();
                init_getEditsForFileRename();
                init_patternMatcher();
                init_preProcess();
                init_sourcemaps();
                init_suggestionDiagnostics();
                init_transpile();
                init_services();
                init_transform();
                init_ts_BreakpointResolver();
                init_ts_CallHierarchy();
                init_ts_classifier();
                init_ts_codefix();
                init_ts_Completions();
                init_ts_FindAllReferences();
                init_ts_GoToDefinition();
                init_ts_InlayHints();
                init_ts_JsDoc();
                init_ts_NavigateTo();
                init_ts_NavigationBar();
                init_ts_OrganizeImports();
                init_ts_OutliningElementsCollector();
                init_ts_refactor();
                init_ts_Rename();
                init_ts_SignatureHelp();
                init_ts_SmartSelectionRange();
                init_ts_SymbolDisplay();
                init_ts_textChanges();
                init_ts_formatting();
            }
        });
        // src/deprecatedCompat/deprecate.ts
        function getTypeScriptVersion() {
            return typeScriptVersion2 ?? (typeScriptVersion2 = new Version(version));
        }
        function formatDeprecationMessage(name, error2, errorAfter, since, message) {
            let deprecationMessage = error2 ? "DeprecationError: " : "DeprecationWarning: ";
            deprecationMessage += `'${name}' `;
            deprecationMessage += since ? `has been deprecated since v${since}` : "is deprecated";
            deprecationMessage += error2 ? " and can no longer be used." : errorAfter ? ` and will no longer be usable after v${errorAfter}.` : ".";
            deprecationMessage += message ? ` ${formatStringFromArgs(message, [name])}` : "";
            return deprecationMessage;
        }
        function createErrorDeprecation(name, errorAfter, since, message) {
            const deprecationMessage = formatDeprecationMessage(name, 
            /*error*/
            true, errorAfter, since, message);
            return () => {
                throw new TypeError(deprecationMessage);
            };
        }
        function createWarningDeprecation(name, errorAfter, since, message) {
            let hasWrittenDeprecation = false;
            return () => {
                if (enableDeprecationWarnings && !hasWrittenDeprecation) {
                    Debug.log.warn(formatDeprecationMessage(name, 
                    /*error*/
                    false, errorAfter, since, message));
                    hasWrittenDeprecation = true;
                }
            };
        }
        function createDeprecation(name, options = {}) {
            const version2 = typeof options.typeScriptVersion === "string" ? new Version(options.typeScriptVersion) : options.typeScriptVersion ?? getTypeScriptVersion();
            const errorAfter = typeof options.errorAfter === "string" ? new Version(options.errorAfter) : options.errorAfter;
            const warnAfter = typeof options.warnAfter === "string" ? new Version(options.warnAfter) : options.warnAfter;
            const since = typeof options.since === "string" ? new Version(options.since) : options.since ?? warnAfter;
            const error2 = options.error || errorAfter && version2.compareTo(errorAfter) >= 0;
            const warn = !warnAfter || version2.compareTo(warnAfter) >= 0;
            return error2 ? createErrorDeprecation(name, errorAfter, since, options.message) : warn ? createWarningDeprecation(name, errorAfter, since, options.message) : noop;
        }
        function wrapFunction(deprecation, func) {
            return function () {
                deprecation();
                return func.apply(this, arguments);
            };
        }
        function deprecate(func, options) {
            const deprecation = createDeprecation((options == null ? void 0 : options.name) ?? Debug.getFunctionName(func), options);
            return wrapFunction(deprecation, func);
        }
        var enableDeprecationWarnings, typeScriptVersion2;
        var init_deprecate = __esm({
            "src/deprecatedCompat/deprecate.ts"() {
                "use strict";
                init_ts5();
                enableDeprecationWarnings = true;
            }
        });
        // src/deprecatedCompat/deprecations.ts
        function createOverload(name, overloads, binder2, deprecations) {
            Object.defineProperty(call, "name", { ...Object.getOwnPropertyDescriptor(call, "name"), value: name });
            if (deprecations) {
                for (const key of Object.keys(deprecations)) {
                    const index = +key;
                    if (!isNaN(index) && hasProperty(overloads, `${index}`)) {
                        overloads[index] = deprecate(overloads[index], { ...deprecations[index], name });
                    }
                }
            }
            const bind = createBinder2(overloads, binder2);
            return call;
            function call(...args) {
                const index = bind(args);
                const fn = index !== void 0 ? overloads[index] : void 0;
                if (typeof fn === "function") {
                    return fn(...args);
                }
                throw new TypeError("Invalid arguments");
            }
        }
        function createBinder2(overloads, binder2) {
            return (args) => {
                for (let i = 0; hasProperty(overloads, `${i}`) && hasProperty(binder2, `${i}`); i++) {
                    const fn = binder2[i];
                    if (fn(args)) {
                        return i;
                    }
                }
            };
        }
        function buildOverload(name) {
            return {
                overload: (overloads) => ({
                    bind: (binder2) => ({
                        finish: () => createOverload(name, overloads, binder2),
                        deprecate: (deprecations) => ({
                            finish: () => createOverload(name, overloads, binder2, deprecations)
                        })
                    })
                })
            };
        }
        var init_deprecations = __esm({
            "src/deprecatedCompat/deprecations.ts"() {
                "use strict";
                init_ts5();
                init_deprecate();
            }
        });
        // src/deprecatedCompat/5.0/identifierProperties.ts
        var init_identifierProperties = __esm({
            "src/deprecatedCompat/5.0/identifierProperties.ts"() {
                "use strict";
                init_ts5();
                init_deprecate();
                addObjectAllocatorPatcher((objectAllocator2) => {
                    const Identifier79 = objectAllocator2.getIdentifierConstructor();
                    if (!hasProperty(Identifier79.prototype, "originalKeywordKind")) {
                        Object.defineProperty(Identifier79.prototype, "originalKeywordKind", {
                            get: deprecate(function () {
                                return identifierToKeywordKind(this);
                            }, {
                                name: "originalKeywordKind",
                                since: "5.0",
                                warnAfter: "5.1",
                                errorAfter: "5.2",
                                message: "Use 'identifierToKeywordKind(identifier)' instead."
                            })
                        });
                    }
                    if (!hasProperty(Identifier79.prototype, "isInJSDocNamespace")) {
                        Object.defineProperty(Identifier79.prototype, "isInJSDocNamespace", {
                            get: deprecate(function () {
                                return this.flags & 4096 /* IdentifierIsInJSDocNamespace */ ? true : void 0;
                            }, {
                                name: "isInJSDocNamespace",
                                since: "5.0",
                                warnAfter: "5.1",
                                errorAfter: "5.2",
                                message: "Use '.parent' or the surrounding context to determine this instead."
                            })
                        });
                    }
                });
            }
        });
        // src/deprecatedCompat/_namespaces/ts.ts
        var init_ts5 = __esm({
            "src/deprecatedCompat/_namespaces/ts.ts"() {
                "use strict";
                init_ts2();
                init_deprecations();
                init_identifierProperties();
            }
        });
        // src/typingsInstallerCore/_namespaces/ts.ts
        var init_ts6 = __esm({
            "src/typingsInstallerCore/_namespaces/ts.ts"() {
                "use strict";
                init_ts2();
                init_ts3();
                init_ts_server2();
            }
        });
        // src/typingsInstallerCore/typingsInstaller.ts
        function typingToFileName(cachePath, packageName, installTypingHost, log) {
            try {
                const result = resolveModuleName(packageName, combinePaths(cachePath, "index.d.ts"), { moduleResolution: 2 /* Node10 */ }, installTypingHost);
                return result.resolvedModule && result.resolvedModule.resolvedFileName;
            }
            catch (e) {
                if (log.isEnabled()) {
                    log.writeLine(`Failed to resolve ${packageName} in folder '${cachePath}': ${e.message}`);
                }
                return void 0;
            }
        }
        function installNpmPackages(npmPath, tsVersion, packageNames, install) {
            let hasError = false;
            for (let remaining = packageNames.length; remaining > 0;) {
                const result = getNpmCommandForInstallation(npmPath, tsVersion, packageNames, remaining);
                remaining = result.remaining;
                hasError = install(result.command) || hasError;
            }
            return hasError;
        }
        function getNpmCommandForInstallation(npmPath, tsVersion, packageNames, remaining) {
            const sliceStart = packageNames.length - remaining;
            let command, toSlice = remaining;
            while (true) {
                command = `${npmPath} install --ignore-scripts ${(toSlice === packageNames.length ? packageNames : packageNames.slice(sliceStart, sliceStart + toSlice)).join(" ")} --save-dev --user-agent="typesInstaller/${tsVersion}"`;
                if (command.length < 8e3) {
                    break;
                }
                toSlice = toSlice - Math.floor(toSlice / 2);
            }
            return { command, remaining: remaining - toSlice };
        }
        function typingsName(packageName) {
            return `@types/${packageName}@ts${versionMajorMinor}`;
        }
        var nullLog, TypingsInstaller;
        var init_typingsInstaller = __esm({
            "src/typingsInstallerCore/typingsInstaller.ts"() {
                "use strict";
                init_ts6();
                init_ts_server2();
                nullLog = {
                    isEnabled: () => false,
                    writeLine: noop
                };
                TypingsInstaller = class {
                    constructor(installTypingHost, globalCachePath, safeListPath, typesMapLocation, throttleLimit, log = nullLog) {
                        this.installTypingHost = installTypingHost;
                        this.globalCachePath = globalCachePath;
                        this.safeListPath = safeListPath;
                        this.typesMapLocation = typesMapLocation;
                        this.throttleLimit = throttleLimit;
                        this.log = log;
                        this.packageNameToTypingLocation = /* @__PURE__ */ new Map();
                        this.missingTypingsSet = /* @__PURE__ */ new Set();
                        this.knownCachesSet = /* @__PURE__ */ new Set();
                        this.projectWatchers = /* @__PURE__ */ new Map();
                        /** @internal */
                        this.pendingRunRequests = [];
                        this.installRunCount = 1;
                        this.inFlightRequestCount = 0;
                        this.latestDistTag = "latest";
                        const isLoggingEnabled = this.log.isEnabled();
                        if (isLoggingEnabled) {
                            this.log.writeLine(`Global cache location '${globalCachePath}', safe file path '${safeListPath}', types map path ${typesMapLocation}`);
                        }
                        this.processCacheLocation(this.globalCachePath);
                    }
                    /** @internal */
                    handleRequest(req) {
                        switch (req.kind) {
                            case "discover":
                                this.install(req);
                                break;
                            case "closeProject":
                                this.closeProject(req);
                                break;
                            case "typesRegistry": {
                                const typesRegistry = {};
                                this.typesRegistry.forEach((value, key) => {
                                    typesRegistry[key] = value;
                                });
                                const response = { kind: EventTypesRegistry, typesRegistry };
                                this.sendResponse(response);
                                break;
                            }
                            case "installPackage": {
                                this.installPackage(req);
                                break;
                            }
                            default:
                                Debug.assertNever(req);
                        }
                    }
                    closeProject(req) {
                        this.closeWatchers(req.projectName);
                    }
                    closeWatchers(projectName) {
                        if (this.log.isEnabled()) {
                            this.log.writeLine(`Closing file watchers for project '${projectName}'`);
                        }
                        const watchers = this.projectWatchers.get(projectName);
                        if (!watchers) {
                            if (this.log.isEnabled()) {
                                this.log.writeLine(`No watchers are registered for project '${projectName}'`);
                            }
                            return;
                        }
                        this.projectWatchers.delete(projectName);
                        this.sendResponse({ kind: ActionWatchTypingLocations, projectName, files: [] });
                        if (this.log.isEnabled()) {
                            this.log.writeLine(`Closing file watchers for project '${projectName}' - done.`);
                        }
                    }
                    install(req) {
                        if (this.log.isEnabled()) {
                            this.log.writeLine(`Got install request${stringifyIndented(req)}`);
                        }
                        if (req.cachePath) {
                            if (this.log.isEnabled()) {
                                this.log.writeLine(`Request specifies cache path '${req.cachePath}', loading cached information...`);
                            }
                            this.processCacheLocation(req.cachePath);
                        }
                        if (this.safeList === void 0) {
                            this.initializeSafeList();
                        }
                        const discoverTypingsResult = ts_JsTyping_exports.discoverTypings(this.installTypingHost, this.log.isEnabled() ? (s) => this.log.writeLine(s) : void 0, req.fileNames, req.projectRootPath, this.safeList, this.packageNameToTypingLocation, req.typeAcquisition, req.unresolvedImports, this.typesRegistry, req.compilerOptions);
                        this.watchFiles(req.projectName, discoverTypingsResult.filesToWatch);
                        if (discoverTypingsResult.newTypingNames.length) {
                            this.installTypings(req, req.cachePath || this.globalCachePath, discoverTypingsResult.cachedTypingPaths, discoverTypingsResult.newTypingNames);
                        }
                        else {
                            this.sendResponse(this.createSetTypings(req, discoverTypingsResult.cachedTypingPaths));
                            if (this.log.isEnabled()) {
                                this.log.writeLine(`No new typings were requested as a result of typings discovery`);
                            }
                        }
                    }
                    /** @internal */
                    installPackage(req) {
                        const { fileName, packageName, projectName, projectRootPath, id } = req;
                        const cwd = forEachAncestorDirectory(getDirectoryPath(fileName), (directory) => {
                            if (this.installTypingHost.fileExists(combinePaths(directory, "package.json"))) {
                                return directory;
                            }
                        }) || projectRootPath;
                        if (cwd) {
                            this.installWorker(-1, [packageName], cwd, (success) => {
                                const message = success ? `Package ${packageName} installed.` : `There was an error installing ${packageName}.`;
                                const response = {
                                    kind: ActionPackageInstalled,
                                    projectName,
                                    id,
                                    success,
                                    message
                                };
                                this.sendResponse(response);
                            });
                        }
                        else {
                            const response = {
                                kind: ActionPackageInstalled,
                                projectName,
                                id,
                                success: false,
                                message: "Could not determine a project root path."
                            };
                            this.sendResponse(response);
                        }
                    }
                    initializeSafeList() {
                        if (this.typesMapLocation) {
                            const safeListFromMap = ts_JsTyping_exports.loadTypesMap(this.installTypingHost, this.typesMapLocation);
                            if (safeListFromMap) {
                                this.log.writeLine(`Loaded safelist from types map file '${this.typesMapLocation}'`);
                                this.safeList = safeListFromMap;
                                return;
                            }
                            this.log.writeLine(`Failed to load safelist from types map file '${this.typesMapLocation}'`);
                        }
                        this.safeList = ts_JsTyping_exports.loadSafeList(this.installTypingHost, this.safeListPath);
                    }
                    processCacheLocation(cacheLocation) {
                        if (this.log.isEnabled()) {
                            this.log.writeLine(`Processing cache location '${cacheLocation}'`);
                        }
                        if (this.knownCachesSet.has(cacheLocation)) {
                            if (this.log.isEnabled()) {
                                this.log.writeLine(`Cache location was already processed...`);
                            }
                            return;
                        }
                        const packageJson = combinePaths(cacheLocation, "package.json");
                        const packageLockJson = combinePaths(cacheLocation, "package-lock.json");
                        if (this.log.isEnabled()) {
                            this.log.writeLine(`Trying to find '${packageJson}'...`);
                        }
                        if (this.installTypingHost.fileExists(packageJson) && this.installTypingHost.fileExists(packageLockJson)) {
                            const npmConfig = JSON.parse(this.installTypingHost.readFile(packageJson));
                            const npmLock = JSON.parse(this.installTypingHost.readFile(packageLockJson));
                            if (this.log.isEnabled()) {
                                this.log.writeLine(`Loaded content of '${packageJson}':${stringifyIndented(npmConfig)}`);
                                this.log.writeLine(`Loaded content of '${packageLockJson}':${stringifyIndented(npmLock)}`);
                            }
                            if (npmConfig.devDependencies && npmLock.dependencies) {
                                for (const key in npmConfig.devDependencies) {
                                    if (!hasProperty(npmLock.dependencies, key)) {
                                        continue;
                                    }
                                    const packageName = getBaseFileName(key);
                                    if (!packageName) {
                                        continue;
                                    }
                                    const typingFile = typingToFileName(cacheLocation, packageName, this.installTypingHost, this.log);
                                    if (!typingFile) {
                                        this.missingTypingsSet.add(packageName);
                                        continue;
                                    }
                                    const existingTypingFile = this.packageNameToTypingLocation.get(packageName);
                                    if (existingTypingFile) {
                                        if (existingTypingFile.typingLocation === typingFile) {
                                            continue;
                                        }
                                        if (this.log.isEnabled()) {
                                            this.log.writeLine(`New typing for package ${packageName} from '${typingFile}' conflicts with existing typing file '${existingTypingFile}'`);
                                        }
                                    }
                                    if (this.log.isEnabled()) {
                                        this.log.writeLine(`Adding entry into typings cache: '${packageName}' => '${typingFile}'`);
                                    }
                                    const info = getProperty(npmLock.dependencies, key);
                                    const version2 = info && info.version;
                                    if (!version2) {
                                        continue;
                                    }
                                    const newTyping = { typingLocation: typingFile, version: new Version(version2) };
                                    this.packageNameToTypingLocation.set(packageName, newTyping);
                                }
                            }
                        }
                        if (this.log.isEnabled()) {
                            this.log.writeLine(`Finished processing cache location '${cacheLocation}'`);
                        }
                        this.knownCachesSet.add(cacheLocation);
                    }
                    filterTypings(typingsToInstall) {
                        return mapDefined(typingsToInstall, (typing) => {
                            const typingKey = mangleScopedPackageName(typing);
                            if (this.missingTypingsSet.has(typingKey)) {
                                if (this.log.isEnabled())
                                    this.log.writeLine(`'${typing}':: '${typingKey}' is in missingTypingsSet - skipping...`);
                                return void 0;
                            }
                            const validationResult = ts_JsTyping_exports.validatePackageName(typing);
                            if (validationResult !== ts_JsTyping_exports.NameValidationResult.Ok) {
                                this.missingTypingsSet.add(typingKey);
                                if (this.log.isEnabled())
                                    this.log.writeLine(ts_JsTyping_exports.renderPackageNameValidationFailure(validationResult, typing));
                                return void 0;
                            }
                            if (!this.typesRegistry.has(typingKey)) {
                                if (this.log.isEnabled())
                                    this.log.writeLine(`'${typing}':: Entry for package '${typingKey}' does not exist in local types registry - skipping...`);
                                return void 0;
                            }
                            if (this.packageNameToTypingLocation.get(typingKey) && ts_JsTyping_exports.isTypingUpToDate(this.packageNameToTypingLocation.get(typingKey), this.typesRegistry.get(typingKey))) {
                                if (this.log.isEnabled())
                                    this.log.writeLine(`'${typing}':: '${typingKey}' already has an up-to-date typing - skipping...`);
                                return void 0;
                            }
                            return typingKey;
                        });
                    }
                    ensurePackageDirectoryExists(directory) {
                        const npmConfigPath = combinePaths(directory, "package.json");
                        if (this.log.isEnabled()) {
                            this.log.writeLine(`Npm config file: ${npmConfigPath}`);
                        }
                        if (!this.installTypingHost.fileExists(npmConfigPath)) {
                            if (this.log.isEnabled()) {
                                this.log.writeLine(`Npm config file: '${npmConfigPath}' is missing, creating new one...`);
                            }
                            this.ensureDirectoryExists(directory, this.installTypingHost);
                            this.installTypingHost.writeFile(npmConfigPath, '{ "private": true }');
                        }
                    }
                    installTypings(req, cachePath, currentlyCachedTypings, typingsToInstall) {
                        if (this.log.isEnabled()) {
                            this.log.writeLine(`Installing typings ${JSON.stringify(typingsToInstall)}`);
                        }
                        const filteredTypings = this.filterTypings(typingsToInstall);
                        if (filteredTypings.length === 0) {
                            if (this.log.isEnabled()) {
                                this.log.writeLine(`All typings are known to be missing or invalid - no need to install more typings`);
                            }
                            this.sendResponse(this.createSetTypings(req, currentlyCachedTypings));
                            return;
                        }
                        this.ensurePackageDirectoryExists(cachePath);
                        const requestId = this.installRunCount;
                        this.installRunCount++;
                        this.sendResponse({
                            kind: EventBeginInstallTypes,
                            eventId: requestId,
                            typingsInstallerVersion: version,
                            projectName: req.projectName
                        });
                        const scopedTypings = filteredTypings.map(typingsName);
                        this.installTypingsAsync(requestId, scopedTypings, cachePath, (ok) => {
                            try {
                                if (!ok) {
                                    if (this.log.isEnabled()) {
                                        this.log.writeLine(`install request failed, marking packages as missing to prevent repeated requests: ${JSON.stringify(filteredTypings)}`);
                                    }
                                    for (const typing of filteredTypings) {
                                        this.missingTypingsSet.add(typing);
                                    }
                                    return;
                                }
                                if (this.log.isEnabled()) {
                                    this.log.writeLine(`Installed typings ${JSON.stringify(scopedTypings)}`);
                                }
                                const installedTypingFiles = [];
                                for (const packageName of filteredTypings) {
                                    const typingFile = typingToFileName(cachePath, packageName, this.installTypingHost, this.log);
                                    if (!typingFile) {
                                        this.missingTypingsSet.add(packageName);
                                        continue;
                                    }
                                    const distTags = this.typesRegistry.get(packageName);
                                    const newVersion = new Version(distTags[`ts${versionMajorMinor}`] || distTags[this.latestDistTag]);
                                    const newTyping = { typingLocation: typingFile, version: newVersion };
                                    this.packageNameToTypingLocation.set(packageName, newTyping);
                                    installedTypingFiles.push(typingFile);
                                }
                                if (this.log.isEnabled()) {
                                    this.log.writeLine(`Installed typing files ${JSON.stringify(installedTypingFiles)}`);
                                }
                                this.sendResponse(this.createSetTypings(req, currentlyCachedTypings.concat(installedTypingFiles)));
                            }
                            finally {
                                const response = {
                                    kind: EventEndInstallTypes,
                                    eventId: requestId,
                                    projectName: req.projectName,
                                    packagesToInstall: scopedTypings,
                                    installSuccess: ok,
                                    typingsInstallerVersion: version
                                };
                                this.sendResponse(response);
                            }
                        });
                    }
                    ensureDirectoryExists(directory, host) {
                        const directoryName = getDirectoryPath(directory);
                        if (!host.directoryExists(directoryName)) {
                            this.ensureDirectoryExists(directoryName, host);
                        }
                        if (!host.directoryExists(directory)) {
                            host.createDirectory(directory);
                        }
                    }
                    watchFiles(projectName, files) {
                        if (!files.length) {
                            this.closeWatchers(projectName);
                            return;
                        }
                        const existing = this.projectWatchers.get(projectName);
                        const newSet = new Set(files);
                        if (!existing || forEachKey(newSet, (s) => !existing.has(s)) || forEachKey(existing, (s) => !newSet.has(s))) {
                            this.projectWatchers.set(projectName, newSet);
                            this.sendResponse({ kind: ActionWatchTypingLocations, projectName, files });
                        }
                        else {
                            this.sendResponse({ kind: ActionWatchTypingLocations, projectName, files: void 0 });
                        }
                    }
                    createSetTypings(request, typings) {
                        return {
                            projectName: request.projectName,
                            typeAcquisition: request.typeAcquisition,
                            compilerOptions: request.compilerOptions,
                            typings,
                            unresolvedImports: request.unresolvedImports,
                            kind: ActionSet
                        };
                    }
                    installTypingsAsync(requestId, packageNames, cwd, onRequestCompleted) {
                        this.pendingRunRequests.unshift({ requestId, packageNames, cwd, onRequestCompleted });
                        this.executeWithThrottling();
                    }
                    executeWithThrottling() {
                        while (this.inFlightRequestCount < this.throttleLimit && this.pendingRunRequests.length) {
                            this.inFlightRequestCount++;
                            const request = this.pendingRunRequests.pop();
                            this.installWorker(request.requestId, request.packageNames, request.cwd, (ok) => {
                                this.inFlightRequestCount--;
                                request.onRequestCompleted(ok);
                                this.executeWithThrottling();
                            });
                        }
                    }
                };
            }
        });
        // src/typingsInstallerCore/_namespaces/ts.server.typingsInstaller.ts
        var ts_server_typingsInstaller_exports = {};
        __export(ts_server_typingsInstaller_exports, {
            TypingsInstaller: () => TypingsInstaller,
            getNpmCommandForInstallation: () => getNpmCommandForInstallation,
            installNpmPackages: () => installNpmPackages,
            typingsName: () => typingsName
        });
        var init_ts_server_typingsInstaller = __esm({
            "src/typingsInstallerCore/_namespaces/ts.server.typingsInstaller.ts"() {
                "use strict";
                init_typingsInstaller();
            }
        });
        // src/typingsInstallerCore/_namespaces/ts.server.ts
        var init_ts_server2 = __esm({
            "src/typingsInstallerCore/_namespaces/ts.server.ts"() {
                "use strict";
                init_ts_server();
                init_ts_server_typingsInstaller();
            }
        });
        // src/server/types.ts
        var init_types4 = __esm({
            "src/server/types.ts"() {
                "use strict";
            }
        });
        // src/server/utilitiesPublic.ts
        function createInstallTypingsRequest(project, typeAcquisition, unresolvedImports, cachePath) {
            return {
                projectName: project.getProjectName(),
                fileNames: project.getFileNames(
                /*excludeFilesFromExternalLibraries*/
                true, 
                /*excludeConfigFiles*/
                true).concat(project.getExcludedFiles()),
                compilerOptions: project.getCompilationSettings(),
                typeAcquisition,
                unresolvedImports,
                projectRootPath: project.getCurrentDirectory(),
                cachePath,
                kind: "discover"
            };
        }
        function toNormalizedPath(fileName) {
            return normalizePath(fileName);
        }
        function normalizedPathToPath(normalizedPath, currentDirectory, getCanonicalFileName) {
            const f = isRootedDiskPath(normalizedPath) ? normalizedPath : getNormalizedAbsolutePath(normalizedPath, currentDirectory);
            return getCanonicalFileName(f);
        }
        function asNormalizedPath(fileName) {
            return fileName;
        }
        function createNormalizedPathMap() {
            const map2 = /* @__PURE__ */ new Map();
            return {
                get(path) {
                    return map2.get(path);
                },
                set(path, value) {
                    map2.set(path, value);
                },
                contains(path) {
                    return map2.has(path);
                },
                remove(path) {
                    map2.delete(path);
                }
            };
        }
        function isInferredProjectName(name) {
            return /dev\/null\/inferredProject\d+\*/.test(name);
        }
        function makeInferredProjectName(counter) {
            return `/dev/null/inferredProject${counter}*`;
        }
        function makeAutoImportProviderProjectName(counter) {
            return `/dev/null/autoImportProviderProject${counter}*`;
        }
        function makeAuxiliaryProjectName(counter) {
            return `/dev/null/auxiliaryProject${counter}*`;
        }
        function createSortedArray2() {
            return [];
        }
        var LogLevel2, emptyArray2, Msg, Errors;
        var init_utilitiesPublic3 = __esm({
            "src/server/utilitiesPublic.ts"() {
                "use strict";
                init_ts7();
                LogLevel2 = /* @__PURE__ */ ((LogLevel3) => {
                    LogLevel3[LogLevel3["terse"] = 0] = "terse";
                    LogLevel3[LogLevel3["normal"] = 1] = "normal";
                    LogLevel3[LogLevel3["requestTime"] = 2] = "requestTime";
                    LogLevel3[LogLevel3["verbose"] = 3] = "verbose";
                    return LogLevel3;
                })(LogLevel2 || {});
                emptyArray2 = createSortedArray2();
                Msg = /* @__PURE__ */ ((Msg2) => {
                    Msg2["Err"] = "Err";
                    Msg2["Info"] = "Info";
                    Msg2["Perf"] = "Perf";
                    return Msg2;
                })(Msg || {});
                ((Errors2) => {
                    function ThrowNoProject() {
                        throw new Error("No Project.");
                    }
                    Errors2.ThrowNoProject = ThrowNoProject;
                    function ThrowProjectLanguageServiceDisabled() {
                        throw new Error("The project's language service is disabled.");
                    }
                    Errors2.ThrowProjectLanguageServiceDisabled = ThrowProjectLanguageServiceDisabled;
                    function ThrowProjectDoesNotContainDocument(fileName, project) {
                        throw new Error(`Project '${project.getProjectName()}' does not contain document '${fileName}'`);
                    }
                    Errors2.ThrowProjectDoesNotContainDocument = ThrowProjectDoesNotContainDocument;
                })(Errors || (Errors = {}));
            }
        });
        // src/server/utilities.ts
        function getBaseConfigFileName(configFilePath) {
            const base = getBaseFileName(configFilePath);
            return base === "tsconfig.json" || base === "jsconfig.json" ? base : void 0;
        }
        function removeSorted(array, remove, compare) {
            if (!array || array.length === 0) {
                return;
            }
            if (array[0] === remove) {
                array.splice(0, 1);
                return;
            }
            const removeIndex = binarySearch(array, remove, identity, compare);
            if (removeIndex >= 0) {
                array.splice(removeIndex, 1);
            }
        }
        var ThrottledOperations, GcTimer;
        var init_utilities5 = __esm({
            "src/server/utilities.ts"() {
                "use strict";
                init_ts7();
                init_ts_server3();
                ThrottledOperations = class _ThrottledOperations {
                    constructor(host, logger) {
                        this.host = host;
                        this.pendingTimeouts = /* @__PURE__ */ new Map();
                        this.logger = logger.hasLevel(3 /* verbose */) ? logger : void 0;
                    }
                    /**
                     * Wait `number` milliseconds and then invoke `cb`.  If, while waiting, schedule
                     * is called again with the same `operationId`, cancel this operation in favor
                     * of the new one.  (Note that the amount of time the canceled operation had been
                     * waiting does not affect the amount of time that the new operation waits.)
                     */
                    schedule(operationId, delay, cb) {
                        const pendingTimeout = this.pendingTimeouts.get(operationId);
                        if (pendingTimeout) {
                            this.host.clearTimeout(pendingTimeout);
                        }
                        this.pendingTimeouts.set(operationId, this.host.setTimeout(_ThrottledOperations.run, delay, operationId, this, cb));
                        if (this.logger) {
                            this.logger.info(`Scheduled: ${operationId}${pendingTimeout ? ", Cancelled earlier one" : ""}`);
                        }
                    }
                    cancel(operationId) {
                        const pendingTimeout = this.pendingTimeouts.get(operationId);
                        if (!pendingTimeout)
                            return false;
                        this.host.clearTimeout(pendingTimeout);
                        return this.pendingTimeouts.delete(operationId);
                    }
                    static run(operationId, self, cb) {
                        var _a, _b;
                        (_a = perfLogger) == null ? void 0 : _a.logStartScheduledOperation(operationId);
                        self.pendingTimeouts.delete(operationId);
                        if (self.logger) {
                            self.logger.info(`Running: ${operationId}`);
                        }
                        cb();
                        (_b = perfLogger) == null ? void 0 : _b.logStopScheduledOperation();
                    }
                };
                GcTimer = class _GcTimer {
                    constructor(host, delay, logger) {
                        this.host = host;
                        this.delay = delay;
                        this.logger = logger;
                    }
                    scheduleCollect() {
                        if (!this.host.gc || this.timerId !== void 0) {
                            return;
                        }
                        this.timerId = this.host.setTimeout(_GcTimer.run, this.delay, this);
                    }
                    static run(self) {
                        var _a, _b;
                        self.timerId = void 0;
                        (_a = perfLogger) == null ? void 0 : _a.logStartScheduledOperation("GC collect");
                        const log = self.logger.hasLevel(2 /* requestTime */);
                        const before = log && self.host.getMemoryUsage();
                        self.host.gc();
                        if (log) {
                            const after = self.host.getMemoryUsage();
                            self.logger.perftrc(`GC::before ${before}, after ${after}`);
                        }
                        (_b = perfLogger) == null ? void 0 : _b.logStopScheduledOperation();
                    }
                };
            }
        });
        // src/server/protocol.ts
        var CommandTypes, OrganizeImportsMode2, WatchFileKind2, WatchDirectoryKind2, PollingWatchKind2, CompletionTriggerKind2, IndentStyle2, SemicolonPreference2, JsxEmit2, ModuleKind2, ModuleResolutionKind2, NewLineKind2, ScriptTarget10, ClassificationType2;
        var init_protocol = __esm({
            "src/server/protocol.ts"() {
                "use strict";
                CommandTypes = /* @__PURE__ */ ((CommandTypes2) => {
                    CommandTypes2["JsxClosingTag"] = "jsxClosingTag";
                    CommandTypes2["LinkedEditingRange"] = "linkedEditingRange";
                    CommandTypes2["Brace"] = "brace";
                    CommandTypes2["BraceFull"] = "brace-full";
                    CommandTypes2["BraceCompletion"] = "braceCompletion";
                    CommandTypes2["GetSpanOfEnclosingComment"] = "getSpanOfEnclosingComment";
                    CommandTypes2["Change"] = "change";
                    CommandTypes2["Close"] = "close";
                    CommandTypes2["Completions"] = "completions";
                    CommandTypes2["CompletionInfo"] = "completionInfo";
                    CommandTypes2["CompletionsFull"] = "completions-full";
                    CommandTypes2["CompletionDetails"] = "completionEntryDetails";
                    CommandTypes2["CompletionDetailsFull"] = "completionEntryDetails-full";
                    CommandTypes2["CompileOnSaveAffectedFileList"] = "compileOnSaveAffectedFileList";
                    CommandTypes2["CompileOnSaveEmitFile"] = "compileOnSaveEmitFile";
                    CommandTypes2["Configure"] = "configure";
                    CommandTypes2["Definition"] = "definition";
                    CommandTypes2["DefinitionFull"] = "definition-full";
                    CommandTypes2["DefinitionAndBoundSpan"] = "definitionAndBoundSpan";
                    CommandTypes2["DefinitionAndBoundSpanFull"] = "definitionAndBoundSpan-full";
                    CommandTypes2["Implementation"] = "implementation";
                    CommandTypes2["ImplementationFull"] = "implementation-full";
                    CommandTypes2["EmitOutput"] = "emit-output";
                    CommandTypes2["Exit"] = "exit";
                    CommandTypes2["FileReferences"] = "fileReferences";
                    CommandTypes2["FileReferencesFull"] = "fileReferences-full";
                    CommandTypes2["Format"] = "format";
                    CommandTypes2["Formatonkey"] = "formatonkey";
                    CommandTypes2["FormatFull"] = "format-full";
                    CommandTypes2["FormatonkeyFull"] = "formatonkey-full";
                    CommandTypes2["FormatRangeFull"] = "formatRange-full";
                    CommandTypes2["Geterr"] = "geterr";
                    CommandTypes2["GeterrForProject"] = "geterrForProject";
                    CommandTypes2["SemanticDiagnosticsSync"] = "semanticDiagnosticsSync";
                    CommandTypes2["SyntacticDiagnosticsSync"] = "syntacticDiagnosticsSync";
                    CommandTypes2["SuggestionDiagnosticsSync"] = "suggestionDiagnosticsSync";
                    CommandTypes2["NavBar"] = "navbar";
                    CommandTypes2["NavBarFull"] = "navbar-full";
                    CommandTypes2["Navto"] = "navto";
                    CommandTypes2["NavtoFull"] = "navto-full";
                    CommandTypes2["NavTree"] = "navtree";
                    CommandTypes2["NavTreeFull"] = "navtree-full";
                    CommandTypes2["DocumentHighlights"] = "documentHighlights";
                    CommandTypes2["DocumentHighlightsFull"] = "documentHighlights-full";
                    CommandTypes2["Open"] = "open";
                    CommandTypes2["Quickinfo"] = "quickinfo";
                    CommandTypes2["QuickinfoFull"] = "quickinfo-full";
                    CommandTypes2["References"] = "references";
                    CommandTypes2["ReferencesFull"] = "references-full";
                    CommandTypes2["Reload"] = "reload";
                    CommandTypes2["Rename"] = "rename";
                    CommandTypes2["RenameInfoFull"] = "rename-full";
                    CommandTypes2["RenameLocationsFull"] = "renameLocations-full";
                    CommandTypes2["Saveto"] = "saveto";
                    CommandTypes2["SignatureHelp"] = "signatureHelp";
                    CommandTypes2["SignatureHelpFull"] = "signatureHelp-full";
                    CommandTypes2["FindSourceDefinition"] = "findSourceDefinition";
                    CommandTypes2["Status"] = "status";
                    CommandTypes2["TypeDefinition"] = "typeDefinition";
                    CommandTypes2["ProjectInfo"] = "projectInfo";
                    CommandTypes2["ReloadProjects"] = "reloadProjects";
                    CommandTypes2["Unknown"] = "unknown";
                    CommandTypes2["OpenExternalProject"] = "openExternalProject";
                    CommandTypes2["OpenExternalProjects"] = "openExternalProjects";
                    CommandTypes2["CloseExternalProject"] = "closeExternalProject";
                    CommandTypes2["SynchronizeProjectList"] = "synchronizeProjectList";
                    CommandTypes2["ApplyChangedToOpenFiles"] = "applyChangedToOpenFiles";
                    CommandTypes2["UpdateOpen"] = "updateOpen";
                    CommandTypes2["EncodedSyntacticClassificationsFull"] = "encodedSyntacticClassifications-full";
                    CommandTypes2["EncodedSemanticClassificationsFull"] = "encodedSemanticClassifications-full";
                    CommandTypes2["Cleanup"] = "cleanup";
                    CommandTypes2["GetOutliningSpans"] = "getOutliningSpans";
                    CommandTypes2["GetOutliningSpansFull"] = "outliningSpans";
                    CommandTypes2["TodoComments"] = "todoComments";
                    CommandTypes2["Indentation"] = "indentation";
                    CommandTypes2["DocCommentTemplate"] = "docCommentTemplate";
                    CommandTypes2["CompilerOptionsDiagnosticsFull"] = "compilerOptionsDiagnostics-full";
                    CommandTypes2["NameOrDottedNameSpan"] = "nameOrDottedNameSpan";
                    CommandTypes2["BreakpointStatement"] = "breakpointStatement";
                    CommandTypes2["CompilerOptionsForInferredProjects"] = "compilerOptionsForInferredProjects";
                    CommandTypes2["GetCodeFixes"] = "getCodeFixes";
                    CommandTypes2["GetCodeFixesFull"] = "getCodeFixes-full";
                    CommandTypes2["GetCombinedCodeFix"] = "getCombinedCodeFix";
                    CommandTypes2["GetCombinedCodeFixFull"] = "getCombinedCodeFix-full";
                    CommandTypes2["ApplyCodeActionCommand"] = "applyCodeActionCommand";
                    CommandTypes2["GetSupportedCodeFixes"] = "getSupportedCodeFixes";
                    CommandTypes2["GetApplicableRefactors"] = "getApplicableRefactors";
                    CommandTypes2["GetEditsForRefactor"] = "getEditsForRefactor";
                    CommandTypes2["GetMoveToRefactoringFileSuggestions"] = "getMoveToRefactoringFileSuggestions";
                    CommandTypes2["GetEditsForRefactorFull"] = "getEditsForRefactor-full";
                    CommandTypes2["OrganizeImports"] = "organizeImports";
                    CommandTypes2["OrganizeImportsFull"] = "organizeImports-full";
                    CommandTypes2["GetEditsForFileRename"] = "getEditsForFileRename";
                    CommandTypes2["GetEditsForFileRenameFull"] = "getEditsForFileRename-full";
                    CommandTypes2["ConfigurePlugin"] = "configurePlugin";
                    CommandTypes2["SelectionRange"] = "selectionRange";
                    CommandTypes2["SelectionRangeFull"] = "selectionRange-full";
                    CommandTypes2["ToggleLineComment"] = "toggleLineComment";
                    CommandTypes2["ToggleLineCommentFull"] = "toggleLineComment-full";
                    CommandTypes2["ToggleMultilineComment"] = "toggleMultilineComment";
                    CommandTypes2["ToggleMultilineCommentFull"] = "toggleMultilineComment-full";
                    CommandTypes2["CommentSelection"] = "commentSelection";
                    CommandTypes2["CommentSelectionFull"] = "commentSelection-full";
                    CommandTypes2["UncommentSelection"] = "uncommentSelection";
                    CommandTypes2["UncommentSelectionFull"] = "uncommentSelection-full";
                    CommandTypes2["PrepareCallHierarchy"] = "prepareCallHierarchy";
                    CommandTypes2["ProvideCallHierarchyIncomingCalls"] = "provideCallHierarchyIncomingCalls";
                    CommandTypes2["ProvideCallHierarchyOutgoingCalls"] = "provideCallHierarchyOutgoingCalls";
                    CommandTypes2["ProvideInlayHints"] = "provideInlayHints";
                    CommandTypes2["WatchChange"] = "watchChange";
                    return CommandTypes2;
                })(CommandTypes || {});
                OrganizeImportsMode2 = /* @__PURE__ */ ((OrganizeImportsMode3) => {
                    OrganizeImportsMode3["All"] = "All";
                    OrganizeImportsMode3["SortAndCombine"] = "SortAndCombine";
                    OrganizeImportsMode3["RemoveUnused"] = "RemoveUnused";
                    return OrganizeImportsMode3;
                })(OrganizeImportsMode2 || {});
                WatchFileKind2 = /* @__PURE__ */ ((WatchFileKind3) => {
                    WatchFileKind3["FixedPollingInterval"] = "FixedPollingInterval";
                    WatchFileKind3["PriorityPollingInterval"] = "PriorityPollingInterval";
                    WatchFileKind3["DynamicPriorityPolling"] = "DynamicPriorityPolling";
                    WatchFileKind3["FixedChunkSizePolling"] = "FixedChunkSizePolling";
                    WatchFileKind3["UseFsEvents"] = "UseFsEvents";
                    WatchFileKind3["UseFsEventsOnParentDirectory"] = "UseFsEventsOnParentDirectory";
                    return WatchFileKind3;
                })(WatchFileKind2 || {});
                WatchDirectoryKind2 = /* @__PURE__ */ ((WatchDirectoryKind3) => {
                    WatchDirectoryKind3["UseFsEvents"] = "UseFsEvents";
                    WatchDirectoryKind3["FixedPollingInterval"] = "FixedPollingInterval";
                    WatchDirectoryKind3["DynamicPriorityPolling"] = "DynamicPriorityPolling";
                    WatchDirectoryKind3["FixedChunkSizePolling"] = "FixedChunkSizePolling";
                    return WatchDirectoryKind3;
                })(WatchDirectoryKind2 || {});
                PollingWatchKind2 = /* @__PURE__ */ ((PollingWatchKind3) => {
                    PollingWatchKind3["FixedInterval"] = "FixedInterval";
                    PollingWatchKind3["PriorityInterval"] = "PriorityInterval";
                    PollingWatchKind3["DynamicPriority"] = "DynamicPriority";
                    PollingWatchKind3["FixedChunkSize"] = "FixedChunkSize";
                    return PollingWatchKind3;
                })(PollingWatchKind2 || {});
                CompletionTriggerKind2 = /* @__PURE__ */ ((CompletionTriggerKind4) => {
                    CompletionTriggerKind4[CompletionTriggerKind4["Invoked"] = 1] = "Invoked";
                    CompletionTriggerKind4[CompletionTriggerKind4["TriggerCharacter"] = 2] = "TriggerCharacter";
                    CompletionTriggerKind4[CompletionTriggerKind4["TriggerForIncompleteCompletions"] = 3] = "TriggerForIncompleteCompletions";
                    return CompletionTriggerKind4;
                })(CompletionTriggerKind2 || {});
                IndentStyle2 = /* @__PURE__ */ ((IndentStyle3) => {
                    IndentStyle3["None"] = "None";
                    IndentStyle3["Block"] = "Block";
                    IndentStyle3["Smart"] = "Smart";
                    return IndentStyle3;
                })(IndentStyle2 || {});
                SemicolonPreference2 = /* @__PURE__ */ ((SemicolonPreference3) => {
                    SemicolonPreference3["Ignore"] = "ignore";
                    SemicolonPreference3["Insert"] = "insert";
                    SemicolonPreference3["Remove"] = "remove";
                    return SemicolonPreference3;
                })(SemicolonPreference2 || {});
                JsxEmit2 = /* @__PURE__ */ ((JsxEmit3) => {
                    JsxEmit3["None"] = "None";
                    JsxEmit3["Preserve"] = "Preserve";
                    JsxEmit3["ReactNative"] = "ReactNative";
                    JsxEmit3["React"] = "React";
                    return JsxEmit3;
                })(JsxEmit2 || {});
                ModuleKind2 = /* @__PURE__ */ ((ModuleKind3) => {
                    ModuleKind3["None"] = "None";
                    ModuleKind3["CommonJS"] = "CommonJS";
                    ModuleKind3["AMD"] = "AMD";
                    ModuleKind3["UMD"] = "UMD";
                    ModuleKind3["System"] = "System";
                    ModuleKind3["ES6"] = "ES6";
                    ModuleKind3["ES2015"] = "ES2015";
                    ModuleKind3["ESNext"] = "ESNext";
                    ModuleKind3["Node16"] = "Node16";
                    ModuleKind3["NodeNext"] = "NodeNext";
                    ModuleKind3["Preserve"] = "Preserve";
                    return ModuleKind3;
                })(ModuleKind2 || {});
                ModuleResolutionKind2 = /* @__PURE__ */ ((ModuleResolutionKind3) => {
                    ModuleResolutionKind3["Classic"] = "Classic";
                    ModuleResolutionKind3["Node"] = "Node";
                    ModuleResolutionKind3["Node10"] = "Node10";
                    ModuleResolutionKind3["Node16"] = "Node16";
                    ModuleResolutionKind3["NodeNext"] = "NodeNext";
                    ModuleResolutionKind3["Bundler"] = "Bundler";
                    return ModuleResolutionKind3;
                })(ModuleResolutionKind2 || {});
                NewLineKind2 = /* @__PURE__ */ ((NewLineKind3) => {
                    NewLineKind3["Crlf"] = "Crlf";
                    NewLineKind3["Lf"] = "Lf";
                    return NewLineKind3;
                })(NewLineKind2 || {});
                ScriptTarget10 = /* @__PURE__ */ ((ScriptTarget11) => {
                    ScriptTarget11["ES3"] = "ES3";
                    ScriptTarget11["ES5"] = "ES5";
                    ScriptTarget11["ES6"] = "ES6";
                    ScriptTarget11["ES2015"] = "ES2015";
                    ScriptTarget11["ES2016"] = "ES2016";
                    ScriptTarget11["ES2017"] = "ES2017";
                    ScriptTarget11["ES2018"] = "ES2018";
                    ScriptTarget11["ES2019"] = "ES2019";
                    ScriptTarget11["ES2020"] = "ES2020";
                    ScriptTarget11["ES2021"] = "ES2021";
                    ScriptTarget11["ES2022"] = "ES2022";
                    ScriptTarget11["ESNext"] = "ESNext";
                    return ScriptTarget11;
                })(ScriptTarget10 || {});
                ClassificationType2 = /* @__PURE__ */ ((ClassificationType3) => {
                    ClassificationType3[ClassificationType3["comment"] = 1] = "comment";
                    ClassificationType3[ClassificationType3["identifier"] = 2] = "identifier";
                    ClassificationType3[ClassificationType3["keyword"] = 3] = "keyword";
                    ClassificationType3[ClassificationType3["numericLiteral"] = 4] = "numericLiteral";
                    ClassificationType3[ClassificationType3["operator"] = 5] = "operator";
                    ClassificationType3[ClassificationType3["stringLiteral"] = 6] = "stringLiteral";
                    ClassificationType3[ClassificationType3["regularExpressionLiteral"] = 7] = "regularExpressionLiteral";
                    ClassificationType3[ClassificationType3["whiteSpace"] = 8] = "whiteSpace";
                    ClassificationType3[ClassificationType3["text"] = 9] = "text";
                    ClassificationType3[ClassificationType3["punctuation"] = 10] = "punctuation";
                    ClassificationType3[ClassificationType3["className"] = 11] = "className";
                    ClassificationType3[ClassificationType3["enumName"] = 12] = "enumName";
                    ClassificationType3[ClassificationType3["interfaceName"] = 13] = "interfaceName";
                    ClassificationType3[ClassificationType3["moduleName"] = 14] = "moduleName";
                    ClassificationType3[ClassificationType3["typeParameterName"] = 15] = "typeParameterName";
                    ClassificationType3[ClassificationType3["typeAliasName"] = 16] = "typeAliasName";
                    ClassificationType3[ClassificationType3["parameterName"] = 17] = "parameterName";
                    ClassificationType3[ClassificationType3["docCommentTagName"] = 18] = "docCommentTagName";
                    ClassificationType3[ClassificationType3["jsxOpenTagName"] = 19] = "jsxOpenTagName";
                    ClassificationType3[ClassificationType3["jsxCloseTagName"] = 20] = "jsxCloseTagName";
                    ClassificationType3[ClassificationType3["jsxSelfClosingTagName"] = 21] = "jsxSelfClosingTagName";
                    ClassificationType3[ClassificationType3["jsxAttribute"] = 22] = "jsxAttribute";
                    ClassificationType3[ClassificationType3["jsxText"] = 23] = "jsxText";
                    ClassificationType3[ClassificationType3["jsxAttributeStringLiteralValue"] = 24] = "jsxAttributeStringLiteralValue";
                    ClassificationType3[ClassificationType3["bigintLiteral"] = 25] = "bigintLiteral";
                    return ClassificationType3;
                })(ClassificationType2 || {});
            }
        });
        // src/server/_namespaces/ts.server.protocol.ts
        var ts_server_protocol_exports = {};
        __export(ts_server_protocol_exports, {
            ClassificationType: () => ClassificationType2,
            CommandTypes: () => CommandTypes,
            CompletionTriggerKind: () => CompletionTriggerKind2,
            IndentStyle: () => IndentStyle2,
            JsxEmit: () => JsxEmit2,
            ModuleKind: () => ModuleKind2,
            ModuleResolutionKind: () => ModuleResolutionKind2,
            NewLineKind: () => NewLineKind2,
            OrganizeImportsMode: () => OrganizeImportsMode2,
            PollingWatchKind: () => PollingWatchKind2,
            ScriptTarget: () => ScriptTarget10,
            SemicolonPreference: () => SemicolonPreference2,
            WatchDirectoryKind: () => WatchDirectoryKind2,
            WatchFileKind: () => WatchFileKind2
        });
        var init_ts_server_protocol = __esm({
            "src/server/_namespaces/ts.server.protocol.ts"() {
                "use strict";
                init_protocol();
            }
        });
        // src/server/scriptInfo.ts
        function isDynamicFileName(fileName) {
            return fileName[0] === "^" || (fileName.includes("walkThroughSnippet:/") || fileName.includes("untitled:/")) && getBaseFileName(fileName)[0] === "^" || fileName.includes(":^") && !fileName.includes(directorySeparator);
        }
        function ensurePrimaryProjectKind(project) {
            if (!project || isBackgroundProject(project)) {
                return Errors.ThrowNoProject();
            }
            return project;
        }
        function failIfInvalidPosition(position) {
            Debug.assert(typeof position === "number", `Expected position ${position} to be a number.`);
            Debug.assert(position >= 0, `Expected position to be non-negative.`);
        }
        function failIfInvalidLocation(location) {
            Debug.assert(typeof location.line === "number", `Expected line ${location.line} to be a number.`);
            Debug.assert(typeof location.offset === "number", `Expected offset ${location.offset} to be a number.`);
            Debug.assert(location.line > 0, `Expected line to be non-${location.line === 0 ? "zero" : "negative"}`);
            Debug.assert(location.offset > 0, `Expected offset to be non-${location.offset === 0 ? "zero" : "negative"}`);
        }
        var TextStorage, ScriptInfo;
        var init_scriptInfo = __esm({
            "src/server/scriptInfo.ts"() {
                "use strict";
                init_ts7();
                init_ts_server3();
                TextStorage = class {
                    constructor(host, info, initialVersion) {
                        this.host = host;
                        this.info = info;
                        /**
                         * True if the text is for the file thats open in the editor
                         */
                        this.isOpen = false;
                        /**
                         * True if the text present is the text from the file on the disk
                         */
                        this.ownFileText = false;
                        /**
                         * True when reloading contents of file from the disk is pending
                         */
                        this.pendingReloadFromDisk = false;
                        this.version = initialVersion || 0;
                    }
                    getVersion() {
                        return this.svc ? `SVC-${this.version}-${this.svc.getSnapshotVersion()}` : `Text-${this.version}`;
                    }
                    hasScriptVersionCache_TestOnly() {
                        return this.svc !== void 0;
                    }
                    resetSourceMapInfo() {
                        this.info.sourceFileLike = void 0;
                        this.info.closeSourceMapFileWatcher();
                        this.info.sourceMapFilePath = void 0;
                        this.info.declarationInfoPath = void 0;
                        this.info.sourceInfos = void 0;
                        this.info.documentPositionMapper = void 0;
                    }
                    /** Public for testing */
                    useText(newText) {
                        this.svc = void 0;
                        this.text = newText;
                        this.textSnapshot = void 0;
                        this.lineMap = void 0;
                        this.fileSize = void 0;
                        this.resetSourceMapInfo();
                        this.version++;
                    }
                    edit(start, end, newText) {
                        this.switchToScriptVersionCache().edit(start, end - start, newText);
                        this.ownFileText = false;
                        this.text = void 0;
                        this.textSnapshot = void 0;
                        this.lineMap = void 0;
                        this.fileSize = void 0;
                        this.resetSourceMapInfo();
                    }
                    /**
                     * Set the contents as newText
                     * returns true if text changed
                     */
                    reload(newText) {
                        Debug.assert(newText !== void 0);
                        this.pendingReloadFromDisk = false;
                        if (!this.text && this.svc) {
                            this.text = getSnapshotText(this.svc.getSnapshot());
                        }
                        if (this.text !== newText) {
                            this.useText(newText);
                            this.ownFileText = false;
                            return true;
                        }
                        return false;
                    }
                    /**
                     * Reads the contents from tempFile(if supplied) or own file and sets it as contents
                     * returns true if text changed
                     */
                    reloadWithFileText(tempFileName) {
                        const { text: newText, fileSize } = tempFileName || !this.info.isDynamicOrHasMixedContent() ? this.getFileTextAndSize(tempFileName) : { text: "", fileSize: void 0 };
                        const reloaded = this.reload(newText);
                        this.fileSize = fileSize;
                        this.ownFileText = !tempFileName || tempFileName === this.info.fileName;
                        return reloaded;
                    }
                    /**
                     * Schedule reload from the disk if its not already scheduled and its not own text
                     * returns true when scheduling reload
                     */
                    scheduleReloadIfNeeded() {
                        return !this.pendingReloadFromDisk && !this.ownFileText ? this.pendingReloadFromDisk = true : false;
                    }
                    delayReloadFromFileIntoText() {
                        this.pendingReloadFromDisk = true;
                    }
                    /**
                     * For telemetry purposes, we would like to be able to report the size of the file.
                     * However, we do not want telemetry to require extra file I/O so we report a size
                     * that may be stale (e.g. may not reflect change made on disk since the last reload).
                     * NB: Will read from disk if the file contents have never been loaded because
                     * telemetry falsely indicating size 0 would be counter-productive.
                     */
                    getTelemetryFileSize() {
                        return !!this.fileSize ? this.fileSize : !!this.text ? this.text.length : !!this.svc ? this.svc.getSnapshot().getLength() : this.getSnapshot().getLength();
                    }
                    getSnapshot() {
                        var _a;
                        return ((_a = this.tryUseScriptVersionCache()) == null ? void 0 : _a.getSnapshot()) || (this.textSnapshot ?? (this.textSnapshot = ScriptSnapshot.fromString(Debug.checkDefined(this.text))));
                    }
                    getAbsolutePositionAndLineText(oneBasedLine) {
                        const svc = this.tryUseScriptVersionCache();
                        if (svc)
                            return svc.getAbsolutePositionAndLineText(oneBasedLine);
                        const lineMap = this.getLineMap();
                        return oneBasedLine <= lineMap.length ? {
                            absolutePosition: lineMap[oneBasedLine - 1],
                            lineText: this.text.substring(lineMap[oneBasedLine - 1], lineMap[oneBasedLine])
                        } : {
                            absolutePosition: this.text.length,
                            lineText: void 0
                        };
                    }
                    /**
                     *  @param line 0 based index
                     */
                    lineToTextSpan(line) {
                        const svc = this.tryUseScriptVersionCache();
                        if (svc)
                            return svc.lineToTextSpan(line);
                        const lineMap = this.getLineMap();
                        const start = lineMap[line];
                        const end = line + 1 < lineMap.length ? lineMap[line + 1] : this.text.length;
                        return createTextSpanFromBounds(start, end);
                    }
                    /**
                     * @param line 1 based index
                     * @param offset 1 based index
                     */
                    lineOffsetToPosition(line, offset, allowEdits) {
                        const svc = this.tryUseScriptVersionCache();
                        return svc ? svc.lineOffsetToPosition(line, offset) : computePositionOfLineAndCharacter(this.getLineMap(), line - 1, offset - 1, this.text, allowEdits);
                    }
                    positionToLineOffset(position) {
                        const svc = this.tryUseScriptVersionCache();
                        if (svc)
                            return svc.positionToLineOffset(position);
                        const { line, character } = computeLineAndCharacterOfPosition(this.getLineMap(), position);
                        return { line: line + 1, offset: character + 1 };
                    }
                    getFileTextAndSize(tempFileName) {
                        let text;
                        const fileName = tempFileName || this.info.fileName;
                        const getText = () => text === void 0 ? text = this.host.readFile(fileName) || "" : text;
                        if (!hasTSFileExtension(this.info.fileName)) {
                            const fileSize = this.host.getFileSize ? this.host.getFileSize(fileName) : getText().length;
                            if (fileSize > maxFileSize) {
                                Debug.assert(!!this.info.containingProjects.length);
                                const service = this.info.containingProjects[0].projectService;
                                service.logger.info(`Skipped loading contents of large file ${fileName} for info ${this.info.fileName}: fileSize: ${fileSize}`);
                                this.info.containingProjects[0].projectService.sendLargeFileReferencedEvent(fileName, fileSize);
                                return { text: "", fileSize };
                            }
                        }
                        return { text: getText() };
                    }
                    /** @internal */
                    switchToScriptVersionCache() {
                        if (!this.svc || this.pendingReloadFromDisk) {
                            this.svc = ScriptVersionCache.fromString(this.getOrLoadText());
                            this.textSnapshot = void 0;
                            this.version++;
                        }
                        return this.svc;
                    }
                    tryUseScriptVersionCache() {
                        if (!this.svc || this.pendingReloadFromDisk) {
                            this.getOrLoadText();
                        }
                        if (this.isOpen) {
                            if (!this.svc && !this.textSnapshot) {
                                this.svc = ScriptVersionCache.fromString(Debug.checkDefined(this.text));
                                this.textSnapshot = void 0;
                            }
                            return this.svc;
                        }
                        return this.svc;
                    }
                    getOrLoadText() {
                        if (this.text === void 0 || this.pendingReloadFromDisk) {
                            Debug.assert(!this.svc || this.pendingReloadFromDisk, "ScriptVersionCache should not be set when reloading from disk");
                            this.reloadWithFileText();
                        }
                        return this.text;
                    }
                    getLineMap() {
                        Debug.assert(!this.svc, "ScriptVersionCache should not be set");
                        return this.lineMap || (this.lineMap = computeLineStarts(Debug.checkDefined(this.text)));
                    }
                    getLineInfo() {
                        const svc = this.tryUseScriptVersionCache();
                        if (svc) {
                            return {
                                getLineCount: () => svc.getLineCount(),
                                getLineText: (line) => svc.getAbsolutePositionAndLineText(line + 1).lineText
                            };
                        }
                        const lineMap = this.getLineMap();
                        return getLineInfo(this.text, lineMap);
                    }
                };
                ScriptInfo = class {
                    constructor(host, fileName, scriptKind, hasMixedContent, path, initialVersion) {
                        this.host = host;
                        this.fileName = fileName;
                        this.scriptKind = scriptKind;
                        this.hasMixedContent = hasMixedContent;
                        this.path = path;
                        /**
                         * All projects that include this file
                         */
                        this.containingProjects = [];
                        this.isDynamic = isDynamicFileName(fileName);
                        this.textStorage = new TextStorage(host, this, initialVersion);
                        if (hasMixedContent || this.isDynamic) {
                            this.realpath = this.path;
                        }
                        this.scriptKind = scriptKind ? scriptKind : getScriptKindFromFileName(fileName);
                    }
                    /** @internal */
                    isDynamicOrHasMixedContent() {
                        return this.hasMixedContent || this.isDynamic;
                    }
                    isScriptOpen() {
                        return this.textStorage.isOpen;
                    }
                    open(newText) {
                        this.textStorage.isOpen = true;
                        if (newText !== void 0 && this.textStorage.reload(newText)) {
                            this.markContainingProjectsAsDirty();
                        }
                    }
                    close(fileExists = true) {
                        this.textStorage.isOpen = false;
                        if (fileExists && this.textStorage.scheduleReloadIfNeeded()) {
                            this.markContainingProjectsAsDirty();
                        }
                    }
                    getSnapshot() {
                        return this.textStorage.getSnapshot();
                    }
                    ensureRealPath() {
                        if (this.realpath === void 0) {
                            this.realpath = this.path;
                            if (this.host.realpath) {
                                Debug.assert(!!this.containingProjects.length);
                                const project = this.containingProjects[0];
                                const realpath = this.host.realpath(this.path);
                                if (realpath) {
                                    this.realpath = project.toPath(realpath);
                                    if (this.realpath !== this.path) {
                                        project.projectService.realpathToScriptInfos.add(this.realpath, this);
                                    }
                                }
                            }
                        }
                    }
                    /** @internal */
                    getRealpathIfDifferent() {
                        return this.realpath && this.realpath !== this.path ? this.realpath : void 0;
                    }
                    /**
                     * @internal
                     * Does not compute realpath; uses precomputed result. Use `ensureRealPath`
                     * first if a definite result is needed.
                     */
                    isSymlink() {
                        return this.realpath && this.realpath !== this.path;
                    }
                    getFormatCodeSettings() {
                        return this.formatSettings;
                    }
                    getPreferences() {
                        return this.preferences;
                    }
                    attachToProject(project) {
                        const isNew = !this.isAttached(project);
                        if (isNew) {
                            this.containingProjects.push(project);
                            if (!project.getCompilerOptions().preserveSymlinks) {
                                this.ensureRealPath();
                            }
                            project.onFileAddedOrRemoved(this.isSymlink());
                        }
                        return isNew;
                    }
                    isAttached(project) {
                        switch (this.containingProjects.length) {
                            case 0:
                                return false;
                            case 1:
                                return this.containingProjects[0] === project;
                            case 2:
                                return this.containingProjects[0] === project || this.containingProjects[1] === project;
                            default:
                                return contains(this.containingProjects, project);
                        }
                    }
                    detachFromProject(project) {
                        switch (this.containingProjects.length) {
                            case 0:
                                return;
                            case 1:
                                if (this.containingProjects[0] === project) {
                                    project.onFileAddedOrRemoved(this.isSymlink());
                                    this.containingProjects.pop();
                                }
                                break;
                            case 2:
                                if (this.containingProjects[0] === project) {
                                    project.onFileAddedOrRemoved(this.isSymlink());
                                    this.containingProjects[0] = this.containingProjects.pop();
                                }
                                else if (this.containingProjects[1] === project) {
                                    project.onFileAddedOrRemoved(this.isSymlink());
                                    this.containingProjects.pop();
                                }
                                break;
                            default:
                                if (orderedRemoveItem(this.containingProjects, project)) {
                                    project.onFileAddedOrRemoved(this.isSymlink());
                                }
                                break;
                        }
                    }
                    detachAllProjects() {
                        for (const p of this.containingProjects) {
                            if (isConfiguredProject(p)) {
                                p.getCachedDirectoryStructureHost().addOrDeleteFile(this.fileName, this.path, 2 /* Deleted */);
                            }
                            const existingRoot = p.getRootFilesMap().get(this.path);
                            p.removeFile(this, 
                            /*fileExists*/
                            false, 
                            /*detachFromProject*/
                            false);
                            p.onFileAddedOrRemoved(this.isSymlink());
                            if (existingRoot && !isInferredProject(p)) {
                                p.addMissingFileRoot(existingRoot.fileName);
                            }
                        }
                        clear(this.containingProjects);
                    }
                    getDefaultProject() {
                        switch (this.containingProjects.length) {
                            case 0:
                                return Errors.ThrowNoProject();
                            case 1:
                                return ensurePrimaryProjectKind(this.containingProjects[0]);
                            default:
                                let firstExternalProject;
                                let firstConfiguredProject;
                                let firstInferredProject;
                                let firstNonSourceOfProjectReferenceRedirect;
                                let defaultConfiguredProject;
                                for (let index = 0; index < this.containingProjects.length; index++) {
                                    const project = this.containingProjects[index];
                                    if (isConfiguredProject(project)) {
                                        if (!project.isSourceOfProjectReferenceRedirect(this.fileName)) {
                                            if (defaultConfiguredProject === void 0 && index !== this.containingProjects.length - 1) {
                                                defaultConfiguredProject = project.projectService.findDefaultConfiguredProject(this) || false;
                                            }
                                            if (defaultConfiguredProject === project)
                                                return project;
                                            if (!firstNonSourceOfProjectReferenceRedirect)
                                                firstNonSourceOfProjectReferenceRedirect = project;
                                        }
                                        if (!firstConfiguredProject)
                                            firstConfiguredProject = project;
                                    }
                                    else if (!firstExternalProject && isExternalProject(project)) {
                                        firstExternalProject = project;
                                    }
                                    else if (!firstInferredProject && isInferredProject(project)) {
                                        firstInferredProject = project;
                                    }
                                }
                                return ensurePrimaryProjectKind(defaultConfiguredProject || firstNonSourceOfProjectReferenceRedirect || firstConfiguredProject || firstExternalProject || firstInferredProject);
                        }
                    }
                    registerFileUpdate() {
                        for (const p of this.containingProjects) {
                            p.registerFileUpdate(this.path);
                        }
                    }
                    setOptions(formatSettings, preferences) {
                        if (formatSettings) {
                            if (!this.formatSettings) {
                                this.formatSettings = getDefaultFormatCodeSettings(this.host.newLine);
                                assign(this.formatSettings, formatSettings);
                            }
                            else {
                                this.formatSettings = { ...this.formatSettings, ...formatSettings };
                            }
                        }
                        if (preferences) {
                            if (!this.preferences) {
                                this.preferences = emptyOptions;
                            }
                            this.preferences = { ...this.preferences, ...preferences };
                        }
                    }
                    getLatestVersion() {
                        this.textStorage.getSnapshot();
                        return this.textStorage.getVersion();
                    }
                    saveTo(fileName) {
                        this.host.writeFile(fileName, getSnapshotText(this.textStorage.getSnapshot()));
                    }
                    /** @internal */
                    delayReloadNonMixedContentFile() {
                        Debug.assert(!this.isDynamicOrHasMixedContent());
                        this.textStorage.delayReloadFromFileIntoText();
                        this.markContainingProjectsAsDirty();
                    }
                    reloadFromFile(tempFileName) {
                        if (this.textStorage.reloadWithFileText(tempFileName)) {
                            this.markContainingProjectsAsDirty();
                            return true;
                        }
                        return false;
                    }
                    editContent(start, end, newText) {
                        this.textStorage.edit(start, end, newText);
                        this.markContainingProjectsAsDirty();
                    }
                    markContainingProjectsAsDirty() {
                        for (const p of this.containingProjects) {
                            p.markFileAsDirty(this.path);
                        }
                    }
                    isOrphan() {
                        return !forEach(this.containingProjects, (p) => !p.isOrphan());
                    }
                    /** @internal */
                    isContainedByBackgroundProject() {
                        return some(this.containingProjects, isBackgroundProject);
                    }
                    /**
                     *  @param line 1 based index
                     */
                    lineToTextSpan(line) {
                        return this.textStorage.lineToTextSpan(line);
                    }
                    // eslint-disable-line @typescript-eslint/unified-signatures
                    lineOffsetToPosition(line, offset, allowEdits) {
                        return this.textStorage.lineOffsetToPosition(line, offset, allowEdits);
                    }
                    positionToLineOffset(position) {
                        failIfInvalidPosition(position);
                        const location = this.textStorage.positionToLineOffset(position);
                        failIfInvalidLocation(location);
                        return location;
                    }
                    isJavaScript() {
                        return this.scriptKind === 1 /* JS */ || this.scriptKind === 2 /* JSX */;
                    }
                    /** @internal */
                    closeSourceMapFileWatcher() {
                        if (this.sourceMapFilePath && !isString(this.sourceMapFilePath)) {
                            closeFileWatcherOf(this.sourceMapFilePath);
                            this.sourceMapFilePath = void 0;
                        }
                    }
                };
            }
        });
        // src/server/typingsCache.ts
        function setIsEqualTo(arr1, arr2) {
            if (arr1 === arr2) {
                return true;
            }
            if ((arr1 || emptyArray2).length === 0 && (arr2 || emptyArray2).length === 0) {
                return true;
            }
            const set = /* @__PURE__ */ new Map();
            let unique = 0;
            for (const v of arr1) {
                if (set.get(v) !== true) {
                    set.set(v, true);
                    unique++;
                }
            }
            for (const v of arr2) {
                const isSet = set.get(v);
                if (isSet === void 0) {
                    return false;
                }
                if (isSet === true) {
                    set.set(v, false);
                    unique--;
                }
            }
            return unique === 0;
        }
        function typeAcquisitionChanged(opt1, opt2) {
            return opt1.enable !== opt2.enable || !setIsEqualTo(opt1.include, opt2.include) || !setIsEqualTo(opt1.exclude, opt2.exclude);
        }
        function compilerOptionsChanged(opt1, opt2) {
            return getAllowJSCompilerOption(opt1) !== getAllowJSCompilerOption(opt2);
        }
        function unresolvedImportsChanged(imports1, imports2) {
            if (imports1 === imports2) {
                return false;
            }
            return !arrayIsEqualTo(imports1, imports2);
        }
        var nullTypingsInstaller, TypingsCache;
        var init_typingsCache = __esm({
            "src/server/typingsCache.ts"() {
                "use strict";
                init_ts7();
                init_ts_server3();
                nullTypingsInstaller = {
                    isKnownTypesPackageName: returnFalse,
                    // Should never be called because we never provide a types registry.
                    installPackage: notImplemented,
                    enqueueInstallTypingsRequest: noop,
                    attach: noop,
                    onProjectClosed: noop,
                    globalTypingsCacheLocation: void 0
                    // TODO: GH#18217
                };
                TypingsCache = class {
                    constructor(installer) {
                        this.installer = installer;
                        this.perProjectCache = /* @__PURE__ */ new Map();
                    }
                    isKnownTypesPackageName(name) {
                        return this.installer.isKnownTypesPackageName(name);
                    }
                    installPackage(options) {
                        return this.installer.installPackage(options);
                    }
                    enqueueInstallTypingsForProject(project, unresolvedImports, forceRefresh) {
                        const typeAcquisition = project.getTypeAcquisition();
                        if (!typeAcquisition || !typeAcquisition.enable) {
                            return;
                        }
                        const entry = this.perProjectCache.get(project.getProjectName());
                        if (forceRefresh || !entry || typeAcquisitionChanged(typeAcquisition, entry.typeAcquisition) || compilerOptionsChanged(project.getCompilationSettings(), entry.compilerOptions) || unresolvedImportsChanged(unresolvedImports, entry.unresolvedImports)) {
                            this.perProjectCache.set(project.getProjectName(), {
                                compilerOptions: project.getCompilationSettings(),
                                typeAcquisition,
                                typings: entry ? entry.typings : emptyArray2,
                                unresolvedImports,
                                poisoned: true
                            });
                            this.installer.enqueueInstallTypingsRequest(project, typeAcquisition, unresolvedImports);
                        }
                    }
                    updateTypingsForProject(projectName, compilerOptions, typeAcquisition, unresolvedImports, newTypings) {
                        const typings = sort(newTypings);
                        this.perProjectCache.set(projectName, {
                            compilerOptions,
                            typeAcquisition,
                            typings,
                            unresolvedImports,
                            poisoned: false
                        });
                        return !typeAcquisition || !typeAcquisition.enable ? emptyArray2 : typings;
                    }
                    onProjectClosed(project) {
                        if (this.perProjectCache.delete(project.getProjectName())) {
                            this.installer.onProjectClosed(project);
                        }
                    }
                };
            }
        });
        // src/server/project.ts
        function countEachFileTypes(infos, includeSizes = false) {
            const result = {
                js: 0,
                jsSize: 0,
                jsx: 0,
                jsxSize: 0,
                ts: 0,
                tsSize: 0,
                tsx: 0,
                tsxSize: 0,
                dts: 0,
                dtsSize: 0,
                deferred: 0,
                deferredSize: 0
            };
            for (const info of infos) {
                const fileSize = includeSizes ? info.textStorage.getTelemetryFileSize() : 0;
                switch (info.scriptKind) {
                    case 1 /* JS */:
                        result.js += 1;
                        result.jsSize += fileSize;
                        break;
                    case 2 /* JSX */:
                        result.jsx += 1;
                        result.jsxSize += fileSize;
                        break;
                    case 3 /* TS */:
                        if (isDeclarationFileName(info.fileName)) {
                            result.dts += 1;
                            result.dtsSize += fileSize;
                        }
                        else {
                            result.ts += 1;
                            result.tsSize += fileSize;
                        }
                        break;
                    case 4 /* TSX */:
                        result.tsx += 1;
                        result.tsxSize += fileSize;
                        break;
                    case 7 /* Deferred */:
                        result.deferred += 1;
                        result.deferredSize += fileSize;
                        break;
                }
            }
            return result;
        }
        function hasOneOrMoreJsAndNoTsFiles(project) {
            const counts2 = countEachFileTypes(project.getScriptInfos());
            return counts2.js > 0 && counts2.ts === 0 && counts2.tsx === 0;
        }
        function allRootFilesAreJsOrDts(project) {
            const counts2 = countEachFileTypes(project.getRootScriptInfos());
            return counts2.ts === 0 && counts2.tsx === 0;
        }
        function allFilesAreJsOrDts(project) {
            const counts2 = countEachFileTypes(project.getScriptInfos());
            return counts2.ts === 0 && counts2.tsx === 0;
        }
        function hasNoTypeScriptSource(fileNames) {
            return !fileNames.some((fileName) => fileExtensionIs(fileName, ".ts" /* Ts */) && !isDeclarationFileName(fileName) || fileExtensionIs(fileName, ".tsx" /* Tsx */));
        }
        function isGeneratedFileWatcher(watch) {
            return watch.generatedFilePath !== void 0;
        }
        function getUnresolvedImports(program, cachedUnresolvedImportsPerFile) {
            var _a, _b;
            const sourceFiles = program.getSourceFiles();
            (_a = tracing) == null ? void 0 : _a.push(tracing.Phase.Session, "getUnresolvedImports", { count: sourceFiles.length });
            const ambientModules = program.getTypeChecker().getAmbientModules().map((mod) => stripQuotes(mod.getName()));
            const result = sortAndDeduplicate(flatMap(sourceFiles, (sourceFile) => extractUnresolvedImportsFromSourceFile(program, sourceFile, ambientModules, cachedUnresolvedImportsPerFile)));
            (_b = tracing) == null ? void 0 : _b.pop();
            return result;
        }
        function extractUnresolvedImportsFromSourceFile(program, file, ambientModules, cachedUnresolvedImportsPerFile) {
            return getOrUpdate(cachedUnresolvedImportsPerFile, file.path, () => {
                let unresolvedImports;
                program.forEachResolvedModule(({ resolvedModule }, name) => {
                    if ((!resolvedModule || !resolutionExtensionIsTSOrJson(resolvedModule.extension)) && !isExternalModuleNameRelative(name) && !ambientModules.some((m) => m === name)) {
                        unresolvedImports = append(unresolvedImports, parsePackageName(name).packageName);
                    }
                }, file);
                return unresolvedImports || emptyArray2;
            });
        }
        function isInferredProject(project) {
            return project.projectKind === 0 /* Inferred */;
        }
        function isConfiguredProject(project) {
            return project.projectKind === 1 /* Configured */;
        }
        function isExternalProject(project) {
            return project.projectKind === 2 /* External */;
        }
        function isBackgroundProject(project) {
            return project.projectKind === 3 /* AutoImportProvider */ || project.projectKind === 4 /* Auxiliary */;
        }
        var ProjectKind, Project3, InferredProject2, AuxiliaryProject, _AutoImportProviderProject, AutoImportProviderProject, ConfiguredProject2, ExternalProject2;
        var init_project = __esm({
            "src/server/project.ts"() {
                "use strict";
                init_ts7();
                init_ts7();
                init_ts_server3();
                ProjectKind = /* @__PURE__ */ ((ProjectKind2) => {
                    ProjectKind2[ProjectKind2["Inferred"] = 0] = "Inferred";
                    ProjectKind2[ProjectKind2["Configured"] = 1] = "Configured";
                    ProjectKind2[ProjectKind2["External"] = 2] = "External";
                    ProjectKind2[ProjectKind2["AutoImportProvider"] = 3] = "AutoImportProvider";
                    ProjectKind2[ProjectKind2["Auxiliary"] = 4] = "Auxiliary";
                    return ProjectKind2;
                })(ProjectKind || {});
                Project3 = class _Project {
                    /** @internal */
                    constructor(projectName, projectKind, projectService, documentRegistry, hasExplicitListOfFiles, lastFileExceededProgramSize, compilerOptions, compileOnSaveEnabled, watchOptions, directoryStructureHost, currentDirectory) {
                        this.projectKind = projectKind;
                        this.projectService = projectService;
                        this.documentRegistry = documentRegistry;
                        this.compilerOptions = compilerOptions;
                        this.compileOnSaveEnabled = compileOnSaveEnabled;
                        this.watchOptions = watchOptions;
                        this.rootFiles = [];
                        this.rootFilesMap = /* @__PURE__ */ new Map();
                        /** @internal */
                        this.plugins = [];
                        /**
                         * This is map from files to unresolved imports in it
                         * Maop does not contain entries for files that do not have unresolved imports
                         * This helps in containing the set of files to invalidate
                         *
                         * @internal
                         */
                        this.cachedUnresolvedImportsPerFile = /* @__PURE__ */ new Map();
                        /** @internal */
                        this.hasAddedorRemovedFiles = false;
                        /** @internal */
                        this.hasAddedOrRemovedSymlinks = false;
                        /**
                         * Last version that was reported.
                         */
                        this.lastReportedVersion = 0;
                        /**
                         * Current project's program version. (incremented everytime new program is created that is not complete reuse from the old one)
                         * This property is changed in 'updateGraph' based on the set of files in program
                         * @internal
                         */
                        this.projectProgramVersion = 0;
                        /**
                         * Current version of the project state. It is changed when:
                         * - new root file was added/removed
                         * - edit happen in some file that is currently included in the project.
                         * This property is different from projectStructureVersion since in most cases edits don't affect set of files in the project
                         * @internal
                         */
                        this.projectStateVersion = 0;
                        this.isInitialLoadPending = returnFalse;
                        /** @internal */
                        this.dirty = false;
                        /** @internal */
                        this.typingFiles = emptyArray2;
                        /** @internal */
                        this.moduleSpecifierCache = createModuleSpecifierCache(this);
                        /** @internal */
                        this.createHash = maybeBind(this.projectService.host, this.projectService.host.createHash);
                        /** @internal */
                        this.globalCacheResolutionModuleName = ts_JsTyping_exports.nonRelativeModuleNameForTypingCache;
                        /** @internal */
                        this.updateFromProjectInProgress = false;
                        this.projectName = projectName;
                        this.directoryStructureHost = directoryStructureHost;
                        this.currentDirectory = this.projectService.getNormalizedAbsolutePath(currentDirectory);
                        this.getCanonicalFileName = this.projectService.toCanonicalFileName;
                        this.jsDocParsingMode = this.projectService.jsDocParsingMode;
                        this.cancellationToken = new ThrottledCancellationToken(this.projectService.cancellationToken, this.projectService.throttleWaitMilliseconds);
                        if (!this.compilerOptions) {
                            this.compilerOptions = getDefaultCompilerOptions2();
                            this.compilerOptions.allowNonTsExtensions = true;
                            this.compilerOptions.allowJs = true;
                        }
                        else if (hasExplicitListOfFiles || getAllowJSCompilerOption(this.compilerOptions) || this.projectService.hasDeferredExtension()) {
                            this.compilerOptions.allowNonTsExtensions = true;
                        }
                        switch (projectService.serverMode) {
                            case 0 /* Semantic */:
                                this.languageServiceEnabled = true;
                                break;
                            case 1 /* PartialSemantic */:
                                this.languageServiceEnabled = true;
                                this.compilerOptions.noResolve = true;
                                this.compilerOptions.types = [];
                                break;
                            case 2 /* Syntactic */:
                                this.languageServiceEnabled = false;
                                this.compilerOptions.noResolve = true;
                                this.compilerOptions.types = [];
                                break;
                            default:
                                Debug.assertNever(projectService.serverMode);
                        }
                        this.setInternalCompilerOptionsForEmittingJsFiles();
                        const host = this.projectService.host;
                        if (this.projectService.logger.loggingEnabled()) {
                            this.trace = (s) => this.writeLog(s);
                        }
                        else if (host.trace) {
                            this.trace = (s) => host.trace(s);
                        }
                        this.realpath = maybeBind(host, host.realpath);
                        this.resolutionCache = createResolutionCache(this, this.currentDirectory, 
                        /*logChangesWhenResolvingModule*/
                        true);
                        this.languageService = createLanguageService(this, this.documentRegistry, this.projectService.serverMode);
                        if (lastFileExceededProgramSize) {
                            this.disableLanguageService(lastFileExceededProgramSize);
                        }
                        this.markAsDirty();
                        if (!isBackgroundProject(this)) {
                            this.projectService.pendingEnsureProjectForOpenFiles = true;
                        }
                        this.projectService.onProjectCreation(this);
                    }
                    /** @internal */
                    getResolvedProjectReferenceToRedirect(_fileName) {
                        return void 0;
                    }
                    isNonTsProject() {
                        updateProjectIfDirty(this);
                        return allFilesAreJsOrDts(this);
                    }
                    isJsOnlyProject() {
                        updateProjectIfDirty(this);
                        return hasOneOrMoreJsAndNoTsFiles(this);
                    }
                    static resolveModule(moduleName, initialDir, host, log) {
                        return _Project.importServicePluginSync({ name: moduleName }, [initialDir], host, log).resolvedModule;
                    }
                    /** @internal */
                    static importServicePluginSync(pluginConfigEntry, searchPaths, host, log) {
                        Debug.assertIsDefined(host.require);
                        let errorLogs;
                        let resolvedModule;
                        for (const initialDir of searchPaths) {
                            const resolvedPath = normalizeSlashes(host.resolvePath(combinePaths(initialDir, "node_modules")));
                            log(`Loading ${pluginConfigEntry.name} from ${initialDir} (resolved to ${resolvedPath})`);
                            const result = host.require(resolvedPath, pluginConfigEntry.name);
                            if (!result.error) {
                                resolvedModule = result.module;
                                break;
                            }
                            const err = result.error.stack || result.error.message || JSON.stringify(result.error);
                            (errorLogs ?? (errorLogs = [])).push(`Failed to load module '${pluginConfigEntry.name}' from ${resolvedPath}: ${err}`);
                        }
                        return { pluginConfigEntry, resolvedModule, errorLogs };
                    }
                    /** @internal */
                    static async importServicePluginAsync(pluginConfigEntry, searchPaths, host, log) {
                        Debug.assertIsDefined(host.importPlugin);
                        let errorLogs;
                        let resolvedModule;
                        for (const initialDir of searchPaths) {
                            const resolvedPath = combinePaths(initialDir, "node_modules");
                            log(`Dynamically importing ${pluginConfigEntry.name} from ${initialDir} (resolved to ${resolvedPath})`);
                            let result;
                            try {
                                result = await host.importPlugin(resolvedPath, pluginConfigEntry.name);
                            }
                            catch (e) {
                                result = { module: void 0, error: e };
                            }
                            if (!result.error) {
                                resolvedModule = result.module;
                                break;
                            }
                            const err = result.error.stack || result.error.message || JSON.stringify(result.error);
                            (errorLogs ?? (errorLogs = [])).push(`Failed to dynamically import module '${pluginConfigEntry.name}' from ${resolvedPath}: ${err}`);
                        }
                        return { pluginConfigEntry, resolvedModule, errorLogs };
                    }
                    isKnownTypesPackageName(name) {
                        return this.typingsCache.isKnownTypesPackageName(name);
                    }
                    installPackage(options) {
                        return this.typingsCache.installPackage({ ...options, projectName: this.projectName, projectRootPath: this.toPath(this.currentDirectory) });
                    }
                    /** @internal */
                    getGlobalTypingsCacheLocation() {
                        return this.getGlobalCache();
                    }
                    get typingsCache() {
                        return this.projectService.typingsCache;
                    }
                    /** @internal */
                    getSymlinkCache() {
                        if (!this.symlinks) {
                            this.symlinks = createSymlinkCache(this.getCurrentDirectory(), this.getCanonicalFileName);
                        }
                        if (this.program && !this.symlinks.hasProcessedResolutions()) {
                            this.symlinks.setSymlinksFromResolutions(this.program.forEachResolvedModule, this.program.forEachResolvedTypeReferenceDirective, this.program.getAutomaticTypeDirectiveResolutions());
                        }
                        return this.symlinks;
                    }
                    // Method of LanguageServiceHost
                    getCompilationSettings() {
                        return this.compilerOptions;
                    }
                    // Method to support public API
                    getCompilerOptions() {
                        return this.getCompilationSettings();
                    }
                    getNewLine() {
                        return this.projectService.host.newLine;
                    }
                    getProjectVersion() {
                        return this.projectStateVersion.toString();
                    }
                    getProjectReferences() {
                        return void 0;
                    }
                    getScriptFileNames() {
                        if (!this.rootFiles) {
                            return emptyArray;
                        }
                        let result;
                        this.rootFilesMap.forEach((value) => {
                            if (this.languageServiceEnabled || value.info && value.info.isScriptOpen()) {
                                (result || (result = [])).push(value.fileName);
                            }
                        });
                        return addRange(result, this.typingFiles) || emptyArray;
                    }
                    getOrCreateScriptInfoAndAttachToProject(fileName) {
                        const scriptInfo = this.projectService.getOrCreateScriptInfoNotOpenedByClient(fileName, this.currentDirectory, this.directoryStructureHost);
                        if (scriptInfo) {
                            const existingValue = this.rootFilesMap.get(scriptInfo.path);
                            if (existingValue && existingValue.info !== scriptInfo) {
                                this.rootFiles.push(scriptInfo);
                                existingValue.info = scriptInfo;
                            }
                            scriptInfo.attachToProject(this);
                        }
                        return scriptInfo;
                    }
                    getScriptKind(fileName) {
                        const info = this.projectService.getScriptInfoForPath(this.toPath(fileName));
                        return info && info.scriptKind;
                    }
                    getScriptVersion(filename) {
                        const info = this.projectService.getOrCreateScriptInfoNotOpenedByClient(filename, this.currentDirectory, this.directoryStructureHost);
                        return info && info.getLatestVersion();
                    }
                    getScriptSnapshot(filename) {
                        const scriptInfo = this.getOrCreateScriptInfoAndAttachToProject(filename);
                        if (scriptInfo) {
                            return scriptInfo.getSnapshot();
                        }
                    }
                    getCancellationToken() {
                        return this.cancellationToken;
                    }
                    getCurrentDirectory() {
                        return this.currentDirectory;
                    }
                    getDefaultLibFileName() {
                        const nodeModuleBinDir = getDirectoryPath(normalizePath(this.projectService.getExecutingFilePath()));
                        return combinePaths(nodeModuleBinDir, getDefaultLibFileName(this.compilerOptions));
                    }
                    useCaseSensitiveFileNames() {
                        return this.projectService.host.useCaseSensitiveFileNames;
                    }
                    readDirectory(path, extensions, exclude, include, depth) {
                        return this.directoryStructureHost.readDirectory(path, extensions, exclude, include, depth);
                    }
                    readFile(fileName) {
                        return this.projectService.host.readFile(fileName);
                    }
                    writeFile(fileName, content) {
                        return this.projectService.host.writeFile(fileName, content);
                    }
                    fileExists(file) {
                        const path = this.toPath(file);
                        return !this.isWatchedMissingFile(path) && this.directoryStructureHost.fileExists(file);
                    }
                    /** @internal */
                    resolveModuleNameLiterals(moduleLiterals, containingFile, redirectedReference, options, containingSourceFile, reusedNames) {
                        return this.resolutionCache.resolveModuleNameLiterals(moduleLiterals, containingFile, redirectedReference, options, containingSourceFile, reusedNames);
                    }
                    /** @internal */
                    getModuleResolutionCache() {
                        return this.resolutionCache.getModuleResolutionCache();
                    }
                    /** @internal */
                    resolveTypeReferenceDirectiveReferences(typeDirectiveReferences, containingFile, redirectedReference, options, containingSourceFile, reusedNames) {
                        return this.resolutionCache.resolveTypeReferenceDirectiveReferences(typeDirectiveReferences, containingFile, redirectedReference, options, containingSourceFile, reusedNames);
                    }
                    /** @internal */
                    resolveLibrary(libraryName, resolveFrom, options, libFileName) {
                        return this.resolutionCache.resolveLibrary(libraryName, resolveFrom, options, libFileName);
                    }
                    directoryExists(path) {
                        return this.directoryStructureHost.directoryExists(path);
                    }
                    getDirectories(path) {
                        return this.directoryStructureHost.getDirectories(path);
                    }
                    /** @internal */
                    getCachedDirectoryStructureHost() {
                        return void 0;
                    }
                    /** @internal */
                    toPath(fileName) {
                        return toPath(fileName, this.currentDirectory, this.projectService.toCanonicalFileName);
                    }
                    /** @internal */
                    watchDirectoryOfFailedLookupLocation(directory, cb, flags) {
                        return this.projectService.watchFactory.watchDirectory(directory, cb, flags, this.projectService.getWatchOptions(this), WatchType.FailedLookupLocations, this);
                    }
                    /** @internal */
                    watchAffectingFileLocation(file, cb) {
                        return this.projectService.watchFactory.watchFile(file, cb, 2e3 /* High */, this.projectService.getWatchOptions(this), WatchType.AffectingFileLocation, this);
                    }
                    /** @internal */
                    clearInvalidateResolutionOfFailedLookupTimer() {
                        return this.projectService.throttledOperations.cancel(`${this.getProjectName()}FailedLookupInvalidation`);
                    }
                    /** @internal */
                    scheduleInvalidateResolutionsOfFailedLookupLocations() {
                        this.projectService.throttledOperations.schedule(`${this.getProjectName()}FailedLookupInvalidation`, 
                        /*delay*/
                        1e3, () => {
                            if (this.resolutionCache.invalidateResolutionsOfFailedLookupLocations()) {
                                this.projectService.delayUpdateProjectGraphAndEnsureProjectStructureForOpenFiles(this);
                            }
                        });
                    }
                    /** @internal */
                    invalidateResolutionsOfFailedLookupLocations() {
                        if (this.clearInvalidateResolutionOfFailedLookupTimer() && this.resolutionCache.invalidateResolutionsOfFailedLookupLocations()) {
                            this.markAsDirty();
                            this.projectService.delayEnsureProjectForOpenFiles();
                        }
                    }
                    /** @internal */
                    onInvalidatedResolution() {
                        this.projectService.delayUpdateProjectGraphAndEnsureProjectStructureForOpenFiles(this);
                    }
                    /** @internal */
                    watchTypeRootsDirectory(directory, cb, flags) {
                        return this.projectService.watchFactory.watchDirectory(directory, cb, flags, this.projectService.getWatchOptions(this), WatchType.TypeRoots, this);
                    }
                    /** @internal */
                    hasChangedAutomaticTypeDirectiveNames() {
                        return this.resolutionCache.hasChangedAutomaticTypeDirectiveNames();
                    }
                    /** @internal */
                    onChangedAutomaticTypeDirectiveNames() {
                        this.projectService.delayUpdateProjectGraphAndEnsureProjectStructureForOpenFiles(this);
                    }
                    /** @internal */
                    getGlobalCache() {
                        return this.getTypeAcquisition().enable ? this.projectService.typingsInstaller.globalTypingsCacheLocation : void 0;
                    }
                    /** @internal */
                    fileIsOpen(filePath) {
                        return this.projectService.openFiles.has(filePath);
                    }
                    /** @internal */
                    writeLog(s) {
                        this.projectService.logger.info(s);
                    }
                    log(s) {
                        this.writeLog(s);
                    }
                    error(s) {
                        this.projectService.logger.msg(s, "Err" /* Err */);
                    }
                    setInternalCompilerOptionsForEmittingJsFiles() {
                        if (this.projectKind === 0 /* Inferred */ || this.projectKind === 2 /* External */) {
                            this.compilerOptions.noEmitForJsFiles = true;
                        }
                    }
                    /**
                     * Get the errors that dont have any file name associated
                     */
                    getGlobalProjectErrors() {
                        return filter(this.projectErrors, (diagnostic) => !diagnostic.file) || emptyArray2;
                    }
                    /**
                     * Get all the project errors
                     */
                    getAllProjectErrors() {
                        return this.projectErrors || emptyArray2;
                    }
                    setProjectErrors(projectErrors) {
                        this.projectErrors = projectErrors;
                    }
                    getLanguageService(ensureSynchronized = true) {
                        if (ensureSynchronized) {
                            updateProjectIfDirty(this);
                        }
                        return this.languageService;
                    }
                    /** @internal */
                    getSourceMapper() {
                        return this.getLanguageService().getSourceMapper();
                    }
                    /** @internal */
                    clearSourceMapperCache() {
                        this.languageService.clearSourceMapperCache();
                    }
                    /** @internal */
                    getDocumentPositionMapper(generatedFileName, sourceFileName) {
                        return this.projectService.getDocumentPositionMapper(this, generatedFileName, sourceFileName);
                    }
                    /** @internal */
                    getSourceFileLike(fileName) {
                        return this.projectService.getSourceFileLike(fileName, this);
                    }
                    /** @internal */
                    shouldEmitFile(scriptInfo) {
                        return scriptInfo && !scriptInfo.isDynamicOrHasMixedContent() && !this.program.isSourceOfProjectReferenceRedirect(scriptInfo.path);
                    }
                    getCompileOnSaveAffectedFileList(scriptInfo) {
                        if (!this.languageServiceEnabled) {
                            return [];
                        }
                        updateProjectIfDirty(this);
                        this.builderState = BuilderState.create(this.program, this.builderState, 
                        /*disableUseFileVersionAsSignature*/
                        true);
                        return mapDefined(BuilderState.getFilesAffectedBy(this.builderState, this.program, scriptInfo.path, this.cancellationToken, this.projectService.host), (sourceFile) => this.shouldEmitFile(this.projectService.getScriptInfoForPath(sourceFile.path)) ? sourceFile.fileName : void 0);
                    }
                    /**
                     * Returns true if emit was conducted
                     */
                    emitFile(scriptInfo, writeFile2) {
                        if (!this.languageServiceEnabled || !this.shouldEmitFile(scriptInfo)) {
                            return { emitSkipped: true, diagnostics: emptyArray2 };
                        }
                        const { emitSkipped, diagnostics, outputFiles } = this.getLanguageService().getEmitOutput(scriptInfo.fileName);
                        if (!emitSkipped) {
                            for (const outputFile of outputFiles) {
                                const outputFileAbsoluteFileName = getNormalizedAbsolutePath(outputFile.name, this.currentDirectory);
                                writeFile2(outputFileAbsoluteFileName, outputFile.text, outputFile.writeByteOrderMark);
                            }
                            if (this.builderState && getEmitDeclarations(this.compilerOptions)) {
                                const dtsFiles = outputFiles.filter((f) => isDeclarationFileName(f.name));
                                if (dtsFiles.length === 1) {
                                    const sourceFile = this.program.getSourceFile(scriptInfo.fileName);
                                    const signature = this.projectService.host.createHash ? this.projectService.host.createHash(dtsFiles[0].text) : generateDjb2Hash(dtsFiles[0].text);
                                    BuilderState.updateSignatureOfFile(this.builderState, signature, sourceFile.resolvedPath);
                                }
                            }
                        }
                        return { emitSkipped, diagnostics };
                    }
                    enableLanguageService() {
                        if (this.languageServiceEnabled || this.projectService.serverMode === 2 /* Syntactic */) {
                            return;
                        }
                        this.languageServiceEnabled = true;
                        this.lastFileExceededProgramSize = void 0;
                        this.projectService.onUpdateLanguageServiceStateForProject(this, 
                        /*languageServiceEnabled*/
                        true);
                    }
                    /** @internal */
                    cleanupProgram() {
                        if (this.program) {
                            for (const f of this.program.getSourceFiles()) {
                                this.detachScriptInfoIfNotRoot(f.fileName);
                            }
                            this.program.forEachResolvedProjectReference((ref) => this.detachScriptInfoFromProject(ref.sourceFile.fileName));
                            this.program = void 0;
                        }
                    }
                    disableLanguageService(lastFileExceededProgramSize) {
                        if (!this.languageServiceEnabled) {
                            return;
                        }
                        Debug.assert(this.projectService.serverMode !== 2 /* Syntactic */);
                        this.languageService.cleanupSemanticCache();
                        this.languageServiceEnabled = false;
                        this.cleanupProgram();
                        this.lastFileExceededProgramSize = lastFileExceededProgramSize;
                        this.builderState = void 0;
                        if (this.autoImportProviderHost) {
                            this.autoImportProviderHost.close();
                        }
                        this.autoImportProviderHost = void 0;
                        this.resolutionCache.closeTypeRootsWatch();
                        this.clearGeneratedFileWatch();
                        this.projectService.verifyDocumentRegistry();
                        this.projectService.onUpdateLanguageServiceStateForProject(this, 
                        /*languageServiceEnabled*/
                        false);
                    }
                    getProjectName() {
                        return this.projectName;
                    }
                    removeLocalTypingsFromTypeAcquisition(newTypeAcquisition) {
                        if (!newTypeAcquisition || !newTypeAcquisition.include) {
                            return newTypeAcquisition;
                        }
                        return { ...newTypeAcquisition, include: this.removeExistingTypings(newTypeAcquisition.include) };
                    }
                    getExternalFiles(updateLevel) {
                        return sort(flatMap(this.plugins, (plugin) => {
                            if (typeof plugin.module.getExternalFiles !== "function")
                                return;
                            try {
                                return plugin.module.getExternalFiles(this, updateLevel || 0 /* Update */);
                            }
                            catch (e) {
                                this.projectService.logger.info(`A plugin threw an exception in getExternalFiles: ${e}`);
                                if (e.stack) {
                                    this.projectService.logger.info(e.stack);
                                }
                            }
                        }));
                    }
                    getSourceFile(path) {
                        if (!this.program) {
                            return void 0;
                        }
                        return this.program.getSourceFileByPath(path);
                    }
                    /** @internal */
                    getSourceFileOrConfigFile(path) {
                        const options = this.program.getCompilerOptions();
                        return path === options.configFilePath ? options.configFile : this.getSourceFile(path);
                    }
                    close() {
                        var _a;
                        this.projectService.typingsCache.onProjectClosed(this);
                        this.closeWatchingTypingLocations();
                        this.cleanupProgram();
                        forEach(this.externalFiles, (externalFile) => this.detachScriptInfoIfNotRoot(externalFile));
                        for (const root of this.rootFiles) {
                            root.detachFromProject(this);
                        }
                        this.projectService.pendingEnsureProjectForOpenFiles = true;
                        this.rootFiles = void 0;
                        this.rootFilesMap = void 0;
                        this.externalFiles = void 0;
                        this.program = void 0;
                        this.builderState = void 0;
                        this.resolutionCache.clear();
                        this.resolutionCache = void 0;
                        this.cachedUnresolvedImportsPerFile = void 0;
                        (_a = this.packageJsonWatches) == null ? void 0 : _a.forEach((watcher) => {
                            watcher.projects.delete(this);
                            watcher.close();
                        });
                        this.packageJsonWatches = void 0;
                        this.moduleSpecifierCache.clear();
                        this.moduleSpecifierCache = void 0;
                        this.directoryStructureHost = void 0;
                        this.exportMapCache = void 0;
                        this.projectErrors = void 0;
                        this.plugins.length = 0;
                        if (this.missingFilesMap) {
                            clearMap(this.missingFilesMap, closeFileWatcher);
                            this.missingFilesMap = void 0;
                        }
                        this.clearGeneratedFileWatch();
                        this.clearInvalidateResolutionOfFailedLookupTimer();
                        if (this.autoImportProviderHost) {
                            this.autoImportProviderHost.close();
                        }
                        this.autoImportProviderHost = void 0;
                        if (this.noDtsResolutionProject) {
                            this.noDtsResolutionProject.close();
                        }
                        this.noDtsResolutionProject = void 0;
                        this.languageService.dispose();
                        this.languageService = void 0;
                    }
                    detachScriptInfoIfNotRoot(uncheckedFilename) {
                        const info = this.projectService.getScriptInfo(uncheckedFilename);
                        if (info && !this.isRoot(info)) {
                            info.detachFromProject(this);
                        }
                    }
                    isClosed() {
                        return this.rootFiles === void 0;
                    }
                    hasRoots() {
                        return this.rootFiles && this.rootFiles.length > 0;
                    }
                    /** @internal */
                    isOrphan() {
                        return false;
                    }
                    getRootFiles() {
                        return this.rootFiles && this.rootFiles.map((info) => info.fileName);
                    }
                    /** @internal */
                    getRootFilesMap() {
                        return this.rootFilesMap;
                    }
                    getRootScriptInfos() {
                        return this.rootFiles;
                    }
                    getScriptInfos() {
                        if (!this.languageServiceEnabled) {
                            return this.rootFiles;
                        }
                        return map(this.program.getSourceFiles(), (sourceFile) => {
                            const scriptInfo = this.projectService.getScriptInfoForPath(sourceFile.resolvedPath);
                            Debug.assert(!!scriptInfo, "getScriptInfo", () => `scriptInfo for a file '${sourceFile.fileName}' Path: '${sourceFile.path}' / '${sourceFile.resolvedPath}' is missing.`);
                            return scriptInfo;
                        });
                    }
                    getExcludedFiles() {
                        return emptyArray2;
                    }
                    getFileNames(excludeFilesFromExternalLibraries, excludeConfigFiles) {
                        if (!this.program) {
                            return [];
                        }
                        if (!this.languageServiceEnabled) {
                            let rootFiles = this.getRootFiles();
                            if (this.compilerOptions) {
                                const defaultLibrary = getDefaultLibFilePath(this.compilerOptions);
                                if (defaultLibrary) {
                                    (rootFiles || (rootFiles = [])).push(asNormalizedPath(defaultLibrary));
                                }
                            }
                            return rootFiles;
                        }
                        const result = [];
                        for (const f of this.program.getSourceFiles()) {
                            if (excludeFilesFromExternalLibraries && this.program.isSourceFileFromExternalLibrary(f)) {
                                continue;
                            }
                            result.push(asNormalizedPath(f.fileName));
                        }
                        if (!excludeConfigFiles) {
                            const configFile = this.program.getCompilerOptions().configFile;
                            if (configFile) {
                                result.push(asNormalizedPath(configFile.fileName));
                                if (configFile.extendedSourceFiles) {
                                    for (const f of configFile.extendedSourceFiles) {
                                        result.push(asNormalizedPath(f));
                                    }
                                }
                            }
                        }
                        return result;
                    }
                    /** @internal */
                    getFileNamesWithRedirectInfo(includeProjectReferenceRedirectInfo) {
                        return this.getFileNames().map((fileName) => ({
                            fileName,
                            isSourceOfProjectReferenceRedirect: includeProjectReferenceRedirectInfo && this.isSourceOfProjectReferenceRedirect(fileName)
                        }));
                    }
                    hasConfigFile(configFilePath) {
                        if (this.program && this.languageServiceEnabled) {
                            const configFile = this.program.getCompilerOptions().configFile;
                            if (configFile) {
                                if (configFilePath === asNormalizedPath(configFile.fileName)) {
                                    return true;
                                }
                                if (configFile.extendedSourceFiles) {
                                    for (const f of configFile.extendedSourceFiles) {
                                        if (configFilePath === asNormalizedPath(f)) {
                                            return true;
                                        }
                                    }
                                }
                            }
                        }
                        return false;
                    }
                    containsScriptInfo(info) {
                        if (this.isRoot(info))
                            return true;
                        if (!this.program)
                            return false;
                        const file = this.program.getSourceFileByPath(info.path);
                        return !!file && file.resolvedPath === info.path;
                    }
                    containsFile(filename, requireOpen) {
                        const info = this.projectService.getScriptInfoForNormalizedPath(filename);
                        if (info && (info.isScriptOpen() || !requireOpen)) {
                            return this.containsScriptInfo(info);
                        }
                        return false;
                    }
                    isRoot(info) {
                        var _a;
                        return this.rootFilesMap && ((_a = this.rootFilesMap.get(info.path)) == null ? void 0 : _a.info) === info;
                    }
                    // add a root file to project
                    addRoot(info, fileName) {
                        Debug.assert(!this.isRoot(info));
                        this.rootFiles.push(info);
                        this.rootFilesMap.set(info.path, { fileName: fileName || info.fileName, info });
                        info.attachToProject(this);
                        this.markAsDirty();
                    }
                    // add a root file that doesnt exist on host
                    addMissingFileRoot(fileName) {
                        const path = this.projectService.toPath(fileName);
                        this.rootFilesMap.set(path, { fileName });
                        this.markAsDirty();
                    }
                    removeFile(info, fileExists, detachFromProject) {
                        if (this.isRoot(info)) {
                            this.removeRoot(info);
                        }
                        if (fileExists) {
                            this.resolutionCache.removeResolutionsOfFile(info.path);
                        }
                        else {
                            this.resolutionCache.invalidateResolutionOfFile(info.path);
                        }
                        this.cachedUnresolvedImportsPerFile.delete(info.path);
                        if (detachFromProject) {
                            info.detachFromProject(this);
                        }
                        this.markAsDirty();
                    }
                    registerFileUpdate(fileName) {
                        (this.updatedFileNames || (this.updatedFileNames = /* @__PURE__ */ new Set())).add(fileName);
                    }
                    /** @internal */
                    markFileAsDirty(changedFile) {
                        this.markAsDirty();
                        if (this.exportMapCache && !this.exportMapCache.isEmpty()) {
                            (this.changedFilesForExportMapCache || (this.changedFilesForExportMapCache = /* @__PURE__ */ new Set())).add(changedFile);
                        }
                    }
                    markAsDirty() {
                        if (!this.dirty) {
                            this.projectStateVersion++;
                            this.dirty = true;
                        }
                    }
                    /** @internal */
                    onAutoImportProviderSettingsChanged() {
                        var _a;
                        if (this.autoImportProviderHost === false) {
                            this.autoImportProviderHost = void 0;
                        }
                        else {
                            (_a = this.autoImportProviderHost) == null ? void 0 : _a.markAsDirty();
                        }
                    }
                    /** @internal */
                    onPackageJsonChange() {
                        this.moduleSpecifierCache.clear();
                        if (this.autoImportProviderHost) {
                            this.autoImportProviderHost.markAsDirty();
                        }
                    }
                    /** @internal */
                    onFileAddedOrRemoved(isSymlink) {
                        this.hasAddedorRemovedFiles = true;
                        if (isSymlink) {
                            this.hasAddedOrRemovedSymlinks = true;
                        }
                    }
                    /** @internal */
                    onDiscoveredSymlink() {
                        this.hasAddedOrRemovedSymlinks = true;
                    }
                    /** @internal */
                    updateFromProject() {
                        updateProjectIfDirty(this);
                    }
                    /**
                     * Updates set of files that contribute to this project
                     * @returns: true if set of files in the project stays the same and false - otherwise.
                     */
                    updateGraph() {
                        var _a, _b, _c, _d, _e;
                        (_a = tracing) == null ? void 0 : _a.push(tracing.Phase.Session, "updateGraph", { name: this.projectName, kind: ProjectKind[this.projectKind] });
                        (_b = perfLogger) == null ? void 0 : _b.logStartUpdateGraph();
                        this.resolutionCache.startRecordingFilesWithChangedResolutions();
                        const hasNewProgram = this.updateGraphWorker();
                        const hasAddedorRemovedFiles = this.hasAddedorRemovedFiles;
                        this.hasAddedorRemovedFiles = false;
                        this.hasAddedOrRemovedSymlinks = false;
                        const changedFiles = this.resolutionCache.finishRecordingFilesWithChangedResolutions() || emptyArray2;
                        for (const file of changedFiles) {
                            this.cachedUnresolvedImportsPerFile.delete(file);
                        }
                        if (this.languageServiceEnabled && this.projectService.serverMode === 0 /* Semantic */ && !this.isOrphan()) {
                            if (hasNewProgram || changedFiles.length) {
                                this.lastCachedUnresolvedImportsList = getUnresolvedImports(this.program, this.cachedUnresolvedImportsPerFile);
                            }
                            this.projectService.typingsCache.enqueueInstallTypingsForProject(this, this.lastCachedUnresolvedImportsList, hasAddedorRemovedFiles);
                        }
                        else {
                            this.lastCachedUnresolvedImportsList = void 0;
                        }
                        const isFirstProgramLoad = this.projectProgramVersion === 0 && hasNewProgram;
                        if (hasNewProgram) {
                            this.projectProgramVersion++;
                        }
                        if (hasAddedorRemovedFiles) {
                            if (!this.autoImportProviderHost)
                                this.autoImportProviderHost = void 0;
                            (_c = this.autoImportProviderHost) == null ? void 0 : _c.markAsDirty();
                        }
                        if (isFirstProgramLoad) {
                            this.getPackageJsonAutoImportProvider();
                        }
                        (_d = perfLogger) == null ? void 0 : _d.logStopUpdateGraph();
                        (_e = tracing) == null ? void 0 : _e.pop();
                        return !hasNewProgram;
                    }
                    /** @internal */
                    updateTypingFiles(typingFiles) {
                        if (enumerateInsertsAndDeletes(typingFiles, this.typingFiles, getStringComparer(!this.useCaseSensitiveFileNames()), 
                        /*inserted*/
                        noop, (removed) => this.detachScriptInfoFromProject(removed))) {
                            this.typingFiles = typingFiles;
                            this.resolutionCache.setFilesWithInvalidatedNonRelativeUnresolvedImports(this.cachedUnresolvedImportsPerFile);
                            this.projectService.delayUpdateProjectGraphAndEnsureProjectStructureForOpenFiles(this);
                        }
                    }
                    /** @internal */
                    closeWatchingTypingLocations() {
                        if (this.typingWatchers)
                            clearMap(this.typingWatchers, closeFileWatcher);
                        this.typingWatchers = void 0;
                    }
                    /** @internal */
                    onTypingInstallerWatchInvoke() {
                        this.typingWatchers.isInvoked = true;
                        this.projectService.updateTypingsForProject({ projectName: this.getProjectName(), kind: ActionInvalidate });
                    }
                    /** @internal */
                    watchTypingLocations(files) {
                        if (!files) {
                            this.typingWatchers.isInvoked = false;
                            return;
                        }
                        if (!files.length) {
                            this.closeWatchingTypingLocations();
                            return;
                        }
                        const toRemove = new Map(this.typingWatchers);
                        if (!this.typingWatchers)
                            this.typingWatchers = /* @__PURE__ */ new Map();
                        this.typingWatchers.isInvoked = false;
                        const createProjectWatcher = (path, typingsWatcherType) => {
                            const canonicalPath = this.toPath(path);
                            toRemove.delete(canonicalPath);
                            if (!this.typingWatchers.has(canonicalPath)) {
                                this.typingWatchers.set(canonicalPath, typingsWatcherType === "FileWatcher" /* FileWatcher */ ? this.projectService.watchFactory.watchFile(path, () => !this.typingWatchers.isInvoked ? this.onTypingInstallerWatchInvoke() : this.writeLog(`TypingWatchers already invoked`), 2e3 /* High */, this.projectService.getWatchOptions(this), WatchType.TypingInstallerLocationFile, this) : this.projectService.watchFactory.watchDirectory(path, (f) => {
                                    if (this.typingWatchers.isInvoked)
                                        return this.writeLog(`TypingWatchers already invoked`);
                                    if (!fileExtensionIs(f, ".json" /* Json */))
                                        return this.writeLog(`Ignoring files that are not *.json`);
                                    if (comparePaths(f, combinePaths(this.projectService.typingsInstaller.globalTypingsCacheLocation, "package.json"), !this.useCaseSensitiveFileNames()))
                                        return this.writeLog(`Ignoring package.json change at global typings location`);
                                    this.onTypingInstallerWatchInvoke();
                                }, 1 /* Recursive */, this.projectService.getWatchOptions(this), WatchType.TypingInstallerLocationDirectory, this));
                            }
                        };
                        for (const file of files) {
                            const basename = getBaseFileName(file);
                            if (basename === "package.json" || basename === "bower.json") {
                                createProjectWatcher(file, "FileWatcher" /* FileWatcher */);
                                continue;
                            }
                            if (containsPath(this.currentDirectory, file, this.currentDirectory, !this.useCaseSensitiveFileNames())) {
                                const subDirectory = file.indexOf(directorySeparator, this.currentDirectory.length + 1);
                                if (subDirectory !== -1) {
                                    createProjectWatcher(file.substr(0, subDirectory), "DirectoryWatcher" /* DirectoryWatcher */);
                                }
                                else {
                                    createProjectWatcher(file, "DirectoryWatcher" /* DirectoryWatcher */);
                                }
                                continue;
                            }
                            if (containsPath(this.projectService.typingsInstaller.globalTypingsCacheLocation, file, this.currentDirectory, !this.useCaseSensitiveFileNames())) {
                                createProjectWatcher(this.projectService.typingsInstaller.globalTypingsCacheLocation, "DirectoryWatcher" /* DirectoryWatcher */);
                                continue;
                            }
                            createProjectWatcher(file, "DirectoryWatcher" /* DirectoryWatcher */);
                        }
                        toRemove.forEach((watch, path) => {
                            watch.close();
                            this.typingWatchers.delete(path);
                        });
                    }
                    /** @internal */
                    getCurrentProgram() {
                        return this.program;
                    }
                    removeExistingTypings(include) {
                        const existing = getAutomaticTypeDirectiveNames(this.getCompilerOptions(), this.directoryStructureHost);
                        return include.filter((i) => !existing.includes(i));
                    }
                    updateGraphWorker() {
                        var _a, _b;
                        const oldProgram = this.languageService.getCurrentProgram();
                        Debug.assert(oldProgram === this.program);
                        Debug.assert(!this.isClosed(), "Called update graph worker of closed project");
                        this.writeLog(`Starting updateGraphWorker: Project: ${this.getProjectName()}`);
                        const start = timestamp();
                        const { hasInvalidatedResolutions, hasInvalidatedLibResolutions } = this.resolutionCache.createHasInvalidatedResolutions(returnFalse, returnFalse);
                        this.hasInvalidatedResolutions = hasInvalidatedResolutions;
                        this.hasInvalidatedLibResolutions = hasInvalidatedLibResolutions;
                        this.resolutionCache.startCachingPerDirectoryResolution();
                        this.dirty = false;
                        this.updateFromProjectInProgress = true;
                        this.program = this.languageService.getProgram();
                        this.updateFromProjectInProgress = false;
                        (_a = tracing) == null ? void 0 : _a.push(tracing.Phase.Session, "finishCachingPerDirectoryResolution");
                        this.resolutionCache.finishCachingPerDirectoryResolution(this.program, oldProgram);
                        (_b = tracing) == null ? void 0 : _b.pop();
                        Debug.assert(oldProgram === void 0 || this.program !== void 0);
                        let hasNewProgram = false;
                        if (this.program && (!oldProgram || this.program !== oldProgram && this.program.structureIsReused !== 2 /* Completely */)) {
                            hasNewProgram = true;
                            if (oldProgram) {
                                for (const f of oldProgram.getSourceFiles()) {
                                    const newFile = this.program.getSourceFileByPath(f.resolvedPath);
                                    if (!newFile || f.resolvedPath === f.path && newFile.resolvedPath !== f.path) {
                                        this.detachScriptInfoFromProject(f.fileName, !!this.program.getSourceFileByPath(f.path), 
                                        /*syncDirWatcherRemove*/
                                        true);
                                    }
                                }
                                oldProgram.forEachResolvedProjectReference((resolvedProjectReference) => {
                                    if (!this.program.getResolvedProjectReferenceByPath(resolvedProjectReference.sourceFile.path)) {
                                        this.detachScriptInfoFromProject(resolvedProjectReference.sourceFile.fileName, 
                                        /*noRemoveResolution*/
                                        void 0, 
                                        /*syncDirWatcherRemove*/
                                        true);
                                    }
                                });
                            }
                            updateMissingFilePathsWatch(this.program, this.missingFilesMap || (this.missingFilesMap = /* @__PURE__ */ new Map()), 
                            // Watch the missing files
                            (missingFilePath, missingFileName) => this.addMissingFileWatcher(missingFilePath, missingFileName));
                            if (this.generatedFilesMap) {
                                const outPath = outFile(this.compilerOptions);
                                if (isGeneratedFileWatcher(this.generatedFilesMap)) {
                                    if (!outPath || !this.isValidGeneratedFileWatcher(removeFileExtension(outPath) + ".d.ts" /* Dts */, this.generatedFilesMap)) {
                                        this.clearGeneratedFileWatch();
                                    }
                                }
                                else {
                                    if (outPath) {
                                        this.clearGeneratedFileWatch();
                                    }
                                    else {
                                        this.generatedFilesMap.forEach((watcher, source) => {
                                            const sourceFile = this.program.getSourceFileByPath(source);
                                            if (!sourceFile || sourceFile.resolvedPath !== source || !this.isValidGeneratedFileWatcher(getDeclarationEmitOutputFilePathWorker(sourceFile.fileName, this.compilerOptions, this.currentDirectory, this.program.getCommonSourceDirectory(), this.getCanonicalFileName), watcher)) {
                                                closeFileWatcherOf(watcher);
                                                this.generatedFilesMap.delete(source);
                                            }
                                        });
                                    }
                                }
                            }
                            if (this.languageServiceEnabled && this.projectService.serverMode === 0 /* Semantic */) {
                                this.resolutionCache.updateTypeRootsWatch();
                            }
                        }
                        this.projectService.verifyProgram(this);
                        if (this.exportMapCache && !this.exportMapCache.isEmpty()) {
                            this.exportMapCache.releaseSymbols();
                            if (this.hasAddedorRemovedFiles || oldProgram && !this.program.structureIsReused) {
                                this.exportMapCache.clear();
                            }
                            else if (this.changedFilesForExportMapCache && oldProgram && this.program) {
                                forEachKey(this.changedFilesForExportMapCache, (fileName) => {
                                    const oldSourceFile = oldProgram.getSourceFileByPath(fileName);
                                    const sourceFile = this.program.getSourceFileByPath(fileName);
                                    if (!oldSourceFile || !sourceFile) {
                                        this.exportMapCache.clear();
                                        return true;
                                    }
                                    return this.exportMapCache.onFileChanged(oldSourceFile, sourceFile, !!this.getTypeAcquisition().enable);
                                });
                            }
                        }
                        if (this.changedFilesForExportMapCache) {
                            this.changedFilesForExportMapCache.clear();
                        }
                        if (this.hasAddedOrRemovedSymlinks || this.program && !this.program.structureIsReused && this.getCompilerOptions().preserveSymlinks) {
                            this.symlinks = void 0;
                            this.moduleSpecifierCache.clear();
                        }
                        const oldExternalFiles = this.externalFiles || emptyArray2;
                        this.externalFiles = this.getExternalFiles();
                        enumerateInsertsAndDeletes(this.externalFiles, oldExternalFiles, getStringComparer(!this.useCaseSensitiveFileNames()), 
                        // Ensure a ScriptInfo is created for new external files. This is performed indirectly
                        // by the host for files in the program when the program is retrieved above but
                        // the program doesn't contain external files so this must be done explicitly.
                        (inserted) => {
                            const scriptInfo = this.projectService.getOrCreateScriptInfoNotOpenedByClient(inserted, this.currentDirectory, this.directoryStructureHost);
                            scriptInfo == null ? void 0 : scriptInfo.attachToProject(this);
                        }, (removed) => this.detachScriptInfoFromProject(removed));
                        const elapsed = timestamp() - start;
                        this.sendPerformanceEvent("UpdateGraph", elapsed);
                        this.writeLog(`Finishing updateGraphWorker: Project: ${this.getProjectName()} projectStateVersion: ${this.projectStateVersion} projectProgramVersion: ${this.projectProgramVersion} structureChanged: ${hasNewProgram}${this.program ? ` structureIsReused:: ${StructureIsReused[this.program.structureIsReused]}` : ""} Elapsed: ${elapsed}ms`);
                        if (this.projectService.logger.isTestLogger) {
                            if (this.program !== oldProgram) {
                                this.print(
                                /*writeProjectFileNames*/
                                true, this.hasAddedorRemovedFiles, 
                                /*writeFileVersionAndText*/
                                true);
                            }
                            else {
                                this.writeLog(`Same program as before`);
                            }
                        }
                        else if (this.hasAddedorRemovedFiles) {
                            this.print(
                            /*writeProjectFileNames*/
                            true, 
                            /*writeFileExplaination*/
                            true, 
                            /*writeFileVersionAndText*/
                            false);
                        }
                        else if (this.program !== oldProgram) {
                            this.writeLog(`Different program with same set of files`);
                        }
                        this.projectService.verifyDocumentRegistry();
                        return hasNewProgram;
                    }
                    /** @internal */
                    sendPerformanceEvent(kind, durationMs) {
                        this.projectService.sendPerformanceEvent(kind, durationMs);
                    }
                    detachScriptInfoFromProject(uncheckedFileName, noRemoveResolution, syncDirWatcherRemove) {
                        const scriptInfoToDetach = this.projectService.getScriptInfo(uncheckedFileName);
                        if (scriptInfoToDetach) {
                            scriptInfoToDetach.detachFromProject(this);
                            if (!noRemoveResolution) {
                                this.resolutionCache.removeResolutionsOfFile(scriptInfoToDetach.path, syncDirWatcherRemove);
                            }
                        }
                    }
                    addMissingFileWatcher(missingFilePath, missingFileName) {
                        var _a;
                        if (isConfiguredProject(this)) {
                            const configFileExistenceInfo = this.projectService.configFileExistenceInfoCache.get(missingFilePath);
                            if ((_a = configFileExistenceInfo == null ? void 0 : configFileExistenceInfo.config) == null ? void 0 : _a.projects.has(this.canonicalConfigFilePath))
                                return noopFileWatcher;
                        }
                        const fileWatcher = this.projectService.watchFactory.watchFile(getNormalizedAbsolutePath(missingFileName, this.currentDirectory), (fileName, eventKind) => {
                            if (isConfiguredProject(this)) {
                                this.getCachedDirectoryStructureHost().addOrDeleteFile(fileName, missingFilePath, eventKind);
                            }
                            if (eventKind === 0 /* Created */ && this.missingFilesMap.has(missingFilePath)) {
                                this.missingFilesMap.delete(missingFilePath);
                                fileWatcher.close();
                                this.projectService.delayUpdateProjectGraphAndEnsureProjectStructureForOpenFiles(this);
                            }
                        }, 500 /* Medium */, this.projectService.getWatchOptions(this), WatchType.MissingFile, this);
                        return fileWatcher;
                    }
                    isWatchedMissingFile(path) {
                        return !!this.missingFilesMap && this.missingFilesMap.has(path);
                    }
                    /** @internal */
                    addGeneratedFileWatch(generatedFile, sourceFile) {
                        if (outFile(this.compilerOptions)) {
                            if (!this.generatedFilesMap) {
                                this.generatedFilesMap = this.createGeneratedFileWatcher(generatedFile);
                            }
                        }
                        else {
                            const path = this.toPath(sourceFile);
                            if (this.generatedFilesMap) {
                                if (isGeneratedFileWatcher(this.generatedFilesMap)) {
                                    Debug.fail(`${this.projectName} Expected to not have --out watcher for generated file with options: ${JSON.stringify(this.compilerOptions)}`);
                                    return;
                                }
                                if (this.generatedFilesMap.has(path))
                                    return;
                            }
                            else {
                                this.generatedFilesMap = /* @__PURE__ */ new Map();
                            }
                            this.generatedFilesMap.set(path, this.createGeneratedFileWatcher(generatedFile));
                        }
                    }
                    createGeneratedFileWatcher(generatedFile) {
                        return {
                            generatedFilePath: this.toPath(generatedFile),
                            watcher: this.projectService.watchFactory.watchFile(generatedFile, () => {
                                this.clearSourceMapperCache();
                                this.projectService.delayUpdateProjectGraphAndEnsureProjectStructureForOpenFiles(this);
                            }, 2e3 /* High */, this.projectService.getWatchOptions(this), WatchType.MissingGeneratedFile, this)
                        };
                    }
                    isValidGeneratedFileWatcher(generateFile, watcher) {
                        return this.toPath(generateFile) === watcher.generatedFilePath;
                    }
                    clearGeneratedFileWatch() {
                        if (this.generatedFilesMap) {
                            if (isGeneratedFileWatcher(this.generatedFilesMap)) {
                                closeFileWatcherOf(this.generatedFilesMap);
                            }
                            else {
                                clearMap(this.generatedFilesMap, closeFileWatcherOf);
                            }
                            this.generatedFilesMap = void 0;
                        }
                    }
                    getScriptInfoForNormalizedPath(fileName) {
                        const scriptInfo = this.projectService.getScriptInfoForPath(this.toPath(fileName));
                        if (scriptInfo && !scriptInfo.isAttached(this)) {
                            return Errors.ThrowProjectDoesNotContainDocument(fileName, this);
                        }
                        return scriptInfo;
                    }
                    getScriptInfo(uncheckedFileName) {
                        return this.projectService.getScriptInfo(uncheckedFileName);
                    }
                    filesToString(writeProjectFileNames) {
                        return this.filesToStringWorker(writeProjectFileNames, 
                        /*writeFileExplaination*/
                        true, 
                        /*writeFileVersionAndText*/
                        false);
                    }
                    /** @internal */
                    filesToStringWorker(writeProjectFileNames, writeFileExplaination, writeFileVersionAndText) {
                        if (this.isInitialLoadPending())
                            return "	Files (0) InitialLoadPending\n";
                        if (!this.program)
                            return "	Files (0) NoProgram\n";
                        const sourceFiles = this.program.getSourceFiles();
                        let strBuilder = `	Files (${sourceFiles.length})
`;
                        if (writeProjectFileNames) {
                            for (const file of sourceFiles) {
                                strBuilder += `	${file.fileName}${writeFileVersionAndText ? ` ${file.version} ${JSON.stringify(file.text)}` : ""}
`;
                            }
                            if (writeFileExplaination) {
                                strBuilder += "\n\n";
                                explainFiles(this.program, (s) => strBuilder += `	${s}
`);
                            }
                        }
                        return strBuilder;
                    }
                    /** @internal */
                    print(writeProjectFileNames, writeFileExplaination, writeFileVersionAndText) {
                        var _a;
                        this.writeLog(`Project '${this.projectName}' (${ProjectKind[this.projectKind]})`);
                        this.writeLog(this.filesToStringWorker(writeProjectFileNames && this.projectService.logger.hasLevel(3 /* verbose */), writeFileExplaination && this.projectService.logger.hasLevel(3 /* verbose */), writeFileVersionAndText && this.projectService.logger.hasLevel(3 /* verbose */)));
                        this.writeLog("-----------------------------------------------");
                        if (this.autoImportProviderHost) {
                            this.autoImportProviderHost.print(
                            /*writeProjectFileNames*/
                            false, 
                            /*writeFileExplaination*/
                            false, 
                            /*writeFileVersionAndText*/
                            false);
                        }
                        (_a = this.noDtsResolutionProject) == null ? void 0 : _a.print(
                        /*writeProjectFileNames*/
                        false, 
                        /*writeFileExplaination*/
                        false, 
                        /*writeFileVersionAndText*/
                        false);
                    }
                    setCompilerOptions(compilerOptions) {
                        var _a;
                        if (compilerOptions) {
                            compilerOptions.allowNonTsExtensions = true;
                            const oldOptions = this.compilerOptions;
                            this.compilerOptions = compilerOptions;
                            this.setInternalCompilerOptionsForEmittingJsFiles();
                            (_a = this.noDtsResolutionProject) == null ? void 0 : _a.setCompilerOptions(this.getCompilerOptionsForNoDtsResolutionProject());
                            if (changesAffectModuleResolution(oldOptions, compilerOptions)) {
                                this.cachedUnresolvedImportsPerFile.clear();
                                this.lastCachedUnresolvedImportsList = void 0;
                                this.resolutionCache.onChangesAffectModuleResolution();
                                this.moduleSpecifierCache.clear();
                            }
                            this.markAsDirty();
                        }
                    }
                    /** @internal */
                    setWatchOptions(watchOptions) {
                        this.watchOptions = watchOptions;
                    }
                    /** @internal */
                    getWatchOptions() {
                        return this.watchOptions;
                    }
                    setTypeAcquisition(newTypeAcquisition) {
                        if (newTypeAcquisition) {
                            this.typeAcquisition = this.removeLocalTypingsFromTypeAcquisition(newTypeAcquisition);
                        }
                    }
                    getTypeAcquisition() {
                        return this.typeAcquisition || {};
                    }
                    /** @internal */
                    getChangesSinceVersion(lastKnownVersion, includeProjectReferenceRedirectInfo) {
                        var _a, _b;
                        const includeProjectReferenceRedirectInfoIfRequested = includeProjectReferenceRedirectInfo ? (files) => arrayFrom(files.entries(), ([fileName, isSourceOfProjectReferenceRedirect]) => ({
                            fileName,
                            isSourceOfProjectReferenceRedirect
                        })) : (files) => arrayFrom(files.keys());
                        if (!this.isInitialLoadPending()) {
                            updateProjectIfDirty(this);
                        }
                        const info = {
                            projectName: this.getProjectName(),
                            version: this.projectProgramVersion,
                            isInferred: isInferredProject(this),
                            options: this.getCompilationSettings(),
                            languageServiceDisabled: !this.languageServiceEnabled,
                            lastFileExceededProgramSize: this.lastFileExceededProgramSize
                        };
                        const updatedFileNames = this.updatedFileNames;
                        this.updatedFileNames = void 0;
                        if (this.lastReportedFileNames && lastKnownVersion === this.lastReportedVersion) {
                            if (this.projectProgramVersion === this.lastReportedVersion && !updatedFileNames) {
                                return { info, projectErrors: this.getGlobalProjectErrors() };
                            }
                            const lastReportedFileNames = this.lastReportedFileNames;
                            const externalFiles = ((_a = this.externalFiles) == null ? void 0 : _a.map((f) => ({
                                fileName: toNormalizedPath(f),
                                isSourceOfProjectReferenceRedirect: false
                            }))) || emptyArray2;
                            const currentFiles = arrayToMap(this.getFileNamesWithRedirectInfo(!!includeProjectReferenceRedirectInfo).concat(externalFiles), (info2) => info2.fileName, (info2) => info2.isSourceOfProjectReferenceRedirect);
                            const added = /* @__PURE__ */ new Map();
                            const removed = /* @__PURE__ */ new Map();
                            const updated = updatedFileNames ? arrayFrom(updatedFileNames.keys()) : [];
                            const updatedRedirects = [];
                            forEachEntry(currentFiles, (isSourceOfProjectReferenceRedirect, fileName) => {
                                if (!lastReportedFileNames.has(fileName)) {
                                    added.set(fileName, isSourceOfProjectReferenceRedirect);
                                }
                                else if (includeProjectReferenceRedirectInfo && isSourceOfProjectReferenceRedirect !== lastReportedFileNames.get(fileName)) {
                                    updatedRedirects.push({
                                        fileName,
                                        isSourceOfProjectReferenceRedirect
                                    });
                                }
                            });
                            forEachEntry(lastReportedFileNames, (isSourceOfProjectReferenceRedirect, fileName) => {
                                if (!currentFiles.has(fileName)) {
                                    removed.set(fileName, isSourceOfProjectReferenceRedirect);
                                }
                            });
                            this.lastReportedFileNames = currentFiles;
                            this.lastReportedVersion = this.projectProgramVersion;
                            return {
                                info,
                                changes: {
                                    added: includeProjectReferenceRedirectInfoIfRequested(added),
                                    removed: includeProjectReferenceRedirectInfoIfRequested(removed),
                                    updated: includeProjectReferenceRedirectInfo ? updated.map((fileName) => ({
                                        fileName,
                                        isSourceOfProjectReferenceRedirect: this.isSourceOfProjectReferenceRedirect(fileName)
                                    })) : updated,
                                    updatedRedirects: includeProjectReferenceRedirectInfo ? updatedRedirects : void 0
                                },
                                projectErrors: this.getGlobalProjectErrors()
                            };
                        }
                        else {
                            const projectFileNames = this.getFileNamesWithRedirectInfo(!!includeProjectReferenceRedirectInfo);
                            const externalFiles = ((_b = this.externalFiles) == null ? void 0 : _b.map((f) => ({
                                fileName: toNormalizedPath(f),
                                isSourceOfProjectReferenceRedirect: false
                            }))) || emptyArray2;
                            const allFiles = projectFileNames.concat(externalFiles);
                            this.lastReportedFileNames = arrayToMap(allFiles, (info2) => info2.fileName, (info2) => info2.isSourceOfProjectReferenceRedirect);
                            this.lastReportedVersion = this.projectProgramVersion;
                            return {
                                info,
                                files: includeProjectReferenceRedirectInfo ? allFiles : allFiles.map((f) => f.fileName),
                                projectErrors: this.getGlobalProjectErrors()
                            };
                        }
                    }
                    // remove a root file from project
                    removeRoot(info) {
                        orderedRemoveItem(this.rootFiles, info);
                        this.rootFilesMap.delete(info.path);
                    }
                    /** @internal */
                    isSourceOfProjectReferenceRedirect(fileName) {
                        return !!this.program && this.program.isSourceOfProjectReferenceRedirect(fileName);
                    }
                    /** @internal */
                    getGlobalPluginSearchPaths() {
                        return [
                            ...this.projectService.pluginProbeLocations,
                            // ../../.. to walk from X/node_modules/typescript/lib/tsserver.js to X/node_modules/
                            combinePaths(this.projectService.getExecutingFilePath(), "../../..")
                        ];
                    }
                    enableGlobalPlugins(options) {
                        if (!this.projectService.globalPlugins.length)
                            return;
                        const host = this.projectService.host;
                        if (!host.require && !host.importPlugin) {
                            this.projectService.logger.info("Plugins were requested but not running in environment that supports 'require'. Nothing will be loaded");
                            return;
                        }
                        const searchPaths = this.getGlobalPluginSearchPaths();
                        for (const globalPluginName of this.projectService.globalPlugins) {
                            if (!globalPluginName)
                                continue;
                            if (options.plugins && options.plugins.some((p) => p.name === globalPluginName))
                                continue;
                            this.projectService.logger.info(`Loading global plugin ${globalPluginName}`);
                            this.enablePlugin({ name: globalPluginName, global: true }, searchPaths);
                        }
                    }
                    enablePlugin(pluginConfigEntry, searchPaths) {
                        this.projectService.requestEnablePlugin(this, pluginConfigEntry, searchPaths);
                    }
                    /** @internal */
                    enableProxy(pluginModuleFactory, configEntry) {
                        try {
                            if (typeof pluginModuleFactory !== "function") {
                                this.projectService.logger.info(`Skipped loading plugin ${configEntry.name} because it did not expose a proper factory function`);
                                return;
                            }
                            const info = {
                                config: configEntry,
                                project: this,
                                languageService: this.languageService,
                                languageServiceHost: this,
                                serverHost: this.projectService.host,
                                session: this.projectService.session
                            };
                            const pluginModule = pluginModuleFactory({ typescript: ts_exports2 });
                            const newLS = pluginModule.create(info);
                            for (const k of Object.keys(this.languageService)) {
                                if (!(k in newLS)) {
                                    this.projectService.logger.info(`Plugin activation warning: Missing proxied method ${k} in created LS. Patching.`);
                                    newLS[k] = this.languageService[k];
                                }
                            }
                            this.projectService.logger.info(`Plugin validation succeeded`);
                            this.languageService = newLS;
                            this.plugins.push({ name: configEntry.name, module: pluginModule });
                        }
                        catch (e) {
                            this.projectService.logger.info(`Plugin activation failed: ${e}`);
                        }
                    }
                    /** @internal */
                    onPluginConfigurationChanged(pluginName, configuration) {
                        this.plugins.filter((plugin) => plugin.name === pluginName).forEach((plugin) => {
                            if (plugin.module.onConfigurationChanged) {
                                plugin.module.onConfigurationChanged(configuration);
                            }
                        });
                    }
                    /** Starts a new check for diagnostics. Call this if some file has updated that would cause diagnostics to be changed. */
                    refreshDiagnostics() {
                        this.projectService.sendProjectsUpdatedInBackgroundEvent();
                    }
                    /** @internal */
                    getPackageJsonsVisibleToFile(fileName, rootDir) {
                        if (this.projectService.serverMode !== 0 /* Semantic */)
                            return emptyArray2;
                        return this.projectService.getPackageJsonsVisibleToFile(fileName, this, rootDir);
                    }
                    /** @internal */
                    getNearestAncestorDirectoryWithPackageJson(fileName) {
                        return this.projectService.getNearestAncestorDirectoryWithPackageJson(fileName);
                    }
                    /** @internal */
                    getPackageJsonsForAutoImport(rootDir) {
                        return this.getPackageJsonsVisibleToFile(combinePaths(this.currentDirectory, inferredTypesContainingFile), rootDir);
                    }
                    /** @internal */
                    getPackageJsonCache() {
                        return this.projectService.packageJsonCache;
                    }
                    /** @internal */
                    getCachedExportInfoMap() {
                        return this.exportMapCache || (this.exportMapCache = createCacheableExportInfoMap(this));
                    }
                    /** @internal */
                    clearCachedExportInfoMap() {
                        var _a;
                        (_a = this.exportMapCache) == null ? void 0 : _a.clear();
                    }
                    /** @internal */
                    getModuleSpecifierCache() {
                        return this.moduleSpecifierCache;
                    }
                    /** @internal */
                    includePackageJsonAutoImports() {
                        if (this.projectService.includePackageJsonAutoImports() === 0 /* Off */ || !this.languageServiceEnabled || isInsideNodeModules(this.currentDirectory) || !this.isDefaultProjectForOpenFiles()) {
                            return 0 /* Off */;
                        }
                        return this.projectService.includePackageJsonAutoImports();
                    }
                    /** @internal */
                    getHostForAutoImportProvider() {
                        var _a, _b;
                        if (this.program) {
                            return {
                                fileExists: this.program.fileExists,
                                directoryExists: this.program.directoryExists,
                                realpath: this.program.realpath || ((_a = this.projectService.host.realpath) == null ? void 0 : _a.bind(this.projectService.host)),
                                getCurrentDirectory: this.getCurrentDirectory.bind(this),
                                readFile: this.projectService.host.readFile.bind(this.projectService.host),
                                getDirectories: this.projectService.host.getDirectories.bind(this.projectService.host),
                                trace: (_b = this.projectService.host.trace) == null ? void 0 : _b.bind(this.projectService.host),
                                useCaseSensitiveFileNames: this.program.useCaseSensitiveFileNames(),
                                readDirectory: this.projectService.host.readDirectory.bind(this.projectService.host)
                            };
                        }
                        return this.projectService.host;
                    }
                    /** @internal */
                    getPackageJsonAutoImportProvider() {
                        var _a, _b, _c;
                        if (this.autoImportProviderHost === false) {
                            return void 0;
                        }
                        if (this.projectService.serverMode !== 0 /* Semantic */) {
                            this.autoImportProviderHost = false;
                            return void 0;
                        }
                        if (this.autoImportProviderHost) {
                            updateProjectIfDirty(this.autoImportProviderHost);
                            if (this.autoImportProviderHost.isEmpty()) {
                                this.autoImportProviderHost.close();
                                this.autoImportProviderHost = void 0;
                                return void 0;
                            }
                            return this.autoImportProviderHost.getCurrentProgram();
                        }
                        const dependencySelection = this.includePackageJsonAutoImports();
                        if (dependencySelection) {
                            (_a = tracing) == null ? void 0 : _a.push(tracing.Phase.Session, "getPackageJsonAutoImportProvider");
                            const start = timestamp();
                            this.autoImportProviderHost = AutoImportProviderProject.create(dependencySelection, this, this.getHostForAutoImportProvider(), this.documentRegistry);
                            if (this.autoImportProviderHost) {
                                updateProjectIfDirty(this.autoImportProviderHost);
                                this.sendPerformanceEvent("CreatePackageJsonAutoImportProvider", timestamp() - start);
                                (_b = tracing) == null ? void 0 : _b.pop();
                                return this.autoImportProviderHost.getCurrentProgram();
                            }
                            (_c = tracing) == null ? void 0 : _c.pop();
                        }
                    }
                    /** @internal */
                    isDefaultProjectForOpenFiles() {
                        return !!forEachEntry(this.projectService.openFiles, (_, fileName) => this.projectService.tryGetDefaultProjectForFile(toNormalizedPath(fileName)) === this);
                    }
                    /** @internal */
                    watchNodeModulesForPackageJsonChanges(directoryPath) {
                        return this.projectService.watchPackageJsonsInNodeModules(directoryPath, this);
                    }
                    /** @internal */
                    getIncompleteCompletionsCache() {
                        return this.projectService.getIncompleteCompletionsCache();
                    }
                    /** @internal */
                    getNoDtsResolutionProject(rootFile) {
                        Debug.assert(this.projectService.serverMode === 0 /* Semantic */);
                        if (!this.noDtsResolutionProject) {
                            this.noDtsResolutionProject = new AuxiliaryProject(this.projectService, this.documentRegistry, this.getCompilerOptionsForNoDtsResolutionProject(), this.currentDirectory);
                        }
                        if (this.noDtsResolutionProject.rootFile !== rootFile) {
                            this.projectService.setFileNamesOfAutpImportProviderOrAuxillaryProject(this.noDtsResolutionProject, [rootFile]);
                            this.noDtsResolutionProject.rootFile = rootFile;
                        }
                        return this.noDtsResolutionProject;
                    }
                    /** @internal */
                    getCompilerOptionsForNoDtsResolutionProject() {
                        return {
                            ...this.getCompilerOptions(),
                            noDtsResolution: true,
                            allowJs: true,
                            maxNodeModuleJsDepth: 3,
                            diagnostics: false,
                            skipLibCheck: true,
                            sourceMap: false,
                            types: emptyArray,
                            lib: emptyArray,
                            noLib: true
                        };
                    }
                };
                InferredProject2 = class extends Project3 {
                    /** @internal */
                    constructor(projectService, documentRegistry, compilerOptions, watchOptions, projectRootPath, currentDirectory, typeAcquisition) {
                        super(projectService.newInferredProjectName(), 0 /* Inferred */, projectService, documentRegistry, 
                        // TODO: GH#18217
                        /*files*/
                        void 0, 
                        /*lastFileExceededProgramSize*/
                        void 0, compilerOptions, 
                        /*compileOnSaveEnabled*/
                        false, watchOptions, projectService.host, currentDirectory);
                        this._isJsInferredProject = false;
                        this.typeAcquisition = typeAcquisition;
                        this.projectRootPath = projectRootPath && projectService.toCanonicalFileName(projectRootPath);
                        if (!projectRootPath && !projectService.useSingleInferredProject) {
                            this.canonicalCurrentDirectory = projectService.toCanonicalFileName(this.currentDirectory);
                        }
                        this.enableGlobalPlugins(this.getCompilerOptions());
                    }
                    toggleJsInferredProject(isJsInferredProject) {
                        if (isJsInferredProject !== this._isJsInferredProject) {
                            this._isJsInferredProject = isJsInferredProject;
                            this.setCompilerOptions();
                        }
                    }
                    setCompilerOptions(options) {
                        if (!options && !this.getCompilationSettings()) {
                            return;
                        }
                        const newOptions = cloneCompilerOptions(options || this.getCompilationSettings());
                        if (this._isJsInferredProject && typeof newOptions.maxNodeModuleJsDepth !== "number") {
                            newOptions.maxNodeModuleJsDepth = 2;
                        }
                        else if (!this._isJsInferredProject) {
                            newOptions.maxNodeModuleJsDepth = void 0;
                        }
                        newOptions.allowJs = true;
                        super.setCompilerOptions(newOptions);
                    }
                    addRoot(info) {
                        Debug.assert(info.isScriptOpen());
                        this.projectService.startWatchingConfigFilesForInferredProjectRoot(info);
                        if (!this._isJsInferredProject && info.isJavaScript()) {
                            this.toggleJsInferredProject(
                            /*isJsInferredProject*/
                            true);
                        }
                        else if (this.isOrphan() && this._isJsInferredProject && !info.isJavaScript()) {
                            this.toggleJsInferredProject(
                            /*isJsInferredProject*/
                            false);
                        }
                        super.addRoot(info);
                    }
                    removeRoot(info) {
                        this.projectService.stopWatchingConfigFilesForInferredProjectRoot(info);
                        super.removeRoot(info);
                        if (!this.isOrphan() && this._isJsInferredProject && info.isJavaScript()) {
                            if (every(this.getRootScriptInfos(), (rootInfo) => !rootInfo.isJavaScript())) {
                                this.toggleJsInferredProject(
                                /*isJsInferredProject*/
                                false);
                            }
                        }
                    }
                    /** @internal */
                    isOrphan() {
                        return !this.hasRoots();
                    }
                    isProjectWithSingleRoot() {
                        return !this.projectRootPath && !this.projectService.useSingleInferredProject || this.getRootScriptInfos().length === 1;
                    }
                    close() {
                        forEach(this.getRootScriptInfos(), (info) => this.projectService.stopWatchingConfigFilesForInferredProjectRoot(info));
                        super.close();
                    }
                    getTypeAcquisition() {
                        return this.typeAcquisition || {
                            enable: allRootFilesAreJsOrDts(this),
                            include: emptyArray,
                            exclude: emptyArray
                        };
                    }
                };
                AuxiliaryProject = class extends Project3 {
                    constructor(projectService, documentRegistry, compilerOptions, currentDirectory) {
                        super(projectService.newAuxiliaryProjectName(), 4 /* Auxiliary */, projectService, documentRegistry, 
                        /*hasExplicitListOfFiles*/
                        false, 
                        /*lastFileExceededProgramSize*/
                        void 0, compilerOptions, 
                        /*compileOnSaveEnabled*/
                        false, 
                        /*watchOptions*/
                        void 0, projectService.host, currentDirectory);
                    }
                    isOrphan() {
                        return true;
                    }
                    scheduleInvalidateResolutionsOfFailedLookupLocations() {
                        return;
                    }
                };
                _AutoImportProviderProject = class _AutoImportProviderProject extends Project3 {
                    /** @internal */
                    constructor(hostProject, initialRootNames, documentRegistry, compilerOptions) {
                        super(hostProject.projectService.newAutoImportProviderProjectName(), 3 /* AutoImportProvider */, hostProject.projectService, documentRegistry, 
                        /*hasExplicitListOfFiles*/
                        false, 
                        /*lastFileExceededProgramSize*/
                        void 0, compilerOptions, 
                        /*compileOnSaveEnabled*/
                        false, hostProject.getWatchOptions(), hostProject.projectService.host, hostProject.currentDirectory);
                        this.hostProject = hostProject;
                        this.rootFileNames = initialRootNames;
                        this.useSourceOfProjectReferenceRedirect = maybeBind(this.hostProject, this.hostProject.useSourceOfProjectReferenceRedirect);
                        this.getParsedCommandLine = maybeBind(this.hostProject, this.hostProject.getParsedCommandLine);
                    }
                    /** @internal */
                    static getRootFileNames(dependencySelection, hostProject, host, compilerOptions) {
                        var _a, _b;
                        if (!dependencySelection) {
                            return emptyArray;
                        }
                        const program = hostProject.getCurrentProgram();
                        if (!program) {
                            return emptyArray;
                        }
                        const start = timestamp();
                        let dependencyNames;
                        let rootNames;
                        const rootFileName = combinePaths(hostProject.currentDirectory, inferredTypesContainingFile);
                        const packageJsons = hostProject.getPackageJsonsForAutoImport(combinePaths(hostProject.currentDirectory, rootFileName));
                        for (const packageJson of packageJsons) {
                            (_a = packageJson.dependencies) == null ? void 0 : _a.forEach((_, dependenyName) => addDependency(dependenyName));
                            (_b = packageJson.peerDependencies) == null ? void 0 : _b.forEach((_, dependencyName) => addDependency(dependencyName));
                        }
                        let dependenciesAdded = 0;
                        if (dependencyNames) {
                            const symlinkCache = hostProject.getSymlinkCache();
                            for (const name of arrayFrom(dependencyNames.keys())) {
                                if (dependencySelection === 2 /* Auto */ && dependenciesAdded > this.maxDependencies) {
                                    hostProject.log(`AutoImportProviderProject: attempted to add more than ${this.maxDependencies} dependencies. Aborting.`);
                                    return emptyArray;
                                }
                                const packageJson = resolvePackageNameToPackageJson(name, hostProject.currentDirectory, compilerOptions, host, program.getModuleResolutionCache());
                                if (packageJson) {
                                    const entrypoints = getRootNamesFromPackageJson(packageJson, program, symlinkCache);
                                    if (entrypoints) {
                                        rootNames = concatenate(rootNames, entrypoints);
                                        dependenciesAdded += entrypoints.length ? 1 : 0;
                                        continue;
                                    }
                                }
                                const done = forEach([hostProject.currentDirectory, hostProject.getGlobalTypingsCacheLocation()], (directory) => {
                                    if (directory) {
                                        const typesPackageJson = resolvePackageNameToPackageJson(`@types/${name}`, directory, compilerOptions, host, program.getModuleResolutionCache());
                                        if (typesPackageJson) {
                                            const entrypoints = getRootNamesFromPackageJson(typesPackageJson, program, symlinkCache);
                                            rootNames = concatenate(rootNames, entrypoints);
                                            dependenciesAdded += (entrypoints == null ? void 0 : entrypoints.length) ? 1 : 0;
                                            return true;
                                        }
                                    }
                                });
                                if (done)
                                    continue;
                                if (packageJson && compilerOptions.allowJs && compilerOptions.maxNodeModuleJsDepth) {
                                    const entrypoints = getRootNamesFromPackageJson(packageJson, program, symlinkCache, 
                                    /*resolveJs*/
                                    true);
                                    rootNames = concatenate(rootNames, entrypoints);
                                    dependenciesAdded += (entrypoints == null ? void 0 : entrypoints.length) ? 1 : 0;
                                }
                            }
                        }
                        if (rootNames == null ? void 0 : rootNames.length) {
                            hostProject.log(`AutoImportProviderProject: found ${rootNames.length} root files in ${dependenciesAdded} dependencies in ${timestamp() - start} ms`);
                        }
                        return rootNames || emptyArray;
                        function addDependency(dependency) {
                            if (!startsWith(dependency, "@types/")) {
                                (dependencyNames || (dependencyNames = /* @__PURE__ */ new Set())).add(dependency);
                            }
                        }
                        function getRootNamesFromPackageJson(packageJson, program2, symlinkCache, resolveJs) {
                            var _a2;
                            const entrypoints = getEntrypointsFromPackageJsonInfo(packageJson, compilerOptions, host, program2.getModuleResolutionCache(), resolveJs);
                            if (entrypoints) {
                                const real = (_a2 = host.realpath) == null ? void 0 : _a2.call(host, packageJson.packageDirectory);
                                const realPath2 = real ? hostProject.toPath(real) : void 0;
                                const isSymlink = realPath2 && realPath2 !== hostProject.toPath(packageJson.packageDirectory);
                                if (isSymlink) {
                                    symlinkCache.setSymlinkedDirectory(packageJson.packageDirectory, {
                                        real: ensureTrailingDirectorySeparator(real),
                                        realPath: ensureTrailingDirectorySeparator(realPath2)
                                    });
                                }
                                return mapDefined(entrypoints, (entrypoint) => {
                                    const resolvedFileName = isSymlink ? entrypoint.replace(packageJson.packageDirectory, real) : entrypoint;
                                    if (!program2.getSourceFile(resolvedFileName) && !(isSymlink && program2.getSourceFile(entrypoint))) {
                                        return resolvedFileName;
                                    }
                                });
                            }
                        }
                    }
                    /** @internal */
                    static create(dependencySelection, hostProject, host, documentRegistry) {
                        if (dependencySelection === 0 /* Off */) {
                            return void 0;
                        }
                        const compilerOptions = {
                            ...hostProject.getCompilerOptions(),
                            ...this.compilerOptionsOverrides
                        };
                        const rootNames = this.getRootFileNames(dependencySelection, hostProject, host, compilerOptions);
                        if (!rootNames.length) {
                            return void 0;
                        }
                        return new _AutoImportProviderProject(hostProject, rootNames, documentRegistry, compilerOptions);
                    }
                    /** @internal */
                    isEmpty() {
                        return !some(this.rootFileNames);
                    }
                    isOrphan() {
                        return true;
                    }
                    updateGraph() {
                        let rootFileNames = this.rootFileNames;
                        if (!rootFileNames) {
                            rootFileNames = _AutoImportProviderProject.getRootFileNames(this.hostProject.includePackageJsonAutoImports(), this.hostProject, this.hostProject.getHostForAutoImportProvider(), this.getCompilationSettings());
                        }
                        this.projectService.setFileNamesOfAutpImportProviderOrAuxillaryProject(this, rootFileNames);
                        this.rootFileNames = rootFileNames;
                        const oldProgram = this.getCurrentProgram();
                        const hasSameSetOfFiles = super.updateGraph();
                        if (oldProgram && oldProgram !== this.getCurrentProgram()) {
                            this.hostProject.clearCachedExportInfoMap();
                        }
                        return hasSameSetOfFiles;
                    }
                    /** @internal */
                    scheduleInvalidateResolutionsOfFailedLookupLocations() {
                        return;
                    }
                    hasRoots() {
                        var _a;
                        return !!((_a = this.rootFileNames) == null ? void 0 : _a.length);
                    }
                    markAsDirty() {
                        this.rootFileNames = void 0;
                        super.markAsDirty();
                    }
                    getScriptFileNames() {
                        return this.rootFileNames || emptyArray;
                    }
                    getLanguageService() {
                        throw new Error("AutoImportProviderProject language service should never be used. To get the program, use `project.getCurrentProgram()`.");
                    }
                    /** @internal */
                    onAutoImportProviderSettingsChanged() {
                        throw new Error("AutoImportProviderProject is an auto import provider; use `markAsDirty()` instead.");
                    }
                    /** @internal */
                    onPackageJsonChange() {
                        throw new Error("package.json changes should be notified on an AutoImportProvider's host project");
                    }
                    getHostForAutoImportProvider() {
                        throw new Error("AutoImportProviderProject cannot provide its own host; use `hostProject.getModuleResolutionHostForAutomImportProvider()` instead.");
                    }
                    getProjectReferences() {
                        return this.hostProject.getProjectReferences();
                    }
                    /** @internal */
                    includePackageJsonAutoImports() {
                        return 0 /* Off */;
                    }
                    /** @internal */
                    getSymlinkCache() {
                        return this.hostProject.getSymlinkCache();
                    }
                    /** @internal */
                    getModuleResolutionCache() {
                        var _a;
                        return (_a = this.hostProject.getCurrentProgram()) == null ? void 0 : _a.getModuleResolutionCache();
                    }
                };
                /** @internal */
                _AutoImportProviderProject.maxDependencies = 10;
                /** @internal */
                _AutoImportProviderProject.compilerOptionsOverrides = {
                    diagnostics: false,
                    skipLibCheck: true,
                    sourceMap: false,
                    types: emptyArray,
                    lib: emptyArray,
                    noLib: true
                };
                AutoImportProviderProject = _AutoImportProviderProject;
                ConfiguredProject2 = class extends Project3 {
                    /** @internal */
                    constructor(configFileName, canonicalConfigFilePath, projectService, documentRegistry, cachedDirectoryStructureHost) {
                        super(configFileName, 1 /* Configured */, projectService, documentRegistry, 
                        /*hasExplicitListOfFiles*/
                        false, 
                        /*lastFileExceededProgramSize*/
                        void 0, 
                        /*compilerOptions*/
                        {}, 
                        /*compileOnSaveEnabled*/
                        false, 
                        /*watchOptions*/
                        void 0, cachedDirectoryStructureHost, getDirectoryPath(configFileName));
                        this.canonicalConfigFilePath = canonicalConfigFilePath;
                        /** @internal */
                        this.openFileWatchTriggered = /* @__PURE__ */ new Map();
                        /** @internal */
                        this.canConfigFileJsonReportNoInputFiles = false;
                        /** Ref count to the project when opened from external project */
                        this.externalProjectRefCount = 0;
                        /** @internal */
                        this.isInitialLoadPending = returnTrue;
                        /** @internal */
                        this.sendLoadingProjectFinish = false;
                    }
                    /** @internal */
                    setCompilerHost(host) {
                        this.compilerHost = host;
                    }
                    /** @internal */
                    getCompilerHost() {
                        return this.compilerHost;
                    }
                    /** @internal */
                    useSourceOfProjectReferenceRedirect() {
                        return this.languageServiceEnabled;
                    }
                    /** @internal */
                    getParsedCommandLine(fileName) {
                        const configFileName = asNormalizedPath(normalizePath(fileName));
                        const canonicalConfigFilePath = asNormalizedPath(this.projectService.toCanonicalFileName(configFileName));
                        let configFileExistenceInfo = this.projectService.configFileExistenceInfoCache.get(canonicalConfigFilePath);
                        if (!configFileExistenceInfo) {
                            this.projectService.configFileExistenceInfoCache.set(canonicalConfigFilePath, configFileExistenceInfo = { exists: this.projectService.host.fileExists(configFileName) });
                        }
                        this.projectService.ensureParsedConfigUptoDate(configFileName, canonicalConfigFilePath, configFileExistenceInfo, this);
                        if (this.languageServiceEnabled && this.projectService.serverMode === 0 /* Semantic */) {
                            this.projectService.watchWildcards(configFileName, configFileExistenceInfo, this);
                        }
                        return configFileExistenceInfo.exists ? configFileExistenceInfo.config.parsedCommandLine : void 0;
                    }
                    /** @internal */
                    onReleaseParsedCommandLine(fileName) {
                        this.releaseParsedConfig(asNormalizedPath(this.projectService.toCanonicalFileName(asNormalizedPath(normalizePath(fileName)))));
                    }
                    /** @internal */
                    releaseParsedConfig(canonicalConfigFilePath) {
                        this.projectService.stopWatchingWildCards(canonicalConfigFilePath, this);
                        this.projectService.releaseParsedConfig(canonicalConfigFilePath, this);
                    }
                    /**
                     * If the project has reload from disk pending, it reloads (and then updates graph as part of that) instead of just updating the graph
                     * @returns: true if set of files in the project stays the same and false - otherwise.
                     */
                    updateGraph() {
                        const isInitialLoad = this.isInitialLoadPending();
                        this.isInitialLoadPending = returnFalse;
                        const updateLevel = this.pendingUpdateLevel;
                        this.pendingUpdateLevel = 0 /* Update */;
                        let result;
                        switch (updateLevel) {
                            case 1 /* RootNamesAndUpdate */:
                                this.openFileWatchTriggered.clear();
                                result = this.projectService.reloadFileNamesOfConfiguredProject(this);
                                break;
                            case 2 /* Full */:
                                this.openFileWatchTriggered.clear();
                                const reason = Debug.checkDefined(this.pendingUpdateReason);
                                this.pendingUpdateReason = void 0;
                                this.projectService.reloadConfiguredProject(this, reason, isInitialLoad, 
                                /*clearSemanticCache*/
                                false);
                                result = true;
                                break;
                            default:
                                result = super.updateGraph();
                        }
                        this.compilerHost = void 0;
                        this.projectService.sendProjectLoadingFinishEvent(this);
                        this.projectService.sendProjectTelemetry(this);
                        return result;
                    }
                    /** @internal */
                    getCachedDirectoryStructureHost() {
                        return this.directoryStructureHost;
                    }
                    getConfigFilePath() {
                        return asNormalizedPath(this.getProjectName());
                    }
                    getProjectReferences() {
                        return this.projectReferences;
                    }
                    updateReferences(refs) {
                        this.projectReferences = refs;
                        this.potentialProjectReferences = void 0;
                    }
                    /** @internal */
                    setPotentialProjectReference(canonicalConfigPath) {
                        Debug.assert(this.isInitialLoadPending());
                        (this.potentialProjectReferences || (this.potentialProjectReferences = /* @__PURE__ */ new Set())).add(canonicalConfigPath);
                    }
                    /** @internal */
                    getResolvedProjectReferenceToRedirect(fileName) {
                        const program = this.getCurrentProgram();
                        return program && program.getResolvedProjectReferenceToRedirect(fileName);
                    }
                    /** @internal */
                    forEachResolvedProjectReference(cb) {
                        var _a;
                        return (_a = this.getCurrentProgram()) == null ? void 0 : _a.forEachResolvedProjectReference(cb);
                    }
                    /** @internal */
                    enablePluginsWithOptions(options) {
                        var _a;
                        this.plugins.length = 0;
                        if (!((_a = options.plugins) == null ? void 0 : _a.length) && !this.projectService.globalPlugins.length)
                            return;
                        const host = this.projectService.host;
                        if (!host.require && !host.importPlugin) {
                            this.projectService.logger.info("Plugins were requested but not running in environment that supports 'require'. Nothing will be loaded");
                            return;
                        }
                        const searchPaths = this.getGlobalPluginSearchPaths();
                        if (this.projectService.allowLocalPluginLoads) {
                            const local = getDirectoryPath(this.canonicalConfigFilePath);
                            this.projectService.logger.info(`Local plugin loading enabled; adding ${local} to search paths`);
                            searchPaths.unshift(local);
                        }
                        if (options.plugins) {
                            for (const pluginConfigEntry of options.plugins) {
                                this.enablePlugin(pluginConfigEntry, searchPaths);
                            }
                        }
                        return this.enableGlobalPlugins(options);
                    }
                    /**
                     * Get the errors that dont have any file name associated
                     */
                    getGlobalProjectErrors() {
                        return filter(this.projectErrors, (diagnostic) => !diagnostic.file) || emptyArray2;
                    }
                    /**
                     * Get all the project errors
                     */
                    getAllProjectErrors() {
                        return this.projectErrors || emptyArray2;
                    }
                    setProjectErrors(projectErrors) {
                        this.projectErrors = projectErrors;
                    }
                    close() {
                        this.projectService.configFileExistenceInfoCache.forEach((_configFileExistenceInfo, canonicalConfigFilePath) => this.releaseParsedConfig(canonicalConfigFilePath));
                        this.projectErrors = void 0;
                        this.openFileWatchTriggered.clear();
                        this.compilerHost = void 0;
                        super.close();
                    }
                    /** @internal */
                    addExternalProjectReference() {
                        this.externalProjectRefCount++;
                    }
                    /** @internal */
                    deleteExternalProjectReference() {
                        this.externalProjectRefCount--;
                    }
                    /** @internal */
                    isSolution() {
                        return this.getRootFilesMap().size === 0 && !this.canConfigFileJsonReportNoInputFiles;
                    }
                    /**
                     * Find the configured project from the project references in project which contains the info directly
                     *
                     * @internal
                     */
                    getDefaultChildProjectFromProjectWithReferences(info) {
                        return forEachResolvedProjectReferenceProject(this, info.path, (child) => projectContainsInfoDirectly(child, info) ? child : void 0, 0 /* Find */);
                    }
                    /**
                     * Returns true if the project is needed by any of the open script info/external project
                     *
                     * @internal
                     */
                    hasOpenRef() {
                        var _a;
                        if (!!this.externalProjectRefCount) {
                            return true;
                        }
                        if (this.isClosed()) {
                            return false;
                        }
                        const configFileExistenceInfo = this.projectService.configFileExistenceInfoCache.get(this.canonicalConfigFilePath);
                        if (this.projectService.hasPendingProjectUpdate(this)) {
                            return !!((_a = configFileExistenceInfo.openFilesImpactedByConfigFile) == null ? void 0 : _a.size);
                        }
                        return !!configFileExistenceInfo.openFilesImpactedByConfigFile && forEachEntry(configFileExistenceInfo.openFilesImpactedByConfigFile, (_value, infoPath) => {
                            const info = this.projectService.getScriptInfoForPath(infoPath);
                            return this.containsScriptInfo(info) || !!forEachResolvedProjectReferenceProject(this, info.path, (child) => child.containsScriptInfo(info), 0 /* Find */);
                        }) || false;
                    }
                    /** @internal */
                    hasExternalProjectRef() {
                        return !!this.externalProjectRefCount;
                    }
                    getEffectiveTypeRoots() {
                        return getEffectiveTypeRoots(this.getCompilationSettings(), this) || [];
                    }
                    /** @internal */
                    updateErrorOnNoInputFiles(fileNames) {
                        updateErrorForNoInputFiles(fileNames, this.getConfigFilePath(), this.getCompilerOptions().configFile.configFileSpecs, this.projectErrors, this.canConfigFileJsonReportNoInputFiles);
                    }
                };
                ExternalProject2 = class extends Project3 {
                    /** @internal */
                    constructor(externalProjectName, projectService, documentRegistry, compilerOptions, lastFileExceededProgramSize, compileOnSaveEnabled, projectFilePath, watchOptions) {
                        super(externalProjectName, 2 /* External */, projectService, documentRegistry, 
                        /*hasExplicitListOfFiles*/
                        true, lastFileExceededProgramSize, compilerOptions, compileOnSaveEnabled, watchOptions, projectService.host, getDirectoryPath(projectFilePath || normalizeSlashes(externalProjectName)));
                        this.externalProjectName = externalProjectName;
                        this.compileOnSaveEnabled = compileOnSaveEnabled;
                        this.excludedFiles = [];
                        this.enableGlobalPlugins(this.getCompilerOptions());
                    }
                    updateGraph() {
                        const result = super.updateGraph();
                        this.projectService.sendProjectTelemetry(this);
                        return result;
                    }
                    getExcludedFiles() {
                        return this.excludedFiles;
                    }
                };
            }
        });
        // src/server/editorServices.ts
        function prepareConvertersForEnumLikeCompilerOptions(commandLineOptions) {
            const map2 = /* @__PURE__ */ new Map();
            for (const option of commandLineOptions) {
                if (typeof option.type === "object") {
                    const optionMap = option.type;
                    optionMap.forEach((value) => {
                        Debug.assert(typeof value === "number");
                    });
                    map2.set(option.name, optionMap);
                }
            }
            return map2;
        }
        function convertFormatOptions(protocolOptions) {
            if (isString(protocolOptions.indentStyle)) {
                protocolOptions.indentStyle = indentStyle.get(protocolOptions.indentStyle.toLowerCase());
                Debug.assert(protocolOptions.indentStyle !== void 0);
            }
            return protocolOptions;
        }
        function convertCompilerOptions(protocolOptions) {
            compilerOptionConverters.forEach((mappedValues, id) => {
                const propertyValue = protocolOptions[id];
                if (isString(propertyValue)) {
                    protocolOptions[id] = mappedValues.get(propertyValue.toLowerCase());
                }
            });
            return protocolOptions;
        }
        function convertWatchOptions(protocolOptions, currentDirectory) {
            let watchOptions;
            let errors;
            optionsForWatch.forEach((option) => {
                const propertyValue = protocolOptions[option.name];
                if (propertyValue === void 0)
                    return;
                const mappedValues = watchOptionsConverters.get(option.name);
                (watchOptions || (watchOptions = {}))[option.name] = mappedValues ? isString(propertyValue) ? mappedValues.get(propertyValue.toLowerCase()) : propertyValue : convertJsonOption(option, propertyValue, currentDirectory || "", errors || (errors = []));
            });
            return watchOptions && { watchOptions, errors };
        }
        function convertTypeAcquisition(protocolOptions) {
            let result;
            typeAcquisitionDeclarations.forEach((option) => {
                const propertyValue = protocolOptions[option.name];
                if (propertyValue === void 0)
                    return;
                (result || (result = {}))[option.name] = propertyValue;
            });
            return result;
        }
        function tryConvertScriptKindName(scriptKindName) {
            return isString(scriptKindName) ? convertScriptKindName(scriptKindName) : scriptKindName;
        }
        function convertScriptKindName(scriptKindName) {
            switch (scriptKindName) {
                case "JS":
                    return 1 /* JS */;
                case "JSX":
                    return 2 /* JSX */;
                case "TS":
                    return 3 /* TS */;
                case "TSX":
                    return 4 /* TSX */;
                default:
                    return 0 /* Unknown */;
            }
        }
        function convertUserPreferences(preferences) {
            const { lazyConfiguredProjectsFromExternalProject: _, ...userPreferences } = preferences;
            return userPreferences;
        }
        function findProjectByName(projectName, projects) {
            for (const proj of projects) {
                if (proj.getProjectName() === projectName) {
                    return proj;
                }
            }
        }
        function isOpenScriptInfo(infoOrFileNameOrConfig) {
            return !!infoOrFileNameOrConfig.containingProjects;
        }
        function isAncestorConfigFileInfo(infoOrFileNameOrConfig) {
            return !!infoOrFileNameOrConfig.configFileInfo;
        }
        function forEachResolvedProjectReferenceProject(project, fileName, cb, projectReferenceProjectLoadKind, reason) {
            var _a;
            const resolvedRefs = (_a = project.getCurrentProgram()) == null ? void 0 : _a.getResolvedProjectReferences();
            if (!resolvedRefs)
                return void 0;
            let seenResolvedRefs;
            const possibleDefaultRef = fileName ? project.getResolvedProjectReferenceToRedirect(fileName) : void 0;
            if (possibleDefaultRef) {
                const configFileName = toNormalizedPath(possibleDefaultRef.sourceFile.fileName);
                const child = project.projectService.findConfiguredProjectByProjectName(configFileName);
                if (child) {
                    const result = cb(child);
                    if (result)
                        return result;
                }
                else if (projectReferenceProjectLoadKind !== 0 /* Find */) {
                    seenResolvedRefs = /* @__PURE__ */ new Map();
                    const result = forEachResolvedProjectReferenceProjectWorker(resolvedRefs, project.getCompilerOptions(), (ref, loadKind) => possibleDefaultRef === ref ? callback(ref, loadKind) : void 0, projectReferenceProjectLoadKind, project.projectService, seenResolvedRefs);
                    if (result)
                        return result;
                    seenResolvedRefs.clear();
                }
            }
            return forEachResolvedProjectReferenceProjectWorker(resolvedRefs, project.getCompilerOptions(), (ref, loadKind) => possibleDefaultRef !== ref ? callback(ref, loadKind) : void 0, projectReferenceProjectLoadKind, project.projectService, seenResolvedRefs);
            function callback(ref, loadKind) {
                const configFileName = toNormalizedPath(ref.sourceFile.fileName);
                const child = project.projectService.findConfiguredProjectByProjectName(configFileName) || (loadKind === 0 /* Find */ ? void 0 : loadKind === 1 /* FindCreate */ ? project.projectService.createConfiguredProject(configFileName) : loadKind === 2 /* FindCreateLoad */ ? project.projectService.createAndLoadConfiguredProject(configFileName, reason) : Debug.assertNever(loadKind));
                return child && cb(child);
            }
        }
        function forEachResolvedProjectReferenceProjectWorker(resolvedProjectReferences, parentOptions, cb, projectReferenceProjectLoadKind, projectService, seenResolvedRefs) {
            const loadKind = parentOptions.disableReferencedProjectLoad ? 0 /* Find */ : projectReferenceProjectLoadKind;
            return forEach(resolvedProjectReferences, (ref) => {
                if (!ref)
                    return void 0;
                const configFileName = toNormalizedPath(ref.sourceFile.fileName);
                const canonicalPath = projectService.toCanonicalFileName(configFileName);
                const seenValue = seenResolvedRefs == null ? void 0 : seenResolvedRefs.get(canonicalPath);
                if (seenValue !== void 0 && seenValue >= loadKind) {
                    return void 0;
                }
                const result = cb(ref, loadKind);
                if (result) {
                    return result;
                }
                (seenResolvedRefs || (seenResolvedRefs = /* @__PURE__ */ new Map())).set(canonicalPath, loadKind);
                return ref.references && forEachResolvedProjectReferenceProjectWorker(ref.references, ref.commandLine.options, cb, loadKind, projectService, seenResolvedRefs);
            });
        }
        function forEachPotentialProjectReference(project, cb) {
            return project.potentialProjectReferences && forEachKey(project.potentialProjectReferences, cb);
        }
        function forEachAnyProjectReferenceKind(project, cb, cbProjectRef, cbPotentialProjectRef) {
            return project.getCurrentProgram() ? project.forEachResolvedProjectReference(cb) : project.isInitialLoadPending() ? forEachPotentialProjectReference(project, cbPotentialProjectRef) : forEach(project.getProjectReferences(), cbProjectRef);
        }
        function callbackRefProject(project, cb, refPath) {
            const refProject = refPath && project.projectService.configuredProjects.get(refPath);
            return refProject && cb(refProject);
        }
        function forEachReferencedProject(project, cb) {
            return forEachAnyProjectReferenceKind(project, (resolvedRef) => callbackRefProject(project, cb, resolvedRef.sourceFile.path), (projectRef) => callbackRefProject(project, cb, project.toPath(resolveProjectReferencePath(projectRef))), (potentialProjectRef) => callbackRefProject(project, cb, potentialProjectRef));
        }
        function getDetailWatchInfo(watchType, project) {
            return `${isString(project) ? `Config: ${project} ` : project ? `Project: ${project.getProjectName()} ` : ""}WatchType: ${watchType}`;
        }
        function isScriptInfoWatchedFromNodeModules(info) {
            return !info.isScriptOpen() && info.mTime !== void 0;
        }
        function projectContainsInfoDirectly(project, info) {
            return project.containsScriptInfo(info) && !project.isSourceOfProjectReferenceRedirect(info.path);
        }
        function updateProjectIfDirty(project) {
            project.invalidateResolutionsOfFailedLookupLocations();
            return project.dirty && project.updateGraph();
        }
        function setProjectOptionsUsed(project) {
            if (isConfiguredProject(project)) {
                project.projectOptions = true;
            }
        }
        function createProjectNameFactoryWithCounter(nameFactory) {
            let nextId = 1;
            return () => nameFactory(nextId++);
        }
        function getHostWatcherMap() {
            return { idToCallbacks: /* @__PURE__ */ new Map(), pathToId: /* @__PURE__ */ new Map() };
        }
        function createWatchFactoryHostUsingWatchEvents(service, canUseWatchEvents) {
            if (!canUseWatchEvents || !service.eventHandler || !service.session)
                return void 0;
            const watchedFiles = getHostWatcherMap();
            const watchedDirectories = getHostWatcherMap();
            const watchedDirectoriesRecursive = getHostWatcherMap();
            let ids = 1;
            service.session.addProtocolHandler("watchChange" /* WatchChange */, (req) => {
                onWatchChange(req.arguments);
                return { responseRequired: false };
            });
            return {
                watchFile: watchFile2,
                watchDirectory,
                getCurrentDirectory: () => service.host.getCurrentDirectory(),
                useCaseSensitiveFileNames: service.host.useCaseSensitiveFileNames
            };
            function watchFile2(path, callback) {
                return getOrCreateFileWatcher(watchedFiles, path, callback, (id) => ({ eventName: CreateFileWatcherEvent, data: { id, path } }));
            }
            function watchDirectory(path, callback, recursive) {
                return getOrCreateFileWatcher(recursive ? watchedDirectoriesRecursive : watchedDirectories, path, callback, (id) => ({ eventName: CreateDirectoryWatcherEvent, data: { id, path, recursive: !!recursive } }));
            }
            function getOrCreateFileWatcher({ pathToId, idToCallbacks }, path, callback, event) {
                const key = service.toPath(path);
                let id = pathToId.get(key);
                if (!id)
                    pathToId.set(key, id = ids++);
                let callbacks = idToCallbacks.get(id);
                if (!callbacks) {
                    idToCallbacks.set(id, callbacks = /* @__PURE__ */ new Set());
                    service.eventHandler(event(id));
                }
                callbacks.add(callback);
                return {
                    close() {
                        const callbacks2 = idToCallbacks.get(id);
                        if (!(callbacks2 == null ? void 0 : callbacks2.delete(callback)))
                            return;
                        if (callbacks2.size)
                            return;
                        idToCallbacks.delete(id);
                        pathToId.delete(key);
                        service.eventHandler({ eventName: CloseFileWatcherEvent, data: { id } });
                    }
                };
            }
            function onWatchChange({ id, path, eventType }) {
                onFileWatcherCallback(id, path, eventType);
                onDirectoryWatcherCallback(watchedDirectories, id, path, eventType);
                onDirectoryWatcherCallback(watchedDirectoriesRecursive, id, path, eventType);
            }
            function onFileWatcherCallback(id, eventPath, eventType) {
                var _a;
                (_a = watchedFiles.idToCallbacks.get(id)) == null ? void 0 : _a.forEach((callback) => {
                    const eventKind = eventType === "create" ? 0 /* Created */ : eventType === "delete" ? 2 /* Deleted */ : 1 /* Changed */;
                    callback(eventPath, eventKind);
                });
            }
            function onDirectoryWatcherCallback({ idToCallbacks }, id, eventPath, eventType) {
                var _a;
                if (eventType === "update")
                    return;
                (_a = idToCallbacks.get(id)) == null ? void 0 : _a.forEach((callback) => {
                    callback(eventPath);
                });
            }
        }
        function createIncompleteCompletionsCache() {
            let info;
            return {
                get() {
                    return info;
                },
                set(newInfo) {
                    info = newInfo;
                },
                clear() {
                    info = void 0;
                }
            };
        }
        function isConfigFile(config) {
            return config.kind !== void 0;
        }
        function printProjectWithoutFileNames(project) {
            project.print(
            /*writeProjectFileNames*/
            false, 
            /*writeFileExplaination*/
            false, 
            /*writeFileVersionAndText*/
            false);
        }
        var maxProgramSizeForNonTsFiles, maxFileSize, ProjectsUpdatedInBackgroundEvent, ProjectLoadingStartEvent, ProjectLoadingFinishEvent, LargeFileReferencedEvent, ConfigFileDiagEvent, ProjectLanguageServiceStateEvent, ProjectInfoTelemetryEvent, OpenFileInfoTelemetryEvent, CreateFileWatcherEvent, CreateDirectoryWatcherEvent, CloseFileWatcherEvent, ensureProjectForOpenFileSchedule, compilerOptionConverters, watchOptionsConverters, indentStyle, defaultTypeSafeList, fileNamePropertyReader, externalFilePropertyReader, noopConfigFileWatcher, ProjectReferenceProjectLoadKind, _ProjectService, ProjectService3;
        var init_editorServices = __esm({
            "src/server/editorServices.ts"() {
                "use strict";
                init_ts7();
                init_ts_server3();
                init_protocol();
                maxProgramSizeForNonTsFiles = 20 * 1024 * 1024;
                maxFileSize = 4 * 1024 * 1024;
                ProjectsUpdatedInBackgroundEvent = "projectsUpdatedInBackground";
                ProjectLoadingStartEvent = "projectLoadingStart";
                ProjectLoadingFinishEvent = "projectLoadingFinish";
                LargeFileReferencedEvent = "largeFileReferenced";
                ConfigFileDiagEvent = "configFileDiag";
                ProjectLanguageServiceStateEvent = "projectLanguageServiceState";
                ProjectInfoTelemetryEvent = "projectInfo";
                OpenFileInfoTelemetryEvent = "openFileInfo";
                CreateFileWatcherEvent = "createFileWatcher";
                CreateDirectoryWatcherEvent = "createDirectoryWatcher";
                CloseFileWatcherEvent = "closeFileWatcher";
                ensureProjectForOpenFileSchedule = "*ensureProjectForOpenFiles*";
                compilerOptionConverters = prepareConvertersForEnumLikeCompilerOptions(optionDeclarations);
                watchOptionsConverters = prepareConvertersForEnumLikeCompilerOptions(optionsForWatch);
                indentStyle = new Map(Object.entries({
                    none: 0 /* None */,
                    block: 1 /* Block */,
                    smart: 2 /* Smart */
                }));
                defaultTypeSafeList = {
                    "jquery": {
                        // jquery files can have names like "jquery-1.10.2.min.js" (or "jquery.intellisense.js")
                        match: /jquery(-[\d.]+)?(\.intellisense)?(\.min)?\.js$/i,
                        types: ["jquery"]
                    },
                    "WinJS": {
                        // e.g. c:/temp/UWApp1/lib/winjs-4.0.1/js/base.js
                        match: /^(.*\/winjs-[.\d]+)\/js\/base\.js$/i,
                        // If the winjs/base.js file is found..
                        exclude: [["^", 1, "/.*"]],
                        // ..then exclude all files under the winjs folder
                        types: ["winjs"]
                        // And fetch the @types package for WinJS
                    },
                    "Kendo": {
                        // e.g. /Kendo3/wwwroot/lib/kendo/kendo.all.min.js
                        match: /^(.*\/kendo(-ui)?)\/kendo\.all(\.min)?\.js$/i,
                        exclude: [["^", 1, "/.*"]],
                        types: ["kendo-ui"]
                    },
                    "Office Nuget": {
                        // e.g. /scripts/Office/1/excel-15.debug.js
                        match: /^(.*\/office\/1)\/excel-\d+\.debug\.js$/i,
                        // Office NuGet package is installed under a "1/office" folder
                        exclude: [["^", 1, "/.*"]],
                        // Exclude that whole folder if the file indicated above is found in it
                        types: ["office"]
                        // @types package to fetch instead
                    },
                    "References": {
                        match: /^(.*\/_references\.js)$/i,
                        exclude: [["^", 1, "$"]]
                    }
                };
                fileNamePropertyReader = {
                    getFileName: (x) => x,
                    getScriptKind: (fileName, extraFileExtensions) => {
                        let result;
                        if (extraFileExtensions) {
                            const fileExtension = getAnyExtensionFromPath(fileName);
                            if (fileExtension) {
                                some(extraFileExtensions, (info) => {
                                    if (info.extension === fileExtension) {
                                        result = info.scriptKind;
                                        return true;
                                    }
                                    return false;
                                });
                            }
                        }
                        return result;
                    },
                    hasMixedContent: (fileName, extraFileExtensions) => some(extraFileExtensions, (ext) => ext.isMixedContent && fileExtensionIs(fileName, ext.extension))
                };
                externalFilePropertyReader = {
                    getFileName: (x) => x.fileName,
                    getScriptKind: (x) => tryConvertScriptKindName(x.scriptKind),
                    // TODO: GH#18217
                    hasMixedContent: (x) => !!x.hasMixedContent
                };
                noopConfigFileWatcher = { close: noop };
                ProjectReferenceProjectLoadKind = /* @__PURE__ */ ((ProjectReferenceProjectLoadKind2) => {
                    ProjectReferenceProjectLoadKind2[ProjectReferenceProjectLoadKind2["Find"] = 0] = "Find";
                    ProjectReferenceProjectLoadKind2[ProjectReferenceProjectLoadKind2["FindCreate"] = 1] = "FindCreate";
                    ProjectReferenceProjectLoadKind2[ProjectReferenceProjectLoadKind2["FindCreateLoad"] = 2] = "FindCreateLoad";
                    return ProjectReferenceProjectLoadKind2;
                })(ProjectReferenceProjectLoadKind || {});
                _ProjectService = class _ProjectService {
                    constructor(opts) {
                        /**
                         * Container of all known scripts
                         *
                         * @internal
                         */
                        this.filenameToScriptInfo = /* @__PURE__ */ new Map();
                        this.nodeModulesWatchers = /* @__PURE__ */ new Map();
                        /**
                         * Contains all the deleted script info's version information so that
                         * it does not reset when creating script info again
                         * (and could have potentially collided with version where contents mismatch)
                         */
                        this.filenameToScriptInfoVersion = /* @__PURE__ */ new Map();
                        // Set of all '.js' files ever opened.
                        this.allJsFilesForOpenFileTelemetry = /* @__PURE__ */ new Map();
                        /**
                         * maps external project file name to list of config files that were the part of this project
                         */
                        this.externalProjectToConfiguredProjectMap = /* @__PURE__ */ new Map();
                        /**
                         * external projects (configuration and list of root files is not controlled by tsserver)
                         */
                        this.externalProjects = [];
                        /**
                         * projects built from openFileRoots
                         */
                        this.inferredProjects = [];
                        /**
                         * projects specified by a tsconfig.json file
                         */
                        this.configuredProjects = /* @__PURE__ */ new Map();
                        /** @internal */
                        this.newInferredProjectName = createProjectNameFactoryWithCounter(makeInferredProjectName);
                        /** @internal */
                        this.newAutoImportProviderProjectName = createProjectNameFactoryWithCounter(makeAutoImportProviderProjectName);
                        /** @internal */
                        this.newAuxiliaryProjectName = createProjectNameFactoryWithCounter(makeAuxiliaryProjectName);
                        /**
                         * Open files: with value being project root path, and key being Path of the file that is open
                         */
                        this.openFiles = /* @__PURE__ */ new Map();
                        /** @internal */
                        this.configFileForOpenFiles = /* @__PURE__ */ new Map();
                        /**
                         * Map of open files that are opened without complete path but have projectRoot as current directory
                         */
                        this.openFilesWithNonRootedDiskPath = /* @__PURE__ */ new Map();
                        this.compilerOptionsForInferredProjectsPerProjectRoot = /* @__PURE__ */ new Map();
                        this.watchOptionsForInferredProjectsPerProjectRoot = /* @__PURE__ */ new Map();
                        this.typeAcquisitionForInferredProjectsPerProjectRoot = /* @__PURE__ */ new Map();
                        /**
                         * Project size for configured or external projects
                         */
                        this.projectToSizeMap = /* @__PURE__ */ new Map();
                        /**
                         * This is a map of config file paths existence that doesnt need query to disk
                         * - The entry can be present because there is inferred project that needs to watch addition of config file to directory
                         *   In this case the exists could be true/false based on config file is present or not
                         * - Or it is present if we have configured project open with config file at that location
                         *   In this case the exists property is always true
                         *
                         * @internal
                         */
                        this.configFileExistenceInfoCache = /* @__PURE__ */ new Map();
                        this.safelist = defaultTypeSafeList;
                        this.legacySafelist = /* @__PURE__ */ new Map();
                        this.pendingProjectUpdates = /* @__PURE__ */ new Map();
                        /** @internal */
                        this.pendingEnsureProjectForOpenFiles = false;
                        /** Tracks projects that we have already sent telemetry for. */
                        this.seenProjects = /* @__PURE__ */ new Map();
                        /** @internal */
                        this.sharedExtendedConfigFileWatchers = /* @__PURE__ */ new Map();
                        /** @internal */
                        this.extendedConfigCache = /* @__PURE__ */ new Map();
                        /** @internal */
                        this.baseline = noop;
                        /** @internal */
                        this.verifyDocumentRegistry = noop;
                        /** @internal */
                        this.verifyProgram = noop;
                        /** @internal */
                        this.onProjectCreation = noop;
                        var _a;
                        this.host = opts.host;
                        this.logger = opts.logger;
                        this.cancellationToken = opts.cancellationToken;
                        this.useSingleInferredProject = opts.useSingleInferredProject;
                        this.useInferredProjectPerProjectRoot = opts.useInferredProjectPerProjectRoot;
                        this.typingsInstaller = opts.typingsInstaller || nullTypingsInstaller;
                        this.throttleWaitMilliseconds = opts.throttleWaitMilliseconds;
                        this.eventHandler = opts.eventHandler;
                        this.suppressDiagnosticEvents = opts.suppressDiagnosticEvents;
                        this.globalPlugins = opts.globalPlugins || emptyArray2;
                        this.pluginProbeLocations = opts.pluginProbeLocations || emptyArray2;
                        this.allowLocalPluginLoads = !!opts.allowLocalPluginLoads;
                        this.typesMapLocation = opts.typesMapLocation === void 0 ? combinePaths(getDirectoryPath(this.getExecutingFilePath()), "typesMap.json") : opts.typesMapLocation;
                        this.session = opts.session;
                        this.jsDocParsingMode = opts.jsDocParsingMode;
                        if (opts.serverMode !== void 0) {
                            this.serverMode = opts.serverMode;
                        }
                        else {
                            this.serverMode = 0 /* Semantic */;
                        }
                        if (this.host.realpath) {
                            this.realpathToScriptInfos = createMultiMap();
                        }
                        this.currentDirectory = toNormalizedPath(this.host.getCurrentDirectory());
                        this.toCanonicalFileName = createGetCanonicalFileName(this.host.useCaseSensitiveFileNames);
                        this.globalCacheLocationDirectoryPath = this.typingsInstaller.globalTypingsCacheLocation ? ensureTrailingDirectorySeparator(this.toPath(this.typingsInstaller.globalTypingsCacheLocation)) : void 0;
                        this.throttledOperations = new ThrottledOperations(this.host, this.logger);
                        if (this.typesMapLocation) {
                            this.loadTypesMap();
                        }
                        else {
                            this.logger.info("No types map provided; using the default");
                        }
                        this.typingsInstaller.attach(this);
                        this.typingsCache = new TypingsCache(this.typingsInstaller);
                        this.hostConfiguration = {
                            formatCodeOptions: getDefaultFormatCodeSettings(this.host.newLine),
                            preferences: emptyOptions,
                            hostInfo: "Unknown host",
                            extraFileExtensions: []
                        };
                        this.documentRegistry = createDocumentRegistryInternal(this.host.useCaseSensitiveFileNames, this.currentDirectory, this.jsDocParsingMode, this);
                        const watchLogLevel = this.logger.hasLevel(3 /* verbose */) ? 2 /* Verbose */ : this.logger.loggingEnabled() ? 1 /* TriggerOnly */ : 0 /* None */;
                        const log = watchLogLevel !== 0 /* None */ ? (s) => this.logger.info(s) : noop;
                        this.packageJsonCache = createPackageJsonCache(this);
                        this.watchFactory = this.serverMode !== 0 /* Semantic */ ? {
                            watchFile: returnNoopFileWatcher,
                            watchDirectory: returnNoopFileWatcher
                        } : getWatchFactory(createWatchFactoryHostUsingWatchEvents(this, opts.canUseWatchEvents) || this.host, watchLogLevel, log, getDetailWatchInfo);
                        (_a = opts.incrementalVerifier) == null ? void 0 : _a.call(opts, this);
                    }
                    toPath(fileName) {
                        return toPath(fileName, this.currentDirectory, this.toCanonicalFileName);
                    }
                    /** @internal */
                    getExecutingFilePath() {
                        return this.getNormalizedAbsolutePath(this.host.getExecutingFilePath());
                    }
                    /** @internal */
                    getNormalizedAbsolutePath(fileName) {
                        return getNormalizedAbsolutePath(fileName, this.host.getCurrentDirectory());
                    }
                    /** @internal */
                    setDocument(key, path, sourceFile) {
                        const info = Debug.checkDefined(this.getScriptInfoForPath(path));
                        info.cacheSourceFile = { key, sourceFile };
                    }
                    /** @internal */
                    getDocument(key, path) {
                        const info = this.getScriptInfoForPath(path);
                        return info && info.cacheSourceFile && info.cacheSourceFile.key === key ? info.cacheSourceFile.sourceFile : void 0;
                    }
                    /** @internal */
                    ensureInferredProjectsUpToDate_TestOnly() {
                        this.ensureProjectStructuresUptoDate();
                    }
                    /** @internal */
                    getCompilerOptionsForInferredProjects() {
                        return this.compilerOptionsForInferredProjects;
                    }
                    /** @internal */
                    onUpdateLanguageServiceStateForProject(project, languageServiceEnabled) {
                        if (!this.eventHandler) {
                            return;
                        }
                        const event = {
                            eventName: ProjectLanguageServiceStateEvent,
                            data: { project, languageServiceEnabled }
                        };
                        this.eventHandler(event);
                    }
                    loadTypesMap() {
                        try {
                            const fileContent = this.host.readFile(this.typesMapLocation);
                            if (fileContent === void 0) {
                                this.logger.info(`Provided types map file "${this.typesMapLocation}" doesn't exist`);
                                return;
                            }
                            const raw = JSON.parse(fileContent);
                            for (const k of Object.keys(raw.typesMap)) {
                                raw.typesMap[k].match = new RegExp(raw.typesMap[k].match, "i");
                            }
                            this.safelist = raw.typesMap;
                            for (const key in raw.simpleMap) {
                                if (hasProperty(raw.simpleMap, key)) {
                                    this.legacySafelist.set(key, raw.simpleMap[key].toLowerCase());
                                }
                            }
                        }
                        catch (e) {
                            this.logger.info(`Error loading types map: ${e}`);
                            this.safelist = defaultTypeSafeList;
                            this.legacySafelist.clear();
                        }
                    }
                    // eslint-disable-line @typescript-eslint/unified-signatures
                    updateTypingsForProject(response) {
                        const project = this.findProject(response.projectName);
                        if (!project) {
                            return;
                        }
                        switch (response.kind) {
                            case ActionSet:
                                project.updateTypingFiles(this.typingsCache.updateTypingsForProject(response.projectName, response.compilerOptions, response.typeAcquisition, response.unresolvedImports, response.typings));
                                return;
                            case ActionInvalidate:
                                this.typingsCache.enqueueInstallTypingsForProject(project, project.lastCachedUnresolvedImportsList, 
                                /*forceRefresh*/
                                true);
                                return;
                        }
                    }
                    /** @internal */
                    watchTypingLocations(response) {
                        var _a;
                        (_a = this.findProject(response.projectName)) == null ? void 0 : _a.watchTypingLocations(response.files);
                    }
                    /** @internal */
                    delayEnsureProjectForOpenFiles() {
                        if (!this.openFiles.size)
                            return;
                        this.pendingEnsureProjectForOpenFiles = true;
                        this.throttledOperations.schedule(ensureProjectForOpenFileSchedule, 
                        /*delay*/
                        2500, () => {
                            if (this.pendingProjectUpdates.size !== 0) {
                                this.delayEnsureProjectForOpenFiles();
                            }
                            else {
                                if (this.pendingEnsureProjectForOpenFiles) {
                                    this.ensureProjectForOpenFiles();
                                    this.sendProjectsUpdatedInBackgroundEvent();
                                }
                            }
                        });
                    }
                    delayUpdateProjectGraph(project) {
                        project.markAsDirty();
                        if (isBackgroundProject(project))
                            return;
                        const projectName = project.getProjectName();
                        this.pendingProjectUpdates.set(projectName, project);
                        this.throttledOperations.schedule(projectName, 
                        /*delay*/
                        250, () => {
                            if (this.pendingProjectUpdates.delete(projectName)) {
                                updateProjectIfDirty(project);
                            }
                        });
                    }
                    /** @internal */
                    hasPendingProjectUpdate(project) {
                        return this.pendingProjectUpdates.has(project.getProjectName());
                    }
                    /** @internal */
                    sendProjectsUpdatedInBackgroundEvent() {
                        if (!this.eventHandler) {
                            return;
                        }
                        const event = {
                            eventName: ProjectsUpdatedInBackgroundEvent,
                            data: {
                                openFiles: arrayFrom(this.openFiles.keys(), (path) => this.getScriptInfoForPath(path).fileName)
                            }
                        };
                        this.eventHandler(event);
                    }
                    /** @internal */
                    sendLargeFileReferencedEvent(file, fileSize) {
                        if (!this.eventHandler) {
                            return;
                        }
                        const event = {
                            eventName: LargeFileReferencedEvent,
                            data: { file, fileSize, maxFileSize }
                        };
                        this.eventHandler(event);
                    }
                    /** @internal */
                    sendProjectLoadingStartEvent(project, reason) {
                        if (!this.eventHandler) {
                            return;
                        }
                        project.sendLoadingProjectFinish = true;
                        const event = {
                            eventName: ProjectLoadingStartEvent,
                            data: { project, reason }
                        };
                        this.eventHandler(event);
                    }
                    /** @internal */
                    sendProjectLoadingFinishEvent(project) {
                        if (!this.eventHandler || !project.sendLoadingProjectFinish) {
                            return;
                        }
                        project.sendLoadingProjectFinish = false;
                        const event = {
                            eventName: ProjectLoadingFinishEvent,
                            data: { project }
                        };
                        this.eventHandler(event);
                    }
                    /** @internal */
                    sendPerformanceEvent(kind, durationMs) {
                        if (this.performanceEventHandler) {
                            this.performanceEventHandler({ kind, durationMs });
                        }
                    }
                    /** @internal */
                    delayUpdateProjectGraphAndEnsureProjectStructureForOpenFiles(project) {
                        this.delayUpdateProjectGraph(project);
                        this.delayEnsureProjectForOpenFiles();
                    }
                    delayUpdateProjectGraphs(projects, clearSourceMapperCache) {
                        if (projects.length) {
                            for (const project of projects) {
                                if (clearSourceMapperCache)
                                    project.clearSourceMapperCache();
                                this.delayUpdateProjectGraph(project);
                            }
                            this.delayEnsureProjectForOpenFiles();
                        }
                    }
                    setCompilerOptionsForInferredProjects(projectCompilerOptions, projectRootPath) {
                        Debug.assert(projectRootPath === void 0 || this.useInferredProjectPerProjectRoot, "Setting compiler options per project root path is only supported when useInferredProjectPerProjectRoot is enabled");
                        const compilerOptions = convertCompilerOptions(projectCompilerOptions);
                        const watchOptions = convertWatchOptions(projectCompilerOptions, projectRootPath);
                        const typeAcquisition = convertTypeAcquisition(projectCompilerOptions);
                        compilerOptions.allowNonTsExtensions = true;
                        const canonicalProjectRootPath = projectRootPath && this.toCanonicalFileName(projectRootPath);
                        if (canonicalProjectRootPath) {
                            this.compilerOptionsForInferredProjectsPerProjectRoot.set(canonicalProjectRootPath, compilerOptions);
                            this.watchOptionsForInferredProjectsPerProjectRoot.set(canonicalProjectRootPath, watchOptions || false);
                            this.typeAcquisitionForInferredProjectsPerProjectRoot.set(canonicalProjectRootPath, typeAcquisition);
                        }
                        else {
                            this.compilerOptionsForInferredProjects = compilerOptions;
                            this.watchOptionsForInferredProjects = watchOptions;
                            this.typeAcquisitionForInferredProjects = typeAcquisition;
                        }
                        for (const project of this.inferredProjects) {
                            if (canonicalProjectRootPath ? project.projectRootPath === canonicalProjectRootPath : !project.projectRootPath || !this.compilerOptionsForInferredProjectsPerProjectRoot.has(project.projectRootPath)) {
                                project.setCompilerOptions(compilerOptions);
                                project.setTypeAcquisition(typeAcquisition);
                                project.setWatchOptions(watchOptions == null ? void 0 : watchOptions.watchOptions);
                                project.setProjectErrors(watchOptions == null ? void 0 : watchOptions.errors);
                                project.compileOnSaveEnabled = compilerOptions.compileOnSave;
                                project.markAsDirty();
                                this.delayUpdateProjectGraph(project);
                            }
                        }
                        this.delayEnsureProjectForOpenFiles();
                    }
                    findProject(projectName) {
                        if (projectName === void 0) {
                            return void 0;
                        }
                        if (isInferredProjectName(projectName)) {
                            return findProjectByName(projectName, this.inferredProjects);
                        }
                        return this.findExternalProjectByProjectName(projectName) || this.findConfiguredProjectByProjectName(toNormalizedPath(projectName));
                    }
                    /** @internal */
                    forEachProject(cb) {
                        this.externalProjects.forEach(cb);
                        this.configuredProjects.forEach(cb);
                        this.inferredProjects.forEach(cb);
                    }
                    /** @internal */
                    forEachEnabledProject(cb) {
                        this.forEachProject((project) => {
                            if (!project.isOrphan() && project.languageServiceEnabled) {
                                cb(project);
                            }
                        });
                    }
                    getDefaultProjectForFile(fileName, ensureProject) {
                        return ensureProject ? this.ensureDefaultProjectForFile(fileName) : this.tryGetDefaultProjectForFile(fileName);
                    }
                    /** @internal */
                    tryGetDefaultProjectForFile(fileNameOrScriptInfo) {
                        const scriptInfo = isString(fileNameOrScriptInfo) ? this.getScriptInfoForNormalizedPath(fileNameOrScriptInfo) : fileNameOrScriptInfo;
                        return scriptInfo && !scriptInfo.isOrphan() ? scriptInfo.getDefaultProject() : void 0;
                    }
                    /** @internal */
                    ensureDefaultProjectForFile(fileNameOrScriptInfo) {
                        return this.tryGetDefaultProjectForFile(fileNameOrScriptInfo) || this.doEnsureDefaultProjectForFile(fileNameOrScriptInfo);
                    }
                    doEnsureDefaultProjectForFile(fileNameOrScriptInfo) {
                        this.ensureProjectStructuresUptoDate();
                        const scriptInfo = isString(fileNameOrScriptInfo) ? this.getScriptInfoForNormalizedPath(fileNameOrScriptInfo) : fileNameOrScriptInfo;
                        return scriptInfo ? scriptInfo.getDefaultProject() : (this.logErrorForScriptInfoNotFound(isString(fileNameOrScriptInfo) ? fileNameOrScriptInfo : fileNameOrScriptInfo.fileName), Errors.ThrowNoProject());
                    }
                    getScriptInfoEnsuringProjectsUptoDate(uncheckedFileName) {
                        this.ensureProjectStructuresUptoDate();
                        return this.getScriptInfo(uncheckedFileName);
                    }
                    /**
                     * Ensures the project structures are upto date
                     * This means,
                     * - we go through all the projects and update them if they are dirty
                     * - if updates reflect some change in structure or there was pending request to ensure projects for open files
                     *   ensure that each open script info has project
                     */
                    ensureProjectStructuresUptoDate() {
                        let hasChanges = this.pendingEnsureProjectForOpenFiles;
                        this.pendingProjectUpdates.clear();
                        const updateGraph = (project) => {
                            hasChanges = updateProjectIfDirty(project) || hasChanges;
                        };
                        this.externalProjects.forEach(updateGraph);
                        this.configuredProjects.forEach(updateGraph);
                        this.inferredProjects.forEach(updateGraph);
                        if (hasChanges) {
                            this.ensureProjectForOpenFiles();
                        }
                    }
                    getFormatCodeOptions(file) {
                        const info = this.getScriptInfoForNormalizedPath(file);
                        return info && info.getFormatCodeSettings() || this.hostConfiguration.formatCodeOptions;
                    }
                    getPreferences(file) {
                        const info = this.getScriptInfoForNormalizedPath(file);
                        return { ...this.hostConfiguration.preferences, ...info && info.getPreferences() };
                    }
                    getHostFormatCodeOptions() {
                        return this.hostConfiguration.formatCodeOptions;
                    }
                    getHostPreferences() {
                        return this.hostConfiguration.preferences;
                    }
                    onSourceFileChanged(info, eventKind) {
                        if (eventKind === 2 /* Deleted */) {
                            this.handleDeletedFile(info);
                        }
                        else if (!info.isScriptOpen()) {
                            info.delayReloadNonMixedContentFile();
                            this.delayUpdateProjectGraphs(info.containingProjects, 
                            /*clearSourceMapperCache*/
                            false);
                            this.handleSourceMapProjects(info);
                        }
                    }
                    handleSourceMapProjects(info) {
                        if (info.sourceMapFilePath) {
                            if (isString(info.sourceMapFilePath)) {
                                const sourceMapFileInfo = this.getScriptInfoForPath(info.sourceMapFilePath);
                                this.delayUpdateSourceInfoProjects(sourceMapFileInfo && sourceMapFileInfo.sourceInfos);
                            }
                            else {
                                this.delayUpdateSourceInfoProjects(info.sourceMapFilePath.sourceInfos);
                            }
                        }
                        this.delayUpdateSourceInfoProjects(info.sourceInfos);
                        if (info.declarationInfoPath) {
                            this.delayUpdateProjectsOfScriptInfoPath(info.declarationInfoPath);
                        }
                    }
                    delayUpdateSourceInfoProjects(sourceInfos) {
                        if (sourceInfos) {
                            sourceInfos.forEach((_value, path) => this.delayUpdateProjectsOfScriptInfoPath(path));
                        }
                    }
                    delayUpdateProjectsOfScriptInfoPath(path) {
                        const info = this.getScriptInfoForPath(path);
                        if (info) {
                            this.delayUpdateProjectGraphs(info.containingProjects, 
                            /*clearSourceMapperCache*/
                            true);
                        }
                    }
                    handleDeletedFile(info) {
                        this.stopWatchingScriptInfo(info);
                        if (!info.isScriptOpen()) {
                            this.deleteScriptInfo(info);
                            const containingProjects = info.containingProjects.slice();
                            info.detachAllProjects();
                            this.delayUpdateProjectGraphs(containingProjects, 
                            /*clearSourceMapperCache*/
                            false);
                            this.handleSourceMapProjects(info);
                            info.closeSourceMapFileWatcher();
                            if (info.declarationInfoPath) {
                                const declarationInfo = this.getScriptInfoForPath(info.declarationInfoPath);
                                if (declarationInfo) {
                                    declarationInfo.sourceMapFilePath = void 0;
                                }
                            }
                        }
                    }
                    /**
                     * This is to watch whenever files are added or removed to the wildcard directories
                     *
                     * @internal
                     */
                    watchWildcardDirectory(directory, flags, configFileName, config) {
                        let watcher = this.watchFactory.watchDirectory(directory, (fileOrDirectory) => {
                            const fileOrDirectoryPath = this.toPath(fileOrDirectory);
                            const fsResult = config.cachedDirectoryStructureHost.addOrDeleteFileOrDirectory(fileOrDirectory, fileOrDirectoryPath);
                            if (getBaseFileName(fileOrDirectoryPath) === "package.json" && !isInsideNodeModules(fileOrDirectoryPath) && (fsResult && fsResult.fileExists || !fsResult && this.host.fileExists(fileOrDirectory))) {
                                const file = this.getNormalizedAbsolutePath(fileOrDirectory);
                                this.logger.info(`Config: ${configFileName} Detected new package.json: ${file}`);
                                this.packageJsonCache.addOrUpdate(file, fileOrDirectoryPath);
                                this.watchPackageJsonFile(file, fileOrDirectoryPath, result);
                            }
                            const configuredProjectForConfig = this.findConfiguredProjectByProjectName(configFileName);
                            if (isIgnoredFileFromWildCardWatching({
                                watchedDirPath: this.toPath(directory),
                                fileOrDirectory,
                                fileOrDirectoryPath,
                                configFileName,
                                extraFileExtensions: this.hostConfiguration.extraFileExtensions,
                                currentDirectory: this.currentDirectory,
                                options: config.parsedCommandLine.options,
                                program: (configuredProjectForConfig == null ? void 0 : configuredProjectForConfig.getCurrentProgram()) || config.parsedCommandLine.fileNames,
                                useCaseSensitiveFileNames: this.host.useCaseSensitiveFileNames,
                                writeLog: (s) => this.logger.info(s),
                                toPath: (s) => this.toPath(s),
                                getScriptKind: configuredProjectForConfig ? (fileName) => configuredProjectForConfig.getScriptKind(fileName) : void 0
                            }))
                                return;
                            if (config.updateLevel !== 2 /* Full */)
                                config.updateLevel = 1 /* RootNamesAndUpdate */;
                            config.projects.forEach((watchWildcardDirectories, projectCanonicalPath) => {
                                if (!watchWildcardDirectories)
                                    return;
                                const project = this.getConfiguredProjectByCanonicalConfigFilePath(projectCanonicalPath);
                                if (!project)
                                    return;
                                const updateLevel = configuredProjectForConfig === project ? 1 /* RootNamesAndUpdate */ : 0 /* Update */;
                                if (project.pendingUpdateLevel !== void 0 && project.pendingUpdateLevel > updateLevel)
                                    return;
                                if (this.openFiles.has(fileOrDirectoryPath)) {
                                    const info = Debug.checkDefined(this.getScriptInfoForPath(fileOrDirectoryPath));
                                    if (info.isAttached(project)) {
                                        const loadLevelToSet = Math.max(updateLevel, project.openFileWatchTriggered.get(fileOrDirectoryPath) || 0 /* Update */);
                                        project.openFileWatchTriggered.set(fileOrDirectoryPath, loadLevelToSet);
                                    }
                                    else {
                                        project.pendingUpdateLevel = updateLevel;
                                        this.delayUpdateProjectGraphAndEnsureProjectStructureForOpenFiles(project);
                                    }
                                }
                                else {
                                    project.pendingUpdateLevel = updateLevel;
                                    this.delayUpdateProjectGraphAndEnsureProjectStructureForOpenFiles(project);
                                }
                            });
                        }, flags, this.getWatchOptionsFromProjectWatchOptions(config.parsedCommandLine.watchOptions), WatchType.WildcardDirectory, configFileName);
                        const result = {
                            packageJsonWatches: void 0,
                            close() {
                                var _a;
                                if (watcher) {
                                    watcher.close();
                                    watcher = void 0;
                                    (_a = result.packageJsonWatches) == null ? void 0 : _a.forEach((watcher2) => {
                                        watcher2.projects.delete(result);
                                        watcher2.close();
                                    });
                                    result.packageJsonWatches = void 0;
                                }
                            }
                        };
                        return result;
                    }
                    /** @internal */
                    delayUpdateProjectsFromParsedConfigOnConfigFileChange(canonicalConfigFilePath, loadReason) {
                        const configFileExistenceInfo = this.configFileExistenceInfoCache.get(canonicalConfigFilePath);
                        if (!(configFileExistenceInfo == null ? void 0 : configFileExistenceInfo.config))
                            return false;
                        let scheduledAnyProjectUpdate = false;
                        configFileExistenceInfo.config.updateLevel = 2 /* Full */;
                        configFileExistenceInfo.config.projects.forEach((_watchWildcardDirectories, projectCanonicalPath) => {
                            const project = this.getConfiguredProjectByCanonicalConfigFilePath(projectCanonicalPath);
                            if (!project)
                                return;
                            scheduledAnyProjectUpdate = true;
                            if (projectCanonicalPath === canonicalConfigFilePath) {
                                if (project.isInitialLoadPending())
                                    return;
                                project.pendingUpdateLevel = 2 /* Full */;
                                project.pendingUpdateReason = loadReason;
                                this.delayUpdateProjectGraph(project);
                            }
                            else {
                                project.resolutionCache.removeResolutionsFromProjectReferenceRedirects(this.toPath(canonicalConfigFilePath));
                                this.delayUpdateProjectGraph(project);
                            }
                        });
                        return scheduledAnyProjectUpdate;
                    }
                    /** @internal */
                    onConfigFileChanged(canonicalConfigFilePath, eventKind) {
                        var _a;
                        const configFileExistenceInfo = this.configFileExistenceInfoCache.get(canonicalConfigFilePath);
                        if (eventKind === 2 /* Deleted */) {
                            configFileExistenceInfo.exists = false;
                            const project = ((_a = configFileExistenceInfo.config) == null ? void 0 : _a.projects.has(canonicalConfigFilePath)) ? this.getConfiguredProjectByCanonicalConfigFilePath(canonicalConfigFilePath) : void 0;
                            if (project)
                                this.removeProject(project);
                        }
                        else {
                            configFileExistenceInfo.exists = true;
                        }
                        this.delayUpdateProjectsFromParsedConfigOnConfigFileChange(canonicalConfigFilePath, "Change in config file detected");
                        this.reloadConfiguredProjectForFiles(configFileExistenceInfo.openFilesImpactedByConfigFile, 
                        /*clearSemanticCache*/
                        false, 
                        /*delayReload*/
                        true, eventKind !== 2 /* Deleted */ ? identity : (
                        // Reload open files if they are root of inferred project
                        returnTrue), 
                        // Reload all the open files impacted by config file
                        "Change in config file detected");
                        this.delayEnsureProjectForOpenFiles();
                    }
                    removeProject(project) {
                        this.logger.info("`remove Project::");
                        project.print(
                        /*writeProjectFileNames*/
                        true, 
                        /*writeFileExplaination*/
                        true, 
                        /*writeFileVersionAndText*/
                        false);
                        project.close();
                        if (Debug.shouldAssert(1 /* Normal */)) {
                            this.filenameToScriptInfo.forEach((info) => Debug.assert(!info.isAttached(project), "Found script Info still attached to project", () => `${project.projectName}: ScriptInfos still attached: ${JSON.stringify(arrayFrom(mapDefinedIterator(this.filenameToScriptInfo.values(), (info2) => info2.isAttached(project) ? {
                                fileName: info2.fileName,
                                projects: info2.containingProjects.map((p) => p.projectName),
                                hasMixedContent: info2.hasMixedContent
                            } : void 0)), 
                            /*replacer*/
                            void 0, " ")}`));
                        }
                        this.pendingProjectUpdates.delete(project.getProjectName());
                        switch (project.projectKind) {
                            case 2 /* External */:
                                unorderedRemoveItem(this.externalProjects, project);
                                this.projectToSizeMap.delete(project.getProjectName());
                                break;
                            case 1 /* Configured */:
                                this.configuredProjects.delete(project.canonicalConfigFilePath);
                                this.projectToSizeMap.delete(project.canonicalConfigFilePath);
                                break;
                            case 0 /* Inferred */:
                                unorderedRemoveItem(this.inferredProjects, project);
                                break;
                        }
                    }
                    /** @internal */
                    assignOrphanScriptInfoToInferredProject(info, projectRootPath) {
                        Debug.assert(info.isOrphan());
                        const project = this.getOrCreateInferredProjectForProjectRootPathIfEnabled(info, projectRootPath) || this.getOrCreateSingleInferredProjectIfEnabled() || this.getOrCreateSingleInferredWithoutProjectRoot(info.isDynamic ? projectRootPath || this.currentDirectory : getDirectoryPath(isRootedDiskPath(info.fileName) ? info.fileName : getNormalizedAbsolutePath(info.fileName, projectRootPath ? this.getNormalizedAbsolutePath(projectRootPath) : this.currentDirectory)));
                        project.addRoot(info);
                        if (info.containingProjects[0] !== project) {
                            orderedRemoveItem(info.containingProjects, project);
                            info.containingProjects.unshift(project);
                        }
                        project.updateGraph();
                        if (!this.useSingleInferredProject && !project.projectRootPath) {
                            for (const inferredProject of this.inferredProjects) {
                                if (inferredProject === project || inferredProject.isOrphan()) {
                                    continue;
                                }
                                const roots = inferredProject.getRootScriptInfos();
                                Debug.assert(roots.length === 1 || !!inferredProject.projectRootPath);
                                if (roots.length === 1 && forEach(roots[0].containingProjects, (p) => p !== roots[0].containingProjects[0] && !p.isOrphan())) {
                                    inferredProject.removeFile(roots[0], 
                                    /*fileExists*/
                                    true, 
                                    /*detachFromProject*/
                                    true);
                                }
                            }
                        }
                        return project;
                    }
                    assignOrphanScriptInfosToInferredProject() {
                        this.openFiles.forEach((projectRootPath, path) => {
                            const info = this.getScriptInfoForPath(path);
                            if (info.isOrphan()) {
                                this.assignOrphanScriptInfoToInferredProject(info, projectRootPath);
                            }
                        });
                    }
                    /**
                     * Remove this file from the set of open, non-configured files.
                     * @param info The file that has been closed or newly configured
                     */
                    closeOpenFile(info, skipAssignOrphanScriptInfosToInferredProject) {
                        const fileExists = info.isDynamic ? false : this.host.fileExists(info.fileName);
                        info.close(fileExists);
                        this.stopWatchingConfigFilesForClosedScriptInfo(info);
                        const canonicalFileName = this.toCanonicalFileName(info.fileName);
                        if (this.openFilesWithNonRootedDiskPath.get(canonicalFileName) === info) {
                            this.openFilesWithNonRootedDiskPath.delete(canonicalFileName);
                        }
                        let ensureProjectsForOpenFiles = false;
                        for (const p of info.containingProjects) {
                            if (isConfiguredProject(p)) {
                                if (info.hasMixedContent) {
                                    info.registerFileUpdate();
                                }
                                const updateLevel = p.openFileWatchTriggered.get(info.path);
                                if (updateLevel !== void 0) {
                                    p.openFileWatchTriggered.delete(info.path);
                                    if (p.pendingUpdateLevel !== void 0 && p.pendingUpdateLevel < updateLevel) {
                                        p.pendingUpdateLevel = updateLevel;
                                        p.markFileAsDirty(info.path);
                                    }
                                }
                            }
                            else if (isInferredProject(p) && p.isRoot(info)) {
                                if (p.isProjectWithSingleRoot()) {
                                    ensureProjectsForOpenFiles = true;
                                }
                                p.removeFile(info, fileExists, 
                                /*detachFromProject*/
                                true);
                            }
                            if (!p.languageServiceEnabled) {
                                p.markAsDirty();
                            }
                        }
                        this.openFiles.delete(info.path);
                        this.configFileForOpenFiles.delete(info.path);
                        if (!skipAssignOrphanScriptInfosToInferredProject && ensureProjectsForOpenFiles) {
                            this.assignOrphanScriptInfosToInferredProject();
                        }
                        if (fileExists) {
                            this.watchClosedScriptInfo(info);
                        }
                        else {
                            this.handleDeletedFile(info);
                        }
                        return ensureProjectsForOpenFiles;
                    }
                    deleteScriptInfo(info) {
                        this.filenameToScriptInfo.delete(info.path);
                        this.filenameToScriptInfoVersion.set(info.path, info.textStorage.version);
                        const realpath = info.getRealpathIfDifferent();
                        if (realpath) {
                            this.realpathToScriptInfos.remove(realpath, info);
                        }
                    }
                    configFileExists(configFileName, canonicalConfigFilePath, info) {
                        var _a;
                        let configFileExistenceInfo = this.configFileExistenceInfoCache.get(canonicalConfigFilePath);
                        if (configFileExistenceInfo) {
                            if (isOpenScriptInfo(info) && !((_a = configFileExistenceInfo.openFilesImpactedByConfigFile) == null ? void 0 : _a.has(info.path))) {
                                (configFileExistenceInfo.openFilesImpactedByConfigFile || (configFileExistenceInfo.openFilesImpactedByConfigFile = /* @__PURE__ */ new Map())).set(info.path, false);
                            }
                            return configFileExistenceInfo.exists;
                        }
                        const exists = this.host.fileExists(configFileName);
                        let openFilesImpactedByConfigFile;
                        if (isOpenScriptInfo(info)) {
                            (openFilesImpactedByConfigFile || (openFilesImpactedByConfigFile = /* @__PURE__ */ new Map())).set(info.path, false);
                        }
                        configFileExistenceInfo = { exists, openFilesImpactedByConfigFile };
                        this.configFileExistenceInfoCache.set(canonicalConfigFilePath, configFileExistenceInfo);
                        return exists;
                    }
                    /** @internal */
                    createConfigFileWatcherForParsedConfig(configFileName, canonicalConfigFilePath, forProject) {
                        var _a, _b;
                        const configFileExistenceInfo = this.configFileExistenceInfoCache.get(canonicalConfigFilePath);
                        if (!configFileExistenceInfo.watcher || configFileExistenceInfo.watcher === noopConfigFileWatcher) {
                            configFileExistenceInfo.watcher = this.watchFactory.watchFile(configFileName, (_fileName, eventKind) => this.onConfigFileChanged(canonicalConfigFilePath, eventKind), 2e3 /* High */, this.getWatchOptionsFromProjectWatchOptions((_b = (_a = configFileExistenceInfo == null ? void 0 : configFileExistenceInfo.config) == null ? void 0 : _a.parsedCommandLine) == null ? void 0 : _b.watchOptions), WatchType.ConfigFile, forProject);
                        }
                        const projects = configFileExistenceInfo.config.projects;
                        projects.set(forProject.canonicalConfigFilePath, projects.get(forProject.canonicalConfigFilePath) || false);
                    }
                    /**
                     * Returns true if the configFileExistenceInfo is needed/impacted by open files that are root of inferred project
                     */
                    configFileExistenceImpactsRootOfInferredProject(configFileExistenceInfo) {
                        return configFileExistenceInfo.openFilesImpactedByConfigFile && forEachEntry(configFileExistenceInfo.openFilesImpactedByConfigFile, identity);
                    }
                    /** @internal */
                    releaseParsedConfig(canonicalConfigFilePath, forProject) {
                        var _a, _b, _c;
                        const configFileExistenceInfo = this.configFileExistenceInfoCache.get(canonicalConfigFilePath);
                        if (!((_a = configFileExistenceInfo.config) == null ? void 0 : _a.projects.delete(forProject.canonicalConfigFilePath)))
                            return;
                        if ((_b = configFileExistenceInfo.config) == null ? void 0 : _b.projects.size)
                            return;
                        configFileExistenceInfo.config = void 0;
                        clearSharedExtendedConfigFileWatcher(canonicalConfigFilePath, this.sharedExtendedConfigFileWatchers);
                        Debug.checkDefined(configFileExistenceInfo.watcher);
                        if ((_c = configFileExistenceInfo.openFilesImpactedByConfigFile) == null ? void 0 : _c.size) {
                            if (this.configFileExistenceImpactsRootOfInferredProject(configFileExistenceInfo)) {
                                if (!canWatchDirectoryOrFile(getPathComponents(getDirectoryPath(canonicalConfigFilePath)))) {
                                    configFileExistenceInfo.watcher.close();
                                    configFileExistenceInfo.watcher = noopConfigFileWatcher;
                                }
                            }
                            else {
                                configFileExistenceInfo.watcher.close();
                                configFileExistenceInfo.watcher = void 0;
                            }
                        }
                        else {
                            configFileExistenceInfo.watcher.close();
                            this.configFileExistenceInfoCache.delete(canonicalConfigFilePath);
                        }
                    }
                    /**
                     * Close the config file watcher in the cached ConfigFileExistenceInfo
                     *   if there arent any open files that are root of inferred project and there is no parsed config held by any project
                     *
                     * @internal
                     */
                    closeConfigFileWatcherOnReleaseOfOpenFile(configFileExistenceInfo) {
                        if (configFileExistenceInfo.watcher && !configFileExistenceInfo.config && !this.configFileExistenceImpactsRootOfInferredProject(configFileExistenceInfo)) {
                            configFileExistenceInfo.watcher.close();
                            configFileExistenceInfo.watcher = void 0;
                        }
                    }
                    /**
                     * This is called on file close, so that we stop watching the config file for this script info
                     */
                    stopWatchingConfigFilesForClosedScriptInfo(info) {
                        Debug.assert(!info.isScriptOpen());
                        this.forEachConfigFileLocation(info, (canonicalConfigFilePath) => {
                            var _a, _b, _c;
                            const configFileExistenceInfo = this.configFileExistenceInfoCache.get(canonicalConfigFilePath);
                            if (configFileExistenceInfo) {
                                const infoIsRootOfInferredProject = (_a = configFileExistenceInfo.openFilesImpactedByConfigFile) == null ? void 0 : _a.get(info.path);
                                (_b = configFileExistenceInfo.openFilesImpactedByConfigFile) == null ? void 0 : _b.delete(info.path);
                                if (infoIsRootOfInferredProject) {
                                    this.closeConfigFileWatcherOnReleaseOfOpenFile(configFileExistenceInfo);
                                }
                                if (!((_c = configFileExistenceInfo.openFilesImpactedByConfigFile) == null ? void 0 : _c.size) && !configFileExistenceInfo.config) {
                                    Debug.assert(!configFileExistenceInfo.watcher);
                                    this.configFileExistenceInfoCache.delete(canonicalConfigFilePath);
                                }
                            }
                        });
                    }
                    /**
                     * This is called by inferred project whenever script info is added as a root
                     *
                     * @internal
                     */
                    startWatchingConfigFilesForInferredProjectRoot(info) {
                        Debug.assert(info.isScriptOpen());
                        this.forEachConfigFileLocation(info, (canonicalConfigFilePath, configFileName) => {
                            let configFileExistenceInfo = this.configFileExistenceInfoCache.get(canonicalConfigFilePath);
                            if (!configFileExistenceInfo) {
                                configFileExistenceInfo = { exists: this.host.fileExists(configFileName) };
                                this.configFileExistenceInfoCache.set(canonicalConfigFilePath, configFileExistenceInfo);
                            }
                            (configFileExistenceInfo.openFilesImpactedByConfigFile || (configFileExistenceInfo.openFilesImpactedByConfigFile = /* @__PURE__ */ new Map())).set(info.path, true);
                            configFileExistenceInfo.watcher || (configFileExistenceInfo.watcher = canWatchDirectoryOrFile(getPathComponents(getDirectoryPath(canonicalConfigFilePath))) ? this.watchFactory.watchFile(configFileName, (_filename, eventKind) => this.onConfigFileChanged(canonicalConfigFilePath, eventKind), 2e3 /* High */, this.hostConfiguration.watchOptions, WatchType.ConfigFileForInferredRoot) : noopConfigFileWatcher);
                        });
                    }
                    /**
                     * This is called by inferred project whenever root script info is removed from it
                     *
                     * @internal
                     */
                    stopWatchingConfigFilesForInferredProjectRoot(info) {
                        this.forEachConfigFileLocation(info, (canonicalConfigFilePath) => {
                            var _a;
                            const configFileExistenceInfo = this.configFileExistenceInfoCache.get(canonicalConfigFilePath);
                            if ((_a = configFileExistenceInfo == null ? void 0 : configFileExistenceInfo.openFilesImpactedByConfigFile) == null ? void 0 : _a.has(info.path)) {
                                Debug.assert(info.isScriptOpen());
                                configFileExistenceInfo.openFilesImpactedByConfigFile.set(info.path, false);
                                this.closeConfigFileWatcherOnReleaseOfOpenFile(configFileExistenceInfo);
                            }
                        });
                    }
                    /**
                     * This function tries to search for a tsconfig.json for the given file.
                     * This is different from the method the compiler uses because
                     * the compiler can assume it will always start searching in the
                     * current directory (the directory in which tsc was invoked).
                     * The server must start searching from the directory containing
                     * the newly opened file.
                     */
                    forEachConfigFileLocation(info, action) {
                        if (this.serverMode !== 0 /* Semantic */) {
                            return void 0;
                        }
                        Debug.assert(!isOpenScriptInfo(info) || this.openFiles.has(info.path));
                        const projectRootPath = this.openFiles.get(info.path);
                        const scriptInfo = Debug.checkDefined(this.getScriptInfo(info.path));
                        if (scriptInfo.isDynamic)
                            return void 0;
                        let searchPath = asNormalizedPath(getDirectoryPath(info.fileName));
                        const isSearchPathInProjectRoot = () => containsPath(projectRootPath, searchPath, this.currentDirectory, !this.host.useCaseSensitiveFileNames);
                        const anySearchPathOk = !projectRootPath || !isSearchPathInProjectRoot();
                        let searchInDirectory = !isAncestorConfigFileInfo(info);
                        do {
                            if (searchInDirectory) {
                                const canonicalSearchPath = normalizedPathToPath(searchPath, this.currentDirectory, this.toCanonicalFileName);
                                const tsconfigFileName = asNormalizedPath(combinePaths(searchPath, "tsconfig.json"));
                                let result = action(combinePaths(canonicalSearchPath, "tsconfig.json"), tsconfigFileName);
                                if (result)
                                    return tsconfigFileName;
                                const jsconfigFileName = asNormalizedPath(combinePaths(searchPath, "jsconfig.json"));
                                result = action(combinePaths(canonicalSearchPath, "jsconfig.json"), jsconfigFileName);
                                if (result)
                                    return jsconfigFileName;
                                if (isNodeModulesDirectory(canonicalSearchPath)) {
                                    break;
                                }
                            }
                            const parentPath = asNormalizedPath(getDirectoryPath(searchPath));
                            if (parentPath === searchPath)
                                break;
                            searchPath = parentPath;
                            searchInDirectory = true;
                        } while (anySearchPathOk || isSearchPathInProjectRoot());
                        return void 0;
                    }
                    /** @internal */
                    findDefaultConfiguredProject(info) {
                        if (!info.isScriptOpen())
                            return void 0;
                        const configFileName = this.getConfigFileNameForFile(info);
                        const project = configFileName && this.findConfiguredProjectByProjectName(configFileName);
                        return project && projectContainsInfoDirectly(project, info) ? project : project == null ? void 0 : project.getDefaultChildProjectFromProjectWithReferences(info);
                    }
                    /**
                     * This function tries to search for a tsconfig.json for the given file.
                     * This is different from the method the compiler uses because
                     * the compiler can assume it will always start searching in the
                     * current directory (the directory in which tsc was invoked).
                     * The server must start searching from the directory containing
                     * the newly opened file.
                     * If script info is passed in, it is asserted to be open script info
                     * otherwise just file name
                     */
                    getConfigFileNameForFile(info) {
                        if (!isAncestorConfigFileInfo(info)) {
                            const result = this.configFileForOpenFiles.get(info.path);
                            if (result !== void 0)
                                return result || void 0;
                        }
                        this.logger.info(`Search path: ${getDirectoryPath(info.fileName)}`);
                        const configFileName = this.forEachConfigFileLocation(info, (canonicalConfigFilePath, configFileName2) => this.configFileExists(configFileName2, canonicalConfigFilePath, info));
                        if (configFileName) {
                            this.logger.info(`For info: ${info.fileName} :: Config file name: ${configFileName}`);
                        }
                        else {
                            this.logger.info(`For info: ${info.fileName} :: No config files found.`);
                        }
                        if (isOpenScriptInfo(info)) {
                            this.configFileForOpenFiles.set(info.path, configFileName || false);
                        }
                        return configFileName;
                    }
                    printProjects() {
                        if (!this.logger.hasLevel(1 /* normal */)) {
                            return;
                        }
                        this.logger.startGroup();
                        this.externalProjects.forEach(printProjectWithoutFileNames);
                        this.configuredProjects.forEach(printProjectWithoutFileNames);
                        this.inferredProjects.forEach(printProjectWithoutFileNames);
                        this.logger.info("Open files: ");
                        this.openFiles.forEach((projectRootPath, path) => {
                            const info = this.getScriptInfoForPath(path);
                            this.logger.info(`	FileName: ${info.fileName} ProjectRootPath: ${projectRootPath}`);
                            this.logger.info(`		Projects: ${info.containingProjects.map((p) => p.getProjectName())}`);
                        });
                        this.logger.endGroup();
                    }
                    /** @internal */
                    findConfiguredProjectByProjectName(configFileName) {
                        const canonicalConfigFilePath = asNormalizedPath(this.toCanonicalFileName(configFileName));
                        return this.getConfiguredProjectByCanonicalConfigFilePath(canonicalConfigFilePath);
                    }
                    getConfiguredProjectByCanonicalConfigFilePath(canonicalConfigFilePath) {
                        return this.configuredProjects.get(canonicalConfigFilePath);
                    }
                    findExternalProjectByProjectName(projectFileName) {
                        return findProjectByName(projectFileName, this.externalProjects);
                    }
                    /** Get a filename if the language service exceeds the maximum allowed program size; otherwise returns undefined. */
                    getFilenameForExceededTotalSizeLimitForNonTsFiles(name, options, fileNames, propertyReader) {
                        if (options && options.disableSizeLimit || !this.host.getFileSize) {
                            return;
                        }
                        let availableSpace = maxProgramSizeForNonTsFiles;
                        this.projectToSizeMap.set(name, 0);
                        this.projectToSizeMap.forEach((val) => availableSpace -= val || 0);
                        let totalNonTsFileSize = 0;
                        for (const f of fileNames) {
                            const fileName = propertyReader.getFileName(f);
                            if (hasTSFileExtension(fileName)) {
                                continue;
                            }
                            totalNonTsFileSize += this.host.getFileSize(fileName);
                            if (totalNonTsFileSize > maxProgramSizeForNonTsFiles || totalNonTsFileSize > availableSpace) {
                                const top5LargestFiles = fileNames.map((f2) => propertyReader.getFileName(f2)).filter((name2) => !hasTSFileExtension(name2)).map((name2) => ({ name: name2, size: this.host.getFileSize(name2) })).sort((a, b) => b.size - a.size).slice(0, 5);
                                this.logger.info(`Non TS file size exceeded limit (${totalNonTsFileSize}). Largest files: ${top5LargestFiles.map((file) => `${file.name}:${file.size}`).join(", ")}`);
                                return fileName;
                            }
                        }
                        this.projectToSizeMap.set(name, totalNonTsFileSize);
                    }
                    createExternalProject(projectFileName, files, options, typeAcquisition, excludedFiles) {
                        const compilerOptions = convertCompilerOptions(options);
                        const watchOptionsAndErrors = convertWatchOptions(options, getDirectoryPath(normalizeSlashes(projectFileName)));
                        const project = new ExternalProject2(projectFileName, this, this.documentRegistry, compilerOptions, 
                        /*lastFileExceededProgramSize*/
                        this.getFilenameForExceededTotalSizeLimitForNonTsFiles(projectFileName, compilerOptions, files, externalFilePropertyReader), options.compileOnSave === void 0 ? true : options.compileOnSave, 
                        /*projectFilePath*/
                        void 0, watchOptionsAndErrors == null ? void 0 : watchOptionsAndErrors.watchOptions);
                        project.setProjectErrors(watchOptionsAndErrors == null ? void 0 : watchOptionsAndErrors.errors);
                        project.excludedFiles = excludedFiles;
                        this.addFilesToNonInferredProject(project, files, externalFilePropertyReader, typeAcquisition);
                        this.externalProjects.push(project);
                        return project;
                    }
                    /** @internal */
                    sendProjectTelemetry(project) {
                        if (this.seenProjects.has(project.projectName)) {
                            setProjectOptionsUsed(project);
                            return;
                        }
                        this.seenProjects.set(project.projectName, true);
                        if (!this.eventHandler || !this.host.createSHA256Hash) {
                            setProjectOptionsUsed(project);
                            return;
                        }
                        const projectOptions = isConfiguredProject(project) ? project.projectOptions : void 0;
                        setProjectOptionsUsed(project);
                        const data = {
                            projectId: this.host.createSHA256Hash(project.projectName),
                            fileStats: countEachFileTypes(project.getScriptInfos(), 
                            /*includeSizes*/
                            true),
                            compilerOptions: convertCompilerOptionsForTelemetry(project.getCompilationSettings()),
                            typeAcquisition: convertTypeAcquisition2(project.getTypeAcquisition()),
                            extends: projectOptions && projectOptions.configHasExtendsProperty,
                            files: projectOptions && projectOptions.configHasFilesProperty,
                            include: projectOptions && projectOptions.configHasIncludeProperty,
                            exclude: projectOptions && projectOptions.configHasExcludeProperty,
                            compileOnSave: project.compileOnSaveEnabled,
                            configFileName: configFileName(),
                            projectType: project instanceof ExternalProject2 ? "external" : "configured",
                            languageServiceEnabled: project.languageServiceEnabled,
                            version
                        };
                        this.eventHandler({ eventName: ProjectInfoTelemetryEvent, data });
                        function configFileName() {
                            if (!isConfiguredProject(project)) {
                                return "other";
                            }
                            return getBaseConfigFileName(project.getConfigFilePath()) || "other";
                        }
                        function convertTypeAcquisition2({ enable: enable2, include, exclude }) {
                            return {
                                enable: enable2,
                                include: include !== void 0 && include.length !== 0,
                                exclude: exclude !== void 0 && exclude.length !== 0
                            };
                        }
                    }
                    addFilesToNonInferredProject(project, files, propertyReader, typeAcquisition) {
                        this.updateNonInferredProjectFiles(project, files, propertyReader);
                        project.setTypeAcquisition(typeAcquisition);
                        project.markAsDirty();
                    }
                    /** @internal */
                    createConfiguredProject(configFileName) {
                        var _a;
                        (_a = tracing) == null ? void 0 : _a.instant(tracing.Phase.Session, "createConfiguredProject", { configFilePath: configFileName });
                        this.logger.info(`Creating configuration project ${configFileName}`);
                        const canonicalConfigFilePath = asNormalizedPath(this.toCanonicalFileName(configFileName));
                        let configFileExistenceInfo = this.configFileExistenceInfoCache.get(canonicalConfigFilePath);
                        if (!configFileExistenceInfo) {
                            this.configFileExistenceInfoCache.set(canonicalConfigFilePath, configFileExistenceInfo = { exists: true });
                        }
                        else {
                            configFileExistenceInfo.exists = true;
                        }
                        if (!configFileExistenceInfo.config) {
                            configFileExistenceInfo.config = {
                                cachedDirectoryStructureHost: createCachedDirectoryStructureHost(this.host, this.host.getCurrentDirectory(), this.host.useCaseSensitiveFileNames),
                                projects: /* @__PURE__ */ new Map(),
                                updateLevel: 2 /* Full */
                            };
                        }
                        const project = new ConfiguredProject2(configFileName, canonicalConfigFilePath, this, this.documentRegistry, configFileExistenceInfo.config.cachedDirectoryStructureHost);
                        this.configuredProjects.set(canonicalConfigFilePath, project);
                        this.createConfigFileWatcherForParsedConfig(configFileName, canonicalConfigFilePath, project);
                        return project;
                    }
                    /** @internal */
                    createConfiguredProjectWithDelayLoad(configFileName, reason) {
                        const project = this.createConfiguredProject(configFileName);
                        project.pendingUpdateLevel = 2 /* Full */;
                        project.pendingUpdateReason = reason;
                        return project;
                    }
                    /** @internal */
                    createAndLoadConfiguredProject(configFileName, reason) {
                        const project = this.createConfiguredProject(configFileName);
                        this.loadConfiguredProject(project, reason);
                        return project;
                    }
                    /** @internal */
                    createLoadAndUpdateConfiguredProject(configFileName, reason) {
                        const project = this.createAndLoadConfiguredProject(configFileName, reason);
                        project.updateGraph();
                        return project;
                    }
                    /**
                     * Read the config file of the project, and update the project root file names.
                     *
                     * @internal
                     */
                    loadConfiguredProject(project, reason) {
                        var _a, _b;
                        (_a = tracing) == null ? void 0 : _a.push(tracing.Phase.Session, "loadConfiguredProject", { configFilePath: project.canonicalConfigFilePath });
                        this.sendProjectLoadingStartEvent(project, reason);
                        const configFilename = asNormalizedPath(normalizePath(project.getConfigFilePath()));
                        const configFileExistenceInfo = this.ensureParsedConfigUptoDate(configFilename, project.canonicalConfigFilePath, this.configFileExistenceInfoCache.get(project.canonicalConfigFilePath), project);
                        const parsedCommandLine = configFileExistenceInfo.config.parsedCommandLine;
                        Debug.assert(!!parsedCommandLine.fileNames);
                        const compilerOptions = parsedCommandLine.options;
                        if (!project.projectOptions) {
                            project.projectOptions = {
                                configHasExtendsProperty: parsedCommandLine.raw.extends !== void 0,
                                configHasFilesProperty: parsedCommandLine.raw.files !== void 0,
                                configHasIncludeProperty: parsedCommandLine.raw.include !== void 0,
                                configHasExcludeProperty: parsedCommandLine.raw.exclude !== void 0
                            };
                        }
                        project.canConfigFileJsonReportNoInputFiles = canJsonReportNoInputFiles(parsedCommandLine.raw);
                        project.setProjectErrors(parsedCommandLine.options.configFile.parseDiagnostics);
                        project.updateReferences(parsedCommandLine.projectReferences);
                        const lastFileExceededProgramSize = this.getFilenameForExceededTotalSizeLimitForNonTsFiles(project.canonicalConfigFilePath, compilerOptions, parsedCommandLine.fileNames, fileNamePropertyReader);
                        if (lastFileExceededProgramSize) {
                            project.disableLanguageService(lastFileExceededProgramSize);
                            this.configFileExistenceInfoCache.forEach((_configFileExistenceInfo, canonicalConfigFilePath) => this.stopWatchingWildCards(canonicalConfigFilePath, project));
                        }
                        else {
                            project.setCompilerOptions(compilerOptions);
                            project.setWatchOptions(parsedCommandLine.watchOptions);
                            project.enableLanguageService();
                            this.watchWildcards(configFilename, configFileExistenceInfo, project);
                        }
                        project.enablePluginsWithOptions(compilerOptions);
                        const filesToAdd = parsedCommandLine.fileNames.concat(project.getExternalFiles(2 /* Full */));
                        this.updateRootAndOptionsOfNonInferredProject(project, filesToAdd, fileNamePropertyReader, compilerOptions, parsedCommandLine.typeAcquisition, parsedCommandLine.compileOnSave, parsedCommandLine.watchOptions);
                        (_b = tracing) == null ? void 0 : _b.pop();
                    }
                    /** @internal */
                    ensureParsedConfigUptoDate(configFilename, canonicalConfigFilePath, configFileExistenceInfo, forProject) {
                        var _a, _b, _c;
                        if (configFileExistenceInfo.config) {
                            if (!configFileExistenceInfo.config.updateLevel)
                                return configFileExistenceInfo;
                            if (configFileExistenceInfo.config.updateLevel === 1 /* RootNamesAndUpdate */) {
                                this.reloadFileNamesOfParsedConfig(configFilename, configFileExistenceInfo.config);
                                return configFileExistenceInfo;
                            }
                        }
                        const cachedDirectoryStructureHost = ((_a = configFileExistenceInfo.config) == null ? void 0 : _a.cachedDirectoryStructureHost) || createCachedDirectoryStructureHost(this.host, this.host.getCurrentDirectory(), this.host.useCaseSensitiveFileNames);
                        const configFileContent = tryReadFile(configFilename, (fileName) => this.host.readFile(fileName));
                        const configFile = parseJsonText(configFilename, isString(configFileContent) ? configFileContent : "");
                        const configFileErrors = configFile.parseDiagnostics;
                        if (!isString(configFileContent))
                            configFileErrors.push(configFileContent);
                        const parsedCommandLine = parseJsonSourceFileConfigFileContent(configFile, cachedDirectoryStructureHost, getDirectoryPath(configFilename), 
                        /*existingOptions*/
                        {}, configFilename, 
                        /*resolutionStack*/
                        [], this.hostConfiguration.extraFileExtensions, this.extendedConfigCache);
                        if (parsedCommandLine.errors.length) {
                            configFileErrors.push(...parsedCommandLine.errors);
                        }
                        this.logger.info(`Config: ${configFilename} : ${JSON.stringify({
                            rootNames: parsedCommandLine.fileNames,
                            options: parsedCommandLine.options,
                            watchOptions: parsedCommandLine.watchOptions,
                            projectReferences: parsedCommandLine.projectReferences
                        }, 
                        /*replacer*/
                        void 0, " ")}`);
                        const oldCommandLine = (_b = configFileExistenceInfo.config) == null ? void 0 : _b.parsedCommandLine;
                        if (!configFileExistenceInfo.config) {
                            configFileExistenceInfo.config = { parsedCommandLine, cachedDirectoryStructureHost, projects: /* @__PURE__ */ new Map() };
                        }
                        else {
                            configFileExistenceInfo.config.parsedCommandLine = parsedCommandLine;
                            configFileExistenceInfo.config.watchedDirectoriesStale = true;
                            configFileExistenceInfo.config.updateLevel = void 0;
                        }
                        if (!oldCommandLine && !isJsonEqual(
                        // Old options
                        this.getWatchOptionsFromProjectWatchOptions(
                        /*projectOptions*/
                        void 0), 
                        // New options
                        this.getWatchOptionsFromProjectWatchOptions(parsedCommandLine.watchOptions))) {
                            (_c = configFileExistenceInfo.watcher) == null ? void 0 : _c.close();
                            configFileExistenceInfo.watcher = void 0;
                        }
                        this.createConfigFileWatcherForParsedConfig(configFilename, canonicalConfigFilePath, forProject);
                        updateSharedExtendedConfigFileWatcher(canonicalConfigFilePath, parsedCommandLine.options, this.sharedExtendedConfigFileWatchers, (extendedConfigFileName, extendedConfigFilePath) => this.watchFactory.watchFile(extendedConfigFileName, () => {
                            var _a2;
                            cleanExtendedConfigCache(this.extendedConfigCache, extendedConfigFilePath, (fileName) => this.toPath(fileName));
                            let ensureProjectsForOpenFiles = false;
                            (_a2 = this.sharedExtendedConfigFileWatchers.get(extendedConfigFilePath)) == null ? void 0 : _a2.projects.forEach((canonicalPath) => {
                                ensureProjectsForOpenFiles = this.delayUpdateProjectsFromParsedConfigOnConfigFileChange(canonicalPath, `Change in extended config file ${extendedConfigFileName} detected`) || ensureProjectsForOpenFiles;
                            });
                            if (ensureProjectsForOpenFiles)
                                this.delayEnsureProjectForOpenFiles();
                        }, 2e3 /* High */, this.hostConfiguration.watchOptions, WatchType.ExtendedConfigFile, configFilename), (fileName) => this.toPath(fileName));
                        return configFileExistenceInfo;
                    }
                    /** @internal */
                    watchWildcards(configFileName, { exists, config }, forProject) {
                        config.projects.set(forProject.canonicalConfigFilePath, true);
                        if (exists) {
                            if (config.watchedDirectories && !config.watchedDirectoriesStale)
                                return;
                            config.watchedDirectoriesStale = false;
                            updateWatchingWildcardDirectories(config.watchedDirectories || (config.watchedDirectories = /* @__PURE__ */ new Map()), config.parsedCommandLine.wildcardDirectories, 
                            // Create new directory watcher
                            (directory, flags) => this.watchWildcardDirectory(directory, flags, configFileName, config));
                        }
                        else {
                            config.watchedDirectoriesStale = false;
                            if (!config.watchedDirectories)
                                return;
                            clearMap(config.watchedDirectories, closeFileWatcherOf);
                            config.watchedDirectories = void 0;
                        }
                    }
                    /** @internal */
                    stopWatchingWildCards(canonicalConfigFilePath, forProject) {
                        const configFileExistenceInfo = this.configFileExistenceInfoCache.get(canonicalConfigFilePath);
                        if (!configFileExistenceInfo.config || !configFileExistenceInfo.config.projects.get(forProject.canonicalConfigFilePath)) {
                            return;
                        }
                        configFileExistenceInfo.config.projects.set(forProject.canonicalConfigFilePath, false);
                        if (forEachEntry(configFileExistenceInfo.config.projects, identity))
                            return;
                        if (configFileExistenceInfo.config.watchedDirectories) {
                            clearMap(configFileExistenceInfo.config.watchedDirectories, closeFileWatcherOf);
                            configFileExistenceInfo.config.watchedDirectories = void 0;
                        }
                        configFileExistenceInfo.config.watchedDirectoriesStale = void 0;
                    }
                    updateNonInferredProjectFiles(project, files, propertyReader) {
                        const projectRootFilesMap = project.getRootFilesMap();
                        const newRootScriptInfoMap = /* @__PURE__ */ new Map();
                        for (const f of files) {
                            const newRootFile = propertyReader.getFileName(f);
                            const fileName = toNormalizedPath(newRootFile);
                            const isDynamic = isDynamicFileName(fileName);
                            let path;
                            if (!isDynamic && !project.fileExists(newRootFile)) {
                                path = normalizedPathToPath(fileName, this.currentDirectory, this.toCanonicalFileName);
                                const existingValue = projectRootFilesMap.get(path);
                                if (existingValue) {
                                    if (existingValue.info) {
                                        project.removeFile(existingValue.info, 
                                        /*fileExists*/
                                        false, 
                                        /*detachFromProject*/
                                        true);
                                        existingValue.info = void 0;
                                    }
                                    existingValue.fileName = fileName;
                                }
                                else {
                                    projectRootFilesMap.set(path, { fileName });
                                }
                            }
                            else {
                                const scriptKind = propertyReader.getScriptKind(f, this.hostConfiguration.extraFileExtensions);
                                const hasMixedContent = propertyReader.hasMixedContent(f, this.hostConfiguration.extraFileExtensions);
                                const scriptInfo = Debug.checkDefined(this.getOrCreateScriptInfoNotOpenedByClientForNormalizedPath(fileName, project.currentDirectory, scriptKind, hasMixedContent, project.directoryStructureHost));
                                path = scriptInfo.path;
                                const existingValue = projectRootFilesMap.get(path);
                                if (!existingValue || existingValue.info !== scriptInfo) {
                                    project.addRoot(scriptInfo, fileName);
                                    if (scriptInfo.isScriptOpen()) {
                                        this.removeRootOfInferredProjectIfNowPartOfOtherProject(scriptInfo);
                                    }
                                }
                                else {
                                    existingValue.fileName = fileName;
                                }
                            }
                            newRootScriptInfoMap.set(path, true);
                        }
                        if (projectRootFilesMap.size > newRootScriptInfoMap.size) {
                            projectRootFilesMap.forEach((value, path) => {
                                if (!newRootScriptInfoMap.has(path)) {
                                    if (value.info) {
                                        project.removeFile(value.info, project.fileExists(value.info.fileName), 
                                        /*detachFromProject*/
                                        true);
                                    }
                                    else {
                                        projectRootFilesMap.delete(path);
                                    }
                                }
                            });
                        }
                    }
                    updateRootAndOptionsOfNonInferredProject(project, newUncheckedFiles, propertyReader, newOptions, newTypeAcquisition, compileOnSave, watchOptions) {
                        project.setCompilerOptions(newOptions);
                        project.setWatchOptions(watchOptions);
                        if (compileOnSave !== void 0) {
                            project.compileOnSaveEnabled = compileOnSave;
                        }
                        this.addFilesToNonInferredProject(project, newUncheckedFiles, propertyReader, newTypeAcquisition);
                    }
                    /**
                     * Reload the file names from config file specs and update the project graph
                     *
                     * @internal
                     */
                    reloadFileNamesOfConfiguredProject(project) {
                        const fileNames = this.reloadFileNamesOfParsedConfig(project.getConfigFilePath(), this.configFileExistenceInfoCache.get(project.canonicalConfigFilePath).config);
                        project.updateErrorOnNoInputFiles(fileNames);
                        this.updateNonInferredProjectFiles(project, fileNames.concat(project.getExternalFiles(1 /* RootNamesAndUpdate */)), fileNamePropertyReader);
                        project.markAsDirty();
                        return project.updateGraph();
                    }
                    /** @internal */
                    reloadFileNamesOfParsedConfig(configFileName, config) {
                        if (config.updateLevel === void 0)
                            return config.parsedCommandLine.fileNames;
                        Debug.assert(config.updateLevel === 1 /* RootNamesAndUpdate */);
                        const configFileSpecs = config.parsedCommandLine.options.configFile.configFileSpecs;
                        const fileNames = getFileNamesFromConfigSpecs(configFileSpecs, getDirectoryPath(configFileName), config.parsedCommandLine.options, config.cachedDirectoryStructureHost, this.hostConfiguration.extraFileExtensions);
                        config.parsedCommandLine = { ...config.parsedCommandLine, fileNames };
                        return fileNames;
                    }
                    /** @internal */
                    setFileNamesOfAutpImportProviderOrAuxillaryProject(project, fileNames) {
                        this.updateNonInferredProjectFiles(project, fileNames, fileNamePropertyReader);
                    }
                    /**
                     * Read the config file of the project again by clearing the cache and update the project graph
                     *
                     * @internal
                     */
                    reloadConfiguredProject(project, reason, isInitialLoad, clearSemanticCache) {
                        const host = project.getCachedDirectoryStructureHost();
                        if (clearSemanticCache)
                            this.clearSemanticCache(project);
                        host.clearCache();
                        const configFileName = project.getConfigFilePath();
                        this.logger.info(`${isInitialLoad ? "Loading" : "Reloading"} configured project ${configFileName}`);
                        this.loadConfiguredProject(project, reason);
                        project.updateGraph();
                        this.sendConfigFileDiagEvent(project, configFileName);
                    }
                    /** @internal */
                    clearSemanticCache(project) {
                        project.resolutionCache.clear();
                        project.getLanguageService(
                        /*ensureSynchronized*/
                        false).cleanupSemanticCache();
                        project.cleanupProgram();
                        project.markAsDirty();
                    }
                    sendConfigFileDiagEvent(project, triggerFile) {
                        if (!this.eventHandler || this.suppressDiagnosticEvents) {
                            return;
                        }
                        const diagnostics = project.getLanguageService().getCompilerOptionsDiagnostics();
                        diagnostics.push(...project.getAllProjectErrors());
                        this.eventHandler({
                            eventName: ConfigFileDiagEvent,
                            data: { configFileName: project.getConfigFilePath(), diagnostics, triggerFile }
                        });
                    }
                    getOrCreateInferredProjectForProjectRootPathIfEnabled(info, projectRootPath) {
                        if (!this.useInferredProjectPerProjectRoot || // Its a dynamic info opened without project root
                            info.isDynamic && projectRootPath === void 0) {
                            return void 0;
                        }
                        if (projectRootPath) {
                            const canonicalProjectRootPath = this.toCanonicalFileName(projectRootPath);
                            for (const project of this.inferredProjects) {
                                if (project.projectRootPath === canonicalProjectRootPath) {
                                    return project;
                                }
                            }
                            return this.createInferredProject(projectRootPath, 
                            /*isSingleInferredProject*/
                            false, projectRootPath);
                        }
                        let bestMatch;
                        for (const project of this.inferredProjects) {
                            if (!project.projectRootPath)
                                continue;
                            if (!containsPath(project.projectRootPath, info.path, this.host.getCurrentDirectory(), !this.host.useCaseSensitiveFileNames))
                                continue;
                            if (bestMatch && bestMatch.projectRootPath.length > project.projectRootPath.length)
                                continue;
                            bestMatch = project;
                        }
                        return bestMatch;
                    }
                    getOrCreateSingleInferredProjectIfEnabled() {
                        if (!this.useSingleInferredProject) {
                            return void 0;
                        }
                        if (this.inferredProjects.length > 0 && this.inferredProjects[0].projectRootPath === void 0) {
                            return this.inferredProjects[0];
                        }
                        return this.createInferredProject("", 
                        /*isSingleInferredProject*/
                        true);
                    }
                    getOrCreateSingleInferredWithoutProjectRoot(currentDirectory) {
                        Debug.assert(!this.useSingleInferredProject);
                        const expectedCurrentDirectory = this.toCanonicalFileName(this.getNormalizedAbsolutePath(currentDirectory));
                        for (const inferredProject of this.inferredProjects) {
                            if (!inferredProject.projectRootPath && inferredProject.isOrphan() && inferredProject.canonicalCurrentDirectory === expectedCurrentDirectory) {
                                return inferredProject;
                            }
                        }
                        return this.createInferredProject(currentDirectory);
                    }
                    createInferredProject(currentDirectory, isSingleInferredProject, projectRootPath) {
                        const compilerOptions = projectRootPath && this.compilerOptionsForInferredProjectsPerProjectRoot.get(projectRootPath) || this.compilerOptionsForInferredProjects;
                        let watchOptionsAndErrors;
                        let typeAcquisition;
                        if (projectRootPath) {
                            watchOptionsAndErrors = this.watchOptionsForInferredProjectsPerProjectRoot.get(projectRootPath);
                            typeAcquisition = this.typeAcquisitionForInferredProjectsPerProjectRoot.get(projectRootPath);
                        }
                        if (watchOptionsAndErrors === void 0) {
                            watchOptionsAndErrors = this.watchOptionsForInferredProjects;
                        }
                        if (typeAcquisition === void 0) {
                            typeAcquisition = this.typeAcquisitionForInferredProjects;
                        }
                        watchOptionsAndErrors = watchOptionsAndErrors || void 0;
                        const project = new InferredProject2(this, this.documentRegistry, compilerOptions, watchOptionsAndErrors == null ? void 0 : watchOptionsAndErrors.watchOptions, projectRootPath, currentDirectory, typeAcquisition);
                        project.setProjectErrors(watchOptionsAndErrors == null ? void 0 : watchOptionsAndErrors.errors);
                        if (isSingleInferredProject) {
                            this.inferredProjects.unshift(project);
                        }
                        else {
                            this.inferredProjects.push(project);
                        }
                        return project;
                    }
                    /** @internal */
                    getOrCreateScriptInfoNotOpenedByClient(uncheckedFileName, currentDirectory, hostToQueryFileExistsOn) {
                        return this.getOrCreateScriptInfoNotOpenedByClientForNormalizedPath(toNormalizedPath(uncheckedFileName), currentDirectory, 
                        /*scriptKind*/
                        void 0, 
                        /*hasMixedContent*/
                        void 0, hostToQueryFileExistsOn);
                    }
                    getScriptInfo(uncheckedFileName) {
                        return this.getScriptInfoForNormalizedPath(toNormalizedPath(uncheckedFileName));
                    }
                    /** @internal */
                    getScriptInfoOrConfig(uncheckedFileName) {
                        const path = toNormalizedPath(uncheckedFileName);
                        const info = this.getScriptInfoForNormalizedPath(path);
                        if (info)
                            return info;
                        const configProject = this.configuredProjects.get(this.toPath(uncheckedFileName));
                        return configProject && configProject.getCompilerOptions().configFile;
                    }
                    /** @internal */
                    logErrorForScriptInfoNotFound(fileName) {
                        const names = arrayFrom(this.filenameToScriptInfo.entries(), ([path, scriptInfo]) => ({ path, fileName: scriptInfo.fileName }));
                        this.logger.msg(`Could not find file ${JSON.stringify(fileName)}.
All files are: ${JSON.stringify(names)}`, "Err" /* Err */);
                    }
                    /**
                     * Returns the projects that contain script info through SymLink
                     * Note that this does not return projects in info.containingProjects
                     *
                     * @internal
                     */
                    getSymlinkedProjects(info) {
                        let projects;
                        if (this.realpathToScriptInfos) {
                            const realpath = info.getRealpathIfDifferent();
                            if (realpath) {
                                forEach(this.realpathToScriptInfos.get(realpath), combineProjects);
                            }
                            forEach(this.realpathToScriptInfos.get(info.path), combineProjects);
                        }
                        return projects;
                        function combineProjects(toAddInfo) {
                            if (toAddInfo !== info) {
                                for (const project of toAddInfo.containingProjects) {
                                    if (project.languageServiceEnabled && !project.isOrphan() && !project.getCompilerOptions().preserveSymlinks && !info.isAttached(project)) {
                                        if (!projects) {
                                            projects = createMultiMap();
                                            projects.add(toAddInfo.path, project);
                                        }
                                        else if (!forEachEntry(projects, (projs, path) => path === toAddInfo.path ? false : contains(projs, project))) {
                                            projects.add(toAddInfo.path, project);
                                        }
                                    }
                                }
                            }
                        }
                    }
                    watchClosedScriptInfo(info) {
                        Debug.assert(!info.fileWatcher);
                        if (!info.isDynamicOrHasMixedContent() && (!this.globalCacheLocationDirectoryPath || !startsWith(info.path, this.globalCacheLocationDirectoryPath))) {
                            const indexOfNodeModules = info.fileName.indexOf("/node_modules/");
                            if (!this.host.getModifiedTime || indexOfNodeModules === -1) {
                                info.fileWatcher = this.watchFactory.watchFile(info.fileName, (_fileName, eventKind) => this.onSourceFileChanged(info, eventKind), 500 /* Medium */, this.hostConfiguration.watchOptions, WatchType.ClosedScriptInfo);
                            }
                            else {
                                info.mTime = this.getModifiedTime(info);
                                info.fileWatcher = this.watchClosedScriptInfoInNodeModules(info.fileName.substring(0, indexOfNodeModules));
                            }
                        }
                    }
                    createNodeModulesWatcher(dir, dirPath) {
                        let watcher = this.watchFactory.watchDirectory(dir, (fileOrDirectory) => {
                            var _a;
                            const fileOrDirectoryPath = removeIgnoredPath(this.toPath(fileOrDirectory));
                            if (!fileOrDirectoryPath)
                                return;
                            const basename = getBaseFileName(fileOrDirectoryPath);
                            if (((_a = result.affectedModuleSpecifierCacheProjects) == null ? void 0 : _a.size) && (basename === "package.json" || basename === "node_modules")) {
                                result.affectedModuleSpecifierCacheProjects.forEach((project) => {
                                    var _a2;
                                    (_a2 = project.getModuleSpecifierCache()) == null ? void 0 : _a2.clear();
                                });
                            }
                            if (result.refreshScriptInfoRefCount) {
                                if (dirPath === fileOrDirectoryPath) {
                                    this.refreshScriptInfosInDirectory(dirPath);
                                }
                                else {
                                    const info = this.getScriptInfoForPath(fileOrDirectoryPath);
                                    if (info) {
                                        if (isScriptInfoWatchedFromNodeModules(info)) {
                                            this.refreshScriptInfo(info);
                                        }
                                    }
                                    else if (!hasExtension(fileOrDirectoryPath)) {
                                        this.refreshScriptInfosInDirectory(fileOrDirectoryPath);
                                    }
                                }
                            }
                        }, 1 /* Recursive */, this.hostConfiguration.watchOptions, WatchType.NodeModules);
                        const result = {
                            refreshScriptInfoRefCount: 0,
                            affectedModuleSpecifierCacheProjects: void 0,
                            close: () => {
                                var _a;
                                if (watcher && !result.refreshScriptInfoRefCount && !((_a = result.affectedModuleSpecifierCacheProjects) == null ? void 0 : _a.size)) {
                                    watcher.close();
                                    watcher = void 0;
                                    this.nodeModulesWatchers.delete(dirPath);
                                }
                            }
                        };
                        this.nodeModulesWatchers.set(dirPath, result);
                        return result;
                    }
                    /** @internal */
                    watchPackageJsonsInNodeModules(dir, project) {
                        var _a;
                        const dirPath = this.toPath(dir);
                        const watcher = this.nodeModulesWatchers.get(dirPath) || this.createNodeModulesWatcher(dir, dirPath);
                        Debug.assert(!((_a = watcher.affectedModuleSpecifierCacheProjects) == null ? void 0 : _a.has(project)));
                        (watcher.affectedModuleSpecifierCacheProjects || (watcher.affectedModuleSpecifierCacheProjects = /* @__PURE__ */ new Set())).add(project);
                        return {
                            close: () => {
                                var _a2;
                                (_a2 = watcher.affectedModuleSpecifierCacheProjects) == null ? void 0 : _a2.delete(project);
                                watcher.close();
                            }
                        };
                    }
                    watchClosedScriptInfoInNodeModules(dir) {
                        const watchDir = dir + "/node_modules";
                        const watchDirPath = this.toPath(watchDir);
                        const watcher = this.nodeModulesWatchers.get(watchDirPath) || this.createNodeModulesWatcher(watchDir, watchDirPath);
                        watcher.refreshScriptInfoRefCount++;
                        return {
                            close: () => {
                                watcher.refreshScriptInfoRefCount--;
                                watcher.close();
                            }
                        };
                    }
                    getModifiedTime(info) {
                        return (this.host.getModifiedTime(info.fileName) || missingFileModifiedTime).getTime();
                    }
                    refreshScriptInfo(info) {
                        const mTime = this.getModifiedTime(info);
                        if (mTime !== info.mTime) {
                            const eventKind = getFileWatcherEventKind(info.mTime, mTime);
                            info.mTime = mTime;
                            this.onSourceFileChanged(info, eventKind);
                        }
                    }
                    refreshScriptInfosInDirectory(dir) {
                        dir = dir + directorySeparator;
                        this.filenameToScriptInfo.forEach((info) => {
                            if (isScriptInfoWatchedFromNodeModules(info) && startsWith(info.path, dir)) {
                                this.refreshScriptInfo(info);
                            }
                        });
                    }
                    stopWatchingScriptInfo(info) {
                        if (info.fileWatcher) {
                            info.fileWatcher.close();
                            info.fileWatcher = void 0;
                        }
                    }
                    getOrCreateScriptInfoNotOpenedByClientForNormalizedPath(fileName, currentDirectory, scriptKind, hasMixedContent, hostToQueryFileExistsOn) {
                        if (isRootedDiskPath(fileName) || isDynamicFileName(fileName)) {
                            return this.getOrCreateScriptInfoWorker(fileName, currentDirectory, 
                            /*openedByClient*/
                            false, 
                            /*fileContent*/
                            void 0, scriptKind, hasMixedContent, hostToQueryFileExistsOn);
                        }
                        const info = this.openFilesWithNonRootedDiskPath.get(this.toCanonicalFileName(fileName));
                        if (info) {
                            return info;
                        }
                        return void 0;
                    }
                    getOrCreateScriptInfoOpenedByClientForNormalizedPath(fileName, currentDirectory, fileContent, scriptKind, hasMixedContent) {
                        return this.getOrCreateScriptInfoWorker(fileName, currentDirectory, 
                        /*openedByClient*/
                        true, fileContent, scriptKind, hasMixedContent);
                    }
                    getOrCreateScriptInfoForNormalizedPath(fileName, openedByClient, fileContent, scriptKind, hasMixedContent, hostToQueryFileExistsOn) {
                        return this.getOrCreateScriptInfoWorker(fileName, this.currentDirectory, openedByClient, fileContent, scriptKind, hasMixedContent, hostToQueryFileExistsOn);
                    }
                    getOrCreateScriptInfoWorker(fileName, currentDirectory, openedByClient, fileContent, scriptKind, hasMixedContent, hostToQueryFileExistsOn) {
                        Debug.assert(fileContent === void 0 || openedByClient, "ScriptInfo needs to be opened by client to be able to set its user defined content");
                        const path = normalizedPathToPath(fileName, currentDirectory, this.toCanonicalFileName);
                        let info = this.getScriptInfoForPath(path);
                        if (!info) {
                            const isDynamic = isDynamicFileName(fileName);
                            Debug.assert(isRootedDiskPath(fileName) || isDynamic || openedByClient, "", () => `${JSON.stringify({ fileName, currentDirectory, hostCurrentDirectory: this.currentDirectory, openKeys: arrayFrom(this.openFilesWithNonRootedDiskPath.keys()) })}
Script info with non-dynamic relative file name can only be open script info or in context of host currentDirectory`);
                            Debug.assert(!isRootedDiskPath(fileName) || this.currentDirectory === currentDirectory || !this.openFilesWithNonRootedDiskPath.has(this.toCanonicalFileName(fileName)), "", () => `${JSON.stringify({ fileName, currentDirectory, hostCurrentDirectory: this.currentDirectory, openKeys: arrayFrom(this.openFilesWithNonRootedDiskPath.keys()) })}
Open script files with non rooted disk path opened with current directory context cannot have same canonical names`);
                            Debug.assert(!isDynamic || this.currentDirectory === currentDirectory || this.useInferredProjectPerProjectRoot, "", () => `${JSON.stringify({ fileName, currentDirectory, hostCurrentDirectory: this.currentDirectory, openKeys: arrayFrom(this.openFilesWithNonRootedDiskPath.keys()) })}
Dynamic files must always be opened with service's current directory or service should support inferred project per projectRootPath.`);
                            if (!openedByClient && !isDynamic && !(hostToQueryFileExistsOn || this.host).fileExists(fileName)) {
                                return;
                            }
                            info = new ScriptInfo(this.host, fileName, scriptKind, !!hasMixedContent, path, this.filenameToScriptInfoVersion.get(path));
                            this.filenameToScriptInfo.set(info.path, info);
                            this.filenameToScriptInfoVersion.delete(info.path);
                            if (!openedByClient) {
                                this.watchClosedScriptInfo(info);
                            }
                            else if (!isRootedDiskPath(fileName) && (!isDynamic || this.currentDirectory !== currentDirectory)) {
                                this.openFilesWithNonRootedDiskPath.set(this.toCanonicalFileName(fileName), info);
                            }
                        }
                        if (openedByClient) {
                            this.stopWatchingScriptInfo(info);
                            info.open(fileContent);
                            if (hasMixedContent) {
                                info.registerFileUpdate();
                            }
                        }
                        return info;
                    }
                    /**
                     * This gets the script info for the normalized path. If the path is not rooted disk path then the open script info with project root context is preferred
                     */
                    getScriptInfoForNormalizedPath(fileName) {
                        return !isRootedDiskPath(fileName) && this.openFilesWithNonRootedDiskPath.get(this.toCanonicalFileName(fileName)) || this.getScriptInfoForPath(normalizedPathToPath(fileName, this.currentDirectory, this.toCanonicalFileName));
                    }
                    getScriptInfoForPath(fileName) {
                        return this.filenameToScriptInfo.get(fileName);
                    }
                    /** @internal */
                    getDocumentPositionMapper(project, generatedFileName, sourceFileName) {
                        const declarationInfo = this.getOrCreateScriptInfoNotOpenedByClient(generatedFileName, project.currentDirectory, this.host);
                        if (!declarationInfo) {
                            if (sourceFileName) {
                                project.addGeneratedFileWatch(generatedFileName, sourceFileName);
                            }
                            return void 0;
                        }
                        declarationInfo.getSnapshot();
                        if (isString(declarationInfo.sourceMapFilePath)) {
                            const sourceMapFileInfo2 = this.getScriptInfoForPath(declarationInfo.sourceMapFilePath);
                            if (sourceMapFileInfo2) {
                                sourceMapFileInfo2.getSnapshot();
                                if (sourceMapFileInfo2.documentPositionMapper !== void 0) {
                                    sourceMapFileInfo2.sourceInfos = this.addSourceInfoToSourceMap(sourceFileName, project, sourceMapFileInfo2.sourceInfos);
                                    return sourceMapFileInfo2.documentPositionMapper ? sourceMapFileInfo2.documentPositionMapper : void 0;
                                }
                            }
                            declarationInfo.sourceMapFilePath = void 0;
                        }
                        else if (declarationInfo.sourceMapFilePath) {
                            declarationInfo.sourceMapFilePath.sourceInfos = this.addSourceInfoToSourceMap(sourceFileName, project, declarationInfo.sourceMapFilePath.sourceInfos);
                            return void 0;
                        }
                        else if (declarationInfo.sourceMapFilePath !== void 0) {
                            return void 0;
                        }
                        let sourceMapFileInfo;
                        let mapFileNameFromDeclarationInfo;
                        let readMapFile = (mapFileName, mapFileNameFromDts) => {
                            const mapInfo = this.getOrCreateScriptInfoNotOpenedByClient(mapFileName, project.currentDirectory, this.host);
                            if (!mapInfo) {
                                mapFileNameFromDeclarationInfo = mapFileNameFromDts;
                                return void 0;
                            }
                            sourceMapFileInfo = mapInfo;
                            const snap = mapInfo.getSnapshot();
                            if (mapInfo.documentPositionMapper !== void 0)
                                return mapInfo.documentPositionMapper;
                            return getSnapshotText(snap);
                        };
                        const projectName = project.projectName;
                        const documentPositionMapper = getDocumentPositionMapper({ getCanonicalFileName: this.toCanonicalFileName, log: (s) => this.logger.info(s), getSourceFileLike: (f) => this.getSourceFileLike(f, projectName, declarationInfo) }, declarationInfo.fileName, declarationInfo.textStorage.getLineInfo(), readMapFile);
                        readMapFile = void 0;
                        if (sourceMapFileInfo) {
                            declarationInfo.sourceMapFilePath = sourceMapFileInfo.path;
                            sourceMapFileInfo.declarationInfoPath = declarationInfo.path;
                            sourceMapFileInfo.documentPositionMapper = documentPositionMapper || false;
                            sourceMapFileInfo.sourceInfos = this.addSourceInfoToSourceMap(sourceFileName, project, sourceMapFileInfo.sourceInfos);
                        }
                        else if (mapFileNameFromDeclarationInfo) {
                            declarationInfo.sourceMapFilePath = {
                                watcher: this.addMissingSourceMapFile(project.currentDirectory === this.currentDirectory ? mapFileNameFromDeclarationInfo : getNormalizedAbsolutePath(mapFileNameFromDeclarationInfo, project.currentDirectory), declarationInfo.path),
                                sourceInfos: this.addSourceInfoToSourceMap(sourceFileName, project)
                            };
                        }
                        else {
                            declarationInfo.sourceMapFilePath = false;
                        }
                        return documentPositionMapper;
                    }
                    addSourceInfoToSourceMap(sourceFileName, project, sourceInfos) {
                        if (sourceFileName) {
                            const sourceInfo = this.getOrCreateScriptInfoNotOpenedByClient(sourceFileName, project.currentDirectory, project.directoryStructureHost);
                            (sourceInfos || (sourceInfos = /* @__PURE__ */ new Set())).add(sourceInfo.path);
                        }
                        return sourceInfos;
                    }
                    addMissingSourceMapFile(mapFileName, declarationInfoPath) {
                        const fileWatcher = this.watchFactory.watchFile(mapFileName, () => {
                            const declarationInfo = this.getScriptInfoForPath(declarationInfoPath);
                            if (declarationInfo && declarationInfo.sourceMapFilePath && !isString(declarationInfo.sourceMapFilePath)) {
                                this.delayUpdateProjectGraphs(declarationInfo.containingProjects, 
                                /*clearSourceMapperCache*/
                                true);
                                this.delayUpdateSourceInfoProjects(declarationInfo.sourceMapFilePath.sourceInfos);
                                declarationInfo.closeSourceMapFileWatcher();
                            }
                        }, 2e3 /* High */, this.hostConfiguration.watchOptions, WatchType.MissingSourceMapFile);
                        return fileWatcher;
                    }
                    /** @internal */
                    getSourceFileLike(fileName, projectNameOrProject, declarationInfo) {
                        const project = projectNameOrProject.projectName ? projectNameOrProject : this.findProject(projectNameOrProject);
                        if (project) {
                            const path = project.toPath(fileName);
                            const sourceFile = project.getSourceFile(path);
                            if (sourceFile && sourceFile.resolvedPath === path)
                                return sourceFile;
                        }
                        const info = this.getOrCreateScriptInfoNotOpenedByClient(fileName, (project || this).currentDirectory, project ? project.directoryStructureHost : this.host);
                        if (!info)
                            return void 0;
                        if (declarationInfo && isString(declarationInfo.sourceMapFilePath) && info !== declarationInfo) {
                            const sourceMapInfo = this.getScriptInfoForPath(declarationInfo.sourceMapFilePath);
                            if (sourceMapInfo) {
                                (sourceMapInfo.sourceInfos || (sourceMapInfo.sourceInfos = /* @__PURE__ */ new Set())).add(info.path);
                            }
                        }
                        if (info.cacheSourceFile)
                            return info.cacheSourceFile.sourceFile;
                        if (!info.sourceFileLike) {
                            info.sourceFileLike = {
                                get text() {
                                    Debug.fail("shouldnt need text");
                                    return "";
                                },
                                getLineAndCharacterOfPosition: (pos) => {
                                    const lineOffset = info.positionToLineOffset(pos);
                                    return { line: lineOffset.line - 1, character: lineOffset.offset - 1 };
                                },
                                getPositionOfLineAndCharacter: (line, character, allowEdits) => info.lineOffsetToPosition(line + 1, character + 1, allowEdits)
                            };
                        }
                        return info.sourceFileLike;
                    }
                    /** @internal */
                    setPerformanceEventHandler(performanceEventHandler) {
                        this.performanceEventHandler = performanceEventHandler;
                    }
                    setHostConfiguration(args) {
                        var _a;
                        if (args.file) {
                            const info = this.getScriptInfoForNormalizedPath(toNormalizedPath(args.file));
                            if (info) {
                                info.setOptions(convertFormatOptions(args.formatOptions), args.preferences);
                                this.logger.info(`Host configuration update for file ${args.file}`);
                            }
                        }
                        else {
                            if (args.hostInfo !== void 0) {
                                this.hostConfiguration.hostInfo = args.hostInfo;
                                this.logger.info(`Host information ${args.hostInfo}`);
                            }
                            if (args.formatOptions) {
                                this.hostConfiguration.formatCodeOptions = { ...this.hostConfiguration.formatCodeOptions, ...convertFormatOptions(args.formatOptions) };
                                this.logger.info("Format host information updated");
                            }
                            if (args.preferences) {
                                const { lazyConfiguredProjectsFromExternalProject, includePackageJsonAutoImports } = this.hostConfiguration.preferences;
                                this.hostConfiguration.preferences = { ...this.hostConfiguration.preferences, ...args.preferences };
                                if (lazyConfiguredProjectsFromExternalProject && !this.hostConfiguration.preferences.lazyConfiguredProjectsFromExternalProject) {
                                    this.externalProjectToConfiguredProjectMap.forEach((projects) => projects.forEach((project) => {
                                        if (!project.isClosed() && project.hasExternalProjectRef() && project.pendingUpdateLevel === 2 /* Full */ && !this.pendingProjectUpdates.has(project.getProjectName())) {
                                            project.updateGraph();
                                        }
                                    }));
                                }
                                if (includePackageJsonAutoImports !== args.preferences.includePackageJsonAutoImports) {
                                    this.forEachProject((project) => {
                                        project.onAutoImportProviderSettingsChanged();
                                    });
                                }
                            }
                            if (args.extraFileExtensions) {
                                this.hostConfiguration.extraFileExtensions = args.extraFileExtensions;
                                this.reloadProjects();
                                this.logger.info("Host file extension mappings updated");
                            }
                            if (args.watchOptions) {
                                this.hostConfiguration.watchOptions = (_a = convertWatchOptions(args.watchOptions)) == null ? void 0 : _a.watchOptions;
                                this.logger.info(`Host watch options changed to ${JSON.stringify(this.hostConfiguration.watchOptions)}, it will be take effect for next watches.`);
                            }
                        }
                    }
                    /** @internal */
                    getWatchOptions(project) {
                        return this.getWatchOptionsFromProjectWatchOptions(project.getWatchOptions());
                    }
                    /** @internal */
                    getWatchOptionsFromProjectWatchOptions(projectOptions) {
                        return projectOptions && this.hostConfiguration.watchOptions ? { ...this.hostConfiguration.watchOptions, ...projectOptions } : projectOptions || this.hostConfiguration.watchOptions;
                    }
                    closeLog() {
                        this.logger.close();
                    }
                    /**
                     * This function rebuilds the project for every file opened by the client
                     * This does not reload contents of open files from disk. But we could do that if needed
                     */
                    reloadProjects() {
                        this.logger.info("reload projects.");
                        this.filenameToScriptInfo.forEach((info) => {
                            if (this.openFiles.has(info.path))
                                return;
                            if (!info.fileWatcher)
                                return;
                            this.onSourceFileChanged(info, this.host.fileExists(info.fileName) ? 1 /* Changed */ : 2 /* Deleted */);
                        });
                        this.pendingProjectUpdates.forEach((_project, projectName) => {
                            this.throttledOperations.cancel(projectName);
                            this.pendingProjectUpdates.delete(projectName);
                        });
                        this.throttledOperations.cancel(ensureProjectForOpenFileSchedule);
                        this.pendingEnsureProjectForOpenFiles = false;
                        this.configFileExistenceInfoCache.forEach((info) => {
                            if (info.config)
                                info.config.updateLevel = 2 /* Full */;
                        });
                        this.reloadConfiguredProjectForFiles(this.openFiles, 
                        /*clearSemanticCache*/
                        true, 
                        /*delayReload*/
                        false, returnTrue, "User requested reload projects");
                        this.externalProjects.forEach((project) => {
                            this.clearSemanticCache(project);
                            project.updateGraph();
                        });
                        this.inferredProjects.forEach((project) => this.clearSemanticCache(project));
                        this.ensureProjectForOpenFiles();
                        this.logger.info("After reloading projects..");
                        this.printProjects();
                    }
                    /**
                     * This function goes through all the openFiles and tries to file the config file for them.
                     * If the config file is found and it refers to existing project, it reloads it either immediately
                     * or schedules it for reload depending on delayReload option
                     * If there is no existing project it just opens the configured project for the config file
                     * reloadForInfo provides a way to filter out files to reload configured project for
                     */
                    reloadConfiguredProjectForFiles(openFiles, clearSemanticCache, delayReload, shouldReloadProjectFor, reason) {
                        const updatedProjects = /* @__PURE__ */ new Map();
                        const reloadChildProject = (child) => {
                            if (!updatedProjects.has(child.canonicalConfigFilePath)) {
                                updatedProjects.set(child.canonicalConfigFilePath, true);
                                this.reloadConfiguredProject(child, reason, 
                                /*isInitialLoad*/
                                false, clearSemanticCache);
                            }
                        };
                        openFiles == null ? void 0 : openFiles.forEach((openFileValue, path) => {
                            this.configFileForOpenFiles.delete(path);
                            if (!shouldReloadProjectFor(openFileValue)) {
                                return;
                            }
                            const info = this.getScriptInfoForPath(path);
                            Debug.assert(info.isScriptOpen());
                            const configFileName = this.getConfigFileNameForFile(info);
                            if (configFileName) {
                                const project = this.findConfiguredProjectByProjectName(configFileName) || this.createConfiguredProject(configFileName);
                                if (!updatedProjects.has(project.canonicalConfigFilePath)) {
                                    updatedProjects.set(project.canonicalConfigFilePath, true);
                                    if (delayReload) {
                                        project.pendingUpdateLevel = 2 /* Full */;
                                        project.pendingUpdateReason = reason;
                                        if (clearSemanticCache)
                                            this.clearSemanticCache(project);
                                        this.delayUpdateProjectGraph(project);
                                    }
                                    else {
                                        this.reloadConfiguredProject(project, reason, 
                                        /*isInitialLoad*/
                                        false, clearSemanticCache);
                                        if (!projectContainsInfoDirectly(project, info)) {
                                            const referencedProject = forEachResolvedProjectReferenceProject(project, info.path, (child) => {
                                                reloadChildProject(child);
                                                return projectContainsInfoDirectly(child, info);
                                            }, 1 /* FindCreate */);
                                            if (referencedProject) {
                                                forEachResolvedProjectReferenceProject(project, 
                                                /*fileName*/
                                                void 0, reloadChildProject, 0 /* Find */);
                                            }
                                        }
                                    }
                                }
                            }
                        });
                    }
                    /**
                     * Remove the root of inferred project if script info is part of another project
                     */
                    removeRootOfInferredProjectIfNowPartOfOtherProject(info) {
                        Debug.assert(info.containingProjects.length > 0);
                        const firstProject = info.containingProjects[0];
                        if (!firstProject.isOrphan() && isInferredProject(firstProject) && firstProject.isRoot(info) && forEach(info.containingProjects, (p) => p !== firstProject && !p.isOrphan())) {
                            firstProject.removeFile(info, 
                            /*fileExists*/
                            true, 
                            /*detachFromProject*/
                            true);
                        }
                    }
                    /**
                     * This function is to update the project structure for every inferred project.
                     * It is called on the premise that all the configured projects are
                     * up to date.
                     * This will go through open files and assign them to inferred project if open file is not part of any other project
                     * After that all the inferred project graphs are updated
                     */
                    ensureProjectForOpenFiles() {
                        this.logger.info("Before ensureProjectForOpenFiles:");
                        this.printProjects();
                        this.openFiles.forEach((projectRootPath, path) => {
                            const info = this.getScriptInfoForPath(path);
                            if (info.isOrphan()) {
                                this.assignOrphanScriptInfoToInferredProject(info, projectRootPath);
                            }
                            else {
                                this.removeRootOfInferredProjectIfNowPartOfOtherProject(info);
                            }
                        });
                        this.pendingEnsureProjectForOpenFiles = false;
                        this.inferredProjects.forEach(updateProjectIfDirty);
                        this.logger.info("After ensureProjectForOpenFiles:");
                        this.printProjects();
                    }
                    /**
                     * Open file whose contents is managed by the client
                     * @param filename is absolute pathname
                     * @param fileContent is a known version of the file content that is more up to date than the one on disk
                     */
                    openClientFile(fileName, fileContent, scriptKind, projectRootPath) {
                        return this.openClientFileWithNormalizedPath(toNormalizedPath(fileName), fileContent, scriptKind, 
                        /*hasMixedContent*/
                        false, projectRootPath ? toNormalizedPath(projectRootPath) : void 0);
                    }
                    /** @internal */
                    getOriginalLocationEnsuringConfiguredProject(project, location) {
                        const isSourceOfProjectReferenceRedirect = project.isSourceOfProjectReferenceRedirect(location.fileName);
                        const originalLocation = isSourceOfProjectReferenceRedirect ? location : project.getSourceMapper().tryGetSourcePosition(location);
                        if (!originalLocation)
                            return void 0;
                        const { fileName } = originalLocation;
                        const scriptInfo = this.getScriptInfo(fileName);
                        if (!scriptInfo && !this.host.fileExists(fileName))
                            return void 0;
                        const originalFileInfo = { fileName: toNormalizedPath(fileName), path: this.toPath(fileName) };
                        const configFileName = this.getConfigFileNameForFile(originalFileInfo);
                        if (!configFileName)
                            return void 0;
                        let configuredProject = this.findConfiguredProjectByProjectName(configFileName);
                        if (!configuredProject) {
                            if (project.getCompilerOptions().disableReferencedProjectLoad) {
                                if (isSourceOfProjectReferenceRedirect) {
                                    return location;
                                }
                                return (scriptInfo == null ? void 0 : scriptInfo.containingProjects.length) ? originalLocation : location;
                            }
                            configuredProject = this.createAndLoadConfiguredProject(configFileName, `Creating project for original file: ${originalFileInfo.fileName}${location !== originalLocation ? " for location: " + location.fileName : ""}`);
                        }
                        updateProjectIfDirty(configuredProject);
                        const projectContainsOriginalInfo = (project2) => {
                            const info = this.getScriptInfo(fileName);
                            return info && projectContainsInfoDirectly(project2, info);
                        };
                        if (configuredProject.isSolution() || !projectContainsOriginalInfo(configuredProject)) {
                            configuredProject = forEachResolvedProjectReferenceProject(configuredProject, fileName, (child) => {
                                updateProjectIfDirty(child);
                                return projectContainsOriginalInfo(child) ? child : void 0;
                            }, 2 /* FindCreateLoad */, `Creating project referenced in solution ${configuredProject.projectName} to find possible configured project for original file: ${originalFileInfo.fileName}${location !== originalLocation ? " for location: " + location.fileName : ""}`);
                            if (!configuredProject)
                                return void 0;
                            if (configuredProject === project)
                                return originalLocation;
                        }
                        addOriginalConfiguredProject(configuredProject);
                        const originalScriptInfo = this.getScriptInfo(fileName);
                        if (!originalScriptInfo || !originalScriptInfo.containingProjects.length)
                            return void 0;
                        originalScriptInfo.containingProjects.forEach((project2) => {
                            if (isConfiguredProject(project2)) {
                                addOriginalConfiguredProject(project2);
                            }
                        });
                        return originalLocation;
                        function addOriginalConfiguredProject(originalProject) {
                            if (!project.originalConfiguredProjects) {
                                project.originalConfiguredProjects = /* @__PURE__ */ new Set();
                            }
                            project.originalConfiguredProjects.add(originalProject.canonicalConfigFilePath);
                        }
                    }
                    /** @internal */
                    fileExists(fileName) {
                        return !!this.getScriptInfoForNormalizedPath(fileName) || this.host.fileExists(fileName);
                    }
                    findExternalProjectContainingOpenScriptInfo(info) {
                        return find(this.externalProjects, (proj) => {
                            updateProjectIfDirty(proj);
                            return proj.containsScriptInfo(info);
                        });
                    }
                    getOrCreateOpenScriptInfo(fileName, fileContent, scriptKind, hasMixedContent, projectRootPath) {
                        const info = this.getOrCreateScriptInfoOpenedByClientForNormalizedPath(fileName, projectRootPath ? this.getNormalizedAbsolutePath(projectRootPath) : this.currentDirectory, fileContent, scriptKind, hasMixedContent);
                        this.openFiles.set(info.path, projectRootPath);
                        return info;
                    }
                    assignProjectToOpenedScriptInfo(info) {
                        let configFileName;
                        let configFileErrors;
                        let project = this.findExternalProjectContainingOpenScriptInfo(info);
                        let retainProjects;
                        let projectForConfigFileDiag;
                        let defaultConfigProjectIsCreated = false;
                        if (!project && this.serverMode === 0 /* Semantic */) {
                            configFileName = this.getConfigFileNameForFile(info);
                            if (configFileName) {
                                project = this.findConfiguredProjectByProjectName(configFileName);
                                if (!project) {
                                    project = this.createLoadAndUpdateConfiguredProject(configFileName, `Creating possible configured project for ${info.fileName} to open`);
                                    defaultConfigProjectIsCreated = true;
                                }
                                else {
                                    updateProjectIfDirty(project);
                                }
                                projectForConfigFileDiag = project.containsScriptInfo(info) ? project : void 0;
                                retainProjects = project;
                                if (!projectContainsInfoDirectly(project, info)) {
                                    forEachResolvedProjectReferenceProject(project, info.path, (child) => {
                                        updateProjectIfDirty(child);
                                        if (!isArray(retainProjects)) {
                                            retainProjects = [project, child];
                                        }
                                        else {
                                            retainProjects.push(child);
                                        }
                                        if (projectContainsInfoDirectly(child, info)) {
                                            projectForConfigFileDiag = child;
                                            return child;
                                        }
                                        if (!projectForConfigFileDiag && child.containsScriptInfo(info)) {
                                            projectForConfigFileDiag = child;
                                        }
                                    }, 2 /* FindCreateLoad */, `Creating project referenced in solution ${project.projectName} to find possible configured project for ${info.fileName} to open`);
                                }
                                if (projectForConfigFileDiag) {
                                    configFileName = projectForConfigFileDiag.getConfigFilePath();
                                    if (projectForConfigFileDiag !== project || defaultConfigProjectIsCreated) {
                                        configFileErrors = projectForConfigFileDiag.getAllProjectErrors();
                                        this.sendConfigFileDiagEvent(projectForConfigFileDiag, info.fileName);
                                    }
                                }
                                else {
                                    configFileName = void 0;
                                }
                                this.createAncestorProjects(info, project);
                            }
                        }
                        info.containingProjects.forEach(updateProjectIfDirty);
                        if (info.isOrphan()) {
                            if (isArray(retainProjects)) {
                                retainProjects.forEach((project2) => this.sendConfigFileDiagEvent(project2, info.fileName));
                            }
                            else if (retainProjects) {
                                this.sendConfigFileDiagEvent(retainProjects, info.fileName);
                            }
                            Debug.assert(this.openFiles.has(info.path));
                            this.assignOrphanScriptInfoToInferredProject(info, this.openFiles.get(info.path));
                        }
                        Debug.assert(!info.isOrphan());
                        return { configFileName, configFileErrors, retainProjects };
                    }
                    createAncestorProjects(info, project) {
                        if (!info.isAttached(project))
                            return;
                        while (true) {
                            if (!project.isInitialLoadPending() && (!project.getCompilerOptions().composite || project.getCompilerOptions().disableSolutionSearching))
                                return;
                            const configFileName = this.getConfigFileNameForFile({
                                fileName: project.getConfigFilePath(),
                                path: info.path,
                                configFileInfo: true
                            });
                            if (!configFileName)
                                return;
                            const ancestor = this.findConfiguredProjectByProjectName(configFileName) || this.createConfiguredProjectWithDelayLoad(configFileName, `Creating project possibly referencing default composite project ${project.getProjectName()} of open file ${info.fileName}`);
                            if (ancestor.isInitialLoadPending()) {
                                ancestor.setPotentialProjectReference(project.canonicalConfigFilePath);
                            }
                            project = ancestor;
                        }
                    }
                    /** @internal */
                    loadAncestorProjectTree(forProjects) {
                        forProjects = forProjects || mapDefinedEntries(this.configuredProjects, (key, project) => !project.isInitialLoadPending() ? [key, true] : void 0);
                        const seenProjects = /* @__PURE__ */ new Set();
                        for (const project of arrayFrom(this.configuredProjects.values())) {
                            if (forEachPotentialProjectReference(project, (potentialRefPath) => forProjects.has(potentialRefPath))) {
                                updateProjectIfDirty(project);
                            }
                            this.ensureProjectChildren(project, forProjects, seenProjects);
                        }
                    }
                    ensureProjectChildren(project, forProjects, seenProjects) {
                        var _a;
                        if (!tryAddToSet(seenProjects, project.canonicalConfigFilePath))
                            return;
                        if (project.getCompilerOptions().disableReferencedProjectLoad)
                            return;
                        const children = (_a = project.getCurrentProgram()) == null ? void 0 : _a.getResolvedProjectReferences();
                        if (!children)
                            return;
                        for (const child of children) {
                            if (!child)
                                continue;
                            const referencedProject = forEachResolvedProjectReference(child.references, (ref) => forProjects.has(ref.sourceFile.path) ? ref : void 0);
                            if (!referencedProject)
                                continue;
                            const configFileName = toNormalizedPath(child.sourceFile.fileName);
                            const childProject = project.projectService.findConfiguredProjectByProjectName(configFileName) || project.projectService.createAndLoadConfiguredProject(configFileName, `Creating project referenced by : ${project.projectName} as it references project ${referencedProject.sourceFile.fileName}`);
                            updateProjectIfDirty(childProject);
                            this.ensureProjectChildren(childProject, forProjects, seenProjects);
                        }
                    }
                    cleanupAfterOpeningFile(toRetainConfigProjects) {
                        this.removeOrphanConfiguredProjects(toRetainConfigProjects);
                        for (const inferredProject of this.inferredProjects.slice()) {
                            if (inferredProject.isOrphan()) {
                                this.removeProject(inferredProject);
                            }
                        }
                        this.removeOrphanScriptInfos();
                    }
                    openClientFileWithNormalizedPath(fileName, fileContent, scriptKind, hasMixedContent, projectRootPath) {
                        const info = this.getOrCreateOpenScriptInfo(fileName, fileContent, scriptKind, hasMixedContent, projectRootPath);
                        const { retainProjects, ...result } = this.assignProjectToOpenedScriptInfo(info);
                        this.cleanupAfterOpeningFile(retainProjects);
                        this.telemetryOnOpenFile(info);
                        this.printProjects();
                        return result;
                    }
                    removeOrphanConfiguredProjects(toRetainConfiguredProjects) {
                        const toRemoveConfiguredProjects = new Map(this.configuredProjects);
                        const markOriginalProjectsAsUsed = (project) => {
                            if (!project.isOrphan() && project.originalConfiguredProjects) {
                                project.originalConfiguredProjects.forEach((_value, configuredProjectPath) => {
                                    const project2 = this.getConfiguredProjectByCanonicalConfigFilePath(configuredProjectPath);
                                    return project2 && retainConfiguredProject(project2);
                                });
                            }
                        };
                        if (toRetainConfiguredProjects) {
                            if (isArray(toRetainConfiguredProjects)) {
                                toRetainConfiguredProjects.forEach(retainConfiguredProject);
                            }
                            else {
                                retainConfiguredProject(toRetainConfiguredProjects);
                            }
                        }
                        this.inferredProjects.forEach(markOriginalProjectsAsUsed);
                        this.externalProjects.forEach(markOriginalProjectsAsUsed);
                        this.configuredProjects.forEach((project) => {
                            if (project.hasOpenRef()) {
                                retainConfiguredProject(project);
                            }
                            else if (toRemoveConfiguredProjects.has(project.canonicalConfigFilePath)) {
                                forEachReferencedProject(project, (ref) => isRetained(ref) && retainConfiguredProject(project));
                            }
                        });
                        toRemoveConfiguredProjects.forEach((project) => this.removeProject(project));
                        function isRetained(project) {
                            return project.hasOpenRef() || !toRemoveConfiguredProjects.has(project.canonicalConfigFilePath);
                        }
                        function retainConfiguredProject(project) {
                            if (toRemoveConfiguredProjects.delete(project.canonicalConfigFilePath)) {
                                markOriginalProjectsAsUsed(project);
                                forEachReferencedProject(project, retainConfiguredProject);
                            }
                        }
                    }
                    removeOrphanScriptInfos() {
                        const toRemoveScriptInfos = new Map(this.filenameToScriptInfo);
                        this.filenameToScriptInfo.forEach((info) => {
                            if (!info.isScriptOpen() && info.isOrphan() && !info.isContainedByBackgroundProject()) {
                                if (!info.sourceMapFilePath)
                                    return;
                                let sourceInfos;
                                if (isString(info.sourceMapFilePath)) {
                                    const sourceMapInfo = this.getScriptInfoForPath(info.sourceMapFilePath);
                                    sourceInfos = sourceMapInfo && sourceMapInfo.sourceInfos;
                                }
                                else {
                                    sourceInfos = info.sourceMapFilePath.sourceInfos;
                                }
                                if (!sourceInfos)
                                    return;
                                if (!forEachKey(sourceInfos, (path) => {
                                    const info2 = this.getScriptInfoForPath(path);
                                    return !!info2 && (info2.isScriptOpen() || !info2.isOrphan());
                                })) {
                                    return;
                                }
                            }
                            toRemoveScriptInfos.delete(info.path);
                            if (info.sourceMapFilePath) {
                                let sourceInfos;
                                if (isString(info.sourceMapFilePath)) {
                                    toRemoveScriptInfos.delete(info.sourceMapFilePath);
                                    const sourceMapInfo = this.getScriptInfoForPath(info.sourceMapFilePath);
                                    sourceInfos = sourceMapInfo && sourceMapInfo.sourceInfos;
                                }
                                else {
                                    sourceInfos = info.sourceMapFilePath.sourceInfos;
                                }
                                if (sourceInfos) {
                                    sourceInfos.forEach((_value, path) => toRemoveScriptInfos.delete(path));
                                }
                            }
                        });
                        toRemoveScriptInfos.forEach((info) => {
                            this.stopWatchingScriptInfo(info);
                            this.deleteScriptInfo(info);
                            info.closeSourceMapFileWatcher();
                        });
                    }
                    telemetryOnOpenFile(scriptInfo) {
                        if (this.serverMode !== 0 /* Semantic */ || !this.eventHandler || !scriptInfo.isJavaScript() || !addToSeen(this.allJsFilesForOpenFileTelemetry, scriptInfo.path)) {
                            return;
                        }
                        const project = this.ensureDefaultProjectForFile(scriptInfo);
                        if (!project.languageServiceEnabled) {
                            return;
                        }
                        const sourceFile = project.getSourceFile(scriptInfo.path);
                        const checkJs = !!sourceFile && !!sourceFile.checkJsDirective;
                        this.eventHandler({ eventName: OpenFileInfoTelemetryEvent, data: { info: { checkJs } } });
                    }
                    closeClientFile(uncheckedFileName, skipAssignOrphanScriptInfosToInferredProject) {
                        const info = this.getScriptInfoForNormalizedPath(toNormalizedPath(uncheckedFileName));
                        const result = info ? this.closeOpenFile(info, skipAssignOrphanScriptInfosToInferredProject) : false;
                        if (!skipAssignOrphanScriptInfosToInferredProject) {
                            this.printProjects();
                        }
                        return result;
                    }
                    collectChanges(lastKnownProjectVersions, currentProjects, includeProjectReferenceRedirectInfo, result) {
                        for (const proj of currentProjects) {
                            const knownProject = find(lastKnownProjectVersions, (p) => p.projectName === proj.getProjectName());
                            result.push(proj.getChangesSinceVersion(knownProject && knownProject.version, includeProjectReferenceRedirectInfo));
                        }
                    }
                    /** @internal */
                    synchronizeProjectList(knownProjects, includeProjectReferenceRedirectInfo) {
                        const files = [];
                        this.collectChanges(knownProjects, this.externalProjects, includeProjectReferenceRedirectInfo, files);
                        this.collectChanges(knownProjects, this.configuredProjects.values(), includeProjectReferenceRedirectInfo, files);
                        this.collectChanges(knownProjects, this.inferredProjects, includeProjectReferenceRedirectInfo, files);
                        return files;
                    }
                    /** @internal */
                    applyChangesInOpenFiles(openFiles, changedFiles, closedFiles) {
                        let openScriptInfos;
                        let assignOrphanScriptInfosToInferredProject = false;
                        if (openFiles) {
                            for (const file of openFiles) {
                                const info = this.getOrCreateOpenScriptInfo(toNormalizedPath(file.fileName), file.content, tryConvertScriptKindName(file.scriptKind), file.hasMixedContent, file.projectRootPath ? toNormalizedPath(file.projectRootPath) : void 0);
                                (openScriptInfos || (openScriptInfos = [])).push(info);
                            }
                        }
                        if (changedFiles) {
                            for (const file of changedFiles) {
                                const scriptInfo = this.getScriptInfo(file.fileName);
                                Debug.assert(!!scriptInfo);
                                this.applyChangesToFile(scriptInfo, file.changes);
                            }
                        }
                        if (closedFiles) {
                            for (const file of closedFiles) {
                                assignOrphanScriptInfosToInferredProject = this.closeClientFile(file, 
                                /*skipAssignOrphanScriptInfosToInferredProject*/
                                true) || assignOrphanScriptInfosToInferredProject;
                            }
                        }
                        let retainProjects;
                        if (openScriptInfos) {
                            retainProjects = flatMap(openScriptInfos, (info) => this.assignProjectToOpenedScriptInfo(info).retainProjects);
                        }
                        if (assignOrphanScriptInfosToInferredProject) {
                            this.assignOrphanScriptInfosToInferredProject();
                        }
                        if (openScriptInfos) {
                            this.cleanupAfterOpeningFile(retainProjects);
                            openScriptInfos.forEach((info) => this.telemetryOnOpenFile(info));
                            this.printProjects();
                        }
                        else if (length(closedFiles)) {
                            this.printProjects();
                        }
                    }
                    /** @internal */
                    applyChangesToFile(scriptInfo, changes) {
                        for (const change of changes) {
                            scriptInfo.editContent(change.span.start, change.span.start + change.span.length, change.newText);
                        }
                    }
                    closeConfiguredProjectReferencedFromExternalProject(configuredProjects) {
                        configuredProjects == null ? void 0 : configuredProjects.forEach((configuredProject) => {
                            if (!configuredProject.isClosed()) {
                                configuredProject.deleteExternalProjectReference();
                                if (!configuredProject.hasOpenRef())
                                    this.removeProject(configuredProject);
                            }
                        });
                    }
                    closeExternalProject(uncheckedFileName, print) {
                        const fileName = toNormalizedPath(uncheckedFileName);
                        const configuredProjects = this.externalProjectToConfiguredProjectMap.get(fileName);
                        if (configuredProjects) {
                            this.closeConfiguredProjectReferencedFromExternalProject(configuredProjects);
                            this.externalProjectToConfiguredProjectMap.delete(fileName);
                        }
                        else {
                            const externalProject = this.findExternalProjectByProjectName(uncheckedFileName);
                            if (externalProject) {
                                this.removeProject(externalProject);
                            }
                        }
                        if (print)
                            this.printProjects();
                    }
                    openExternalProjects(projects) {
                        const projectsToClose = arrayToMap(this.externalProjects, (p) => p.getProjectName(), (_) => true);
                        forEachKey(this.externalProjectToConfiguredProjectMap, (externalProjectName) => {
                            projectsToClose.set(externalProjectName, true);
                        });
                        for (const externalProject of projects) {
                            this.openExternalProject(externalProject, 
                            /*print*/
                            false);
                            projectsToClose.delete(externalProject.projectFileName);
                        }
                        forEachKey(projectsToClose, (externalProjectName) => {
                            this.closeExternalProject(externalProjectName, 
                            /*print*/
                            false);
                        });
                        this.printProjects();
                    }
                    static escapeFilenameForRegex(filename) {
                        return filename.replace(this.filenameEscapeRegexp, "\\$&");
                    }
                    resetSafeList() {
                        this.safelist = defaultTypeSafeList;
                    }
                    applySafeList(proj) {
                        const typeAcquisition = proj.typeAcquisition;
                        Debug.assert(!!typeAcquisition, "proj.typeAcquisition should be set by now");
                        const result = this.applySafeListWorker(proj, proj.rootFiles, typeAcquisition);
                        return (result == null ? void 0 : result.excludedFiles) ?? [];
                    }
                    applySafeListWorker(proj, rootFiles, typeAcquisition) {
                        if (typeAcquisition.enable === false || typeAcquisition.disableFilenameBasedTypeAcquisition) {
                            return void 0;
                        }
                        const typeAcqInclude = typeAcquisition.include || (typeAcquisition.include = []);
                        const excludeRules = [];
                        const normalizedNames = rootFiles.map((f) => normalizeSlashes(f.fileName));
                        for (const name of Object.keys(this.safelist)) {
                            const rule2 = this.safelist[name];
                            for (const root of normalizedNames) {
                                if (rule2.match.test(root)) {
                                    this.logger.info(`Excluding files based on rule ${name} matching file '${root}'`);
                                    if (rule2.types) {
                                        for (const type of rule2.types) {
                                            if (!typeAcqInclude.includes(type)) {
                                                typeAcqInclude.push(type);
                                            }
                                        }
                                    }
                                    if (rule2.exclude) {
                                        for (const exclude of rule2.exclude) {
                                            const processedRule = root.replace(rule2.match, (...groups) => {
                                                return exclude.map((groupNumberOrString) => {
                                                    if (typeof groupNumberOrString === "number") {
                                                        if (!isString(groups[groupNumberOrString])) {
                                                            this.logger.info(`Incorrect RegExp specification in safelist rule ${name} - not enough groups`);
                                                            return "\\*";
                                                        }
                                                        return _ProjectService.escapeFilenameForRegex(groups[groupNumberOrString]);
                                                    }
                                                    return groupNumberOrString;
                                                }).join("");
                                            });
                                            if (!excludeRules.includes(processedRule)) {
                                                excludeRules.push(processedRule);
                                            }
                                        }
                                    }
                                    else {
                                        const escaped = _ProjectService.escapeFilenameForRegex(root);
                                        if (!excludeRules.includes(escaped)) {
                                            excludeRules.push(escaped);
                                        }
                                    }
                                }
                            }
                        }
                        const excludeRegexes = excludeRules.map((e) => new RegExp(e, "i"));
                        let filesToKeep;
                        let excludedFiles;
                        for (let i = 0; i < rootFiles.length; i++) {
                            if (excludeRegexes.some((re) => re.test(normalizedNames[i]))) {
                                addExcludedFile(i);
                            }
                            else {
                                if (typeAcquisition.enable) {
                                    const baseName = getBaseFileName(toFileNameLowerCase(normalizedNames[i]));
                                    if (fileExtensionIs(baseName, "js")) {
                                        const inferredTypingName = removeFileExtension(baseName);
                                        const cleanedTypingName = removeMinAndVersionNumbers(inferredTypingName);
                                        const typeName = this.legacySafelist.get(cleanedTypingName);
                                        if (typeName !== void 0) {
                                            this.logger.info(`Excluded '${normalizedNames[i]}' because it matched ${cleanedTypingName} from the legacy safelist`);
                                            addExcludedFile(i);
                                            if (!typeAcqInclude.includes(typeName)) {
                                                typeAcqInclude.push(typeName);
                                            }
                                            continue;
                                        }
                                    }
                                }
                                if (/^.+[.-]min\.js$/.test(normalizedNames[i])) {
                                    addExcludedFile(i);
                                }
                                else {
                                    filesToKeep == null ? void 0 : filesToKeep.push(rootFiles[i]);
                                }
                            }
                        }
                        return excludedFiles ? {
                            rootFiles: filesToKeep,
                            excludedFiles
                        } : void 0;
                        function addExcludedFile(index) {
                            if (!excludedFiles) {
                                Debug.assert(!filesToKeep);
                                filesToKeep = rootFiles.slice(0, index);
                                excludedFiles = [];
                            }
                            excludedFiles.push(normalizedNames[index]);
                        }
                    }
                    openExternalProject(proj, print) {
                        const existingExternalProject = this.findExternalProjectByProjectName(proj.projectFileName);
                        const existingConfiguredProjects = this.externalProjectToConfiguredProjectMap.get(proj.projectFileName);
                        let configuredProjects;
                        let rootFiles = [];
                        for (const file of proj.rootFiles) {
                            const normalized = toNormalizedPath(file.fileName);
                            if (getBaseConfigFileName(normalized)) {
                                if (this.serverMode === 0 /* Semantic */ && this.host.fileExists(normalized)) {
                                    let project = this.findConfiguredProjectByProjectName(normalized);
                                    if (!project) {
                                        project = this.getHostPreferences().lazyConfiguredProjectsFromExternalProject ? this.createConfiguredProjectWithDelayLoad(normalized, `Creating configured project in external project: ${proj.projectFileName}`) : this.createLoadAndUpdateConfiguredProject(normalized, `Creating configured project in external project: ${proj.projectFileName}`);
                                    }
                                    if (!(existingConfiguredProjects == null ? void 0 : existingConfiguredProjects.has(project))) {
                                        project.addExternalProjectReference();
                                    }
                                    (configuredProjects ?? (configuredProjects = /* @__PURE__ */ new Set())).add(project);
                                    existingConfiguredProjects == null ? void 0 : existingConfiguredProjects.delete(project);
                                }
                            }
                            else {
                                rootFiles.push(file);
                            }
                        }
                        if (configuredProjects) {
                            this.externalProjectToConfiguredProjectMap.set(proj.projectFileName, configuredProjects);
                            if (existingExternalProject)
                                this.removeProject(existingExternalProject);
                        }
                        else {
                            this.externalProjectToConfiguredProjectMap.delete(proj.projectFileName);
                            const typeAcquisition = proj.typeAcquisition || {};
                            typeAcquisition.include = typeAcquisition.include || [];
                            typeAcquisition.exclude = typeAcquisition.exclude || [];
                            if (typeAcquisition.enable === void 0) {
                                typeAcquisition.enable = hasNoTypeScriptSource(rootFiles.map((f) => f.fileName));
                            }
                            const excludeResult = this.applySafeListWorker(proj, rootFiles, typeAcquisition);
                            const excludedFiles = (excludeResult == null ? void 0 : excludeResult.excludedFiles) ?? [];
                            rootFiles = (excludeResult == null ? void 0 : excludeResult.rootFiles) ?? rootFiles;
                            if (existingExternalProject) {
                                existingExternalProject.excludedFiles = excludedFiles;
                                const compilerOptions = convertCompilerOptions(proj.options);
                                const watchOptionsAndErrors = convertWatchOptions(proj.options, existingExternalProject.getCurrentDirectory());
                                const lastFileExceededProgramSize = this.getFilenameForExceededTotalSizeLimitForNonTsFiles(proj.projectFileName, compilerOptions, rootFiles, externalFilePropertyReader);
                                if (lastFileExceededProgramSize) {
                                    existingExternalProject.disableLanguageService(lastFileExceededProgramSize);
                                }
                                else {
                                    existingExternalProject.enableLanguageService();
                                }
                                existingExternalProject.setProjectErrors(watchOptionsAndErrors == null ? void 0 : watchOptionsAndErrors.errors);
                                this.updateRootAndOptionsOfNonInferredProject(existingExternalProject, rootFiles, externalFilePropertyReader, compilerOptions, typeAcquisition, proj.options.compileOnSave, watchOptionsAndErrors == null ? void 0 : watchOptionsAndErrors.watchOptions);
                                existingExternalProject.updateGraph();
                            }
                            else {
                                const project = this.createExternalProject(proj.projectFileName, rootFiles, proj.options, typeAcquisition, excludedFiles);
                                project.updateGraph();
                            }
                        }
                        this.closeConfiguredProjectReferencedFromExternalProject(existingConfiguredProjects);
                        if (print)
                            this.printProjects();
                    }
                    hasDeferredExtension() {
                        for (const extension of this.hostConfiguration.extraFileExtensions) {
                            if (extension.scriptKind === 7 /* Deferred */) {
                                return true;
                            }
                        }
                        return false;
                    }
                    /**
                     * Performs the initial steps of enabling a plugin by finding and instantiating the module for a plugin either asynchronously or synchronously
                     * @internal
                     */
                    requestEnablePlugin(project, pluginConfigEntry, searchPaths) {
                        if (!this.host.importPlugin && !this.host.require) {
                            this.logger.info("Plugins were requested but not running in environment that supports 'require'. Nothing will be loaded");
                            return;
                        }
                        this.logger.info(`Enabling plugin ${pluginConfigEntry.name} from candidate paths: ${searchPaths.join(",")}`);
                        if (!pluginConfigEntry.name || parsePackageName(pluginConfigEntry.name).rest) {
                            this.logger.info(`Skipped loading plugin ${pluginConfigEntry.name || JSON.stringify(pluginConfigEntry)} because only package name is allowed plugin name`);
                            return;
                        }
                        if (this.host.importPlugin) {
                            const importPromise = Project3.importServicePluginAsync(pluginConfigEntry, searchPaths, this.host, (s) => this.logger.info(s));
                            this.pendingPluginEnablements ?? (this.pendingPluginEnablements = /* @__PURE__ */ new Map());
                            let promises = this.pendingPluginEnablements.get(project);
                            if (!promises)
                                this.pendingPluginEnablements.set(project, promises = []);
                            promises.push(importPromise);
                            return;
                        }
                        this.endEnablePlugin(project, Project3.importServicePluginSync(pluginConfigEntry, searchPaths, this.host, (s) => this.logger.info(s)));
                    }
                    /**
                     * Performs the remaining steps of enabling a plugin after its module has been instantiated.
                     * @internal
                     */
                    endEnablePlugin(project, { pluginConfigEntry, resolvedModule, errorLogs }) {
                        var _a;
                        if (resolvedModule) {
                            const configurationOverride = (_a = this.currentPluginConfigOverrides) == null ? void 0 : _a.get(pluginConfigEntry.name);
                            if (configurationOverride) {
                                const pluginName = pluginConfigEntry.name;
                                pluginConfigEntry = configurationOverride;
                                pluginConfigEntry.name = pluginName;
                            }
                            project.enableProxy(resolvedModule, pluginConfigEntry);
                        }
                        else {
                            forEach(errorLogs, (message) => this.logger.info(message));
                            this.logger.info(`Couldn't find ${pluginConfigEntry.name}`);
                        }
                    }
                    /** @internal */
                    hasNewPluginEnablementRequests() {
                        return !!this.pendingPluginEnablements;
                    }
                    /** @internal */
                    hasPendingPluginEnablements() {
                        return !!this.currentPluginEnablementPromise;
                    }
                    /**
                     * Waits for any ongoing plugin enablement requests to complete.
                     *
                     * @internal
                     */
                    async waitForPendingPlugins() {
                        while (this.currentPluginEnablementPromise) {
                            await this.currentPluginEnablementPromise;
                        }
                    }
                    /**
                     * Starts enabling any requested plugins without waiting for the result.
                     *
                     * @internal
                     */
                    enableRequestedPlugins() {
                        if (this.pendingPluginEnablements) {
                            void this.enableRequestedPluginsAsync();
                        }
                    }
                    async enableRequestedPluginsAsync() {
                        if (this.currentPluginEnablementPromise) {
                            await this.waitForPendingPlugins();
                        }
                        if (!this.pendingPluginEnablements) {
                            return;
                        }
                        const entries = arrayFrom(this.pendingPluginEnablements.entries());
                        this.pendingPluginEnablements = void 0;
                        this.currentPluginEnablementPromise = this.enableRequestedPluginsWorker(entries);
                        await this.currentPluginEnablementPromise;
                    }
                    async enableRequestedPluginsWorker(pendingPlugins) {
                        Debug.assert(this.currentPluginEnablementPromise === void 0);
                        await Promise.all(map(pendingPlugins, ([project, promises]) => this.enableRequestedPluginsForProjectAsync(project, promises)));
                        this.currentPluginEnablementPromise = void 0;
                        this.sendProjectsUpdatedInBackgroundEvent();
                    }
                    async enableRequestedPluginsForProjectAsync(project, promises) {
                        const results = await Promise.all(promises);
                        if (project.isClosed()) {
                            return;
                        }
                        for (const result of results) {
                            this.endEnablePlugin(project, result);
                        }
                        this.delayUpdateProjectGraph(project);
                    }
                    configurePlugin(args) {
                        this.forEachEnabledProject((project) => project.onPluginConfigurationChanged(args.pluginName, args.configuration));
                        this.currentPluginConfigOverrides = this.currentPluginConfigOverrides || /* @__PURE__ */ new Map();
                        this.currentPluginConfigOverrides.set(args.pluginName, args.configuration);
                    }
                    /** @internal */
                    getPackageJsonsVisibleToFile(fileName, project, rootDir) {
                        const packageJsonCache = this.packageJsonCache;
                        const rootPath = rootDir && this.toPath(rootDir);
                        const result = [];
                        const processDirectory = (directory) => {
                            switch (packageJsonCache.directoryHasPackageJson(directory)) {
                                case 3 /* Maybe */:
                                    packageJsonCache.searchDirectoryAndAncestors(directory);
                                    return processDirectory(directory);
                                case -1 /* True */:
                                    const packageJsonFileName = combinePaths(directory, "package.json");
                                    this.watchPackageJsonFile(packageJsonFileName, this.toPath(packageJsonFileName), project);
                                    const info = packageJsonCache.getInDirectory(directory);
                                    if (info)
                                        result.push(info);
                            }
                            if (rootPath && rootPath === directory) {
                                return true;
                            }
                        };
                        forEachAncestorDirectory(getDirectoryPath(fileName), processDirectory);
                        return result;
                    }
                    /** @internal */
                    getNearestAncestorDirectoryWithPackageJson(fileName) {
                        return forEachAncestorDirectory(fileName, (directory) => {
                            switch (this.packageJsonCache.directoryHasPackageJson(directory)) {
                                case -1 /* True */:
                                    return directory;
                                case 0 /* False */:
                                    return void 0;
                                case 3 /* Maybe */:
                                    return this.host.fileExists(combinePaths(directory, "package.json")) ? directory : void 0;
                            }
                        });
                    }
                    /** @internal */
                    watchPackageJsonFile(file, path, project) {
                        Debug.assert(project !== void 0);
                        let result = (this.packageJsonFilesMap ?? (this.packageJsonFilesMap = /* @__PURE__ */ new Map())).get(path);
                        if (!result) {
                            let watcher = this.watchFactory.watchFile(file, (fileName, eventKind) => {
                                switch (eventKind) {
                                    case 0 /* Created */:
                                        return Debug.fail();
                                    case 1 /* Changed */:
                                        this.packageJsonCache.addOrUpdate(fileName, path);
                                        this.onPackageJsonChange(result);
                                        break;
                                    case 2 /* Deleted */:
                                        this.packageJsonCache.delete(path);
                                        this.onPackageJsonChange(result);
                                        result.projects.clear();
                                        result.close();
                                }
                            }, 250 /* Low */, this.hostConfiguration.watchOptions, WatchType.PackageJson);
                            result = {
                                projects: /* @__PURE__ */ new Set(),
                                close: () => {
                                    var _a;
                                    if (result.projects.size || !watcher)
                                        return;
                                    watcher.close();
                                    watcher = void 0;
                                    (_a = this.packageJsonFilesMap) == null ? void 0 : _a.delete(path);
                                    this.packageJsonCache.invalidate(path);
                                }
                            };
                            this.packageJsonFilesMap.set(path, result);
                        }
                        result.projects.add(project);
                        (project.packageJsonWatches ?? (project.packageJsonWatches = /* @__PURE__ */ new Set())).add(result);
                    }
                    /** @internal */
                    onPackageJsonChange(result) {
                        result.projects.forEach((project) => {
                            var _a;
                            return (_a = project.onPackageJsonChange) == null ? void 0 : _a.call(project);
                        });
                    }
                    /** @internal */
                    includePackageJsonAutoImports() {
                        switch (this.hostConfiguration.preferences.includePackageJsonAutoImports) {
                            case "on":
                                return 1 /* On */;
                            case "off":
                                return 0 /* Off */;
                            default:
                                return 2 /* Auto */;
                        }
                    }
                    /** @internal */
                    getIncompleteCompletionsCache() {
                        return this.incompleteCompletionsCache || (this.incompleteCompletionsCache = createIncompleteCompletionsCache());
                    }
                };
                /** Makes a filename safe to insert in a RegExp */
                _ProjectService.filenameEscapeRegexp = /[-/\\^$*+?.()|[\]{}]/g;
                ProjectService3 = _ProjectService;
            }
        });
        // src/server/moduleSpecifierCache.ts
        function createModuleSpecifierCache(host) {
            let containedNodeModulesWatchers;
            let cache;
            let currentKey;
            const result = {
                get(fromFileName, toFileName2, preferences, options) {
                    if (!cache || currentKey !== key(fromFileName, preferences, options))
                        return void 0;
                    return cache.get(toFileName2);
                },
                set(fromFileName, toFileName2, preferences, options, modulePaths, moduleSpecifiers) {
                    ensureCache(fromFileName, preferences, options).set(toFileName2, createInfo(modulePaths, moduleSpecifiers, 
                    /*isBlockedByPackageJsonDependencies*/
                    false));
                    if (moduleSpecifiers) {
                        for (const p of modulePaths) {
                            if (p.isInNodeModules) {
                                const nodeModulesPath = p.path.substring(0, p.path.indexOf(nodeModulesPathPart) + nodeModulesPathPart.length - 1);
                                const key2 = host.toPath(nodeModulesPath);
                                if (!(containedNodeModulesWatchers == null ? void 0 : containedNodeModulesWatchers.has(key2))) {
                                    (containedNodeModulesWatchers || (containedNodeModulesWatchers = /* @__PURE__ */ new Map())).set(key2, host.watchNodeModulesForPackageJsonChanges(nodeModulesPath));
                                }
                            }
                        }
                    }
                },
                setModulePaths(fromFileName, toFileName2, preferences, options, modulePaths) {
                    const cache2 = ensureCache(fromFileName, preferences, options);
                    const info = cache2.get(toFileName2);
                    if (info) {
                        info.modulePaths = modulePaths;
                    }
                    else {
                        cache2.set(toFileName2, createInfo(modulePaths, 
                        /*moduleSpecifiers*/
                        void 0, 
                        /*isBlockedByPackageJsonDependencies*/
                        void 0));
                    }
                },
                setBlockedByPackageJsonDependencies(fromFileName, toFileName2, preferences, options, isBlockedByPackageJsonDependencies) {
                    const cache2 = ensureCache(fromFileName, preferences, options);
                    const info = cache2.get(toFileName2);
                    if (info) {
                        info.isBlockedByPackageJsonDependencies = isBlockedByPackageJsonDependencies;
                    }
                    else {
                        cache2.set(toFileName2, createInfo(
                        /*modulePaths*/
                        void 0, 
                        /*moduleSpecifiers*/
                        void 0, isBlockedByPackageJsonDependencies));
                    }
                },
                clear() {
                    containedNodeModulesWatchers == null ? void 0 : containedNodeModulesWatchers.forEach(closeFileWatcher);
                    cache == null ? void 0 : cache.clear();
                    containedNodeModulesWatchers == null ? void 0 : containedNodeModulesWatchers.clear();
                    currentKey = void 0;
                },
                count() {
                    return cache ? cache.size : 0;
                }
            };
            if (Debug.isDebugging) {
                Object.defineProperty(result, "__cache", { get: () => cache });
            }
            return result;
            function ensureCache(fromFileName, preferences, options) {
                const newKey = key(fromFileName, preferences, options);
                if (cache && currentKey !== newKey) {
                    result.clear();
                }
                currentKey = newKey;
                return cache || (cache = /* @__PURE__ */ new Map());
            }
            function key(fromFileName, preferences, options) {
                return `${fromFileName},${preferences.importModuleSpecifierEnding},${preferences.importModuleSpecifierPreference},${options.overrideImportMode}`;
            }
            function createInfo(modulePaths, moduleSpecifiers, isBlockedByPackageJsonDependencies) {
                return { modulePaths, moduleSpecifiers, isBlockedByPackageJsonDependencies };
            }
        }
        var init_moduleSpecifierCache = __esm({
            "src/server/moduleSpecifierCache.ts"() {
                "use strict";
                init_ts7();
            }
        });
        // src/server/packageJsonCache.ts
        function createPackageJsonCache(host) {
            const packageJsons = /* @__PURE__ */ new Map();
            const directoriesWithoutPackageJson = /* @__PURE__ */ new Map();
            return {
                addOrUpdate,
                invalidate,
                delete: (fileName) => {
                    packageJsons.delete(fileName);
                    directoriesWithoutPackageJson.set(getDirectoryPath(fileName), true);
                },
                getInDirectory: (directory) => {
                    return packageJsons.get(host.toPath(combinePaths(directory, "package.json"))) || void 0;
                },
                directoryHasPackageJson: (directory) => directoryHasPackageJson(host.toPath(directory)),
                searchDirectoryAndAncestors: (directory) => {
                    forEachAncestorDirectory(directory, (ancestor) => {
                        const ancestorPath = host.toPath(ancestor);
                        if (directoryHasPackageJson(ancestorPath) !== 3 /* Maybe */) {
                            return true;
                        }
                        const packageJsonFileName = combinePaths(ancestor, "package.json");
                        if (tryFileExists(host, packageJsonFileName)) {
                            addOrUpdate(packageJsonFileName, combinePaths(ancestorPath, "package.json"));
                        }
                        else {
                            directoriesWithoutPackageJson.set(ancestorPath, true);
                        }
                    });
                }
            };
            function addOrUpdate(fileName, path) {
                const packageJsonInfo = Debug.checkDefined(createPackageJsonInfo(fileName, host.host));
                packageJsons.set(path, packageJsonInfo);
                directoriesWithoutPackageJson.delete(getDirectoryPath(path));
            }
            function invalidate(path) {
                packageJsons.delete(path);
                directoriesWithoutPackageJson.delete(getDirectoryPath(path));
            }
            function directoryHasPackageJson(directory) {
                return packageJsons.has(combinePaths(directory, "package.json")) ? -1 /* True */ : directoriesWithoutPackageJson.has(directory) ? 0 /* False */ : 3 /* Maybe */;
            }
        }
        var init_packageJsonCache = __esm({
            "src/server/packageJsonCache.ts"() {
                "use strict";
                init_ts7();
            }
        });
        // src/server/session.ts
        function hrTimeToMilliseconds(time) {
            const seconds = time[0];
            const nanoseconds = time[1];
            return (1e9 * seconds + nanoseconds) / 1e6;
        }
        function isDeclarationFileInJSOnlyNonConfiguredProject(project, file) {
            if ((isInferredProject(project) || isExternalProject(project)) && project.isJsOnlyProject()) {
                const scriptInfo = project.getScriptInfoForNormalizedPath(file);
                return scriptInfo && !scriptInfo.isJavaScript();
            }
            return false;
        }
        function dtsChangeCanAffectEmit(compilationSettings) {
            return getEmitDeclarations(compilationSettings) || !!compilationSettings.emitDecoratorMetadata;
        }
        function formatDiag(fileName, project, diag2) {
            const scriptInfo = project.getScriptInfoForNormalizedPath(fileName);
            return {
                start: scriptInfo.positionToLineOffset(diag2.start),
                end: scriptInfo.positionToLineOffset(diag2.start + diag2.length),
                // TODO: GH#18217
                text: flattenDiagnosticMessageText(diag2.messageText, "\n"),
                code: diag2.code,
                category: diagnosticCategoryName(diag2),
                reportsUnnecessary: diag2.reportsUnnecessary,
                reportsDeprecated: diag2.reportsDeprecated,
                source: diag2.source,
                relatedInformation: map(diag2.relatedInformation, formatRelatedInformation)
            };
        }
        function formatRelatedInformation(info) {
            if (!info.file) {
                return {
                    message: flattenDiagnosticMessageText(info.messageText, "\n"),
                    category: diagnosticCategoryName(info),
                    code: info.code
                };
            }
            return {
                span: {
                    start: convertToLocation(getLineAndCharacterOfPosition(info.file, info.start)),
                    end: convertToLocation(getLineAndCharacterOfPosition(info.file, info.start + info.length)),
                    // TODO: GH#18217
                    file: info.file.fileName
                },
                message: flattenDiagnosticMessageText(info.messageText, "\n"),
                category: diagnosticCategoryName(info),
                code: info.code
            };
        }
        function convertToLocation(lineAndCharacter) {
            return { line: lineAndCharacter.line + 1, offset: lineAndCharacter.character + 1 };
        }
        function formatDiagnosticToProtocol(diag2, includeFileName) {
            const start = diag2.file && convertToLocation(getLineAndCharacterOfPosition(diag2.file, diag2.start));
            const end = diag2.file && convertToLocation(getLineAndCharacterOfPosition(diag2.file, diag2.start + diag2.length));
            const text = flattenDiagnosticMessageText(diag2.messageText, "\n");
            const { code, source } = diag2;
            const category = diagnosticCategoryName(diag2);
            const common = {
                start,
                end,
                text,
                code,
                category,
                reportsUnnecessary: diag2.reportsUnnecessary,
                reportsDeprecated: diag2.reportsDeprecated,
                source,
                relatedInformation: map(diag2.relatedInformation, formatRelatedInformation)
            };
            return includeFileName ? { ...common, fileName: diag2.file && diag2.file.fileName } : common;
        }
        function allEditsBeforePos(edits, pos) {
            return edits.every((edit) => textSpanEnd(edit.span) < pos);
        }
        function formatMessage2(msg, logger, byteLength, newLine) {
            const verboseLogging = logger.hasLevel(3 /* verbose */);
            const json = JSON.stringify(msg);
            if (verboseLogging) {
                logger.info(`${msg.type}:${stringifyIndented(msg)}`);
            }
            const len = byteLength(json, "utf8");
            return `Content-Length: ${1 + len}\r
\r
${json}${newLine}`;
        }
        function toEvent(eventName, body) {
            return {
                seq: 0,
                type: "event",
                event: eventName,
                body
            };
        }
        function combineProjectOutput(defaultValue, getValue, projects, action) {
            const outputs = flatMapToMutable(isArray(projects) ? projects : projects.projects, (project) => action(project, defaultValue));
            if (!isArray(projects) && projects.symLinkedProjects) {
                projects.symLinkedProjects.forEach((projects2, path) => {
                    const value = getValue(path);
                    outputs.push(...flatMap(projects2, (project) => action(project, value)));
                });
            }
            return deduplicate(outputs, equateValues);
        }
        function createDocumentSpanSet(useCaseSensitiveFileNames2) {
            return createSet(({ textSpan }) => textSpan.start + 100003 * textSpan.length, getDocumentSpansEqualityComparer(useCaseSensitiveFileNames2));
        }
        function getRenameLocationsWorker(projects, defaultProject, initialLocation, findInStrings, findInComments, preferences, useCaseSensitiveFileNames2) {
            const perProjectResults = getPerProjectReferences(projects, defaultProject, initialLocation, 
            /*isForRename*/
            true, (project, position) => project.getLanguageService().findRenameLocations(position.fileName, position.pos, findInStrings, findInComments, preferences), (renameLocation, cb) => cb(documentSpanLocation(renameLocation)));
            if (isArray(perProjectResults)) {
                return perProjectResults;
            }
            const results = [];
            const seen = createDocumentSpanSet(useCaseSensitiveFileNames2);
            perProjectResults.forEach((projectResults, project) => {
                for (const result of projectResults) {
                    if (!seen.has(result) && !getMappedLocationForProject(documentSpanLocation(result), project)) {
                        results.push(result);
                        seen.add(result);
                    }
                }
            });
            return results;
        }
        function getDefinitionLocation(defaultProject, initialLocation, isForRename) {
            const infos = defaultProject.getLanguageService().getDefinitionAtPosition(initialLocation.fileName, initialLocation.pos, 
            /*searchOtherFilesOnly*/
            false, 
            /*stopAtAlias*/
            isForRename);
            const info = infos && firstOrUndefined(infos);
            return info && !info.isLocal ? { fileName: info.fileName, pos: info.textSpan.start } : void 0;
        }
        function getReferencesWorker(projects, defaultProject, initialLocation, useCaseSensitiveFileNames2, logger) {
            var _a, _b;
            const perProjectResults = getPerProjectReferences(projects, defaultProject, initialLocation, 
            /*isForRename*/
            false, (project, position) => {
                logger.info(`Finding references to ${position.fileName} position ${position.pos} in project ${project.getProjectName()}`);
                return project.getLanguageService().findReferences(position.fileName, position.pos);
            }, (referencedSymbol, cb) => {
                cb(documentSpanLocation(referencedSymbol.definition));
                for (const ref of referencedSymbol.references) {
                    cb(documentSpanLocation(ref));
                }
            });
            if (isArray(perProjectResults)) {
                return perProjectResults;
            }
            const defaultProjectResults = perProjectResults.get(defaultProject);
            if (((_b = (_a = defaultProjectResults == null ? void 0 : defaultProjectResults[0]) == null ? void 0 : _a.references[0]) == null ? void 0 : _b.isDefinition) === void 0) {
                perProjectResults.forEach((projectResults) => {
                    for (const referencedSymbol of projectResults) {
                        for (const ref of referencedSymbol.references) {
                            delete ref.isDefinition;
                        }
                    }
                });
            }
            else {
                const knownSymbolSpans = createDocumentSpanSet(useCaseSensitiveFileNames2);
                for (const referencedSymbol of defaultProjectResults) {
                    for (const ref of referencedSymbol.references) {
                        if (ref.isDefinition) {
                            knownSymbolSpans.add(ref);
                            break;
                        }
                    }
                }
                const updatedProjects = /* @__PURE__ */ new Set();
                while (true) {
                    let progress = false;
                    perProjectResults.forEach((referencedSymbols, project) => {
                        if (updatedProjects.has(project))
                            return;
                        const updated = project.getLanguageService().updateIsDefinitionOfReferencedSymbols(referencedSymbols, knownSymbolSpans);
                        if (updated) {
                            updatedProjects.add(project);
                            progress = true;
                        }
                    });
                    if (!progress)
                        break;
                }
                perProjectResults.forEach((referencedSymbols, project) => {
                    if (updatedProjects.has(project))
                        return;
                    for (const referencedSymbol of referencedSymbols) {
                        for (const ref of referencedSymbol.references) {
                            ref.isDefinition = false;
                        }
                    }
                });
            }
            const results = [];
            const seenRefs = createDocumentSpanSet(useCaseSensitiveFileNames2);
            perProjectResults.forEach((projectResults, project) => {
                for (const referencedSymbol of projectResults) {
                    const mappedDefinitionFile = getMappedLocationForProject(documentSpanLocation(referencedSymbol.definition), project);
                    const definition = mappedDefinitionFile === void 0 ? referencedSymbol.definition : {
                        ...referencedSymbol.definition,
                        textSpan: createTextSpan(mappedDefinitionFile.pos, referencedSymbol.definition.textSpan.length),
                        // Why would the length be the same in the original?
                        fileName: mappedDefinitionFile.fileName,
                        contextSpan: getMappedContextSpanForProject(referencedSymbol.definition, project)
                    };
                    let symbolToAddTo = find(results, (o) => documentSpansEqual(o.definition, definition, useCaseSensitiveFileNames2));
                    if (!symbolToAddTo) {
                        symbolToAddTo = { definition, references: [] };
                        results.push(symbolToAddTo);
                    }
                    for (const ref of referencedSymbol.references) {
                        if (!seenRefs.has(ref) && !getMappedLocationForProject(documentSpanLocation(ref), project)) {
                            seenRefs.add(ref);
                            symbolToAddTo.references.push(ref);
                        }
                    }
                }
            });
            return results.filter((o) => o.references.length !== 0);
        }
        function forEachProjectInProjects(projects, path, cb) {
            for (const project of isArray(projects) ? projects : projects.projects) {
                cb(project, path);
            }
            if (!isArray(projects) && projects.symLinkedProjects) {
                projects.symLinkedProjects.forEach((symlinkedProjects, symlinkedPath) => {
                    for (const project of symlinkedProjects) {
                        cb(project, symlinkedPath);
                    }
                });
            }
        }
        function getPerProjectReferences(projects, defaultProject, initialLocation, isForRename, getResultsForPosition, forPositionInResult) {
            const resultsMap = /* @__PURE__ */ new Map();
            const queue = createQueue();
            queue.enqueue({ project: defaultProject, location: initialLocation });
            forEachProjectInProjects(projects, initialLocation.fileName, (project, path) => {
                const location = { fileName: path, pos: initialLocation.pos };
                queue.enqueue({ project, location });
            });
            const projectService = defaultProject.projectService;
            const cancellationToken = defaultProject.getCancellationToken();
            const defaultDefinition = getDefinitionLocation(defaultProject, initialLocation, isForRename);
            const getGeneratedDefinition = memoize(() => defaultProject.isSourceOfProjectReferenceRedirect(defaultDefinition.fileName) ? defaultDefinition : defaultProject.getLanguageService().getSourceMapper().tryGetGeneratedPosition(defaultDefinition));
            const getSourceDefinition = memoize(() => defaultProject.isSourceOfProjectReferenceRedirect(defaultDefinition.fileName) ? defaultDefinition : defaultProject.getLanguageService().getSourceMapper().tryGetSourcePosition(defaultDefinition));
            const searchedProjectKeys = /* @__PURE__ */ new Set();
            onCancellation: while (!queue.isEmpty()) {
                while (!queue.isEmpty()) {
                    if (cancellationToken.isCancellationRequested())
                        break onCancellation;
                    const { project, location } = queue.dequeue();
                    if (resultsMap.has(project))
                        continue;
                    if (isLocationProjectReferenceRedirect(project, location))
                        continue;
                    updateProjectIfDirty(project);
                    if (!project.containsFile(toNormalizedPath(location.fileName))) {
                        continue;
                    }
                    const projectResults = searchPosition(project, location);
                    resultsMap.set(project, projectResults ?? emptyArray2);
                    searchedProjectKeys.add(getProjectKey(project));
                }
                if (defaultDefinition) {
                    projectService.loadAncestorProjectTree(searchedProjectKeys);
                    projectService.forEachEnabledProject((project) => {
                        if (cancellationToken.isCancellationRequested())
                            return;
                        if (resultsMap.has(project))
                            return;
                        const location = mapDefinitionInProject(defaultDefinition, project, getGeneratedDefinition, getSourceDefinition);
                        if (location) {
                            queue.enqueue({ project, location });
                        }
                    });
                }
            }
            if (resultsMap.size === 1) {
                return firstIterator(resultsMap.values());
            }
            return resultsMap;
            function searchPosition(project, location) {
                const projectResults = getResultsForPosition(project, location);
                if (!projectResults)
                    return void 0;
                for (const result of projectResults) {
                    forPositionInResult(result, (position) => {
                        const originalLocation = projectService.getOriginalLocationEnsuringConfiguredProject(project, position);
                        if (!originalLocation)
                            return;
                        const originalScriptInfo = projectService.getScriptInfo(originalLocation.fileName);
                        for (const project2 of originalScriptInfo.containingProjects) {
                            if (!project2.isOrphan() && !resultsMap.has(project2)) {
                                queue.enqueue({ project: project2, location: originalLocation });
                            }
                        }
                        const symlinkedProjectsMap = projectService.getSymlinkedProjects(originalScriptInfo);
                        if (symlinkedProjectsMap) {
                            symlinkedProjectsMap.forEach((symlinkedProjects, symlinkedPath) => {
                                for (const symlinkedProject of symlinkedProjects) {
                                    if (!symlinkedProject.isOrphan() && !resultsMap.has(symlinkedProject)) {
                                        queue.enqueue({ project: symlinkedProject, location: { fileName: symlinkedPath, pos: originalLocation.pos } });
                                    }
                                }
                            });
                        }
                    });
                }
                return projectResults;
            }
        }
        function mapDefinitionInProject(definition, project, getGeneratedDefinition, getSourceDefinition) {
            if (project.containsFile(toNormalizedPath(definition.fileName)) && !isLocationProjectReferenceRedirect(project, definition)) {
                return definition;
            }
            const generatedDefinition = getGeneratedDefinition();
            if (generatedDefinition && project.containsFile(toNormalizedPath(generatedDefinition.fileName)))
                return generatedDefinition;
            const sourceDefinition = getSourceDefinition();
            return sourceDefinition && project.containsFile(toNormalizedPath(sourceDefinition.fileName)) ? sourceDefinition : void 0;
        }
        function isLocationProjectReferenceRedirect(project, location) {
            if (!location)
                return false;
            const program = project.getLanguageService().getProgram();
            if (!program)
                return false;
            const sourceFile = program.getSourceFile(location.fileName);
            return !!sourceFile && sourceFile.resolvedPath !== sourceFile.path && sourceFile.resolvedPath !== project.toPath(location.fileName);
        }
        function getProjectKey(project) {
            return isConfiguredProject(project) ? project.canonicalConfigFilePath : project.getProjectName();
        }
        function documentSpanLocation({ fileName, textSpan }) {
            return { fileName, pos: textSpan.start };
        }
        function getMappedLocationForProject(location, project) {
            return getMappedLocation(location, project.getSourceMapper(), (p) => project.projectService.fileExists(p));
        }
        function getMappedDocumentSpanForProject(documentSpan, project) {
            return getMappedDocumentSpan(documentSpan, project.getSourceMapper(), (p) => project.projectService.fileExists(p));
        }
        function getMappedContextSpanForProject(documentSpan, project) {
            return getMappedContextSpan(documentSpan, project.getSourceMapper(), (p) => project.projectService.fileExists(p));
        }
        function toProtocolTextSpan(textSpan, scriptInfo) {
            return {
                start: scriptInfo.positionToLineOffset(textSpan.start),
                end: scriptInfo.positionToLineOffset(textSpanEnd(textSpan))
            };
        }
        function toProtocolTextSpanWithContext(span, contextSpan, scriptInfo) {
            const textSpan = toProtocolTextSpan(span, scriptInfo);
            const contextTextSpan = contextSpan && toProtocolTextSpan(contextSpan, scriptInfo);
            return contextTextSpan ? { ...textSpan, contextStart: contextTextSpan.start, contextEnd: contextTextSpan.end } : textSpan;
        }
        function convertTextChangeToCodeEdit(change, scriptInfo) {
            return { start: positionToLineOffset(scriptInfo, change.span.start), end: positionToLineOffset(scriptInfo, textSpanEnd(change.span)), newText: change.newText };
        }
        function positionToLineOffset(info, position) {
            return isConfigFile(info) ? locationFromLineAndCharacter(info.getLineAndCharacterOfPosition(position)) : info.positionToLineOffset(position);
        }
        function convertLinkedEditInfoToRanges(linkedEdit, scriptInfo) {
            const ranges = linkedEdit.ranges.map((r) => {
                return {
                    start: scriptInfo.positionToLineOffset(r.start),
                    end: scriptInfo.positionToLineOffset(r.start + r.length)
                };
            });
            if (!linkedEdit.wordPattern)
                return { ranges };
            return { ranges, wordPattern: linkedEdit.wordPattern };
        }
        function locationFromLineAndCharacter(lc) {
            return { line: lc.line + 1, offset: lc.character + 1 };
        }
        function convertNewFileTextChangeToCodeEdit(textChanges2) {
            Debug.assert(textChanges2.textChanges.length === 1);
            const change = first(textChanges2.textChanges);
            Debug.assert(change.span.start === 0 && change.span.length === 0);
            return { fileName: textChanges2.fileName, textChanges: [{ start: { line: 0, offset: 0 }, end: { line: 0, offset: 0 }, newText: change.newText }] };
        }
        function getLocationInNewDocument(oldText, renameFilename, renameLocation, edits) {
            const newText = applyEdits(oldText, renameFilename, edits);
            const { line, character } = computeLineAndCharacterOfPosition(computeLineStarts(newText), renameLocation);
            return { line: line + 1, offset: character + 1 };
        }
        function applyEdits(text, textFilename, edits) {
            for (const { fileName, textChanges: textChanges2 } of edits) {
                if (fileName !== textFilename) {
                    continue;
                }
                for (let i = textChanges2.length - 1; i >= 0; i--) {
                    const { newText, span: { start, length: length2 } } = textChanges2[i];
                    text = text.slice(0, start) + newText + text.slice(start + length2);
                }
            }
            return text;
        }
        function referenceEntryToReferencesResponseItem(projectService, { fileName, textSpan, contextSpan, isWriteAccess: isWriteAccess2, isDefinition }, { disableLineTextInReferences }) {
            const scriptInfo = Debug.checkDefined(projectService.getScriptInfo(fileName));
            const span = toProtocolTextSpanWithContext(textSpan, contextSpan, scriptInfo);
            const lineText = disableLineTextInReferences ? void 0 : getLineText(scriptInfo, span);
            return {
                file: fileName,
                ...span,
                lineText,
                isWriteAccess: isWriteAccess2,
                isDefinition
            };
        }
        function getLineText(scriptInfo, span) {
            const lineSpan = scriptInfo.lineToTextSpan(span.start.line - 1);
            return scriptInfo.getSnapshot().getText(lineSpan.start, textSpanEnd(lineSpan)).replace(/\r|\n/g, "");
        }
        function isCompletionEntryData(data) {
            return data === void 0 || data && typeof data === "object" && typeof data.exportName === "string" && (data.fileName === void 0 || typeof data.fileName === "string") && (data.ambientModuleName === void 0 || typeof data.ambientModuleName === "string" && (data.isPackageJsonImport === void 0 || typeof data.isPackageJsonImport === "boolean"));
        }
        var nullCancellationToken, CommandNames, MultistepOperation, invalidPartialSemanticModeCommands, invalidSyntacticModeCommands, Session3;
        var init_session = __esm({
            "src/server/session.ts"() {
                "use strict";
                init_ts7();
                init_ts_server3();
                init_protocol();
                nullCancellationToken = {
                    isCancellationRequested: () => false,
                    setRequest: () => void 0,
                    resetRequest: () => void 0
                };
                CommandNames = CommandTypes;
                MultistepOperation = class {
                    constructor(operationHost) {
                        this.operationHost = operationHost;
                    }
                    startNew(action) {
                        this.complete();
                        this.requestId = this.operationHost.getCurrentRequestId();
                        this.executeAction(action);
                    }
                    complete() {
                        if (this.requestId !== void 0) {
                            this.operationHost.sendRequestCompletedEvent(this.requestId);
                            this.requestId = void 0;
                        }
                        this.setTimerHandle(void 0);
                        this.setImmediateId(void 0);
                    }
                    immediate(actionType, action) {
                        const requestId = this.requestId;
                        Debug.assert(requestId === this.operationHost.getCurrentRequestId(), "immediate: incorrect request id");
                        this.setImmediateId(this.operationHost.getServerHost().setImmediate(() => {
                            this.immediateId = void 0;
                            this.operationHost.executeWithRequestId(requestId, () => this.executeAction(action));
                        }, actionType));
                    }
                    delay(actionType, ms, action) {
                        const requestId = this.requestId;
                        Debug.assert(requestId === this.operationHost.getCurrentRequestId(), "delay: incorrect request id");
                        this.setTimerHandle(this.operationHost.getServerHost().setTimeout(() => {
                            this.timerHandle = void 0;
                            this.operationHost.executeWithRequestId(requestId, () => this.executeAction(action));
                        }, ms, actionType));
                    }
                    executeAction(action) {
                        var _a, _b, _c, _d, _e, _f;
                        let stop = false;
                        try {
                            if (this.operationHost.isCancellationRequested()) {
                                stop = true;
                                (_a = tracing) == null ? void 0 : _a.instant(tracing.Phase.Session, "stepCanceled", { seq: this.requestId, early: true });
                            }
                            else {
                                (_b = tracing) == null ? void 0 : _b.push(tracing.Phase.Session, "stepAction", { seq: this.requestId });
                                action(this);
                                (_c = tracing) == null ? void 0 : _c.pop();
                            }
                        }
                        catch (e) {
                            (_d = tracing) == null ? void 0 : _d.popAll();
                            stop = true;
                            if (e instanceof OperationCanceledException) {
                                (_e = tracing) == null ? void 0 : _e.instant(tracing.Phase.Session, "stepCanceled", { seq: this.requestId });
                            }
                            else {
                                (_f = tracing) == null ? void 0 : _f.instant(tracing.Phase.Session, "stepError", { seq: this.requestId, message: e.message });
                                this.operationHost.logError(e, `delayed processing of request ${this.requestId}`);
                            }
                        }
                        if (stop || !this.hasPendingWork()) {
                            this.complete();
                        }
                    }
                    setTimerHandle(timerHandle) {
                        if (this.timerHandle !== void 0) {
                            this.operationHost.getServerHost().clearTimeout(this.timerHandle);
                        }
                        this.timerHandle = timerHandle;
                    }
                    setImmediateId(immediateId) {
                        if (this.immediateId !== void 0) {
                            this.operationHost.getServerHost().clearImmediate(this.immediateId);
                        }
                        this.immediateId = immediateId;
                    }
                    hasPendingWork() {
                        return !!this.timerHandle || !!this.immediateId;
                    }
                };
                invalidPartialSemanticModeCommands = [
                    "openExternalProject" /* OpenExternalProject */,
                    "openExternalProjects" /* OpenExternalProjects */,
                    "closeExternalProject" /* CloseExternalProject */,
                    "synchronizeProjectList" /* SynchronizeProjectList */,
                    "emit-output" /* EmitOutput */,
                    "compileOnSaveAffectedFileList" /* CompileOnSaveAffectedFileList */,
                    "compileOnSaveEmitFile" /* CompileOnSaveEmitFile */,
                    "compilerOptionsDiagnostics-full" /* CompilerOptionsDiagnosticsFull */,
                    "encodedSemanticClassifications-full" /* EncodedSemanticClassificationsFull */,
                    "semanticDiagnosticsSync" /* SemanticDiagnosticsSync */,
                    "suggestionDiagnosticsSync" /* SuggestionDiagnosticsSync */,
                    "geterrForProject" /* GeterrForProject */,
                    "reload" /* Reload */,
                    "reloadProjects" /* ReloadProjects */,
                    "getCodeFixes" /* GetCodeFixes */,
                    "getCodeFixes-full" /* GetCodeFixesFull */,
                    "getCombinedCodeFix" /* GetCombinedCodeFix */,
                    "getCombinedCodeFix-full" /* GetCombinedCodeFixFull */,
                    "applyCodeActionCommand" /* ApplyCodeActionCommand */,
                    "getSupportedCodeFixes" /* GetSupportedCodeFixes */,
                    "getApplicableRefactors" /* GetApplicableRefactors */,
                    "getMoveToRefactoringFileSuggestions" /* GetMoveToRefactoringFileSuggestions */,
                    "getEditsForRefactor" /* GetEditsForRefactor */,
                    "getEditsForRefactor-full" /* GetEditsForRefactorFull */,
                    "organizeImports" /* OrganizeImports */,
                    "organizeImports-full" /* OrganizeImportsFull */,
                    "getEditsForFileRename" /* GetEditsForFileRename */,
                    "getEditsForFileRename-full" /* GetEditsForFileRenameFull */,
                    "prepareCallHierarchy" /* PrepareCallHierarchy */,
                    "provideCallHierarchyIncomingCalls" /* ProvideCallHierarchyIncomingCalls */,
                    "provideCallHierarchyOutgoingCalls" /* ProvideCallHierarchyOutgoingCalls */
                ];
                invalidSyntacticModeCommands = [
                    ...invalidPartialSemanticModeCommands,
                    "definition" /* Definition */,
                    "definition-full" /* DefinitionFull */,
                    "definitionAndBoundSpan" /* DefinitionAndBoundSpan */,
                    "definitionAndBoundSpan-full" /* DefinitionAndBoundSpanFull */,
                    "typeDefinition" /* TypeDefinition */,
                    "implementation" /* Implementation */,
                    "implementation-full" /* ImplementationFull */,
                    "references" /* References */,
                    "references-full" /* ReferencesFull */,
                    "rename" /* Rename */,
                    "renameLocations-full" /* RenameLocationsFull */,
                    "rename-full" /* RenameInfoFull */,
                    "quickinfo" /* Quickinfo */,
                    "quickinfo-full" /* QuickinfoFull */,
                    "completionInfo" /* CompletionInfo */,
                    "completions" /* Completions */,
                    "completions-full" /* CompletionsFull */,
                    "completionEntryDetails" /* CompletionDetails */,
                    "completionEntryDetails-full" /* CompletionDetailsFull */,
                    "signatureHelp" /* SignatureHelp */,
                    "signatureHelp-full" /* SignatureHelpFull */,
                    "navto" /* Navto */,
                    "navto-full" /* NavtoFull */,
                    "documentHighlights" /* DocumentHighlights */,
                    "documentHighlights-full" /* DocumentHighlightsFull */
                ];
                Session3 = class _Session {
                    constructor(opts) {
                        this.changeSeq = 0;
                        this.handlers = new Map(Object.entries({
                            // TODO(jakebailey): correctly type the handlers
                            ["status" /* Status */]: () => {
                                const response = { version };
                                return this.requiredResponse(response);
                            },
                            ["openExternalProject" /* OpenExternalProject */]: (request) => {
                                this.projectService.openExternalProject(request.arguments, 
                                /*print*/
                                true);
                                return this.requiredResponse(
                                /*response*/
                                true);
                            },
                            ["openExternalProjects" /* OpenExternalProjects */]: (request) => {
                                this.projectService.openExternalProjects(request.arguments.projects);
                                return this.requiredResponse(
                                /*response*/
                                true);
                            },
                            ["closeExternalProject" /* CloseExternalProject */]: (request) => {
                                this.projectService.closeExternalProject(request.arguments.projectFileName, 
                                /*print*/
                                true);
                                return this.requiredResponse(
                                /*response*/
                                true);
                            },
                            ["synchronizeProjectList" /* SynchronizeProjectList */]: (request) => {
                                const result = this.projectService.synchronizeProjectList(request.arguments.knownProjects, request.arguments.includeProjectReferenceRedirectInfo);
                                if (!result.some((p) => p.projectErrors && p.projectErrors.length !== 0)) {
                                    return this.requiredResponse(result);
                                }
                                const converted = map(result, (p) => {
                                    if (!p.projectErrors || p.projectErrors.length === 0) {
                                        return p;
                                    }
                                    return {
                                        info: p.info,
                                        changes: p.changes,
                                        files: p.files,
                                        projectErrors: this.convertToDiagnosticsWithLinePosition(p.projectErrors, 
                                        /*scriptInfo*/
                                        void 0)
                                    };
                                });
                                return this.requiredResponse(converted);
                            },
                            ["updateOpen" /* UpdateOpen */]: (request) => {
                                this.changeSeq++;
                                this.projectService.applyChangesInOpenFiles(request.arguments.openFiles && mapIterator(request.arguments.openFiles, (file) => ({
                                    fileName: file.file,
                                    content: file.fileContent,
                                    scriptKind: file.scriptKindName,
                                    projectRootPath: file.projectRootPath
                                })), request.arguments.changedFiles && mapIterator(request.arguments.changedFiles, (file) => ({
                                    fileName: file.fileName,
                                    changes: mapDefinedIterator(arrayReverseIterator(file.textChanges), (change) => {
                                        const scriptInfo = Debug.checkDefined(this.projectService.getScriptInfo(file.fileName));
                                        const start = scriptInfo.lineOffsetToPosition(change.start.line, change.start.offset);
                                        const end = scriptInfo.lineOffsetToPosition(change.end.line, change.end.offset);
                                        return start >= 0 ? { span: { start, length: end - start }, newText: change.newText } : void 0;
                                    })
                                })), request.arguments.closedFiles);
                                return this.requiredResponse(
                                /*response*/
                                true);
                            },
                            ["applyChangedToOpenFiles" /* ApplyChangedToOpenFiles */]: (request) => {
                                this.changeSeq++;
                                this.projectService.applyChangesInOpenFiles(request.arguments.openFiles, request.arguments.changedFiles && mapIterator(request.arguments.changedFiles, (file) => ({
                                    fileName: file.fileName,
                                    // apply changes in reverse order
                                    changes: arrayReverseIterator(file.changes)
                                })), request.arguments.closedFiles);
                                return this.requiredResponse(
                                /*response*/
                                true);
                            },
                            ["exit" /* Exit */]: () => {
                                this.exit();
                                return this.notRequired();
                            },
                            ["definition" /* Definition */]: (request) => {
                                return this.requiredResponse(this.getDefinition(request.arguments, 
                                /*simplifiedResult*/
                                true));
                            },
                            ["definition-full" /* DefinitionFull */]: (request) => {
                                return this.requiredResponse(this.getDefinition(request.arguments, 
                                /*simplifiedResult*/
                                false));
                            },
                            ["definitionAndBoundSpan" /* DefinitionAndBoundSpan */]: (request) => {
                                return this.requiredResponse(this.getDefinitionAndBoundSpan(request.arguments, 
                                /*simplifiedResult*/
                                true));
                            },
                            ["definitionAndBoundSpan-full" /* DefinitionAndBoundSpanFull */]: (request) => {
                                return this.requiredResponse(this.getDefinitionAndBoundSpan(request.arguments, 
                                /*simplifiedResult*/
                                false));
                            },
                            ["findSourceDefinition" /* FindSourceDefinition */]: (request) => {
                                return this.requiredResponse(this.findSourceDefinition(request.arguments));
                            },
                            ["emit-output" /* EmitOutput */]: (request) => {
                                return this.requiredResponse(this.getEmitOutput(request.arguments));
                            },
                            ["typeDefinition" /* TypeDefinition */]: (request) => {
                                return this.requiredResponse(this.getTypeDefinition(request.arguments));
                            },
                            ["implementation" /* Implementation */]: (request) => {
                                return this.requiredResponse(this.getImplementation(request.arguments, 
                                /*simplifiedResult*/
                                true));
                            },
                            ["implementation-full" /* ImplementationFull */]: (request) => {
                                return this.requiredResponse(this.getImplementation(request.arguments, 
                                /*simplifiedResult*/
                                false));
                            },
                            ["references" /* References */]: (request) => {
                                return this.requiredResponse(this.getReferences(request.arguments, 
                                /*simplifiedResult*/
                                true));
                            },
                            ["references-full" /* ReferencesFull */]: (request) => {
                                return this.requiredResponse(this.getReferences(request.arguments, 
                                /*simplifiedResult*/
                                false));
                            },
                            ["rename" /* Rename */]: (request) => {
                                return this.requiredResponse(this.getRenameLocations(request.arguments, 
                                /*simplifiedResult*/
                                true));
                            },
                            ["renameLocations-full" /* RenameLocationsFull */]: (request) => {
                                return this.requiredResponse(this.getRenameLocations(request.arguments, 
                                /*simplifiedResult*/
                                false));
                            },
                            ["rename-full" /* RenameInfoFull */]: (request) => {
                                return this.requiredResponse(this.getRenameInfo(request.arguments));
                            },
                            ["open" /* Open */]: (request) => {
                                this.openClientFile(toNormalizedPath(request.arguments.file), request.arguments.fileContent, convertScriptKindName(request.arguments.scriptKindName), 
                                // TODO: GH#18217
                                request.arguments.projectRootPath ? toNormalizedPath(request.arguments.projectRootPath) : void 0);
                                return this.notRequired();
                            },
                            ["quickinfo" /* Quickinfo */]: (request) => {
                                return this.requiredResponse(this.getQuickInfoWorker(request.arguments, 
                                /*simplifiedResult*/
                                true));
                            },
                            ["quickinfo-full" /* QuickinfoFull */]: (request) => {
                                return this.requiredResponse(this.getQuickInfoWorker(request.arguments, 
                                /*simplifiedResult*/
                                false));
                            },
                            ["getOutliningSpans" /* GetOutliningSpans */]: (request) => {
                                return this.requiredResponse(this.getOutliningSpans(request.arguments, 
                                /*simplifiedResult*/
                                true));
                            },
                            ["outliningSpans" /* GetOutliningSpansFull */]: (request) => {
                                return this.requiredResponse(this.getOutliningSpans(request.arguments, 
                                /*simplifiedResult*/
                                false));
                            },
                            ["todoComments" /* TodoComments */]: (request) => {
                                return this.requiredResponse(this.getTodoComments(request.arguments));
                            },
                            ["indentation" /* Indentation */]: (request) => {
                                return this.requiredResponse(this.getIndentation(request.arguments));
                            },
                            ["nameOrDottedNameSpan" /* NameOrDottedNameSpan */]: (request) => {
                                return this.requiredResponse(this.getNameOrDottedNameSpan(request.arguments));
                            },
                            ["breakpointStatement" /* BreakpointStatement */]: (request) => {
                                return this.requiredResponse(this.getBreakpointStatement(request.arguments));
                            },
                            ["braceCompletion" /* BraceCompletion */]: (request) => {
                                return this.requiredResponse(this.isValidBraceCompletion(request.arguments));
                            },
                            ["docCommentTemplate" /* DocCommentTemplate */]: (request) => {
                                return this.requiredResponse(this.getDocCommentTemplate(request.arguments));
                            },
                            ["getSpanOfEnclosingComment" /* GetSpanOfEnclosingComment */]: (request) => {
                                return this.requiredResponse(this.getSpanOfEnclosingComment(request.arguments));
                            },
                            ["fileReferences" /* FileReferences */]: (request) => {
                                return this.requiredResponse(this.getFileReferences(request.arguments, 
                                /*simplifiedResult*/
                                true));
                            },
                            ["fileReferences-full" /* FileReferencesFull */]: (request) => {
                                return this.requiredResponse(this.getFileReferences(request.arguments, 
                                /*simplifiedResult*/
                                false));
                            },
                            ["format" /* Format */]: (request) => {
                                return this.requiredResponse(this.getFormattingEditsForRange(request.arguments));
                            },
                            ["formatonkey" /* Formatonkey */]: (request) => {
                                return this.requiredResponse(this.getFormattingEditsAfterKeystroke(request.arguments));
                            },
                            ["format-full" /* FormatFull */]: (request) => {
                                return this.requiredResponse(this.getFormattingEditsForDocumentFull(request.arguments));
                            },
                            ["formatonkey-full" /* FormatonkeyFull */]: (request) => {
                                return this.requiredResponse(this.getFormattingEditsAfterKeystrokeFull(request.arguments));
                            },
                            ["formatRange-full" /* FormatRangeFull */]: (request) => {
                                return this.requiredResponse(this.getFormattingEditsForRangeFull(request.arguments));
                            },
                            ["completionInfo" /* CompletionInfo */]: (request) => {
                                return this.requiredResponse(this.getCompletions(request.arguments, "completionInfo" /* CompletionInfo */));
                            },
                            ["completions" /* Completions */]: (request) => {
                                return this.requiredResponse(this.getCompletions(request.arguments, "completions" /* Completions */));
                            },
                            ["completions-full" /* CompletionsFull */]: (request) => {
                                return this.requiredResponse(this.getCompletions(request.arguments, "completions-full" /* CompletionsFull */));
                            },
                            ["completionEntryDetails" /* CompletionDetails */]: (request) => {
                                return this.requiredResponse(this.getCompletionEntryDetails(request.arguments, 
                                /*fullResult*/
                                false));
                            },
                            ["completionEntryDetails-full" /* CompletionDetailsFull */]: (request) => {
                                return this.requiredResponse(this.getCompletionEntryDetails(request.arguments, 
                                /*fullResult*/
                                true));
                            },
                            ["compileOnSaveAffectedFileList" /* CompileOnSaveAffectedFileList */]: (request) => {
                                return this.requiredResponse(this.getCompileOnSaveAffectedFileList(request.arguments));
                            },
                            ["compileOnSaveEmitFile" /* CompileOnSaveEmitFile */]: (request) => {
                                return this.requiredResponse(this.emitFile(request.arguments));
                            },
                            ["signatureHelp" /* SignatureHelp */]: (request) => {
                                return this.requiredResponse(this.getSignatureHelpItems(request.arguments, 
                                /*simplifiedResult*/
                                true));
                            },
                            ["signatureHelp-full" /* SignatureHelpFull */]: (request) => {
                                return this.requiredResponse(this.getSignatureHelpItems(request.arguments, 
                                /*simplifiedResult*/
                                false));
                            },
                            ["compilerOptionsDiagnostics-full" /* CompilerOptionsDiagnosticsFull */]: (request) => {
                                return this.requiredResponse(this.getCompilerOptionsDiagnostics(request.arguments));
                            },
                            ["encodedSyntacticClassifications-full" /* EncodedSyntacticClassificationsFull */]: (request) => {
                                return this.requiredResponse(this.getEncodedSyntacticClassifications(request.arguments));
                            },
                            ["encodedSemanticClassifications-full" /* EncodedSemanticClassificationsFull */]: (request) => {
                                return this.requiredResponse(this.getEncodedSemanticClassifications(request.arguments));
                            },
                            ["cleanup" /* Cleanup */]: () => {
                                this.cleanup();
                                return this.requiredResponse(
                                /*response*/
                                true);
                            },
                            ["semanticDiagnosticsSync" /* SemanticDiagnosticsSync */]: (request) => {
                                return this.requiredResponse(this.getSemanticDiagnosticsSync(request.arguments));
                            },
                            ["syntacticDiagnosticsSync" /* SyntacticDiagnosticsSync */]: (request) => {
                                return this.requiredResponse(this.getSyntacticDiagnosticsSync(request.arguments));
                            },
                            ["suggestionDiagnosticsSync" /* SuggestionDiagnosticsSync */]: (request) => {
                                return this.requiredResponse(this.getSuggestionDiagnosticsSync(request.arguments));
                            },
                            ["geterr" /* Geterr */]: (request) => {
                                this.errorCheck.startNew((next) => this.getDiagnostics(next, request.arguments.delay, request.arguments.files));
                                return this.notRequired();
                            },
                            ["geterrForProject" /* GeterrForProject */]: (request) => {
                                this.errorCheck.startNew((next) => this.getDiagnosticsForProject(next, request.arguments.delay, request.arguments.file));
                                return this.notRequired();
                            },
                            ["change" /* Change */]: (request) => {
                                this.change(request.arguments);
                                return this.notRequired();
                            },
                            ["configure" /* Configure */]: (request) => {
                                this.projectService.setHostConfiguration(request.arguments);
                                this.doOutput(
                                /*info*/
                                void 0, "configure" /* Configure */, request.seq, 
                                /*success*/
                                true);
                                return this.notRequired();
                            },
                            ["reload" /* Reload */]: (request) => {
                                this.reload(request.arguments, request.seq);
                                return this.requiredResponse({ reloadFinished: true });
                            },
                            ["saveto" /* Saveto */]: (request) => {
                                const savetoArgs = request.arguments;
                                this.saveToTmp(savetoArgs.file, savetoArgs.tmpfile);
                                return this.notRequired();
                            },
                            ["close" /* Close */]: (request) => {
                                const closeArgs = request.arguments;
                                this.closeClientFile(closeArgs.file);
                                return this.notRequired();
                            },
                            ["navto" /* Navto */]: (request) => {
                                return this.requiredResponse(this.getNavigateToItems(request.arguments, 
                                /*simplifiedResult*/
                                true));
                            },
                            ["navto-full" /* NavtoFull */]: (request) => {
                                return this.requiredResponse(this.getNavigateToItems(request.arguments, 
                                /*simplifiedResult*/
                                false));
                            },
                            ["brace" /* Brace */]: (request) => {
                                return this.requiredResponse(this.getBraceMatching(request.arguments, 
                                /*simplifiedResult*/
                                true));
                            },
                            ["brace-full" /* BraceFull */]: (request) => {
                                return this.requiredResponse(this.getBraceMatching(request.arguments, 
                                /*simplifiedResult*/
                                false));
                            },
                            ["navbar" /* NavBar */]: (request) => {
                                return this.requiredResponse(this.getNavigationBarItems(request.arguments, 
                                /*simplifiedResult*/
                                true));
                            },
                            ["navbar-full" /* NavBarFull */]: (request) => {
                                return this.requiredResponse(this.getNavigationBarItems(request.arguments, 
                                /*simplifiedResult*/
                                false));
                            },
                            ["navtree" /* NavTree */]: (request) => {
                                return this.requiredResponse(this.getNavigationTree(request.arguments, 
                                /*simplifiedResult*/
                                true));
                            },
                            ["navtree-full" /* NavTreeFull */]: (request) => {
                                return this.requiredResponse(this.getNavigationTree(request.arguments, 
                                /*simplifiedResult*/
                                false));
                            },
                            ["documentHighlights" /* DocumentHighlights */]: (request) => {
                                return this.requiredResponse(this.getDocumentHighlights(request.arguments, 
                                /*simplifiedResult*/
                                true));
                            },
                            ["documentHighlights-full" /* DocumentHighlightsFull */]: (request) => {
                                return this.requiredResponse(this.getDocumentHighlights(request.arguments, 
                                /*simplifiedResult*/
                                false));
                            },
                            ["compilerOptionsForInferredProjects" /* CompilerOptionsForInferredProjects */]: (request) => {
                                this.setCompilerOptionsForInferredProjects(request.arguments);
                                return this.requiredResponse(
                                /*response*/
                                true);
                            },
                            ["projectInfo" /* ProjectInfo */]: (request) => {
                                return this.requiredResponse(this.getProjectInfo(request.arguments));
                            },
                            ["reloadProjects" /* ReloadProjects */]: () => {
                                this.projectService.reloadProjects();
                                return this.notRequired();
                            },
                            ["jsxClosingTag" /* JsxClosingTag */]: (request) => {
                                return this.requiredResponse(this.getJsxClosingTag(request.arguments));
                            },
                            ["linkedEditingRange" /* LinkedEditingRange */]: (request) => {
                                return this.requiredResponse(this.getLinkedEditingRange(request.arguments));
                            },
                            ["getCodeFixes" /* GetCodeFixes */]: (request) => {
                                return this.requiredResponse(this.getCodeFixes(request.arguments, 
                                /*simplifiedResult*/
                                true));
                            },
                            ["getCodeFixes-full" /* GetCodeFixesFull */]: (request) => {
                                return this.requiredResponse(this.getCodeFixes(request.arguments, 
                                /*simplifiedResult*/
                                false));
                            },
                            ["getCombinedCodeFix" /* GetCombinedCodeFix */]: (request) => {
                                return this.requiredResponse(this.getCombinedCodeFix(request.arguments, 
                                /*simplifiedResult*/
                                true));
                            },
                            ["getCombinedCodeFix-full" /* GetCombinedCodeFixFull */]: (request) => {
                                return this.requiredResponse(this.getCombinedCodeFix(request.arguments, 
                                /*simplifiedResult*/
                                false));
                            },
                            ["applyCodeActionCommand" /* ApplyCodeActionCommand */]: (request) => {
                                return this.requiredResponse(this.applyCodeActionCommand(request.arguments));
                            },
                            ["getSupportedCodeFixes" /* GetSupportedCodeFixes */]: (request) => {
                                return this.requiredResponse(this.getSupportedCodeFixes(request.arguments));
                            },
                            ["getApplicableRefactors" /* GetApplicableRefactors */]: (request) => {
                                return this.requiredResponse(this.getApplicableRefactors(request.arguments));
                            },
                            ["getEditsForRefactor" /* GetEditsForRefactor */]: (request) => {
                                return this.requiredResponse(this.getEditsForRefactor(request.arguments, 
                                /*simplifiedResult*/
                                true));
                            },
                            ["getMoveToRefactoringFileSuggestions" /* GetMoveToRefactoringFileSuggestions */]: (request) => {
                                return this.requiredResponse(this.getMoveToRefactoringFileSuggestions(request.arguments));
                            },
                            ["getEditsForRefactor-full" /* GetEditsForRefactorFull */]: (request) => {
                                return this.requiredResponse(this.getEditsForRefactor(request.arguments, 
                                /*simplifiedResult*/
                                false));
                            },
                            ["organizeImports" /* OrganizeImports */]: (request) => {
                                return this.requiredResponse(this.organizeImports(request.arguments, 
                                /*simplifiedResult*/
                                true));
                            },
                            ["organizeImports-full" /* OrganizeImportsFull */]: (request) => {
                                return this.requiredResponse(this.organizeImports(request.arguments, 
                                /*simplifiedResult*/
                                false));
                            },
                            ["getEditsForFileRename" /* GetEditsForFileRename */]: (request) => {
                                return this.requiredResponse(this.getEditsForFileRename(request.arguments, 
                                /*simplifiedResult*/
                                true));
                            },
                            ["getEditsForFileRename-full" /* GetEditsForFileRenameFull */]: (request) => {
                                return this.requiredResponse(this.getEditsForFileRename(request.arguments, 
                                /*simplifiedResult*/
                                false));
                            },
                            ["configurePlugin" /* ConfigurePlugin */]: (request) => {
                                this.configurePlugin(request.arguments);
                                this.doOutput(
                                /*info*/
                                void 0, "configurePlugin" /* ConfigurePlugin */, request.seq, 
                                /*success*/
                                true);
                                return this.notRequired();
                            },
                            ["selectionRange" /* SelectionRange */]: (request) => {
                                return this.requiredResponse(this.getSmartSelectionRange(request.arguments, 
                                /*simplifiedResult*/
                                true));
                            },
                            ["selectionRange-full" /* SelectionRangeFull */]: (request) => {
                                return this.requiredResponse(this.getSmartSelectionRange(request.arguments, 
                                /*simplifiedResult*/
                                false));
                            },
                            ["prepareCallHierarchy" /* PrepareCallHierarchy */]: (request) => {
                                return this.requiredResponse(this.prepareCallHierarchy(request.arguments));
                            },
                            ["provideCallHierarchyIncomingCalls" /* ProvideCallHierarchyIncomingCalls */]: (request) => {
                                return this.requiredResponse(this.provideCallHierarchyIncomingCalls(request.arguments));
                            },
                            ["provideCallHierarchyOutgoingCalls" /* ProvideCallHierarchyOutgoingCalls */]: (request) => {
                                return this.requiredResponse(this.provideCallHierarchyOutgoingCalls(request.arguments));
                            },
                            ["toggleLineComment" /* ToggleLineComment */]: (request) => {
                                return this.requiredResponse(this.toggleLineComment(request.arguments, 
                                /*simplifiedResult*/
                                true));
                            },
                            ["toggleLineComment-full" /* ToggleLineCommentFull */]: (request) => {
                                return this.requiredResponse(this.toggleLineComment(request.arguments, 
                                /*simplifiedResult*/
                                false));
                            },
                            ["toggleMultilineComment" /* ToggleMultilineComment */]: (request) => {
                                return this.requiredResponse(this.toggleMultilineComment(request.arguments, 
                                /*simplifiedResult*/
                                true));
                            },
                            ["toggleMultilineComment-full" /* ToggleMultilineCommentFull */]: (request) => {
                                return this.requiredResponse(this.toggleMultilineComment(request.arguments, 
                                /*simplifiedResult*/
                                false));
                            },
                            ["commentSelection" /* CommentSelection */]: (request) => {
                                return this.requiredResponse(this.commentSelection(request.arguments, 
                                /*simplifiedResult*/
                                true));
                            },
                            ["commentSelection-full" /* CommentSelectionFull */]: (request) => {
                                return this.requiredResponse(this.commentSelection(request.arguments, 
                                /*simplifiedResult*/
                                false));
                            },
                            ["uncommentSelection" /* UncommentSelection */]: (request) => {
                                return this.requiredResponse(this.uncommentSelection(request.arguments, 
                                /*simplifiedResult*/
                                true));
                            },
                            ["uncommentSelection-full" /* UncommentSelectionFull */]: (request) => {
                                return this.requiredResponse(this.uncommentSelection(request.arguments, 
                                /*simplifiedResult*/
                                false));
                            },
                            ["provideInlayHints" /* ProvideInlayHints */]: (request) => {
                                return this.requiredResponse(this.provideInlayHints(request.arguments));
                            }
                        }));
                        this.host = opts.host;
                        this.cancellationToken = opts.cancellationToken;
                        this.typingsInstaller = opts.typingsInstaller || nullTypingsInstaller;
                        this.byteLength = opts.byteLength;
                        this.hrtime = opts.hrtime;
                        this.logger = opts.logger;
                        this.canUseEvents = opts.canUseEvents;
                        this.suppressDiagnosticEvents = opts.suppressDiagnosticEvents;
                        this.noGetErrOnBackgroundUpdate = opts.noGetErrOnBackgroundUpdate;
                        const { throttleWaitMilliseconds } = opts;
                        this.eventHandler = this.canUseEvents ? opts.eventHandler || ((event) => this.defaultEventHandler(event)) : void 0;
                        const multistepOperationHost = {
                            executeWithRequestId: (requestId, action) => this.executeWithRequestId(requestId, action),
                            getCurrentRequestId: () => this.currentRequestId,
                            getServerHost: () => this.host,
                            logError: (err, cmd) => this.logError(err, cmd),
                            sendRequestCompletedEvent: (requestId) => this.sendRequestCompletedEvent(requestId),
                            isCancellationRequested: () => this.cancellationToken.isCancellationRequested()
                        };
                        this.errorCheck = new MultistepOperation(multistepOperationHost);
                        const settings = {
                            host: this.host,
                            logger: this.logger,
                            cancellationToken: this.cancellationToken,
                            useSingleInferredProject: opts.useSingleInferredProject,
                            useInferredProjectPerProjectRoot: opts.useInferredProjectPerProjectRoot,
                            typingsInstaller: this.typingsInstaller,
                            throttleWaitMilliseconds,
                            eventHandler: this.eventHandler,
                            suppressDiagnosticEvents: this.suppressDiagnosticEvents,
                            globalPlugins: opts.globalPlugins,
                            pluginProbeLocations: opts.pluginProbeLocations,
                            allowLocalPluginLoads: opts.allowLocalPluginLoads,
                            typesMapLocation: opts.typesMapLocation,
                            serverMode: opts.serverMode,
                            session: this,
                            canUseWatchEvents: opts.canUseWatchEvents,
                            incrementalVerifier: opts.incrementalVerifier
                        };
                        this.projectService = new ProjectService3(settings);
                        this.projectService.setPerformanceEventHandler(this.performanceEventHandler.bind(this));
                        this.gcTimer = new GcTimer(this.host, 
                        /*delay*/
                        7e3, this.logger);
                        switch (this.projectService.serverMode) {
                            case 0 /* Semantic */:
                                break;
                            case 1 /* PartialSemantic */:
                                invalidPartialSemanticModeCommands.forEach((commandName) => this.handlers.set(commandName, (request) => {
                                    throw new Error(`Request: ${request.command} not allowed in LanguageServiceMode.PartialSemantic`);
                                }));
                                break;
                            case 2 /* Syntactic */:
                                invalidSyntacticModeCommands.forEach((commandName) => this.handlers.set(commandName, (request) => {
                                    throw new Error(`Request: ${request.command} not allowed in LanguageServiceMode.Syntactic`);
                                }));
                                break;
                            default:
                                Debug.assertNever(this.projectService.serverMode);
                        }
                    }
                    sendRequestCompletedEvent(requestId) {
                        this.event({ request_seq: requestId }, "requestCompleted");
                    }
                    addPerformanceData(key, value) {
                        if (!this.performanceData) {
                            this.performanceData = {};
                        }
                        this.performanceData[key] = (this.performanceData[key] ?? 0) + value;
                    }
                    performanceEventHandler(event) {
                        switch (event.kind) {
                            case "UpdateGraph":
                                this.addPerformanceData("updateGraphDurationMs", event.durationMs);
                                break;
                            case "CreatePackageJsonAutoImportProvider":
                                this.addPerformanceData("createAutoImportProviderProgramDurationMs", event.durationMs);
                                break;
                        }
                    }
                    defaultEventHandler(event) {
                        switch (event.eventName) {
                            case ProjectsUpdatedInBackgroundEvent:
                                this.projectsUpdatedInBackgroundEvent(event.data.openFiles);
                                break;
                            case ProjectLoadingStartEvent:
                                this.event({
                                    projectName: event.data.project.getProjectName(),
                                    reason: event.data.reason
                                }, event.eventName);
                                break;
                            case ProjectLoadingFinishEvent:
                                this.event({
                                    projectName: event.data.project.getProjectName()
                                }, event.eventName);
                                break;
                            case LargeFileReferencedEvent:
                            case CreateFileWatcherEvent:
                            case CreateDirectoryWatcherEvent:
                            case CloseFileWatcherEvent:
                                this.event(event.data, event.eventName);
                                break;
                            case ConfigFileDiagEvent:
                                this.event({
                                    triggerFile: event.data.triggerFile,
                                    configFile: event.data.configFileName,
                                    diagnostics: map(event.data.diagnostics, (diagnostic) => formatDiagnosticToProtocol(diagnostic, 
                                    /*includeFileName*/
                                    true))
                                }, event.eventName);
                                break;
                            case ProjectLanguageServiceStateEvent: {
                                this.event({
                                    projectName: event.data.project.getProjectName(),
                                    languageServiceEnabled: event.data.languageServiceEnabled
                                }, event.eventName);
                                break;
                            }
                            case ProjectInfoTelemetryEvent: {
                                const eventName = "telemetry";
                                this.event({
                                    telemetryEventName: event.eventName,
                                    payload: event.data
                                }, eventName);
                                break;
                            }
                        }
                    }
                    projectsUpdatedInBackgroundEvent(openFiles) {
                        this.projectService.logger.info(`got projects updated in background ${openFiles}`);
                        if (openFiles.length) {
                            if (!this.suppressDiagnosticEvents && !this.noGetErrOnBackgroundUpdate) {
                                this.projectService.logger.info(`Queueing diagnostics update for ${openFiles}`);
                                this.errorCheck.startNew((next) => this.updateErrorCheck(next, openFiles, 100, 
                                /*requireOpen*/
                                true));
                            }
                            this.event({
                                openFiles
                            }, ProjectsUpdatedInBackgroundEvent);
                        }
                    }
                    logError(err, cmd) {
                        this.logErrorWorker(err, cmd);
                    }
                    logErrorWorker(err, cmd, fileRequest) {
                        let msg = "Exception on executing command " + cmd;
                        if (err.message) {
                            msg += ":\n" + indent2(err.message);
                            if (err.stack) {
                                msg += "\n" + indent2(err.stack);
                            }
                        }
                        if (this.logger.hasLevel(3 /* verbose */)) {
                            if (fileRequest) {
                                try {
                                    const { file, project } = this.getFileAndProject(fileRequest);
                                    const scriptInfo = project.getScriptInfoForNormalizedPath(file);
                                    if (scriptInfo) {
                                        const text = getSnapshotText(scriptInfo.getSnapshot());
                                        msg += `

File text of ${fileRequest.file}:${indent2(text)}
`;
                                    }
                                }
                                catch {
                                }
                            }
                            if (err.ProgramFiles) {
                                msg += `

Program files: ${JSON.stringify(err.ProgramFiles)}
`;
                                msg += `

Projects::
`;
                                let counter = 0;
                                const addProjectInfo = (project) => {
                                    msg += `
Project '${project.projectName}' (${ProjectKind[project.projectKind]}) ${counter}
`;
                                    msg += project.filesToString(
                                    /*writeProjectFileNames*/
                                    true);
                                    msg += "\n-----------------------------------------------\n";
                                    counter++;
                                };
                                this.projectService.externalProjects.forEach(addProjectInfo);
                                this.projectService.configuredProjects.forEach(addProjectInfo);
                                this.projectService.inferredProjects.forEach(addProjectInfo);
                            }
                        }
                        this.logger.msg(msg, "Err" /* Err */);
                    }
                    send(msg) {
                        if (msg.type === "event" && !this.canUseEvents) {
                            if (this.logger.hasLevel(3 /* verbose */)) {
                                this.logger.info(`Session does not support events: ignored event: ${stringifyIndented(msg)}`);
                            }
                            return;
                        }
                        this.writeMessage(msg);
                    }
                    writeMessage(msg) {
                        var _a;
                        const msgText = formatMessage2(msg, this.logger, this.byteLength, this.host.newLine);
                        (_a = perfLogger) == null ? void 0 : _a.logEvent(`Response message size: ${msgText.length}`);
                        this.host.write(msgText);
                    }
                    event(body, eventName) {
                        this.send(toEvent(eventName, body));
                    }
                    /** @internal */
                    doOutput(info, cmdName, reqSeq, success, message) {
                        const res = {
                            seq: 0,
                            type: "response",
                            command: cmdName,
                            request_seq: reqSeq,
                            success,
                            performanceData: this.performanceData
                        };
                        if (success) {
                            let metadata;
                            if (isArray(info)) {
                                res.body = info;
                                metadata = info.metadata;
                                delete info.metadata;
                            }
                            else if (typeof info === "object") {
                                if (info.metadata) {
                                    const { metadata: infoMetadata, ...body } = info;
                                    res.body = body;
                                    metadata = infoMetadata;
                                }
                                else {
                                    res.body = info;
                                }
                            }
                            else {
                                res.body = info;
                            }
                            if (metadata)
                                res.metadata = metadata;
                        }
                        else {
                            Debug.assert(info === void 0);
                        }
                        if (message) {
                            res.message = message;
                        }
                        this.send(res);
                    }
                    semanticCheck(file, project) {
                        var _a, _b;
                        (_a = tracing) == null ? void 0 : _a.push(tracing.Phase.Session, "semanticCheck", { file, configFilePath: project.canonicalConfigFilePath });
                        const diags = isDeclarationFileInJSOnlyNonConfiguredProject(project, file) ? emptyArray2 : project.getLanguageService().getSemanticDiagnostics(file).filter((d) => !!d.file);
                        this.sendDiagnosticsEvent(file, project, diags, "semanticDiag");
                        (_b = tracing) == null ? void 0 : _b.pop();
                    }
                    syntacticCheck(file, project) {
                        var _a, _b;
                        (_a = tracing) == null ? void 0 : _a.push(tracing.Phase.Session, "syntacticCheck", { file, configFilePath: project.canonicalConfigFilePath });
                        this.sendDiagnosticsEvent(file, project, project.getLanguageService().getSyntacticDiagnostics(file), "syntaxDiag");
                        (_b = tracing) == null ? void 0 : _b.pop();
                    }
                    suggestionCheck(file, project) {
                        var _a, _b;
                        (_a = tracing) == null ? void 0 : _a.push(tracing.Phase.Session, "suggestionCheck", { file, configFilePath: project.canonicalConfigFilePath });
                        this.sendDiagnosticsEvent(file, project, project.getLanguageService().getSuggestionDiagnostics(file), "suggestionDiag");
                        (_b = tracing) == null ? void 0 : _b.pop();
                    }
                    sendDiagnosticsEvent(file, project, diagnostics, kind) {
                        try {
                            this.event({ file, diagnostics: diagnostics.map((diag2) => formatDiag(file, project, diag2)) }, kind);
                        }
                        catch (err) {
                            this.logError(err, kind);
                        }
                    }
                    /** It is the caller's responsibility to verify that `!this.suppressDiagnosticEvents`. */
                    updateErrorCheck(next, checkList, ms, requireOpen = true) {
                        Debug.assert(!this.suppressDiagnosticEvents);
                        const seq = this.changeSeq;
                        const followMs = Math.min(ms, 200);
                        let index = 0;
                        const goNext = () => {
                            index++;
                            if (checkList.length > index) {
                                next.delay("checkOne", followMs, checkOne);
                            }
                        };
                        const checkOne = () => {
                            if (this.changeSeq !== seq) {
                                return;
                            }
                            let item = checkList[index];
                            if (isString(item)) {
                                item = this.toPendingErrorCheck(item);
                                if (!item) {
                                    goNext();
                                    return;
                                }
                            }
                            const { fileName, project } = item;
                            updateProjectIfDirty(project);
                            if (!project.containsFile(fileName, requireOpen)) {
                                return;
                            }
                            this.syntacticCheck(fileName, project);
                            if (this.changeSeq !== seq) {
                                return;
                            }
                            if (project.projectService.serverMode !== 0 /* Semantic */) {
                                goNext();
                                return;
                            }
                            next.immediate("semanticCheck", () => {
                                this.semanticCheck(fileName, project);
                                if (this.changeSeq !== seq) {
                                    return;
                                }
                                if (this.getPreferences(fileName).disableSuggestions) {
                                    goNext();
                                    return;
                                }
                                next.immediate("suggestionCheck", () => {
                                    this.suggestionCheck(fileName, project);
                                    goNext();
                                });
                            });
                        };
                        if (checkList.length > index && this.changeSeq === seq) {
                            next.delay("checkOne", ms, checkOne);
                        }
                    }
                    cleanProjects(caption, projects) {
                        if (!projects) {
                            return;
                        }
                        this.logger.info(`cleaning ${caption}`);
                        for (const p of projects) {
                            p.getLanguageService(
                            /*ensureSynchronized*/
                            false).cleanupSemanticCache();
                            p.cleanupProgram();
                        }
                    }
                    cleanup() {
                        this.cleanProjects("inferred projects", this.projectService.inferredProjects);
                        this.cleanProjects("configured projects", arrayFrom(this.projectService.configuredProjects.values()));
                        this.cleanProjects("external projects", this.projectService.externalProjects);
                        if (this.host.gc) {
                            this.logger.info(`host.gc()`);
                            this.host.gc();
                        }
                    }
                    getEncodedSyntacticClassifications(args) {
                        const { file, languageService } = this.getFileAndLanguageServiceForSyntacticOperation(args);
                        return languageService.getEncodedSyntacticClassifications(file, args);
                    }
                    getEncodedSemanticClassifications(args) {
                        const { file, project } = this.getFileAndProject(args);
                        const format = args.format === "2020" ? "2020" /* TwentyTwenty */ : "original" /* Original */;
                        return project.getLanguageService().getEncodedSemanticClassifications(file, args, format);
                    }
                    getProject(projectFileName) {
                        return projectFileName === void 0 ? void 0 : this.projectService.findProject(projectFileName);
                    }
                    getConfigFileAndProject(args) {
                        const project = this.getProject(args.projectFileName);
                        const file = toNormalizedPath(args.file);
                        return {
                            configFile: project && project.hasConfigFile(file) ? file : void 0,
                            project
                        };
                    }
                    getConfigFileDiagnostics(configFile, project, includeLinePosition) {
                        const projectErrors = project.getAllProjectErrors();
                        const optionsErrors = project.getLanguageService().getCompilerOptionsDiagnostics();
                        const diagnosticsForConfigFile = filter(concatenate(projectErrors, optionsErrors), (diagnostic) => !!diagnostic.file && diagnostic.file.fileName === configFile);
                        return includeLinePosition ? this.convertToDiagnosticsWithLinePositionFromDiagnosticFile(diagnosticsForConfigFile) : map(diagnosticsForConfigFile, (diagnostic) => formatDiagnosticToProtocol(diagnostic, 
                        /*includeFileName*/
                        false));
                    }
                    convertToDiagnosticsWithLinePositionFromDiagnosticFile(diagnostics) {
                        return diagnostics.map((d) => ({
                            message: flattenDiagnosticMessageText(d.messageText, this.host.newLine),
                            start: d.start,
                            // TODO: GH#18217
                            length: d.length,
                            // TODO: GH#18217
                            category: diagnosticCategoryName(d),
                            code: d.code,
                            source: d.source,
                            startLocation: d.file && convertToLocation(getLineAndCharacterOfPosition(d.file, d.start)),
                            // TODO: GH#18217
                            endLocation: d.file && convertToLocation(getLineAndCharacterOfPosition(d.file, d.start + d.length)),
                            // TODO: GH#18217
                            reportsUnnecessary: d.reportsUnnecessary,
                            reportsDeprecated: d.reportsDeprecated,
                            relatedInformation: map(d.relatedInformation, formatRelatedInformation)
                        }));
                    }
                    getCompilerOptionsDiagnostics(args) {
                        const project = this.getProject(args.projectFileName);
                        return this.convertToDiagnosticsWithLinePosition(filter(project.getLanguageService().getCompilerOptionsDiagnostics(), (diagnostic) => !diagnostic.file), 
                        /*scriptInfo*/
                        void 0);
                    }
                    convertToDiagnosticsWithLinePosition(diagnostics, scriptInfo) {
                        return diagnostics.map((d) => ({
                            message: flattenDiagnosticMessageText(d.messageText, this.host.newLine),
                            start: d.start,
                            length: d.length,
                            category: diagnosticCategoryName(d),
                            code: d.code,
                            source: d.source,
                            startLocation: scriptInfo && scriptInfo.positionToLineOffset(d.start),
                            // TODO: GH#18217
                            endLocation: scriptInfo && scriptInfo.positionToLineOffset(d.start + d.length),
                            reportsUnnecessary: d.reportsUnnecessary,
                            reportsDeprecated: d.reportsDeprecated,
                            relatedInformation: map(d.relatedInformation, formatRelatedInformation)
                        }));
                    }
                    getDiagnosticsWorker(args, isSemantic, selector, includeLinePosition) {
                        const { project, file } = this.getFileAndProject(args);
                        if (isSemantic && isDeclarationFileInJSOnlyNonConfiguredProject(project, file)) {
                            return emptyArray2;
                        }
                        const scriptInfo = project.getScriptInfoForNormalizedPath(file);
                        const diagnostics = selector(project, file);
                        return includeLinePosition ? this.convertToDiagnosticsWithLinePosition(diagnostics, scriptInfo) : diagnostics.map((d) => formatDiag(file, project, d));
                    }
                    getDefinition(args, simplifiedResult) {
                        const { file, project } = this.getFileAndProject(args);
                        const position = this.getPositionInFile(args, file);
                        const definitions = this.mapDefinitionInfoLocations(project.getLanguageService().getDefinitionAtPosition(file, position) || emptyArray2, project);
                        return simplifiedResult ? this.mapDefinitionInfo(definitions, project) : definitions.map(_Session.mapToOriginalLocation);
                    }
                    mapDefinitionInfoLocations(definitions, project) {
                        return definitions.map((info) => {
                            const newDocumentSpan = getMappedDocumentSpanForProject(info, project);
                            return !newDocumentSpan ? info : {
                                ...newDocumentSpan,
                                containerKind: info.containerKind,
                                containerName: info.containerName,
                                kind: info.kind,
                                name: info.name,
                                failedAliasResolution: info.failedAliasResolution,
                                ...info.unverified && { unverified: info.unverified }
                            };
                        });
                    }
                    getDefinitionAndBoundSpan(args, simplifiedResult) {
                        const { file, project } = this.getFileAndProject(args);
                        const position = this.getPositionInFile(args, file);
                        const scriptInfo = Debug.checkDefined(project.getScriptInfo(file));
                        const unmappedDefinitionAndBoundSpan = project.getLanguageService().getDefinitionAndBoundSpan(file, position);
                        if (!unmappedDefinitionAndBoundSpan || !unmappedDefinitionAndBoundSpan.definitions) {
                            return {
                                definitions: emptyArray2,
                                textSpan: void 0
                                // TODO: GH#18217
                            };
                        }
                        const definitions = this.mapDefinitionInfoLocations(unmappedDefinitionAndBoundSpan.definitions, project);
                        const { textSpan } = unmappedDefinitionAndBoundSpan;
                        if (simplifiedResult) {
                            return {
                                definitions: this.mapDefinitionInfo(definitions, project),
                                textSpan: toProtocolTextSpan(textSpan, scriptInfo)
                            };
                        }
                        return {
                            definitions: definitions.map(_Session.mapToOriginalLocation),
                            textSpan
                        };
                    }
                    findSourceDefinition(args) {
                        var _a;
                        const { file, project } = this.getFileAndProject(args);
                        const position = this.getPositionInFile(args, file);
                        const unmappedDefinitions = project.getLanguageService().getDefinitionAtPosition(file, position);
                        let definitions = this.mapDefinitionInfoLocations(unmappedDefinitions || emptyArray2, project).slice();
                        const needsJsResolution = this.projectService.serverMode === 0 /* Semantic */ && (!some(definitions, (d) => toNormalizedPath(d.fileName) !== file && !d.isAmbient) || some(definitions, (d) => !!d.failedAliasResolution));
                        if (needsJsResolution) {
                            const definitionSet = createSet((d) => d.textSpan.start, getDocumentSpansEqualityComparer(this.host.useCaseSensitiveFileNames));
                            definitions == null ? void 0 : definitions.forEach((d) => definitionSet.add(d));
                            const noDtsProject = project.getNoDtsResolutionProject(file);
                            const ls = noDtsProject.getLanguageService();
                            const jsDefinitions = (_a = ls.getDefinitionAtPosition(file, position, 
                            /*searchOtherFilesOnly*/
                            true, 
                            /*stopAtAlias*/
                            false)) == null ? void 0 : _a.filter((d) => toNormalizedPath(d.fileName) !== file);
                            if (some(jsDefinitions)) {
                                for (const jsDefinition of jsDefinitions) {
                                    if (jsDefinition.unverified) {
                                        const refined = tryRefineDefinition(jsDefinition, project.getLanguageService().getProgram(), ls.getProgram());
                                        if (some(refined)) {
                                            for (const def of refined) {
                                                definitionSet.add(def);
                                            }
                                            continue;
                                        }
                                    }
                                    definitionSet.add(jsDefinition);
                                }
                            }
                            else {
                                const ambientCandidates = definitions.filter((d) => toNormalizedPath(d.fileName) !== file && d.isAmbient);
                                for (const candidate of some(ambientCandidates) ? ambientCandidates : getAmbientCandidatesByClimbingAccessChain()) {
                                    const fileNameToSearch = findImplementationFileFromDtsFileName(candidate.fileName, file, noDtsProject);
                                    if (!fileNameToSearch)
                                        continue;
                                    const info = this.projectService.getOrCreateScriptInfoNotOpenedByClient(fileNameToSearch, noDtsProject.currentDirectory, noDtsProject.directoryStructureHost);
                                    if (!info)
                                        continue;
                                    if (!noDtsProject.containsScriptInfo(info)) {
                                        noDtsProject.addRoot(info);
                                        noDtsProject.updateGraph();
                                    }
                                    const noDtsProgram = ls.getProgram();
                                    const fileToSearch = Debug.checkDefined(noDtsProgram.getSourceFile(fileNameToSearch));
                                    for (const match of searchForDeclaration(candidate.name, fileToSearch, noDtsProgram)) {
                                        definitionSet.add(match);
                                    }
                                }
                            }
                            definitions = arrayFrom(definitionSet.values());
                        }
                        definitions = definitions.filter((d) => !d.isAmbient && !d.failedAliasResolution);
                        return this.mapDefinitionInfo(definitions, project);
                        function findImplementationFileFromDtsFileName(fileName, resolveFromFile, auxiliaryProject) {
                            var _a2, _b, _c;
                            const nodeModulesPathParts = getNodeModulePathParts(fileName);
                            if (nodeModulesPathParts && fileName.lastIndexOf(nodeModulesPathPart) === nodeModulesPathParts.topLevelNodeModulesIndex) {
                                const packageDirectory = fileName.substring(0, nodeModulesPathParts.packageRootIndex);
                                const packageJsonCache = (_a2 = project.getModuleResolutionCache()) == null ? void 0 : _a2.getPackageJsonInfoCache();
                                const compilerOptions = project.getCompilationSettings();
                                const packageJson = getPackageScopeForPath(getNormalizedAbsolutePath(packageDirectory + "/package.json", project.getCurrentDirectory()), getTemporaryModuleResolutionState(packageJsonCache, project, compilerOptions));
                                if (!packageJson)
                                    return void 0;
                                const entrypoints = getEntrypointsFromPackageJsonInfo(packageJson, { moduleResolution: 2 /* Node10 */ }, project, project.getModuleResolutionCache());
                                const packageNamePathPart = fileName.substring(nodeModulesPathParts.topLevelPackageNameIndex + 1, nodeModulesPathParts.packageRootIndex);
                                const packageName = getPackageNameFromTypesPackageName(unmangleScopedPackageName(packageNamePathPart));
                                const path = project.toPath(fileName);
                                if (entrypoints && some(entrypoints, (e) => project.toPath(e) === path)) {
                                    return (_b = auxiliaryProject.resolutionCache.resolveSingleModuleNameWithoutWatching(packageName, resolveFromFile).resolvedModule) == null ? void 0 : _b.resolvedFileName;
                                }
                                else {
                                    const pathToFileInPackage = fileName.substring(nodeModulesPathParts.packageRootIndex + 1);
                                    const specifier = `${packageName}/${removeFileExtension(pathToFileInPackage)}`;
                                    return (_c = auxiliaryProject.resolutionCache.resolveSingleModuleNameWithoutWatching(specifier, resolveFromFile).resolvedModule) == null ? void 0 : _c.resolvedFileName;
                                }
                            }
                            return void 0;
                        }
                        function getAmbientCandidatesByClimbingAccessChain() {
                            const ls = project.getLanguageService();
                            const program = ls.getProgram();
                            const initialNode = getTouchingPropertyName(program.getSourceFile(file), position);
                            if ((isStringLiteralLike(initialNode) || isIdentifier(initialNode)) && isAccessExpression(initialNode.parent)) {
                                return forEachNameInAccessChainWalkingLeft(initialNode, (nameInChain) => {
                                    var _a2;
                                    if (nameInChain === initialNode)
                                        return void 0;
                                    const candidates = (_a2 = ls.getDefinitionAtPosition(file, nameInChain.getStart(), 
                                    /*searchOtherFilesOnly*/
                                    true, 
                                    /*stopAtAlias*/
                                    false)) == null ? void 0 : _a2.filter((d) => toNormalizedPath(d.fileName) !== file && d.isAmbient).map((d) => ({
                                        fileName: d.fileName,
                                        name: getTextOfIdentifierOrLiteral(initialNode)
                                    }));
                                    if (some(candidates)) {
                                        return candidates;
                                    }
                                }) || emptyArray2;
                            }
                            return emptyArray2;
                        }
                        function tryRefineDefinition(definition, program, noDtsProgram) {
                            var _a2;
                            const fileToSearch = noDtsProgram.getSourceFile(definition.fileName);
                            if (!fileToSearch) {
                                return void 0;
                            }
                            const initialNode = getTouchingPropertyName(program.getSourceFile(file), position);
                            const symbol = program.getTypeChecker().getSymbolAtLocation(initialNode);
                            const importSpecifier = symbol && getDeclarationOfKind(symbol, 276 /* ImportSpecifier */);
                            if (!importSpecifier)
                                return void 0;
                            const nameToSearch = ((_a2 = importSpecifier.propertyName) == null ? void 0 : _a2.text) || importSpecifier.name.text;
                            return searchForDeclaration(nameToSearch, fileToSearch, noDtsProgram);
                        }
                        function searchForDeclaration(declarationName, fileToSearch, noDtsProgram) {
                            const matches = ts_FindAllReferences_exports.Core.getTopMostDeclarationNamesInFile(declarationName, fileToSearch);
                            return mapDefined(matches, (match) => {
                                const symbol = noDtsProgram.getTypeChecker().getSymbolAtLocation(match);
                                const decl = getDeclarationFromName(match);
                                if (symbol && decl) {
                                    return ts_GoToDefinition_exports.createDefinitionInfo(decl, noDtsProgram.getTypeChecker(), symbol, decl, 
                                    /*unverified*/
                                    true);
                                }
                            });
                        }
                    }
                    getEmitOutput(args) {
                        const { file, project } = this.getFileAndProject(args);
                        if (!project.shouldEmitFile(project.getScriptInfo(file))) {
                            return { emitSkipped: true, outputFiles: [], diagnostics: [] };
                        }
                        const result = project.getLanguageService().getEmitOutput(file);
                        return args.richResponse ? {
                            ...result,
                            diagnostics: args.includeLinePosition ? this.convertToDiagnosticsWithLinePositionFromDiagnosticFile(result.diagnostics) : result.diagnostics.map((d) => formatDiagnosticToProtocol(d, 
                            /*includeFileName*/
                            true))
                        } : result;
                    }
                    mapJSDocTagInfo(tags, project, richResponse) {
                        return tags ? tags.map((tag) => {
                            var _a;
                            return {
                                ...tag,
                                text: richResponse ? this.mapDisplayParts(tag.text, project) : (_a = tag.text) == null ? void 0 : _a.map((part) => part.text).join("")
                            };
                        }) : [];
                    }
                    mapDisplayParts(parts, project) {
                        if (!parts) {
                            return [];
                        }
                        return parts.map((part) => part.kind !== "linkName" ? part : {
                            ...part,
                            target: this.toFileSpan(part.target.fileName, part.target.textSpan, project)
                        });
                    }
                    mapSignatureHelpItems(items, project, richResponse) {
                        return items.map((item) => ({
                            ...item,
                            documentation: this.mapDisplayParts(item.documentation, project),
                            parameters: item.parameters.map((p) => ({ ...p, documentation: this.mapDisplayParts(p.documentation, project) })),
                            tags: this.mapJSDocTagInfo(item.tags, project, richResponse)
                        }));
                    }
                    mapDefinitionInfo(definitions, project) {
                        return definitions.map((def) => ({ ...this.toFileSpanWithContext(def.fileName, def.textSpan, def.contextSpan, project), ...def.unverified && { unverified: def.unverified } }));
                    }
                    /*
                     * When we map a .d.ts location to .ts, Visual Studio gets confused because there's no associated Roslyn Document in
                     * the same project which corresponds to the file. VS Code has no problem with this, and luckily we have two protocols.
                     * This retains the existing behavior for the "simplified" (VS Code) protocol but stores the .d.ts location in a
                     * set of additional fields, and does the reverse for VS (store the .d.ts location where
                     * it used to be and stores the .ts location in the additional fields).
                     */
                    static mapToOriginalLocation(def) {
                        if (def.originalFileName) {
                            Debug.assert(def.originalTextSpan !== void 0, "originalTextSpan should be present if originalFileName is");
                            return {
                                ...def,
                                fileName: def.originalFileName,
                                textSpan: def.originalTextSpan,
                                targetFileName: def.fileName,
                                targetTextSpan: def.textSpan,
                                contextSpan: def.originalContextSpan,
                                targetContextSpan: def.contextSpan
                            };
                        }
                        return def;
                    }
                    toFileSpan(fileName, textSpan, project) {
                        const ls = project.getLanguageService();
                        const start = ls.toLineColumnOffset(fileName, textSpan.start);
                        const end = ls.toLineColumnOffset(fileName, textSpanEnd(textSpan));
                        return {
                            file: fileName,
                            start: { line: start.line + 1, offset: start.character + 1 },
                            end: { line: end.line + 1, offset: end.character + 1 }
                        };
                    }
                    toFileSpanWithContext(fileName, textSpan, contextSpan, project) {
                        const fileSpan = this.toFileSpan(fileName, textSpan, project);
                        const context = contextSpan && this.toFileSpan(fileName, contextSpan, project);
                        return context ? { ...fileSpan, contextStart: context.start, contextEnd: context.end } : fileSpan;
                    }
                    getTypeDefinition(args) {
                        const { file, project } = this.getFileAndProject(args);
                        const position = this.getPositionInFile(args, file);
                        const definitions = this.mapDefinitionInfoLocations(project.getLanguageService().getTypeDefinitionAtPosition(file, position) || emptyArray2, project);
                        return this.mapDefinitionInfo(definitions, project);
                    }
                    mapImplementationLocations(implementations, project) {
                        return implementations.map((info) => {
                            const newDocumentSpan = getMappedDocumentSpanForProject(info, project);
                            return !newDocumentSpan ? info : {
                                ...newDocumentSpan,
                                kind: info.kind,
                                displayParts: info.displayParts
                            };
                        });
                    }
                    getImplementation(args, simplifiedResult) {
                        const { file, project } = this.getFileAndProject(args);
                        const position = this.getPositionInFile(args, file);
                        const implementations = this.mapImplementationLocations(project.getLanguageService().getImplementationAtPosition(file, position) || emptyArray2, project);
                        return simplifiedResult ? implementations.map(({ fileName, textSpan, contextSpan }) => this.toFileSpanWithContext(fileName, textSpan, contextSpan, project)) : implementations.map(_Session.mapToOriginalLocation);
                    }
                    getSyntacticDiagnosticsSync(args) {
                        const { configFile } = this.getConfigFileAndProject(args);
                        if (configFile) {
                            return emptyArray2;
                        }
                        return this.getDiagnosticsWorker(args, 
                        /*isSemantic*/
                        false, (project, file) => project.getLanguageService().getSyntacticDiagnostics(file), !!args.includeLinePosition);
                    }
                    getSemanticDiagnosticsSync(args) {
                        const { configFile, project } = this.getConfigFileAndProject(args);
                        if (configFile) {
                            return this.getConfigFileDiagnostics(configFile, project, !!args.includeLinePosition);
                        }
                        return this.getDiagnosticsWorker(args, 
                        /*isSemantic*/
                        true, (project2, file) => project2.getLanguageService().getSemanticDiagnostics(file).filter((d) => !!d.file), !!args.includeLinePosition);
                    }
                    getSuggestionDiagnosticsSync(args) {
                        const { configFile } = this.getConfigFileAndProject(args);
                        if (configFile) {
                            return emptyArray2;
                        }
                        return this.getDiagnosticsWorker(args, 
                        /*isSemantic*/
                        true, (project, file) => project.getLanguageService().getSuggestionDiagnostics(file), !!args.includeLinePosition);
                    }
                    getJsxClosingTag(args) {
                        const { file, languageService } = this.getFileAndLanguageServiceForSyntacticOperation(args);
                        const position = this.getPositionInFile(args, file);
                        const tag = languageService.getJsxClosingTagAtPosition(file, position);
                        return tag === void 0 ? void 0 : { newText: tag.newText, caretOffset: 0 };
                    }
                    getLinkedEditingRange(args) {
                        const { file, languageService } = this.getFileAndLanguageServiceForSyntacticOperation(args);
                        const position = this.getPositionInFile(args, file);
                        const linkedEditInfo = languageService.getLinkedEditingRangeAtPosition(file, position);
                        const scriptInfo = this.projectService.getScriptInfoForNormalizedPath(file);
                        if (scriptInfo === void 0 || linkedEditInfo === void 0)
                            return void 0;
                        return convertLinkedEditInfoToRanges(linkedEditInfo, scriptInfo);
                    }
                    getDocumentHighlights(args, simplifiedResult) {
                        const { file, project } = this.getFileAndProject(args);
                        const position = this.getPositionInFile(args, file);
                        const documentHighlights = project.getLanguageService().getDocumentHighlights(file, position, args.filesToSearch);
                        if (!documentHighlights)
                            return emptyArray2;
                        if (!simplifiedResult)
                            return documentHighlights;
                        return documentHighlights.map(({ fileName, highlightSpans }) => {
                            const scriptInfo = project.getScriptInfo(fileName);
                            return {
                                file: fileName,
                                highlightSpans: highlightSpans.map(({ textSpan, kind, contextSpan }) => ({
                                    ...toProtocolTextSpanWithContext(textSpan, contextSpan, scriptInfo),
                                    kind
                                }))
                            };
                        });
                    }
                    provideInlayHints(args) {
                        const { file, project } = this.getFileAndProject(args);
                        const scriptInfo = this.projectService.getScriptInfoForNormalizedPath(file);
                        const hints = project.getLanguageService().provideInlayHints(file, args, this.getPreferences(file));
                        return hints.map((hint) => {
                            const { position, displayParts } = hint;
                            return {
                                ...hint,
                                position: scriptInfo.positionToLineOffset(position),
                                displayParts: displayParts == null ? void 0 : displayParts.map(({ text, span, file: file2 }) => {
                                    if (span) {
                                        Debug.assertIsDefined(file2, "Target file should be defined together with its span.");
                                        const scriptInfo2 = this.projectService.getScriptInfo(file2);
                                        return {
                                            text,
                                            span: {
                                                start: scriptInfo2.positionToLineOffset(span.start),
                                                end: scriptInfo2.positionToLineOffset(span.start + span.length),
                                                file: file2
                                            }
                                        };
                                    }
                                    else {
                                        return { text };
                                    }
                                })
                            };
                        });
                    }
                    setCompilerOptionsForInferredProjects(args) {
                        this.projectService.setCompilerOptionsForInferredProjects(args.options, args.projectRootPath);
                    }
                    getProjectInfo(args) {
                        return this.getProjectInfoWorker(args.file, args.projectFileName, args.needFileNameList, 
                        /*excludeConfigFiles*/
                        false);
                    }
                    getProjectInfoWorker(uncheckedFileName, projectFileName, needFileNameList, excludeConfigFiles) {
                        const { project } = this.getFileAndProjectWorker(uncheckedFileName, projectFileName);
                        updateProjectIfDirty(project);
                        const projectInfo = {
                            configFileName: project.getProjectName(),
                            languageServiceDisabled: !project.languageServiceEnabled,
                            fileNames: needFileNameList ? project.getFileNames(
                            /*excludeFilesFromExternalLibraries*/
                            false, excludeConfigFiles) : void 0
                        };
                        return projectInfo;
                    }
                    getRenameInfo(args) {
                        const { file, project } = this.getFileAndProject(args);
                        const position = this.getPositionInFile(args, file);
                        const preferences = this.getPreferences(file);
                        return project.getLanguageService().getRenameInfo(file, position, preferences);
                    }
                    getProjects(args, getScriptInfoEnsuringProjectsUptoDate, ignoreNoProjectError) {
                        let projects;
                        let symLinkedProjects;
                        if (args.projectFileName) {
                            const project = this.getProject(args.projectFileName);
                            if (project) {
                                projects = [project];
                            }
                        }
                        else {
                            const scriptInfo = getScriptInfoEnsuringProjectsUptoDate ? this.projectService.getScriptInfoEnsuringProjectsUptoDate(args.file) : this.projectService.getScriptInfo(args.file);
                            if (!scriptInfo) {
                                if (ignoreNoProjectError)
                                    return emptyArray2;
                                this.projectService.logErrorForScriptInfoNotFound(args.file);
                                return Errors.ThrowNoProject();
                            }
                            else if (!getScriptInfoEnsuringProjectsUptoDate) {
                                this.projectService.ensureDefaultProjectForFile(scriptInfo);
                            }
                            projects = scriptInfo.containingProjects;
                            symLinkedProjects = this.projectService.getSymlinkedProjects(scriptInfo);
                        }
                        projects = filter(projects, (p) => p.languageServiceEnabled && !p.isOrphan());
                        if (!ignoreNoProjectError && (!projects || !projects.length) && !symLinkedProjects) {
                            this.projectService.logErrorForScriptInfoNotFound(args.file ?? args.projectFileName);
                            return Errors.ThrowNoProject();
                        }
                        return symLinkedProjects ? { projects, symLinkedProjects } : projects;
                    }
                    getDefaultProject(args) {
                        if (args.projectFileName) {
                            const project = this.getProject(args.projectFileName);
                            if (project) {
                                return project;
                            }
                            if (!args.file) {
                                return Errors.ThrowNoProject();
                            }
                        }
                        const info = this.projectService.getScriptInfo(args.file);
                        return info.getDefaultProject();
                    }
                    getRenameLocations(args, simplifiedResult) {
                        const file = toNormalizedPath(args.file);
                        const position = this.getPositionInFile(args, file);
                        const projects = this.getProjects(args);
                        const defaultProject = this.getDefaultProject(args);
                        const preferences = this.getPreferences(file);
                        const renameInfo = this.mapRenameInfo(defaultProject.getLanguageService().getRenameInfo(file, position, preferences), Debug.checkDefined(this.projectService.getScriptInfo(file)));
                        if (!renameInfo.canRename)
                            return simplifiedResult ? { info: renameInfo, locs: [] } : [];
                        const locations = getRenameLocationsWorker(projects, defaultProject, { fileName: args.file, pos: position }, !!args.findInStrings, !!args.findInComments, preferences, this.host.useCaseSensitiveFileNames);
                        if (!simplifiedResult)
                            return locations;
                        return { info: renameInfo, locs: this.toSpanGroups(locations) };
                    }
                    mapRenameInfo(info, scriptInfo) {
                        if (info.canRename) {
                            const { canRename, fileToRename, displayName, fullDisplayName, kind, kindModifiers, triggerSpan } = info;
                            return identity({ canRename, fileToRename, displayName, fullDisplayName, kind, kindModifiers, triggerSpan: toProtocolTextSpan(triggerSpan, scriptInfo) });
                        }
                        else {
                            return info;
                        }
                    }
                    toSpanGroups(locations) {
                        const map2 = /* @__PURE__ */ new Map();
                        for (const { fileName, textSpan, contextSpan, originalContextSpan: _2, originalTextSpan: _, originalFileName: _1, ...prefixSuffixText } of locations) {
                            let group2 = map2.get(fileName);
                            if (!group2)
                                map2.set(fileName, group2 = { file: fileName, locs: [] });
                            const scriptInfo = Debug.checkDefined(this.projectService.getScriptInfo(fileName));
                            group2.locs.push({ ...toProtocolTextSpanWithContext(textSpan, contextSpan, scriptInfo), ...prefixSuffixText });
                        }
                        return arrayFrom(map2.values());
                    }
                    getReferences(args, simplifiedResult) {
                        const file = toNormalizedPath(args.file);
                        const projects = this.getProjects(args);
                        const position = this.getPositionInFile(args, file);
                        const references = getReferencesWorker(projects, this.getDefaultProject(args), { fileName: args.file, pos: position }, this.host.useCaseSensitiveFileNames, this.logger);
                        if (!simplifiedResult)
                            return references;
                        const preferences = this.getPreferences(file);
                        const defaultProject = this.getDefaultProject(args);
                        const scriptInfo = defaultProject.getScriptInfoForNormalizedPath(file);
                        const nameInfo = defaultProject.getLanguageService().getQuickInfoAtPosition(file, position);
                        const symbolDisplayString = nameInfo ? displayPartsToString(nameInfo.displayParts) : "";
                        const nameSpan = nameInfo && nameInfo.textSpan;
                        const symbolStartOffset = nameSpan ? scriptInfo.positionToLineOffset(nameSpan.start).offset : 0;
                        const symbolName2 = nameSpan ? scriptInfo.getSnapshot().getText(nameSpan.start, textSpanEnd(nameSpan)) : "";
                        const refs = flatMap(references, (referencedSymbol) => {
                            return referencedSymbol.references.map((entry) => referenceEntryToReferencesResponseItem(this.projectService, entry, preferences));
                        });
                        return { refs, symbolName: symbolName2, symbolStartOffset, symbolDisplayString };
                    }
                    getFileReferences(args, simplifiedResult) {
                        const projects = this.getProjects(args);
                        const fileName = args.file;
                        const preferences = this.getPreferences(toNormalizedPath(fileName));
                        const references = [];
                        const seen = createDocumentSpanSet(this.host.useCaseSensitiveFileNames);
                        forEachProjectInProjects(projects, 
                        /*path*/
                        void 0, (project) => {
                            if (project.getCancellationToken().isCancellationRequested())
                                return;
                            const projectOutputs = project.getLanguageService().getFileReferences(fileName);
                            if (projectOutputs) {
                                for (const referenceEntry of projectOutputs) {
                                    if (!seen.has(referenceEntry)) {
                                        references.push(referenceEntry);
                                        seen.add(referenceEntry);
                                    }
                                }
                            }
                        });
                        if (!simplifiedResult)
                            return references;
                        const refs = references.map((entry) => referenceEntryToReferencesResponseItem(this.projectService, entry, preferences));
                        return {
                            refs,
                            symbolName: `"${args.file}"`
                        };
                    }
                    /**
                     * @param fileName is the name of the file to be opened
                     * @param fileContent is a version of the file content that is known to be more up to date than the one on disk
                     */
                    openClientFile(fileName, fileContent, scriptKind, projectRootPath) {
                        this.projectService.openClientFileWithNormalizedPath(fileName, fileContent, scriptKind, 
                        /*hasMixedContent*/
                        false, projectRootPath);
                    }
                    getPosition(args, scriptInfo) {
                        return args.position !== void 0 ? args.position : scriptInfo.lineOffsetToPosition(args.line, args.offset);
                    }
                    getPositionInFile(args, file) {
                        const scriptInfo = this.projectService.getScriptInfoForNormalizedPath(file);
                        return this.getPosition(args, scriptInfo);
                    }
                    getFileAndProject(args) {
                        return this.getFileAndProjectWorker(args.file, args.projectFileName);
                    }
                    getFileAndLanguageServiceForSyntacticOperation(args) {
                        const { file, project } = this.getFileAndProject(args);
                        return {
                            file,
                            languageService: project.getLanguageService(
                            /*ensureSynchronized*/
                            false)
                        };
                    }
                    getFileAndProjectWorker(uncheckedFileName, projectFileName) {
                        const file = toNormalizedPath(uncheckedFileName);
                        const project = this.getProject(projectFileName) || this.projectService.ensureDefaultProjectForFile(file);
                        return { file, project };
                    }
                    getOutliningSpans(args, simplifiedResult) {
                        const { file, languageService } = this.getFileAndLanguageServiceForSyntacticOperation(args);
                        const spans = languageService.getOutliningSpans(file);
                        if (simplifiedResult) {
                            const scriptInfo = this.projectService.getScriptInfoForNormalizedPath(file);
                            return spans.map((s) => ({
                                textSpan: toProtocolTextSpan(s.textSpan, scriptInfo),
                                hintSpan: toProtocolTextSpan(s.hintSpan, scriptInfo),
                                bannerText: s.bannerText,
                                autoCollapse: s.autoCollapse,
                                kind: s.kind
                            }));
                        }
                        else {
                            return spans;
                        }
                    }
                    getTodoComments(args) {
                        const { file, project } = this.getFileAndProject(args);
                        return project.getLanguageService().getTodoComments(file, args.descriptors);
                    }
                    getDocCommentTemplate(args) {
                        const { file, languageService } = this.getFileAndLanguageServiceForSyntacticOperation(args);
                        const position = this.getPositionInFile(args, file);
                        return languageService.getDocCommentTemplateAtPosition(file, position, this.getPreferences(file), this.getFormatOptions(file));
                    }
                    getSpanOfEnclosingComment(args) {
                        const { file, languageService } = this.getFileAndLanguageServiceForSyntacticOperation(args);
                        const onlyMultiLine = args.onlyMultiLine;
                        const position = this.getPositionInFile(args, file);
                        return languageService.getSpanOfEnclosingComment(file, position, onlyMultiLine);
                    }
                    getIndentation(args) {
                        const { file, languageService } = this.getFileAndLanguageServiceForSyntacticOperation(args);
                        const position = this.getPositionInFile(args, file);
                        const options = args.options ? convertFormatOptions(args.options) : this.getFormatOptions(file);
                        const indentation = languageService.getIndentationAtPosition(file, position, options);
                        return { position, indentation };
                    }
                    getBreakpointStatement(args) {
                        const { file, languageService } = this.getFileAndLanguageServiceForSyntacticOperation(args);
                        const position = this.getPositionInFile(args, file);
                        return languageService.getBreakpointStatementAtPosition(file, position);
                    }
                    getNameOrDottedNameSpan(args) {
                        const { file, languageService } = this.getFileAndLanguageServiceForSyntacticOperation(args);
                        const position = this.getPositionInFile(args, file);
                        return languageService.getNameOrDottedNameSpan(file, position, position);
                    }
                    isValidBraceCompletion(args) {
                        const { file, languageService } = this.getFileAndLanguageServiceForSyntacticOperation(args);
                        const position = this.getPositionInFile(args, file);
                        return languageService.isValidBraceCompletionAtPosition(file, position, args.openingBrace.charCodeAt(0));
                    }
                    getQuickInfoWorker(args, simplifiedResult) {
                        const { file, project } = this.getFileAndProject(args);
                        const scriptInfo = this.projectService.getScriptInfoForNormalizedPath(file);
                        const quickInfo = project.getLanguageService().getQuickInfoAtPosition(file, this.getPosition(args, scriptInfo));
                        if (!quickInfo) {
                            return void 0;
                        }
                        const useDisplayParts = !!this.getPreferences(file).displayPartsForJSDoc;
                        if (simplifiedResult) {
                            const displayString = displayPartsToString(quickInfo.displayParts);
                            return {
                                kind: quickInfo.kind,
                                kindModifiers: quickInfo.kindModifiers,
                                start: scriptInfo.positionToLineOffset(quickInfo.textSpan.start),
                                end: scriptInfo.positionToLineOffset(textSpanEnd(quickInfo.textSpan)),
                                displayString,
                                documentation: useDisplayParts ? this.mapDisplayParts(quickInfo.documentation, project) : displayPartsToString(quickInfo.documentation),
                                tags: this.mapJSDocTagInfo(quickInfo.tags, project, useDisplayParts)
                            };
                        }
                        else {
                            return useDisplayParts ? quickInfo : {
                                ...quickInfo,
                                tags: this.mapJSDocTagInfo(quickInfo.tags, project, 
                                /*richResponse*/
                                false)
                            };
                        }
                    }
                    getFormattingEditsForRange(args) {
                        const { file, languageService } = this.getFileAndLanguageServiceForSyntacticOperation(args);
                        const scriptInfo = this.projectService.getScriptInfoForNormalizedPath(file);
                        const startPosition = scriptInfo.lineOffsetToPosition(args.line, args.offset);
                        const endPosition = scriptInfo.lineOffsetToPosition(args.endLine, args.endOffset);
                        const edits = languageService.getFormattingEditsForRange(file, startPosition, endPosition, this.getFormatOptions(file));
                        if (!edits) {
                            return void 0;
                        }
                        return edits.map((edit) => this.convertTextChangeToCodeEdit(edit, scriptInfo));
                    }
                    getFormattingEditsForRangeFull(args) {
                        const { file, languageService } = this.getFileAndLanguageServiceForSyntacticOperation(args);
                        const options = args.options ? convertFormatOptions(args.options) : this.getFormatOptions(file);
                        return languageService.getFormattingEditsForRange(file, args.position, args.endPosition, options);
                    }
                    getFormattingEditsForDocumentFull(args) {
                        const { file, languageService } = this.getFileAndLanguageServiceForSyntacticOperation(args);
                        const options = args.options ? convertFormatOptions(args.options) : this.getFormatOptions(file);
                        return languageService.getFormattingEditsForDocument(file, options);
                    }
                    getFormattingEditsAfterKeystrokeFull(args) {
                        const { file, languageService } = this.getFileAndLanguageServiceForSyntacticOperation(args);
                        const options = args.options ? convertFormatOptions(args.options) : this.getFormatOptions(file);
                        return languageService.getFormattingEditsAfterKeystroke(file, args.position, args.key, options);
                    }
                    getFormattingEditsAfterKeystroke(args) {
                        const { file, languageService } = this.getFileAndLanguageServiceForSyntacticOperation(args);
                        const scriptInfo = this.projectService.getScriptInfoForNormalizedPath(file);
                        const position = scriptInfo.lineOffsetToPosition(args.line, args.offset);
                        const formatOptions = this.getFormatOptions(file);
                        const edits = languageService.getFormattingEditsAfterKeystroke(file, position, args.key, formatOptions);
                        if (args.key === "\n" && (!edits || edits.length === 0 || allEditsBeforePos(edits, position))) {
                            const { lineText, absolutePosition } = scriptInfo.textStorage.getAbsolutePositionAndLineText(args.line);
                            if (lineText && lineText.search("\\S") < 0) {
                                const preferredIndent = languageService.getIndentationAtPosition(file, position, formatOptions);
                                let hasIndent = 0;
                                let i, len;
                                for (i = 0, len = lineText.length; i < len; i++) {
                                    if (lineText.charAt(i) === " ") {
                                        hasIndent++;
                                    }
                                    else if (lineText.charAt(i) === "	") {
                                        hasIndent += formatOptions.tabSize;
                                    }
                                    else {
                                        break;
                                    }
                                }
                                if (preferredIndent !== hasIndent) {
                                    const firstNoWhiteSpacePosition = absolutePosition + i;
                                    edits.push({
                                        span: createTextSpanFromBounds(absolutePosition, firstNoWhiteSpacePosition),
                                        newText: ts_formatting_exports.getIndentationString(preferredIndent, formatOptions)
                                    });
                                }
                            }
                        }
                        if (!edits) {
                            return void 0;
                        }
                        return edits.map((edit) => {
                            return {
                                start: scriptInfo.positionToLineOffset(edit.span.start),
                                end: scriptInfo.positionToLineOffset(textSpanEnd(edit.span)),
                                newText: edit.newText ? edit.newText : ""
                            };
                        });
                    }
                    getCompletions(args, kind) {
                        const { file, project } = this.getFileAndProject(args);
                        const scriptInfo = this.projectService.getScriptInfoForNormalizedPath(file);
                        const position = this.getPosition(args, scriptInfo);
                        const completions = project.getLanguageService().getCompletionsAtPosition(file, position, {
                            ...convertUserPreferences(this.getPreferences(file)),
                            triggerCharacter: args.triggerCharacter,
                            triggerKind: args.triggerKind,
                            includeExternalModuleExports: args.includeExternalModuleExports,
                            includeInsertTextCompletions: args.includeInsertTextCompletions
                        }, project.projectService.getFormatCodeOptions(file));
                        if (completions === void 0)
                            return void 0;
                        if (kind === "completions-full" /* CompletionsFull */)
                            return completions;
                        const prefix = args.prefix || "";
                        const entries = mapDefined(completions.entries, (entry) => {
                            if (completions.isMemberCompletion || startsWith(entry.name.toLowerCase(), prefix.toLowerCase())) {
                                const { name, kind: kind2, kindModifiers, sortText, insertText, filterText, replacementSpan, hasAction, source, sourceDisplay, labelDetails, isSnippet, isRecommended, isPackageJsonImport, isImportStatementCompletion, data } = entry;
                                const convertedSpan = replacementSpan ? toProtocolTextSpan(replacementSpan, scriptInfo) : void 0;
                                return {
                                    name,
                                    kind: kind2,
                                    kindModifiers,
                                    sortText,
                                    insertText,
                                    filterText,
                                    replacementSpan: convertedSpan,
                                    isSnippet,
                                    hasAction: hasAction || void 0,
                                    source,
                                    sourceDisplay,
                                    labelDetails,
                                    isRecommended,
                                    isPackageJsonImport,
                                    isImportStatementCompletion,
                                    data
                                };
                            }
                        });
                        if (kind === "completions" /* Completions */) {
                            if (completions.metadata)
                                entries.metadata = completions.metadata;
                            return entries;
                        }
                        const res = {
                            ...completions,
                            optionalReplacementSpan: completions.optionalReplacementSpan && toProtocolTextSpan(completions.optionalReplacementSpan, scriptInfo),
                            entries
                        };
                        return res;
                    }
                    getCompletionEntryDetails(args, fullResult) {
                        const { file, project } = this.getFileAndProject(args);
                        const scriptInfo = this.projectService.getScriptInfoForNormalizedPath(file);
                        const position = this.getPosition(args, scriptInfo);
                        const formattingOptions = project.projectService.getFormatCodeOptions(file);
                        const useDisplayParts = !!this.getPreferences(file).displayPartsForJSDoc;
                        const result = mapDefined(args.entryNames, (entryName) => {
                            const { name, source, data } = typeof entryName === "string" ? { name: entryName, source: void 0, data: void 0 } : entryName;
                            return project.getLanguageService().getCompletionEntryDetails(file, position, name, formattingOptions, source, this.getPreferences(file), data ? cast(data, isCompletionEntryData) : void 0);
                        });
                        return fullResult ? useDisplayParts ? result : result.map((details) => ({ ...details, tags: this.mapJSDocTagInfo(details.tags, project, 
                            /*richResponse*/
                            false) })) : result.map((details) => ({
                            ...details,
                            codeActions: map(details.codeActions, (action) => this.mapCodeAction(action)),
                            documentation: this.mapDisplayParts(details.documentation, project),
                            tags: this.mapJSDocTagInfo(details.tags, project, useDisplayParts)
                        }));
                    }
                    getCompileOnSaveAffectedFileList(args) {
                        const projects = this.getProjects(args, 
                        /*getScriptInfoEnsuringProjectsUptoDate*/
                        true, 
                        /*ignoreNoProjectError*/
                        true);
                        const info = this.projectService.getScriptInfo(args.file);
                        if (!info) {
                            return emptyArray2;
                        }
                        return combineProjectOutput(info, (path) => this.projectService.getScriptInfoForPath(path), projects, (project, info2) => {
                            if (!project.compileOnSaveEnabled || !project.languageServiceEnabled || project.isOrphan()) {
                                return void 0;
                            }
                            const compilationSettings = project.getCompilationSettings();
                            if (!!compilationSettings.noEmit || isDeclarationFileName(info2.fileName) && !dtsChangeCanAffectEmit(compilationSettings)) {
                                return void 0;
                            }
                            return {
                                projectFileName: project.getProjectName(),
                                fileNames: project.getCompileOnSaveAffectedFileList(info2),
                                projectUsesOutFile: !!outFile(compilationSettings)
                            };
                        });
                    }
                    emitFile(args) {
                        const { file, project } = this.getFileAndProject(args);
                        if (!project) {
                            Errors.ThrowNoProject();
                        }
                        if (!project.languageServiceEnabled) {
                            return args.richResponse ? { emitSkipped: true, diagnostics: [] } : false;
                        }
                        const scriptInfo = project.getScriptInfo(file);
                        const { emitSkipped, diagnostics } = project.emitFile(scriptInfo, (path, data, writeByteOrderMark) => this.host.writeFile(path, data, writeByteOrderMark));
                        return args.richResponse ? {
                            emitSkipped,
                            diagnostics: args.includeLinePosition ? this.convertToDiagnosticsWithLinePositionFromDiagnosticFile(diagnostics) : diagnostics.map((d) => formatDiagnosticToProtocol(d, 
                            /*includeFileName*/
                            true))
                        } : !emitSkipped;
                    }
                    getSignatureHelpItems(args, simplifiedResult) {
                        const { file, project } = this.getFileAndProject(args);
                        const scriptInfo = this.projectService.getScriptInfoForNormalizedPath(file);
                        const position = this.getPosition(args, scriptInfo);
                        const helpItems = project.getLanguageService().getSignatureHelpItems(file, position, args);
                        const useDisplayParts = !!this.getPreferences(file).displayPartsForJSDoc;
                        if (helpItems && simplifiedResult) {
                            const span = helpItems.applicableSpan;
                            return {
                                ...helpItems,
                                applicableSpan: {
                                    start: scriptInfo.positionToLineOffset(span.start),
                                    end: scriptInfo.positionToLineOffset(span.start + span.length)
                                },
                                items: this.mapSignatureHelpItems(helpItems.items, project, useDisplayParts)
                            };
                        }
                        else if (useDisplayParts || !helpItems) {
                            return helpItems;
                        }
                        else {
                            return {
                                ...helpItems,
                                items: helpItems.items.map((item) => ({ ...item, tags: this.mapJSDocTagInfo(item.tags, project, 
                                    /*richResponse*/
                                    false) }))
                            };
                        }
                    }
                    toPendingErrorCheck(uncheckedFileName) {
                        const fileName = toNormalizedPath(uncheckedFileName);
                        const project = this.projectService.tryGetDefaultProjectForFile(fileName);
                        return project && { fileName, project };
                    }
                    getDiagnostics(next, delay, fileNames) {
                        if (this.suppressDiagnosticEvents) {
                            return;
                        }
                        if (fileNames.length > 0) {
                            this.updateErrorCheck(next, fileNames, delay);
                        }
                    }
                    change(args) {
                        const scriptInfo = this.projectService.getScriptInfo(args.file);
                        Debug.assert(!!scriptInfo);
                        scriptInfo.textStorage.switchToScriptVersionCache();
                        const start = scriptInfo.lineOffsetToPosition(args.line, args.offset);
                        const end = scriptInfo.lineOffsetToPosition(args.endLine, args.endOffset);
                        if (start >= 0) {
                            this.changeSeq++;
                            this.projectService.applyChangesToFile(scriptInfo, singleIterator({
                                span: { start, length: end - start },
                                newText: args.insertString
                                // TODO: GH#18217
                            }));
                        }
                    }
                    reload(args, reqSeq) {
                        const file = toNormalizedPath(args.file);
                        const tempFileName = args.tmpfile === void 0 ? void 0 : toNormalizedPath(args.tmpfile);
                        const info = this.projectService.getScriptInfoForNormalizedPath(file);
                        if (info) {
                            this.changeSeq++;
                            if (info.reloadFromFile(tempFileName)) {
                                this.doOutput(
                                /*info*/
                                void 0, "reload" /* Reload */, reqSeq, 
                                /*success*/
                                true);
                            }
                        }
                    }
                    saveToTmp(fileName, tempFileName) {
                        const scriptInfo = this.projectService.getScriptInfo(fileName);
                        if (scriptInfo) {
                            scriptInfo.saveTo(tempFileName);
                        }
                    }
                    closeClientFile(fileName) {
                        if (!fileName) {
                            return;
                        }
                        const file = normalizePath(fileName);
                        this.projectService.closeClientFile(file);
                    }
                    mapLocationNavigationBarItems(items, scriptInfo) {
                        return map(items, (item) => ({
                            text: item.text,
                            kind: item.kind,
                            kindModifiers: item.kindModifiers,
                            spans: item.spans.map((span) => toProtocolTextSpan(span, scriptInfo)),
                            childItems: this.mapLocationNavigationBarItems(item.childItems, scriptInfo),
                            indent: item.indent
                        }));
                    }
                    getNavigationBarItems(args, simplifiedResult) {
                        const { file, languageService } = this.getFileAndLanguageServiceForSyntacticOperation(args);
                        const items = languageService.getNavigationBarItems(file);
                        return !items ? void 0 : simplifiedResult ? this.mapLocationNavigationBarItems(items, this.projectService.getScriptInfoForNormalizedPath(file)) : items;
                    }
                    toLocationNavigationTree(tree, scriptInfo) {
                        return {
                            text: tree.text,
                            kind: tree.kind,
                            kindModifiers: tree.kindModifiers,
                            spans: tree.spans.map((span) => toProtocolTextSpan(span, scriptInfo)),
                            nameSpan: tree.nameSpan && toProtocolTextSpan(tree.nameSpan, scriptInfo),
                            childItems: map(tree.childItems, (item) => this.toLocationNavigationTree(item, scriptInfo))
                        };
                    }
                    getNavigationTree(args, simplifiedResult) {
                        const { file, languageService } = this.getFileAndLanguageServiceForSyntacticOperation(args);
                        const tree = languageService.getNavigationTree(file);
                        return !tree ? void 0 : simplifiedResult ? this.toLocationNavigationTree(tree, this.projectService.getScriptInfoForNormalizedPath(file)) : tree;
                    }
                    getNavigateToItems(args, simplifiedResult) {
                        const full = this.getFullNavigateToItems(args);
                        return !simplifiedResult ? flatMap(full, ({ navigateToItems }) => navigateToItems) : flatMap(full, ({ project, navigateToItems }) => navigateToItems.map((navItem) => {
                            const scriptInfo = project.getScriptInfo(navItem.fileName);
                            const bakedItem = {
                                name: navItem.name,
                                kind: navItem.kind,
                                kindModifiers: navItem.kindModifiers,
                                isCaseSensitive: navItem.isCaseSensitive,
                                matchKind: navItem.matchKind,
                                file: navItem.fileName,
                                start: scriptInfo.positionToLineOffset(navItem.textSpan.start),
                                end: scriptInfo.positionToLineOffset(textSpanEnd(navItem.textSpan))
                            };
                            if (navItem.kindModifiers && navItem.kindModifiers !== "") {
                                bakedItem.kindModifiers = navItem.kindModifiers;
                            }
                            if (navItem.containerName && navItem.containerName.length > 0) {
                                bakedItem.containerName = navItem.containerName;
                            }
                            if (navItem.containerKind && navItem.containerKind.length > 0) {
                                bakedItem.containerKind = navItem.containerKind;
                            }
                            return bakedItem;
                        }));
                    }
                    getFullNavigateToItems(args) {
                        const { currentFileOnly, searchValue, maxResultCount, projectFileName } = args;
                        if (currentFileOnly) {
                            Debug.assertIsDefined(args.file);
                            const { file, project } = this.getFileAndProject(args);
                            return [{ project, navigateToItems: project.getLanguageService().getNavigateToItems(searchValue, maxResultCount, file) }];
                        }
                        const preferences = this.getHostPreferences();
                        const outputs = [];
                        const seenItems = /* @__PURE__ */ new Map();
                        if (!args.file && !projectFileName) {
                            this.projectService.loadAncestorProjectTree();
                            this.projectService.forEachEnabledProject((project) => addItemsForProject(project));
                        }
                        else {
                            const projects = this.getProjects(args);
                            forEachProjectInProjects(projects, 
                            /*path*/
                            void 0, (project) => addItemsForProject(project));
                        }
                        return outputs;
                        function addItemsForProject(project) {
                            const projectItems = project.getLanguageService().getNavigateToItems(searchValue, maxResultCount, 
                            /*fileName*/
                            void 0, 
                            /*excludeDts*/
                            project.isNonTsProject(), 
                            /*excludeLibFiles*/
                            preferences.excludeLibrarySymbolsInNavTo);
                            const unseenItems = filter(projectItems, (item) => tryAddSeenItem(item) && !getMappedLocationForProject(documentSpanLocation(item), project));
                            if (unseenItems.length) {
                                outputs.push({ project, navigateToItems: unseenItems });
                            }
                        }
                        function tryAddSeenItem(item) {
                            const name = item.name;
                            if (!seenItems.has(name)) {
                                seenItems.set(name, [item]);
                                return true;
                            }
                            const seen = seenItems.get(name);
                            for (const seenItem of seen) {
                                if (navigateToItemIsEqualTo(seenItem, item)) {
                                    return false;
                                }
                            }
                            seen.push(item);
                            return true;
                        }
                        function navigateToItemIsEqualTo(a, b) {
                            if (a === b) {
                                return true;
                            }
                            if (!a || !b) {
                                return false;
                            }
                            return a.containerKind === b.containerKind && a.containerName === b.containerName && a.fileName === b.fileName && a.isCaseSensitive === b.isCaseSensitive && a.kind === b.kind && a.kindModifiers === b.kindModifiers && a.matchKind === b.matchKind && a.name === b.name && a.textSpan.start === b.textSpan.start && a.textSpan.length === b.textSpan.length;
                        }
                    }
                    getSupportedCodeFixes(args) {
                        if (!args)
                            return getSupportedCodeFixes();
                        if (args.file) {
                            const { file, project: project2 } = this.getFileAndProject(args);
                            return project2.getLanguageService().getSupportedCodeFixes(file);
                        }
                        const project = this.getProject(args.projectFileName);
                        if (!project)
                            Errors.ThrowNoProject();
                        return project.getLanguageService().getSupportedCodeFixes();
                    }
                    isLocation(locationOrSpan) {
                        return locationOrSpan.line !== void 0;
                    }
                    extractPositionOrRange(args, scriptInfo) {
                        let position;
                        let textRange;
                        if (this.isLocation(args)) {
                            position = getPosition(args);
                        }
                        else {
                            textRange = this.getRange(args, scriptInfo);
                        }
                        return Debug.checkDefined(position === void 0 ? textRange : position);
                        function getPosition(loc) {
                            return loc.position !== void 0 ? loc.position : scriptInfo.lineOffsetToPosition(loc.line, loc.offset);
                        }
                    }
                    getRange(args, scriptInfo) {
                        const { startPosition, endPosition } = this.getStartAndEndPosition(args, scriptInfo);
                        return { pos: startPosition, end: endPosition };
                    }
                    getApplicableRefactors(args) {
                        const { file, project } = this.getFileAndProject(args);
                        const scriptInfo = project.getScriptInfoForNormalizedPath(file);
                        return project.getLanguageService().getApplicableRefactors(file, this.extractPositionOrRange(args, scriptInfo), this.getPreferences(file), args.triggerReason, args.kind, args.includeInteractiveActions);
                    }
                    getEditsForRefactor(args, simplifiedResult) {
                        const { file, project } = this.getFileAndProject(args);
                        const scriptInfo = project.getScriptInfoForNormalizedPath(file);
                        const result = project.getLanguageService().getEditsForRefactor(file, this.getFormatOptions(file), this.extractPositionOrRange(args, scriptInfo), args.refactor, args.action, this.getPreferences(file), args.interactiveRefactorArguments);
                        if (result === void 0) {
                            return {
                                edits: []
                            };
                        }
                        if (simplifiedResult) {
                            const { renameFilename, renameLocation, edits } = result;
                            let mappedRenameLocation;
                            if (renameFilename !== void 0 && renameLocation !== void 0) {
                                const renameScriptInfo = project.getScriptInfoForNormalizedPath(toNormalizedPath(renameFilename));
                                mappedRenameLocation = getLocationInNewDocument(getSnapshotText(renameScriptInfo.getSnapshot()), renameFilename, renameLocation, edits);
                            }
                            return {
                                renameLocation: mappedRenameLocation,
                                renameFilename,
                                edits: this.mapTextChangesToCodeEdits(edits),
                                notApplicableReason: result.notApplicableReason
                            };
                        }
                        return result;
                    }
                    getMoveToRefactoringFileSuggestions(args) {
                        const { file, project } = this.getFileAndProject(args);
                        const scriptInfo = project.getScriptInfoForNormalizedPath(file);
                        return project.getLanguageService().getMoveToRefactoringFileSuggestions(file, this.extractPositionOrRange(args, scriptInfo), this.getPreferences(file));
                    }
                    organizeImports(args, simplifiedResult) {
                        Debug.assert(args.scope.type === "file");
                        const { file, project } = this.getFileAndProject(args.scope.args);
                        const changes = project.getLanguageService().organizeImports({
                            fileName: file,
                            mode: args.mode ?? (args.skipDestructiveCodeActions ? "SortAndCombine" /* SortAndCombine */ : void 0),
                            type: "file"
                        }, this.getFormatOptions(file), this.getPreferences(file));
                        if (simplifiedResult) {
                            return this.mapTextChangesToCodeEdits(changes);
                        }
                        else {
                            return changes;
                        }
                    }
                    getEditsForFileRename(args, simplifiedResult) {
                        const oldPath = toNormalizedPath(args.oldFilePath);
                        const newPath = toNormalizedPath(args.newFilePath);
                        const formatOptions = this.getHostFormatOptions();
                        const preferences = this.getHostPreferences();
                        const seenFiles = /* @__PURE__ */ new Set();
                        const textChanges2 = [];
                        this.projectService.loadAncestorProjectTree();
                        this.projectService.forEachEnabledProject((project) => {
                            const projectTextChanges = project.getLanguageService().getEditsForFileRename(oldPath, newPath, formatOptions, preferences);
                            const projectFiles = [];
                            for (const textChange of projectTextChanges) {
                                if (!seenFiles.has(textChange.fileName)) {
                                    textChanges2.push(textChange);
                                    projectFiles.push(textChange.fileName);
                                }
                            }
                            for (const file of projectFiles) {
                                seenFiles.add(file);
                            }
                        });
                        return simplifiedResult ? textChanges2.map((c) => this.mapTextChangeToCodeEdit(c)) : textChanges2;
                    }
                    getCodeFixes(args, simplifiedResult) {
                        const { file, project } = this.getFileAndProject(args);
                        const scriptInfo = project.getScriptInfoForNormalizedPath(file);
                        const { startPosition, endPosition } = this.getStartAndEndPosition(args, scriptInfo);
                        let codeActions;
                        try {
                            codeActions = project.getLanguageService().getCodeFixesAtPosition(file, startPosition, endPosition, args.errorCodes, this.getFormatOptions(file), this.getPreferences(file));
                        }
                        catch (e) {
                            const ls = project.getLanguageService();
                            const existingDiagCodes = [
                                ...ls.getSyntacticDiagnostics(file),
                                ...ls.getSemanticDiagnostics(file),
                                ...ls.getSuggestionDiagnostics(file)
                            ].map((d) => decodedTextSpanIntersectsWith(startPosition, endPosition - startPosition, d.start, d.length) && d.code);
                            const badCode = args.errorCodes.find((c) => !existingDiagCodes.includes(c));
                            if (badCode !== void 0) {
                                e.message = `BADCLIENT: Bad error code, ${badCode} not found in range ${startPosition}..${endPosition} (found: ${existingDiagCodes.join(", ")}); could have caused this error:
${e.message}`;
                            }
                            throw e;
                        }
                        return simplifiedResult ? codeActions.map((codeAction) => this.mapCodeFixAction(codeAction)) : codeActions;
                    }
                    getCombinedCodeFix({ scope, fixId: fixId52 }, simplifiedResult) {
                        Debug.assert(scope.type === "file");
                        const { file, project } = this.getFileAndProject(scope.args);
                        const res = project.getLanguageService().getCombinedCodeFix({ type: "file", fileName: file }, fixId52, this.getFormatOptions(file), this.getPreferences(file));
                        if (simplifiedResult) {
                            return { changes: this.mapTextChangesToCodeEdits(res.changes), commands: res.commands };
                        }
                        else {
                            return res;
                        }
                    }
                    applyCodeActionCommand(args) {
                        const commands = args.command;
                        for (const command of toArray(commands)) {
                            const { file, project } = this.getFileAndProject(command);
                            project.getLanguageService().applyCodeActionCommand(command, this.getFormatOptions(file)).then((_result) => {
                            }, (_error) => {
                            });
                        }
                        return {};
                    }
                    getStartAndEndPosition(args, scriptInfo) {
                        let startPosition, endPosition;
                        if (args.startPosition !== void 0) {
                            startPosition = args.startPosition;
                        }
                        else {
                            startPosition = scriptInfo.lineOffsetToPosition(args.startLine, args.startOffset);
                            args.startPosition = startPosition;
                        }
                        if (args.endPosition !== void 0) {
                            endPosition = args.endPosition;
                        }
                        else {
                            endPosition = scriptInfo.lineOffsetToPosition(args.endLine, args.endOffset);
                            args.endPosition = endPosition;
                        }
                        return { startPosition, endPosition };
                    }
                    mapCodeAction({ description: description3, changes, commands }) {
                        return { description: description3, changes: this.mapTextChangesToCodeEdits(changes), commands };
                    }
                    mapCodeFixAction({ fixName: fixName8, description: description3, changes, commands, fixId: fixId52, fixAllDescription }) {
                        return { fixName: fixName8, description: description3, changes: this.mapTextChangesToCodeEdits(changes), commands, fixId: fixId52, fixAllDescription };
                    }
                    mapTextChangesToCodeEdits(textChanges2) {
                        return textChanges2.map((change) => this.mapTextChangeToCodeEdit(change));
                    }
                    mapTextChangeToCodeEdit(textChanges2) {
                        const scriptInfo = this.projectService.getScriptInfoOrConfig(textChanges2.fileName);
                        if (!!textChanges2.isNewFile === !!scriptInfo) {
                            if (!scriptInfo) {
                                this.projectService.logErrorForScriptInfoNotFound(textChanges2.fileName);
                            }
                            Debug.fail("Expected isNewFile for (only) new files. " + JSON.stringify({ isNewFile: !!textChanges2.isNewFile, hasScriptInfo: !!scriptInfo }));
                        }
                        return scriptInfo ? { fileName: textChanges2.fileName, textChanges: textChanges2.textChanges.map((textChange) => convertTextChangeToCodeEdit(textChange, scriptInfo)) } : convertNewFileTextChangeToCodeEdit(textChanges2);
                    }
                    convertTextChangeToCodeEdit(change, scriptInfo) {
                        return {
                            start: scriptInfo.positionToLineOffset(change.span.start),
                            end: scriptInfo.positionToLineOffset(change.span.start + change.span.length),
                            newText: change.newText ? change.newText : ""
                        };
                    }
                    getBraceMatching(args, simplifiedResult) {
                        const { file, languageService } = this.getFileAndLanguageServiceForSyntacticOperation(args);
                        const scriptInfo = this.projectService.getScriptInfoForNormalizedPath(file);
                        const position = this.getPosition(args, scriptInfo);
                        const spans = languageService.getBraceMatchingAtPosition(file, position);
                        return !spans ? void 0 : simplifiedResult ? spans.map((span) => toProtocolTextSpan(span, scriptInfo)) : spans;
                    }
                    getDiagnosticsForProject(next, delay, fileName) {
                        if (this.suppressDiagnosticEvents) {
                            return;
                        }
                        const { fileNames, languageServiceDisabled } = this.getProjectInfoWorker(fileName, 
                        /*projectFileName*/
                        void 0, 
                        /*needFileNameList*/
                        true, 
                        /*excludeConfigFiles*/
                        true);
                        if (languageServiceDisabled) {
                            return;
                        }
                        const fileNamesInProject = fileNames.filter((value) => !value.includes("lib.d.ts"));
                        if (fileNamesInProject.length === 0) {
                            return;
                        }
                        const highPriorityFiles = [];
                        const mediumPriorityFiles = [];
                        const lowPriorityFiles = [];
                        const veryLowPriorityFiles = [];
                        const normalizedFileName = toNormalizedPath(fileName);
                        const project = this.projectService.ensureDefaultProjectForFile(normalizedFileName);
                        for (const fileNameInProject of fileNamesInProject) {
                            if (this.getCanonicalFileName(fileNameInProject) === this.getCanonicalFileName(fileName)) {
                                highPriorityFiles.push(fileNameInProject);
                            }
                            else {
                                const info = this.projectService.getScriptInfo(fileNameInProject);
                                if (!info.isScriptOpen()) {
                                    if (isDeclarationFileName(fileNameInProject)) {
                                        veryLowPriorityFiles.push(fileNameInProject);
                                    }
                                    else {
                                        lowPriorityFiles.push(fileNameInProject);
                                    }
                                }
                                else {
                                    mediumPriorityFiles.push(fileNameInProject);
                                }
                            }
                        }
                        const sortedFiles = [...highPriorityFiles, ...mediumPriorityFiles, ...lowPriorityFiles, ...veryLowPriorityFiles];
                        const checkList = sortedFiles.map((fileName2) => ({ fileName: fileName2, project }));
                        this.updateErrorCheck(next, checkList, delay, 
                        /*requireOpen*/
                        false);
                    }
                    configurePlugin(args) {
                        this.projectService.configurePlugin(args);
                    }
                    getSmartSelectionRange(args, simplifiedResult) {
                        const { locations } = args;
                        const { file, languageService } = this.getFileAndLanguageServiceForSyntacticOperation(args);
                        const scriptInfo = Debug.checkDefined(this.projectService.getScriptInfo(file));
                        return map(locations, (location) => {
                            const pos = this.getPosition(location, scriptInfo);
                            const selectionRange = languageService.getSmartSelectionRange(file, pos);
                            return simplifiedResult ? this.mapSelectionRange(selectionRange, scriptInfo) : selectionRange;
                        });
                    }
                    toggleLineComment(args, simplifiedResult) {
                        const { file, languageService } = this.getFileAndLanguageServiceForSyntacticOperation(args);
                        const scriptInfo = this.projectService.getScriptInfo(file);
                        const textRange = this.getRange(args, scriptInfo);
                        const textChanges2 = languageService.toggleLineComment(file, textRange);
                        if (simplifiedResult) {
                            const scriptInfo2 = this.projectService.getScriptInfoForNormalizedPath(file);
                            return textChanges2.map((textChange) => this.convertTextChangeToCodeEdit(textChange, scriptInfo2));
                        }
                        return textChanges2;
                    }
                    toggleMultilineComment(args, simplifiedResult) {
                        const { file, languageService } = this.getFileAndLanguageServiceForSyntacticOperation(args);
                        const scriptInfo = this.projectService.getScriptInfoForNormalizedPath(file);
                        const textRange = this.getRange(args, scriptInfo);
                        const textChanges2 = languageService.toggleMultilineComment(file, textRange);
                        if (simplifiedResult) {
                            const scriptInfo2 = this.projectService.getScriptInfoForNormalizedPath(file);
                            return textChanges2.map((textChange) => this.convertTextChangeToCodeEdit(textChange, scriptInfo2));
                        }
                        return textChanges2;
                    }
                    commentSelection(args, simplifiedResult) {
                        const { file, languageService } = this.getFileAndLanguageServiceForSyntacticOperation(args);
                        const scriptInfo = this.projectService.getScriptInfoForNormalizedPath(file);
                        const textRange = this.getRange(args, scriptInfo);
                        const textChanges2 = languageService.commentSelection(file, textRange);
                        if (simplifiedResult) {
                            const scriptInfo2 = this.projectService.getScriptInfoForNormalizedPath(file);
                            return textChanges2.map((textChange) => this.convertTextChangeToCodeEdit(textChange, scriptInfo2));
                        }
                        return textChanges2;
                    }
                    uncommentSelection(args, simplifiedResult) {
                        const { file, languageService } = this.getFileAndLanguageServiceForSyntacticOperation(args);
                        const scriptInfo = this.projectService.getScriptInfoForNormalizedPath(file);
                        const textRange = this.getRange(args, scriptInfo);
                        const textChanges2 = languageService.uncommentSelection(file, textRange);
                        if (simplifiedResult) {
                            const scriptInfo2 = this.projectService.getScriptInfoForNormalizedPath(file);
                            return textChanges2.map((textChange) => this.convertTextChangeToCodeEdit(textChange, scriptInfo2));
                        }
                        return textChanges2;
                    }
                    mapSelectionRange(selectionRange, scriptInfo) {
                        const result = {
                            textSpan: toProtocolTextSpan(selectionRange.textSpan, scriptInfo)
                        };
                        if (selectionRange.parent) {
                            result.parent = this.mapSelectionRange(selectionRange.parent, scriptInfo);
                        }
                        return result;
                    }
                    getScriptInfoFromProjectService(file) {
                        const normalizedFile = toNormalizedPath(file);
                        const scriptInfo = this.projectService.getScriptInfoForNormalizedPath(normalizedFile);
                        if (!scriptInfo) {
                            this.projectService.logErrorForScriptInfoNotFound(normalizedFile);
                            return Errors.ThrowNoProject();
                        }
                        return scriptInfo;
                    }
                    toProtocolCallHierarchyItem(item) {
                        const scriptInfo = this.getScriptInfoFromProjectService(item.file);
                        return {
                            name: item.name,
                            kind: item.kind,
                            kindModifiers: item.kindModifiers,
                            file: item.file,
                            containerName: item.containerName,
                            span: toProtocolTextSpan(item.span, scriptInfo),
                            selectionSpan: toProtocolTextSpan(item.selectionSpan, scriptInfo)
                        };
                    }
                    toProtocolCallHierarchyIncomingCall(incomingCall) {
                        const scriptInfo = this.getScriptInfoFromProjectService(incomingCall.from.file);
                        return {
                            from: this.toProtocolCallHierarchyItem(incomingCall.from),
                            fromSpans: incomingCall.fromSpans.map((fromSpan) => toProtocolTextSpan(fromSpan, scriptInfo))
                        };
                    }
                    toProtocolCallHierarchyOutgoingCall(outgoingCall, scriptInfo) {
                        return {
                            to: this.toProtocolCallHierarchyItem(outgoingCall.to),
                            fromSpans: outgoingCall.fromSpans.map((fromSpan) => toProtocolTextSpan(fromSpan, scriptInfo))
                        };
                    }
                    prepareCallHierarchy(args) {
                        const { file, project } = this.getFileAndProject(args);
                        const scriptInfo = this.projectService.getScriptInfoForNormalizedPath(file);
                        if (scriptInfo) {
                            const position = this.getPosition(args, scriptInfo);
                            const result = project.getLanguageService().prepareCallHierarchy(file, position);
                            return result && mapOneOrMany(result, (item) => this.toProtocolCallHierarchyItem(item));
                        }
                        return void 0;
                    }
                    provideCallHierarchyIncomingCalls(args) {
                        const { file, project } = this.getFileAndProject(args);
                        const scriptInfo = this.getScriptInfoFromProjectService(file);
                        const incomingCalls = project.getLanguageService().provideCallHierarchyIncomingCalls(file, this.getPosition(args, scriptInfo));
                        return incomingCalls.map((call) => this.toProtocolCallHierarchyIncomingCall(call));
                    }
                    provideCallHierarchyOutgoingCalls(args) {
                        const { file, project } = this.getFileAndProject(args);
                        const scriptInfo = this.getScriptInfoFromProjectService(file);
                        const outgoingCalls = project.getLanguageService().provideCallHierarchyOutgoingCalls(file, this.getPosition(args, scriptInfo));
                        return outgoingCalls.map((call) => this.toProtocolCallHierarchyOutgoingCall(call, scriptInfo));
                    }
                    getCanonicalFileName(fileName) {
                        const name = this.host.useCaseSensitiveFileNames ? fileName : toFileNameLowerCase(fileName);
                        return normalizePath(name);
                    }
                    exit() {
                    }
                    notRequired() {
                        return { responseRequired: false };
                    }
                    requiredResponse(response) {
                        return { response, responseRequired: true };
                    }
                    addProtocolHandler(command, handler) {
                        if (this.handlers.has(command)) {
                            throw new Error(`Protocol handler already exists for command "${command}"`);
                        }
                        this.handlers.set(command, handler);
                    }
                    setCurrentRequest(requestId) {
                        Debug.assert(this.currentRequestId === void 0);
                        this.currentRequestId = requestId;
                        this.cancellationToken.setRequest(requestId);
                    }
                    resetCurrentRequest(requestId) {
                        Debug.assert(this.currentRequestId === requestId);
                        this.currentRequestId = void 0;
                        this.cancellationToken.resetRequest(requestId);
                    }
                    executeWithRequestId(requestId, f) {
                        try {
                            this.setCurrentRequest(requestId);
                            return f();
                        }
                        finally {
                            this.resetCurrentRequest(requestId);
                        }
                    }
                    executeCommand(request) {
                        const handler = this.handlers.get(request.command);
                        if (handler) {
                            const response = this.executeWithRequestId(request.seq, () => handler(request));
                            this.projectService.enableRequestedPlugins();
                            return response;
                        }
                        else {
                            this.logger.msg(`Unrecognized JSON command:${stringifyIndented(request)}`, "Err" /* Err */);
                            this.doOutput(
                            /*info*/
                            void 0, "unknown" /* Unknown */, request.seq, 
                            /*success*/
                            false, `Unrecognized JSON command: ${request.command}`);
                            return { responseRequired: false };
                        }
                    }
                    onMessage(message) {
                        var _a, _b, _c, _d, _e, _f, _g, _h, _i, _j, _k;
                        this.gcTimer.scheduleCollect();
                        this.performanceData = void 0;
                        let start;
                        if (this.logger.hasLevel(2 /* requestTime */)) {
                            start = this.hrtime();
                            if (this.logger.hasLevel(3 /* verbose */)) {
                                this.logger.info(`request:${indent2(this.toStringMessage(message))}`);
                            }
                        }
                        let request;
                        let relevantFile;
                        try {
                            request = this.parseMessage(message);
                            relevantFile = request.arguments && request.arguments.file ? request.arguments : void 0;
                            (_a = tracing) == null ? void 0 : _a.instant(tracing.Phase.Session, "request", { seq: request.seq, command: request.command });
                            (_b = perfLogger) == null ? void 0 : _b.logStartCommand("" + request.command, this.toStringMessage(message).substring(0, 100));
                            (_c = tracing) == null ? void 0 : _c.push(tracing.Phase.Session, "executeCommand", { seq: request.seq, command: request.command }, 
                            /*separateBeginAndEnd*/
                            true);
                            const { response, responseRequired } = this.executeCommand(request);
                            (_d = tracing) == null ? void 0 : _d.pop();
                            if (this.logger.hasLevel(2 /* requestTime */)) {
                                const elapsedTime = hrTimeToMilliseconds(this.hrtime(start)).toFixed(4);
                                if (responseRequired) {
                                    this.logger.perftrc(`${request.seq}::${request.command}: elapsed time (in milliseconds) ${elapsedTime}`);
                                }
                                else {
                                    this.logger.perftrc(`${request.seq}::${request.command}: async elapsed time (in milliseconds) ${elapsedTime}`);
                                }
                            }
                            (_e = perfLogger) == null ? void 0 : _e.logStopCommand("" + request.command, "Success");
                            (_f = tracing) == null ? void 0 : _f.instant(tracing.Phase.Session, "response", { seq: request.seq, command: request.command, success: !!response });
                            if (response) {
                                this.doOutput(response, request.command, request.seq, 
                                /*success*/
                                true);
                            }
                            else if (responseRequired) {
                                this.doOutput(
                                /*info*/
                                void 0, request.command, request.seq, 
                                /*success*/
                                false, "No content available.");
                            }
                        }
                        catch (err) {
                            (_g = tracing) == null ? void 0 : _g.popAll();
                            if (err instanceof OperationCanceledException) {
                                (_h = perfLogger) == null ? void 0 : _h.logStopCommand("" + (request && request.command), "Canceled: " + err);
                                (_i = tracing) == null ? void 0 : _i.instant(tracing.Phase.Session, "commandCanceled", { seq: request == null ? void 0 : request.seq, command: request == null ? void 0 : request.command });
                                this.doOutput({ canceled: true }, request.command, request.seq, 
                                /*success*/
                                true);
                                return;
                            }
                            this.logErrorWorker(err, this.toStringMessage(message), relevantFile);
                            (_j = perfLogger) == null ? void 0 : _j.logStopCommand("" + (request && request.command), "Error: " + err);
                            (_k = tracing) == null ? void 0 : _k.instant(tracing.Phase.Session, "commandError", { seq: request == null ? void 0 : request.seq, command: request == null ? void 0 : request.command, message: err.message });
                            this.doOutput(
                            /*info*/
                            void 0, request ? request.command : "unknown" /* Unknown */, request ? request.seq : 0, 
                            /*success*/
                            false, "Error processing request. " + err.message + "\n" + err.stack);
                        }
                    }
                    parseMessage(message) {
                        return JSON.parse(message);
                    }
                    toStringMessage(message) {
                        return message;
                    }
                    getFormatOptions(file) {
                        return this.projectService.getFormatCodeOptions(file);
                    }
                    getPreferences(file) {
                        return this.projectService.getPreferences(file);
                    }
                    getHostFormatOptions() {
                        return this.projectService.getHostFormatCodeOptions();
                    }
                    getHostPreferences() {
                        return this.projectService.getHostPreferences();
                    }
                };
            }
        });
        // src/server/scriptVersionCache.ts
        var lineCollectionCapacity, CharRangeSection, EditWalker, TextChange9, _ScriptVersionCache, ScriptVersionCache, LineIndexSnapshot, LineIndex, LineNode, LineLeaf;
        var init_scriptVersionCache = __esm({
            "src/server/scriptVersionCache.ts"() {
                "use strict";
                init_ts7();
                init_ts_server3();
                lineCollectionCapacity = 4;
                CharRangeSection = /* @__PURE__ */ ((CharRangeSection2) => {
                    CharRangeSection2[CharRangeSection2["PreStart"] = 0] = "PreStart";
                    CharRangeSection2[CharRangeSection2["Start"] = 1] = "Start";
                    CharRangeSection2[CharRangeSection2["Entire"] = 2] = "Entire";
                    CharRangeSection2[CharRangeSection2["Mid"] = 3] = "Mid";
                    CharRangeSection2[CharRangeSection2["End"] = 4] = "End";
                    CharRangeSection2[CharRangeSection2["PostEnd"] = 5] = "PostEnd";
                    return CharRangeSection2;
                })(CharRangeSection || {});
                EditWalker = class {
                    constructor() {
                        this.goSubtree = true;
                        this.lineIndex = new LineIndex();
                        this.endBranch = [];
                        this.state = 2 /* Entire */;
                        this.initialText = "";
                        this.trailingText = "";
                        this.lineIndex.root = new LineNode();
                        this.startPath = [this.lineIndex.root];
                        this.stack = [this.lineIndex.root];
                    }
                    get done() {
                        return false;
                    }
                    insertLines(insertedText, suppressTrailingText) {
                        if (suppressTrailingText) {
                            this.trailingText = "";
                        }
                        if (insertedText) {
                            insertedText = this.initialText + insertedText + this.trailingText;
                        }
                        else {
                            insertedText = this.initialText + this.trailingText;
                        }
                        const lm = LineIndex.linesFromText(insertedText);
                        const lines = lm.lines;
                        if (lines.length > 1 && lines[lines.length - 1] === "") {
                            lines.pop();
                        }
                        let branchParent;
                        let lastZeroCount;
                        for (let k = this.endBranch.length - 1; k >= 0; k--) {
                            this.endBranch[k].updateCounts();
                            if (this.endBranch[k].charCount() === 0) {
                                lastZeroCount = this.endBranch[k];
                                if (k > 0) {
                                    branchParent = this.endBranch[k - 1];
                                }
                                else {
                                    branchParent = this.branchNode;
                                }
                            }
                        }
                        if (lastZeroCount) {
                            branchParent.remove(lastZeroCount);
                        }
                        const leafNode = this.startPath[this.startPath.length - 1];
                        if (lines.length > 0) {
                            leafNode.text = lines[0];
                            if (lines.length > 1) {
                                let insertedNodes = new Array(lines.length - 1);
                                let startNode2 = leafNode;
                                for (let i = 1; i < lines.length; i++) {
                                    insertedNodes[i - 1] = new LineLeaf(lines[i]);
                                }
                                let pathIndex = this.startPath.length - 2;
                                while (pathIndex >= 0) {
                                    const insertionNode = this.startPath[pathIndex];
                                    insertedNodes = insertionNode.insertAt(startNode2, insertedNodes);
                                    pathIndex--;
                                    startNode2 = insertionNode;
                                }
                                let insertedNodesLen = insertedNodes.length;
                                while (insertedNodesLen > 0) {
                                    const newRoot = new LineNode();
                                    newRoot.add(this.lineIndex.root);
                                    insertedNodes = newRoot.insertAt(this.lineIndex.root, insertedNodes);
                                    insertedNodesLen = insertedNodes.length;
                                    this.lineIndex.root = newRoot;
                                }
                                this.lineIndex.root.updateCounts();
                            }
                            else {
                                for (let j = this.startPath.length - 2; j >= 0; j--) {
                                    this.startPath[j].updateCounts();
                                }
                            }
                        }
                        else {
                            const insertionNode = this.startPath[this.startPath.length - 2];
                            insertionNode.remove(leafNode);
                            for (let j = this.startPath.length - 2; j >= 0; j--) {
                                this.startPath[j].updateCounts();
                            }
                        }
                        return this.lineIndex;
                    }
                    post(_relativeStart, _relativeLength, lineCollection) {
                        if (lineCollection === this.lineCollectionAtBranch) {
                            this.state = 4 /* End */;
                        }
                        this.stack.pop();
                    }
                    pre(_relativeStart, _relativeLength, lineCollection, _parent, nodeType) {
                        const currentNode = this.stack[this.stack.length - 1];
                        if (this.state === 2 /* Entire */ && nodeType === 1 /* Start */) {
                            this.state = 1 /* Start */;
                            this.branchNode = currentNode;
                            this.lineCollectionAtBranch = lineCollection;
                        }
                        let child;
                        function fresh(node) {
                            if (node.isLeaf()) {
                                return new LineLeaf("");
                            }
                            else
                                return new LineNode();
                        }
                        switch (nodeType) {
                            case 0 /* PreStart */:
                                this.goSubtree = false;
                                if (this.state !== 4 /* End */) {
                                    currentNode.add(lineCollection);
                                }
                                break;
                            case 1 /* Start */:
                                if (this.state === 4 /* End */) {
                                    this.goSubtree = false;
                                }
                                else {
                                    child = fresh(lineCollection);
                                    currentNode.add(child);
                                    this.startPath.push(child);
                                }
                                break;
                            case 2 /* Entire */:
                                if (this.state !== 4 /* End */) {
                                    child = fresh(lineCollection);
                                    currentNode.add(child);
                                    this.startPath.push(child);
                                }
                                else {
                                    if (!lineCollection.isLeaf()) {
                                        child = fresh(lineCollection);
                                        currentNode.add(child);
                                        this.endBranch.push(child);
                                    }
                                }
                                break;
                            case 3 /* Mid */:
                                this.goSubtree = false;
                                break;
                            case 4 /* End */:
                                if (this.state !== 4 /* End */) {
                                    this.goSubtree = false;
                                }
                                else {
                                    if (!lineCollection.isLeaf()) {
                                        child = fresh(lineCollection);
                                        currentNode.add(child);
                                        this.endBranch.push(child);
                                    }
                                }
                                break;
                            case 5 /* PostEnd */:
                                this.goSubtree = false;
                                if (this.state !== 1 /* Start */) {
                                    currentNode.add(lineCollection);
                                }
                                break;
                        }
                        if (this.goSubtree) {
                            this.stack.push(child);
                        }
                    }
                    // just gather text from the leaves
                    leaf(relativeStart, relativeLength, ll) {
                        if (this.state === 1 /* Start */) {
                            this.initialText = ll.text.substring(0, relativeStart);
                        }
                        else if (this.state === 2 /* Entire */) {
                            this.initialText = ll.text.substring(0, relativeStart);
                            this.trailingText = ll.text.substring(relativeStart + relativeLength);
                        }
                        else {
                            this.trailingText = ll.text.substring(relativeStart + relativeLength);
                        }
                    }
                };
                TextChange9 = class {
                    constructor(pos, deleteLen, insertedText) {
                        this.pos = pos;
                        this.deleteLen = deleteLen;
                        this.insertedText = insertedText;
                    }
                    getTextChangeRange() {
                        return createTextChangeRange(createTextSpan(this.pos, this.deleteLen), this.insertedText ? this.insertedText.length : 0);
                    }
                };
                _ScriptVersionCache = class _ScriptVersionCache {
                    constructor() {
                        this.changes = [];
                        this.versions = new Array(_ScriptVersionCache.maxVersions);
                        this.minVersion = 0;
                        // no versions earlier than min version will maintain change history
                        this.currentVersion = 0;
                    }
                    versionToIndex(version2) {
                        if (version2 < this.minVersion || version2 > this.currentVersion) {
                            return void 0;
                        }
                        return version2 % _ScriptVersionCache.maxVersions;
                    }
                    currentVersionToIndex() {
                        return this.currentVersion % _ScriptVersionCache.maxVersions;
                    }
                    // REVIEW: can optimize by coalescing simple edits
                    edit(pos, deleteLen, insertedText) {
                        this.changes.push(new TextChange9(pos, deleteLen, insertedText));
                        if (this.changes.length > _ScriptVersionCache.changeNumberThreshold || deleteLen > _ScriptVersionCache.changeLengthThreshold || insertedText && insertedText.length > _ScriptVersionCache.changeLengthThreshold) {
                            this.getSnapshot();
                        }
                    }
                    getSnapshot() {
                        return this._getSnapshot();
                    }
                    _getSnapshot() {
                        let snap = this.versions[this.currentVersionToIndex()];
                        if (this.changes.length > 0) {
                            let snapIndex = snap.index;
                            for (const change of this.changes) {
                                snapIndex = snapIndex.edit(change.pos, change.deleteLen, change.insertedText);
                            }
                            snap = new LineIndexSnapshot(this.currentVersion + 1, this, snapIndex, this.changes);
                            this.currentVersion = snap.version;
                            this.versions[this.currentVersionToIndex()] = snap;
                            this.changes = [];
                            if (this.currentVersion - this.minVersion >= _ScriptVersionCache.maxVersions) {
                                this.minVersion = this.currentVersion - _ScriptVersionCache.maxVersions + 1;
                            }
                        }
                        return snap;
                    }
                    getSnapshotVersion() {
                        return this._getSnapshot().version;
                    }
                    getAbsolutePositionAndLineText(oneBasedLine) {
                        return this._getSnapshot().index.lineNumberToInfo(oneBasedLine);
                    }
                    lineOffsetToPosition(line, column) {
                        return this._getSnapshot().index.absolutePositionOfStartOfLine(line) + (column - 1);
                    }
                    positionToLineOffset(position) {
                        return this._getSnapshot().index.positionToLineOffset(position);
                    }
                    lineToTextSpan(line) {
                        const index = this._getSnapshot().index;
                        const { lineText, absolutePosition } = index.lineNumberToInfo(line + 1);
                        const len = lineText !== void 0 ? lineText.length : index.absolutePositionOfStartOfLine(line + 2) - absolutePosition;
                        return createTextSpan(absolutePosition, len);
                    }
                    getTextChangesBetweenVersions(oldVersion, newVersion) {
                        if (oldVersion < newVersion) {
                            if (oldVersion >= this.minVersion) {
                                const textChangeRanges = [];
                                for (let i = oldVersion + 1; i <= newVersion; i++) {
                                    const snap = this.versions[this.versionToIndex(i)];
                                    for (const textChange of snap.changesSincePreviousVersion) {
                                        textChangeRanges.push(textChange.getTextChangeRange());
                                    }
                                }
                                return collapseTextChangeRangesAcrossMultipleVersions(textChangeRanges);
                            }
                            else {
                                return void 0;
                            }
                        }
                        else {
                            return unchangedTextChangeRange;
                        }
                    }
                    getLineCount() {
                        return this._getSnapshot().index.getLineCount();
                    }
                    static fromString(script) {
                        const svc = new _ScriptVersionCache();
                        const snap = new LineIndexSnapshot(0, svc, new LineIndex());
                        svc.versions[svc.currentVersion] = snap;
                        const lm = LineIndex.linesFromText(script);
                        snap.index.load(lm.lines);
                        return svc;
                    }
                };
                _ScriptVersionCache.changeNumberThreshold = 8;
                _ScriptVersionCache.changeLengthThreshold = 256;
                _ScriptVersionCache.maxVersions = 8;
                ScriptVersionCache = _ScriptVersionCache;
                LineIndexSnapshot = class _LineIndexSnapshot {
                    constructor(version2, cache, index, changesSincePreviousVersion = emptyArray2) {
                        this.version = version2;
                        this.cache = cache;
                        this.index = index;
                        this.changesSincePreviousVersion = changesSincePreviousVersion;
                    }
                    getText(rangeStart, rangeEnd) {
                        return this.index.getText(rangeStart, rangeEnd - rangeStart);
                    }
                    getLength() {
                        return this.index.getLength();
                    }
                    getChangeRange(oldSnapshot) {
                        if (oldSnapshot instanceof _LineIndexSnapshot && this.cache === oldSnapshot.cache) {
                            if (this.version <= oldSnapshot.version) {
                                return unchangedTextChangeRange;
                            }
                            else {
                                return this.cache.getTextChangesBetweenVersions(oldSnapshot.version, this.version);
                            }
                        }
                    }
                };
                LineIndex = class _LineIndex {
                    constructor() {
                        // set this to true to check each edit for accuracy
                        this.checkEdits = false;
                    }
                    absolutePositionOfStartOfLine(oneBasedLine) {
                        return this.lineNumberToInfo(oneBasedLine).absolutePosition;
                    }
                    positionToLineOffset(position) {
                        const { oneBasedLine, zeroBasedColumn } = this.root.charOffsetToLineInfo(1, position);
                        return { line: oneBasedLine, offset: zeroBasedColumn + 1 };
                    }
                    positionToColumnAndLineText(position) {
                        return this.root.charOffsetToLineInfo(1, position);
                    }
                    getLineCount() {
                        return this.root.lineCount();
                    }
                    lineNumberToInfo(oneBasedLine) {
                        const lineCount = this.getLineCount();
                        if (oneBasedLine <= lineCount) {
                            const { position, leaf } = this.root.lineNumberToInfo(oneBasedLine, 0);
                            return { absolutePosition: position, lineText: leaf && leaf.text };
                        }
                        else {
                            return { absolutePosition: this.root.charCount(), lineText: void 0 };
                        }
                    }
                    load(lines) {
                        if (lines.length > 0) {
                            const leaves = [];
                            for (let i = 0; i < lines.length; i++) {
                                leaves[i] = new LineLeaf(lines[i]);
                            }
                            this.root = _LineIndex.buildTreeFromBottom(leaves);
                        }
                        else {
                            this.root = new LineNode();
                        }
                    }
                    walk(rangeStart, rangeLength, walkFns) {
                        this.root.walk(rangeStart, rangeLength, walkFns);
                    }
                    getText(rangeStart, rangeLength) {
                        let accum = "";
                        if (rangeLength > 0 && rangeStart < this.root.charCount()) {
                            this.walk(rangeStart, rangeLength, {
                                goSubtree: true,
                                done: false,
                                leaf: (relativeStart, relativeLength, ll) => {
                                    accum = accum.concat(ll.text.substring(relativeStart, relativeStart + relativeLength));
                                }
                            });
                        }
                        return accum;
                    }
                    getLength() {
                        return this.root.charCount();
                    }
                    every(f, rangeStart, rangeEnd) {
                        if (!rangeEnd) {
                            rangeEnd = this.root.charCount();
                        }
                        const walkFns = {
                            goSubtree: true,
                            done: false,
                            leaf(relativeStart, relativeLength, ll) {
                                if (!f(ll, relativeStart, relativeLength)) {
                                    this.done = true;
                                }
                            }
                        };
                        this.walk(rangeStart, rangeEnd - rangeStart, walkFns);
                        return !walkFns.done;
                    }
                    edit(pos, deleteLength, newText) {
                        if (this.root.charCount() === 0) {
                            Debug.assert(deleteLength === 0);
                            if (newText !== void 0) {
                                this.load(_LineIndex.linesFromText(newText).lines);
                                return this;
                            }
                            return void 0;
                        }
                        else {
                            let checkText;
                            if (this.checkEdits) {
                                const source = this.getText(0, this.root.charCount());
                                checkText = source.slice(0, pos) + newText + source.slice(pos + deleteLength);
                            }
                            const walker = new EditWalker();
                            let suppressTrailingText = false;
                            if (pos >= this.root.charCount()) {
                                pos = this.root.charCount() - 1;
                                const endString = this.getText(pos, 1);
                                if (newText) {
                                    newText = endString + newText;
                                }
                                else {
                                    newText = endString;
                                }
                                deleteLength = 0;
                                suppressTrailingText = true;
                            }
                            else if (deleteLength > 0) {
                                const e = pos + deleteLength;
                                const { zeroBasedColumn, lineText } = this.positionToColumnAndLineText(e);
                                if (zeroBasedColumn === 0) {
                                    deleteLength += lineText.length;
                                    newText = newText ? newText + lineText : lineText;
                                }
                            }
                            this.root.walk(pos, deleteLength, walker);
                            walker.insertLines(newText, suppressTrailingText);
                            if (this.checkEdits) {
                                const updatedText = walker.lineIndex.getText(0, walker.lineIndex.getLength());
                                Debug.assert(checkText === updatedText, "buffer edit mismatch");
                            }
                            return walker.lineIndex;
                        }
                    }
                    static buildTreeFromBottom(nodes) {
                        if (nodes.length < lineCollectionCapacity) {
                            return new LineNode(nodes);
                        }
                        const interiorNodes = new Array(Math.ceil(nodes.length / lineCollectionCapacity));
                        let nodeIndex = 0;
                        for (let i = 0; i < interiorNodes.length; i++) {
                            const end = Math.min(nodeIndex + lineCollectionCapacity, nodes.length);
                            interiorNodes[i] = new LineNode(nodes.slice(nodeIndex, end));
                            nodeIndex = end;
                        }
                        return this.buildTreeFromBottom(interiorNodes);
                    }
                    static linesFromText(text) {
                        const lineMap = computeLineStarts(text);
                        if (lineMap.length === 0) {
                            return { lines: [], lineMap };
                        }
                        const lines = new Array(lineMap.length);
                        const lc = lineMap.length - 1;
                        for (let lmi = 0; lmi < lc; lmi++) {
                            lines[lmi] = text.substring(lineMap[lmi], lineMap[lmi + 1]);
                        }
                        const endText = text.substring(lineMap[lc]);
                        if (endText.length > 0) {
                            lines[lc] = endText;
                        }
                        else {
                            lines.pop();
                        }
                        return { lines, lineMap };
                    }
                };
                LineNode = class _LineNode {
                    constructor(children = []) {
                        this.children = children;
                        this.totalChars = 0;
                        this.totalLines = 0;
                        if (children.length)
                            this.updateCounts();
                    }
                    isLeaf() {
                        return false;
                    }
                    updateCounts() {
                        this.totalChars = 0;
                        this.totalLines = 0;
                        for (const child of this.children) {
                            this.totalChars += child.charCount();
                            this.totalLines += child.lineCount();
                        }
                    }
                    execWalk(rangeStart, rangeLength, walkFns, childIndex, nodeType) {
                        if (walkFns.pre) {
                            walkFns.pre(rangeStart, rangeLength, this.children[childIndex], this, nodeType);
                        }
                        if (walkFns.goSubtree) {
                            this.children[childIndex].walk(rangeStart, rangeLength, walkFns);
                            if (walkFns.post) {
                                walkFns.post(rangeStart, rangeLength, this.children[childIndex], this, nodeType);
                            }
                        }
                        else {
                            walkFns.goSubtree = true;
                        }
                        return walkFns.done;
                    }
                    skipChild(relativeStart, relativeLength, childIndex, walkFns, nodeType) {
                        if (walkFns.pre && !walkFns.done) {
                            walkFns.pre(relativeStart, relativeLength, this.children[childIndex], this, nodeType);
                            walkFns.goSubtree = true;
                        }
                    }
                    walk(rangeStart, rangeLength, walkFns) {
                        let childIndex = 0;
                        let childCharCount = this.children[childIndex].charCount();
                        let adjustedStart = rangeStart;
                        while (adjustedStart >= childCharCount) {
                            this.skipChild(adjustedStart, rangeLength, childIndex, walkFns, 0 /* PreStart */);
                            adjustedStart -= childCharCount;
                            childIndex++;
                            childCharCount = this.children[childIndex].charCount();
                        }
                        if (adjustedStart + rangeLength <= childCharCount) {
                            if (this.execWalk(adjustedStart, rangeLength, walkFns, childIndex, 2 /* Entire */)) {
                                return;
                            }
                        }
                        else {
                            if (this.execWalk(adjustedStart, childCharCount - adjustedStart, walkFns, childIndex, 1 /* Start */)) {
                                return;
                            }
                            let adjustedLength = rangeLength - (childCharCount - adjustedStart);
                            childIndex++;
                            const child = this.children[childIndex];
                            childCharCount = child.charCount();
                            while (adjustedLength > childCharCount) {
                                if (this.execWalk(0, childCharCount, walkFns, childIndex, 3 /* Mid */)) {
                                    return;
                                }
                                adjustedLength -= childCharCount;
                                childIndex++;
                                childCharCount = this.children[childIndex].charCount();
                            }
                            if (adjustedLength > 0) {
                                if (this.execWalk(0, adjustedLength, walkFns, childIndex, 4 /* End */)) {
                                    return;
                                }
                            }
                        }
                        if (walkFns.pre) {
                            const clen = this.children.length;
                            if (childIndex < clen - 1) {
                                for (let ej = childIndex + 1; ej < clen; ej++) {
                                    this.skipChild(0, 0, ej, walkFns, 5 /* PostEnd */);
                                }
                            }
                        }
                    }
                    // Input position is relative to the start of this node.
                    // Output line number is absolute.
                    charOffsetToLineInfo(lineNumberAccumulator, relativePosition) {
                        if (this.children.length === 0) {
                            return { oneBasedLine: lineNumberAccumulator, zeroBasedColumn: relativePosition, lineText: void 0 };
                        }
                        for (const child of this.children) {
                            if (child.charCount() > relativePosition) {
                                if (child.isLeaf()) {
                                    return { oneBasedLine: lineNumberAccumulator, zeroBasedColumn: relativePosition, lineText: child.text };
                                }
                                else {
                                    return child.charOffsetToLineInfo(lineNumberAccumulator, relativePosition);
                                }
                            }
                            else {
                                relativePosition -= child.charCount();
                                lineNumberAccumulator += child.lineCount();
                            }
                        }
                        const lineCount = this.lineCount();
                        if (lineCount === 0) {
                            return { oneBasedLine: 1, zeroBasedColumn: 0, lineText: void 0 };
                        }
                        const leaf = Debug.checkDefined(this.lineNumberToInfo(lineCount, 0).leaf);
                        return { oneBasedLine: lineCount, zeroBasedColumn: leaf.charCount(), lineText: void 0 };
                    }
                    /**
                     * Input line number is relative to the start of this node.
                     * Output line number is relative to the child.
                     * positionAccumulator will be an absolute position once relativeLineNumber reaches 0.
                     */
                    lineNumberToInfo(relativeOneBasedLine, positionAccumulator) {
                        for (const child of this.children) {
                            const childLineCount = child.lineCount();
                            if (childLineCount >= relativeOneBasedLine) {
                                return child.isLeaf() ? { position: positionAccumulator, leaf: child } : child.lineNumberToInfo(relativeOneBasedLine, positionAccumulator);
                            }
                            else {
                                relativeOneBasedLine -= childLineCount;
                                positionAccumulator += child.charCount();
                            }
                        }
                        return { position: positionAccumulator, leaf: void 0 };
                    }
                    splitAfter(childIndex) {
                        let splitNode;
                        const clen = this.children.length;
                        childIndex++;
                        const endLength = childIndex;
                        if (childIndex < clen) {
                            splitNode = new _LineNode();
                            while (childIndex < clen) {
                                splitNode.add(this.children[childIndex]);
                                childIndex++;
                            }
                            splitNode.updateCounts();
                        }
                        this.children.length = endLength;
                        return splitNode;
                    }
                    remove(child) {
                        const childIndex = this.findChildIndex(child);
                        const clen = this.children.length;
                        if (childIndex < clen - 1) {
                            for (let i = childIndex; i < clen - 1; i++) {
                                this.children[i] = this.children[i + 1];
                            }
                        }
                        this.children.pop();
                    }
                    findChildIndex(child) {
                        const childIndex = this.children.indexOf(child);
                        Debug.assert(childIndex !== -1);
                        return childIndex;
                    }
                    insertAt(child, nodes) {
                        let childIndex = this.findChildIndex(child);
                        const clen = this.children.length;
                        const nodeCount = nodes.length;
                        if (clen < lineCollectionCapacity && childIndex === clen - 1 && nodeCount === 1) {
                            this.add(nodes[0]);
                            this.updateCounts();
                            return [];
                        }
                        else {
                            const shiftNode = this.splitAfter(childIndex);
                            let nodeIndex = 0;
                            childIndex++;
                            while (childIndex < lineCollectionCapacity && nodeIndex < nodeCount) {
                                this.children[childIndex] = nodes[nodeIndex];
                                childIndex++;
                                nodeIndex++;
                            }
                            let splitNodes = [];
                            let splitNodeCount = 0;
                            if (nodeIndex < nodeCount) {
                                splitNodeCount = Math.ceil((nodeCount - nodeIndex) / lineCollectionCapacity);
                                splitNodes = new Array(splitNodeCount);
                                let splitNodeIndex = 0;
                                for (let i = 0; i < splitNodeCount; i++) {
                                    splitNodes[i] = new _LineNode();
                                }
                                let splitNode = splitNodes[0];
                                while (nodeIndex < nodeCount) {
                                    splitNode.add(nodes[nodeIndex]);
                                    nodeIndex++;
                                    if (splitNode.children.length === lineCollectionCapacity) {
                                        splitNodeIndex++;
                                        splitNode = splitNodes[splitNodeIndex];
                                    }
                                }
                                for (let i = splitNodes.length - 1; i >= 0; i--) {
                                    if (splitNodes[i].children.length === 0) {
                                        splitNodes.pop();
                                    }
                                }
                            }
                            if (shiftNode) {
                                splitNodes.push(shiftNode);
                            }
                            this.updateCounts();
                            for (let i = 0; i < splitNodeCount; i++) {
                                splitNodes[i].updateCounts();
                            }
                            return splitNodes;
                        }
                    }
                    // assume there is room for the item; return true if more room
                    add(collection) {
                        this.children.push(collection);
                        Debug.assert(this.children.length <= lineCollectionCapacity);
                    }
                    charCount() {
                        return this.totalChars;
                    }
                    lineCount() {
                        return this.totalLines;
                    }
                };
                LineLeaf = class {
                    constructor(text) {
                        this.text = text;
                    }
                    isLeaf() {
                        return true;
                    }
                    walk(rangeStart, rangeLength, walkFns) {
                        walkFns.leaf(rangeStart, rangeLength, this);
                    }
                    charCount() {
                        return this.text.length;
                    }
                    lineCount() {
                        return 1;
                    }
                };
            }
        });
        // src/server/typingInstallerAdapter.ts
        var _TypingsInstallerAdapter, TypingsInstallerAdapter;
        var init_typingInstallerAdapter = __esm({
            "src/server/typingInstallerAdapter.ts"() {
                "use strict";
                init_ts7();
                init_ts_server3();
                _TypingsInstallerAdapter = class _TypingsInstallerAdapter {
                    constructor(telemetryEnabled, logger, host, globalTypingsCacheLocation, event, maxActiveRequestCount) {
                        this.telemetryEnabled = telemetryEnabled;
                        this.logger = logger;
                        this.host = host;
                        this.globalTypingsCacheLocation = globalTypingsCacheLocation;
                        this.event = event;
                        this.maxActiveRequestCount = maxActiveRequestCount;
                        this.activeRequestCount = 0;
                        this.requestQueue = createQueue();
                        this.requestMap = /* @__PURE__ */ new Map();
                        // Maps project name to newest requestQueue entry for that project
                        /** We will lazily request the types registry on the first call to `isKnownTypesPackageName` and store it in `typesRegistryCache`. */
                        this.requestedRegistry = false;
                        this.packageInstallId = 0;
                    }
                    isKnownTypesPackageName(name) {
                        var _a;
                        const validationResult = ts_JsTyping_exports.validatePackageName(name);
                        if (validationResult !== ts_JsTyping_exports.NameValidationResult.Ok) {
                            return false;
                        }
                        if (!this.requestedRegistry) {
                            this.requestedRegistry = true;
                            this.installer.send({ kind: "typesRegistry" });
                        }
                        return !!((_a = this.typesRegistryCache) == null ? void 0 : _a.has(name));
                    }
                    installPackage(options) {
                        this.packageInstallId++;
                        const request = { kind: "installPackage", ...options, id: this.packageInstallId };
                        const promise = new Promise((resolve, reject) => {
                            (this.packageInstalledPromise ?? (this.packageInstalledPromise = /* @__PURE__ */ new Map())).set(this.packageInstallId, { resolve, reject });
                        });
                        this.installer.send(request);
                        return promise;
                    }
                    attach(projectService) {
                        this.projectService = projectService;
                        this.installer = this.createInstallerProcess();
                    }
                    onProjectClosed(p) {
                        this.installer.send({ projectName: p.getProjectName(), kind: "closeProject" });
                    }
                    enqueueInstallTypingsRequest(project, typeAcquisition, unresolvedImports) {
                        const request = createInstallTypingsRequest(project, typeAcquisition, unresolvedImports);
                        if (this.logger.hasLevel(3 /* verbose */)) {
                            this.logger.info(`TIAdapter:: Scheduling throttled operation:${stringifyIndented(request)}`);
                        }
                        if (this.activeRequestCount < this.maxActiveRequestCount) {
                            this.scheduleRequest(request);
                        }
                        else {
                            if (this.logger.hasLevel(3 /* verbose */)) {
                                this.logger.info(`TIAdapter:: Deferring request for: ${request.projectName}`);
                            }
                            this.requestQueue.enqueue(request);
                            this.requestMap.set(request.projectName, request);
                        }
                    }
                    handleMessage(response) {
                        var _a, _b;
                        if (this.logger.hasLevel(3 /* verbose */)) {
                            this.logger.info(`TIAdapter:: Received response:${stringifyIndented(response)}`);
                        }
                        switch (response.kind) {
                            case EventTypesRegistry:
                                this.typesRegistryCache = new Map(Object.entries(response.typesRegistry));
                                break;
                            case ActionPackageInstalled: {
                                const promise = (_a = this.packageInstalledPromise) == null ? void 0 : _a.get(response.id);
                                Debug.assertIsDefined(promise, "Should find the promise for package install");
                                (_b = this.packageInstalledPromise) == null ? void 0 : _b.delete(response.id);
                                if (response.success) {
                                    promise.resolve({ successMessage: response.message });
                                }
                                else {
                                    promise.reject(response.message);
                                }
                                this.projectService.updateTypingsForProject(response);
                                this.event(response, "setTypings");
                                break;
                            }
                            case EventInitializationFailed: {
                                const body = {
                                    message: response.message
                                };
                                const eventName = "typesInstallerInitializationFailed";
                                this.event(body, eventName);
                                break;
                            }
                            case EventBeginInstallTypes: {
                                const body = {
                                    eventId: response.eventId,
                                    packages: response.packagesToInstall
                                };
                                const eventName = "beginInstallTypes";
                                this.event(body, eventName);
                                break;
                            }
                            case EventEndInstallTypes: {
                                if (this.telemetryEnabled) {
                                    const body2 = {
                                        telemetryEventName: "typingsInstalled",
                                        payload: {
                                            installedPackages: response.packagesToInstall.join(","),
                                            installSuccess: response.installSuccess,
                                            typingsInstallerVersion: response.typingsInstallerVersion
                                        }
                                    };
                                    const eventName2 = "telemetry";
                                    this.event(body2, eventName2);
                                }
                                const body = {
                                    eventId: response.eventId,
                                    packages: response.packagesToInstall,
                                    success: response.installSuccess
                                };
                                const eventName = "endInstallTypes";
                                this.event(body, eventName);
                                break;
                            }
                            case ActionInvalidate: {
                                this.projectService.updateTypingsForProject(response);
                                break;
                            }
                            case ActionSet: {
                                if (this.activeRequestCount > 0) {
                                    this.activeRequestCount--;
                                }
                                else {
                                    Debug.fail("TIAdapter:: Received too many responses");
                                }
                                while (!this.requestQueue.isEmpty()) {
                                    const queuedRequest = this.requestQueue.dequeue();
                                    if (this.requestMap.get(queuedRequest.projectName) === queuedRequest) {
                                        this.requestMap.delete(queuedRequest.projectName);
                                        this.scheduleRequest(queuedRequest);
                                        break;
                                    }
                                    if (this.logger.hasLevel(3 /* verbose */)) {
                                        this.logger.info(`TIAdapter:: Skipping defunct request for: ${queuedRequest.projectName}`);
                                    }
                                }
                                this.projectService.updateTypingsForProject(response);
                                this.event(response, "setTypings");
                                break;
                            }
                            case ActionWatchTypingLocations:
                                this.projectService.watchTypingLocations(response);
                                break;
                            default:
                                assertType(response);
                        }
                    }
                    scheduleRequest(request) {
                        if (this.logger.hasLevel(3 /* verbose */)) {
                            this.logger.info(`TIAdapter:: Scheduling request for: ${request.projectName}`);
                        }
                        this.activeRequestCount++;
                        this.host.setTimeout(() => {
                            if (this.logger.hasLevel(3 /* verbose */)) {
                                this.logger.info(`TIAdapter:: Sending request:${stringifyIndented(request)}`);
                            }
                            this.installer.send(request);
                        }, _TypingsInstallerAdapter.requestDelayMillis, `${request.projectName}::${request.kind}`);
                    }
                };
                // This number is essentially arbitrary.  Processing more than one typings request
                // at a time makes sense, but having too many in the pipe results in a hang
                // (see https://github.com/nodejs/node/issues/7657).
                // It would be preferable to base our limit on the amount of space left in the
                // buffer, but we have yet to find a way to retrieve that value.
                _TypingsInstallerAdapter.requestDelayMillis = 100;
                TypingsInstallerAdapter = _TypingsInstallerAdapter;
            }
        });
        // src/server/_namespaces/ts.server.ts
        var ts_server_exports3 = {};
        __export(ts_server_exports3, {
            ActionInvalidate: () => ActionInvalidate,
            ActionPackageInstalled: () => ActionPackageInstalled,
            ActionSet: () => ActionSet,
            ActionWatchTypingLocations: () => ActionWatchTypingLocations,
            Arguments: () => Arguments,
            AutoImportProviderProject: () => AutoImportProviderProject,
            AuxiliaryProject: () => AuxiliaryProject,
            CharRangeSection: () => CharRangeSection,
            CloseFileWatcherEvent: () => CloseFileWatcherEvent,
            CommandNames: () => CommandNames,
            ConfigFileDiagEvent: () => ConfigFileDiagEvent,
            ConfiguredProject: () => ConfiguredProject2,
            CreateDirectoryWatcherEvent: () => CreateDirectoryWatcherEvent,
            CreateFileWatcherEvent: () => CreateFileWatcherEvent,
            Errors: () => Errors,
            EventBeginInstallTypes: () => EventBeginInstallTypes,
            EventEndInstallTypes: () => EventEndInstallTypes,
            EventInitializationFailed: () => EventInitializationFailed,
            EventTypesRegistry: () => EventTypesRegistry,
            ExternalProject: () => ExternalProject2,
            GcTimer: () => GcTimer,
            InferredProject: () => InferredProject2,
            LargeFileReferencedEvent: () => LargeFileReferencedEvent,
            LineIndex: () => LineIndex,
            LineLeaf: () => LineLeaf,
            LineNode: () => LineNode,
            LogLevel: () => LogLevel2,
            Msg: () => Msg,
            OpenFileInfoTelemetryEvent: () => OpenFileInfoTelemetryEvent,
            Project: () => Project3,
            ProjectInfoTelemetryEvent: () => ProjectInfoTelemetryEvent,
            ProjectKind: () => ProjectKind,
            ProjectLanguageServiceStateEvent: () => ProjectLanguageServiceStateEvent,
            ProjectLoadingFinishEvent: () => ProjectLoadingFinishEvent,
            ProjectLoadingStartEvent: () => ProjectLoadingStartEvent,
            ProjectReferenceProjectLoadKind: () => ProjectReferenceProjectLoadKind,
            ProjectService: () => ProjectService3,
            ProjectsUpdatedInBackgroundEvent: () => ProjectsUpdatedInBackgroundEvent,
            ScriptInfo: () => ScriptInfo,
            ScriptVersionCache: () => ScriptVersionCache,
            Session: () => Session3,
            TextStorage: () => TextStorage,
            ThrottledOperations: () => ThrottledOperations,
            TypingsCache: () => TypingsCache,
            TypingsInstallerAdapter: () => TypingsInstallerAdapter,
            allFilesAreJsOrDts: () => allFilesAreJsOrDts,
            allRootFilesAreJsOrDts: () => allRootFilesAreJsOrDts,
            asNormalizedPath: () => asNormalizedPath,
            convertCompilerOptions: () => convertCompilerOptions,
            convertFormatOptions: () => convertFormatOptions,
            convertScriptKindName: () => convertScriptKindName,
            convertTypeAcquisition: () => convertTypeAcquisition,
            convertUserPreferences: () => convertUserPreferences,
            convertWatchOptions: () => convertWatchOptions,
            countEachFileTypes: () => countEachFileTypes,
            createInstallTypingsRequest: () => createInstallTypingsRequest,
            createModuleSpecifierCache: () => createModuleSpecifierCache,
            createNormalizedPathMap: () => createNormalizedPathMap,
            createPackageJsonCache: () => createPackageJsonCache,
            createSortedArray: () => createSortedArray2,
            emptyArray: () => emptyArray2,
            findArgument: () => findArgument,
            forEachResolvedProjectReferenceProject: () => forEachResolvedProjectReferenceProject,
            formatDiagnosticToProtocol: () => formatDiagnosticToProtocol,
            formatMessage: () => formatMessage2,
            getBaseConfigFileName: () => getBaseConfigFileName,
            getLocationInNewDocument: () => getLocationInNewDocument,
            hasArgument: () => hasArgument,
            hasNoTypeScriptSource: () => hasNoTypeScriptSource,
            indent: () => indent2,
            isBackgroundProject: () => isBackgroundProject,
            isConfigFile: () => isConfigFile,
            isConfiguredProject: () => isConfiguredProject,
            isDynamicFileName: () => isDynamicFileName,
            isExternalProject: () => isExternalProject,
            isInferredProject: () => isInferredProject,
            isInferredProjectName: () => isInferredProjectName,
            makeAutoImportProviderProjectName: () => makeAutoImportProviderProjectName,
            makeAuxiliaryProjectName: () => makeAuxiliaryProjectName,
            makeInferredProjectName: () => makeInferredProjectName,
            maxFileSize: () => maxFileSize,
            maxProgramSizeForNonTsFiles: () => maxProgramSizeForNonTsFiles,
            normalizedPathToPath: () => normalizedPathToPath,
            nowString: () => nowString,
            nullCancellationToken: () => nullCancellationToken,
            nullTypingsInstaller: () => nullTypingsInstaller,
            projectContainsInfoDirectly: () => projectContainsInfoDirectly,
            protocol: () => ts_server_protocol_exports,
            removeSorted: () => removeSorted,
            stringifyIndented: () => stringifyIndented,
            toEvent: () => toEvent,
            toNormalizedPath: () => toNormalizedPath,
            tryConvertScriptKindName: () => tryConvertScriptKindName,
            typingsInstaller: () => ts_server_typingsInstaller_exports,
            updateProjectIfDirty: () => updateProjectIfDirty
        });
        var init_ts_server3 = __esm({
            "src/server/_namespaces/ts.server.ts"() {
                "use strict";
                init_ts_server();
                init_ts_server2();
                init_types4();
                init_utilitiesPublic3();
                init_utilities5();
                init_ts_server_protocol();
                init_scriptInfo();
                init_typingsCache();
                init_project();
                init_editorServices();
                init_moduleSpecifierCache();
                init_packageJsonCache();
                init_session();
                init_scriptVersionCache();
                init_typingInstallerAdapter();
            }
        });
        // src/server/_namespaces/ts.ts
        var ts_exports2 = {};
        __export(ts_exports2, {
            ANONYMOUS: () => ANONYMOUS,
            AccessFlags: () => AccessFlags,
            AssertionLevel: () => AssertionLevel,
            AssignmentDeclarationKind: () => AssignmentDeclarationKind,
            AssignmentKind: () => AssignmentKind,
            Associativity: () => Associativity,
            BreakpointResolver: () => ts_BreakpointResolver_exports,
            BuilderFileEmit: () => BuilderFileEmit,
            BuilderProgramKind: () => BuilderProgramKind,
            BuilderState: () => BuilderState,
            BundleFileSectionKind: () => BundleFileSectionKind,
            CallHierarchy: () => ts_CallHierarchy_exports,
            CharacterCodes: () => CharacterCodes,
            CheckFlags: () => CheckFlags,
            CheckMode: () => CheckMode,
            ClassificationType: () => ClassificationType,
            ClassificationTypeNames: () => ClassificationTypeNames,
            CommentDirectiveType: () => CommentDirectiveType,
            Comparison: () => Comparison,
            CompletionInfoFlags: () => CompletionInfoFlags,
            CompletionTriggerKind: () => CompletionTriggerKind,
            Completions: () => ts_Completions_exports,
            ContainerFlags: () => ContainerFlags,
            ContextFlags: () => ContextFlags,
            Debug: () => Debug,
            DiagnosticCategory: () => DiagnosticCategory,
            Diagnostics: () => Diagnostics,
            DocumentHighlights: () => DocumentHighlights,
            ElementFlags: () => ElementFlags,
            EmitFlags: () => EmitFlags,
            EmitHint: () => EmitHint,
            EmitOnly: () => EmitOnly,
            EndOfLineState: () => EndOfLineState,
            EnumKind: () => EnumKind,
            ExitStatus: () => ExitStatus,
            ExportKind: () => ExportKind,
            Extension: () => Extension,
            ExternalEmitHelpers: () => ExternalEmitHelpers,
            FileIncludeKind: () => FileIncludeKind,
            FilePreprocessingDiagnosticsKind: () => FilePreprocessingDiagnosticsKind,
            FileSystemEntryKind: () => FileSystemEntryKind,
            FileWatcherEventKind: () => FileWatcherEventKind,
            FindAllReferences: () => ts_FindAllReferences_exports,
            FlattenLevel: () => FlattenLevel,
            FlowFlags: () => FlowFlags,
            ForegroundColorEscapeSequences: () => ForegroundColorEscapeSequences,
            FunctionFlags: () => FunctionFlags,
            GeneratedIdentifierFlags: () => GeneratedIdentifierFlags,
            GetLiteralTextFlags: () => GetLiteralTextFlags,
            GoToDefinition: () => ts_GoToDefinition_exports,
            HighlightSpanKind: () => HighlightSpanKind,
            IdentifierNameMap: () => IdentifierNameMap,
            IdentifierNameMultiMap: () => IdentifierNameMultiMap,
            ImportKind: () => ImportKind,
            ImportsNotUsedAsValues: () => ImportsNotUsedAsValues,
            IndentStyle: () => IndentStyle,
            IndexFlags: () => IndexFlags,
            IndexKind: () => IndexKind,
            InferenceFlags: () => InferenceFlags,
            InferencePriority: () => InferencePriority,
            InlayHintKind: () => InlayHintKind,
            InlayHints: () => ts_InlayHints_exports,
            InternalEmitFlags: () => InternalEmitFlags,
            InternalSymbolName: () => InternalSymbolName,
            InvalidatedProjectKind: () => InvalidatedProjectKind,
            JSDocParsingMode: () => JSDocParsingMode,
            JsDoc: () => ts_JsDoc_exports,
            JsTyping: () => ts_JsTyping_exports,
            JsxEmit: () => JsxEmit,
            JsxFlags: () => JsxFlags,
            JsxReferenceKind: () => JsxReferenceKind,
            LanguageServiceMode: () => LanguageServiceMode,
            LanguageVariant: () => LanguageVariant,
            LexicalEnvironmentFlags: () => LexicalEnvironmentFlags,
            ListFormat: () => ListFormat,
            LogLevel: () => LogLevel,
            MemberOverrideStatus: () => MemberOverrideStatus,
            ModifierFlags: () => ModifierFlags,
            ModuleDetectionKind: () => ModuleDetectionKind,
            ModuleInstanceState: () => ModuleInstanceState,
            ModuleKind: () => ModuleKind,
            ModuleResolutionKind: () => ModuleResolutionKind,
            ModuleSpecifierEnding: () => ModuleSpecifierEnding,
            NavigateTo: () => ts_NavigateTo_exports,
            NavigationBar: () => ts_NavigationBar_exports,
            NewLineKind: () => NewLineKind,
            NodeBuilderFlags: () => NodeBuilderFlags,
            NodeCheckFlags: () => NodeCheckFlags,
            NodeFactoryFlags: () => NodeFactoryFlags,
            NodeFlags: () => NodeFlags,
            NodeResolutionFeatures: () => NodeResolutionFeatures,
            ObjectFlags: () => ObjectFlags,
            OperationCanceledException: () => OperationCanceledException,
            OperatorPrecedence: () => OperatorPrecedence,
            OrganizeImports: () => ts_OrganizeImports_exports,
            OrganizeImportsMode: () => OrganizeImportsMode,
            OuterExpressionKinds: () => OuterExpressionKinds,
            OutliningElementsCollector: () => ts_OutliningElementsCollector_exports,
            OutliningSpanKind: () => OutliningSpanKind,
            OutputFileType: () => OutputFileType,
            PackageJsonAutoImportPreference: () => PackageJsonAutoImportPreference,
            PackageJsonDependencyGroup: () => PackageJsonDependencyGroup,
            PatternMatchKind: () => PatternMatchKind,
            PollingInterval: () => PollingInterval,
            PollingWatchKind: () => PollingWatchKind,
            PragmaKindFlags: () => PragmaKindFlags,
            PrivateIdentifierKind: () => PrivateIdentifierKind,
            ProcessLevel: () => ProcessLevel,
            ProgramUpdateLevel: () => ProgramUpdateLevel,
            QuotePreference: () => QuotePreference,
            RelationComparisonResult: () => RelationComparisonResult,
            Rename: () => ts_Rename_exports,
            ScriptElementKind: () => ScriptElementKind,
            ScriptElementKindModifier: () => ScriptElementKindModifier,
            ScriptKind: () => ScriptKind,
            ScriptSnapshot: () => ScriptSnapshot,
            ScriptTarget: () => ScriptTarget,
            SemanticClassificationFormat: () => SemanticClassificationFormat,
            SemanticMeaning: () => SemanticMeaning,
            SemicolonPreference: () => SemicolonPreference,
            SignatureCheckMode: () => SignatureCheckMode,
            SignatureFlags: () => SignatureFlags,
            SignatureHelp: () => ts_SignatureHelp_exports,
            SignatureKind: () => SignatureKind,
            SmartSelectionRange: () => ts_SmartSelectionRange_exports,
            SnippetKind: () => SnippetKind,
            SortKind: () => SortKind,
            StructureIsReused: () => StructureIsReused,
            SymbolAccessibility: () => SymbolAccessibility,
            SymbolDisplay: () => ts_SymbolDisplay_exports,
            SymbolDisplayPartKind: () => SymbolDisplayPartKind,
            SymbolFlags: () => SymbolFlags,
            SymbolFormatFlags: () => SymbolFormatFlags,
            SyntaxKind: () => SyntaxKind,
            SyntheticSymbolKind: () => SyntheticSymbolKind,
            Ternary: () => Ternary,
            ThrottledCancellationToken: () => ThrottledCancellationToken,
            TokenClass: () => TokenClass,
            TokenFlags: () => TokenFlags,
            TransformFlags: () => TransformFlags,
            TypeFacts: () => TypeFacts,
            TypeFlags: () => TypeFlags,
            TypeFormatFlags: () => TypeFormatFlags,
            TypeMapKind: () => TypeMapKind,
            TypePredicateKind: () => TypePredicateKind,
            TypeReferenceSerializationKind: () => TypeReferenceSerializationKind,
            UnionReduction: () => UnionReduction,
            UpToDateStatusType: () => UpToDateStatusType,
            VarianceFlags: () => VarianceFlags,
            Version: () => Version,
            VersionRange: () => VersionRange,
            WatchDirectoryFlags: () => WatchDirectoryFlags,
            WatchDirectoryKind: () => WatchDirectoryKind,
            WatchFileKind: () => WatchFileKind,
            WatchLogLevel: () => WatchLogLevel,
            WatchType: () => WatchType,
            accessPrivateIdentifier: () => accessPrivateIdentifier,
            addDisposableResourceHelper: () => addDisposableResourceHelper,
            addEmitFlags: () => addEmitFlags,
            addEmitHelper: () => addEmitHelper,
            addEmitHelpers: () => addEmitHelpers,
            addInternalEmitFlags: () => addInternalEmitFlags,
            addNodeFactoryPatcher: () => addNodeFactoryPatcher,
            addObjectAllocatorPatcher: () => addObjectAllocatorPatcher,
            addRange: () => addRange,
            addRelatedInfo: () => addRelatedInfo,
            addSyntheticLeadingComment: () => addSyntheticLeadingComment,
            addSyntheticTrailingComment: () => addSyntheticTrailingComment,
            addToSeen: () => addToSeen,
            advancedAsyncSuperHelper: () => advancedAsyncSuperHelper,
            affectsDeclarationPathOptionDeclarations: () => affectsDeclarationPathOptionDeclarations,
            affectsEmitOptionDeclarations: () => affectsEmitOptionDeclarations,
            allKeysStartWithDot: () => allKeysStartWithDot,
            altDirectorySeparator: () => altDirectorySeparator,
            and: () => and,
            append: () => append,
            appendIfUnique: () => appendIfUnique,
            arrayFrom: () => arrayFrom,
            arrayIsEqualTo: () => arrayIsEqualTo,
            arrayIsHomogeneous: () => arrayIsHomogeneous,
            arrayIsSorted: () => arrayIsSorted,
            arrayOf: () => arrayOf,
            arrayReverseIterator: () => arrayReverseIterator,
            arrayToMap: () => arrayToMap,
            arrayToMultiMap: () => arrayToMultiMap,
            arrayToNumericMap: () => arrayToNumericMap,
            arraysEqual: () => arraysEqual,
            assertType: () => assertType,
            assign: () => assign,
            assignHelper: () => assignHelper,
            asyncDelegator: () => asyncDelegator,
            asyncGeneratorHelper: () => asyncGeneratorHelper,
            asyncSuperHelper: () => asyncSuperHelper,
            asyncValues: () => asyncValues,
            attachFileToDiagnostics: () => attachFileToDiagnostics,
            awaitHelper: () => awaitHelper,
            awaiterHelper: () => awaiterHelper,
            base64decode: () => base64decode,
            base64encode: () => base64encode,
            binarySearch: () => binarySearch,
            binarySearchKey: () => binarySearchKey,
            bindSourceFile: () => bindSourceFile,
            breakIntoCharacterSpans: () => breakIntoCharacterSpans,
            breakIntoWordSpans: () => breakIntoWordSpans,
            buildLinkParts: () => buildLinkParts,
            buildOpts: () => buildOpts,
            buildOverload: () => buildOverload,
            bundlerModuleNameResolver: () => bundlerModuleNameResolver,
            canBeConvertedToAsync: () => canBeConvertedToAsync,
            canHaveDecorators: () => canHaveDecorators,
            canHaveExportModifier: () => canHaveExportModifier,
            canHaveFlowNode: () => canHaveFlowNode,
            canHaveIllegalDecorators: () => canHaveIllegalDecorators,
            canHaveIllegalModifiers: () => canHaveIllegalModifiers,
            canHaveIllegalType: () => canHaveIllegalType,
            canHaveIllegalTypeParameters: () => canHaveIllegalTypeParameters,
            canHaveJSDoc: () => canHaveJSDoc,
            canHaveLocals: () => canHaveLocals,
            canHaveModifiers: () => canHaveModifiers,
            canHaveSymbol: () => canHaveSymbol,
            canJsonReportNoInputFiles: () => canJsonReportNoInputFiles,
            canProduceDiagnostics: () => canProduceDiagnostics,
            canUsePropertyAccess: () => canUsePropertyAccess,
            canWatchAffectingLocation: () => canWatchAffectingLocation,
            canWatchAtTypes: () => canWatchAtTypes,
            canWatchDirectoryOrFile: () => canWatchDirectoryOrFile,
            cartesianProduct: () => cartesianProduct,
            cast: () => cast,
            chainBundle: () => chainBundle,
            chainDiagnosticMessages: () => chainDiagnosticMessages,
            changeAnyExtension: () => changeAnyExtension,
            changeCompilerHostLikeToUseCache: () => changeCompilerHostLikeToUseCache,
            changeExtension: () => changeExtension,
            changeFullExtension: () => changeFullExtension,
            changesAffectModuleResolution: () => changesAffectModuleResolution,
            changesAffectingProgramStructure: () => changesAffectingProgramStructure,
            childIsDecorated: () => childIsDecorated,
            classElementOrClassElementParameterIsDecorated: () => classElementOrClassElementParameterIsDecorated,
            classHasClassThisAssignment: () => classHasClassThisAssignment,
            classHasDeclaredOrExplicitlyAssignedName: () => classHasDeclaredOrExplicitlyAssignedName,
            classHasExplicitlyAssignedName: () => classHasExplicitlyAssignedName,
            classOrConstructorParameterIsDecorated: () => classOrConstructorParameterIsDecorated,
            classPrivateFieldGetHelper: () => classPrivateFieldGetHelper,
            classPrivateFieldInHelper: () => classPrivateFieldInHelper,
            classPrivateFieldSetHelper: () => classPrivateFieldSetHelper,
            classicNameResolver: () => classicNameResolver,
            classifier: () => ts_classifier_exports,
            cleanExtendedConfigCache: () => cleanExtendedConfigCache,
            clear: () => clear,
            clearMap: () => clearMap,
            clearSharedExtendedConfigFileWatcher: () => clearSharedExtendedConfigFileWatcher,
            climbPastPropertyAccess: () => climbPastPropertyAccess,
            climbPastPropertyOrElementAccess: () => climbPastPropertyOrElementAccess,
            clone: () => clone,
            cloneCompilerOptions: () => cloneCompilerOptions,
            closeFileWatcher: () => closeFileWatcher,
            closeFileWatcherOf: () => closeFileWatcherOf,
            codefix: () => ts_codefix_exports,
            collapseTextChangeRangesAcrossMultipleVersions: () => collapseTextChangeRangesAcrossMultipleVersions,
            collectExternalModuleInfo: () => collectExternalModuleInfo,
            combine: () => combine,
            combinePaths: () => combinePaths,
            commentPragmas: () => commentPragmas,
            commonOptionsWithBuild: () => commonOptionsWithBuild,
            commonPackageFolders: () => commonPackageFolders,
            compact: () => compact,
            compareBooleans: () => compareBooleans,
            compareDataObjects: () => compareDataObjects,
            compareDiagnostics: () => compareDiagnostics,
            compareDiagnosticsSkipRelatedInformation: () => compareDiagnosticsSkipRelatedInformation,
            compareEmitHelpers: () => compareEmitHelpers,
            compareNumberOfDirectorySeparators: () => compareNumberOfDirectorySeparators,
            comparePaths: () => comparePaths,
            comparePathsCaseInsensitive: () => comparePathsCaseInsensitive,
            comparePathsCaseSensitive: () => comparePathsCaseSensitive,
            comparePatternKeys: () => comparePatternKeys,
            compareProperties: () => compareProperties,
            compareStringsCaseInsensitive: () => compareStringsCaseInsensitive,
            compareStringsCaseInsensitiveEslintCompatible: () => compareStringsCaseInsensitiveEslintCompatible,
            compareStringsCaseSensitive: () => compareStringsCaseSensitive,
            compareStringsCaseSensitiveUI: () => compareStringsCaseSensitiveUI,
            compareTextSpans: () => compareTextSpans,
            compareValues: () => compareValues,
            compileOnSaveCommandLineOption: () => compileOnSaveCommandLineOption,
            compilerOptionsAffectDeclarationPath: () => compilerOptionsAffectDeclarationPath,
            compilerOptionsAffectEmit: () => compilerOptionsAffectEmit,
            compilerOptionsAffectSemanticDiagnostics: () => compilerOptionsAffectSemanticDiagnostics,
            compilerOptionsDidYouMeanDiagnostics: () => compilerOptionsDidYouMeanDiagnostics,
            compilerOptionsIndicateEsModules: () => compilerOptionsIndicateEsModules,
            compose: () => compose,
            computeCommonSourceDirectoryOfFilenames: () => computeCommonSourceDirectoryOfFilenames,
            computeLineAndCharacterOfPosition: () => computeLineAndCharacterOfPosition,
            computeLineOfPosition: () => computeLineOfPosition,
            computeLineStarts: () => computeLineStarts,
            computePositionOfLineAndCharacter: () => computePositionOfLineAndCharacter,
            computeSignature: () => computeSignature,
            computeSignatureWithDiagnostics: () => computeSignatureWithDiagnostics,
            computeSuggestionDiagnostics: () => computeSuggestionDiagnostics,
            computedOptions: () => computedOptions,
            concatenate: () => concatenate,
            concatenateDiagnosticMessageChains: () => concatenateDiagnosticMessageChains,
            consumesNodeCoreModules: () => consumesNodeCoreModules,
            contains: () => contains,
            containsIgnoredPath: () => containsIgnoredPath,
            containsObjectRestOrSpread: () => containsObjectRestOrSpread,
            containsParseError: () => containsParseError,
            containsPath: () => containsPath,
            convertCompilerOptionsForTelemetry: () => convertCompilerOptionsForTelemetry,
            convertCompilerOptionsFromJson: () => convertCompilerOptionsFromJson,
            convertJsonOption: () => convertJsonOption,
            convertToBase64: () => convertToBase64,
            convertToJson: () => convertToJson,
            convertToObject: () => convertToObject,
            convertToOptionsWithAbsolutePaths: () => convertToOptionsWithAbsolutePaths,
            convertToRelativePath: () => convertToRelativePath,
            convertToTSConfig: () => convertToTSConfig,
            convertTypeAcquisitionFromJson: () => convertTypeAcquisitionFromJson,
            copyComments: () => copyComments,
            copyEntries: () => copyEntries,
            copyLeadingComments: () => copyLeadingComments,
            copyProperties: () => copyProperties,
            copyTrailingAsLeadingComments: () => copyTrailingAsLeadingComments,
            copyTrailingComments: () => copyTrailingComments,
            couldStartTrivia: () => couldStartTrivia,
            countWhere: () => countWhere,
            createAbstractBuilder: () => createAbstractBuilder,
            createAccessorPropertyBackingField: () => createAccessorPropertyBackingField,
            createAccessorPropertyGetRedirector: () => createAccessorPropertyGetRedirector,
            createAccessorPropertySetRedirector: () => createAccessorPropertySetRedirector,
            createBaseNodeFactory: () => createBaseNodeFactory,
            createBinaryExpressionTrampoline: () => createBinaryExpressionTrampoline,
            createBindingHelper: () => createBindingHelper,
            createBuildInfo: () => createBuildInfo,
            createBuilderProgram: () => createBuilderProgram,
            createBuilderProgramUsingProgramBuildInfo: () => createBuilderProgramUsingProgramBuildInfo,
            createBuilderStatusReporter: () => createBuilderStatusReporter,
            createCacheWithRedirects: () => createCacheWithRedirects,
            createCacheableExportInfoMap: () => createCacheableExportInfoMap,
            createCachedDirectoryStructureHost: () => createCachedDirectoryStructureHost,
            createClassNamedEvaluationHelperBlock: () => createClassNamedEvaluationHelperBlock,
            createClassThisAssignmentBlock: () => createClassThisAssignmentBlock,
            createClassifier: () => createClassifier,
            createCommentDirectivesMap: () => createCommentDirectivesMap,
            createCompilerDiagnostic: () => createCompilerDiagnostic,
            createCompilerDiagnosticForInvalidCustomType: () => createCompilerDiagnosticForInvalidCustomType,
            createCompilerDiagnosticFromMessageChain: () => createCompilerDiagnosticFromMessageChain,
            createCompilerHost: () => createCompilerHost,
            createCompilerHostFromProgramHost: () => createCompilerHostFromProgramHost,
            createCompilerHostWorker: () => createCompilerHostWorker,
            createDetachedDiagnostic: () => createDetachedDiagnostic,
            createDiagnosticCollection: () => createDiagnosticCollection,
            createDiagnosticForFileFromMessageChain: () => createDiagnosticForFileFromMessageChain,
            createDiagnosticForNode: () => createDiagnosticForNode,
            createDiagnosticForNodeArray: () => createDiagnosticForNodeArray,
            createDiagnosticForNodeArrayFromMessageChain: () => createDiagnosticForNodeArrayFromMessageChain,
            createDiagnosticForNodeFromMessageChain: () => createDiagnosticForNodeFromMessageChain,
            createDiagnosticForNodeInSourceFile: () => createDiagnosticForNodeInSourceFile,
            createDiagnosticForRange: () => createDiagnosticForRange,
            createDiagnosticMessageChainFromDiagnostic: () => createDiagnosticMessageChainFromDiagnostic,
            createDiagnosticReporter: () => createDiagnosticReporter,
            createDocumentPositionMapper: () => createDocumentPositionMapper,
            createDocumentRegistry: () => createDocumentRegistry,
            createDocumentRegistryInternal: () => createDocumentRegistryInternal,
            createEmitAndSemanticDiagnosticsBuilderProgram: () => createEmitAndSemanticDiagnosticsBuilderProgram,
            createEmitHelperFactory: () => createEmitHelperFactory,
            createEmptyExports: () => createEmptyExports,
            createExpressionForJsxElement: () => createExpressionForJsxElement,
            createExpressionForJsxFragment: () => createExpressionForJsxFragment,
            createExpressionForObjectLiteralElementLike: () => createExpressionForObjectLiteralElementLike,
            createExpressionForPropertyName: () => createExpressionForPropertyName,
            createExpressionFromEntityName: () => createExpressionFromEntityName,
            createExternalHelpersImportDeclarationIfNeeded: () => createExternalHelpersImportDeclarationIfNeeded,
            createFileDiagnostic: () => createFileDiagnostic,
            createFileDiagnosticFromMessageChain: () => createFileDiagnosticFromMessageChain,
            createForOfBindingStatement: () => createForOfBindingStatement,
            createGetCanonicalFileName: () => createGetCanonicalFileName,
            createGetSourceFile: () => createGetSourceFile,
            createGetSymbolAccessibilityDiagnosticForNode: () => createGetSymbolAccessibilityDiagnosticForNode,
            createGetSymbolAccessibilityDiagnosticForNodeName: () => createGetSymbolAccessibilityDiagnosticForNodeName,
            createGetSymbolWalker: () => createGetSymbolWalker,
            createIncrementalCompilerHost: () => createIncrementalCompilerHost,
            createIncrementalProgram: () => createIncrementalProgram,
            createInputFiles: () => createInputFiles,
            createInputFilesWithFilePaths: () => createInputFilesWithFilePaths,
            createInputFilesWithFileTexts: () => createInputFilesWithFileTexts,
            createJsxFactoryExpression: () => createJsxFactoryExpression,
            createLanguageService: () => createLanguageService,
            createLanguageServiceSourceFile: () => createLanguageServiceSourceFile,
            createMemberAccessForPropertyName: () => createMemberAccessForPropertyName,
            createModeAwareCache: () => createModeAwareCache,
            createModeAwareCacheKey: () => createModeAwareCacheKey,
            createModuleNotFoundChain: () => createModuleNotFoundChain,
            createModuleResolutionCache: () => createModuleResolutionCache,
            createModuleResolutionLoader: () => createModuleResolutionLoader,
            createModuleResolutionLoaderUsingGlobalCache: () => createModuleResolutionLoaderUsingGlobalCache,
            createModuleSpecifierResolutionHost: () => createModuleSpecifierResolutionHost,
            createMultiMap: () => createMultiMap,
            createNodeConverters: () => createNodeConverters,
            createNodeFactory: () => createNodeFactory,
            createOptionNameMap: () => createOptionNameMap,
            createOverload: () => createOverload,
            createPackageJsonImportFilter: () => createPackageJsonImportFilter,
            createPackageJsonInfo: () => createPackageJsonInfo,
            createParenthesizerRules: () => createParenthesizerRules,
            createPatternMatcher: () => createPatternMatcher,
            createPrependNodes: () => createPrependNodes,
            createPrinter: () => createPrinter,
            createPrinterWithDefaults: () => createPrinterWithDefaults,
            createPrinterWithRemoveComments: () => createPrinterWithRemoveComments,
            createPrinterWithRemoveCommentsNeverAsciiEscape: () => createPrinterWithRemoveCommentsNeverAsciiEscape,
            createPrinterWithRemoveCommentsOmitTrailingSemicolon: () => createPrinterWithRemoveCommentsOmitTrailingSemicolon,
            createProgram: () => createProgram,
            createProgramHost: () => createProgramHost,
            createPropertyNameNodeForIdentifierOrLiteral: () => createPropertyNameNodeForIdentifierOrLiteral,
            createQueue: () => createQueue,
            createRange: () => createRange,
            createRedirectedBuilderProgram: () => createRedirectedBuilderProgram,
            createResolutionCache: () => createResolutionCache,
            createRuntimeTypeSerializer: () => createRuntimeTypeSerializer,
            createScanner: () => createScanner,
            createSemanticDiagnosticsBuilderProgram: () => createSemanticDiagnosticsBuilderProgram,
            createSet: () => createSet,
            createSolutionBuilder: () => createSolutionBuilder,
            createSolutionBuilderHost: () => createSolutionBuilderHost,
            createSolutionBuilderWithWatch: () => createSolutionBuilderWithWatch,
            createSolutionBuilderWithWatchHost: () => createSolutionBuilderWithWatchHost,
            createSortedArray: () => createSortedArray,
            createSourceFile: () => createSourceFile,
            createSourceMapGenerator: () => createSourceMapGenerator,
            createSourceMapSource: () => createSourceMapSource,
            createSuperAccessVariableStatement: () => createSuperAccessVariableStatement,
            createSymbolTable: () => createSymbolTable,
            createSymlinkCache: () => createSymlinkCache,
            createSystemWatchFunctions: () => createSystemWatchFunctions,
            createTextChange: () => createTextChange,
            createTextChangeFromStartLength: () => createTextChangeFromStartLength,
            createTextChangeRange: () => createTextChangeRange,
            createTextRangeFromNode: () => createTextRangeFromNode,
            createTextRangeFromSpan: () => createTextRangeFromSpan,
            createTextSpan: () => createTextSpan,
            createTextSpanFromBounds: () => createTextSpanFromBounds,
            createTextSpanFromNode: () => createTextSpanFromNode,
            createTextSpanFromRange: () => createTextSpanFromRange,
            createTextSpanFromStringLiteralLikeContent: () => createTextSpanFromStringLiteralLikeContent,
            createTextWriter: () => createTextWriter,
            createTokenRange: () => createTokenRange,
            createTypeChecker: () => createTypeChecker,
            createTypeReferenceDirectiveResolutionCache: () => createTypeReferenceDirectiveResolutionCache,
            createTypeReferenceResolutionLoader: () => createTypeReferenceResolutionLoader,
            createUnparsedSourceFile: () => createUnparsedSourceFile,
            createWatchCompilerHost: () => createWatchCompilerHost2,
            createWatchCompilerHostOfConfigFile: () => createWatchCompilerHostOfConfigFile,
            createWatchCompilerHostOfFilesAndCompilerOptions: () => createWatchCompilerHostOfFilesAndCompilerOptions,
            createWatchFactory: () => createWatchFactory,
            createWatchHost: () => createWatchHost,
            createWatchProgram: () => createWatchProgram,
            createWatchStatusReporter: () => createWatchStatusReporter,
            createWriteFileMeasuringIO: () => createWriteFileMeasuringIO,
            declarationNameToString: () => declarationNameToString,
            decodeMappings: () => decodeMappings,
            decodedTextSpanIntersectsWith: () => decodedTextSpanIntersectsWith,
            decorateHelper: () => decorateHelper,
            deduplicate: () => deduplicate,
            defaultIncludeSpec: () => defaultIncludeSpec,
            defaultInitCompilerOptions: () => defaultInitCompilerOptions,
            defaultMaximumTruncationLength: () => defaultMaximumTruncationLength,
            detectSortCaseSensitivity: () => detectSortCaseSensitivity,
            diagnosticCategoryName: () => diagnosticCategoryName,
            diagnosticToString: () => diagnosticToString,
            directoryProbablyExists: () => directoryProbablyExists,
            directorySeparator: () => directorySeparator,
            displayPart: () => displayPart,
            displayPartsToString: () => displayPartsToString,
            disposeEmitNodes: () => disposeEmitNodes,
            disposeResourcesHelper: () => disposeResourcesHelper,
            documentSpansEqual: () => documentSpansEqual,
            dumpTracingLegend: () => dumpTracingLegend,
            elementAt: () => elementAt,
            elideNodes: () => elideNodes,
            emitComments: () => emitComments,
            emitDetachedComments: () => emitDetachedComments,
            emitFiles: () => emitFiles,
            emitFilesAndReportErrors: () => emitFilesAndReportErrors,
            emitFilesAndReportErrorsAndGetExitStatus: () => emitFilesAndReportErrorsAndGetExitStatus,
            emitModuleKindIsNonNodeESM: () => emitModuleKindIsNonNodeESM,
            emitNewLineBeforeLeadingCommentOfPosition: () => emitNewLineBeforeLeadingCommentOfPosition,
            emitNewLineBeforeLeadingComments: () => emitNewLineBeforeLeadingComments,
            emitNewLineBeforeLeadingCommentsOfPosition: () => emitNewLineBeforeLeadingCommentsOfPosition,
            emitSkippedWithNoDiagnostics: () => emitSkippedWithNoDiagnostics,
            emitUsingBuildInfo: () => emitUsingBuildInfo,
            emptyArray: () => emptyArray,
            emptyFileSystemEntries: () => emptyFileSystemEntries,
            emptyMap: () => emptyMap,
            emptyOptions: () => emptyOptions,
            emptySet: () => emptySet,
            endsWith: () => endsWith,
            ensurePathIsNonModuleName: () => ensurePathIsNonModuleName,
            ensureScriptKind: () => ensureScriptKind,
            ensureTrailingDirectorySeparator: () => ensureTrailingDirectorySeparator,
            entityNameToString: () => entityNameToString,
            enumerateInsertsAndDeletes: () => enumerateInsertsAndDeletes,
            equalOwnProperties: () => equalOwnProperties,
            equateStringsCaseInsensitive: () => equateStringsCaseInsensitive,
            equateStringsCaseSensitive: () => equateStringsCaseSensitive,
            equateValues: () => equateValues,
            esDecorateHelper: () => esDecorateHelper,
            escapeJsxAttributeString: () => escapeJsxAttributeString,
            escapeLeadingUnderscores: () => escapeLeadingUnderscores,
            escapeNonAsciiString: () => escapeNonAsciiString,
            escapeSnippetText: () => escapeSnippetText,
            escapeString: () => escapeString,
            escapeTemplateSubstitution: () => escapeTemplateSubstitution,
            every: () => every,
            expandPreOrPostfixIncrementOrDecrementExpression: () => expandPreOrPostfixIncrementOrDecrementExpression,
            explainFiles: () => explainFiles,
            explainIfFileIsRedirectAndImpliedFormat: () => explainIfFileIsRedirectAndImpliedFormat,
            exportAssignmentIsAlias: () => exportAssignmentIsAlias,
            exportStarHelper: () => exportStarHelper,
            expressionResultIsUnused: () => expressionResultIsUnused,
            extend: () => extend,
            extendsHelper: () => extendsHelper,
            extensionFromPath: () => extensionFromPath,
            extensionIsTS: () => extensionIsTS,
            extensionsNotSupportingExtensionlessResolution: () => extensionsNotSupportingExtensionlessResolution,
            externalHelpersModuleNameText: () => externalHelpersModuleNameText,
            factory: () => factory,
            fileExtensionIs: () => fileExtensionIs,
            fileExtensionIsOneOf: () => fileExtensionIsOneOf,
            fileIncludeReasonToDiagnostics: () => fileIncludeReasonToDiagnostics,
            fileShouldUseJavaScriptRequire: () => fileShouldUseJavaScriptRequire,
            filter: () => filter,
            filterMutate: () => filterMutate,
            filterSemanticDiagnostics: () => filterSemanticDiagnostics,
            find: () => find,
            findAncestor: () => findAncestor,
            findBestPatternMatch: () => findBestPatternMatch,
            findChildOfKind: () => findChildOfKind,
            findComputedPropertyNameCacheAssignment: () => findComputedPropertyNameCacheAssignment,
            findConfigFile: () => findConfigFile,
            findContainingList: () => findContainingList,
            findDiagnosticForNode: () => findDiagnosticForNode,
            findFirstNonJsxWhitespaceToken: () => findFirstNonJsxWhitespaceToken,
            findIndex: () => findIndex,
            findLast: () => findLast,
            findLastIndex: () => findLastIndex,
            findListItemInfo: () => findListItemInfo,
            findMap: () => findMap,
            findModifier: () => findModifier,
            findNextToken: () => findNextToken,
            findPackageJson: () => findPackageJson,
            findPackageJsons: () => findPackageJsons,
            findPrecedingMatchingToken: () => findPrecedingMatchingToken,
            findPrecedingToken: () => findPrecedingToken,
            findSuperStatementIndexPath: () => findSuperStatementIndexPath,
            findTokenOnLeftOfPosition: () => findTokenOnLeftOfPosition,
            findUseStrictPrologue: () => findUseStrictPrologue,
            first: () => first,
            firstDefined: () => firstDefined,
            firstDefinedIterator: () => firstDefinedIterator,
            firstIterator: () => firstIterator,
            firstOrOnly: () => firstOrOnly,
            firstOrUndefined: () => firstOrUndefined,
            firstOrUndefinedIterator: () => firstOrUndefinedIterator,
            fixupCompilerOptions: () => fixupCompilerOptions,
            flatMap: () => flatMap,
            flatMapIterator: () => flatMapIterator,
            flatMapToMutable: () => flatMapToMutable,
            flatten: () => flatten,
            flattenCommaList: () => flattenCommaList,
            flattenDestructuringAssignment: () => flattenDestructuringAssignment,
            flattenDestructuringBinding: () => flattenDestructuringBinding,
            flattenDiagnosticMessageText: () => flattenDiagnosticMessageText,
            forEach: () => forEach,
            forEachAncestor: () => forEachAncestor,
            forEachAncestorDirectory: () => forEachAncestorDirectory,
            forEachChild: () => forEachChild,
            forEachChildRecursively: () => forEachChildRecursively,
            forEachEmittedFile: () => forEachEmittedFile,
            forEachEnclosingBlockScopeContainer: () => forEachEnclosingBlockScopeContainer,
            forEachEntry: () => forEachEntry,
            forEachExternalModuleToImportFrom: () => forEachExternalModuleToImportFrom,
            forEachImportClauseDeclaration: () => forEachImportClauseDeclaration,
            forEachKey: () => forEachKey,
            forEachLeadingCommentRange: () => forEachLeadingCommentRange,
            forEachNameInAccessChainWalkingLeft: () => forEachNameInAccessChainWalkingLeft,
            forEachPropertyAssignment: () => forEachPropertyAssignment,
            forEachResolvedProjectReference: () => forEachResolvedProjectReference,
            forEachReturnStatement: () => forEachReturnStatement,
            forEachRight: () => forEachRight,
            forEachTrailingCommentRange: () => forEachTrailingCommentRange,
            forEachTsConfigPropArray: () => forEachTsConfigPropArray,
            forEachUnique: () => forEachUnique,
            forEachYieldExpression: () => forEachYieldExpression,
            forSomeAncestorDirectory: () => forSomeAncestorDirectory,
            formatColorAndReset: () => formatColorAndReset,
            formatDiagnostic: () => formatDiagnostic,
            formatDiagnostics: () => formatDiagnostics,
            formatDiagnosticsWithColorAndContext: () => formatDiagnosticsWithColorAndContext,
            formatGeneratedName: () => formatGeneratedName,
            formatGeneratedNamePart: () => formatGeneratedNamePart,
            formatLocation: () => formatLocation,
            formatMessage: () => formatMessage,
            formatStringFromArgs: () => formatStringFromArgs,
            formatting: () => ts_formatting_exports,
            fullTripleSlashAMDReferencePathRegEx: () => fullTripleSlashAMDReferencePathRegEx,
            fullTripleSlashReferencePathRegEx: () => fullTripleSlashReferencePathRegEx,
            generateDjb2Hash: () => generateDjb2Hash,
            generateTSConfig: () => generateTSConfig,
            generatorHelper: () => generatorHelper,
            getAdjustedReferenceLocation: () => getAdjustedReferenceLocation,
            getAdjustedRenameLocation: () => getAdjustedRenameLocation,
            getAliasDeclarationFromName: () => getAliasDeclarationFromName,
            getAllAccessorDeclarations: () => getAllAccessorDeclarations,
            getAllDecoratorsOfClass: () => getAllDecoratorsOfClass,
            getAllDecoratorsOfClassElement: () => getAllDecoratorsOfClassElement,
            getAllJSDocTags: () => getAllJSDocTags,
            getAllJSDocTagsOfKind: () => getAllJSDocTagsOfKind,
            getAllKeys: () => getAllKeys,
            getAllProjectOutputs: () => getAllProjectOutputs,
            getAllSuperTypeNodes: () => getAllSuperTypeNodes,
            getAllUnscopedEmitHelpers: () => getAllUnscopedEmitHelpers,
            getAllowJSCompilerOption: () => getAllowJSCompilerOption,
            getAllowSyntheticDefaultImports: () => getAllowSyntheticDefaultImports,
            getAncestor: () => getAncestor,
            getAnyExtensionFromPath: () => getAnyExtensionFromPath,
            getAreDeclarationMapsEnabled: () => getAreDeclarationMapsEnabled,
            getAssignedExpandoInitializer: () => getAssignedExpandoInitializer,
            getAssignedName: () => getAssignedName,
            getAssignedNameOfIdentifier: () => getAssignedNameOfIdentifier,
            getAssignmentDeclarationKind: () => getAssignmentDeclarationKind,
            getAssignmentDeclarationPropertyAccessKind: () => getAssignmentDeclarationPropertyAccessKind,
            getAssignmentTargetKind: () => getAssignmentTargetKind,
            getAutomaticTypeDirectiveNames: () => getAutomaticTypeDirectiveNames,
            getBaseFileName: () => getBaseFileName,
            getBinaryOperatorPrecedence: () => getBinaryOperatorPrecedence,
            getBuildInfo: () => getBuildInfo,
            getBuildInfoFileVersionMap: () => getBuildInfoFileVersionMap,
            getBuildInfoText: () => getBuildInfoText,
            getBuildOrderFromAnyBuildOrder: () => getBuildOrderFromAnyBuildOrder,
            getBuilderCreationParameters: () => getBuilderCreationParameters,
            getBuilderFileEmit: () => getBuilderFileEmit,
            getCheckFlags: () => getCheckFlags,
            getClassExtendsHeritageElement: () => getClassExtendsHeritageElement,
            getClassLikeDeclarationOfSymbol: () => getClassLikeDeclarationOfSymbol,
            getCombinedLocalAndExportSymbolFlags: () => getCombinedLocalAndExportSymbolFlags,
            getCombinedModifierFlags: () => getCombinedModifierFlags,
            getCombinedNodeFlags: () => getCombinedNodeFlags,
            getCombinedNodeFlagsAlwaysIncludeJSDoc: () => getCombinedNodeFlagsAlwaysIncludeJSDoc,
            getCommentRange: () => getCommentRange,
            getCommonSourceDirectory: () => getCommonSourceDirectory,
            getCommonSourceDirectoryOfConfig: () => getCommonSourceDirectoryOfConfig,
            getCompilerOptionValue: () => getCompilerOptionValue,
            getCompilerOptionsDiffValue: () => getCompilerOptionsDiffValue,
            getConditions: () => getConditions,
            getConfigFileParsingDiagnostics: () => getConfigFileParsingDiagnostics,
            getConstantValue: () => getConstantValue,
            getContainerFlags: () => getContainerFlags,
            getContainerNode: () => getContainerNode,
            getContainingClass: () => getContainingClass,
            getContainingClassExcludingClassDecorators: () => getContainingClassExcludingClassDecorators,
            getContainingClassStaticBlock: () => getContainingClassStaticBlock,
            getContainingFunction: () => getContainingFunction,
            getContainingFunctionDeclaration: () => getContainingFunctionDeclaration,
            getContainingFunctionOrClassStaticBlock: () => getContainingFunctionOrClassStaticBlock,
            getContainingNodeArray: () => getContainingNodeArray,
            getContainingObjectLiteralElement: () => getContainingObjectLiteralElement,
            getContextualTypeFromParent: () => getContextualTypeFromParent,
            getContextualTypeFromParentOrAncestorTypeNode: () => getContextualTypeFromParentOrAncestorTypeNode,
            getCurrentTime: () => getCurrentTime,
            getDeclarationDiagnostics: () => getDeclarationDiagnostics,
            getDeclarationEmitExtensionForPath: () => getDeclarationEmitExtensionForPath,
            getDeclarationEmitOutputFilePath: () => getDeclarationEmitOutputFilePath,
            getDeclarationEmitOutputFilePathWorker: () => getDeclarationEmitOutputFilePathWorker,
            getDeclarationFileExtension: () => getDeclarationFileExtension,
            getDeclarationFromName: () => getDeclarationFromName,
            getDeclarationModifierFlagsFromSymbol: () => getDeclarationModifierFlagsFromSymbol,
            getDeclarationOfKind: () => getDeclarationOfKind,
            getDeclarationsOfKind: () => getDeclarationsOfKind,
            getDeclaredExpandoInitializer: () => getDeclaredExpandoInitializer,
            getDecorators: () => getDecorators,
            getDefaultCompilerOptions: () => getDefaultCompilerOptions2,
            getDefaultExportInfoWorker: () => getDefaultExportInfoWorker,
            getDefaultFormatCodeSettings: () => getDefaultFormatCodeSettings,
            getDefaultLibFileName: () => getDefaultLibFileName,
            getDefaultLibFilePath: () => getDefaultLibFilePath,
            getDefaultLikeExportInfo: () => getDefaultLikeExportInfo,
            getDiagnosticText: () => getDiagnosticText,
            getDiagnosticsWithinSpan: () => getDiagnosticsWithinSpan,
            getDirectoryPath: () => getDirectoryPath,
            getDirectoryToWatchFailedLookupLocation: () => getDirectoryToWatchFailedLookupLocation,
            getDirectoryToWatchFailedLookupLocationFromTypeRoot: () => getDirectoryToWatchFailedLookupLocationFromTypeRoot,
            getDocumentPositionMapper: () => getDocumentPositionMapper,
            getDocumentSpansEqualityComparer: () => getDocumentSpansEqualityComparer,
            getESModuleInterop: () => getESModuleInterop,
            getEditsForFileRename: () => getEditsForFileRename,
            getEffectiveBaseTypeNode: () => getEffectiveBaseTypeNode,
            getEffectiveConstraintOfTypeParameter: () => getEffectiveConstraintOfTypeParameter,
            getEffectiveContainerForJSDocTemplateTag: () => getEffectiveContainerForJSDocTemplateTag,
            getEffectiveImplementsTypeNodes: () => getEffectiveImplementsTypeNodes,
            getEffectiveInitializer: () => getEffectiveInitializer,
            getEffectiveJSDocHost: () => getEffectiveJSDocHost,
            getEffectiveModifierFlags: () => getEffectiveModifierFlags,
            getEffectiveModifierFlagsAlwaysIncludeJSDoc: () => getEffectiveModifierFlagsAlwaysIncludeJSDoc,
            getEffectiveModifierFlagsNoCache: () => getEffectiveModifierFlagsNoCache,
            getEffectiveReturnTypeNode: () => getEffectiveReturnTypeNode,
            getEffectiveSetAccessorTypeAnnotationNode: () => getEffectiveSetAccessorTypeAnnotationNode,
            getEffectiveTypeAnnotationNode: () => getEffectiveTypeAnnotationNode,
            getEffectiveTypeParameterDeclarations: () => getEffectiveTypeParameterDeclarations,
            getEffectiveTypeRoots: () => getEffectiveTypeRoots,
            getElementOrPropertyAccessArgumentExpressionOrName: () => getElementOrPropertyAccessArgumentExpressionOrName,
            getElementOrPropertyAccessName: () => getElementOrPropertyAccessName,
            getElementsOfBindingOrAssignmentPattern: () => getElementsOfBindingOrAssignmentPattern,
            getEmitDeclarations: () => getEmitDeclarations,
            getEmitFlags: () => getEmitFlags,
            getEmitHelpers: () => getEmitHelpers,
            getEmitModuleDetectionKind: () => getEmitModuleDetectionKind,
            getEmitModuleKind: () => getEmitModuleKind,
            getEmitModuleResolutionKind: () => getEmitModuleResolutionKind,
            getEmitScriptTarget: () => getEmitScriptTarget,
            getEmitStandardClassFields: () => getEmitStandardClassFields,
            getEnclosingBlockScopeContainer: () => getEnclosingBlockScopeContainer,
            getEnclosingContainer: () => getEnclosingContainer,
            getEncodedSemanticClassifications: () => getEncodedSemanticClassifications,
            getEncodedSyntacticClassifications: () => getEncodedSyntacticClassifications,
            getEndLinePosition: () => getEndLinePosition,
            getEntityNameFromTypeNode: () => getEntityNameFromTypeNode,
            getEntrypointsFromPackageJsonInfo: () => getEntrypointsFromPackageJsonInfo,
            getErrorCountForSummary: () => getErrorCountForSummary,
            getErrorSpanForNode: () => getErrorSpanForNode,
            getErrorSummaryText: () => getErrorSummaryText,
            getEscapedTextOfIdentifierOrLiteral: () => getEscapedTextOfIdentifierOrLiteral,
            getEscapedTextOfJsxAttributeName: () => getEscapedTextOfJsxAttributeName,
            getEscapedTextOfJsxNamespacedName: () => getEscapedTextOfJsxNamespacedName,
            getExpandoInitializer: () => getExpandoInitializer,
            getExportAssignmentExpression: () => getExportAssignmentExpression,
            getExportInfoMap: () => getExportInfoMap,
            getExportNeedsImportStarHelper: () => getExportNeedsImportStarHelper,
            getExpressionAssociativity: () => getExpressionAssociativity,
            getExpressionPrecedence: () => getExpressionPrecedence,
            getExternalHelpersModuleName: () => getExternalHelpersModuleName,
            getExternalModuleImportEqualsDeclarationExpression: () => getExternalModuleImportEqualsDeclarationExpression,
            getExternalModuleName: () => getExternalModuleName,
            getExternalModuleNameFromDeclaration: () => getExternalModuleNameFromDeclaration,
            getExternalModuleNameFromPath: () => getExternalModuleNameFromPath,
            getExternalModuleNameLiteral: () => getExternalModuleNameLiteral,
            getExternalModuleRequireArgument: () => getExternalModuleRequireArgument,
            getFallbackOptions: () => getFallbackOptions,
            getFileEmitOutput: () => getFileEmitOutput,
            getFileMatcherPatterns: () => getFileMatcherPatterns,
            getFileNamesFromConfigSpecs: () => getFileNamesFromConfigSpecs,
            getFileWatcherEventKind: () => getFileWatcherEventKind,
            getFilesInErrorForSummary: () => getFilesInErrorForSummary,
            getFirstConstructorWithBody: () => getFirstConstructorWithBody,
            getFirstIdentifier: () => getFirstIdentifier,
            getFirstNonSpaceCharacterPosition: () => getFirstNonSpaceCharacterPosition,
            getFirstProjectOutput: () => getFirstProjectOutput,
            getFixableErrorSpanExpression: () => getFixableErrorSpanExpression,
            getFormatCodeSettingsForWriting: () => getFormatCodeSettingsForWriting,
            getFullWidth: () => getFullWidth,
            getFunctionFlags: () => getFunctionFlags,
            getHeritageClause: () => getHeritageClause,
            getHostSignatureFromJSDoc: () => getHostSignatureFromJSDoc,
            getIdentifierAutoGenerate: () => getIdentifierAutoGenerate,
            getIdentifierGeneratedImportReference: () => getIdentifierGeneratedImportReference,
            getIdentifierTypeArguments: () => getIdentifierTypeArguments,
            getImmediatelyInvokedFunctionExpression: () => getImmediatelyInvokedFunctionExpression,
            getImpliedNodeFormatForFile: () => getImpliedNodeFormatForFile,
            getImpliedNodeFormatForFileWorker: () => getImpliedNodeFormatForFileWorker,
            getImportNeedsImportDefaultHelper: () => getImportNeedsImportDefaultHelper,
            getImportNeedsImportStarHelper: () => getImportNeedsImportStarHelper,
            getIndentSize: () => getIndentSize,
            getIndentString: () => getIndentString,
            getInferredLibraryNameResolveFrom: () => getInferredLibraryNameResolveFrom,
            getInitializedVariables: () => getInitializedVariables,
            getInitializerOfBinaryExpression: () => getInitializerOfBinaryExpression,
            getInitializerOfBindingOrAssignmentElement: () => getInitializerOfBindingOrAssignmentElement,
            getInterfaceBaseTypeNodes: () => getInterfaceBaseTypeNodes,
            getInternalEmitFlags: () => getInternalEmitFlags,
            getInvokedExpression: () => getInvokedExpression,
            getIsolatedModules: () => getIsolatedModules,
            getJSDocAugmentsTag: () => getJSDocAugmentsTag,
            getJSDocClassTag: () => getJSDocClassTag,
            getJSDocCommentRanges: () => getJSDocCommentRanges,
            getJSDocCommentsAndTags: () => getJSDocCommentsAndTags,
            getJSDocDeprecatedTag: () => getJSDocDeprecatedTag,
            getJSDocDeprecatedTagNoCache: () => getJSDocDeprecatedTagNoCache,
            getJSDocEnumTag: () => getJSDocEnumTag,
            getJSDocHost: () => getJSDocHost,
            getJSDocImplementsTags: () => getJSDocImplementsTags,
            getJSDocOverloadTags: () => getJSDocOverloadTags,
            getJSDocOverrideTagNoCache: () => getJSDocOverrideTagNoCache,
            getJSDocParameterTags: () => getJSDocParameterTags,
            getJSDocParameterTagsNoCache: () => getJSDocParameterTagsNoCache,
            getJSDocPrivateTag: () => getJSDocPrivateTag,
            getJSDocPrivateTagNoCache: () => getJSDocPrivateTagNoCache,
            getJSDocProtectedTag: () => getJSDocProtectedTag,
            getJSDocProtectedTagNoCache: () => getJSDocProtectedTagNoCache,
            getJSDocPublicTag: () => getJSDocPublicTag,
            getJSDocPublicTagNoCache: () => getJSDocPublicTagNoCache,
            getJSDocReadonlyTag: () => getJSDocReadonlyTag,
            getJSDocReadonlyTagNoCache: () => getJSDocReadonlyTagNoCache,
            getJSDocReturnTag: () => getJSDocReturnTag,
            getJSDocReturnType: () => getJSDocReturnType,
            getJSDocRoot: () => getJSDocRoot,
            getJSDocSatisfiesExpressionType: () => getJSDocSatisfiesExpressionType,
            getJSDocSatisfiesTag: () => getJSDocSatisfiesTag,
            getJSDocTags: () => getJSDocTags,
            getJSDocTagsNoCache: () => getJSDocTagsNoCache,
            getJSDocTemplateTag: () => getJSDocTemplateTag,
            getJSDocThisTag: () => getJSDocThisTag,
            getJSDocType: () => getJSDocType,
            getJSDocTypeAliasName: () => getJSDocTypeAliasName,
            getJSDocTypeAssertionType: () => getJSDocTypeAssertionType,
            getJSDocTypeParameterDeclarations: () => getJSDocTypeParameterDeclarations,
            getJSDocTypeParameterTags: () => getJSDocTypeParameterTags,
            getJSDocTypeParameterTagsNoCache: () => getJSDocTypeParameterTagsNoCache,
            getJSDocTypeTag: () => getJSDocTypeTag,
            getJSXImplicitImportBase: () => getJSXImplicitImportBase,
            getJSXRuntimeImport: () => getJSXRuntimeImport,
            getJSXTransformEnabled: () => getJSXTransformEnabled,
            getKeyForCompilerOptions: () => getKeyForCompilerOptions,
            getLanguageVariant: () => getLanguageVariant,
            getLastChild: () => getLastChild,
            getLeadingCommentRanges: () => getLeadingCommentRanges,
            getLeadingCommentRangesOfNode: () => getLeadingCommentRangesOfNode,
            getLeftmostAccessExpression: () => getLeftmostAccessExpression,
            getLeftmostExpression: () => getLeftmostExpression,
            getLibraryNameFromLibFileName: () => getLibraryNameFromLibFileName,
            getLineAndCharacterOfPosition: () => getLineAndCharacterOfPosition,
            getLineInfo: () => getLineInfo,
            getLineOfLocalPosition: () => getLineOfLocalPosition,
            getLineOfLocalPositionFromLineMap: () => getLineOfLocalPositionFromLineMap,
            getLineStartPositionForPosition: () => getLineStartPositionForPosition,
            getLineStarts: () => getLineStarts,
            getLinesBetweenPositionAndNextNonWhitespaceCharacter: () => getLinesBetweenPositionAndNextNonWhitespaceCharacter,
            getLinesBetweenPositionAndPrecedingNonWhitespaceCharacter: () => getLinesBetweenPositionAndPrecedingNonWhitespaceCharacter,
            getLinesBetweenPositions: () => getLinesBetweenPositions,
            getLinesBetweenRangeEndAndRangeStart: () => getLinesBetweenRangeEndAndRangeStart,
            getLinesBetweenRangeEndPositions: () => getLinesBetweenRangeEndPositions,
            getLiteralText: () => getLiteralText,
            getLocalNameForExternalImport: () => getLocalNameForExternalImport,
            getLocalSymbolForExportDefault: () => getLocalSymbolForExportDefault,
            getLocaleSpecificMessage: () => getLocaleSpecificMessage,
            getLocaleTimeString: () => getLocaleTimeString,
            getMappedContextSpan: () => getMappedContextSpan,
            getMappedDocumentSpan: () => getMappedDocumentSpan,
            getMappedLocation: () => getMappedLocation,
            getMatchedFileSpec: () => getMatchedFileSpec,
            getMatchedIncludeSpec: () => getMatchedIncludeSpec,
            getMeaningFromDeclaration: () => getMeaningFromDeclaration,
            getMeaningFromLocation: () => getMeaningFromLocation,
            getMembersOfDeclaration: () => getMembersOfDeclaration,
            getModeForFileReference: () => getModeForFileReference,
            getModeForResolutionAtIndex: () => getModeForResolutionAtIndex,
            getModeForUsageLocation: () => getModeForUsageLocation,
            getModifiedTime: () => getModifiedTime,
            getModifiers: () => getModifiers,
            getModuleInstanceState: () => getModuleInstanceState,
            getModuleNameStringLiteralAt: () => getModuleNameStringLiteralAt,
            getModuleSpecifierEndingPreference: () => getModuleSpecifierEndingPreference,
            getModuleSpecifierResolverHost: () => getModuleSpecifierResolverHost,
            getNameForExportedSymbol: () => getNameForExportedSymbol,
            getNameFromImportAttribute: () => getNameFromImportAttribute,
            getNameFromIndexInfo: () => getNameFromIndexInfo,
            getNameFromPropertyName: () => getNameFromPropertyName,
            getNameOfAccessExpression: () => getNameOfAccessExpression,
            getNameOfCompilerOptionValue: () => getNameOfCompilerOptionValue,
            getNameOfDeclaration: () => getNameOfDeclaration,
            getNameOfExpando: () => getNameOfExpando,
            getNameOfJSDocTypedef: () => getNameOfJSDocTypedef,
            getNameOrArgument: () => getNameOrArgument,
            getNameTable: () => getNameTable,
            getNamesForExportedSymbol: () => getNamesForExportedSymbol,
            getNamespaceDeclarationNode: () => getNamespaceDeclarationNode,
            getNewLineCharacter: () => getNewLineCharacter,
            getNewLineKind: () => getNewLineKind,
            getNewLineOrDefaultFromHost: () => getNewLineOrDefaultFromHost,
            getNewTargetContainer: () => getNewTargetContainer,
            getNextJSDocCommentLocation: () => getNextJSDocCommentLocation,
            getNodeForGeneratedName: () => getNodeForGeneratedName,
            getNodeId: () => getNodeId,
            getNodeKind: () => getNodeKind,
            getNodeModifiers: () => getNodeModifiers,
            getNodeModulePathParts: () => getNodeModulePathParts,
            getNonAssignedNameOfDeclaration: () => getNonAssignedNameOfDeclaration,
            getNonAssignmentOperatorForCompoundAssignment: () => getNonAssignmentOperatorForCompoundAssignment,
            getNonAugmentationDeclaration: () => getNonAugmentationDeclaration,
            getNonDecoratorTokenPosOfNode: () => getNonDecoratorTokenPosOfNode,
            getNormalizedAbsolutePath: () => getNormalizedAbsolutePath,
            getNormalizedAbsolutePathWithoutRoot: () => getNormalizedAbsolutePathWithoutRoot,
            getNormalizedPathComponents: () => getNormalizedPathComponents,
            getObjectFlags: () => getObjectFlags,
            getOperator: () => getOperator,
            getOperatorAssociativity: () => getOperatorAssociativity,
            getOperatorPrecedence: () => getOperatorPrecedence,
            getOptionFromName: () => getOptionFromName,
            getOptionsForLibraryResolution: () => getOptionsForLibraryResolution,
            getOptionsNameMap: () => getOptionsNameMap,
            getOrCreateEmitNode: () => getOrCreateEmitNode,
            getOrCreateExternalHelpersModuleNameIfNeeded: () => getOrCreateExternalHelpersModuleNameIfNeeded,
            getOrUpdate: () => getOrUpdate,
            getOriginalNode: () => getOriginalNode,
            getOriginalNodeId: () => getOriginalNodeId,
            getOriginalSourceFile: () => getOriginalSourceFile,
            getOutputDeclarationFileName: () => getOutputDeclarationFileName,
            getOutputDeclarationFileNameWorker: () => getOutputDeclarationFileNameWorker,
            getOutputExtension: () => getOutputExtension,
            getOutputFileNames: () => getOutputFileNames,
            getOutputJSFileNameWorker: () => getOutputJSFileNameWorker,
            getOutputPathsFor: () => getOutputPathsFor,
            getOutputPathsForBundle: () => getOutputPathsForBundle,
            getOwnEmitOutputFilePath: () => getOwnEmitOutputFilePath,
            getOwnKeys: () => getOwnKeys,
            getOwnValues: () => getOwnValues,
            getPackageJsonInfo: () => getPackageJsonInfo,
            getPackageJsonTypesVersionsPaths: () => getPackageJsonTypesVersionsPaths,
            getPackageJsonsVisibleToFile: () => getPackageJsonsVisibleToFile,
            getPackageNameFromTypesPackageName: () => getPackageNameFromTypesPackageName,
            getPackageScopeForPath: () => getPackageScopeForPath,
            getParameterSymbolFromJSDoc: () => getParameterSymbolFromJSDoc,
            getParameterTypeNode: () => getParameterTypeNode,
            getParentNodeInSpan: () => getParentNodeInSpan,
            getParseTreeNode: () => getParseTreeNode,
            getParsedCommandLineOfConfigFile: () => getParsedCommandLineOfConfigFile,
            getPathComponents: () => getPathComponents,
            getPathComponentsRelativeTo: () => getPathComponentsRelativeTo,
            getPathFromPathComponents: () => getPathFromPathComponents,
            getPathUpdater: () => getPathUpdater,
            getPathsBasePath: () => getPathsBasePath,
            getPatternFromSpec: () => getPatternFromSpec,
            getPendingEmitKind: () => getPendingEmitKind,
            getPositionOfLineAndCharacter: () => getPositionOfLineAndCharacter,
            getPossibleGenericSignatures: () => getPossibleGenericSignatures,
            getPossibleOriginalInputExtensionForExtension: () => getPossibleOriginalInputExtensionForExtension,
            getPossibleTypeArgumentsInfo: () => getPossibleTypeArgumentsInfo,
            getPreEmitDiagnostics: () => getPreEmitDiagnostics,
            getPrecedingNonSpaceCharacterPosition: () => getPrecedingNonSpaceCharacterPosition,
            getPrivateIdentifier: () => getPrivateIdentifier,
            getProperties: () => getProperties,
            getProperty: () => getProperty,
            getPropertyArrayElementValue: () => getPropertyArrayElementValue,
            getPropertyAssignmentAliasLikeExpression: () => getPropertyAssignmentAliasLikeExpression,
            getPropertyNameForPropertyNameNode: () => getPropertyNameForPropertyNameNode,
            getPropertyNameForUniqueESSymbol: () => getPropertyNameForUniqueESSymbol,
            getPropertyNameFromType: () => getPropertyNameFromType,
            getPropertyNameOfBindingOrAssignmentElement: () => getPropertyNameOfBindingOrAssignmentElement,
            getPropertySymbolFromBindingElement: () => getPropertySymbolFromBindingElement,
            getPropertySymbolsFromContextualType: () => getPropertySymbolsFromContextualType,
            getQuoteFromPreference: () => getQuoteFromPreference,
            getQuotePreference: () => getQuotePreference,
            getRangesWhere: () => getRangesWhere,
            getRefactorContextSpan: () => getRefactorContextSpan,
            getReferencedFileLocation: () => getReferencedFileLocation,
            getRegexFromPattern: () => getRegexFromPattern,
            getRegularExpressionForWildcard: () => getRegularExpressionForWildcard,
            getRegularExpressionsForWildcards: () => getRegularExpressionsForWildcards,
            getRelativePathFromDirectory: () => getRelativePathFromDirectory,
            getRelativePathFromFile: () => getRelativePathFromFile,
            getRelativePathToDirectoryOrUrl: () => getRelativePathToDirectoryOrUrl,
            getRenameLocation: () => getRenameLocation,
            getReplacementSpanForContextToken: () => getReplacementSpanForContextToken,
            getResolutionDiagnostic: () => getResolutionDiagnostic,
            getResolutionModeOverride: () => getResolutionModeOverride,
            getResolveJsonModule: () => getResolveJsonModule,
            getResolvePackageJsonExports: () => getResolvePackageJsonExports,
            getResolvePackageJsonImports: () => getResolvePackageJsonImports,
            getResolvedExternalModuleName: () => getResolvedExternalModuleName,
            getRestIndicatorOfBindingOrAssignmentElement: () => getRestIndicatorOfBindingOrAssignmentElement,
            getRestParameterElementType: () => getRestParameterElementType,
            getRightMostAssignedExpression: () => getRightMostAssignedExpression,
            getRootDeclaration: () => getRootDeclaration,
            getRootDirectoryOfResolutionCache: () => getRootDirectoryOfResolutionCache,
            getRootLength: () => getRootLength,
            getRootPathSplitLength: () => getRootPathSplitLength,
            getScriptKind: () => getScriptKind,
            getScriptKindFromFileName: () => getScriptKindFromFileName,
            getScriptTargetFeatures: () => getScriptTargetFeatures,
            getSelectedEffectiveModifierFlags: () => getSelectedEffectiveModifierFlags,
            getSelectedSyntacticModifierFlags: () => getSelectedSyntacticModifierFlags,
            getSemanticClassifications: () => getSemanticClassifications,
            getSemanticJsxChildren: () => getSemanticJsxChildren,
            getSetAccessorTypeAnnotationNode: () => getSetAccessorTypeAnnotationNode,
            getSetAccessorValueParameter: () => getSetAccessorValueParameter,
            getSetExternalModuleIndicator: () => getSetExternalModuleIndicator,
            getShebang: () => getShebang,
            getSingleInitializerOfVariableStatementOrPropertyDeclaration: () => getSingleInitializerOfVariableStatementOrPropertyDeclaration,
            getSingleVariableOfVariableStatement: () => getSingleVariableOfVariableStatement,
            getSnapshotText: () => getSnapshotText,
            getSnippetElement: () => getSnippetElement,
            getSourceFileOfModule: () => getSourceFileOfModule,
            getSourceFileOfNode: () => getSourceFileOfNode,
            getSourceFilePathInNewDir: () => getSourceFilePathInNewDir,
            getSourceFilePathInNewDirWorker: () => getSourceFilePathInNewDirWorker,
            getSourceFileVersionAsHashFromText: () => getSourceFileVersionAsHashFromText,
            getSourceFilesToEmit: () => getSourceFilesToEmit,
            getSourceMapRange: () => getSourceMapRange,
            getSourceMapper: () => getSourceMapper,
            getSourceTextOfNodeFromSourceFile: () => getSourceTextOfNodeFromSourceFile,
            getSpanOfTokenAtPosition: () => getSpanOfTokenAtPosition,
            getSpellingSuggestion: () => getSpellingSuggestion,
            getStartPositionOfLine: () => getStartPositionOfLine,
            getStartPositionOfRange: () => getStartPositionOfRange,
            getStartsOnNewLine: () => getStartsOnNewLine,
            getStaticPropertiesAndClassStaticBlock: () => getStaticPropertiesAndClassStaticBlock,
            getStrictOptionValue: () => getStrictOptionValue,
            getStringComparer: () => getStringComparer,
            getSubPatternFromSpec: () => getSubPatternFromSpec,
            getSuperCallFromStatement: () => getSuperCallFromStatement,
            getSuperContainer: () => getSuperContainer,
            getSupportedCodeFixes: () => getSupportedCodeFixes,
            getSupportedExtensions: () => getSupportedExtensions,
            getSupportedExtensionsWithJsonIfResolveJsonModule: () => getSupportedExtensionsWithJsonIfResolveJsonModule,
            getSwitchedType: () => getSwitchedType,
            getSymbolId: () => getSymbolId,
            getSymbolNameForPrivateIdentifier: () => getSymbolNameForPrivateIdentifier,
            getSymbolTarget: () => getSymbolTarget,
            getSyntacticClassifications: () => getSyntacticClassifications,
            getSyntacticModifierFlags: () => getSyntacticModifierFlags,
            getSyntacticModifierFlagsNoCache: () => getSyntacticModifierFlagsNoCache,
            getSynthesizedDeepClone: () => getSynthesizedDeepClone,
            getSynthesizedDeepCloneWithReplacements: () => getSynthesizedDeepCloneWithReplacements,
            getSynthesizedDeepClones: () => getSynthesizedDeepClones,
            getSynthesizedDeepClonesWithReplacements: () => getSynthesizedDeepClonesWithReplacements,
            getSyntheticLeadingComments: () => getSyntheticLeadingComments,
            getSyntheticTrailingComments: () => getSyntheticTrailingComments,
            getTargetLabel: () => getTargetLabel,
            getTargetOfBindingOrAssignmentElement: () => getTargetOfBindingOrAssignmentElement,
            getTemporaryModuleResolutionState: () => getTemporaryModuleResolutionState,
            getTextOfConstantValue: () => getTextOfConstantValue,
            getTextOfIdentifierOrLiteral: () => getTextOfIdentifierOrLiteral,
            getTextOfJSDocComment: () => getTextOfJSDocComment,
            getTextOfJsxAttributeName: () => getTextOfJsxAttributeName,
            getTextOfJsxNamespacedName: () => getTextOfJsxNamespacedName,
            getTextOfNode: () => getTextOfNode,
            getTextOfNodeFromSourceText: () => getTextOfNodeFromSourceText,
            getTextOfPropertyName: () => getTextOfPropertyName,
            getThisContainer: () => getThisContainer,
            getThisParameter: () => getThisParameter,
            getTokenAtPosition: () => getTokenAtPosition,
            getTokenPosOfNode: () => getTokenPosOfNode,
            getTokenSourceMapRange: () => getTokenSourceMapRange,
            getTouchingPropertyName: () => getTouchingPropertyName,
            getTouchingToken: () => getTouchingToken,
            getTrailingCommentRanges: () => getTrailingCommentRanges,
            getTrailingSemicolonDeferringWriter: () => getTrailingSemicolonDeferringWriter,
            getTransformFlagsSubtreeExclusions: () => getTransformFlagsSubtreeExclusions,
            getTransformers: () => getTransformers,
            getTsBuildInfoEmitOutputFilePath: () => getTsBuildInfoEmitOutputFilePath,
            getTsConfigObjectLiteralExpression: () => getTsConfigObjectLiteralExpression,
            getTsConfigPropArrayElementValue: () => getTsConfigPropArrayElementValue,
            getTypeAnnotationNode: () => getTypeAnnotationNode,
            getTypeArgumentOrTypeParameterList: () => getTypeArgumentOrTypeParameterList,
            getTypeKeywordOfTypeOnlyImport: () => getTypeKeywordOfTypeOnlyImport,
            getTypeNode: () => getTypeNode,
            getTypeNodeIfAccessible: () => getTypeNodeIfAccessible,
            getTypeParameterFromJsDoc: () => getTypeParameterFromJsDoc,
            getTypeParameterOwner: () => getTypeParameterOwner,
            getTypesPackageName: () => getTypesPackageName,
            getUILocale: () => getUILocale,
            getUniqueName: () => getUniqueName,
            getUniqueSymbolId: () => getUniqueSymbolId,
            getUseDefineForClassFields: () => getUseDefineForClassFields,
            getWatchErrorSummaryDiagnosticMessage: () => getWatchErrorSummaryDiagnosticMessage,
            getWatchFactory: () => getWatchFactory,
            group: () => group,
            groupBy: () => groupBy,
            guessIndentation: () => guessIndentation,
            handleNoEmitOptions: () => handleNoEmitOptions,
            hasAbstractModifier: () => hasAbstractModifier,
            hasAccessorModifier: () => hasAccessorModifier,
            hasAmbientModifier: () => hasAmbientModifier,
            hasChangesInResolutions: () => hasChangesInResolutions,
            hasChildOfKind: () => hasChildOfKind,
            hasContextSensitiveParameters: () => hasContextSensitiveParameters,
            hasDecorators: () => hasDecorators,
            hasDocComment: () => hasDocComment,
            hasDynamicName: () => hasDynamicName,
            hasEffectiveModifier: () => hasEffectiveModifier,
            hasEffectiveModifiers: () => hasEffectiveModifiers,
            hasEffectiveReadonlyModifier: () => hasEffectiveReadonlyModifier,
            hasExtension: () => hasExtension,
            hasIndexSignature: () => hasIndexSignature,
            hasInitializer: () => hasInitializer,
            hasInvalidEscape: () => hasInvalidEscape,
            hasJSDocNodes: () => hasJSDocNodes,
            hasJSDocParameterTags: () => hasJSDocParameterTags,
            hasJSFileExtension: () => hasJSFileExtension,
            hasJsonModuleEmitEnabled: () => hasJsonModuleEmitEnabled,
            hasOnlyExpressionInitializer: () => hasOnlyExpressionInitializer,
            hasOverrideModifier: () => hasOverrideModifier,
            hasPossibleExternalModuleReference: () => hasPossibleExternalModuleReference,
            hasProperty: () => hasProperty,
            hasPropertyAccessExpressionWithName: () => hasPropertyAccessExpressionWithName,
            hasQuestionToken: () => hasQuestionToken,
            hasRecordedExternalHelpers: () => hasRecordedExternalHelpers,
            hasResolutionModeOverride: () => hasResolutionModeOverride,
            hasRestParameter: () => hasRestParameter,
            hasScopeMarker: () => hasScopeMarker,
            hasStaticModifier: () => hasStaticModifier,
            hasSyntacticModifier: () => hasSyntacticModifier,
            hasSyntacticModifiers: () => hasSyntacticModifiers,
            hasTSFileExtension: () => hasTSFileExtension,
            hasTabstop: () => hasTabstop,
            hasTrailingDirectorySeparator: () => hasTrailingDirectorySeparator,
            hasType: () => hasType,
            hasTypeArguments: () => hasTypeArguments,
            hasZeroOrOneAsteriskCharacter: () => hasZeroOrOneAsteriskCharacter,
            helperString: () => helperString,
            hostGetCanonicalFileName: () => hostGetCanonicalFileName,
            hostUsesCaseSensitiveFileNames: () => hostUsesCaseSensitiveFileNames,
            idText: () => idText,
            identifierIsThisKeyword: () => identifierIsThisKeyword,
            identifierToKeywordKind: () => identifierToKeywordKind,
            identity: () => identity,
            identitySourceMapConsumer: () => identitySourceMapConsumer,
            ignoreSourceNewlines: () => ignoreSourceNewlines,
            ignoredPaths: () => ignoredPaths,
            importDefaultHelper: () => importDefaultHelper,
            importFromModuleSpecifier: () => importFromModuleSpecifier,
            importNameElisionDisabled: () => importNameElisionDisabled,
            importStarHelper: () => importStarHelper,
            indexOfAnyCharCode: () => indexOfAnyCharCode,
            indexOfNode: () => indexOfNode,
            indicesOf: () => indicesOf,
            inferredTypesContainingFile: () => inferredTypesContainingFile,
            injectClassNamedEvaluationHelperBlockIfMissing: () => injectClassNamedEvaluationHelperBlockIfMissing,
            injectClassThisAssignmentIfMissing: () => injectClassThisAssignmentIfMissing,
            insertImports: () => insertImports,
            insertLeadingStatement: () => insertLeadingStatement,
            insertSorted: () => insertSorted,
            insertStatementAfterCustomPrologue: () => insertStatementAfterCustomPrologue,
            insertStatementAfterStandardPrologue: () => insertStatementAfterStandardPrologue,
            insertStatementsAfterCustomPrologue: () => insertStatementsAfterCustomPrologue,
            insertStatementsAfterStandardPrologue: () => insertStatementsAfterStandardPrologue,
            intersperse: () => intersperse,
            intrinsicTagNameToString: () => intrinsicTagNameToString,
            introducesArgumentsExoticObject: () => introducesArgumentsExoticObject,
            inverseJsxOptionMap: () => inverseJsxOptionMap,
            isAbstractConstructorSymbol: () => isAbstractConstructorSymbol,
            isAbstractModifier: () => isAbstractModifier,
            isAccessExpression: () => isAccessExpression,
            isAccessibilityModifier: () => isAccessibilityModifier,
            isAccessor: () => isAccessor,
            isAccessorModifier: () => isAccessorModifier,
            isAliasSymbolDeclaration: () => isAliasSymbolDeclaration,
            isAliasableExpression: () => isAliasableExpression,
            isAmbientModule: () => isAmbientModule,
            isAmbientPropertyDeclaration: () => isAmbientPropertyDeclaration,
            isAnonymousFunctionDefinition: () => isAnonymousFunctionDefinition,
            isAnyDirectorySeparator: () => isAnyDirectorySeparator,
            isAnyImportOrBareOrAccessedRequire: () => isAnyImportOrBareOrAccessedRequire,
            isAnyImportOrReExport: () => isAnyImportOrReExport,
            isAnyImportSyntax: () => isAnyImportSyntax,
            isAnySupportedFileExtension: () => isAnySupportedFileExtension,
            isApplicableVersionedTypesKey: () => isApplicableVersionedTypesKey,
            isArgumentExpressionOfElementAccess: () => isArgumentExpressionOfElementAccess,
            isArray: () => isArray,
            isArrayBindingElement: () => isArrayBindingElement,
            isArrayBindingOrAssignmentElement: () => isArrayBindingOrAssignmentElement,
            isArrayBindingOrAssignmentPattern: () => isArrayBindingOrAssignmentPattern,
            isArrayBindingPattern: () => isArrayBindingPattern,
            isArrayLiteralExpression: () => isArrayLiteralExpression,
            isArrayLiteralOrObjectLiteralDestructuringPattern: () => isArrayLiteralOrObjectLiteralDestructuringPattern,
            isArrayTypeNode: () => isArrayTypeNode,
            isArrowFunction: () => isArrowFunction,
            isAsExpression: () => isAsExpression,
            isAssertClause: () => isAssertClause,
            isAssertEntry: () => isAssertEntry,
            isAssertionExpression: () => isAssertionExpression,
            isAssertsKeyword: () => isAssertsKeyword,
            isAssignmentDeclaration: () => isAssignmentDeclaration,
            isAssignmentExpression: () => isAssignmentExpression,
            isAssignmentOperator: () => isAssignmentOperator,
            isAssignmentPattern: () => isAssignmentPattern,
            isAssignmentTarget: () => isAssignmentTarget,
            isAsteriskToken: () => isAsteriskToken,
            isAsyncFunction: () => isAsyncFunction,
            isAsyncModifier: () => isAsyncModifier,
            isAutoAccessorPropertyDeclaration: () => isAutoAccessorPropertyDeclaration,
            isAwaitExpression: () => isAwaitExpression,
            isAwaitKeyword: () => isAwaitKeyword,
            isBigIntLiteral: () => isBigIntLiteral,
            isBinaryExpression: () => isBinaryExpression,
            isBinaryOperatorToken: () => isBinaryOperatorToken,
            isBindableObjectDefinePropertyCall: () => isBindableObjectDefinePropertyCall,
            isBindableStaticAccessExpression: () => isBindableStaticAccessExpression,
            isBindableStaticElementAccessExpression: () => isBindableStaticElementAccessExpression,
            isBindableStaticNameExpression: () => isBindableStaticNameExpression,
            isBindingElement: () => isBindingElement,
            isBindingElementOfBareOrAccessedRequire: () => isBindingElementOfBareOrAccessedRequire,
            isBindingName: () => isBindingName,
            isBindingOrAssignmentElement: () => isBindingOrAssignmentElement,
            isBindingOrAssignmentPattern: () => isBindingOrAssignmentPattern,
            isBindingPattern: () => isBindingPattern,
            isBlock: () => isBlock,
            isBlockOrCatchScoped: () => isBlockOrCatchScoped,
            isBlockScope: () => isBlockScope,
            isBlockScopedContainerTopLevel: () => isBlockScopedContainerTopLevel,
            isBooleanLiteral: () => isBooleanLiteral,
            isBreakOrContinueStatement: () => isBreakOrContinueStatement,
            isBreakStatement: () => isBreakStatement,
            isBuildInfoFile: () => isBuildInfoFile,
            isBuilderProgram: () => isBuilderProgram2,
            isBundle: () => isBundle,
            isBundleFileTextLike: () => isBundleFileTextLike,
            isCallChain: () => isCallChain,
            isCallExpression: () => isCallExpression,
            isCallExpressionTarget: () => isCallExpressionTarget,
            isCallLikeExpression: () => isCallLikeExpression,
            isCallLikeOrFunctionLikeExpression: () => isCallLikeOrFunctionLikeExpression,
            isCallOrNewExpression: () => isCallOrNewExpression,
            isCallOrNewExpressionTarget: () => isCallOrNewExpressionTarget,
            isCallSignatureDeclaration: () => isCallSignatureDeclaration,
            isCallToHelper: () => isCallToHelper,
            isCaseBlock: () => isCaseBlock,
            isCaseClause: () => isCaseClause,
            isCaseKeyword: () => isCaseKeyword,
            isCaseOrDefaultClause: () => isCaseOrDefaultClause,
            isCatchClause: () => isCatchClause,
            isCatchClauseVariableDeclaration: () => isCatchClauseVariableDeclaration,
            isCatchClauseVariableDeclarationOrBindingElement: () => isCatchClauseVariableDeclarationOrBindingElement,
            isCheckJsEnabledForFile: () => isCheckJsEnabledForFile,
            isChildOfNodeWithKind: () => isChildOfNodeWithKind,
            isCircularBuildOrder: () => isCircularBuildOrder,
            isClassDeclaration: () => isClassDeclaration,
            isClassElement: () => isClassElement,
            isClassExpression: () => isClassExpression,
            isClassInstanceProperty: () => isClassInstanceProperty,
            isClassLike: () => isClassLike,
            isClassMemberModifier: () => isClassMemberModifier,
            isClassNamedEvaluationHelperBlock: () => isClassNamedEvaluationHelperBlock,
            isClassOrTypeElement: () => isClassOrTypeElement,
            isClassStaticBlockDeclaration: () => isClassStaticBlockDeclaration,
            isClassThisAssignmentBlock: () => isClassThisAssignmentBlock,
            isCollapsedRange: () => isCollapsedRange,
            isColonToken: () => isColonToken,
            isCommaExpression: () => isCommaExpression,
            isCommaListExpression: () => isCommaListExpression,
            isCommaSequence: () => isCommaSequence,
            isCommaToken: () => isCommaToken,
            isComment: () => isComment,
            isCommonJsExportPropertyAssignment: () => isCommonJsExportPropertyAssignment,
            isCommonJsExportedExpression: () => isCommonJsExportedExpression,
            isCompoundAssignment: () => isCompoundAssignment,
            isComputedNonLiteralName: () => isComputedNonLiteralName,
            isComputedPropertyName: () => isComputedPropertyName,
            isConciseBody: () => isConciseBody,
            isConditionalExpression: () => isConditionalExpression,
            isConditionalTypeNode: () => isConditionalTypeNode,
            isConstTypeReference: () => isConstTypeReference,
            isConstructSignatureDeclaration: () => isConstructSignatureDeclaration,
            isConstructorDeclaration: () => isConstructorDeclaration,
            isConstructorTypeNode: () => isConstructorTypeNode,
            isContextualKeyword: () => isContextualKeyword,
            isContinueStatement: () => isContinueStatement,
            isCustomPrologue: () => isCustomPrologue,
            isDebuggerStatement: () => isDebuggerStatement,
            isDeclaration: () => isDeclaration,
            isDeclarationBindingElement: () => isDeclarationBindingElement,
            isDeclarationFileName: () => isDeclarationFileName,
            isDeclarationName: () => isDeclarationName,
            isDeclarationNameOfEnumOrNamespace: () => isDeclarationNameOfEnumOrNamespace,
            isDeclarationReadonly: () => isDeclarationReadonly,
            isDeclarationStatement: () => isDeclarationStatement,
            isDeclarationWithTypeParameterChildren: () => isDeclarationWithTypeParameterChildren,
            isDeclarationWithTypeParameters: () => isDeclarationWithTypeParameters,
            isDecorator: () => isDecorator,
            isDecoratorTarget: () => isDecoratorTarget,
            isDefaultClause: () => isDefaultClause,
            isDefaultImport: () => isDefaultImport,
            isDefaultModifier: () => isDefaultModifier,
            isDefaultedExpandoInitializer: () => isDefaultedExpandoInitializer,
            isDeleteExpression: () => isDeleteExpression,
            isDeleteTarget: () => isDeleteTarget,
            isDeprecatedDeclaration: () => isDeprecatedDeclaration,
            isDestructuringAssignment: () => isDestructuringAssignment,
            isDiagnosticWithLocation: () => isDiagnosticWithLocation,
            isDiskPathRoot: () => isDiskPathRoot,
            isDoStatement: () => isDoStatement,
            isDocumentRegistryEntry: () => isDocumentRegistryEntry,
            isDotDotDotToken: () => isDotDotDotToken,
            isDottedName: () => isDottedName,
            isDynamicName: () => isDynamicName,
            isESSymbolIdentifier: () => isESSymbolIdentifier,
            isEffectiveExternalModule: () => isEffectiveExternalModule,
            isEffectiveModuleDeclaration: () => isEffectiveModuleDeclaration,
            isEffectiveStrictModeSourceFile: () => isEffectiveStrictModeSourceFile,
            isElementAccessChain: () => isElementAccessChain,
            isElementAccessExpression: () => isElementAccessExpression,
            isEmittedFileOfProgram: () => isEmittedFileOfProgram,
            isEmptyArrayLiteral: () => isEmptyArrayLiteral,
            isEmptyBindingElement: () => isEmptyBindingElement,
            isEmptyBindingPattern: () => isEmptyBindingPattern,
            isEmptyObjectLiteral: () => isEmptyObjectLiteral,
            isEmptyStatement: () => isEmptyStatement,
            isEmptyStringLiteral: () => isEmptyStringLiteral,
            isEntityName: () => isEntityName,
            isEntityNameExpression: () => isEntityNameExpression,
            isEnumConst: () => isEnumConst,
            isEnumDeclaration: () => isEnumDeclaration,
            isEnumMember: () => isEnumMember,
            isEqualityOperatorKind: () => isEqualityOperatorKind,
            isEqualsGreaterThanToken: () => isEqualsGreaterThanToken,
            isExclamationToken: () => isExclamationToken,
            isExcludedFile: () => isExcludedFile,
            isExclusivelyTypeOnlyImportOrExport: () => isExclusivelyTypeOnlyImportOrExport,
            isExpandoPropertyDeclaration: () => isExpandoPropertyDeclaration,
            isExportAssignment: () => isExportAssignment,
            isExportDeclaration: () => isExportDeclaration,
            isExportModifier: () => isExportModifier,
            isExportName: () => isExportName,
            isExportNamespaceAsDefaultDeclaration: () => isExportNamespaceAsDefaultDeclaration,
            isExportOrDefaultModifier: () => isExportOrDefaultModifier,
            isExportSpecifier: () => isExportSpecifier,
            isExportsIdentifier: () => isExportsIdentifier,
            isExportsOrModuleExportsOrAlias: () => isExportsOrModuleExportsOrAlias,
            isExpression: () => isExpression,
            isExpressionNode: () => isExpressionNode,
            isExpressionOfExternalModuleImportEqualsDeclaration: () => isExpressionOfExternalModuleImportEqualsDeclaration,
            isExpressionOfOptionalChainRoot: () => isExpressionOfOptionalChainRoot,
            isExpressionStatement: () => isExpressionStatement,
            isExpressionWithTypeArguments: () => isExpressionWithTypeArguments,
            isExpressionWithTypeArgumentsInClassExtendsClause: () => isExpressionWithTypeArgumentsInClassExtendsClause,
            isExternalModule: () => isExternalModule,
            isExternalModuleAugmentation: () => isExternalModuleAugmentation,
            isExternalModuleImportEqualsDeclaration: () => isExternalModuleImportEqualsDeclaration,
            isExternalModuleIndicator: () => isExternalModuleIndicator,
            isExternalModuleNameRelative: () => isExternalModuleNameRelative,
            isExternalModuleReference: () => isExternalModuleReference,
            isExternalModuleSymbol: () => isExternalModuleSymbol,
            isExternalOrCommonJsModule: () => isExternalOrCommonJsModule,
            isFileLevelReservedGeneratedIdentifier: () => isFileLevelReservedGeneratedIdentifier,
            isFileLevelUniqueName: () => isFileLevelUniqueName,
            isFileProbablyExternalModule: () => isFileProbablyExternalModule,
            isFirstDeclarationOfSymbolParameter: () => isFirstDeclarationOfSymbolParameter,
            isFixablePromiseHandler: () => isFixablePromiseHandler,
            isForInOrOfStatement: () => isForInOrOfStatement,
            isForInStatement: () => isForInStatement,
            isForInitializer: () => isForInitializer,
            isForOfStatement: () => isForOfStatement,
            isForStatement: () => isForStatement,
            isFunctionBlock: () => isFunctionBlock,
            isFunctionBody: () => isFunctionBody,
            isFunctionDeclaration: () => isFunctionDeclaration,
            isFunctionExpression: () => isFunctionExpression,
            isFunctionExpressionOrArrowFunction: () => isFunctionExpressionOrArrowFunction,
            isFunctionLike: () => isFunctionLike,
            isFunctionLikeDeclaration: () => isFunctionLikeDeclaration,
            isFunctionLikeKind: () => isFunctionLikeKind,
            isFunctionLikeOrClassStaticBlockDeclaration: () => isFunctionLikeOrClassStaticBlockDeclaration,
            isFunctionOrConstructorTypeNode: () => isFunctionOrConstructorTypeNode,
            isFunctionOrModuleBlock: () => isFunctionOrModuleBlock,
            isFunctionSymbol: () => isFunctionSymbol,
            isFunctionTypeNode: () => isFunctionTypeNode,
            isFutureReservedKeyword: () => isFutureReservedKeyword,
            isGeneratedIdentifier: () => isGeneratedIdentifier,
            isGeneratedPrivateIdentifier: () => isGeneratedPrivateIdentifier,
            isGetAccessor: () => isGetAccessor,
            isGetAccessorDeclaration: () => isGetAccessorDeclaration,
            isGetOrSetAccessorDeclaration: () => isGetOrSetAccessorDeclaration,
            isGlobalDeclaration: () => isGlobalDeclaration,
            isGlobalScopeAugmentation: () => isGlobalScopeAugmentation,
            isGrammarError: () => isGrammarError,
            isHeritageClause: () => isHeritageClause,
            isHoistedFunction: () => isHoistedFunction,
            isHoistedVariableStatement: () => isHoistedVariableStatement,
            isIdentifier: () => isIdentifier,
            isIdentifierANonContextualKeyword: () => isIdentifierANonContextualKeyword,
            isIdentifierName: () => isIdentifierName,
            isIdentifierOrThisTypeNode: () => isIdentifierOrThisTypeNode,
            isIdentifierPart: () => isIdentifierPart,
            isIdentifierStart: () => isIdentifierStart,
            isIdentifierText: () => isIdentifierText,
            isIdentifierTypePredicate: () => isIdentifierTypePredicate,
            isIdentifierTypeReference: () => isIdentifierTypeReference,
            isIfStatement: () => isIfStatement,
            isIgnoredFileFromWildCardWatching: () => isIgnoredFileFromWildCardWatching,
            isImplicitGlob: () => isImplicitGlob,
            isImportAttribute: () => isImportAttribute,
            isImportAttributeName: () => isImportAttributeName,
            isImportAttributes: () => isImportAttributes,
            isImportCall: () => isImportCall,
            isImportClause: () => isImportClause,
            isImportDeclaration: () => isImportDeclaration,
            isImportEqualsDeclaration: () => isImportEqualsDeclaration,
            isImportKeyword: () => isImportKeyword,
            isImportMeta: () => isImportMeta,
            isImportOrExportSpecifier: () => isImportOrExportSpecifier,
            isImportOrExportSpecifierName: () => isImportOrExportSpecifierName,
            isImportSpecifier: () => isImportSpecifier,
            isImportTypeAssertionContainer: () => isImportTypeAssertionContainer,
            isImportTypeNode: () => isImportTypeNode,
            isImportableFile: () => isImportableFile,
            isInComment: () => isInComment,
            isInCompoundLikeAssignment: () => isInCompoundLikeAssignment,
            isInExpressionContext: () => isInExpressionContext,
            isInJSDoc: () => isInJSDoc,
            isInJSFile: () => isInJSFile,
            isInJSXText: () => isInJSXText,
            isInJsonFile: () => isInJsonFile,
            isInNonReferenceComment: () => isInNonReferenceComment,
            isInReferenceComment: () => isInReferenceComment,
            isInRightSideOfInternalImportEqualsDeclaration: () => isInRightSideOfInternalImportEqualsDeclaration,
            isInString: () => isInString,
            isInTemplateString: () => isInTemplateString,
            isInTopLevelContext: () => isInTopLevelContext,
            isInTypeQuery: () => isInTypeQuery,
            isIncrementalCompilation: () => isIncrementalCompilation,
            isIndexSignatureDeclaration: () => isIndexSignatureDeclaration,
            isIndexedAccessTypeNode: () => isIndexedAccessTypeNode,
            isInferTypeNode: () => isInferTypeNode,
            isInfinityOrNaNString: () => isInfinityOrNaNString,
            isInitializedProperty: () => isInitializedProperty,
            isInitializedVariable: () => isInitializedVariable,
            isInsideJsxElement: () => isInsideJsxElement,
            isInsideJsxElementOrAttribute: () => isInsideJsxElementOrAttribute,
            isInsideNodeModules: () => isInsideNodeModules,
            isInsideTemplateLiteral: () => isInsideTemplateLiteral,
            isInstanceOfExpression: () => isInstanceOfExpression,
            isInstantiatedModule: () => isInstantiatedModule,
            isInterfaceDeclaration: () => isInterfaceDeclaration,
            isInternalDeclaration: () => isInternalDeclaration,
            isInternalModuleImportEqualsDeclaration: () => isInternalModuleImportEqualsDeclaration,
            isInternalName: () => isInternalName,
            isIntersectionTypeNode: () => isIntersectionTypeNode,
            isIntrinsicJsxName: () => isIntrinsicJsxName,
            isIterationStatement: () => isIterationStatement,
            isJSDoc: () => isJSDoc,
            isJSDocAllType: () => isJSDocAllType,
            isJSDocAugmentsTag: () => isJSDocAugmentsTag,
            isJSDocAuthorTag: () => isJSDocAuthorTag,
            isJSDocCallbackTag: () => isJSDocCallbackTag,
            isJSDocClassTag: () => isJSDocClassTag,
            isJSDocCommentContainingNode: () => isJSDocCommentContainingNode,
            isJSDocConstructSignature: () => isJSDocConstructSignature,
            isJSDocDeprecatedTag: () => isJSDocDeprecatedTag,
            isJSDocEnumTag: () => isJSDocEnumTag,
            isJSDocFunctionType: () => isJSDocFunctionType,
            isJSDocImplementsTag: () => isJSDocImplementsTag,
            isJSDocIndexSignature: () => isJSDocIndexSignature,
            isJSDocLikeText: () => isJSDocLikeText,
            isJSDocLink: () => isJSDocLink,
            isJSDocLinkCode: () => isJSDocLinkCode,
            isJSDocLinkLike: () => isJSDocLinkLike,
            isJSDocLinkPlain: () => isJSDocLinkPlain,
            isJSDocMemberName: () => isJSDocMemberName,
            isJSDocNameReference: () => isJSDocNameReference,
            isJSDocNamepathType: () => isJSDocNamepathType,
            isJSDocNamespaceBody: () => isJSDocNamespaceBody,
            isJSDocNode: () => isJSDocNode,
            isJSDocNonNullableType: () => isJSDocNonNullableType,
            isJSDocNullableType: () => isJSDocNullableType,
            isJSDocOptionalParameter: () => isJSDocOptionalParameter,
            isJSDocOptionalType: () => isJSDocOptionalType,
            isJSDocOverloadTag: () => isJSDocOverloadTag,
            isJSDocOverrideTag: () => isJSDocOverrideTag,
            isJSDocParameterTag: () => isJSDocParameterTag,
            isJSDocPrivateTag: () => isJSDocPrivateTag,
            isJSDocPropertyLikeTag: () => isJSDocPropertyLikeTag,
            isJSDocPropertyTag: () => isJSDocPropertyTag,
            isJSDocProtectedTag: () => isJSDocProtectedTag,
            isJSDocPublicTag: () => isJSDocPublicTag,
            isJSDocReadonlyTag: () => isJSDocReadonlyTag,
            isJSDocReturnTag: () => isJSDocReturnTag,
            isJSDocSatisfiesExpression: () => isJSDocSatisfiesExpression,
            isJSDocSatisfiesTag: () => isJSDocSatisfiesTag,
            isJSDocSeeTag: () => isJSDocSeeTag,
            isJSDocSignature: () => isJSDocSignature,
            isJSDocTag: () => isJSDocTag,
            isJSDocTemplateTag: () => isJSDocTemplateTag,
            isJSDocThisTag: () => isJSDocThisTag,
            isJSDocThrowsTag: () => isJSDocThrowsTag,
            isJSDocTypeAlias: () => isJSDocTypeAlias,
            isJSDocTypeAssertion: () => isJSDocTypeAssertion,
            isJSDocTypeExpression: () => isJSDocTypeExpression,
            isJSDocTypeLiteral: () => isJSDocTypeLiteral,
            isJSDocTypeTag: () => isJSDocTypeTag,
            isJSDocTypedefTag: () => isJSDocTypedefTag,
            isJSDocUnknownTag: () => isJSDocUnknownTag,
            isJSDocUnknownType: () => isJSDocUnknownType,
            isJSDocVariadicType: () => isJSDocVariadicType,
            isJSXTagName: () => isJSXTagName,
            isJsonEqual: () => isJsonEqual,
            isJsonSourceFile: () => isJsonSourceFile,
            isJsxAttribute: () => isJsxAttribute,
            isJsxAttributeLike: () => isJsxAttributeLike,
            isJsxAttributeName: () => isJsxAttributeName,
            isJsxAttributes: () => isJsxAttributes,
            isJsxChild: () => isJsxChild,
            isJsxClosingElement: () => isJsxClosingElement,
            isJsxClosingFragment: () => isJsxClosingFragment,
            isJsxElement: () => isJsxElement,
            isJsxExpression: () => isJsxExpression,
            isJsxFragment: () => isJsxFragment,
            isJsxNamespacedName: () => isJsxNamespacedName,
            isJsxOpeningElement: () => isJsxOpeningElement,
            isJsxOpeningFragment: () => isJsxOpeningFragment,
            isJsxOpeningLikeElement: () => isJsxOpeningLikeElement,
            isJsxOpeningLikeElementTagName: () => isJsxOpeningLikeElementTagName,
            isJsxSelfClosingElement: () => isJsxSelfClosingElement,
            isJsxSpreadAttribute: () => isJsxSpreadAttribute,
            isJsxTagNameExpression: () => isJsxTagNameExpression,
            isJsxText: () => isJsxText,
            isJumpStatementTarget: () => isJumpStatementTarget,
            isKeyword: () => isKeyword,
            isKeywordOrPunctuation: () => isKeywordOrPunctuation,
            isKnownSymbol: () => isKnownSymbol,
            isLabelName: () => isLabelName,
            isLabelOfLabeledStatement: () => isLabelOfLabeledStatement,
            isLabeledStatement: () => isLabeledStatement,
            isLateVisibilityPaintedStatement: () => isLateVisibilityPaintedStatement,
            isLeftHandSideExpression: () => isLeftHandSideExpression,
            isLeftHandSideOfAssignment: () => isLeftHandSideOfAssignment,
            isLet: () => isLet,
            isLineBreak: () => isLineBreak,
            isLiteralComputedPropertyDeclarationName: () => isLiteralComputedPropertyDeclarationName,
            isLiteralExpression: () => isLiteralExpression,
            isLiteralExpressionOfObject: () => isLiteralExpressionOfObject,
            isLiteralImportTypeNode: () => isLiteralImportTypeNode,
            isLiteralKind: () => isLiteralKind,
            isLiteralLikeAccess: () => isLiteralLikeAccess,
            isLiteralLikeElementAccess: () => isLiteralLikeElementAccess,
            isLiteralNameOfPropertyDeclarationOrIndexAccess: () => isLiteralNameOfPropertyDeclarationOrIndexAccess,
            isLiteralTypeLikeExpression: () => isLiteralTypeLikeExpression,
            isLiteralTypeLiteral: () => isLiteralTypeLiteral,
            isLiteralTypeNode: () => isLiteralTypeNode,
            isLocalName: () => isLocalName,
            isLogicalOperator: () => isLogicalOperator,
            isLogicalOrCoalescingAssignmentExpression: () => isLogicalOrCoalescingAssignmentExpression,
            isLogicalOrCoalescingAssignmentOperator: () => isLogicalOrCoalescingAssignmentOperator,
            isLogicalOrCoalescingBinaryExpression: () => isLogicalOrCoalescingBinaryExpression,
            isLogicalOrCoalescingBinaryOperator: () => isLogicalOrCoalescingBinaryOperator,
            isMappedTypeNode: () => isMappedTypeNode,
            isMemberName: () => isMemberName,
            isMetaProperty: () => isMetaProperty,
            isMethodDeclaration: () => isMethodDeclaration,
            isMethodOrAccessor: () => isMethodOrAccessor,
            isMethodSignature: () => isMethodSignature,
            isMinusToken: () => isMinusToken,
            isMissingDeclaration: () => isMissingDeclaration,
            isMissingPackageJsonInfo: () => isMissingPackageJsonInfo,
            isModifier: () => isModifier,
            isModifierKind: () => isModifierKind,
            isModifierLike: () => isModifierLike,
            isModuleAugmentationExternal: () => isModuleAugmentationExternal,
            isModuleBlock: () => isModuleBlock,
            isModuleBody: () => isModuleBody,
            isModuleDeclaration: () => isModuleDeclaration,
            isModuleExportsAccessExpression: () => isModuleExportsAccessExpression,
            isModuleIdentifier: () => isModuleIdentifier,
            isModuleName: () => isModuleName,
            isModuleOrEnumDeclaration: () => isModuleOrEnumDeclaration,
            isModuleReference: () => isModuleReference,
            isModuleSpecifierLike: () => isModuleSpecifierLike,
            isModuleWithStringLiteralName: () => isModuleWithStringLiteralName,
            isNameOfFunctionDeclaration: () => isNameOfFunctionDeclaration,
            isNameOfModuleDeclaration: () => isNameOfModuleDeclaration,
            isNamedClassElement: () => isNamedClassElement,
            isNamedDeclaration: () => isNamedDeclaration,
            isNamedEvaluation: () => isNamedEvaluation,
            isNamedEvaluationSource: () => isNamedEvaluationSource,
            isNamedExportBindings: () => isNamedExportBindings,
            isNamedExports: () => isNamedExports,
            isNamedImportBindings: () => isNamedImportBindings,
            isNamedImports: () => isNamedImports,
            isNamedImportsOrExports: () => isNamedImportsOrExports,
            isNamedTupleMember: () => isNamedTupleMember,
            isNamespaceBody: () => isNamespaceBody,
            isNamespaceExport: () => isNamespaceExport,
            isNamespaceExportDeclaration: () => isNamespaceExportDeclaration,
            isNamespaceImport: () => isNamespaceImport,
            isNamespaceReexportDeclaration: () => isNamespaceReexportDeclaration,
            isNewExpression: () => isNewExpression,
            isNewExpressionTarget: () => isNewExpressionTarget,
            isNoSubstitutionTemplateLiteral: () => isNoSubstitutionTemplateLiteral,
            isNode: () => isNode,
            isNodeArray: () => isNodeArray,
            isNodeArrayMultiLine: () => isNodeArrayMultiLine,
            isNodeDescendantOf: () => isNodeDescendantOf,
            isNodeKind: () => isNodeKind,
            isNodeLikeSystem: () => isNodeLikeSystem,
            isNodeModulesDirectory: () => isNodeModulesDirectory,
            isNodeWithPossibleHoistedDeclaration: () => isNodeWithPossibleHoistedDeclaration,
            isNonContextualKeyword: () => isNonContextualKeyword,
            isNonExportDefaultModifier: () => isNonExportDefaultModifier,
            isNonGlobalAmbientModule: () => isNonGlobalAmbientModule,
            isNonGlobalDeclaration: () => isNonGlobalDeclaration,
            isNonNullAccess: () => isNonNullAccess,
            isNonNullChain: () => isNonNullChain,
            isNonNullExpression: () => isNonNullExpression,
            isNonStaticMethodOrAccessorWithPrivateName: () => isNonStaticMethodOrAccessorWithPrivateName,
            isNotEmittedOrPartiallyEmittedNode: () => isNotEmittedOrPartiallyEmittedNode,
            isNotEmittedStatement: () => isNotEmittedStatement,
            isNullishCoalesce: () => isNullishCoalesce,
            isNumber: () => isNumber,
            isNumericLiteral: () => isNumericLiteral,
            isNumericLiteralName: () => isNumericLiteralName,
            isObjectBindingElementWithoutPropertyName: () => isObjectBindingElementWithoutPropertyName,
            isObjectBindingOrAssignmentElement: () => isObjectBindingOrAssignmentElement,
            isObjectBindingOrAssignmentPattern: () => isObjectBindingOrAssignmentPattern,
            isObjectBindingPattern: () => isObjectBindingPattern,
            isObjectLiteralElement: () => isObjectLiteralElement,
            isObjectLiteralElementLike: () => isObjectLiteralElementLike,
            isObjectLiteralExpression: () => isObjectLiteralExpression,
            isObjectLiteralMethod: () => isObjectLiteralMethod,
            isObjectLiteralOrClassExpressionMethodOrAccessor: () => isObjectLiteralOrClassExpressionMethodOrAccessor,
            isObjectTypeDeclaration: () => isObjectTypeDeclaration,
            isOctalDigit: () => isOctalDigit,
            isOmittedExpression: () => isOmittedExpression,
            isOptionalChain: () => isOptionalChain,
            isOptionalChainRoot: () => isOptionalChainRoot,
            isOptionalDeclaration: () => isOptionalDeclaration,
            isOptionalJSDocPropertyLikeTag: () => isOptionalJSDocPropertyLikeTag,
            isOptionalTypeNode: () => isOptionalTypeNode,
            isOuterExpression: () => isOuterExpression,
            isOutermostOptionalChain: () => isOutermostOptionalChain,
            isOverrideModifier: () => isOverrideModifier,
            isPackageJsonInfo: () => isPackageJsonInfo,
            isPackedArrayLiteral: () => isPackedArrayLiteral,
            isParameter: () => isParameter,
            isParameterDeclaration: () => isParameterDeclaration,
            isParameterPropertyDeclaration: () => isParameterPropertyDeclaration,
            isParameterPropertyModifier: () => isParameterPropertyModifier,
            isParenthesizedExpression: () => isParenthesizedExpression,
            isParenthesizedTypeNode: () => isParenthesizedTypeNode,
            isParseTreeNode: () => isParseTreeNode,
            isPartOfTypeNode: () => isPartOfTypeNode,
            isPartOfTypeQuery: () => isPartOfTypeQuery,
            isPartiallyEmittedExpression: () => isPartiallyEmittedExpression,
            isPatternMatch: () => isPatternMatch,
            isPinnedComment: () => isPinnedComment,
            isPlainJsFile: () => isPlainJsFile,
            isPlusToken: () => isPlusToken,
            isPossiblyTypeArgumentPosition: () => isPossiblyTypeArgumentPosition,
            isPostfixUnaryExpression: () => isPostfixUnaryExpression,
            isPrefixUnaryExpression: () => isPrefixUnaryExpression,
            isPrivateIdentifier: () => isPrivateIdentifier,
            isPrivateIdentifierClassElementDeclaration: () => isPrivateIdentifierClassElementDeclaration,
            isPrivateIdentifierPropertyAccessExpression: () => isPrivateIdentifierPropertyAccessExpression,
            isPrivateIdentifierSymbol: () => isPrivateIdentifierSymbol,
            isProgramBundleEmitBuildInfo: () => isProgramBundleEmitBuildInfo,
            isProgramUptoDate: () => isProgramUptoDate,
            isPrologueDirective: () => isPrologueDirective,
            isPropertyAccessChain: () => isPropertyAccessChain,
            isPropertyAccessEntityNameExpression: () => isPropertyAccessEntityNameExpression,
            isPropertyAccessExpression: () => isPropertyAccessExpression,
            isPropertyAccessOrQualifiedName: () => isPropertyAccessOrQualifiedName,
            isPropertyAccessOrQualifiedNameOrImportTypeNode: () => isPropertyAccessOrQualifiedNameOrImportTypeNode,
            isPropertyAssignment: () => isPropertyAssignment,
            isPropertyDeclaration: () => isPropertyDeclaration,
            isPropertyName: () => isPropertyName,
            isPropertyNameLiteral: () => isPropertyNameLiteral,
            isPropertySignature: () => isPropertySignature,
            isProtoSetter: () => isProtoSetter,
            isPrototypeAccess: () => isPrototypeAccess,
            isPrototypePropertyAssignment: () => isPrototypePropertyAssignment,
            isPunctuation: () => isPunctuation,
            isPushOrUnshiftIdentifier: () => isPushOrUnshiftIdentifier,
            isQualifiedName: () => isQualifiedName,
            isQuestionDotToken: () => isQuestionDotToken,
            isQuestionOrExclamationToken: () => isQuestionOrExclamationToken,
            isQuestionOrPlusOrMinusToken: () => isQuestionOrPlusOrMinusToken,
            isQuestionToken: () => isQuestionToken,
            isRawSourceMap: () => isRawSourceMap,
            isReadonlyKeyword: () => isReadonlyKeyword,
            isReadonlyKeywordOrPlusOrMinusToken: () => isReadonlyKeywordOrPlusOrMinusToken,
            isRecognizedTripleSlashComment: () => isRecognizedTripleSlashComment,
            isReferenceFileLocation: () => isReferenceFileLocation,
            isReferencedFile: () => isReferencedFile,
            isRegularExpressionLiteral: () => isRegularExpressionLiteral,
            isRequireCall: () => isRequireCall,
            isRequireVariableStatement: () => isRequireVariableStatement,
            isRestParameter: () => isRestParameter,
            isRestTypeNode: () => isRestTypeNode,
            isReturnStatement: () => isReturnStatement,
            isReturnStatementWithFixablePromiseHandler: () => isReturnStatementWithFixablePromiseHandler,
            isRightSideOfAccessExpression: () => isRightSideOfAccessExpression,
            isRightSideOfInstanceofExpression: () => isRightSideOfInstanceofExpression,
            isRightSideOfPropertyAccess: () => isRightSideOfPropertyAccess,
            isRightSideOfQualifiedName: () => isRightSideOfQualifiedName,
            isRightSideOfQualifiedNameOrPropertyAccess: () => isRightSideOfQualifiedNameOrPropertyAccess,
            isRightSideOfQualifiedNameOrPropertyAccessOrJSDocMemberName: () => isRightSideOfQualifiedNameOrPropertyAccessOrJSDocMemberName,
            isRootedDiskPath: () => isRootedDiskPath,
            isSameEntityName: () => isSameEntityName,
            isSatisfiesExpression: () => isSatisfiesExpression,
            isScopeMarker: () => isScopeMarker,
            isSemicolonClassElement: () => isSemicolonClassElement,
            isSetAccessor: () => isSetAccessor,
            isSetAccessorDeclaration: () => isSetAccessorDeclaration,
            isShebangTrivia: () => isShebangTrivia,
            isShiftOperatorOrHigher: () => isShiftOperatorOrHigher,
            isShorthandAmbientModuleSymbol: () => isShorthandAmbientModuleSymbol,
            isShorthandPropertyAssignment: () => isShorthandPropertyAssignment,
            isSignedNumericLiteral: () => isSignedNumericLiteral,
            isSimpleCopiableExpression: () => isSimpleCopiableExpression,
            isSimpleInlineableExpression: () => isSimpleInlineableExpression,
            isSimpleParameter: () => isSimpleParameter,
            isSimpleParameterList: () => isSimpleParameterList,
            isSingleOrDoubleQuote: () => isSingleOrDoubleQuote,
            isSourceFile: () => isSourceFile,
            isSourceFileFromLibrary: () => isSourceFileFromLibrary,
            isSourceFileJS: () => isSourceFileJS,
            isSourceFileNotJS: () => isSourceFileNotJS,
            isSourceFileNotJson: () => isSourceFileNotJson,
            isSourceMapping: () => isSourceMapping,
            isSpecialPropertyDeclaration: () => isSpecialPropertyDeclaration,
            isSpreadAssignment: () => isSpreadAssignment,
            isSpreadElement: () => isSpreadElement,
            isStatement: () => isStatement,
            isStatementButNotDeclaration: () => isStatementButNotDeclaration,
            isStatementOrBlock: () => isStatementOrBlock,
            isStatementWithLocals: () => isStatementWithLocals,
            isStatic: () => isStatic,
            isStaticModifier: () => isStaticModifier,
            isString: () => isString,
            isStringAKeyword: () => isStringAKeyword,
            isStringANonContextualKeyword: () => isStringANonContextualKeyword,
            isStringAndEmptyAnonymousObjectIntersection: () => isStringAndEmptyAnonymousObjectIntersection,
            isStringDoubleQuoted: () => isStringDoubleQuoted,
            isStringLiteral: () => isStringLiteral,
            isStringLiteralLike: () => isStringLiteralLike,
            isStringLiteralOrJsxExpression: () => isStringLiteralOrJsxExpression,
            isStringLiteralOrTemplate: () => isStringLiteralOrTemplate,
            isStringOrNumericLiteralLike: () => isStringOrNumericLiteralLike,
            isStringOrRegularExpressionOrTemplateLiteral: () => isStringOrRegularExpressionOrTemplateLiteral,
            isStringTextContainingNode: () => isStringTextContainingNode,
            isSuperCall: () => isSuperCall,
            isSuperKeyword: () => isSuperKeyword,
            isSuperOrSuperProperty: () => isSuperOrSuperProperty,
            isSuperProperty: () => isSuperProperty,
            isSupportedSourceFileName: () => isSupportedSourceFileName,
            isSwitchStatement: () => isSwitchStatement,
            isSyntaxList: () => isSyntaxList,
            isSyntheticExpression: () => isSyntheticExpression,
            isSyntheticReference: () => isSyntheticReference,
            isTagName: () => isTagName,
            isTaggedTemplateExpression: () => isTaggedTemplateExpression,
            isTaggedTemplateTag: () => isTaggedTemplateTag,
            isTemplateExpression: () => isTemplateExpression,
            isTemplateHead: () => isTemplateHead,
            isTemplateLiteral: () => isTemplateLiteral,
            isTemplateLiteralKind: () => isTemplateLiteralKind,
            isTemplateLiteralToken: () => isTemplateLiteralToken,
            isTemplateLiteralTypeNode: () => isTemplateLiteralTypeNode,
            isTemplateLiteralTypeSpan: () => isTemplateLiteralTypeSpan,
            isTemplateMiddle: () => isTemplateMiddle,
            isTemplateMiddleOrTemplateTail: () => isTemplateMiddleOrTemplateTail,
            isTemplateSpan: () => isTemplateSpan,
            isTemplateTail: () => isTemplateTail,
            isTextWhiteSpaceLike: () => isTextWhiteSpaceLike,
            isThis: () => isThis,
            isThisContainerOrFunctionBlock: () => isThisContainerOrFunctionBlock,
            isThisIdentifier: () => isThisIdentifier,
            isThisInTypeQuery: () => isThisInTypeQuery,
            isThisInitializedDeclaration: () => isThisInitializedDeclaration,
            isThisInitializedObjectBindingExpression: () => isThisInitializedObjectBindingExpression,
            isThisProperty: () => isThisProperty,
            isThisTypeNode: () => isThisTypeNode,
            isThisTypeParameter: () => isThisTypeParameter,
            isThisTypePredicate: () => isThisTypePredicate,
            isThrowStatement: () => isThrowStatement,
            isToken: () => isToken,
            isTokenKind: () => isTokenKind,
            isTraceEnabled: () => isTraceEnabled,
            isTransientSymbol: () => isTransientSymbol,
            isTrivia: () => isTrivia,
            isTryStatement: () => isTryStatement,
            isTupleTypeNode: () => isTupleTypeNode,
            isTypeAlias: () => isTypeAlias,
            isTypeAliasDeclaration: () => isTypeAliasDeclaration,
            isTypeAssertionExpression: () => isTypeAssertionExpression,
            isTypeDeclaration: () => isTypeDeclaration,
            isTypeElement: () => isTypeElement,
            isTypeKeyword: () => isTypeKeyword,
            isTypeKeywordToken: () => isTypeKeywordToken,
            isTypeKeywordTokenOrIdentifier: () => isTypeKeywordTokenOrIdentifier,
            isTypeLiteralNode: () => isTypeLiteralNode,
            isTypeNode: () => isTypeNode,
            isTypeNodeKind: () => isTypeNodeKind,
            isTypeOfExpression: () => isTypeOfExpression,
            isTypeOnlyExportDeclaration: () => isTypeOnlyExportDeclaration,
            isTypeOnlyImportDeclaration: () => isTypeOnlyImportDeclaration,
            isTypeOnlyImportOrExportDeclaration: () => isTypeOnlyImportOrExportDeclaration,
            isTypeOperatorNode: () => isTypeOperatorNode,
            isTypeParameterDeclaration: () => isTypeParameterDeclaration,
            isTypePredicateNode: () => isTypePredicateNode,
            isTypeQueryNode: () => isTypeQueryNode,
            isTypeReferenceNode: () => isTypeReferenceNode,
            isTypeReferenceType: () => isTypeReferenceType,
            isTypeUsableAsPropertyName: () => isTypeUsableAsPropertyName,
            isUMDExportSymbol: () => isUMDExportSymbol,
            isUnaryExpression: () => isUnaryExpression,
            isUnaryExpressionWithWrite: () => isUnaryExpressionWithWrite,
            isUnicodeIdentifierStart: () => isUnicodeIdentifierStart,
            isUnionTypeNode: () => isUnionTypeNode,
            isUnparsedNode: () => isUnparsedNode,
            isUnparsedPrepend: () => isUnparsedPrepend,
            isUnparsedSource: () => isUnparsedSource,
            isUnparsedTextLike: () => isUnparsedTextLike,
            isUrl: () => isUrl,
            isValidBigIntString: () => isValidBigIntString,
            isValidESSymbolDeclaration: () => isValidESSymbolDeclaration,
            isValidTypeOnlyAliasUseSite: () => isValidTypeOnlyAliasUseSite,
            isValueSignatureDeclaration: () => isValueSignatureDeclaration,
            isVarAwaitUsing: () => isVarAwaitUsing,
            isVarConst: () => isVarConst,
            isVarUsing: () => isVarUsing,
            isVariableDeclaration: () => isVariableDeclaration,
            isVariableDeclarationInVariableStatement: () => isVariableDeclarationInVariableStatement,
            isVariableDeclarationInitializedToBareOrAccessedRequire: () => isVariableDeclarationInitializedToBareOrAccessedRequire,
            isVariableDeclarationInitializedToRequire: () => isVariableDeclarationInitializedToRequire,
            isVariableDeclarationList: () => isVariableDeclarationList,
            isVariableLike: () => isVariableLike,
            isVariableLikeOrAccessor: () => isVariableLikeOrAccessor,
            isVariableStatement: () => isVariableStatement,
            isVoidExpression: () => isVoidExpression,
            isWatchSet: () => isWatchSet,
            isWhileStatement: () => isWhileStatement,
            isWhiteSpaceLike: () => isWhiteSpaceLike,
            isWhiteSpaceSingleLine: () => isWhiteSpaceSingleLine,
            isWithStatement: () => isWithStatement,
            isWriteAccess: () => isWriteAccess,
            isWriteOnlyAccess: () => isWriteOnlyAccess,
            isYieldExpression: () => isYieldExpression,
            jsxModeNeedsExplicitImport: () => jsxModeNeedsExplicitImport,
            keywordPart: () => keywordPart,
            last: () => last,
            lastOrUndefined: () => lastOrUndefined,
            length: () => length,
            libMap: () => libMap,
            libs: () => libs,
            lineBreakPart: () => lineBreakPart,
            linkNamePart: () => linkNamePart,
            linkPart: () => linkPart,
            linkTextPart: () => linkTextPart,
            listFiles: () => listFiles,
            loadModuleFromGlobalCache: () => loadModuleFromGlobalCache,
            loadWithModeAwareCache: () => loadWithModeAwareCache,
            makeIdentifierFromModuleName: () => makeIdentifierFromModuleName,
            makeImport: () => makeImport,
            makeImportIfNecessary: () => makeImportIfNecessary,
            makeStringLiteral: () => makeStringLiteral,
            mangleScopedPackageName: () => mangleScopedPackageName,
            map: () => map,
            mapAllOrFail: () => mapAllOrFail,
            mapDefined: () => mapDefined,
            mapDefinedEntries: () => mapDefinedEntries,
            mapDefinedIterator: () => mapDefinedIterator,
            mapEntries: () => mapEntries,
            mapIterator: () => mapIterator,
            mapOneOrMany: () => mapOneOrMany,
            mapToDisplayParts: () => mapToDisplayParts,
            matchFiles: () => matchFiles,
            matchPatternOrExact: () => matchPatternOrExact,
            matchedText: () => matchedText,
            matchesExclude: () => matchesExclude,
            maybeBind: () => maybeBind,
            maybeSetLocalizedDiagnosticMessages: () => maybeSetLocalizedDiagnosticMessages,
            memoize: () => memoize,
            memoizeCached: () => memoizeCached,
            memoizeOne: () => memoizeOne,
            memoizeWeak: () => memoizeWeak,
            metadataHelper: () => metadataHelper,
            min: () => min,
            minAndMax: () => minAndMax,
            missingFileModifiedTime: () => missingFileModifiedTime,
            modifierToFlag: () => modifierToFlag,
            modifiersToFlags: () => modifiersToFlags,
            moduleOptionDeclaration: () => moduleOptionDeclaration,
            moduleResolutionIsEqualTo: () => moduleResolutionIsEqualTo,
            moduleResolutionNameAndModeGetter: () => moduleResolutionNameAndModeGetter,
            moduleResolutionOptionDeclarations: () => moduleResolutionOptionDeclarations,
            moduleResolutionSupportsPackageJsonExportsAndImports: () => moduleResolutionSupportsPackageJsonExportsAndImports,
            moduleResolutionUsesNodeModules: () => moduleResolutionUsesNodeModules,
            moduleSpecifiers: () => ts_moduleSpecifiers_exports,
            moveEmitHelpers: () => moveEmitHelpers,
            moveRangeEnd: () => moveRangeEnd,
            moveRangePastDecorators: () => moveRangePastDecorators,
            moveRangePastModifiers: () => moveRangePastModifiers,
            moveRangePos: () => moveRangePos,
            moveSyntheticComments: () => moveSyntheticComments,
            mutateMap: () => mutateMap,
            mutateMapSkippingNewValues: () => mutateMapSkippingNewValues,
            needsParentheses: () => needsParentheses,
            needsScopeMarker: () => needsScopeMarker,
            newCaseClauseTracker: () => newCaseClauseTracker,
            newPrivateEnvironment: () => newPrivateEnvironment,
            noEmitNotification: () => noEmitNotification,
            noEmitSubstitution: () => noEmitSubstitution,
            noTransformers: () => noTransformers,
            noTruncationMaximumTruncationLength: () => noTruncationMaximumTruncationLength,
            nodeCanBeDecorated: () => nodeCanBeDecorated,
            nodeHasName: () => nodeHasName,
            nodeIsDecorated: () => nodeIsDecorated,
            nodeIsMissing: () => nodeIsMissing,
            nodeIsPresent: () => nodeIsPresent,
            nodeIsSynthesized: () => nodeIsSynthesized,
            nodeModuleNameResolver: () => nodeModuleNameResolver,
            nodeModulesPathPart: () => nodeModulesPathPart,
            nodeNextJsonConfigResolver: () => nodeNextJsonConfigResolver,
            nodeOrChildIsDecorated: () => nodeOrChildIsDecorated,
            nodeOverlapsWithStartEnd: () => nodeOverlapsWithStartEnd,
            nodePosToString: () => nodePosToString,
            nodeSeenTracker: () => nodeSeenTracker,
            nodeStartsNewLexicalEnvironment: () => nodeStartsNewLexicalEnvironment,
            nodeToDisplayParts: () => nodeToDisplayParts,
            noop: () => noop,
            noopFileWatcher: () => noopFileWatcher,
            normalizePath: () => normalizePath,
            normalizeSlashes: () => normalizeSlashes,
            not: () => not,
            notImplemented: () => notImplemented,
            notImplementedResolver: () => notImplementedResolver,
            nullNodeConverters: () => nullNodeConverters,
            nullParenthesizerRules: () => nullParenthesizerRules,
            nullTransformationContext: () => nullTransformationContext,
            objectAllocator: () => objectAllocator,
            operatorPart: () => operatorPart,
            optionDeclarations: () => optionDeclarations,
            optionMapToObject: () => optionMapToObject,
            optionsAffectingProgramStructure: () => optionsAffectingProgramStructure,
            optionsForBuild: () => optionsForBuild,
            optionsForWatch: () => optionsForWatch,
            optionsHaveChanges: () => optionsHaveChanges,
            optionsHaveModuleResolutionChanges: () => optionsHaveModuleResolutionChanges,
            or: () => or,
            orderedRemoveItem: () => orderedRemoveItem,
            orderedRemoveItemAt: () => orderedRemoveItemAt,
            outFile: () => outFile,
            packageIdToPackageName: () => packageIdToPackageName,
            packageIdToString: () => packageIdToString,
            paramHelper: () => paramHelper,
            parameterIsThisKeyword: () => parameterIsThisKeyword,
            parameterNamePart: () => parameterNamePart,
            parseBaseNodeFactory: () => parseBaseNodeFactory,
            parseBigInt: () => parseBigInt,
            parseBuildCommand: () => parseBuildCommand,
            parseCommandLine: () => parseCommandLine,
            parseCommandLineWorker: () => parseCommandLineWorker,
            parseConfigFileTextToJson: () => parseConfigFileTextToJson,
            parseConfigFileWithSystem: () => parseConfigFileWithSystem,
            parseConfigHostFromCompilerHostLike: () => parseConfigHostFromCompilerHostLike,
            parseCustomTypeOption: () => parseCustomTypeOption,
            parseIsolatedEntityName: () => parseIsolatedEntityName,
            parseIsolatedJSDocComment: () => parseIsolatedJSDocComment,
            parseJSDocTypeExpressionForTests: () => parseJSDocTypeExpressionForTests,
            parseJsonConfigFileContent: () => parseJsonConfigFileContent,
            parseJsonSourceFileConfigFileContent: () => parseJsonSourceFileConfigFileContent,
            parseJsonText: () => parseJsonText,
            parseListTypeOption: () => parseListTypeOption,
            parseNodeFactory: () => parseNodeFactory,
            parseNodeModuleFromPath: () => parseNodeModuleFromPath,
            parsePackageName: () => parsePackageName,
            parsePseudoBigInt: () => parsePseudoBigInt,
            parseValidBigInt: () => parseValidBigInt,
            patchWriteFileEnsuringDirectory: () => patchWriteFileEnsuringDirectory,
            pathContainsNodeModules: () => pathContainsNodeModules,
            pathIsAbsolute: () => pathIsAbsolute,
            pathIsBareSpecifier: () => pathIsBareSpecifier,
            pathIsRelative: () => pathIsRelative,
            patternText: () => patternText,
            perfLogger: () => perfLogger,
            performIncrementalCompilation: () => performIncrementalCompilation,
            performance: () => ts_performance_exports,
            plainJSErrors: () => plainJSErrors,
            positionBelongsToNode: () => positionBelongsToNode,
            positionIsASICandidate: () => positionIsASICandidate,
            positionIsSynthesized: () => positionIsSynthesized,
            positionsAreOnSameLine: () => positionsAreOnSameLine,
            preProcessFile: () => preProcessFile,
            probablyUsesSemicolons: () => probablyUsesSemicolons,
            processCommentPragmas: () => processCommentPragmas,
            processPragmasIntoFields: () => processPragmasIntoFields,
            processTaggedTemplateExpression: () => processTaggedTemplateExpression,
            programContainsEsModules: () => programContainsEsModules,
            programContainsModules: () => programContainsModules,
            projectReferenceIsEqualTo: () => projectReferenceIsEqualTo,
            propKeyHelper: () => propKeyHelper,
            propertyNamePart: () => propertyNamePart,
            pseudoBigIntToString: () => pseudoBigIntToString,
            punctuationPart: () => punctuationPart,
            pushIfUnique: () => pushIfUnique,
            quote: () => quote,
            quotePreferenceFromString: () => quotePreferenceFromString,
            rangeContainsPosition: () => rangeContainsPosition,
            rangeContainsPositionExclusive: () => rangeContainsPositionExclusive,
            rangeContainsRange: () => rangeContainsRange,
            rangeContainsRangeExclusive: () => rangeContainsRangeExclusive,
            rangeContainsStartEnd: () => rangeContainsStartEnd,
            rangeEndIsOnSameLineAsRangeStart: () => rangeEndIsOnSameLineAsRangeStart,
            rangeEndPositionsAreOnSameLine: () => rangeEndPositionsAreOnSameLine,
            rangeEquals: () => rangeEquals,
            rangeIsOnSingleLine: () => rangeIsOnSingleLine,
            rangeOfNode: () => rangeOfNode,
            rangeOfTypeParameters: () => rangeOfTypeParameters,
            rangeOverlapsWithStartEnd: () => rangeOverlapsWithStartEnd,
            rangeStartIsOnSameLineAsRangeEnd: () => rangeStartIsOnSameLineAsRangeEnd,
            rangeStartPositionsAreOnSameLine: () => rangeStartPositionsAreOnSameLine,
            readBuilderProgram: () => readBuilderProgram,
            readConfigFile: () => readConfigFile,
            readHelper: () => readHelper,
            readJson: () => readJson,
            readJsonConfigFile: () => readJsonConfigFile,
            readJsonOrUndefined: () => readJsonOrUndefined,
            reduceEachLeadingCommentRange: () => reduceEachLeadingCommentRange,
            reduceEachTrailingCommentRange: () => reduceEachTrailingCommentRange,
            reduceLeft: () => reduceLeft,
            reduceLeftIterator: () => reduceLeftIterator,
            reducePathComponents: () => reducePathComponents,
            refactor: () => ts_refactor_exports,
            regExpEscape: () => regExpEscape,
            relativeComplement: () => relativeComplement,
            removeAllComments: () => removeAllComments,
            removeEmitHelper: () => removeEmitHelper,
            removeExtension: () => removeExtension,
            removeFileExtension: () => removeFileExtension,
            removeIgnoredPath: () => removeIgnoredPath,
            removeMinAndVersionNumbers: () => removeMinAndVersionNumbers,
            removeOptionality: () => removeOptionality,
            removePrefix: () => removePrefix,
            removeSuffix: () => removeSuffix,
            removeTrailingDirectorySeparator: () => removeTrailingDirectorySeparator,
            repeatString: () => repeatString,
            replaceElement: () => replaceElement,
            replaceFirstStar: () => replaceFirstStar,
            resolutionExtensionIsTSOrJson: () => resolutionExtensionIsTSOrJson,
            resolveConfigFileProjectName: () => resolveConfigFileProjectName,
            resolveJSModule: () => resolveJSModule,
            resolveLibrary: () => resolveLibrary,
            resolveModuleName: () => resolveModuleName,
            resolveModuleNameFromCache: () => resolveModuleNameFromCache,
            resolvePackageNameToPackageJson: () => resolvePackageNameToPackageJson,
            resolvePath: () => resolvePath,
            resolveProjectReferencePath: () => resolveProjectReferencePath,
            resolveTripleslashReference: () => resolveTripleslashReference,
            resolveTypeReferenceDirective: () => resolveTypeReferenceDirective,
            resolvingEmptyArray: () => resolvingEmptyArray,
            restHelper: () => restHelper,
            returnFalse: () => returnFalse,
            returnNoopFileWatcher: () => returnNoopFileWatcher,
            returnTrue: () => returnTrue,
            returnUndefined: () => returnUndefined,
            returnsPromise: () => returnsPromise,
            runInitializersHelper: () => runInitializersHelper,
            sameFlatMap: () => sameFlatMap,
            sameMap: () => sameMap,
            sameMapping: () => sameMapping,
            scanShebangTrivia: () => scanShebangTrivia,
            scanTokenAtPosition: () => scanTokenAtPosition,
            scanner: () => scanner,
            screenStartingMessageCodes: () => screenStartingMessageCodes,
            semanticDiagnosticsOptionDeclarations: () => semanticDiagnosticsOptionDeclarations,
            serializeCompilerOptions: () => serializeCompilerOptions,
            server: () => ts_server_exports3,
            servicesVersion: () => servicesVersion,
            setCommentRange: () => setCommentRange,
            setConfigFileInOptions: () => setConfigFileInOptions,
            setConstantValue: () => setConstantValue,
            setEachParent: () => setEachParent,
            setEmitFlags: () => setEmitFlags,
            setFunctionNameHelper: () => setFunctionNameHelper,
            setGetSourceFileAsHashVersioned: () => setGetSourceFileAsHashVersioned,
            setIdentifierAutoGenerate: () => setIdentifierAutoGenerate,
            setIdentifierGeneratedImportReference: () => setIdentifierGeneratedImportReference,
            setIdentifierTypeArguments: () => setIdentifierTypeArguments,
            setInternalEmitFlags: () => setInternalEmitFlags,
            setLocalizedDiagnosticMessages: () => setLocalizedDiagnosticMessages,
            setModuleDefaultHelper: () => setModuleDefaultHelper,
            setNodeFlags: () => setNodeFlags,
            setObjectAllocator: () => setObjectAllocator,
            setOriginalNode: () => setOriginalNode,
            setParent: () => setParent,
            setParentRecursive: () => setParentRecursive,
            setPrivateIdentifier: () => setPrivateIdentifier,
            setSnippetElement: () => setSnippetElement,
            setSourceMapRange: () => setSourceMapRange,
            setStackTraceLimit: () => setStackTraceLimit,
            setStartsOnNewLine: () => setStartsOnNewLine,
            setSyntheticLeadingComments: () => setSyntheticLeadingComments,
            setSyntheticTrailingComments: () => setSyntheticTrailingComments,
            setSys: () => setSys,
            setSysLog: () => setSysLog,
            setTextRange: () => setTextRange,
            setTextRangeEnd: () => setTextRangeEnd,
            setTextRangePos: () => setTextRangePos,
            setTextRangePosEnd: () => setTextRangePosEnd,
            setTextRangePosWidth: () => setTextRangePosWidth,
            setTokenSourceMapRange: () => setTokenSourceMapRange,
            setTypeNode: () => setTypeNode,
            setUILocale: () => setUILocale,
            setValueDeclaration: () => setValueDeclaration,
            shouldAllowImportingTsExtension: () => shouldAllowImportingTsExtension,
            shouldPreserveConstEnums: () => shouldPreserveConstEnums,
            shouldUseUriStyleNodeCoreModules: () => shouldUseUriStyleNodeCoreModules,
            showModuleSpecifier: () => showModuleSpecifier,
            signatureHasLiteralTypes: () => signatureHasLiteralTypes,
            signatureHasRestParameter: () => signatureHasRestParameter,
            signatureToDisplayParts: () => signatureToDisplayParts,
            single: () => single,
            singleElementArray: () => singleElementArray,
            singleIterator: () => singleIterator,
            singleOrMany: () => singleOrMany,
            singleOrUndefined: () => singleOrUndefined,
            skipAlias: () => skipAlias,
            skipAssertions: () => skipAssertions,
            skipConstraint: () => skipConstraint,
            skipOuterExpressions: () => skipOuterExpressions,
            skipParentheses: () => skipParentheses,
            skipPartiallyEmittedExpressions: () => skipPartiallyEmittedExpressions,
            skipTrivia: () => skipTrivia,
            skipTypeChecking: () => skipTypeChecking,
            skipTypeParentheses: () => skipTypeParentheses,
            skipWhile: () => skipWhile,
            sliceAfter: () => sliceAfter,
            some: () => some,
            sort: () => sort,
            sortAndDeduplicate: () => sortAndDeduplicate,
            sortAndDeduplicateDiagnostics: () => sortAndDeduplicateDiagnostics,
            sourceFileAffectingCompilerOptions: () => sourceFileAffectingCompilerOptions,
            sourceFileMayBeEmitted: () => sourceFileMayBeEmitted,
            sourceMapCommentRegExp: () => sourceMapCommentRegExp,
            sourceMapCommentRegExpDontCareLineStart: () => sourceMapCommentRegExpDontCareLineStart,
            spacePart: () => spacePart,
            spanMap: () => spanMap,
            spreadArrayHelper: () => spreadArrayHelper,
            stableSort: () => stableSort,
            startEndContainsRange: () => startEndContainsRange,
            startEndOverlapsWithStartEnd: () => startEndOverlapsWithStartEnd,
            startOnNewLine: () => startOnNewLine,
            startTracing: () => startTracing,
            startsWith: () => startsWith,
            startsWithDirectory: () => startsWithDirectory,
            startsWithUnderscore: () => startsWithUnderscore,
            startsWithUseStrict: () => startsWithUseStrict,
            stringContainsAt: () => stringContainsAt,
            stringToToken: () => stringToToken,
            stripQuotes: () => stripQuotes,
            supportedDeclarationExtensions: () => supportedDeclarationExtensions,
            supportedJSExtensions: () => supportedJSExtensions,
            supportedJSExtensionsFlat: () => supportedJSExtensionsFlat,
            supportedLocaleDirectories: () => supportedLocaleDirectories,
            supportedTSExtensions: () => supportedTSExtensions,
            supportedTSExtensionsFlat: () => supportedTSExtensionsFlat,
            supportedTSImplementationExtensions: () => supportedTSImplementationExtensions,
            suppressLeadingAndTrailingTrivia: () => suppressLeadingAndTrailingTrivia,
            suppressLeadingTrivia: () => suppressLeadingTrivia,
            suppressTrailingTrivia: () => suppressTrailingTrivia,
            symbolEscapedNameNoDefault: () => symbolEscapedNameNoDefault,
            symbolName: () => symbolName,
            symbolNameNoDefault: () => symbolNameNoDefault,
            symbolPart: () => symbolPart,
            symbolToDisplayParts: () => symbolToDisplayParts,
            syntaxMayBeASICandidate: () => syntaxMayBeASICandidate,
            syntaxRequiresTrailingSemicolonOrASI: () => syntaxRequiresTrailingSemicolonOrASI,
            sys: () => sys,
            sysLog: () => sysLog,
            tagNamesAreEquivalent: () => tagNamesAreEquivalent,
            takeWhile: () => takeWhile,
            targetOptionDeclaration: () => targetOptionDeclaration,
            templateObjectHelper: () => templateObjectHelper,
            testFormatSettings: () => testFormatSettings,
            textChangeRangeIsUnchanged: () => textChangeRangeIsUnchanged,
            textChangeRangeNewSpan: () => textChangeRangeNewSpan,
            textChanges: () => ts_textChanges_exports,
            textOrKeywordPart: () => textOrKeywordPart,
            textPart: () => textPart,
            textRangeContainsPositionInclusive: () => textRangeContainsPositionInclusive,
            textSpanContainsPosition: () => textSpanContainsPosition,
            textSpanContainsTextSpan: () => textSpanContainsTextSpan,
            textSpanEnd: () => textSpanEnd,
            textSpanIntersection: () => textSpanIntersection,
            textSpanIntersectsWith: () => textSpanIntersectsWith,
            textSpanIntersectsWithPosition: () => textSpanIntersectsWithPosition,
            textSpanIntersectsWithTextSpan: () => textSpanIntersectsWithTextSpan,
            textSpanIsEmpty: () => textSpanIsEmpty,
            textSpanOverlap: () => textSpanOverlap,
            textSpanOverlapsWith: () => textSpanOverlapsWith,
            textSpansEqual: () => textSpansEqual,
            textToKeywordObj: () => textToKeywordObj,
            timestamp: () => timestamp,
            toArray: () => toArray,
            toBuilderFileEmit: () => toBuilderFileEmit,
            toBuilderStateFileInfoForMultiEmit: () => toBuilderStateFileInfoForMultiEmit,
            toEditorSettings: () => toEditorSettings,
            toFileNameLowerCase: () => toFileNameLowerCase,
            toLowerCase: () => toLowerCase,
            toPath: () => toPath,
            toProgramEmitPending: () => toProgramEmitPending,
            tokenIsIdentifierOrKeyword: () => tokenIsIdentifierOrKeyword,
            tokenIsIdentifierOrKeywordOrGreaterThan: () => tokenIsIdentifierOrKeywordOrGreaterThan,
            tokenToString: () => tokenToString,
            trace: () => trace,
            tracing: () => tracing,
            tracingEnabled: () => tracingEnabled,
            transform: () => transform,
            transformClassFields: () => transformClassFields,
            transformDeclarations: () => transformDeclarations,
            transformECMAScriptModule: () => transformECMAScriptModule,
            transformES2015: () => transformES2015,
            transformES2016: () => transformES2016,
            transformES2017: () => transformES2017,
            transformES2018: () => transformES2018,
            transformES2019: () => transformES2019,
            transformES2020: () => transformES2020,
            transformES2021: () => transformES2021,
            transformES5: () => transformES5,
            transformESDecorators: () => transformESDecorators,
            transformESNext: () => transformESNext,
            transformGenerators: () => transformGenerators,
            transformJsx: () => transformJsx,
            transformLegacyDecorators: () => transformLegacyDecorators,
            transformModule: () => transformModule,
            transformNamedEvaluation: () => transformNamedEvaluation,
            transformNodeModule: () => transformNodeModule,
            transformNodes: () => transformNodes,
            transformSystemModule: () => transformSystemModule,
            transformTypeScript: () => transformTypeScript,
            transpile: () => transpile,
            transpileModule: () => transpileModule,
            transpileOptionValueCompilerOptions: () => transpileOptionValueCompilerOptions,
            tryAddToSet: () => tryAddToSet,
            tryAndIgnoreErrors: () => tryAndIgnoreErrors,
            tryCast: () => tryCast,
            tryDirectoryExists: () => tryDirectoryExists,
            tryExtractTSExtension: () => tryExtractTSExtension,
            tryFileExists: () => tryFileExists,
            tryGetClassExtendingExpressionWithTypeArguments: () => tryGetClassExtendingExpressionWithTypeArguments,
            tryGetClassImplementingOrExtendingExpressionWithTypeArguments: () => tryGetClassImplementingOrExtendingExpressionWithTypeArguments,
            tryGetDirectories: () => tryGetDirectories,
            tryGetExtensionFromPath: () => tryGetExtensionFromPath2,
            tryGetImportFromModuleSpecifier: () => tryGetImportFromModuleSpecifier,
            tryGetJSDocSatisfiesTypeNode: () => tryGetJSDocSatisfiesTypeNode,
            tryGetModuleNameFromFile: () => tryGetModuleNameFromFile,
            tryGetModuleSpecifierFromDeclaration: () => tryGetModuleSpecifierFromDeclaration,
            tryGetNativePerformanceHooks: () => tryGetNativePerformanceHooks,
            tryGetPropertyAccessOrIdentifierToString: () => tryGetPropertyAccessOrIdentifierToString,
            tryGetPropertyNameOfBindingOrAssignmentElement: () => tryGetPropertyNameOfBindingOrAssignmentElement,
            tryGetSourceMappingURL: () => tryGetSourceMappingURL,
            tryGetTextOfPropertyName: () => tryGetTextOfPropertyName,
            tryIOAndConsumeErrors: () => tryIOAndConsumeErrors,
            tryParseJson: () => tryParseJson,
            tryParsePattern: () => tryParsePattern,
            tryParsePatterns: () => tryParsePatterns,
            tryParseRawSourceMap: () => tryParseRawSourceMap,
            tryReadDirectory: () => tryReadDirectory,
            tryReadFile: () => tryReadFile,
            tryRemoveDirectoryPrefix: () => tryRemoveDirectoryPrefix,
            tryRemoveExtension: () => tryRemoveExtension,
            tryRemovePrefix: () => tryRemovePrefix,
            tryRemoveSuffix: () => tryRemoveSuffix,
            typeAcquisitionDeclarations: () => typeAcquisitionDeclarations,
            typeAliasNamePart: () => typeAliasNamePart,
            typeDirectiveIsEqualTo: () => typeDirectiveIsEqualTo,
            typeKeywords: () => typeKeywords,
            typeParameterNamePart: () => typeParameterNamePart,
            typeToDisplayParts: () => typeToDisplayParts,
            unchangedPollThresholds: () => unchangedPollThresholds,
            unchangedTextChangeRange: () => unchangedTextChangeRange,
            unescapeLeadingUnderscores: () => unescapeLeadingUnderscores,
            unmangleScopedPackageName: () => unmangleScopedPackageName,
            unorderedRemoveItem: () => unorderedRemoveItem,
            unorderedRemoveItemAt: () => unorderedRemoveItemAt,
            unreachableCodeIsError: () => unreachableCodeIsError,
            unusedLabelIsError: () => unusedLabelIsError,
            unwrapInnermostStatementOfLabel: () => unwrapInnermostStatementOfLabel,
            updateErrorForNoInputFiles: () => updateErrorForNoInputFiles,
            updateLanguageServiceSourceFile: () => updateLanguageServiceSourceFile,
            updateMissingFilePathsWatch: () => updateMissingFilePathsWatch,
            updateResolutionField: () => updateResolutionField,
            updateSharedExtendedConfigFileWatcher: () => updateSharedExtendedConfigFileWatcher,
            updateSourceFile: () => updateSourceFile,
            updateWatchingWildcardDirectories: () => updateWatchingWildcardDirectories,
            usesExtensionsOnImports: () => usesExtensionsOnImports,
            usingSingleLineStringWriter: () => usingSingleLineStringWriter,
            utf16EncodeAsString: () => utf16EncodeAsString,
            validateLocaleAndSetLanguage: () => validateLocaleAndSetLanguage,
            valuesHelper: () => valuesHelper,
            version: () => version,
            versionMajorMinor: () => versionMajorMinor,
            visitArray: () => visitArray,
            visitCommaListElements: () => visitCommaListElements,
            visitEachChild: () => visitEachChild,
            visitFunctionBody: () => visitFunctionBody,
            visitIterationBody: () => visitIterationBody,
            visitLexicalEnvironment: () => visitLexicalEnvironment,
            visitNode: () => visitNode,
            visitNodes: () => visitNodes2,
            visitParameterList: () => visitParameterList,
            walkUpBindingElementsAndPatterns: () => walkUpBindingElementsAndPatterns,
            walkUpLexicalEnvironments: () => walkUpLexicalEnvironments,
            walkUpOuterExpressions: () => walkUpOuterExpressions,
            walkUpParenthesizedExpressions: () => walkUpParenthesizedExpressions,
            walkUpParenthesizedTypes: () => walkUpParenthesizedTypes,
            walkUpParenthesizedTypesAndGetParentAndChild: () => walkUpParenthesizedTypesAndGetParentAndChild,
            whitespaceOrMapCommentRegExp: () => whitespaceOrMapCommentRegExp,
            writeCommentRange: () => writeCommentRange,
            writeFile: () => writeFile,
            writeFileEnsuringDirectories: () => writeFileEnsuringDirectories,
            zipWith: () => zipWith
        });
        var init_ts7 = __esm({
            "src/server/_namespaces/ts.ts"() {
                "use strict";
                init_ts2();
                init_ts3();
                init_ts4();
                init_ts5();
                init_ts_server3();
            }
        });
        // src/typescript/_namespaces/ts.server.ts
        var ts_server_exports4 = {};
        __export(ts_server_exports4, {
            ActionInvalidate: () => ActionInvalidate,
            ActionPackageInstalled: () => ActionPackageInstalled,
            ActionSet: () => ActionSet,
            ActionWatchTypingLocations: () => ActionWatchTypingLocations,
            Arguments: () => Arguments,
            AutoImportProviderProject: () => AutoImportProviderProject,
            AuxiliaryProject: () => AuxiliaryProject,
            CharRangeSection: () => CharRangeSection,
            CloseFileWatcherEvent: () => CloseFileWatcherEvent,
            CommandNames: () => CommandNames,
            ConfigFileDiagEvent: () => ConfigFileDiagEvent,
            ConfiguredProject: () => ConfiguredProject2,
            CreateDirectoryWatcherEvent: () => CreateDirectoryWatcherEvent,
            CreateFileWatcherEvent: () => CreateFileWatcherEvent,
            Errors: () => Errors,
            EventBeginInstallTypes: () => EventBeginInstallTypes,
            EventEndInstallTypes: () => EventEndInstallTypes,
            EventInitializationFailed: () => EventInitializationFailed,
            EventTypesRegistry: () => EventTypesRegistry,
            ExternalProject: () => ExternalProject2,
            GcTimer: () => GcTimer,
            InferredProject: () => InferredProject2,
            LargeFileReferencedEvent: () => LargeFileReferencedEvent,
            LineIndex: () => LineIndex,
            LineLeaf: () => LineLeaf,
            LineNode: () => LineNode,
            LogLevel: () => LogLevel2,
            Msg: () => Msg,
            OpenFileInfoTelemetryEvent: () => OpenFileInfoTelemetryEvent,
            Project: () => Project3,
            ProjectInfoTelemetryEvent: () => ProjectInfoTelemetryEvent,
            ProjectKind: () => ProjectKind,
            ProjectLanguageServiceStateEvent: () => ProjectLanguageServiceStateEvent,
            ProjectLoadingFinishEvent: () => ProjectLoadingFinishEvent,
            ProjectLoadingStartEvent: () => ProjectLoadingStartEvent,
            ProjectReferenceProjectLoadKind: () => ProjectReferenceProjectLoadKind,
            ProjectService: () => ProjectService3,
            ProjectsUpdatedInBackgroundEvent: () => ProjectsUpdatedInBackgroundEvent,
            ScriptInfo: () => ScriptInfo,
            ScriptVersionCache: () => ScriptVersionCache,
            Session: () => Session3,
            TextStorage: () => TextStorage,
            ThrottledOperations: () => ThrottledOperations,
            TypingsCache: () => TypingsCache,
            TypingsInstallerAdapter: () => TypingsInstallerAdapter,
            allFilesAreJsOrDts: () => allFilesAreJsOrDts,
            allRootFilesAreJsOrDts: () => allRootFilesAreJsOrDts,
            asNormalizedPath: () => asNormalizedPath,
            convertCompilerOptions: () => convertCompilerOptions,
            convertFormatOptions: () => convertFormatOptions,
            convertScriptKindName: () => convertScriptKindName,
            convertTypeAcquisition: () => convertTypeAcquisition,
            convertUserPreferences: () => convertUserPreferences,
            convertWatchOptions: () => convertWatchOptions,
            countEachFileTypes: () => countEachFileTypes,
            createInstallTypingsRequest: () => createInstallTypingsRequest,
            createModuleSpecifierCache: () => createModuleSpecifierCache,
            createNormalizedPathMap: () => createNormalizedPathMap,
            createPackageJsonCache: () => createPackageJsonCache,
            createSortedArray: () => createSortedArray2,
            emptyArray: () => emptyArray2,
            findArgument: () => findArgument,
            forEachResolvedProjectReferenceProject: () => forEachResolvedProjectReferenceProject,
            formatDiagnosticToProtocol: () => formatDiagnosticToProtocol,
            formatMessage: () => formatMessage2,
            getBaseConfigFileName: () => getBaseConfigFileName,
            getLocationInNewDocument: () => getLocationInNewDocument,
            hasArgument: () => hasArgument,
            hasNoTypeScriptSource: () => hasNoTypeScriptSource,
            indent: () => indent2,
            isBackgroundProject: () => isBackgroundProject,
            isConfigFile: () => isConfigFile,
            isConfiguredProject: () => isConfiguredProject,
            isDynamicFileName: () => isDynamicFileName,
            isExternalProject: () => isExternalProject,
            isInferredProject: () => isInferredProject,
            isInferredProjectName: () => isInferredProjectName,
            makeAutoImportProviderProjectName: () => makeAutoImportProviderProjectName,
            makeAuxiliaryProjectName: () => makeAuxiliaryProjectName,
            makeInferredProjectName: () => makeInferredProjectName,
            maxFileSize: () => maxFileSize,
            maxProgramSizeForNonTsFiles: () => maxProgramSizeForNonTsFiles,
            normalizedPathToPath: () => normalizedPathToPath,
            nowString: () => nowString,
            nullCancellationToken: () => nullCancellationToken,
            nullTypingsInstaller: () => nullTypingsInstaller,
            projectContainsInfoDirectly: () => projectContainsInfoDirectly,
            protocol: () => ts_server_protocol_exports,
            removeSorted: () => removeSorted,
            stringifyIndented: () => stringifyIndented,
            toEvent: () => toEvent,
            toNormalizedPath: () => toNormalizedPath,
            tryConvertScriptKindName: () => tryConvertScriptKindName,
            typingsInstaller: () => ts_server_typingsInstaller_exports,
            updateProjectIfDirty: () => updateProjectIfDirty
        });
        var init_ts_server4 = __esm({
            "src/typescript/_namespaces/ts.server.ts"() {
                "use strict";
                init_ts_server();
                init_ts_server3();
            }
        });
        // src/typescript/_namespaces/ts.ts
        var ts_exports3 = {};
        __export(ts_exports3, {
            ANONYMOUS: () => ANONYMOUS,
            AccessFlags: () => AccessFlags,
            AssertionLevel: () => AssertionLevel,
            AssignmentDeclarationKind: () => AssignmentDeclarationKind,
            AssignmentKind: () => AssignmentKind,
            Associativity: () => Associativity,
            BreakpointResolver: () => ts_BreakpointResolver_exports,
            BuilderFileEmit: () => BuilderFileEmit,
            BuilderProgramKind: () => BuilderProgramKind,
            BuilderState: () => BuilderState,
            BundleFileSectionKind: () => BundleFileSectionKind,
            CallHierarchy: () => ts_CallHierarchy_exports,
            CharacterCodes: () => CharacterCodes,
            CheckFlags: () => CheckFlags,
            CheckMode: () => CheckMode,
            ClassificationType: () => ClassificationType,
            ClassificationTypeNames: () => ClassificationTypeNames,
            CommentDirectiveType: () => CommentDirectiveType,
            Comparison: () => Comparison,
            CompletionInfoFlags: () => CompletionInfoFlags,
            CompletionTriggerKind: () => CompletionTriggerKind,
            Completions: () => ts_Completions_exports,
            ContainerFlags: () => ContainerFlags,
            ContextFlags: () => ContextFlags,
            Debug: () => Debug,
            DiagnosticCategory: () => DiagnosticCategory,
            Diagnostics: () => Diagnostics,
            DocumentHighlights: () => DocumentHighlights,
            ElementFlags: () => ElementFlags,
            EmitFlags: () => EmitFlags,
            EmitHint: () => EmitHint,
            EmitOnly: () => EmitOnly,
            EndOfLineState: () => EndOfLineState,
            EnumKind: () => EnumKind,
            ExitStatus: () => ExitStatus,
            ExportKind: () => ExportKind,
            Extension: () => Extension,
            ExternalEmitHelpers: () => ExternalEmitHelpers,
            FileIncludeKind: () => FileIncludeKind,
            FilePreprocessingDiagnosticsKind: () => FilePreprocessingDiagnosticsKind,
            FileSystemEntryKind: () => FileSystemEntryKind,
            FileWatcherEventKind: () => FileWatcherEventKind,
            FindAllReferences: () => ts_FindAllReferences_exports,
            FlattenLevel: () => FlattenLevel,
            FlowFlags: () => FlowFlags,
            ForegroundColorEscapeSequences: () => ForegroundColorEscapeSequences,
            FunctionFlags: () => FunctionFlags,
            GeneratedIdentifierFlags: () => GeneratedIdentifierFlags,
            GetLiteralTextFlags: () => GetLiteralTextFlags,
            GoToDefinition: () => ts_GoToDefinition_exports,
            HighlightSpanKind: () => HighlightSpanKind,
            IdentifierNameMap: () => IdentifierNameMap,
            IdentifierNameMultiMap: () => IdentifierNameMultiMap,
            ImportKind: () => ImportKind,
            ImportsNotUsedAsValues: () => ImportsNotUsedAsValues,
            IndentStyle: () => IndentStyle,
            IndexFlags: () => IndexFlags,
            IndexKind: () => IndexKind,
            InferenceFlags: () => InferenceFlags,
            InferencePriority: () => InferencePriority,
            InlayHintKind: () => InlayHintKind,
            InlayHints: () => ts_InlayHints_exports,
            InternalEmitFlags: () => InternalEmitFlags,
            InternalSymbolName: () => InternalSymbolName,
            InvalidatedProjectKind: () => InvalidatedProjectKind,
            JSDocParsingMode: () => JSDocParsingMode,
            JsDoc: () => ts_JsDoc_exports,
            JsTyping: () => ts_JsTyping_exports,
            JsxEmit: () => JsxEmit,
            JsxFlags: () => JsxFlags,
            JsxReferenceKind: () => JsxReferenceKind,
            LanguageServiceMode: () => LanguageServiceMode,
            LanguageVariant: () => LanguageVariant,
            LexicalEnvironmentFlags: () => LexicalEnvironmentFlags,
            ListFormat: () => ListFormat,
            LogLevel: () => LogLevel,
            MemberOverrideStatus: () => MemberOverrideStatus,
            ModifierFlags: () => ModifierFlags,
            ModuleDetectionKind: () => ModuleDetectionKind,
            ModuleInstanceState: () => ModuleInstanceState,
            ModuleKind: () => ModuleKind,
            ModuleResolutionKind: () => ModuleResolutionKind,
            ModuleSpecifierEnding: () => ModuleSpecifierEnding,
            NavigateTo: () => ts_NavigateTo_exports,
            NavigationBar: () => ts_NavigationBar_exports,
            NewLineKind: () => NewLineKind,
            NodeBuilderFlags: () => NodeBuilderFlags,
            NodeCheckFlags: () => NodeCheckFlags,
            NodeFactoryFlags: () => NodeFactoryFlags,
            NodeFlags: () => NodeFlags,
            NodeResolutionFeatures: () => NodeResolutionFeatures,
            ObjectFlags: () => ObjectFlags,
            OperationCanceledException: () => OperationCanceledException,
            OperatorPrecedence: () => OperatorPrecedence,
            OrganizeImports: () => ts_OrganizeImports_exports,
            OrganizeImportsMode: () => OrganizeImportsMode,
            OuterExpressionKinds: () => OuterExpressionKinds,
            OutliningElementsCollector: () => ts_OutliningElementsCollector_exports,
            OutliningSpanKind: () => OutliningSpanKind,
            OutputFileType: () => OutputFileType,
            PackageJsonAutoImportPreference: () => PackageJsonAutoImportPreference,
            PackageJsonDependencyGroup: () => PackageJsonDependencyGroup,
            PatternMatchKind: () => PatternMatchKind,
            PollingInterval: () => PollingInterval,
            PollingWatchKind: () => PollingWatchKind,
            PragmaKindFlags: () => PragmaKindFlags,
            PrivateIdentifierKind: () => PrivateIdentifierKind,
            ProcessLevel: () => ProcessLevel,
            ProgramUpdateLevel: () => ProgramUpdateLevel,
            QuotePreference: () => QuotePreference,
            RelationComparisonResult: () => RelationComparisonResult,
            Rename: () => ts_Rename_exports,
            ScriptElementKind: () => ScriptElementKind,
            ScriptElementKindModifier: () => ScriptElementKindModifier,
            ScriptKind: () => ScriptKind,
            ScriptSnapshot: () => ScriptSnapshot,
            ScriptTarget: () => ScriptTarget,
            SemanticClassificationFormat: () => SemanticClassificationFormat,
            SemanticMeaning: () => SemanticMeaning,
            SemicolonPreference: () => SemicolonPreference,
            SignatureCheckMode: () => SignatureCheckMode,
            SignatureFlags: () => SignatureFlags,
            SignatureHelp: () => ts_SignatureHelp_exports,
            SignatureKind: () => SignatureKind,
            SmartSelectionRange: () => ts_SmartSelectionRange_exports,
            SnippetKind: () => SnippetKind,
            SortKind: () => SortKind,
            StructureIsReused: () => StructureIsReused,
            SymbolAccessibility: () => SymbolAccessibility,
            SymbolDisplay: () => ts_SymbolDisplay_exports,
            SymbolDisplayPartKind: () => SymbolDisplayPartKind,
            SymbolFlags: () => SymbolFlags,
            SymbolFormatFlags: () => SymbolFormatFlags,
            SyntaxKind: () => SyntaxKind,
            SyntheticSymbolKind: () => SyntheticSymbolKind,
            Ternary: () => Ternary,
            ThrottledCancellationToken: () => ThrottledCancellationToken,
            TokenClass: () => TokenClass,
            TokenFlags: () => TokenFlags,
            TransformFlags: () => TransformFlags,
            TypeFacts: () => TypeFacts,
            TypeFlags: () => TypeFlags,
            TypeFormatFlags: () => TypeFormatFlags,
            TypeMapKind: () => TypeMapKind,
            TypePredicateKind: () => TypePredicateKind,
            TypeReferenceSerializationKind: () => TypeReferenceSerializationKind,
            UnionReduction: () => UnionReduction,
            UpToDateStatusType: () => UpToDateStatusType,
            VarianceFlags: () => VarianceFlags,
            Version: () => Version,
            VersionRange: () => VersionRange,
            WatchDirectoryFlags: () => WatchDirectoryFlags,
            WatchDirectoryKind: () => WatchDirectoryKind,
            WatchFileKind: () => WatchFileKind,
            WatchLogLevel: () => WatchLogLevel,
            WatchType: () => WatchType,
            accessPrivateIdentifier: () => accessPrivateIdentifier,
            addDisposableResourceHelper: () => addDisposableResourceHelper,
            addEmitFlags: () => addEmitFlags,
            addEmitHelper: () => addEmitHelper,
            addEmitHelpers: () => addEmitHelpers,
            addInternalEmitFlags: () => addInternalEmitFlags,
            addNodeFactoryPatcher: () => addNodeFactoryPatcher,
            addObjectAllocatorPatcher: () => addObjectAllocatorPatcher,
            addRange: () => addRange,
            addRelatedInfo: () => addRelatedInfo,
            addSyntheticLeadingComment: () => addSyntheticLeadingComment,
            addSyntheticTrailingComment: () => addSyntheticTrailingComment,
            addToSeen: () => addToSeen,
            advancedAsyncSuperHelper: () => advancedAsyncSuperHelper,
            affectsDeclarationPathOptionDeclarations: () => affectsDeclarationPathOptionDeclarations,
            affectsEmitOptionDeclarations: () => affectsEmitOptionDeclarations,
            allKeysStartWithDot: () => allKeysStartWithDot,
            altDirectorySeparator: () => altDirectorySeparator,
            and: () => and,
            append: () => append,
            appendIfUnique: () => appendIfUnique,
            arrayFrom: () => arrayFrom,
            arrayIsEqualTo: () => arrayIsEqualTo,
            arrayIsHomogeneous: () => arrayIsHomogeneous,
            arrayIsSorted: () => arrayIsSorted,
            arrayOf: () => arrayOf,
            arrayReverseIterator: () => arrayReverseIterator,
            arrayToMap: () => arrayToMap,
            arrayToMultiMap: () => arrayToMultiMap,
            arrayToNumericMap: () => arrayToNumericMap,
            arraysEqual: () => arraysEqual,
            assertType: () => assertType,
            assign: () => assign,
            assignHelper: () => assignHelper,
            asyncDelegator: () => asyncDelegator,
            asyncGeneratorHelper: () => asyncGeneratorHelper,
            asyncSuperHelper: () => asyncSuperHelper,
            asyncValues: () => asyncValues,
            attachFileToDiagnostics: () => attachFileToDiagnostics,
            awaitHelper: () => awaitHelper,
            awaiterHelper: () => awaiterHelper,
            base64decode: () => base64decode,
            base64encode: () => base64encode,
            binarySearch: () => binarySearch,
            binarySearchKey: () => binarySearchKey,
            bindSourceFile: () => bindSourceFile,
            breakIntoCharacterSpans: () => breakIntoCharacterSpans,
            breakIntoWordSpans: () => breakIntoWordSpans,
            buildLinkParts: () => buildLinkParts,
            buildOpts: () => buildOpts,
            buildOverload: () => buildOverload,
            bundlerModuleNameResolver: () => bundlerModuleNameResolver,
            canBeConvertedToAsync: () => canBeConvertedToAsync,
            canHaveDecorators: () => canHaveDecorators,
            canHaveExportModifier: () => canHaveExportModifier,
            canHaveFlowNode: () => canHaveFlowNode,
            canHaveIllegalDecorators: () => canHaveIllegalDecorators,
            canHaveIllegalModifiers: () => canHaveIllegalModifiers,
            canHaveIllegalType: () => canHaveIllegalType,
            canHaveIllegalTypeParameters: () => canHaveIllegalTypeParameters,
            canHaveJSDoc: () => canHaveJSDoc,
            canHaveLocals: () => canHaveLocals,
            canHaveModifiers: () => canHaveModifiers,
            canHaveSymbol: () => canHaveSymbol,
            canJsonReportNoInputFiles: () => canJsonReportNoInputFiles,
            canProduceDiagnostics: () => canProduceDiagnostics,
            canUsePropertyAccess: () => canUsePropertyAccess,
            canWatchAffectingLocation: () => canWatchAffectingLocation,
            canWatchAtTypes: () => canWatchAtTypes,
            canWatchDirectoryOrFile: () => canWatchDirectoryOrFile,
            cartesianProduct: () => cartesianProduct,
            cast: () => cast,
            chainBundle: () => chainBundle,
            chainDiagnosticMessages: () => chainDiagnosticMessages,
            changeAnyExtension: () => changeAnyExtension,
            changeCompilerHostLikeToUseCache: () => changeCompilerHostLikeToUseCache,
            changeExtension: () => changeExtension,
            changeFullExtension: () => changeFullExtension,
            changesAffectModuleResolution: () => changesAffectModuleResolution,
            changesAffectingProgramStructure: () => changesAffectingProgramStructure,
            childIsDecorated: () => childIsDecorated,
            classElementOrClassElementParameterIsDecorated: () => classElementOrClassElementParameterIsDecorated,
            classHasClassThisAssignment: () => classHasClassThisAssignment,
            classHasDeclaredOrExplicitlyAssignedName: () => classHasDeclaredOrExplicitlyAssignedName,
            classHasExplicitlyAssignedName: () => classHasExplicitlyAssignedName,
            classOrConstructorParameterIsDecorated: () => classOrConstructorParameterIsDecorated,
            classPrivateFieldGetHelper: () => classPrivateFieldGetHelper,
            classPrivateFieldInHelper: () => classPrivateFieldInHelper,
            classPrivateFieldSetHelper: () => classPrivateFieldSetHelper,
            classicNameResolver: () => classicNameResolver,
            classifier: () => ts_classifier_exports,
            cleanExtendedConfigCache: () => cleanExtendedConfigCache,
            clear: () => clear,
            clearMap: () => clearMap,
            clearSharedExtendedConfigFileWatcher: () => clearSharedExtendedConfigFileWatcher,
            climbPastPropertyAccess: () => climbPastPropertyAccess,
            climbPastPropertyOrElementAccess: () => climbPastPropertyOrElementAccess,
            clone: () => clone,
            cloneCompilerOptions: () => cloneCompilerOptions,
            closeFileWatcher: () => closeFileWatcher,
            closeFileWatcherOf: () => closeFileWatcherOf,
            codefix: () => ts_codefix_exports,
            collapseTextChangeRangesAcrossMultipleVersions: () => collapseTextChangeRangesAcrossMultipleVersions,
            collectExternalModuleInfo: () => collectExternalModuleInfo,
            combine: () => combine,
            combinePaths: () => combinePaths,
            commentPragmas: () => commentPragmas,
            commonOptionsWithBuild: () => commonOptionsWithBuild,
            commonPackageFolders: () => commonPackageFolders,
            compact: () => compact,
            compareBooleans: () => compareBooleans,
            compareDataObjects: () => compareDataObjects,
            compareDiagnostics: () => compareDiagnostics,
            compareDiagnosticsSkipRelatedInformation: () => compareDiagnosticsSkipRelatedInformation,
            compareEmitHelpers: () => compareEmitHelpers,
            compareNumberOfDirectorySeparators: () => compareNumberOfDirectorySeparators,
            comparePaths: () => comparePaths,
            comparePathsCaseInsensitive: () => comparePathsCaseInsensitive,
            comparePathsCaseSensitive: () => comparePathsCaseSensitive,
            comparePatternKeys: () => comparePatternKeys,
            compareProperties: () => compareProperties,
            compareStringsCaseInsensitive: () => compareStringsCaseInsensitive,
            compareStringsCaseInsensitiveEslintCompatible: () => compareStringsCaseInsensitiveEslintCompatible,
            compareStringsCaseSensitive: () => compareStringsCaseSensitive,
            compareStringsCaseSensitiveUI: () => compareStringsCaseSensitiveUI,
            compareTextSpans: () => compareTextSpans,
            compareValues: () => compareValues,
            compileOnSaveCommandLineOption: () => compileOnSaveCommandLineOption,
            compilerOptionsAffectDeclarationPath: () => compilerOptionsAffectDeclarationPath,
            compilerOptionsAffectEmit: () => compilerOptionsAffectEmit,
            compilerOptionsAffectSemanticDiagnostics: () => compilerOptionsAffectSemanticDiagnostics,
            compilerOptionsDidYouMeanDiagnostics: () => compilerOptionsDidYouMeanDiagnostics,
            compilerOptionsIndicateEsModules: () => compilerOptionsIndicateEsModules,
            compose: () => compose,
            computeCommonSourceDirectoryOfFilenames: () => computeCommonSourceDirectoryOfFilenames,
            computeLineAndCharacterOfPosition: () => computeLineAndCharacterOfPosition,
            computeLineOfPosition: () => computeLineOfPosition,
            computeLineStarts: () => computeLineStarts,
            computePositionOfLineAndCharacter: () => computePositionOfLineAndCharacter,
            computeSignature: () => computeSignature,
            computeSignatureWithDiagnostics: () => computeSignatureWithDiagnostics,
            computeSuggestionDiagnostics: () => computeSuggestionDiagnostics,
            computedOptions: () => computedOptions,
            concatenate: () => concatenate,
            concatenateDiagnosticMessageChains: () => concatenateDiagnosticMessageChains,
            consumesNodeCoreModules: () => consumesNodeCoreModules,
            contains: () => contains,
            containsIgnoredPath: () => containsIgnoredPath,
            containsObjectRestOrSpread: () => containsObjectRestOrSpread,
            containsParseError: () => containsParseError,
            containsPath: () => containsPath,
            convertCompilerOptionsForTelemetry: () => convertCompilerOptionsForTelemetry,
            convertCompilerOptionsFromJson: () => convertCompilerOptionsFromJson,
            convertJsonOption: () => convertJsonOption,
            convertToBase64: () => convertToBase64,
            convertToJson: () => convertToJson,
            convertToObject: () => convertToObject,
            convertToOptionsWithAbsolutePaths: () => convertToOptionsWithAbsolutePaths,
            convertToRelativePath: () => convertToRelativePath,
            convertToTSConfig: () => convertToTSConfig,
            convertTypeAcquisitionFromJson: () => convertTypeAcquisitionFromJson,
            copyComments: () => copyComments,
            copyEntries: () => copyEntries,
            copyLeadingComments: () => copyLeadingComments,
            copyProperties: () => copyProperties,
            copyTrailingAsLeadingComments: () => copyTrailingAsLeadingComments,
            copyTrailingComments: () => copyTrailingComments,
            couldStartTrivia: () => couldStartTrivia,
            countWhere: () => countWhere,
            createAbstractBuilder: () => createAbstractBuilder,
            createAccessorPropertyBackingField: () => createAccessorPropertyBackingField,
            createAccessorPropertyGetRedirector: () => createAccessorPropertyGetRedirector,
            createAccessorPropertySetRedirector: () => createAccessorPropertySetRedirector,
            createBaseNodeFactory: () => createBaseNodeFactory,
            createBinaryExpressionTrampoline: () => createBinaryExpressionTrampoline,
            createBindingHelper: () => createBindingHelper,
            createBuildInfo: () => createBuildInfo,
            createBuilderProgram: () => createBuilderProgram,
            createBuilderProgramUsingProgramBuildInfo: () => createBuilderProgramUsingProgramBuildInfo,
            createBuilderStatusReporter: () => createBuilderStatusReporter,
            createCacheWithRedirects: () => createCacheWithRedirects,
            createCacheableExportInfoMap: () => createCacheableExportInfoMap,
            createCachedDirectoryStructureHost: () => createCachedDirectoryStructureHost,
            createClassNamedEvaluationHelperBlock: () => createClassNamedEvaluationHelperBlock,
            createClassThisAssignmentBlock: () => createClassThisAssignmentBlock,
            createClassifier: () => createClassifier,
            createCommentDirectivesMap: () => createCommentDirectivesMap,
            createCompilerDiagnostic: () => createCompilerDiagnostic,
            createCompilerDiagnosticForInvalidCustomType: () => createCompilerDiagnosticForInvalidCustomType,
            createCompilerDiagnosticFromMessageChain: () => createCompilerDiagnosticFromMessageChain,
            createCompilerHost: () => createCompilerHost,
            createCompilerHostFromProgramHost: () => createCompilerHostFromProgramHost,
            createCompilerHostWorker: () => createCompilerHostWorker,
            createDetachedDiagnostic: () => createDetachedDiagnostic,
            createDiagnosticCollection: () => createDiagnosticCollection,
            createDiagnosticForFileFromMessageChain: () => createDiagnosticForFileFromMessageChain,
            createDiagnosticForNode: () => createDiagnosticForNode,
            createDiagnosticForNodeArray: () => createDiagnosticForNodeArray,
            createDiagnosticForNodeArrayFromMessageChain: () => createDiagnosticForNodeArrayFromMessageChain,
            createDiagnosticForNodeFromMessageChain: () => createDiagnosticForNodeFromMessageChain,
            createDiagnosticForNodeInSourceFile: () => createDiagnosticForNodeInSourceFile,
            createDiagnosticForRange: () => createDiagnosticForRange,
            createDiagnosticMessageChainFromDiagnostic: () => createDiagnosticMessageChainFromDiagnostic,
            createDiagnosticReporter: () => createDiagnosticReporter,
            createDocumentPositionMapper: () => createDocumentPositionMapper,
            createDocumentRegistry: () => createDocumentRegistry,
            createDocumentRegistryInternal: () => createDocumentRegistryInternal,
            createEmitAndSemanticDiagnosticsBuilderProgram: () => createEmitAndSemanticDiagnosticsBuilderProgram,
            createEmitHelperFactory: () => createEmitHelperFactory,
            createEmptyExports: () => createEmptyExports,
            createExpressionForJsxElement: () => createExpressionForJsxElement,
            createExpressionForJsxFragment: () => createExpressionForJsxFragment,
            createExpressionForObjectLiteralElementLike: () => createExpressionForObjectLiteralElementLike,
            createExpressionForPropertyName: () => createExpressionForPropertyName,
            createExpressionFromEntityName: () => createExpressionFromEntityName,
            createExternalHelpersImportDeclarationIfNeeded: () => createExternalHelpersImportDeclarationIfNeeded,
            createFileDiagnostic: () => createFileDiagnostic,
            createFileDiagnosticFromMessageChain: () => createFileDiagnosticFromMessageChain,
            createForOfBindingStatement: () => createForOfBindingStatement,
            createGetCanonicalFileName: () => createGetCanonicalFileName,
            createGetSourceFile: () => createGetSourceFile,
            createGetSymbolAccessibilityDiagnosticForNode: () => createGetSymbolAccessibilityDiagnosticForNode,
            createGetSymbolAccessibilityDiagnosticForNodeName: () => createGetSymbolAccessibilityDiagnosticForNodeName,
            createGetSymbolWalker: () => createGetSymbolWalker,
            createIncrementalCompilerHost: () => createIncrementalCompilerHost,
            createIncrementalProgram: () => createIncrementalProgram,
            createInputFiles: () => createInputFiles,
            createInputFilesWithFilePaths: () => createInputFilesWithFilePaths,
            createInputFilesWithFileTexts: () => createInputFilesWithFileTexts,
            createJsxFactoryExpression: () => createJsxFactoryExpression,
            createLanguageService: () => createLanguageService,
            createLanguageServiceSourceFile: () => createLanguageServiceSourceFile,
            createMemberAccessForPropertyName: () => createMemberAccessForPropertyName,
            createModeAwareCache: () => createModeAwareCache,
            createModeAwareCacheKey: () => createModeAwareCacheKey,
            createModuleNotFoundChain: () => createModuleNotFoundChain,
            createModuleResolutionCache: () => createModuleResolutionCache,
            createModuleResolutionLoader: () => createModuleResolutionLoader,
            createModuleResolutionLoaderUsingGlobalCache: () => createModuleResolutionLoaderUsingGlobalCache,
            createModuleSpecifierResolutionHost: () => createModuleSpecifierResolutionHost,
            createMultiMap: () => createMultiMap,
            createNodeConverters: () => createNodeConverters,
            createNodeFactory: () => createNodeFactory,
            createOptionNameMap: () => createOptionNameMap,
            createOverload: () => createOverload,
            createPackageJsonImportFilter: () => createPackageJsonImportFilter,
            createPackageJsonInfo: () => createPackageJsonInfo,
            createParenthesizerRules: () => createParenthesizerRules,
            createPatternMatcher: () => createPatternMatcher,
            createPrependNodes: () => createPrependNodes,
            createPrinter: () => createPrinter,
            createPrinterWithDefaults: () => createPrinterWithDefaults,
            createPrinterWithRemoveComments: () => createPrinterWithRemoveComments,
            createPrinterWithRemoveCommentsNeverAsciiEscape: () => createPrinterWithRemoveCommentsNeverAsciiEscape,
            createPrinterWithRemoveCommentsOmitTrailingSemicolon: () => createPrinterWithRemoveCommentsOmitTrailingSemicolon,
            createProgram: () => createProgram,
            createProgramHost: () => createProgramHost,
            createPropertyNameNodeForIdentifierOrLiteral: () => createPropertyNameNodeForIdentifierOrLiteral,
            createQueue: () => createQueue,
            createRange: () => createRange,
            createRedirectedBuilderProgram: () => createRedirectedBuilderProgram,
            createResolutionCache: () => createResolutionCache,
            createRuntimeTypeSerializer: () => createRuntimeTypeSerializer,
            createScanner: () => createScanner,
            createSemanticDiagnosticsBuilderProgram: () => createSemanticDiagnosticsBuilderProgram,
            createSet: () => createSet,
            createSolutionBuilder: () => createSolutionBuilder,
            createSolutionBuilderHost: () => createSolutionBuilderHost,
            createSolutionBuilderWithWatch: () => createSolutionBuilderWithWatch,
            createSolutionBuilderWithWatchHost: () => createSolutionBuilderWithWatchHost,
            createSortedArray: () => createSortedArray,
            createSourceFile: () => createSourceFile,
            createSourceMapGenerator: () => createSourceMapGenerator,
            createSourceMapSource: () => createSourceMapSource,
            createSuperAccessVariableStatement: () => createSuperAccessVariableStatement,
            createSymbolTable: () => createSymbolTable,
            createSymlinkCache: () => createSymlinkCache,
            createSystemWatchFunctions: () => createSystemWatchFunctions,
            createTextChange: () => createTextChange,
            createTextChangeFromStartLength: () => createTextChangeFromStartLength,
            createTextChangeRange: () => createTextChangeRange,
            createTextRangeFromNode: () => createTextRangeFromNode,
            createTextRangeFromSpan: () => createTextRangeFromSpan,
            createTextSpan: () => createTextSpan,
            createTextSpanFromBounds: () => createTextSpanFromBounds,
            createTextSpanFromNode: () => createTextSpanFromNode,
            createTextSpanFromRange: () => createTextSpanFromRange,
            createTextSpanFromStringLiteralLikeContent: () => createTextSpanFromStringLiteralLikeContent,
            createTextWriter: () => createTextWriter,
            createTokenRange: () => createTokenRange,
            createTypeChecker: () => createTypeChecker,
            createTypeReferenceDirectiveResolutionCache: () => createTypeReferenceDirectiveResolutionCache,
            createTypeReferenceResolutionLoader: () => createTypeReferenceResolutionLoader,
            createUnparsedSourceFile: () => createUnparsedSourceFile,
            createWatchCompilerHost: () => createWatchCompilerHost2,
            createWatchCompilerHostOfConfigFile: () => createWatchCompilerHostOfConfigFile,
            createWatchCompilerHostOfFilesAndCompilerOptions: () => createWatchCompilerHostOfFilesAndCompilerOptions,
            createWatchFactory: () => createWatchFactory,
            createWatchHost: () => createWatchHost,
            createWatchProgram: () => createWatchProgram,
            createWatchStatusReporter: () => createWatchStatusReporter,
            createWriteFileMeasuringIO: () => createWriteFileMeasuringIO,
            declarationNameToString: () => declarationNameToString,
            decodeMappings: () => decodeMappings,
            decodedTextSpanIntersectsWith: () => decodedTextSpanIntersectsWith,
            decorateHelper: () => decorateHelper,
            deduplicate: () => deduplicate,
            defaultIncludeSpec: () => defaultIncludeSpec,
            defaultInitCompilerOptions: () => defaultInitCompilerOptions,
            defaultMaximumTruncationLength: () => defaultMaximumTruncationLength,
            detectSortCaseSensitivity: () => detectSortCaseSensitivity,
            diagnosticCategoryName: () => diagnosticCategoryName,
            diagnosticToString: () => diagnosticToString,
            directoryProbablyExists: () => directoryProbablyExists,
            directorySeparator: () => directorySeparator,
            displayPart: () => displayPart,
            displayPartsToString: () => displayPartsToString,
            disposeEmitNodes: () => disposeEmitNodes,
            disposeResourcesHelper: () => disposeResourcesHelper,
            documentSpansEqual: () => documentSpansEqual,
            dumpTracingLegend: () => dumpTracingLegend,
            elementAt: () => elementAt,
            elideNodes: () => elideNodes,
            emitComments: () => emitComments,
            emitDetachedComments: () => emitDetachedComments,
            emitFiles: () => emitFiles,
            emitFilesAndReportErrors: () => emitFilesAndReportErrors,
            emitFilesAndReportErrorsAndGetExitStatus: () => emitFilesAndReportErrorsAndGetExitStatus,
            emitModuleKindIsNonNodeESM: () => emitModuleKindIsNonNodeESM,
            emitNewLineBeforeLeadingCommentOfPosition: () => emitNewLineBeforeLeadingCommentOfPosition,
            emitNewLineBeforeLeadingComments: () => emitNewLineBeforeLeadingComments,
            emitNewLineBeforeLeadingCommentsOfPosition: () => emitNewLineBeforeLeadingCommentsOfPosition,
            emitSkippedWithNoDiagnostics: () => emitSkippedWithNoDiagnostics,
            emitUsingBuildInfo: () => emitUsingBuildInfo,
            emptyArray: () => emptyArray,
            emptyFileSystemEntries: () => emptyFileSystemEntries,
            emptyMap: () => emptyMap,
            emptyOptions: () => emptyOptions,
            emptySet: () => emptySet,
            endsWith: () => endsWith,
            ensurePathIsNonModuleName: () => ensurePathIsNonModuleName,
            ensureScriptKind: () => ensureScriptKind,
            ensureTrailingDirectorySeparator: () => ensureTrailingDirectorySeparator,
            entityNameToString: () => entityNameToString,
            enumerateInsertsAndDeletes: () => enumerateInsertsAndDeletes,
            equalOwnProperties: () => equalOwnProperties,
            equateStringsCaseInsensitive: () => equateStringsCaseInsensitive,
            equateStringsCaseSensitive: () => equateStringsCaseSensitive,
            equateValues: () => equateValues,
            esDecorateHelper: () => esDecorateHelper,
            escapeJsxAttributeString: () => escapeJsxAttributeString,
            escapeLeadingUnderscores: () => escapeLeadingUnderscores,
            escapeNonAsciiString: () => escapeNonAsciiString,
            escapeSnippetText: () => escapeSnippetText,
            escapeString: () => escapeString,
            escapeTemplateSubstitution: () => escapeTemplateSubstitution,
            every: () => every,
            expandPreOrPostfixIncrementOrDecrementExpression: () => expandPreOrPostfixIncrementOrDecrementExpression,
            explainFiles: () => explainFiles,
            explainIfFileIsRedirectAndImpliedFormat: () => explainIfFileIsRedirectAndImpliedFormat,
            exportAssignmentIsAlias: () => exportAssignmentIsAlias,
            exportStarHelper: () => exportStarHelper,
            expressionResultIsUnused: () => expressionResultIsUnused,
            extend: () => extend,
            extendsHelper: () => extendsHelper,
            extensionFromPath: () => extensionFromPath,
            extensionIsTS: () => extensionIsTS,
            extensionsNotSupportingExtensionlessResolution: () => extensionsNotSupportingExtensionlessResolution,
            externalHelpersModuleNameText: () => externalHelpersModuleNameText,
            factory: () => factory,
            fileExtensionIs: () => fileExtensionIs,
            fileExtensionIsOneOf: () => fileExtensionIsOneOf,
            fileIncludeReasonToDiagnostics: () => fileIncludeReasonToDiagnostics,
            fileShouldUseJavaScriptRequire: () => fileShouldUseJavaScriptRequire,
            filter: () => filter,
            filterMutate: () => filterMutate,
            filterSemanticDiagnostics: () => filterSemanticDiagnostics,
            find: () => find,
            findAncestor: () => findAncestor,
            findBestPatternMatch: () => findBestPatternMatch,
            findChildOfKind: () => findChildOfKind,
            findComputedPropertyNameCacheAssignment: () => findComputedPropertyNameCacheAssignment,
            findConfigFile: () => findConfigFile,
            findContainingList: () => findContainingList,
            findDiagnosticForNode: () => findDiagnosticForNode,
            findFirstNonJsxWhitespaceToken: () => findFirstNonJsxWhitespaceToken,
            findIndex: () => findIndex,
            findLast: () => findLast,
            findLastIndex: () => findLastIndex,
            findListItemInfo: () => findListItemInfo,
            findMap: () => findMap,
            findModifier: () => findModifier,
            findNextToken: () => findNextToken,
            findPackageJson: () => findPackageJson,
            findPackageJsons: () => findPackageJsons,
            findPrecedingMatchingToken: () => findPrecedingMatchingToken,
            findPrecedingToken: () => findPrecedingToken,
            findSuperStatementIndexPath: () => findSuperStatementIndexPath,
            findTokenOnLeftOfPosition: () => findTokenOnLeftOfPosition,
            findUseStrictPrologue: () => findUseStrictPrologue,
            first: () => first,
            firstDefined: () => firstDefined,
            firstDefinedIterator: () => firstDefinedIterator,
            firstIterator: () => firstIterator,
            firstOrOnly: () => firstOrOnly,
            firstOrUndefined: () => firstOrUndefined,
            firstOrUndefinedIterator: () => firstOrUndefinedIterator,
            fixupCompilerOptions: () => fixupCompilerOptions,
            flatMap: () => flatMap,
            flatMapIterator: () => flatMapIterator,
            flatMapToMutable: () => flatMapToMutable,
            flatten: () => flatten,
            flattenCommaList: () => flattenCommaList,
            flattenDestructuringAssignment: () => flattenDestructuringAssignment,
            flattenDestructuringBinding: () => flattenDestructuringBinding,
            flattenDiagnosticMessageText: () => flattenDiagnosticMessageText,
            forEach: () => forEach,
            forEachAncestor: () => forEachAncestor,
            forEachAncestorDirectory: () => forEachAncestorDirectory,
            forEachChild: () => forEachChild,
            forEachChildRecursively: () => forEachChildRecursively,
            forEachEmittedFile: () => forEachEmittedFile,
            forEachEnclosingBlockScopeContainer: () => forEachEnclosingBlockScopeContainer,
            forEachEntry: () => forEachEntry,
            forEachExternalModuleToImportFrom: () => forEachExternalModuleToImportFrom,
            forEachImportClauseDeclaration: () => forEachImportClauseDeclaration,
            forEachKey: () => forEachKey,
            forEachLeadingCommentRange: () => forEachLeadingCommentRange,
            forEachNameInAccessChainWalkingLeft: () => forEachNameInAccessChainWalkingLeft,
            forEachPropertyAssignment: () => forEachPropertyAssignment,
            forEachResolvedProjectReference: () => forEachResolvedProjectReference,
            forEachReturnStatement: () => forEachReturnStatement,
            forEachRight: () => forEachRight,
            forEachTrailingCommentRange: () => forEachTrailingCommentRange,
            forEachTsConfigPropArray: () => forEachTsConfigPropArray,
            forEachUnique: () => forEachUnique,
            forEachYieldExpression: () => forEachYieldExpression,
            forSomeAncestorDirectory: () => forSomeAncestorDirectory,
            formatColorAndReset: () => formatColorAndReset,
            formatDiagnostic: () => formatDiagnostic,
            formatDiagnostics: () => formatDiagnostics,
            formatDiagnosticsWithColorAndContext: () => formatDiagnosticsWithColorAndContext,
            formatGeneratedName: () => formatGeneratedName,
            formatGeneratedNamePart: () => formatGeneratedNamePart,
            formatLocation: () => formatLocation,
            formatMessage: () => formatMessage,
            formatStringFromArgs: () => formatStringFromArgs,
            formatting: () => ts_formatting_exports,
            fullTripleSlashAMDReferencePathRegEx: () => fullTripleSlashAMDReferencePathRegEx,
            fullTripleSlashReferencePathRegEx: () => fullTripleSlashReferencePathRegEx,
            generateDjb2Hash: () => generateDjb2Hash,
            generateTSConfig: () => generateTSConfig,
            generatorHelper: () => generatorHelper,
            getAdjustedReferenceLocation: () => getAdjustedReferenceLocation,
            getAdjustedRenameLocation: () => getAdjustedRenameLocation,
            getAliasDeclarationFromName: () => getAliasDeclarationFromName,
            getAllAccessorDeclarations: () => getAllAccessorDeclarations,
            getAllDecoratorsOfClass: () => getAllDecoratorsOfClass,
            getAllDecoratorsOfClassElement: () => getAllDecoratorsOfClassElement,
            getAllJSDocTags: () => getAllJSDocTags,
            getAllJSDocTagsOfKind: () => getAllJSDocTagsOfKind,
            getAllKeys: () => getAllKeys,
            getAllProjectOutputs: () => getAllProjectOutputs,
            getAllSuperTypeNodes: () => getAllSuperTypeNodes,
            getAllUnscopedEmitHelpers: () => getAllUnscopedEmitHelpers,
            getAllowJSCompilerOption: () => getAllowJSCompilerOption,
            getAllowSyntheticDefaultImports: () => getAllowSyntheticDefaultImports,
            getAncestor: () => getAncestor,
            getAnyExtensionFromPath: () => getAnyExtensionFromPath,
            getAreDeclarationMapsEnabled: () => getAreDeclarationMapsEnabled,
            getAssignedExpandoInitializer: () => getAssignedExpandoInitializer,
            getAssignedName: () => getAssignedName,
            getAssignedNameOfIdentifier: () => getAssignedNameOfIdentifier,
            getAssignmentDeclarationKind: () => getAssignmentDeclarationKind,
            getAssignmentDeclarationPropertyAccessKind: () => getAssignmentDeclarationPropertyAccessKind,
            getAssignmentTargetKind: () => getAssignmentTargetKind,
            getAutomaticTypeDirectiveNames: () => getAutomaticTypeDirectiveNames,
            getBaseFileName: () => getBaseFileName,
            getBinaryOperatorPrecedence: () => getBinaryOperatorPrecedence,
            getBuildInfo: () => getBuildInfo,
            getBuildInfoFileVersionMap: () => getBuildInfoFileVersionMap,
            getBuildInfoText: () => getBuildInfoText,
            getBuildOrderFromAnyBuildOrder: () => getBuildOrderFromAnyBuildOrder,
            getBuilderCreationParameters: () => getBuilderCreationParameters,
            getBuilderFileEmit: () => getBuilderFileEmit,
            getCheckFlags: () => getCheckFlags,
            getClassExtendsHeritageElement: () => getClassExtendsHeritageElement,
            getClassLikeDeclarationOfSymbol: () => getClassLikeDeclarationOfSymbol,
            getCombinedLocalAndExportSymbolFlags: () => getCombinedLocalAndExportSymbolFlags,
            getCombinedModifierFlags: () => getCombinedModifierFlags,
            getCombinedNodeFlags: () => getCombinedNodeFlags,
            getCombinedNodeFlagsAlwaysIncludeJSDoc: () => getCombinedNodeFlagsAlwaysIncludeJSDoc,
            getCommentRange: () => getCommentRange,
            getCommonSourceDirectory: () => getCommonSourceDirectory,
            getCommonSourceDirectoryOfConfig: () => getCommonSourceDirectoryOfConfig,
            getCompilerOptionValue: () => getCompilerOptionValue,
            getCompilerOptionsDiffValue: () => getCompilerOptionsDiffValue,
            getConditions: () => getConditions,
            getConfigFileParsingDiagnostics: () => getConfigFileParsingDiagnostics,
            getConstantValue: () => getConstantValue,
            getContainerFlags: () => getContainerFlags,
            getContainerNode: () => getContainerNode,
            getContainingClass: () => getContainingClass,
            getContainingClassExcludingClassDecorators: () => getContainingClassExcludingClassDecorators,
            getContainingClassStaticBlock: () => getContainingClassStaticBlock,
            getContainingFunction: () => getContainingFunction,
            getContainingFunctionDeclaration: () => getContainingFunctionDeclaration,
            getContainingFunctionOrClassStaticBlock: () => getContainingFunctionOrClassStaticBlock,
            getContainingNodeArray: () => getContainingNodeArray,
            getContainingObjectLiteralElement: () => getContainingObjectLiteralElement,
            getContextualTypeFromParent: () => getContextualTypeFromParent,
            getContextualTypeFromParentOrAncestorTypeNode: () => getContextualTypeFromParentOrAncestorTypeNode,
            getCurrentTime: () => getCurrentTime,
            getDeclarationDiagnostics: () => getDeclarationDiagnostics,
            getDeclarationEmitExtensionForPath: () => getDeclarationEmitExtensionForPath,
            getDeclarationEmitOutputFilePath: () => getDeclarationEmitOutputFilePath,
            getDeclarationEmitOutputFilePathWorker: () => getDeclarationEmitOutputFilePathWorker,
            getDeclarationFileExtension: () => getDeclarationFileExtension,
            getDeclarationFromName: () => getDeclarationFromName,
            getDeclarationModifierFlagsFromSymbol: () => getDeclarationModifierFlagsFromSymbol,
            getDeclarationOfKind: () => getDeclarationOfKind,
            getDeclarationsOfKind: () => getDeclarationsOfKind,
            getDeclaredExpandoInitializer: () => getDeclaredExpandoInitializer,
            getDecorators: () => getDecorators,
            getDefaultCompilerOptions: () => getDefaultCompilerOptions2,
            getDefaultExportInfoWorker: () => getDefaultExportInfoWorker,
            getDefaultFormatCodeSettings: () => getDefaultFormatCodeSettings,
            getDefaultLibFileName: () => getDefaultLibFileName,
            getDefaultLibFilePath: () => getDefaultLibFilePath,
            getDefaultLikeExportInfo: () => getDefaultLikeExportInfo,
            getDiagnosticText: () => getDiagnosticText,
            getDiagnosticsWithinSpan: () => getDiagnosticsWithinSpan,
            getDirectoryPath: () => getDirectoryPath,
            getDirectoryToWatchFailedLookupLocation: () => getDirectoryToWatchFailedLookupLocation,
            getDirectoryToWatchFailedLookupLocationFromTypeRoot: () => getDirectoryToWatchFailedLookupLocationFromTypeRoot,
            getDocumentPositionMapper: () => getDocumentPositionMapper,
            getDocumentSpansEqualityComparer: () => getDocumentSpansEqualityComparer,
            getESModuleInterop: () => getESModuleInterop,
            getEditsForFileRename: () => getEditsForFileRename,
            getEffectiveBaseTypeNode: () => getEffectiveBaseTypeNode,
            getEffectiveConstraintOfTypeParameter: () => getEffectiveConstraintOfTypeParameter,
            getEffectiveContainerForJSDocTemplateTag: () => getEffectiveContainerForJSDocTemplateTag,
            getEffectiveImplementsTypeNodes: () => getEffectiveImplementsTypeNodes,
            getEffectiveInitializer: () => getEffectiveInitializer,
            getEffectiveJSDocHost: () => getEffectiveJSDocHost,
            getEffectiveModifierFlags: () => getEffectiveModifierFlags,
            getEffectiveModifierFlagsAlwaysIncludeJSDoc: () => getEffectiveModifierFlagsAlwaysIncludeJSDoc,
            getEffectiveModifierFlagsNoCache: () => getEffectiveModifierFlagsNoCache,
            getEffectiveReturnTypeNode: () => getEffectiveReturnTypeNode,
            getEffectiveSetAccessorTypeAnnotationNode: () => getEffectiveSetAccessorTypeAnnotationNode,
            getEffectiveTypeAnnotationNode: () => getEffectiveTypeAnnotationNode,
            getEffectiveTypeParameterDeclarations: () => getEffectiveTypeParameterDeclarations,
            getEffectiveTypeRoots: () => getEffectiveTypeRoots,
            getElementOrPropertyAccessArgumentExpressionOrName: () => getElementOrPropertyAccessArgumentExpressionOrName,
            getElementOrPropertyAccessName: () => getElementOrPropertyAccessName,
            getElementsOfBindingOrAssignmentPattern: () => getElementsOfBindingOrAssignmentPattern,
            getEmitDeclarations: () => getEmitDeclarations,
            getEmitFlags: () => getEmitFlags,
            getEmitHelpers: () => getEmitHelpers,
            getEmitModuleDetectionKind: () => getEmitModuleDetectionKind,
            getEmitModuleKind: () => getEmitModuleKind,
            getEmitModuleResolutionKind: () => getEmitModuleResolutionKind,
            getEmitScriptTarget: () => getEmitScriptTarget,
            getEmitStandardClassFields: () => getEmitStandardClassFields,
            getEnclosingBlockScopeContainer: () => getEnclosingBlockScopeContainer,
            getEnclosingContainer: () => getEnclosingContainer,
            getEncodedSemanticClassifications: () => getEncodedSemanticClassifications,
            getEncodedSyntacticClassifications: () => getEncodedSyntacticClassifications,
            getEndLinePosition: () => getEndLinePosition,
            getEntityNameFromTypeNode: () => getEntityNameFromTypeNode,
            getEntrypointsFromPackageJsonInfo: () => getEntrypointsFromPackageJsonInfo,
            getErrorCountForSummary: () => getErrorCountForSummary,
            getErrorSpanForNode: () => getErrorSpanForNode,
            getErrorSummaryText: () => getErrorSummaryText,
            getEscapedTextOfIdentifierOrLiteral: () => getEscapedTextOfIdentifierOrLiteral,
            getEscapedTextOfJsxAttributeName: () => getEscapedTextOfJsxAttributeName,
            getEscapedTextOfJsxNamespacedName: () => getEscapedTextOfJsxNamespacedName,
            getExpandoInitializer: () => getExpandoInitializer,
            getExportAssignmentExpression: () => getExportAssignmentExpression,
            getExportInfoMap: () => getExportInfoMap,
            getExportNeedsImportStarHelper: () => getExportNeedsImportStarHelper,
            getExpressionAssociativity: () => getExpressionAssociativity,
            getExpressionPrecedence: () => getExpressionPrecedence,
            getExternalHelpersModuleName: () => getExternalHelpersModuleName,
            getExternalModuleImportEqualsDeclarationExpression: () => getExternalModuleImportEqualsDeclarationExpression,
            getExternalModuleName: () => getExternalModuleName,
            getExternalModuleNameFromDeclaration: () => getExternalModuleNameFromDeclaration,
            getExternalModuleNameFromPath: () => getExternalModuleNameFromPath,
            getExternalModuleNameLiteral: () => getExternalModuleNameLiteral,
            getExternalModuleRequireArgument: () => getExternalModuleRequireArgument,
            getFallbackOptions: () => getFallbackOptions,
            getFileEmitOutput: () => getFileEmitOutput,
            getFileMatcherPatterns: () => getFileMatcherPatterns,
            getFileNamesFromConfigSpecs: () => getFileNamesFromConfigSpecs,
            getFileWatcherEventKind: () => getFileWatcherEventKind,
            getFilesInErrorForSummary: () => getFilesInErrorForSummary,
            getFirstConstructorWithBody: () => getFirstConstructorWithBody,
            getFirstIdentifier: () => getFirstIdentifier,
            getFirstNonSpaceCharacterPosition: () => getFirstNonSpaceCharacterPosition,
            getFirstProjectOutput: () => getFirstProjectOutput,
            getFixableErrorSpanExpression: () => getFixableErrorSpanExpression,
            getFormatCodeSettingsForWriting: () => getFormatCodeSettingsForWriting,
            getFullWidth: () => getFullWidth,
            getFunctionFlags: () => getFunctionFlags,
            getHeritageClause: () => getHeritageClause,
            getHostSignatureFromJSDoc: () => getHostSignatureFromJSDoc,
            getIdentifierAutoGenerate: () => getIdentifierAutoGenerate,
            getIdentifierGeneratedImportReference: () => getIdentifierGeneratedImportReference,
            getIdentifierTypeArguments: () => getIdentifierTypeArguments,
            getImmediatelyInvokedFunctionExpression: () => getImmediatelyInvokedFunctionExpression,
            getImpliedNodeFormatForFile: () => getImpliedNodeFormatForFile,
            getImpliedNodeFormatForFileWorker: () => getImpliedNodeFormatForFileWorker,
            getImportNeedsImportDefaultHelper: () => getImportNeedsImportDefaultHelper,
            getImportNeedsImportStarHelper: () => getImportNeedsImportStarHelper,
            getIndentSize: () => getIndentSize,
            getIndentString: () => getIndentString,
            getInferredLibraryNameResolveFrom: () => getInferredLibraryNameResolveFrom,
            getInitializedVariables: () => getInitializedVariables,
            getInitializerOfBinaryExpression: () => getInitializerOfBinaryExpression,
            getInitializerOfBindingOrAssignmentElement: () => getInitializerOfBindingOrAssignmentElement,
            getInterfaceBaseTypeNodes: () => getInterfaceBaseTypeNodes,
            getInternalEmitFlags: () => getInternalEmitFlags,
            getInvokedExpression: () => getInvokedExpression,
            getIsolatedModules: () => getIsolatedModules,
            getJSDocAugmentsTag: () => getJSDocAugmentsTag,
            getJSDocClassTag: () => getJSDocClassTag,
            getJSDocCommentRanges: () => getJSDocCommentRanges,
            getJSDocCommentsAndTags: () => getJSDocCommentsAndTags,
            getJSDocDeprecatedTag: () => getJSDocDeprecatedTag,
            getJSDocDeprecatedTagNoCache: () => getJSDocDeprecatedTagNoCache,
            getJSDocEnumTag: () => getJSDocEnumTag,
            getJSDocHost: () => getJSDocHost,
            getJSDocImplementsTags: () => getJSDocImplementsTags,
            getJSDocOverloadTags: () => getJSDocOverloadTags,
            getJSDocOverrideTagNoCache: () => getJSDocOverrideTagNoCache,
            getJSDocParameterTags: () => getJSDocParameterTags,
            getJSDocParameterTagsNoCache: () => getJSDocParameterTagsNoCache,
            getJSDocPrivateTag: () => getJSDocPrivateTag,
            getJSDocPrivateTagNoCache: () => getJSDocPrivateTagNoCache,
            getJSDocProtectedTag: () => getJSDocProtectedTag,
            getJSDocProtectedTagNoCache: () => getJSDocProtectedTagNoCache,
            getJSDocPublicTag: () => getJSDocPublicTag,
            getJSDocPublicTagNoCache: () => getJSDocPublicTagNoCache,
            getJSDocReadonlyTag: () => getJSDocReadonlyTag,
            getJSDocReadonlyTagNoCache: () => getJSDocReadonlyTagNoCache,
            getJSDocReturnTag: () => getJSDocReturnTag,
            getJSDocReturnType: () => getJSDocReturnType,
            getJSDocRoot: () => getJSDocRoot,
            getJSDocSatisfiesExpressionType: () => getJSDocSatisfiesExpressionType,
            getJSDocSatisfiesTag: () => getJSDocSatisfiesTag,
            getJSDocTags: () => getJSDocTags,
            getJSDocTagsNoCache: () => getJSDocTagsNoCache,
            getJSDocTemplateTag: () => getJSDocTemplateTag,
            getJSDocThisTag: () => getJSDocThisTag,
            getJSDocType: () => getJSDocType,
            getJSDocTypeAliasName: () => getJSDocTypeAliasName,
            getJSDocTypeAssertionType: () => getJSDocTypeAssertionType,
            getJSDocTypeParameterDeclarations: () => getJSDocTypeParameterDeclarations,
            getJSDocTypeParameterTags: () => getJSDocTypeParameterTags,
            getJSDocTypeParameterTagsNoCache: () => getJSDocTypeParameterTagsNoCache,
            getJSDocTypeTag: () => getJSDocTypeTag,
            getJSXImplicitImportBase: () => getJSXImplicitImportBase,
            getJSXRuntimeImport: () => getJSXRuntimeImport,
            getJSXTransformEnabled: () => getJSXTransformEnabled,
            getKeyForCompilerOptions: () => getKeyForCompilerOptions,
            getLanguageVariant: () => getLanguageVariant,
            getLastChild: () => getLastChild,
            getLeadingCommentRanges: () => getLeadingCommentRanges,
            getLeadingCommentRangesOfNode: () => getLeadingCommentRangesOfNode,
            getLeftmostAccessExpression: () => getLeftmostAccessExpression,
            getLeftmostExpression: () => getLeftmostExpression,
            getLibraryNameFromLibFileName: () => getLibraryNameFromLibFileName,
            getLineAndCharacterOfPosition: () => getLineAndCharacterOfPosition,
            getLineInfo: () => getLineInfo,
            getLineOfLocalPosition: () => getLineOfLocalPosition,
            getLineOfLocalPositionFromLineMap: () => getLineOfLocalPositionFromLineMap,
            getLineStartPositionForPosition: () => getLineStartPositionForPosition,
            getLineStarts: () => getLineStarts,
            getLinesBetweenPositionAndNextNonWhitespaceCharacter: () => getLinesBetweenPositionAndNextNonWhitespaceCharacter,
            getLinesBetweenPositionAndPrecedingNonWhitespaceCharacter: () => getLinesBetweenPositionAndPrecedingNonWhitespaceCharacter,
            getLinesBetweenPositions: () => getLinesBetweenPositions,
            getLinesBetweenRangeEndAndRangeStart: () => getLinesBetweenRangeEndAndRangeStart,
            getLinesBetweenRangeEndPositions: () => getLinesBetweenRangeEndPositions,
            getLiteralText: () => getLiteralText,
            getLocalNameForExternalImport: () => getLocalNameForExternalImport,
            getLocalSymbolForExportDefault: () => getLocalSymbolForExportDefault,
            getLocaleSpecificMessage: () => getLocaleSpecificMessage,
            getLocaleTimeString: () => getLocaleTimeString,
            getMappedContextSpan: () => getMappedContextSpan,
            getMappedDocumentSpan: () => getMappedDocumentSpan,
            getMappedLocation: () => getMappedLocation,
            getMatchedFileSpec: () => getMatchedFileSpec,
            getMatchedIncludeSpec: () => getMatchedIncludeSpec,
            getMeaningFromDeclaration: () => getMeaningFromDeclaration,
            getMeaningFromLocation: () => getMeaningFromLocation,
            getMembersOfDeclaration: () => getMembersOfDeclaration,
            getModeForFileReference: () => getModeForFileReference,
            getModeForResolutionAtIndex: () => getModeForResolutionAtIndex,
            getModeForUsageLocation: () => getModeForUsageLocation,
            getModifiedTime: () => getModifiedTime,
            getModifiers: () => getModifiers,
            getModuleInstanceState: () => getModuleInstanceState,
            getModuleNameStringLiteralAt: () => getModuleNameStringLiteralAt,
            getModuleSpecifierEndingPreference: () => getModuleSpecifierEndingPreference,
            getModuleSpecifierResolverHost: () => getModuleSpecifierResolverHost,
            getNameForExportedSymbol: () => getNameForExportedSymbol,
            getNameFromImportAttribute: () => getNameFromImportAttribute,
            getNameFromIndexInfo: () => getNameFromIndexInfo,
            getNameFromPropertyName: () => getNameFromPropertyName,
            getNameOfAccessExpression: () => getNameOfAccessExpression,
            getNameOfCompilerOptionValue: () => getNameOfCompilerOptionValue,
            getNameOfDeclaration: () => getNameOfDeclaration,
            getNameOfExpando: () => getNameOfExpando,
            getNameOfJSDocTypedef: () => getNameOfJSDocTypedef,
            getNameOrArgument: () => getNameOrArgument,
            getNameTable: () => getNameTable,
            getNamesForExportedSymbol: () => getNamesForExportedSymbol,
            getNamespaceDeclarationNode: () => getNamespaceDeclarationNode,
            getNewLineCharacter: () => getNewLineCharacter,
            getNewLineKind: () => getNewLineKind,
            getNewLineOrDefaultFromHost: () => getNewLineOrDefaultFromHost,
            getNewTargetContainer: () => getNewTargetContainer,
            getNextJSDocCommentLocation: () => getNextJSDocCommentLocation,
            getNodeForGeneratedName: () => getNodeForGeneratedName,
            getNodeId: () => getNodeId,
            getNodeKind: () => getNodeKind,
            getNodeModifiers: () => getNodeModifiers,
            getNodeModulePathParts: () => getNodeModulePathParts,
            getNonAssignedNameOfDeclaration: () => getNonAssignedNameOfDeclaration,
            getNonAssignmentOperatorForCompoundAssignment: () => getNonAssignmentOperatorForCompoundAssignment,
            getNonAugmentationDeclaration: () => getNonAugmentationDeclaration,
            getNonDecoratorTokenPosOfNode: () => getNonDecoratorTokenPosOfNode,
            getNormalizedAbsolutePath: () => getNormalizedAbsolutePath,
            getNormalizedAbsolutePathWithoutRoot: () => getNormalizedAbsolutePathWithoutRoot,
            getNormalizedPathComponents: () => getNormalizedPathComponents,
            getObjectFlags: () => getObjectFlags,
            getOperator: () => getOperator,
            getOperatorAssociativity: () => getOperatorAssociativity,
            getOperatorPrecedence: () => getOperatorPrecedence,
            getOptionFromName: () => getOptionFromName,
            getOptionsForLibraryResolution: () => getOptionsForLibraryResolution,
            getOptionsNameMap: () => getOptionsNameMap,
            getOrCreateEmitNode: () => getOrCreateEmitNode,
            getOrCreateExternalHelpersModuleNameIfNeeded: () => getOrCreateExternalHelpersModuleNameIfNeeded,
            getOrUpdate: () => getOrUpdate,
            getOriginalNode: () => getOriginalNode,
            getOriginalNodeId: () => getOriginalNodeId,
            getOriginalSourceFile: () => getOriginalSourceFile,
            getOutputDeclarationFileName: () => getOutputDeclarationFileName,
            getOutputDeclarationFileNameWorker: () => getOutputDeclarationFileNameWorker,
            getOutputExtension: () => getOutputExtension,
            getOutputFileNames: () => getOutputFileNames,
            getOutputJSFileNameWorker: () => getOutputJSFileNameWorker,
            getOutputPathsFor: () => getOutputPathsFor,
            getOutputPathsForBundle: () => getOutputPathsForBundle,
            getOwnEmitOutputFilePath: () => getOwnEmitOutputFilePath,
            getOwnKeys: () => getOwnKeys,
            getOwnValues: () => getOwnValues,
            getPackageJsonInfo: () => getPackageJsonInfo,
            getPackageJsonTypesVersionsPaths: () => getPackageJsonTypesVersionsPaths,
            getPackageJsonsVisibleToFile: () => getPackageJsonsVisibleToFile,
            getPackageNameFromTypesPackageName: () => getPackageNameFromTypesPackageName,
            getPackageScopeForPath: () => getPackageScopeForPath,
            getParameterSymbolFromJSDoc: () => getParameterSymbolFromJSDoc,
            getParameterTypeNode: () => getParameterTypeNode,
            getParentNodeInSpan: () => getParentNodeInSpan,
            getParseTreeNode: () => getParseTreeNode,
            getParsedCommandLineOfConfigFile: () => getParsedCommandLineOfConfigFile,
            getPathComponents: () => getPathComponents,
            getPathComponentsRelativeTo: () => getPathComponentsRelativeTo,
            getPathFromPathComponents: () => getPathFromPathComponents,
            getPathUpdater: () => getPathUpdater,
            getPathsBasePath: () => getPathsBasePath,
            getPatternFromSpec: () => getPatternFromSpec,
            getPendingEmitKind: () => getPendingEmitKind,
            getPositionOfLineAndCharacter: () => getPositionOfLineAndCharacter,
            getPossibleGenericSignatures: () => getPossibleGenericSignatures,
            getPossibleOriginalInputExtensionForExtension: () => getPossibleOriginalInputExtensionForExtension,
            getPossibleTypeArgumentsInfo: () => getPossibleTypeArgumentsInfo,
            getPreEmitDiagnostics: () => getPreEmitDiagnostics,
            getPrecedingNonSpaceCharacterPosition: () => getPrecedingNonSpaceCharacterPosition,
            getPrivateIdentifier: () => getPrivateIdentifier,
            getProperties: () => getProperties,
            getProperty: () => getProperty,
            getPropertyArrayElementValue: () => getPropertyArrayElementValue,
            getPropertyAssignmentAliasLikeExpression: () => getPropertyAssignmentAliasLikeExpression,
            getPropertyNameForPropertyNameNode: () => getPropertyNameForPropertyNameNode,
            getPropertyNameForUniqueESSymbol: () => getPropertyNameForUniqueESSymbol,
            getPropertyNameFromType: () => getPropertyNameFromType,
            getPropertyNameOfBindingOrAssignmentElement: () => getPropertyNameOfBindingOrAssignmentElement,
            getPropertySymbolFromBindingElement: () => getPropertySymbolFromBindingElement,
            getPropertySymbolsFromContextualType: () => getPropertySymbolsFromContextualType,
            getQuoteFromPreference: () => getQuoteFromPreference,
            getQuotePreference: () => getQuotePreference,
            getRangesWhere: () => getRangesWhere,
            getRefactorContextSpan: () => getRefactorContextSpan,
            getReferencedFileLocation: () => getReferencedFileLocation,
            getRegexFromPattern: () => getRegexFromPattern,
            getRegularExpressionForWildcard: () => getRegularExpressionForWildcard,
            getRegularExpressionsForWildcards: () => getRegularExpressionsForWildcards,
            getRelativePathFromDirectory: () => getRelativePathFromDirectory,
            getRelativePathFromFile: () => getRelativePathFromFile,
            getRelativePathToDirectoryOrUrl: () => getRelativePathToDirectoryOrUrl,
            getRenameLocation: () => getRenameLocation,
            getReplacementSpanForContextToken: () => getReplacementSpanForContextToken,
            getResolutionDiagnostic: () => getResolutionDiagnostic,
            getResolutionModeOverride: () => getResolutionModeOverride,
            getResolveJsonModule: () => getResolveJsonModule,
            getResolvePackageJsonExports: () => getResolvePackageJsonExports,
            getResolvePackageJsonImports: () => getResolvePackageJsonImports,
            getResolvedExternalModuleName: () => getResolvedExternalModuleName,
            getRestIndicatorOfBindingOrAssignmentElement: () => getRestIndicatorOfBindingOrAssignmentElement,
            getRestParameterElementType: () => getRestParameterElementType,
            getRightMostAssignedExpression: () => getRightMostAssignedExpression,
            getRootDeclaration: () => getRootDeclaration,
            getRootDirectoryOfResolutionCache: () => getRootDirectoryOfResolutionCache,
            getRootLength: () => getRootLength,
            getRootPathSplitLength: () => getRootPathSplitLength,
            getScriptKind: () => getScriptKind,
            getScriptKindFromFileName: () => getScriptKindFromFileName,
            getScriptTargetFeatures: () => getScriptTargetFeatures,
            getSelectedEffectiveModifierFlags: () => getSelectedEffectiveModifierFlags,
            getSelectedSyntacticModifierFlags: () => getSelectedSyntacticModifierFlags,
            getSemanticClassifications: () => getSemanticClassifications,
            getSemanticJsxChildren: () => getSemanticJsxChildren,
            getSetAccessorTypeAnnotationNode: () => getSetAccessorTypeAnnotationNode,
            getSetAccessorValueParameter: () => getSetAccessorValueParameter,
            getSetExternalModuleIndicator: () => getSetExternalModuleIndicator,
            getShebang: () => getShebang,
            getSingleInitializerOfVariableStatementOrPropertyDeclaration: () => getSingleInitializerOfVariableStatementOrPropertyDeclaration,
            getSingleVariableOfVariableStatement: () => getSingleVariableOfVariableStatement,
            getSnapshotText: () => getSnapshotText,
            getSnippetElement: () => getSnippetElement,
            getSourceFileOfModule: () => getSourceFileOfModule,
            getSourceFileOfNode: () => getSourceFileOfNode,
            getSourceFilePathInNewDir: () => getSourceFilePathInNewDir,
            getSourceFilePathInNewDirWorker: () => getSourceFilePathInNewDirWorker,
            getSourceFileVersionAsHashFromText: () => getSourceFileVersionAsHashFromText,
            getSourceFilesToEmit: () => getSourceFilesToEmit,
            getSourceMapRange: () => getSourceMapRange,
            getSourceMapper: () => getSourceMapper,
            getSourceTextOfNodeFromSourceFile: () => getSourceTextOfNodeFromSourceFile,
            getSpanOfTokenAtPosition: () => getSpanOfTokenAtPosition,
            getSpellingSuggestion: () => getSpellingSuggestion,
            getStartPositionOfLine: () => getStartPositionOfLine,
            getStartPositionOfRange: () => getStartPositionOfRange,
            getStartsOnNewLine: () => getStartsOnNewLine,
            getStaticPropertiesAndClassStaticBlock: () => getStaticPropertiesAndClassStaticBlock,
            getStrictOptionValue: () => getStrictOptionValue,
            getStringComparer: () => getStringComparer,
            getSubPatternFromSpec: () => getSubPatternFromSpec,
            getSuperCallFromStatement: () => getSuperCallFromStatement,
            getSuperContainer: () => getSuperContainer,
            getSupportedCodeFixes: () => getSupportedCodeFixes,
            getSupportedExtensions: () => getSupportedExtensions,
            getSupportedExtensionsWithJsonIfResolveJsonModule: () => getSupportedExtensionsWithJsonIfResolveJsonModule,
            getSwitchedType: () => getSwitchedType,
            getSymbolId: () => getSymbolId,
            getSymbolNameForPrivateIdentifier: () => getSymbolNameForPrivateIdentifier,
            getSymbolTarget: () => getSymbolTarget,
            getSyntacticClassifications: () => getSyntacticClassifications,
            getSyntacticModifierFlags: () => getSyntacticModifierFlags,
            getSyntacticModifierFlagsNoCache: () => getSyntacticModifierFlagsNoCache,
            getSynthesizedDeepClone: () => getSynthesizedDeepClone,
            getSynthesizedDeepCloneWithReplacements: () => getSynthesizedDeepCloneWithReplacements,
            getSynthesizedDeepClones: () => getSynthesizedDeepClones,
            getSynthesizedDeepClonesWithReplacements: () => getSynthesizedDeepClonesWithReplacements,
            getSyntheticLeadingComments: () => getSyntheticLeadingComments,
            getSyntheticTrailingComments: () => getSyntheticTrailingComments,
            getTargetLabel: () => getTargetLabel,
            getTargetOfBindingOrAssignmentElement: () => getTargetOfBindingOrAssignmentElement,
            getTemporaryModuleResolutionState: () => getTemporaryModuleResolutionState,
            getTextOfConstantValue: () => getTextOfConstantValue,
            getTextOfIdentifierOrLiteral: () => getTextOfIdentifierOrLiteral,
            getTextOfJSDocComment: () => getTextOfJSDocComment,
            getTextOfJsxAttributeName: () => getTextOfJsxAttributeName,
            getTextOfJsxNamespacedName: () => getTextOfJsxNamespacedName,
            getTextOfNode: () => getTextOfNode,
            getTextOfNodeFromSourceText: () => getTextOfNodeFromSourceText,
            getTextOfPropertyName: () => getTextOfPropertyName,
            getThisContainer: () => getThisContainer,
            getThisParameter: () => getThisParameter,
            getTokenAtPosition: () => getTokenAtPosition,
            getTokenPosOfNode: () => getTokenPosOfNode,
            getTokenSourceMapRange: () => getTokenSourceMapRange,
            getTouchingPropertyName: () => getTouchingPropertyName,
            getTouchingToken: () => getTouchingToken,
            getTrailingCommentRanges: () => getTrailingCommentRanges,
            getTrailingSemicolonDeferringWriter: () => getTrailingSemicolonDeferringWriter,
            getTransformFlagsSubtreeExclusions: () => getTransformFlagsSubtreeExclusions,
            getTransformers: () => getTransformers,
            getTsBuildInfoEmitOutputFilePath: () => getTsBuildInfoEmitOutputFilePath,
            getTsConfigObjectLiteralExpression: () => getTsConfigObjectLiteralExpression,
            getTsConfigPropArrayElementValue: () => getTsConfigPropArrayElementValue,
            getTypeAnnotationNode: () => getTypeAnnotationNode,
            getTypeArgumentOrTypeParameterList: () => getTypeArgumentOrTypeParameterList,
            getTypeKeywordOfTypeOnlyImport: () => getTypeKeywordOfTypeOnlyImport,
            getTypeNode: () => getTypeNode,
            getTypeNodeIfAccessible: () => getTypeNodeIfAccessible,
            getTypeParameterFromJsDoc: () => getTypeParameterFromJsDoc,
            getTypeParameterOwner: () => getTypeParameterOwner,
            getTypesPackageName: () => getTypesPackageName,
            getUILocale: () => getUILocale,
            getUniqueName: () => getUniqueName,
            getUniqueSymbolId: () => getUniqueSymbolId,
            getUseDefineForClassFields: () => getUseDefineForClassFields,
            getWatchErrorSummaryDiagnosticMessage: () => getWatchErrorSummaryDiagnosticMessage,
            getWatchFactory: () => getWatchFactory,
            group: () => group,
            groupBy: () => groupBy,
            guessIndentation: () => guessIndentation,
            handleNoEmitOptions: () => handleNoEmitOptions,
            hasAbstractModifier: () => hasAbstractModifier,
            hasAccessorModifier: () => hasAccessorModifier,
            hasAmbientModifier: () => hasAmbientModifier,
            hasChangesInResolutions: () => hasChangesInResolutions,
            hasChildOfKind: () => hasChildOfKind,
            hasContextSensitiveParameters: () => hasContextSensitiveParameters,
            hasDecorators: () => hasDecorators,
            hasDocComment: () => hasDocComment,
            hasDynamicName: () => hasDynamicName,
            hasEffectiveModifier: () => hasEffectiveModifier,
            hasEffectiveModifiers: () => hasEffectiveModifiers,
            hasEffectiveReadonlyModifier: () => hasEffectiveReadonlyModifier,
            hasExtension: () => hasExtension,
            hasIndexSignature: () => hasIndexSignature,
            hasInitializer: () => hasInitializer,
            hasInvalidEscape: () => hasInvalidEscape,
            hasJSDocNodes: () => hasJSDocNodes,
            hasJSDocParameterTags: () => hasJSDocParameterTags,
            hasJSFileExtension: () => hasJSFileExtension,
            hasJsonModuleEmitEnabled: () => hasJsonModuleEmitEnabled,
            hasOnlyExpressionInitializer: () => hasOnlyExpressionInitializer,
            hasOverrideModifier: () => hasOverrideModifier,
            hasPossibleExternalModuleReference: () => hasPossibleExternalModuleReference,
            hasProperty: () => hasProperty,
            hasPropertyAccessExpressionWithName: () => hasPropertyAccessExpressionWithName,
            hasQuestionToken: () => hasQuestionToken,
            hasRecordedExternalHelpers: () => hasRecordedExternalHelpers,
            hasResolutionModeOverride: () => hasResolutionModeOverride,
            hasRestParameter: () => hasRestParameter,
            hasScopeMarker: () => hasScopeMarker,
            hasStaticModifier: () => hasStaticModifier,
            hasSyntacticModifier: () => hasSyntacticModifier,
            hasSyntacticModifiers: () => hasSyntacticModifiers,
            hasTSFileExtension: () => hasTSFileExtension,
            hasTabstop: () => hasTabstop,
            hasTrailingDirectorySeparator: () => hasTrailingDirectorySeparator,
            hasType: () => hasType,
            hasTypeArguments: () => hasTypeArguments,
            hasZeroOrOneAsteriskCharacter: () => hasZeroOrOneAsteriskCharacter,
            helperString: () => helperString,
            hostGetCanonicalFileName: () => hostGetCanonicalFileName,
            hostUsesCaseSensitiveFileNames: () => hostUsesCaseSensitiveFileNames,
            idText: () => idText,
            identifierIsThisKeyword: () => identifierIsThisKeyword,
            identifierToKeywordKind: () => identifierToKeywordKind,
            identity: () => identity,
            identitySourceMapConsumer: () => identitySourceMapConsumer,
            ignoreSourceNewlines: () => ignoreSourceNewlines,
            ignoredPaths: () => ignoredPaths,
            importDefaultHelper: () => importDefaultHelper,
            importFromModuleSpecifier: () => importFromModuleSpecifier,
            importNameElisionDisabled: () => importNameElisionDisabled,
            importStarHelper: () => importStarHelper,
            indexOfAnyCharCode: () => indexOfAnyCharCode,
            indexOfNode: () => indexOfNode,
            indicesOf: () => indicesOf,
            inferredTypesContainingFile: () => inferredTypesContainingFile,
            injectClassNamedEvaluationHelperBlockIfMissing: () => injectClassNamedEvaluationHelperBlockIfMissing,
            injectClassThisAssignmentIfMissing: () => injectClassThisAssignmentIfMissing,
            insertImports: () => insertImports,
            insertLeadingStatement: () => insertLeadingStatement,
            insertSorted: () => insertSorted,
            insertStatementAfterCustomPrologue: () => insertStatementAfterCustomPrologue,
            insertStatementAfterStandardPrologue: () => insertStatementAfterStandardPrologue,
            insertStatementsAfterCustomPrologue: () => insertStatementsAfterCustomPrologue,
            insertStatementsAfterStandardPrologue: () => insertStatementsAfterStandardPrologue,
            intersperse: () => intersperse,
            intrinsicTagNameToString: () => intrinsicTagNameToString,
            introducesArgumentsExoticObject: () => introducesArgumentsExoticObject,
            inverseJsxOptionMap: () => inverseJsxOptionMap,
            isAbstractConstructorSymbol: () => isAbstractConstructorSymbol,
            isAbstractModifier: () => isAbstractModifier,
            isAccessExpression: () => isAccessExpression,
            isAccessibilityModifier: () => isAccessibilityModifier,
            isAccessor: () => isAccessor,
            isAccessorModifier: () => isAccessorModifier,
            isAliasSymbolDeclaration: () => isAliasSymbolDeclaration,
            isAliasableExpression: () => isAliasableExpression,
            isAmbientModule: () => isAmbientModule,
            isAmbientPropertyDeclaration: () => isAmbientPropertyDeclaration,
            isAnonymousFunctionDefinition: () => isAnonymousFunctionDefinition,
            isAnyDirectorySeparator: () => isAnyDirectorySeparator,
            isAnyImportOrBareOrAccessedRequire: () => isAnyImportOrBareOrAccessedRequire,
            isAnyImportOrReExport: () => isAnyImportOrReExport,
            isAnyImportSyntax: () => isAnyImportSyntax,
            isAnySupportedFileExtension: () => isAnySupportedFileExtension,
            isApplicableVersionedTypesKey: () => isApplicableVersionedTypesKey,
            isArgumentExpressionOfElementAccess: () => isArgumentExpressionOfElementAccess,
            isArray: () => isArray,
            isArrayBindingElement: () => isArrayBindingElement,
            isArrayBindingOrAssignmentElement: () => isArrayBindingOrAssignmentElement,
            isArrayBindingOrAssignmentPattern: () => isArrayBindingOrAssignmentPattern,
            isArrayBindingPattern: () => isArrayBindingPattern,
            isArrayLiteralExpression: () => isArrayLiteralExpression,
            isArrayLiteralOrObjectLiteralDestructuringPattern: () => isArrayLiteralOrObjectLiteralDestructuringPattern,
            isArrayTypeNode: () => isArrayTypeNode,
            isArrowFunction: () => isArrowFunction,
            isAsExpression: () => isAsExpression,
            isAssertClause: () => isAssertClause,
            isAssertEntry: () => isAssertEntry,
            isAssertionExpression: () => isAssertionExpression,
            isAssertsKeyword: () => isAssertsKeyword,
            isAssignmentDeclaration: () => isAssignmentDeclaration,
            isAssignmentExpression: () => isAssignmentExpression,
            isAssignmentOperator: () => isAssignmentOperator,
            isAssignmentPattern: () => isAssignmentPattern,
            isAssignmentTarget: () => isAssignmentTarget,
            isAsteriskToken: () => isAsteriskToken,
            isAsyncFunction: () => isAsyncFunction,
            isAsyncModifier: () => isAsyncModifier,
            isAutoAccessorPropertyDeclaration: () => isAutoAccessorPropertyDeclaration,
            isAwaitExpression: () => isAwaitExpression,
            isAwaitKeyword: () => isAwaitKeyword,
            isBigIntLiteral: () => isBigIntLiteral,
            isBinaryExpression: () => isBinaryExpression,
            isBinaryOperatorToken: () => isBinaryOperatorToken,
            isBindableObjectDefinePropertyCall: () => isBindableObjectDefinePropertyCall,
            isBindableStaticAccessExpression: () => isBindableStaticAccessExpression,
            isBindableStaticElementAccessExpression: () => isBindableStaticElementAccessExpression,
            isBindableStaticNameExpression: () => isBindableStaticNameExpression,
            isBindingElement: () => isBindingElement,
            isBindingElementOfBareOrAccessedRequire: () => isBindingElementOfBareOrAccessedRequire,
            isBindingName: () => isBindingName,
            isBindingOrAssignmentElement: () => isBindingOrAssignmentElement,
            isBindingOrAssignmentPattern: () => isBindingOrAssignmentPattern,
            isBindingPattern: () => isBindingPattern,
            isBlock: () => isBlock,
            isBlockOrCatchScoped: () => isBlockOrCatchScoped,
            isBlockScope: () => isBlockScope,
            isBlockScopedContainerTopLevel: () => isBlockScopedContainerTopLevel,
            isBooleanLiteral: () => isBooleanLiteral,
            isBreakOrContinueStatement: () => isBreakOrContinueStatement,
            isBreakStatement: () => isBreakStatement,
            isBuildInfoFile: () => isBuildInfoFile,
            isBuilderProgram: () => isBuilderProgram2,
            isBundle: () => isBundle,
            isBundleFileTextLike: () => isBundleFileTextLike,
            isCallChain: () => isCallChain,
            isCallExpression: () => isCallExpression,
            isCallExpressionTarget: () => isCallExpressionTarget,
            isCallLikeExpression: () => isCallLikeExpression,
            isCallLikeOrFunctionLikeExpression: () => isCallLikeOrFunctionLikeExpression,
            isCallOrNewExpression: () => isCallOrNewExpression,
            isCallOrNewExpressionTarget: () => isCallOrNewExpressionTarget,
            isCallSignatureDeclaration: () => isCallSignatureDeclaration,
            isCallToHelper: () => isCallToHelper,
            isCaseBlock: () => isCaseBlock,
            isCaseClause: () => isCaseClause,
            isCaseKeyword: () => isCaseKeyword,
            isCaseOrDefaultClause: () => isCaseOrDefaultClause,
            isCatchClause: () => isCatchClause,
            isCatchClauseVariableDeclaration: () => isCatchClauseVariableDeclaration,
            isCatchClauseVariableDeclarationOrBindingElement: () => isCatchClauseVariableDeclarationOrBindingElement,
            isCheckJsEnabledForFile: () => isCheckJsEnabledForFile,
            isChildOfNodeWithKind: () => isChildOfNodeWithKind,
            isCircularBuildOrder: () => isCircularBuildOrder,
            isClassDeclaration: () => isClassDeclaration,
            isClassElement: () => isClassElement,
            isClassExpression: () => isClassExpression,
            isClassInstanceProperty: () => isClassInstanceProperty,
            isClassLike: () => isClassLike,
            isClassMemberModifier: () => isClassMemberModifier,
            isClassNamedEvaluationHelperBlock: () => isClassNamedEvaluationHelperBlock,
            isClassOrTypeElement: () => isClassOrTypeElement,
            isClassStaticBlockDeclaration: () => isClassStaticBlockDeclaration,
            isClassThisAssignmentBlock: () => isClassThisAssignmentBlock,
            isCollapsedRange: () => isCollapsedRange,
            isColonToken: () => isColonToken,
            isCommaExpression: () => isCommaExpression,
            isCommaListExpression: () => isCommaListExpression,
            isCommaSequence: () => isCommaSequence,
            isCommaToken: () => isCommaToken,
            isComment: () => isComment,
            isCommonJsExportPropertyAssignment: () => isCommonJsExportPropertyAssignment,
            isCommonJsExportedExpression: () => isCommonJsExportedExpression,
            isCompoundAssignment: () => isCompoundAssignment,
            isComputedNonLiteralName: () => isComputedNonLiteralName,
            isComputedPropertyName: () => isComputedPropertyName,
            isConciseBody: () => isConciseBody,
            isConditionalExpression: () => isConditionalExpression,
            isConditionalTypeNode: () => isConditionalTypeNode,
            isConstTypeReference: () => isConstTypeReference,
            isConstructSignatureDeclaration: () => isConstructSignatureDeclaration,
            isConstructorDeclaration: () => isConstructorDeclaration,
            isConstructorTypeNode: () => isConstructorTypeNode,
            isContextualKeyword: () => isContextualKeyword,
            isContinueStatement: () => isContinueStatement,
            isCustomPrologue: () => isCustomPrologue,
            isDebuggerStatement: () => isDebuggerStatement,
            isDeclaration: () => isDeclaration,
            isDeclarationBindingElement: () => isDeclarationBindingElement,
            isDeclarationFileName: () => isDeclarationFileName,
            isDeclarationName: () => isDeclarationName,
            isDeclarationNameOfEnumOrNamespace: () => isDeclarationNameOfEnumOrNamespace,
            isDeclarationReadonly: () => isDeclarationReadonly,
            isDeclarationStatement: () => isDeclarationStatement,
            isDeclarationWithTypeParameterChildren: () => isDeclarationWithTypeParameterChildren,
            isDeclarationWithTypeParameters: () => isDeclarationWithTypeParameters,
            isDecorator: () => isDecorator,
            isDecoratorTarget: () => isDecoratorTarget,
            isDefaultClause: () => isDefaultClause,
            isDefaultImport: () => isDefaultImport,
            isDefaultModifier: () => isDefaultModifier,
            isDefaultedExpandoInitializer: () => isDefaultedExpandoInitializer,
            isDeleteExpression: () => isDeleteExpression,
            isDeleteTarget: () => isDeleteTarget,
            isDeprecatedDeclaration: () => isDeprecatedDeclaration,
            isDestructuringAssignment: () => isDestructuringAssignment,
            isDiagnosticWithLocation: () => isDiagnosticWithLocation,
            isDiskPathRoot: () => isDiskPathRoot,
            isDoStatement: () => isDoStatement,
            isDocumentRegistryEntry: () => isDocumentRegistryEntry,
            isDotDotDotToken: () => isDotDotDotToken,
            isDottedName: () => isDottedName,
            isDynamicName: () => isDynamicName,
            isESSymbolIdentifier: () => isESSymbolIdentifier,
            isEffectiveExternalModule: () => isEffectiveExternalModule,
            isEffectiveModuleDeclaration: () => isEffectiveModuleDeclaration,
            isEffectiveStrictModeSourceFile: () => isEffectiveStrictModeSourceFile,
            isElementAccessChain: () => isElementAccessChain,
            isElementAccessExpression: () => isElementAccessExpression,
            isEmittedFileOfProgram: () => isEmittedFileOfProgram,
            isEmptyArrayLiteral: () => isEmptyArrayLiteral,
            isEmptyBindingElement: () => isEmptyBindingElement,
            isEmptyBindingPattern: () => isEmptyBindingPattern,
            isEmptyObjectLiteral: () => isEmptyObjectLiteral,
            isEmptyStatement: () => isEmptyStatement,
            isEmptyStringLiteral: () => isEmptyStringLiteral,
            isEntityName: () => isEntityName,
            isEntityNameExpression: () => isEntityNameExpression,
            isEnumConst: () => isEnumConst,
            isEnumDeclaration: () => isEnumDeclaration,
            isEnumMember: () => isEnumMember,
            isEqualityOperatorKind: () => isEqualityOperatorKind,
            isEqualsGreaterThanToken: () => isEqualsGreaterThanToken,
            isExclamationToken: () => isExclamationToken,
            isExcludedFile: () => isExcludedFile,
            isExclusivelyTypeOnlyImportOrExport: () => isExclusivelyTypeOnlyImportOrExport,
            isExpandoPropertyDeclaration: () => isExpandoPropertyDeclaration,
            isExportAssignment: () => isExportAssignment,
            isExportDeclaration: () => isExportDeclaration,
            isExportModifier: () => isExportModifier,
            isExportName: () => isExportName,
            isExportNamespaceAsDefaultDeclaration: () => isExportNamespaceAsDefaultDeclaration,
            isExportOrDefaultModifier: () => isExportOrDefaultModifier,
            isExportSpecifier: () => isExportSpecifier,
            isExportsIdentifier: () => isExportsIdentifier,
            isExportsOrModuleExportsOrAlias: () => isExportsOrModuleExportsOrAlias,
            isExpression: () => isExpression,
            isExpressionNode: () => isExpressionNode,
            isExpressionOfExternalModuleImportEqualsDeclaration: () => isExpressionOfExternalModuleImportEqualsDeclaration,
            isExpressionOfOptionalChainRoot: () => isExpressionOfOptionalChainRoot,
            isExpressionStatement: () => isExpressionStatement,
            isExpressionWithTypeArguments: () => isExpressionWithTypeArguments,
            isExpressionWithTypeArgumentsInClassExtendsClause: () => isExpressionWithTypeArgumentsInClassExtendsClause,
            isExternalModule: () => isExternalModule,
            isExternalModuleAugmentation: () => isExternalModuleAugmentation,
            isExternalModuleImportEqualsDeclaration: () => isExternalModuleImportEqualsDeclaration,
            isExternalModuleIndicator: () => isExternalModuleIndicator,
            isExternalModuleNameRelative: () => isExternalModuleNameRelative,
            isExternalModuleReference: () => isExternalModuleReference,
            isExternalModuleSymbol: () => isExternalModuleSymbol,
            isExternalOrCommonJsModule: () => isExternalOrCommonJsModule,
            isFileLevelReservedGeneratedIdentifier: () => isFileLevelReservedGeneratedIdentifier,
            isFileLevelUniqueName: () => isFileLevelUniqueName,
            isFileProbablyExternalModule: () => isFileProbablyExternalModule,
            isFirstDeclarationOfSymbolParameter: () => isFirstDeclarationOfSymbolParameter,
            isFixablePromiseHandler: () => isFixablePromiseHandler,
            isForInOrOfStatement: () => isForInOrOfStatement,
            isForInStatement: () => isForInStatement,
            isForInitializer: () => isForInitializer,
            isForOfStatement: () => isForOfStatement,
            isForStatement: () => isForStatement,
            isFunctionBlock: () => isFunctionBlock,
            isFunctionBody: () => isFunctionBody,
            isFunctionDeclaration: () => isFunctionDeclaration,
            isFunctionExpression: () => isFunctionExpression,
            isFunctionExpressionOrArrowFunction: () => isFunctionExpressionOrArrowFunction,
            isFunctionLike: () => isFunctionLike,
            isFunctionLikeDeclaration: () => isFunctionLikeDeclaration,
            isFunctionLikeKind: () => isFunctionLikeKind,
            isFunctionLikeOrClassStaticBlockDeclaration: () => isFunctionLikeOrClassStaticBlockDeclaration,
            isFunctionOrConstructorTypeNode: () => isFunctionOrConstructorTypeNode,
            isFunctionOrModuleBlock: () => isFunctionOrModuleBlock,
            isFunctionSymbol: () => isFunctionSymbol,
            isFunctionTypeNode: () => isFunctionTypeNode,
            isFutureReservedKeyword: () => isFutureReservedKeyword,
            isGeneratedIdentifier: () => isGeneratedIdentifier,
            isGeneratedPrivateIdentifier: () => isGeneratedPrivateIdentifier,
            isGetAccessor: () => isGetAccessor,
            isGetAccessorDeclaration: () => isGetAccessorDeclaration,
            isGetOrSetAccessorDeclaration: () => isGetOrSetAccessorDeclaration,
            isGlobalDeclaration: () => isGlobalDeclaration,
            isGlobalScopeAugmentation: () => isGlobalScopeAugmentation,
            isGrammarError: () => isGrammarError,
            isHeritageClause: () => isHeritageClause,
            isHoistedFunction: () => isHoistedFunction,
            isHoistedVariableStatement: () => isHoistedVariableStatement,
            isIdentifier: () => isIdentifier,
            isIdentifierANonContextualKeyword: () => isIdentifierANonContextualKeyword,
            isIdentifierName: () => isIdentifierName,
            isIdentifierOrThisTypeNode: () => isIdentifierOrThisTypeNode,
            isIdentifierPart: () => isIdentifierPart,
            isIdentifierStart: () => isIdentifierStart,
            isIdentifierText: () => isIdentifierText,
            isIdentifierTypePredicate: () => isIdentifierTypePredicate,
            isIdentifierTypeReference: () => isIdentifierTypeReference,
            isIfStatement: () => isIfStatement,
            isIgnoredFileFromWildCardWatching: () => isIgnoredFileFromWildCardWatching,
            isImplicitGlob: () => isImplicitGlob,
            isImportAttribute: () => isImportAttribute,
            isImportAttributeName: () => isImportAttributeName,
            isImportAttributes: () => isImportAttributes,
            isImportCall: () => isImportCall,
            isImportClause: () => isImportClause,
            isImportDeclaration: () => isImportDeclaration,
            isImportEqualsDeclaration: () => isImportEqualsDeclaration,
            isImportKeyword: () => isImportKeyword,
            isImportMeta: () => isImportMeta,
            isImportOrExportSpecifier: () => isImportOrExportSpecifier,
            isImportOrExportSpecifierName: () => isImportOrExportSpecifierName,
            isImportSpecifier: () => isImportSpecifier,
            isImportTypeAssertionContainer: () => isImportTypeAssertionContainer,
            isImportTypeNode: () => isImportTypeNode,
            isImportableFile: () => isImportableFile,
            isInComment: () => isInComment,
            isInCompoundLikeAssignment: () => isInCompoundLikeAssignment,
            isInExpressionContext: () => isInExpressionContext,
            isInJSDoc: () => isInJSDoc,
            isInJSFile: () => isInJSFile,
            isInJSXText: () => isInJSXText,
            isInJsonFile: () => isInJsonFile,
            isInNonReferenceComment: () => isInNonReferenceComment,
            isInReferenceComment: () => isInReferenceComment,
            isInRightSideOfInternalImportEqualsDeclaration: () => isInRightSideOfInternalImportEqualsDeclaration,
            isInString: () => isInString,
            isInTemplateString: () => isInTemplateString,
            isInTopLevelContext: () => isInTopLevelContext,
            isInTypeQuery: () => isInTypeQuery,
            isIncrementalCompilation: () => isIncrementalCompilation,
            isIndexSignatureDeclaration: () => isIndexSignatureDeclaration,
            isIndexedAccessTypeNode: () => isIndexedAccessTypeNode,
            isInferTypeNode: () => isInferTypeNode,
            isInfinityOrNaNString: () => isInfinityOrNaNString,
            isInitializedProperty: () => isInitializedProperty,
            isInitializedVariable: () => isInitializedVariable,
            isInsideJsxElement: () => isInsideJsxElement,
            isInsideJsxElementOrAttribute: () => isInsideJsxElementOrAttribute,
            isInsideNodeModules: () => isInsideNodeModules,
            isInsideTemplateLiteral: () => isInsideTemplateLiteral,
            isInstanceOfExpression: () => isInstanceOfExpression,
            isInstantiatedModule: () => isInstantiatedModule,
            isInterfaceDeclaration: () => isInterfaceDeclaration,
            isInternalDeclaration: () => isInternalDeclaration,
            isInternalModuleImportEqualsDeclaration: () => isInternalModuleImportEqualsDeclaration,
            isInternalName: () => isInternalName,
            isIntersectionTypeNode: () => isIntersectionTypeNode,
            isIntrinsicJsxName: () => isIntrinsicJsxName,
            isIterationStatement: () => isIterationStatement,
            isJSDoc: () => isJSDoc,
            isJSDocAllType: () => isJSDocAllType,
            isJSDocAugmentsTag: () => isJSDocAugmentsTag,
            isJSDocAuthorTag: () => isJSDocAuthorTag,
            isJSDocCallbackTag: () => isJSDocCallbackTag,
            isJSDocClassTag: () => isJSDocClassTag,
            isJSDocCommentContainingNode: () => isJSDocCommentContainingNode,
            isJSDocConstructSignature: () => isJSDocConstructSignature,
            isJSDocDeprecatedTag: () => isJSDocDeprecatedTag,
            isJSDocEnumTag: () => isJSDocEnumTag,
            isJSDocFunctionType: () => isJSDocFunctionType,
            isJSDocImplementsTag: () => isJSDocImplementsTag,
            isJSDocIndexSignature: () => isJSDocIndexSignature,
            isJSDocLikeText: () => isJSDocLikeText,
            isJSDocLink: () => isJSDocLink,
            isJSDocLinkCode: () => isJSDocLinkCode,
            isJSDocLinkLike: () => isJSDocLinkLike,
            isJSDocLinkPlain: () => isJSDocLinkPlain,
            isJSDocMemberName: () => isJSDocMemberName,
            isJSDocNameReference: () => isJSDocNameReference,
            isJSDocNamepathType: () => isJSDocNamepathType,
            isJSDocNamespaceBody: () => isJSDocNamespaceBody,
            isJSDocNode: () => isJSDocNode,
            isJSDocNonNullableType: () => isJSDocNonNullableType,
            isJSDocNullableType: () => isJSDocNullableType,
            isJSDocOptionalParameter: () => isJSDocOptionalParameter,
            isJSDocOptionalType: () => isJSDocOptionalType,
            isJSDocOverloadTag: () => isJSDocOverloadTag,
            isJSDocOverrideTag: () => isJSDocOverrideTag,
            isJSDocParameterTag: () => isJSDocParameterTag,
            isJSDocPrivateTag: () => isJSDocPrivateTag,
            isJSDocPropertyLikeTag: () => isJSDocPropertyLikeTag,
            isJSDocPropertyTag: () => isJSDocPropertyTag,
            isJSDocProtectedTag: () => isJSDocProtectedTag,
            isJSDocPublicTag: () => isJSDocPublicTag,
            isJSDocReadonlyTag: () => isJSDocReadonlyTag,
            isJSDocReturnTag: () => isJSDocReturnTag,
            isJSDocSatisfiesExpression: () => isJSDocSatisfiesExpression,
            isJSDocSatisfiesTag: () => isJSDocSatisfiesTag,
            isJSDocSeeTag: () => isJSDocSeeTag,
            isJSDocSignature: () => isJSDocSignature,
            isJSDocTag: () => isJSDocTag,
            isJSDocTemplateTag: () => isJSDocTemplateTag,
            isJSDocThisTag: () => isJSDocThisTag,
            isJSDocThrowsTag: () => isJSDocThrowsTag,
            isJSDocTypeAlias: () => isJSDocTypeAlias,
            isJSDocTypeAssertion: () => isJSDocTypeAssertion,
            isJSDocTypeExpression: () => isJSDocTypeExpression,
            isJSDocTypeLiteral: () => isJSDocTypeLiteral,
            isJSDocTypeTag: () => isJSDocTypeTag,
            isJSDocTypedefTag: () => isJSDocTypedefTag,
            isJSDocUnknownTag: () => isJSDocUnknownTag,
            isJSDocUnknownType: () => isJSDocUnknownType,
            isJSDocVariadicType: () => isJSDocVariadicType,
            isJSXTagName: () => isJSXTagName,
            isJsonEqual: () => isJsonEqual,
            isJsonSourceFile: () => isJsonSourceFile,
            isJsxAttribute: () => isJsxAttribute,
            isJsxAttributeLike: () => isJsxAttributeLike,
            isJsxAttributeName: () => isJsxAttributeName,
            isJsxAttributes: () => isJsxAttributes,
            isJsxChild: () => isJsxChild,
            isJsxClosingElement: () => isJsxClosingElement,
            isJsxClosingFragment: () => isJsxClosingFragment,
            isJsxElement: () => isJsxElement,
            isJsxExpression: () => isJsxExpression,
            isJsxFragment: () => isJsxFragment,
            isJsxNamespacedName: () => isJsxNamespacedName,
            isJsxOpeningElement: () => isJsxOpeningElement,
            isJsxOpeningFragment: () => isJsxOpeningFragment,
            isJsxOpeningLikeElement: () => isJsxOpeningLikeElement,
            isJsxOpeningLikeElementTagName: () => isJsxOpeningLikeElementTagName,
            isJsxSelfClosingElement: () => isJsxSelfClosingElement,
            isJsxSpreadAttribute: () => isJsxSpreadAttribute,
            isJsxTagNameExpression: () => isJsxTagNameExpression,
            isJsxText: () => isJsxText,
            isJumpStatementTarget: () => isJumpStatementTarget,
            isKeyword: () => isKeyword,
            isKeywordOrPunctuation: () => isKeywordOrPunctuation,
            isKnownSymbol: () => isKnownSymbol,
            isLabelName: () => isLabelName,
            isLabelOfLabeledStatement: () => isLabelOfLabeledStatement,
            isLabeledStatement: () => isLabeledStatement,
            isLateVisibilityPaintedStatement: () => isLateVisibilityPaintedStatement,
            isLeftHandSideExpression: () => isLeftHandSideExpression,
            isLeftHandSideOfAssignment: () => isLeftHandSideOfAssignment,
            isLet: () => isLet,
            isLineBreak: () => isLineBreak,
            isLiteralComputedPropertyDeclarationName: () => isLiteralComputedPropertyDeclarationName,
            isLiteralExpression: () => isLiteralExpression,
            isLiteralExpressionOfObject: () => isLiteralExpressionOfObject,
            isLiteralImportTypeNode: () => isLiteralImportTypeNode,
            isLiteralKind: () => isLiteralKind,
            isLiteralLikeAccess: () => isLiteralLikeAccess,
            isLiteralLikeElementAccess: () => isLiteralLikeElementAccess,
            isLiteralNameOfPropertyDeclarationOrIndexAccess: () => isLiteralNameOfPropertyDeclarationOrIndexAccess,
            isLiteralTypeLikeExpression: () => isLiteralTypeLikeExpression,
            isLiteralTypeLiteral: () => isLiteralTypeLiteral,
            isLiteralTypeNode: () => isLiteralTypeNode,
            isLocalName: () => isLocalName,
            isLogicalOperator: () => isLogicalOperator,
            isLogicalOrCoalescingAssignmentExpression: () => isLogicalOrCoalescingAssignmentExpression,
            isLogicalOrCoalescingAssignmentOperator: () => isLogicalOrCoalescingAssignmentOperator,
            isLogicalOrCoalescingBinaryExpression: () => isLogicalOrCoalescingBinaryExpression,
            isLogicalOrCoalescingBinaryOperator: () => isLogicalOrCoalescingBinaryOperator,
            isMappedTypeNode: () => isMappedTypeNode,
            isMemberName: () => isMemberName,
            isMetaProperty: () => isMetaProperty,
            isMethodDeclaration: () => isMethodDeclaration,
            isMethodOrAccessor: () => isMethodOrAccessor,
            isMethodSignature: () => isMethodSignature,
            isMinusToken: () => isMinusToken,
            isMissingDeclaration: () => isMissingDeclaration,
            isMissingPackageJsonInfo: () => isMissingPackageJsonInfo,
            isModifier: () => isModifier,
            isModifierKind: () => isModifierKind,
            isModifierLike: () => isModifierLike,
            isModuleAugmentationExternal: () => isModuleAugmentationExternal,
            isModuleBlock: () => isModuleBlock,
            isModuleBody: () => isModuleBody,
            isModuleDeclaration: () => isModuleDeclaration,
            isModuleExportsAccessExpression: () => isModuleExportsAccessExpression,
            isModuleIdentifier: () => isModuleIdentifier,
            isModuleName: () => isModuleName,
            isModuleOrEnumDeclaration: () => isModuleOrEnumDeclaration,
            isModuleReference: () => isModuleReference,
            isModuleSpecifierLike: () => isModuleSpecifierLike,
            isModuleWithStringLiteralName: () => isModuleWithStringLiteralName,
            isNameOfFunctionDeclaration: () => isNameOfFunctionDeclaration,
            isNameOfModuleDeclaration: () => isNameOfModuleDeclaration,
            isNamedClassElement: () => isNamedClassElement,
            isNamedDeclaration: () => isNamedDeclaration,
            isNamedEvaluation: () => isNamedEvaluation,
            isNamedEvaluationSource: () => isNamedEvaluationSource,
            isNamedExportBindings: () => isNamedExportBindings,
            isNamedExports: () => isNamedExports,
            isNamedImportBindings: () => isNamedImportBindings,
            isNamedImports: () => isNamedImports,
            isNamedImportsOrExports: () => isNamedImportsOrExports,
            isNamedTupleMember: () => isNamedTupleMember,
            isNamespaceBody: () => isNamespaceBody,
            isNamespaceExport: () => isNamespaceExport,
            isNamespaceExportDeclaration: () => isNamespaceExportDeclaration,
            isNamespaceImport: () => isNamespaceImport,
            isNamespaceReexportDeclaration: () => isNamespaceReexportDeclaration,
            isNewExpression: () => isNewExpression,
            isNewExpressionTarget: () => isNewExpressionTarget,
            isNoSubstitutionTemplateLiteral: () => isNoSubstitutionTemplateLiteral,
            isNode: () => isNode,
            isNodeArray: () => isNodeArray,
            isNodeArrayMultiLine: () => isNodeArrayMultiLine,
            isNodeDescendantOf: () => isNodeDescendantOf,
            isNodeKind: () => isNodeKind,
            isNodeLikeSystem: () => isNodeLikeSystem,
            isNodeModulesDirectory: () => isNodeModulesDirectory,
            isNodeWithPossibleHoistedDeclaration: () => isNodeWithPossibleHoistedDeclaration,
            isNonContextualKeyword: () => isNonContextualKeyword,
            isNonExportDefaultModifier: () => isNonExportDefaultModifier,
            isNonGlobalAmbientModule: () => isNonGlobalAmbientModule,
            isNonGlobalDeclaration: () => isNonGlobalDeclaration,
            isNonNullAccess: () => isNonNullAccess,
            isNonNullChain: () => isNonNullChain,
            isNonNullExpression: () => isNonNullExpression,
            isNonStaticMethodOrAccessorWithPrivateName: () => isNonStaticMethodOrAccessorWithPrivateName,
            isNotEmittedOrPartiallyEmittedNode: () => isNotEmittedOrPartiallyEmittedNode,
            isNotEmittedStatement: () => isNotEmittedStatement,
            isNullishCoalesce: () => isNullishCoalesce,
            isNumber: () => isNumber,
            isNumericLiteral: () => isNumericLiteral,
            isNumericLiteralName: () => isNumericLiteralName,
            isObjectBindingElementWithoutPropertyName: () => isObjectBindingElementWithoutPropertyName,
            isObjectBindingOrAssignmentElement: () => isObjectBindingOrAssignmentElement,
            isObjectBindingOrAssignmentPattern: () => isObjectBindingOrAssignmentPattern,
            isObjectBindingPattern: () => isObjectBindingPattern,
            isObjectLiteralElement: () => isObjectLiteralElement,
            isObjectLiteralElementLike: () => isObjectLiteralElementLike,
            isObjectLiteralExpression: () => isObjectLiteralExpression,
            isObjectLiteralMethod: () => isObjectLiteralMethod,
            isObjectLiteralOrClassExpressionMethodOrAccessor: () => isObjectLiteralOrClassExpressionMethodOrAccessor,
            isObjectTypeDeclaration: () => isObjectTypeDeclaration,
            isOctalDigit: () => isOctalDigit,
            isOmittedExpression: () => isOmittedExpression,
            isOptionalChain: () => isOptionalChain,
            isOptionalChainRoot: () => isOptionalChainRoot,
            isOptionalDeclaration: () => isOptionalDeclaration,
            isOptionalJSDocPropertyLikeTag: () => isOptionalJSDocPropertyLikeTag,
            isOptionalTypeNode: () => isOptionalTypeNode,
            isOuterExpression: () => isOuterExpression,
            isOutermostOptionalChain: () => isOutermostOptionalChain,
            isOverrideModifier: () => isOverrideModifier,
            isPackageJsonInfo: () => isPackageJsonInfo,
            isPackedArrayLiteral: () => isPackedArrayLiteral,
            isParameter: () => isParameter,
            isParameterDeclaration: () => isParameterDeclaration,
            isParameterPropertyDeclaration: () => isParameterPropertyDeclaration,
            isParameterPropertyModifier: () => isParameterPropertyModifier,
            isParenthesizedExpression: () => isParenthesizedExpression,
            isParenthesizedTypeNode: () => isParenthesizedTypeNode,
            isParseTreeNode: () => isParseTreeNode,
            isPartOfTypeNode: () => isPartOfTypeNode,
            isPartOfTypeQuery: () => isPartOfTypeQuery,
            isPartiallyEmittedExpression: () => isPartiallyEmittedExpression,
            isPatternMatch: () => isPatternMatch,
            isPinnedComment: () => isPinnedComment,
            isPlainJsFile: () => isPlainJsFile,
            isPlusToken: () => isPlusToken,
            isPossiblyTypeArgumentPosition: () => isPossiblyTypeArgumentPosition,
            isPostfixUnaryExpression: () => isPostfixUnaryExpression,
            isPrefixUnaryExpression: () => isPrefixUnaryExpression,
            isPrivateIdentifier: () => isPrivateIdentifier,
            isPrivateIdentifierClassElementDeclaration: () => isPrivateIdentifierClassElementDeclaration,
            isPrivateIdentifierPropertyAccessExpression: () => isPrivateIdentifierPropertyAccessExpression,
            isPrivateIdentifierSymbol: () => isPrivateIdentifierSymbol,
            isProgramBundleEmitBuildInfo: () => isProgramBundleEmitBuildInfo,
            isProgramUptoDate: () => isProgramUptoDate,
            isPrologueDirective: () => isPrologueDirective,
            isPropertyAccessChain: () => isPropertyAccessChain,
            isPropertyAccessEntityNameExpression: () => isPropertyAccessEntityNameExpression,
            isPropertyAccessExpression: () => isPropertyAccessExpression,
            isPropertyAccessOrQualifiedName: () => isPropertyAccessOrQualifiedName,
            isPropertyAccessOrQualifiedNameOrImportTypeNode: () => isPropertyAccessOrQualifiedNameOrImportTypeNode,
            isPropertyAssignment: () => isPropertyAssignment,
            isPropertyDeclaration: () => isPropertyDeclaration,
            isPropertyName: () => isPropertyName,
            isPropertyNameLiteral: () => isPropertyNameLiteral,
            isPropertySignature: () => isPropertySignature,
            isProtoSetter: () => isProtoSetter,
            isPrototypeAccess: () => isPrototypeAccess,
            isPrototypePropertyAssignment: () => isPrototypePropertyAssignment,
            isPunctuation: () => isPunctuation,
            isPushOrUnshiftIdentifier: () => isPushOrUnshiftIdentifier,
            isQualifiedName: () => isQualifiedName,
            isQuestionDotToken: () => isQuestionDotToken,
            isQuestionOrExclamationToken: () => isQuestionOrExclamationToken,
            isQuestionOrPlusOrMinusToken: () => isQuestionOrPlusOrMinusToken,
            isQuestionToken: () => isQuestionToken,
            isRawSourceMap: () => isRawSourceMap,
            isReadonlyKeyword: () => isReadonlyKeyword,
            isReadonlyKeywordOrPlusOrMinusToken: () => isReadonlyKeywordOrPlusOrMinusToken,
            isRecognizedTripleSlashComment: () => isRecognizedTripleSlashComment,
            isReferenceFileLocation: () => isReferenceFileLocation,
            isReferencedFile: () => isReferencedFile,
            isRegularExpressionLiteral: () => isRegularExpressionLiteral,
            isRequireCall: () => isRequireCall,
            isRequireVariableStatement: () => isRequireVariableStatement,
            isRestParameter: () => isRestParameter,
            isRestTypeNode: () => isRestTypeNode,
            isReturnStatement: () => isReturnStatement,
            isReturnStatementWithFixablePromiseHandler: () => isReturnStatementWithFixablePromiseHandler,
            isRightSideOfAccessExpression: () => isRightSideOfAccessExpression,
            isRightSideOfInstanceofExpression: () => isRightSideOfInstanceofExpression,
            isRightSideOfPropertyAccess: () => isRightSideOfPropertyAccess,
            isRightSideOfQualifiedName: () => isRightSideOfQualifiedName,
            isRightSideOfQualifiedNameOrPropertyAccess: () => isRightSideOfQualifiedNameOrPropertyAccess,
            isRightSideOfQualifiedNameOrPropertyAccessOrJSDocMemberName: () => isRightSideOfQualifiedNameOrPropertyAccessOrJSDocMemberName,
            isRootedDiskPath: () => isRootedDiskPath,
            isSameEntityName: () => isSameEntityName,
            isSatisfiesExpression: () => isSatisfiesExpression,
            isScopeMarker: () => isScopeMarker,
            isSemicolonClassElement: () => isSemicolonClassElement,
            isSetAccessor: () => isSetAccessor,
            isSetAccessorDeclaration: () => isSetAccessorDeclaration,
            isShebangTrivia: () => isShebangTrivia,
            isShiftOperatorOrHigher: () => isShiftOperatorOrHigher,
            isShorthandAmbientModuleSymbol: () => isShorthandAmbientModuleSymbol,
            isShorthandPropertyAssignment: () => isShorthandPropertyAssignment,
            isSignedNumericLiteral: () => isSignedNumericLiteral,
            isSimpleCopiableExpression: () => isSimpleCopiableExpression,
            isSimpleInlineableExpression: () => isSimpleInlineableExpression,
            isSimpleParameter: () => isSimpleParameter,
            isSimpleParameterList: () => isSimpleParameterList,
            isSingleOrDoubleQuote: () => isSingleOrDoubleQuote,
            isSourceFile: () => isSourceFile,
            isSourceFileFromLibrary: () => isSourceFileFromLibrary,
            isSourceFileJS: () => isSourceFileJS,
            isSourceFileNotJS: () => isSourceFileNotJS,
            isSourceFileNotJson: () => isSourceFileNotJson,
            isSourceMapping: () => isSourceMapping,
            isSpecialPropertyDeclaration: () => isSpecialPropertyDeclaration,
            isSpreadAssignment: () => isSpreadAssignment,
            isSpreadElement: () => isSpreadElement,
            isStatement: () => isStatement,
            isStatementButNotDeclaration: () => isStatementButNotDeclaration,
            isStatementOrBlock: () => isStatementOrBlock,
            isStatementWithLocals: () => isStatementWithLocals,
            isStatic: () => isStatic,
            isStaticModifier: () => isStaticModifier,
            isString: () => isString,
            isStringAKeyword: () => isStringAKeyword,
            isStringANonContextualKeyword: () => isStringANonContextualKeyword,
            isStringAndEmptyAnonymousObjectIntersection: () => isStringAndEmptyAnonymousObjectIntersection,
            isStringDoubleQuoted: () => isStringDoubleQuoted,
            isStringLiteral: () => isStringLiteral,
            isStringLiteralLike: () => isStringLiteralLike,
            isStringLiteralOrJsxExpression: () => isStringLiteralOrJsxExpression,
            isStringLiteralOrTemplate: () => isStringLiteralOrTemplate,
            isStringOrNumericLiteralLike: () => isStringOrNumericLiteralLike,
            isStringOrRegularExpressionOrTemplateLiteral: () => isStringOrRegularExpressionOrTemplateLiteral,
            isStringTextContainingNode: () => isStringTextContainingNode,
            isSuperCall: () => isSuperCall,
            isSuperKeyword: () => isSuperKeyword,
            isSuperOrSuperProperty: () => isSuperOrSuperProperty,
            isSuperProperty: () => isSuperProperty,
            isSupportedSourceFileName: () => isSupportedSourceFileName,
            isSwitchStatement: () => isSwitchStatement,
            isSyntaxList: () => isSyntaxList,
            isSyntheticExpression: () => isSyntheticExpression,
            isSyntheticReference: () => isSyntheticReference,
            isTagName: () => isTagName,
            isTaggedTemplateExpression: () => isTaggedTemplateExpression,
            isTaggedTemplateTag: () => isTaggedTemplateTag,
            isTemplateExpression: () => isTemplateExpression,
            isTemplateHead: () => isTemplateHead,
            isTemplateLiteral: () => isTemplateLiteral,
            isTemplateLiteralKind: () => isTemplateLiteralKind,
            isTemplateLiteralToken: () => isTemplateLiteralToken,
            isTemplateLiteralTypeNode: () => isTemplateLiteralTypeNode,
            isTemplateLiteralTypeSpan: () => isTemplateLiteralTypeSpan,
            isTemplateMiddle: () => isTemplateMiddle,
            isTemplateMiddleOrTemplateTail: () => isTemplateMiddleOrTemplateTail,
            isTemplateSpan: () => isTemplateSpan,
            isTemplateTail: () => isTemplateTail,
            isTextWhiteSpaceLike: () => isTextWhiteSpaceLike,
            isThis: () => isThis,
            isThisContainerOrFunctionBlock: () => isThisContainerOrFunctionBlock,
            isThisIdentifier: () => isThisIdentifier,
            isThisInTypeQuery: () => isThisInTypeQuery,
            isThisInitializedDeclaration: () => isThisInitializedDeclaration,
            isThisInitializedObjectBindingExpression: () => isThisInitializedObjectBindingExpression,
            isThisProperty: () => isThisProperty,
            isThisTypeNode: () => isThisTypeNode,
            isThisTypeParameter: () => isThisTypeParameter,
            isThisTypePredicate: () => isThisTypePredicate,
            isThrowStatement: () => isThrowStatement,
            isToken: () => isToken,
            isTokenKind: () => isTokenKind,
            isTraceEnabled: () => isTraceEnabled,
            isTransientSymbol: () => isTransientSymbol,
            isTrivia: () => isTrivia,
            isTryStatement: () => isTryStatement,
            isTupleTypeNode: () => isTupleTypeNode,
            isTypeAlias: () => isTypeAlias,
            isTypeAliasDeclaration: () => isTypeAliasDeclaration,
            isTypeAssertionExpression: () => isTypeAssertionExpression,
            isTypeDeclaration: () => isTypeDeclaration,
            isTypeElement: () => isTypeElement,
            isTypeKeyword: () => isTypeKeyword,
            isTypeKeywordToken: () => isTypeKeywordToken,
            isTypeKeywordTokenOrIdentifier: () => isTypeKeywordTokenOrIdentifier,
            isTypeLiteralNode: () => isTypeLiteralNode,
            isTypeNode: () => isTypeNode,
            isTypeNodeKind: () => isTypeNodeKind,
            isTypeOfExpression: () => isTypeOfExpression,
            isTypeOnlyExportDeclaration: () => isTypeOnlyExportDeclaration,
            isTypeOnlyImportDeclaration: () => isTypeOnlyImportDeclaration,
            isTypeOnlyImportOrExportDeclaration: () => isTypeOnlyImportOrExportDeclaration,
            isTypeOperatorNode: () => isTypeOperatorNode,
            isTypeParameterDeclaration: () => isTypeParameterDeclaration,
            isTypePredicateNode: () => isTypePredicateNode,
            isTypeQueryNode: () => isTypeQueryNode,
            isTypeReferenceNode: () => isTypeReferenceNode,
            isTypeReferenceType: () => isTypeReferenceType,
            isTypeUsableAsPropertyName: () => isTypeUsableAsPropertyName,
            isUMDExportSymbol: () => isUMDExportSymbol,
            isUnaryExpression: () => isUnaryExpression,
            isUnaryExpressionWithWrite: () => isUnaryExpressionWithWrite,
            isUnicodeIdentifierStart: () => isUnicodeIdentifierStart,
            isUnionTypeNode: () => isUnionTypeNode,
            isUnparsedNode: () => isUnparsedNode,
            isUnparsedPrepend: () => isUnparsedPrepend,
            isUnparsedSource: () => isUnparsedSource,
            isUnparsedTextLike: () => isUnparsedTextLike,
            isUrl: () => isUrl,
            isValidBigIntString: () => isValidBigIntString,
            isValidESSymbolDeclaration: () => isValidESSymbolDeclaration,
            isValidTypeOnlyAliasUseSite: () => isValidTypeOnlyAliasUseSite,
            isValueSignatureDeclaration: () => isValueSignatureDeclaration,
            isVarAwaitUsing: () => isVarAwaitUsing,
            isVarConst: () => isVarConst,
            isVarUsing: () => isVarUsing,
            isVariableDeclaration: () => isVariableDeclaration,
            isVariableDeclarationInVariableStatement: () => isVariableDeclarationInVariableStatement,
            isVariableDeclarationInitializedToBareOrAccessedRequire: () => isVariableDeclarationInitializedToBareOrAccessedRequire,
            isVariableDeclarationInitializedToRequire: () => isVariableDeclarationInitializedToRequire,
            isVariableDeclarationList: () => isVariableDeclarationList,
            isVariableLike: () => isVariableLike,
            isVariableLikeOrAccessor: () => isVariableLikeOrAccessor,
            isVariableStatement: () => isVariableStatement,
            isVoidExpression: () => isVoidExpression,
            isWatchSet: () => isWatchSet,
            isWhileStatement: () => isWhileStatement,
            isWhiteSpaceLike: () => isWhiteSpaceLike,
            isWhiteSpaceSingleLine: () => isWhiteSpaceSingleLine,
            isWithStatement: () => isWithStatement,
            isWriteAccess: () => isWriteAccess,
            isWriteOnlyAccess: () => isWriteOnlyAccess,
            isYieldExpression: () => isYieldExpression,
            jsxModeNeedsExplicitImport: () => jsxModeNeedsExplicitImport,
            keywordPart: () => keywordPart,
            last: () => last,
            lastOrUndefined: () => lastOrUndefined,
            length: () => length,
            libMap: () => libMap,
            libs: () => libs,
            lineBreakPart: () => lineBreakPart,
            linkNamePart: () => linkNamePart,
            linkPart: () => linkPart,
            linkTextPart: () => linkTextPart,
            listFiles: () => listFiles,
            loadModuleFromGlobalCache: () => loadModuleFromGlobalCache,
            loadWithModeAwareCache: () => loadWithModeAwareCache,
            makeIdentifierFromModuleName: () => makeIdentifierFromModuleName,
            makeImport: () => makeImport,
            makeImportIfNecessary: () => makeImportIfNecessary,
            makeStringLiteral: () => makeStringLiteral,
            mangleScopedPackageName: () => mangleScopedPackageName,
            map: () => map,
            mapAllOrFail: () => mapAllOrFail,
            mapDefined: () => mapDefined,
            mapDefinedEntries: () => mapDefinedEntries,
            mapDefinedIterator: () => mapDefinedIterator,
            mapEntries: () => mapEntries,
            mapIterator: () => mapIterator,
            mapOneOrMany: () => mapOneOrMany,
            mapToDisplayParts: () => mapToDisplayParts,
            matchFiles: () => matchFiles,
            matchPatternOrExact: () => matchPatternOrExact,
            matchedText: () => matchedText,
            matchesExclude: () => matchesExclude,
            maybeBind: () => maybeBind,
            maybeSetLocalizedDiagnosticMessages: () => maybeSetLocalizedDiagnosticMessages,
            memoize: () => memoize,
            memoizeCached: () => memoizeCached,
            memoizeOne: () => memoizeOne,
            memoizeWeak: () => memoizeWeak,
            metadataHelper: () => metadataHelper,
            min: () => min,
            minAndMax: () => minAndMax,
            missingFileModifiedTime: () => missingFileModifiedTime,
            modifierToFlag: () => modifierToFlag,
            modifiersToFlags: () => modifiersToFlags,
            moduleOptionDeclaration: () => moduleOptionDeclaration,
            moduleResolutionIsEqualTo: () => moduleResolutionIsEqualTo,
            moduleResolutionNameAndModeGetter: () => moduleResolutionNameAndModeGetter,
            moduleResolutionOptionDeclarations: () => moduleResolutionOptionDeclarations,
            moduleResolutionSupportsPackageJsonExportsAndImports: () => moduleResolutionSupportsPackageJsonExportsAndImports,
            moduleResolutionUsesNodeModules: () => moduleResolutionUsesNodeModules,
            moduleSpecifiers: () => ts_moduleSpecifiers_exports,
            moveEmitHelpers: () => moveEmitHelpers,
            moveRangeEnd: () => moveRangeEnd,
            moveRangePastDecorators: () => moveRangePastDecorators,
            moveRangePastModifiers: () => moveRangePastModifiers,
            moveRangePos: () => moveRangePos,
            moveSyntheticComments: () => moveSyntheticComments,
            mutateMap: () => mutateMap,
            mutateMapSkippingNewValues: () => mutateMapSkippingNewValues,
            needsParentheses: () => needsParentheses,
            needsScopeMarker: () => needsScopeMarker,
            newCaseClauseTracker: () => newCaseClauseTracker,
            newPrivateEnvironment: () => newPrivateEnvironment,
            noEmitNotification: () => noEmitNotification,
            noEmitSubstitution: () => noEmitSubstitution,
            noTransformers: () => noTransformers,
            noTruncationMaximumTruncationLength: () => noTruncationMaximumTruncationLength,
            nodeCanBeDecorated: () => nodeCanBeDecorated,
            nodeHasName: () => nodeHasName,
            nodeIsDecorated: () => nodeIsDecorated,
            nodeIsMissing: () => nodeIsMissing,
            nodeIsPresent: () => nodeIsPresent,
            nodeIsSynthesized: () => nodeIsSynthesized,
            nodeModuleNameResolver: () => nodeModuleNameResolver,
            nodeModulesPathPart: () => nodeModulesPathPart,
            nodeNextJsonConfigResolver: () => nodeNextJsonConfigResolver,
            nodeOrChildIsDecorated: () => nodeOrChildIsDecorated,
            nodeOverlapsWithStartEnd: () => nodeOverlapsWithStartEnd,
            nodePosToString: () => nodePosToString,
            nodeSeenTracker: () => nodeSeenTracker,
            nodeStartsNewLexicalEnvironment: () => nodeStartsNewLexicalEnvironment,
            nodeToDisplayParts: () => nodeToDisplayParts,
            noop: () => noop,
            noopFileWatcher: () => noopFileWatcher,
            normalizePath: () => normalizePath,
            normalizeSlashes: () => normalizeSlashes,
            not: () => not,
            notImplemented: () => notImplemented,
            notImplementedResolver: () => notImplementedResolver,
            nullNodeConverters: () => nullNodeConverters,
            nullParenthesizerRules: () => nullParenthesizerRules,
            nullTransformationContext: () => nullTransformationContext,
            objectAllocator: () => objectAllocator,
            operatorPart: () => operatorPart,
            optionDeclarations: () => optionDeclarations,
            optionMapToObject: () => optionMapToObject,
            optionsAffectingProgramStructure: () => optionsAffectingProgramStructure,
            optionsForBuild: () => optionsForBuild,
            optionsForWatch: () => optionsForWatch,
            optionsHaveChanges: () => optionsHaveChanges,
            optionsHaveModuleResolutionChanges: () => optionsHaveModuleResolutionChanges,
            or: () => or,
            orderedRemoveItem: () => orderedRemoveItem,
            orderedRemoveItemAt: () => orderedRemoveItemAt,
            outFile: () => outFile,
            packageIdToPackageName: () => packageIdToPackageName,
            packageIdToString: () => packageIdToString,
            paramHelper: () => paramHelper,
            parameterIsThisKeyword: () => parameterIsThisKeyword,
            parameterNamePart: () => parameterNamePart,
            parseBaseNodeFactory: () => parseBaseNodeFactory,
            parseBigInt: () => parseBigInt,
            parseBuildCommand: () => parseBuildCommand,
            parseCommandLine: () => parseCommandLine,
            parseCommandLineWorker: () => parseCommandLineWorker,
            parseConfigFileTextToJson: () => parseConfigFileTextToJson,
            parseConfigFileWithSystem: () => parseConfigFileWithSystem,
            parseConfigHostFromCompilerHostLike: () => parseConfigHostFromCompilerHostLike,
            parseCustomTypeOption: () => parseCustomTypeOption,
            parseIsolatedEntityName: () => parseIsolatedEntityName,
            parseIsolatedJSDocComment: () => parseIsolatedJSDocComment,
            parseJSDocTypeExpressionForTests: () => parseJSDocTypeExpressionForTests,
            parseJsonConfigFileContent: () => parseJsonConfigFileContent,
            parseJsonSourceFileConfigFileContent: () => parseJsonSourceFileConfigFileContent,
            parseJsonText: () => parseJsonText,
            parseListTypeOption: () => parseListTypeOption,
            parseNodeFactory: () => parseNodeFactory,
            parseNodeModuleFromPath: () => parseNodeModuleFromPath,
            parsePackageName: () => parsePackageName,
            parsePseudoBigInt: () => parsePseudoBigInt,
            parseValidBigInt: () => parseValidBigInt,
            patchWriteFileEnsuringDirectory: () => patchWriteFileEnsuringDirectory,
            pathContainsNodeModules: () => pathContainsNodeModules,
            pathIsAbsolute: () => pathIsAbsolute,
            pathIsBareSpecifier: () => pathIsBareSpecifier,
            pathIsRelative: () => pathIsRelative,
            patternText: () => patternText,
            perfLogger: () => perfLogger,
            performIncrementalCompilation: () => performIncrementalCompilation,
            performance: () => ts_performance_exports,
            plainJSErrors: () => plainJSErrors,
            positionBelongsToNode: () => positionBelongsToNode,
            positionIsASICandidate: () => positionIsASICandidate,
            positionIsSynthesized: () => positionIsSynthesized,
            positionsAreOnSameLine: () => positionsAreOnSameLine,
            preProcessFile: () => preProcessFile,
            probablyUsesSemicolons: () => probablyUsesSemicolons,
            processCommentPragmas: () => processCommentPragmas,
            processPragmasIntoFields: () => processPragmasIntoFields,
            processTaggedTemplateExpression: () => processTaggedTemplateExpression,
            programContainsEsModules: () => programContainsEsModules,
            programContainsModules: () => programContainsModules,
            projectReferenceIsEqualTo: () => projectReferenceIsEqualTo,
            propKeyHelper: () => propKeyHelper,
            propertyNamePart: () => propertyNamePart,
            pseudoBigIntToString: () => pseudoBigIntToString,
            punctuationPart: () => punctuationPart,
            pushIfUnique: () => pushIfUnique,
            quote: () => quote,
            quotePreferenceFromString: () => quotePreferenceFromString,
            rangeContainsPosition: () => rangeContainsPosition,
            rangeContainsPositionExclusive: () => rangeContainsPositionExclusive,
            rangeContainsRange: () => rangeContainsRange,
            rangeContainsRangeExclusive: () => rangeContainsRangeExclusive,
            rangeContainsStartEnd: () => rangeContainsStartEnd,
            rangeEndIsOnSameLineAsRangeStart: () => rangeEndIsOnSameLineAsRangeStart,
            rangeEndPositionsAreOnSameLine: () => rangeEndPositionsAreOnSameLine,
            rangeEquals: () => rangeEquals,
            rangeIsOnSingleLine: () => rangeIsOnSingleLine,
            rangeOfNode: () => rangeOfNode,
            rangeOfTypeParameters: () => rangeOfTypeParameters,
            rangeOverlapsWithStartEnd: () => rangeOverlapsWithStartEnd,
            rangeStartIsOnSameLineAsRangeEnd: () => rangeStartIsOnSameLineAsRangeEnd,
            rangeStartPositionsAreOnSameLine: () => rangeStartPositionsAreOnSameLine,
            readBuilderProgram: () => readBuilderProgram,
            readConfigFile: () => readConfigFile,
            readHelper: () => readHelper,
            readJson: () => readJson,
            readJsonConfigFile: () => readJsonConfigFile,
            readJsonOrUndefined: () => readJsonOrUndefined,
            reduceEachLeadingCommentRange: () => reduceEachLeadingCommentRange,
            reduceEachTrailingCommentRange: () => reduceEachTrailingCommentRange,
            reduceLeft: () => reduceLeft,
            reduceLeftIterator: () => reduceLeftIterator,
            reducePathComponents: () => reducePathComponents,
            refactor: () => ts_refactor_exports,
            regExpEscape: () => regExpEscape,
            relativeComplement: () => relativeComplement,
            removeAllComments: () => removeAllComments,
            removeEmitHelper: () => removeEmitHelper,
            removeExtension: () => removeExtension,
            removeFileExtension: () => removeFileExtension,
            removeIgnoredPath: () => removeIgnoredPath,
            removeMinAndVersionNumbers: () => removeMinAndVersionNumbers,
            removeOptionality: () => removeOptionality,
            removePrefix: () => removePrefix,
            removeSuffix: () => removeSuffix,
            removeTrailingDirectorySeparator: () => removeTrailingDirectorySeparator,
            repeatString: () => repeatString,
            replaceElement: () => replaceElement,
            replaceFirstStar: () => replaceFirstStar,
            resolutionExtensionIsTSOrJson: () => resolutionExtensionIsTSOrJson,
            resolveConfigFileProjectName: () => resolveConfigFileProjectName,
            resolveJSModule: () => resolveJSModule,
            resolveLibrary: () => resolveLibrary,
            resolveModuleName: () => resolveModuleName,
            resolveModuleNameFromCache: () => resolveModuleNameFromCache,
            resolvePackageNameToPackageJson: () => resolvePackageNameToPackageJson,
            resolvePath: () => resolvePath,
            resolveProjectReferencePath: () => resolveProjectReferencePath,
            resolveTripleslashReference: () => resolveTripleslashReference,
            resolveTypeReferenceDirective: () => resolveTypeReferenceDirective,
            resolvingEmptyArray: () => resolvingEmptyArray,
            restHelper: () => restHelper,
            returnFalse: () => returnFalse,
            returnNoopFileWatcher: () => returnNoopFileWatcher,
            returnTrue: () => returnTrue,
            returnUndefined: () => returnUndefined,
            returnsPromise: () => returnsPromise,
            runInitializersHelper: () => runInitializersHelper,
            sameFlatMap: () => sameFlatMap,
            sameMap: () => sameMap,
            sameMapping: () => sameMapping,
            scanShebangTrivia: () => scanShebangTrivia,
            scanTokenAtPosition: () => scanTokenAtPosition,
            scanner: () => scanner,
            screenStartingMessageCodes: () => screenStartingMessageCodes,
            semanticDiagnosticsOptionDeclarations: () => semanticDiagnosticsOptionDeclarations,
            serializeCompilerOptions: () => serializeCompilerOptions,
            server: () => ts_server_exports4,
            servicesVersion: () => servicesVersion,
            setCommentRange: () => setCommentRange,
            setConfigFileInOptions: () => setConfigFileInOptions,
            setConstantValue: () => setConstantValue,
            setEachParent: () => setEachParent,
            setEmitFlags: () => setEmitFlags,
            setFunctionNameHelper: () => setFunctionNameHelper,
            setGetSourceFileAsHashVersioned: () => setGetSourceFileAsHashVersioned,
            setIdentifierAutoGenerate: () => setIdentifierAutoGenerate,
            setIdentifierGeneratedImportReference: () => setIdentifierGeneratedImportReference,
            setIdentifierTypeArguments: () => setIdentifierTypeArguments,
            setInternalEmitFlags: () => setInternalEmitFlags,
            setLocalizedDiagnosticMessages: () => setLocalizedDiagnosticMessages,
            setModuleDefaultHelper: () => setModuleDefaultHelper,
            setNodeFlags: () => setNodeFlags,
            setObjectAllocator: () => setObjectAllocator,
            setOriginalNode: () => setOriginalNode,
            setParent: () => setParent,
            setParentRecursive: () => setParentRecursive,
            setPrivateIdentifier: () => setPrivateIdentifier,
            setSnippetElement: () => setSnippetElement,
            setSourceMapRange: () => setSourceMapRange,
            setStackTraceLimit: () => setStackTraceLimit,
            setStartsOnNewLine: () => setStartsOnNewLine,
            setSyntheticLeadingComments: () => setSyntheticLeadingComments,
            setSyntheticTrailingComments: () => setSyntheticTrailingComments,
            setSys: () => setSys,
            setSysLog: () => setSysLog,
            setTextRange: () => setTextRange,
            setTextRangeEnd: () => setTextRangeEnd,
            setTextRangePos: () => setTextRangePos,
            setTextRangePosEnd: () => setTextRangePosEnd,
            setTextRangePosWidth: () => setTextRangePosWidth,
            setTokenSourceMapRange: () => setTokenSourceMapRange,
            setTypeNode: () => setTypeNode,
            setUILocale: () => setUILocale,
            setValueDeclaration: () => setValueDeclaration,
            shouldAllowImportingTsExtension: () => shouldAllowImportingTsExtension,
            shouldPreserveConstEnums: () => shouldPreserveConstEnums,
            shouldUseUriStyleNodeCoreModules: () => shouldUseUriStyleNodeCoreModules,
            showModuleSpecifier: () => showModuleSpecifier,
            signatureHasLiteralTypes: () => signatureHasLiteralTypes,
            signatureHasRestParameter: () => signatureHasRestParameter,
            signatureToDisplayParts: () => signatureToDisplayParts,
            single: () => single,
            singleElementArray: () => singleElementArray,
            singleIterator: () => singleIterator,
            singleOrMany: () => singleOrMany,
            singleOrUndefined: () => singleOrUndefined,
            skipAlias: () => skipAlias,
            skipAssertions: () => skipAssertions,
            skipConstraint: () => skipConstraint,
            skipOuterExpressions: () => skipOuterExpressions,
            skipParentheses: () => skipParentheses,
            skipPartiallyEmittedExpressions: () => skipPartiallyEmittedExpressions,
            skipTrivia: () => skipTrivia,
            skipTypeChecking: () => skipTypeChecking,
            skipTypeParentheses: () => skipTypeParentheses,
            skipWhile: () => skipWhile,
            sliceAfter: () => sliceAfter,
            some: () => some,
            sort: () => sort,
            sortAndDeduplicate: () => sortAndDeduplicate,
            sortAndDeduplicateDiagnostics: () => sortAndDeduplicateDiagnostics,
            sourceFileAffectingCompilerOptions: () => sourceFileAffectingCompilerOptions,
            sourceFileMayBeEmitted: () => sourceFileMayBeEmitted,
            sourceMapCommentRegExp: () => sourceMapCommentRegExp,
            sourceMapCommentRegExpDontCareLineStart: () => sourceMapCommentRegExpDontCareLineStart,
            spacePart: () => spacePart,
            spanMap: () => spanMap,
            spreadArrayHelper: () => spreadArrayHelper,
            stableSort: () => stableSort,
            startEndContainsRange: () => startEndContainsRange,
            startEndOverlapsWithStartEnd: () => startEndOverlapsWithStartEnd,
            startOnNewLine: () => startOnNewLine,
            startTracing: () => startTracing,
            startsWith: () => startsWith,
            startsWithDirectory: () => startsWithDirectory,
            startsWithUnderscore: () => startsWithUnderscore,
            startsWithUseStrict: () => startsWithUseStrict,
            stringContainsAt: () => stringContainsAt,
            stringToToken: () => stringToToken,
            stripQuotes: () => stripQuotes,
            supportedDeclarationExtensions: () => supportedDeclarationExtensions,
            supportedJSExtensions: () => supportedJSExtensions,
            supportedJSExtensionsFlat: () => supportedJSExtensionsFlat,
            supportedLocaleDirectories: () => supportedLocaleDirectories,
            supportedTSExtensions: () => supportedTSExtensions,
            supportedTSExtensionsFlat: () => supportedTSExtensionsFlat,
            supportedTSImplementationExtensions: () => supportedTSImplementationExtensions,
            suppressLeadingAndTrailingTrivia: () => suppressLeadingAndTrailingTrivia,
            suppressLeadingTrivia: () => suppressLeadingTrivia,
            suppressTrailingTrivia: () => suppressTrailingTrivia,
            symbolEscapedNameNoDefault: () => symbolEscapedNameNoDefault,
            symbolName: () => symbolName,
            symbolNameNoDefault: () => symbolNameNoDefault,
            symbolPart: () => symbolPart,
            symbolToDisplayParts: () => symbolToDisplayParts,
            syntaxMayBeASICandidate: () => syntaxMayBeASICandidate,
            syntaxRequiresTrailingSemicolonOrASI: () => syntaxRequiresTrailingSemicolonOrASI,
            sys: () => sys,
            sysLog: () => sysLog,
            tagNamesAreEquivalent: () => tagNamesAreEquivalent,
            takeWhile: () => takeWhile,
            targetOptionDeclaration: () => targetOptionDeclaration,
            templateObjectHelper: () => templateObjectHelper,
            testFormatSettings: () => testFormatSettings,
            textChangeRangeIsUnchanged: () => textChangeRangeIsUnchanged,
            textChangeRangeNewSpan: () => textChangeRangeNewSpan,
            textChanges: () => ts_textChanges_exports,
            textOrKeywordPart: () => textOrKeywordPart,
            textPart: () => textPart,
            textRangeContainsPositionInclusive: () => textRangeContainsPositionInclusive,
            textSpanContainsPosition: () => textSpanContainsPosition,
            textSpanContainsTextSpan: () => textSpanContainsTextSpan,
            textSpanEnd: () => textSpanEnd,
            textSpanIntersection: () => textSpanIntersection,
            textSpanIntersectsWith: () => textSpanIntersectsWith,
            textSpanIntersectsWithPosition: () => textSpanIntersectsWithPosition,
            textSpanIntersectsWithTextSpan: () => textSpanIntersectsWithTextSpan,
            textSpanIsEmpty: () => textSpanIsEmpty,
            textSpanOverlap: () => textSpanOverlap,
            textSpanOverlapsWith: () => textSpanOverlapsWith,
            textSpansEqual: () => textSpansEqual,
            textToKeywordObj: () => textToKeywordObj,
            timestamp: () => timestamp,
            toArray: () => toArray,
            toBuilderFileEmit: () => toBuilderFileEmit,
            toBuilderStateFileInfoForMultiEmit: () => toBuilderStateFileInfoForMultiEmit,
            toEditorSettings: () => toEditorSettings,
            toFileNameLowerCase: () => toFileNameLowerCase,
            toLowerCase: () => toLowerCase,
            toPath: () => toPath,
            toProgramEmitPending: () => toProgramEmitPending,
            tokenIsIdentifierOrKeyword: () => tokenIsIdentifierOrKeyword,
            tokenIsIdentifierOrKeywordOrGreaterThan: () => tokenIsIdentifierOrKeywordOrGreaterThan,
            tokenToString: () => tokenToString,
            trace: () => trace,
            tracing: () => tracing,
            tracingEnabled: () => tracingEnabled,
            transform: () => transform,
            transformClassFields: () => transformClassFields,
            transformDeclarations: () => transformDeclarations,
            transformECMAScriptModule: () => transformECMAScriptModule,
            transformES2015: () => transformES2015,
            transformES2016: () => transformES2016,
            transformES2017: () => transformES2017,
            transformES2018: () => transformES2018,
            transformES2019: () => transformES2019,
            transformES2020: () => transformES2020,
            transformES2021: () => transformES2021,
            transformES5: () => transformES5,
            transformESDecorators: () => transformESDecorators,
            transformESNext: () => transformESNext,
            transformGenerators: () => transformGenerators,
            transformJsx: () => transformJsx,
            transformLegacyDecorators: () => transformLegacyDecorators,
            transformModule: () => transformModule,
            transformNamedEvaluation: () => transformNamedEvaluation,
            transformNodeModule: () => transformNodeModule,
            transformNodes: () => transformNodes,
            transformSystemModule: () => transformSystemModule,
            transformTypeScript: () => transformTypeScript,
            transpile: () => transpile,
            transpileModule: () => transpileModule,
            transpileOptionValueCompilerOptions: () => transpileOptionValueCompilerOptions,
            tryAddToSet: () => tryAddToSet,
            tryAndIgnoreErrors: () => tryAndIgnoreErrors,
            tryCast: () => tryCast,
            tryDirectoryExists: () => tryDirectoryExists,
            tryExtractTSExtension: () => tryExtractTSExtension,
            tryFileExists: () => tryFileExists,
            tryGetClassExtendingExpressionWithTypeArguments: () => tryGetClassExtendingExpressionWithTypeArguments,
            tryGetClassImplementingOrExtendingExpressionWithTypeArguments: () => tryGetClassImplementingOrExtendingExpressionWithTypeArguments,
            tryGetDirectories: () => tryGetDirectories,
            tryGetExtensionFromPath: () => tryGetExtensionFromPath2,
            tryGetImportFromModuleSpecifier: () => tryGetImportFromModuleSpecifier,
            tryGetJSDocSatisfiesTypeNode: () => tryGetJSDocSatisfiesTypeNode,
            tryGetModuleNameFromFile: () => tryGetModuleNameFromFile,
            tryGetModuleSpecifierFromDeclaration: () => tryGetModuleSpecifierFromDeclaration,
            tryGetNativePerformanceHooks: () => tryGetNativePerformanceHooks,
            tryGetPropertyAccessOrIdentifierToString: () => tryGetPropertyAccessOrIdentifierToString,
            tryGetPropertyNameOfBindingOrAssignmentElement: () => tryGetPropertyNameOfBindingOrAssignmentElement,
            tryGetSourceMappingURL: () => tryGetSourceMappingURL,
            tryGetTextOfPropertyName: () => tryGetTextOfPropertyName,
            tryIOAndConsumeErrors: () => tryIOAndConsumeErrors,
            tryParseJson: () => tryParseJson,
            tryParsePattern: () => tryParsePattern,
            tryParsePatterns: () => tryParsePatterns,
            tryParseRawSourceMap: () => tryParseRawSourceMap,
            tryReadDirectory: () => tryReadDirectory,
            tryReadFile: () => tryReadFile,
            tryRemoveDirectoryPrefix: () => tryRemoveDirectoryPrefix,
            tryRemoveExtension: () => tryRemoveExtension,
            tryRemovePrefix: () => tryRemovePrefix,
            tryRemoveSuffix: () => tryRemoveSuffix,
            typeAcquisitionDeclarations: () => typeAcquisitionDeclarations,
            typeAliasNamePart: () => typeAliasNamePart,
            typeDirectiveIsEqualTo: () => typeDirectiveIsEqualTo,
            typeKeywords: () => typeKeywords,
            typeParameterNamePart: () => typeParameterNamePart,
            typeToDisplayParts: () => typeToDisplayParts,
            unchangedPollThresholds: () => unchangedPollThresholds,
            unchangedTextChangeRange: () => unchangedTextChangeRange,
            unescapeLeadingUnderscores: () => unescapeLeadingUnderscores,
            unmangleScopedPackageName: () => unmangleScopedPackageName,
            unorderedRemoveItem: () => unorderedRemoveItem,
            unorderedRemoveItemAt: () => unorderedRemoveItemAt,
            unreachableCodeIsError: () => unreachableCodeIsError,
            unusedLabelIsError: () => unusedLabelIsError,
            unwrapInnermostStatementOfLabel: () => unwrapInnermostStatementOfLabel,
            updateErrorForNoInputFiles: () => updateErrorForNoInputFiles,
            updateLanguageServiceSourceFile: () => updateLanguageServiceSourceFile,
            updateMissingFilePathsWatch: () => updateMissingFilePathsWatch,
            updateResolutionField: () => updateResolutionField,
            updateSharedExtendedConfigFileWatcher: () => updateSharedExtendedConfigFileWatcher,
            updateSourceFile: () => updateSourceFile,
            updateWatchingWildcardDirectories: () => updateWatchingWildcardDirectories,
            usesExtensionsOnImports: () => usesExtensionsOnImports,
            usingSingleLineStringWriter: () => usingSingleLineStringWriter,
            utf16EncodeAsString: () => utf16EncodeAsString,
            validateLocaleAndSetLanguage: () => validateLocaleAndSetLanguage,
            valuesHelper: () => valuesHelper,
            version: () => version,
            versionMajorMinor: () => versionMajorMinor,
            visitArray: () => visitArray,
            visitCommaListElements: () => visitCommaListElements,
            visitEachChild: () => visitEachChild,
            visitFunctionBody: () => visitFunctionBody,
            visitIterationBody: () => visitIterationBody,
            visitLexicalEnvironment: () => visitLexicalEnvironment,
            visitNode: () => visitNode,
            visitNodes: () => visitNodes2,
            visitParameterList: () => visitParameterList,
            walkUpBindingElementsAndPatterns: () => walkUpBindingElementsAndPatterns,
            walkUpLexicalEnvironments: () => walkUpLexicalEnvironments,
            walkUpOuterExpressions: () => walkUpOuterExpressions,
            walkUpParenthesizedExpressions: () => walkUpParenthesizedExpressions,
            walkUpParenthesizedTypes: () => walkUpParenthesizedTypes,
            walkUpParenthesizedTypesAndGetParentAndChild: () => walkUpParenthesizedTypesAndGetParentAndChild,
            whitespaceOrMapCommentRegExp: () => whitespaceOrMapCommentRegExp,
            writeCommentRange: () => writeCommentRange,
            writeFile: () => writeFile,
            writeFileEnsuringDirectories: () => writeFileEnsuringDirectories,
            zipWith: () => zipWith
        });
        var init_ts8 = __esm({
            "src/typescript/_namespaces/ts.ts"() {
                "use strict";
                init_ts2();
                init_ts3();
                init_ts4();
                init_ts7();
                init_ts_server4();
            }
        });
        // src/typescript/typescript.ts
        var require_typescript = __commonJS({
            "src/typescript/typescript.ts"(exports, module2) {
                init_ts8();
                init_ts8();
                if (typeof console !== "undefined") {
                    Debug.loggingHost = {
                        log(level, s) {
                            switch (level) {
                                case 1 /* Error */:
                                    return console.error(s);
                                case 2 /* Warning */:
                                    return console.warn(s);
                                case 3 /* Info */:
                                    return console.log(s);
                                case 4 /* Verbose */:
                                    return console.log(s);
                            }
                        }
                    };
                }
                module2.exports = ts_exports3;
            }
        });
        return require_typescript();
    })();
    if (typeof module !== "undefined" && module.exports) {
        module.exports = ts;
    }
    
},
/* source-map-support/source-map-support.js */ function _(require, module, exports, __esModule, __esExport) {
    var SourceMapConsumer = require(23) /* source-map */.SourceMapConsumer;
    var path = require('path');
    var fs;
    try {
        fs = require('fs');
        if (!fs.existsSync || !fs.readFileSync) {
            // fs doesn't have all methods we need
            fs = null;
        }
    }
    catch (err) {
        /* nop */
    }
    var bufferFrom = require(34) /* buffer-from */;
    /**
     * Requires a module which is protected against bundler minification.
     *
     * @param {NodeModule} mod
     * @param {string} request
     */
    function dynamicRequire(mod, request) {
        return mod.require(request);
    }
    // Only install once if called multiple times
    var errorFormatterInstalled = false;
    var uncaughtShimInstalled = false;
    // If true, the caches are reset before a stack trace formatting operation
    var emptyCacheBetweenOperations = false;
    // Supports {browser, node, auto}
    var environment = "auto";
    // Maps a file path to a string containing the file contents
    var fileContentsCache = {};
    // Maps a file path to a source map for that file
    var sourceMapCache = {};
    // Regex for detecting source maps
    var reSourceMap = /^data:application\/json[^,]+base64,/;
    // Priority list of retrieve handlers
    var retrieveFileHandlers = [];
    var retrieveMapHandlers = [];
    function isInBrowser() {
        if (environment === "browser")
            return true;
        if (environment === "node")
            return false;
        return ((typeof window !== 'undefined') && (typeof XMLHttpRequest === 'function') && !(window.require && window.module && window.process && window.process.type === "renderer"));
    }
    function hasGlobalProcessEventEmitter() {
        return ((typeof process === 'object') && (process !== null) && (typeof process.on === 'function'));
    }
    function globalProcessVersion() {
        if ((typeof process === 'object') && (process !== null)) {
            return process.version;
        }
        else {
            return '';
        }
    }
    function globalProcessStderr() {
        if ((typeof process === 'object') && (process !== null)) {
            return process.stderr;
        }
    }
    function globalProcessExit(code) {
        if ((typeof process === 'object') && (process !== null) && (typeof process.exit === 'function')) {
            return process.exit(code);
        }
    }
    function handlerExec(list) {
        return function (arg) {
            for (var i = 0; i < list.length; i++) {
                var ret = list[i](arg);
                if (ret) {
                    return ret;
                }
            }
            return null;
        };
    }
    var retrieveFile = handlerExec(retrieveFileHandlers);
    retrieveFileHandlers.push(function (path) {
        // Trim the path to make sure there is no extra whitespace.
        path = path.trim();
        if (/^file:/.test(path)) {
            // existsSync/readFileSync can't handle file protocol, but once stripped, it works
            path = path.replace(/file:\/\/\/(\w:)?/, function (protocol, drive) {
                return drive ?
                    '' : // file:///C:/dir/file -> C:/dir/file
                    '/'; // file:///root-dir/file -> /root-dir/file
            });
        }
        if (path in fileContentsCache) {
            return fileContentsCache[path];
        }
        var contents = '';
        try {
            if (!fs) {
                // Use SJAX if we are in the browser
                var xhr = new XMLHttpRequest();
                xhr.open('GET', path, /** async */ false);
                xhr.send(null);
                if (xhr.readyState === 4 && xhr.status === 200) {
                    contents = xhr.responseText;
                }
            }
            else if (fs.existsSync(path)) {
                // Otherwise, use the filesystem
                contents = fs.readFileSync(path, 'utf8');
            }
        }
        catch (er) {
            /* ignore any errors */
        }
        return fileContentsCache[path] = contents;
    });
    // Support URLs relative to a directory, but be careful about a protocol prefix
    // in case we are in the browser (i.e. directories may start with "http://" or "file:///")
    function supportRelativeURL(file, url) {
        if (!file)
            return url;
        var dir = path.dirname(file);
        var match = /^\w+:\/\/[^\/]*/.exec(dir);
        var protocol = match ? match[0] : '';
        var startPath = dir.slice(protocol.length);
        if (protocol && /^\/\w\:/.test(startPath)) {
            // handle file:///C:/ paths
            protocol += '/';
            return protocol + path.resolve(dir.slice(protocol.length), url).replace(/\\/g, '/');
        }
        return protocol + path.resolve(dir.slice(protocol.length), url);
    }
    function retrieveSourceMapURL(source) {
        var fileData;
        if (isInBrowser()) {
            try {
                var xhr = new XMLHttpRequest();
                xhr.open('GET', source, false);
                xhr.send(null);
                fileData = xhr.readyState === 4 ? xhr.responseText : null;
                // Support providing a sourceMappingURL via the SourceMap header
                var sourceMapHeader = xhr.getResponseHeader("SourceMap") ||
                    xhr.getResponseHeader("X-SourceMap");
                if (sourceMapHeader) {
                    return sourceMapHeader;
                }
            }
            catch (e) {
            }
        }
        // Get the URL of the source map
        fileData = retrieveFile(source);
        var re = /(?:\/\/[@#][\s]*sourceMappingURL=([^\s'"]+)[\s]*$)|(?:\/\*[@#][\s]*sourceMappingURL=([^\s*'"]+)[\s]*(?:\*\/)[\s]*$)/mg;
        // Keep executing the search to find the *last* sourceMappingURL to avoid
        // picking up sourceMappingURLs from comments, strings, etc.
        var lastMatch, match;
        while (match = re.exec(fileData))
            lastMatch = match;
        if (!lastMatch)
            return null;
        return lastMatch[1];
    }
    ;
    // Can be overridden by the retrieveSourceMap option to install. Takes a
    // generated source filename; returns a {map, optional url} object, or null if
    // there is no source map.  The map field may be either a string or the parsed
    // JSON object (ie, it must be a valid argument to the SourceMapConsumer
    // constructor).
    var retrieveSourceMap = handlerExec(retrieveMapHandlers);
    retrieveMapHandlers.push(function (source) {
        var sourceMappingURL = retrieveSourceMapURL(source);
        if (!sourceMappingURL)
            return null;
        // Read the contents of the source map
        var sourceMapData;
        if (reSourceMap.test(sourceMappingURL)) {
            // Support source map URL as a data url
            var rawData = sourceMappingURL.slice(sourceMappingURL.indexOf(',') + 1);
            sourceMapData = bufferFrom(rawData, "base64").toString();
            sourceMappingURL = source;
        }
        else {
            // Support source map URLs relative to the source URL
            sourceMappingURL = supportRelativeURL(source, sourceMappingURL);
            sourceMapData = retrieveFile(sourceMappingURL);
        }
        if (!sourceMapData) {
            return null;
        }
        return {
            url: sourceMappingURL,
            map: sourceMapData
        };
    });
    function mapSourcePosition(position) {
        var sourceMap = sourceMapCache[position.source];
        if (!sourceMap) {
            // Call the (overrideable) retrieveSourceMap function to get the source map.
            var urlAndMap = retrieveSourceMap(position.source);
            if (urlAndMap) {
                sourceMap = sourceMapCache[position.source] = {
                    url: urlAndMap.url,
                    map: new SourceMapConsumer(urlAndMap.map)
                };
                // Load all sources stored inline with the source map into the file cache
                // to pretend like they are already loaded. They may not exist on disk.
                if (sourceMap.map.sourcesContent) {
                    sourceMap.map.sources.forEach(function (source, i) {
                        var contents = sourceMap.map.sourcesContent[i];
                        if (contents) {
                            var url = supportRelativeURL(sourceMap.url, source);
                            fileContentsCache[url] = contents;
                        }
                    });
                }
            }
            else {
                sourceMap = sourceMapCache[position.source] = {
                    url: null,
                    map: null
                };
            }
        }
        // Resolve the source URL relative to the URL of the source map
        if (sourceMap && sourceMap.map && typeof sourceMap.map.originalPositionFor === 'function') {
            var originalPosition = sourceMap.map.originalPositionFor(position);
            // Only return the original position if a matching line was found. If no
            // matching line is found then we return position instead, which will cause
            // the stack trace to print the path and line for the compiled file. It is
            // better to give a precise location in the compiled file than a vague
            // location in the original file.
            if (originalPosition.source !== null) {
                originalPosition.source = supportRelativeURL(sourceMap.url, originalPosition.source);
                return originalPosition;
            }
        }
        return position;
    }
    // Parses code generated by FormatEvalOrigin(), a function inside V8:
    // https://code.google.com/p/v8/source/browse/trunk/src/messages.js
    function mapEvalOrigin(origin) {
        // Most eval() calls are in this format
        var match = /^eval at ([^(]+) \((.+):(\d+):(\d+)\)$/.exec(origin);
        if (match) {
            var position = mapSourcePosition({
                source: match[2],
                line: +match[3],
                column: match[4] - 1
            });
            return 'eval at ' + match[1] + ' (' + position.source + ':' +
                position.line + ':' + (position.column + 1) + ')';
        }
        // Parse nested eval() calls using recursion
        match = /^eval at ([^(]+) \((.+)\)$/.exec(origin);
        if (match) {
            return 'eval at ' + match[1] + ' (' + mapEvalOrigin(match[2]) + ')';
        }
        // Make sure we still return useful information if we didn't find anything
        return origin;
    }
    // This is copied almost verbatim from the V8 source code at
    // https://code.google.com/p/v8/source/browse/trunk/src/messages.js. The
    // implementation of wrapCallSite() used to just forward to the actual source
    // code of CallSite.prototype.toString but unfortunately a new release of V8
    // did something to the prototype chain and broke the shim. The only fix I
    // could find was copy/paste.
    function CallSiteToString() {
        var fileName;
        var fileLocation = "";
        if (this.isNative()) {
            fileLocation = "native";
        }
        else {
            fileName = this.getScriptNameOrSourceURL();
            if (!fileName && this.isEval()) {
                fileLocation = this.getEvalOrigin();
                fileLocation += ", "; // Expecting source position to follow.
            }
            if (fileName) {
                fileLocation += fileName;
            }
            else {
                // Source code does not originate from a file and is not native, but we
                // can still get the source position inside the source string, e.g. in
                // an eval string.
                fileLocation += "<anonymous>";
            }
            var lineNumber = this.getLineNumber();
            if (lineNumber != null) {
                fileLocation += ":" + lineNumber;
                var columnNumber = this.getColumnNumber();
                if (columnNumber) {
                    fileLocation += ":" + columnNumber;
                }
            }
        }
        var line = "";
        var functionName = this.getFunctionName();
        var addSuffix = true;
        var isConstructor = this.isConstructor();
        var isMethodCall = !(this.isToplevel() || isConstructor);
        if (isMethodCall) {
            var typeName = this.getTypeName();
            // Fixes shim to be backward compatable with Node v0 to v4
            if (typeName === "[object Object]") {
                typeName = "null";
            }
            var methodName = this.getMethodName();
            if (functionName) {
                if (typeName && functionName.indexOf(typeName) != 0) {
                    line += typeName + ".";
                }
                line += functionName;
                if (methodName && functionName.indexOf("." + methodName) != functionName.length - methodName.length - 1) {
                    line += " [as " + methodName + "]";
                }
            }
            else {
                line += typeName + "." + (methodName || "<anonymous>");
            }
        }
        else if (isConstructor) {
            line += "new " + (functionName || "<anonymous>");
        }
        else if (functionName) {
            line += functionName;
        }
        else {
            line += fileLocation;
            addSuffix = false;
        }
        if (addSuffix) {
            line += " (" + fileLocation + ")";
        }
        return line;
    }
    function cloneCallSite(frame) {
        var object = {};
        Object.getOwnPropertyNames(Object.getPrototypeOf(frame)).forEach(function (name) {
            object[name] = /^(?:is|get)/.test(name) ? function () { return frame[name].call(frame); } : frame[name];
        });
        object.toString = CallSiteToString;
        return object;
    }
    function wrapCallSite(frame, state) {
        // provides interface backward compatibility
        if (state === undefined) {
            state = { nextPosition: null, curPosition: null };
        }
        if (frame.isNative()) {
            state.curPosition = null;
            return frame;
        }
        // Most call sites will return the source file from getFileName(), but code
        // passed to eval() ending in "//# sourceURL=..." will return the source file
        // from getScriptNameOrSourceURL() instead
        var source = frame.getFileName() || frame.getScriptNameOrSourceURL();
        if (source) {
            var line = frame.getLineNumber();
            var column = frame.getColumnNumber() - 1;
            // Fix position in Node where some (internal) code is prepended.
            // See https://github.com/evanw/node-source-map-support/issues/36
            // Header removed in node at ^10.16 || >=11.11.0
            // v11 is not an LTS candidate, we can just test the one version with it.
            // Test node versions for: 10.16-19, 10.20+, 12-19, 20-99, 100+, or 11.11
            var noHeader = /^v(10\.1[6-9]|10\.[2-9][0-9]|10\.[0-9]{3,}|1[2-9]\d*|[2-9]\d|\d{3,}|11\.11)/;
            var headerLength = noHeader.test(globalProcessVersion()) ? 0 : 62;
            if (line === 1 && column > headerLength && !isInBrowser() && !frame.isEval()) {
                column -= headerLength;
            }
            var position = mapSourcePosition({
                source: source,
                line: line,
                column: column
            });
            state.curPosition = position;
            frame = cloneCallSite(frame);
            var originalFunctionName = frame.getFunctionName;
            frame.getFunctionName = function () {
                if (state.nextPosition == null) {
                    return originalFunctionName();
                }
                return state.nextPosition.name || originalFunctionName();
            };
            frame.getFileName = function () { return position.source; };
            frame.getLineNumber = function () { return position.line; };
            frame.getColumnNumber = function () { return position.column + 1; };
            frame.getScriptNameOrSourceURL = function () { return position.source; };
            return frame;
        }
        // Code called using eval() needs special handling
        var origin = frame.isEval() && frame.getEvalOrigin();
        if (origin) {
            origin = mapEvalOrigin(origin);
            frame = cloneCallSite(frame);
            frame.getEvalOrigin = function () { return origin; };
            return frame;
        }
        // If we get here then we were unable to change the source position
        return frame;
    }
    // This function is part of the V8 stack trace API, for more info see:
    // https://v8.dev/docs/stack-trace-api
    function prepareStackTrace(error, stack) {
        if (emptyCacheBetweenOperations) {
            fileContentsCache = {};
            sourceMapCache = {};
        }
        var name = error.name || 'Error';
        var message = error.message || '';
        var errorString = name + ": " + message;
        var state = { nextPosition: null, curPosition: null };
        var processedStack = [];
        for (var i = stack.length - 1; i >= 0; i--) {
            processedStack.push('\n    at ' + wrapCallSite(stack[i], state));
            state.nextPosition = state.curPosition;
        }
        state.curPosition = state.nextPosition = null;
        return errorString + processedStack.reverse().join('');
    }
    // Generate position and snippet of original source with pointer
    function getErrorSource(error) {
        var match = /\n    at [^(]+ \((.*):(\d+):(\d+)\)/.exec(error.stack);
        if (match) {
            var source = match[1];
            var line = +match[2];
            var column = +match[3];
            // Support the inline sourceContents inside the source map
            var contents = fileContentsCache[source];
            // Support files on disk
            if (!contents && fs && fs.existsSync(source)) {
                try {
                    contents = fs.readFileSync(source, 'utf8');
                }
                catch (er) {
                    contents = '';
                }
            }
            // Format the line from the original source code like node does
            if (contents) {
                var code = contents.split(/(?:\r\n|\r|\n)/)[line - 1];
                if (code) {
                    return source + ':' + line + '\n' + code + '\n' +
                        new Array(column).join(' ') + '^';
                }
            }
        }
        return null;
    }
    function printErrorAndExit(error) {
        var source = getErrorSource(error);
        // Ensure error is printed synchronously and not truncated
        var stderr = globalProcessStderr();
        if (stderr && stderr._handle && stderr._handle.setBlocking) {
            stderr._handle.setBlocking(true);
        }
        if (source) {
            console.error();
            console.error(source);
        }
        console.error(error.stack);
        globalProcessExit(1);
    }
    function shimEmitUncaughtException() {
        var origEmit = process.emit;
        process.emit = function (type) {
            if (type === 'uncaughtException') {
                var hasStack = (arguments[1] && arguments[1].stack);
                var hasListeners = (this.listeners(type).length > 0);
                if (hasStack && !hasListeners) {
                    return printErrorAndExit(arguments[1]);
                }
            }
            return origEmit.apply(this, arguments);
        };
    }
    var originalRetrieveFileHandlers = retrieveFileHandlers.slice(0);
    var originalRetrieveMapHandlers = retrieveMapHandlers.slice(0);
    exports.wrapCallSite = wrapCallSite;
    exports.getErrorSource = getErrorSource;
    exports.mapSourcePosition = mapSourcePosition;
    exports.retrieveSourceMap = retrieveSourceMap;
    exports.install = function (options) {
        options = options || {};
        if (options.environment) {
            environment = options.environment;
            if (["node", "browser", "auto"].indexOf(environment) === -1) {
                throw new Error("environment " + environment + " was unknown. Available options are {auto, browser, node}");
            }
        }
        // Allow sources to be found by methods other than reading the files
        // directly from disk.
        if (options.retrieveFile) {
            if (options.overrideRetrieveFile) {
                retrieveFileHandlers.length = 0;
            }
            retrieveFileHandlers.unshift(options.retrieveFile);
        }
        // Allow source maps to be found by methods other than reading the files
        // directly from disk.
        if (options.retrieveSourceMap) {
            if (options.overrideRetrieveSourceMap) {
                retrieveMapHandlers.length = 0;
            }
            retrieveMapHandlers.unshift(options.retrieveSourceMap);
        }
        // Support runtime transpilers that include inline source maps
        if (options.hookRequire && !isInBrowser()) {
            // Use dynamicRequire to avoid including in browser bundles
            var Module = dynamicRequire(module, 'module');
            var $compile = Module.prototype._compile;
            if (!$compile.__sourceMapSupport) {
                Module.prototype._compile = function (content, filename) {
                    fileContentsCache[filename] = content;
                    sourceMapCache[filename] = undefined;
                    return $compile.call(this, content, filename);
                };
                Module.prototype._compile.__sourceMapSupport = true;
            }
        }
        // Configure options
        if (!emptyCacheBetweenOperations) {
            emptyCacheBetweenOperations = 'emptyCacheBetweenOperations' in options ?
                options.emptyCacheBetweenOperations : false;
        }
        // Install the error reformatter
        if (!errorFormatterInstalled) {
            errorFormatterInstalled = true;
            Error.prepareStackTrace = prepareStackTrace;
        }
        if (!uncaughtShimInstalled) {
            var installHandler = 'handleUncaughtExceptions' in options ?
                options.handleUncaughtExceptions : true;
            // Do not override 'uncaughtException' with our own handler in Node.js
            // Worker threads. Workers pass the error to the main thread as an event,
            // rather than printing something to stderr and exiting.
            try {
                // We need to use `dynamicRequire` because `require` on it's own will be optimized by WebPack/Browserify.
                var worker_threads = dynamicRequire(module, 'worker_threads');
                if (worker_threads.isMainThread === false) {
                    installHandler = false;
                }
            }
            catch (e) { }
            // Provide the option to not install the uncaught exception handler. This is
            // to support other uncaught exception handlers (in test frameworks, for
            // example). If this handler is not installed and there are no other uncaught
            // exception handlers, uncaught exceptions will be caught by node's built-in
            // exception handler and the process will still be terminated. However, the
            // generated JavaScript code will be shown above the stack trace instead of
            // the original source code.
            if (installHandler && hasGlobalProcessEventEmitter()) {
                uncaughtShimInstalled = true;
                shimEmitUncaughtException();
            }
        }
    };
    exports.resetRetrieveHandlers = function () {
        retrieveFileHandlers.length = 0;
        retrieveMapHandlers.length = 0;
        retrieveFileHandlers = originalRetrieveFileHandlers.slice(0);
        retrieveMapHandlers = originalRetrieveMapHandlers.slice(0);
        retrieveSourceMap = handlerExec(retrieveMapHandlers);
        retrieveFile = handlerExec(retrieveFileHandlers);
    };
},
/* source-map/source-map.js */ function _(require, module, exports, __esModule, __esExport) {
    /*
     * Copyright 2009-2011 Mozilla Foundation and contributors
     * Licensed under the New BSD license. See LICENSE.txt or:
     * http://opensource.org/licenses/BSD-3-Clause
     */
    exports.SourceMapGenerator = require(24) /* ./lib/source-map-generator */.SourceMapGenerator;
    exports.SourceMapConsumer = require(30) /* ./lib/source-map-consumer */.SourceMapConsumer;
    exports.SourceNode = require(33) /* ./lib/source-node */.SourceNode;
},
/* source-map/lib/source-map-generator.js */ function _(require, module, exports, __esModule, __esExport) {/* -*- Mode: js; js-indent-level: 2; -*- */
    /*
     * Copyright 2011 Mozilla Foundation and contributors
     * Licensed under the New BSD license. See LICENSE or:
     * http://opensource.org/licenses/BSD-3-Clause
     */
    var base64VLQ = require(25) /* ./base64-vlq */;
    var util = require(27) /* ./util */;
    var ArraySet = require(28) /* ./array-set */.ArraySet;
    var MappingList = require(29) /* ./mapping-list */.MappingList;
    /**
     * An instance of the SourceMapGenerator represents a source map which is
     * being built incrementally. You may pass an object with the following
     * properties:
     *
     *   - file: The filename of the generated source.
     *   - sourceRoot: A root for all relative URLs in this source map.
     */
    function SourceMapGenerator(aArgs) {
        if (!aArgs) {
            aArgs = {};
        }
        this._file = util.getArg(aArgs, 'file', null);
        this._sourceRoot = util.getArg(aArgs, 'sourceRoot', null);
        this._skipValidation = util.getArg(aArgs, 'skipValidation', false);
        this._sources = new ArraySet();
        this._names = new ArraySet();
        this._mappings = new MappingList();
        this._sourcesContents = null;
    }
    SourceMapGenerator.prototype._version = 3;
    /**
     * Creates a new SourceMapGenerator based on a SourceMapConsumer
     *
     * @param aSourceMapConsumer The SourceMap.
     */
    SourceMapGenerator.fromSourceMap =
        function SourceMapGenerator_fromSourceMap(aSourceMapConsumer) {
            var sourceRoot = aSourceMapConsumer.sourceRoot;
            var generator = new SourceMapGenerator({
                file: aSourceMapConsumer.file,
                sourceRoot: sourceRoot
            });
            aSourceMapConsumer.eachMapping(function (mapping) {
                var newMapping = {
                    generated: {
                        line: mapping.generatedLine,
                        column: mapping.generatedColumn
                    }
                };
                if (mapping.source != null) {
                    newMapping.source = mapping.source;
                    if (sourceRoot != null) {
                        newMapping.source = util.relative(sourceRoot, newMapping.source);
                    }
                    newMapping.original = {
                        line: mapping.originalLine,
                        column: mapping.originalColumn
                    };
                    if (mapping.name != null) {
                        newMapping.name = mapping.name;
                    }
                }
                generator.addMapping(newMapping);
            });
            aSourceMapConsumer.sources.forEach(function (sourceFile) {
                var sourceRelative = sourceFile;
                if (sourceRoot !== null) {
                    sourceRelative = util.relative(sourceRoot, sourceFile);
                }
                if (!generator._sources.has(sourceRelative)) {
                    generator._sources.add(sourceRelative);
                }
                var content = aSourceMapConsumer.sourceContentFor(sourceFile);
                if (content != null) {
                    generator.setSourceContent(sourceFile, content);
                }
            });
            return generator;
        };
    /**
     * Add a single mapping from original source line and column to the generated
     * source's line and column for this source map being created. The mapping
     * object should have the following properties:
     *
     *   - generated: An object with the generated line and column positions.
     *   - original: An object with the original line and column positions.
     *   - source: The original source file (relative to the sourceRoot).
     *   - name: An optional original token name for this mapping.
     */
    SourceMapGenerator.prototype.addMapping =
        function SourceMapGenerator_addMapping(aArgs) {
            var generated = util.getArg(aArgs, 'generated');
            var original = util.getArg(aArgs, 'original', null);
            var source = util.getArg(aArgs, 'source', null);
            var name = util.getArg(aArgs, 'name', null);
            if (!this._skipValidation) {
                this._validateMapping(generated, original, source, name);
            }
            if (source != null) {
                source = String(source);
                if (!this._sources.has(source)) {
                    this._sources.add(source);
                }
            }
            if (name != null) {
                name = String(name);
                if (!this._names.has(name)) {
                    this._names.add(name);
                }
            }
            this._mappings.add({
                generatedLine: generated.line,
                generatedColumn: generated.column,
                originalLine: original != null && original.line,
                originalColumn: original != null && original.column,
                source: source,
                name: name
            });
        };
    /**
     * Set the source content for a source file.
     */
    SourceMapGenerator.prototype.setSourceContent =
        function SourceMapGenerator_setSourceContent(aSourceFile, aSourceContent) {
            var source = aSourceFile;
            if (this._sourceRoot != null) {
                source = util.relative(this._sourceRoot, source);
            }
            if (aSourceContent != null) {
                // Add the source content to the _sourcesContents map.
                // Create a new _sourcesContents map if the property is null.
                if (!this._sourcesContents) {
                    this._sourcesContents = Object.create(null);
                }
                this._sourcesContents[util.toSetString(source)] = aSourceContent;
            }
            else if (this._sourcesContents) {
                // Remove the source file from the _sourcesContents map.
                // If the _sourcesContents map is empty, set the property to null.
                delete this._sourcesContents[util.toSetString(source)];
                if (Object.keys(this._sourcesContents).length === 0) {
                    this._sourcesContents = null;
                }
            }
        };
    /**
     * Applies the mappings of a sub-source-map for a specific source file to the
     * source map being generated. Each mapping to the supplied source file is
     * rewritten using the supplied source map. Note: The resolution for the
     * resulting mappings is the minimium of this map and the supplied map.
     *
     * @param aSourceMapConsumer The source map to be applied.
     * @param aSourceFile Optional. The filename of the source file.
     *        If omitted, SourceMapConsumer's file property will be used.
     * @param aSourceMapPath Optional. The dirname of the path to the source map
     *        to be applied. If relative, it is relative to the SourceMapConsumer.
     *        This parameter is needed when the two source maps aren't in the same
     *        directory, and the source map to be applied contains relative source
     *        paths. If so, those relative source paths need to be rewritten
     *        relative to the SourceMapGenerator.
     */
    SourceMapGenerator.prototype.applySourceMap =
        function SourceMapGenerator_applySourceMap(aSourceMapConsumer, aSourceFile, aSourceMapPath) {
            var sourceFile = aSourceFile;
            // If aSourceFile is omitted, we will use the file property of the SourceMap
            if (aSourceFile == null) {
                if (aSourceMapConsumer.file == null) {
                    throw new Error('SourceMapGenerator.prototype.applySourceMap requires either an explicit source file, ' +
                        'or the source map\'s "file" property. Both were omitted.');
                }
                sourceFile = aSourceMapConsumer.file;
            }
            var sourceRoot = this._sourceRoot;
            // Make "sourceFile" relative if an absolute Url is passed.
            if (sourceRoot != null) {
                sourceFile = util.relative(sourceRoot, sourceFile);
            }
            // Applying the SourceMap can add and remove items from the sources and
            // the names array.
            var newSources = new ArraySet();
            var newNames = new ArraySet();
            // Find mappings for the "sourceFile"
            this._mappings.unsortedForEach(function (mapping) {
                if (mapping.source === sourceFile && mapping.originalLine != null) {
                    // Check if it can be mapped by the source map, then update the mapping.
                    var original = aSourceMapConsumer.originalPositionFor({
                        line: mapping.originalLine,
                        column: mapping.originalColumn
                    });
                    if (original.source != null) {
                        // Copy mapping
                        mapping.source = original.source;
                        if (aSourceMapPath != null) {
                            mapping.source = util.join(aSourceMapPath, mapping.source);
                        }
                        if (sourceRoot != null) {
                            mapping.source = util.relative(sourceRoot, mapping.source);
                        }
                        mapping.originalLine = original.line;
                        mapping.originalColumn = original.column;
                        if (original.name != null) {
                            mapping.name = original.name;
                        }
                    }
                }
                var source = mapping.source;
                if (source != null && !newSources.has(source)) {
                    newSources.add(source);
                }
                var name = mapping.name;
                if (name != null && !newNames.has(name)) {
                    newNames.add(name);
                }
            }, this);
            this._sources = newSources;
            this._names = newNames;
            // Copy sourcesContents of applied map.
            aSourceMapConsumer.sources.forEach(function (sourceFile) {
                var content = aSourceMapConsumer.sourceContentFor(sourceFile);
                if (content != null) {
                    if (aSourceMapPath != null) {
                        sourceFile = util.join(aSourceMapPath, sourceFile);
                    }
                    if (sourceRoot != null) {
                        sourceFile = util.relative(sourceRoot, sourceFile);
                    }
                    this.setSourceContent(sourceFile, content);
                }
            }, this);
        };
    /**
     * A mapping can have one of the three levels of data:
     *
     *   1. Just the generated position.
     *   2. The Generated position, original position, and original source.
     *   3. Generated and original position, original source, as well as a name
     *      token.
     *
     * To maintain consistency, we validate that any new mapping being added falls
     * in to one of these categories.
     */
    SourceMapGenerator.prototype._validateMapping =
        function SourceMapGenerator_validateMapping(aGenerated, aOriginal, aSource, aName) {
            // When aOriginal is truthy but has empty values for .line and .column,
            // it is most likely a programmer error. In this case we throw a very
            // specific error message to try to guide them the right way.
            // For example: https://github.com/Polymer/polymer-bundler/pull/519
            if (aOriginal && typeof aOriginal.line !== 'number' && typeof aOriginal.column !== 'number') {
                throw new Error('original.line and original.column are not numbers -- you probably meant to omit ' +
                    'the original mapping entirely and only map the generated position. If so, pass ' +
                    'null for the original mapping instead of an object with empty or null values.');
            }
            if (aGenerated && 'line' in aGenerated && 'column' in aGenerated
                && aGenerated.line > 0 && aGenerated.column >= 0
                && !aOriginal && !aSource && !aName) {
                // Case 1.
                return;
            }
            else if (aGenerated && 'line' in aGenerated && 'column' in aGenerated
                && aOriginal && 'line' in aOriginal && 'column' in aOriginal
                && aGenerated.line > 0 && aGenerated.column >= 0
                && aOriginal.line > 0 && aOriginal.column >= 0
                && aSource) {
                // Cases 2 and 3.
                return;
            }
            else {
                throw new Error('Invalid mapping: ' + JSON.stringify({
                    generated: aGenerated,
                    source: aSource,
                    original: aOriginal,
                    name: aName
                }));
            }
        };
    /**
     * Serialize the accumulated mappings in to the stream of base 64 VLQs
     * specified by the source map format.
     */
    SourceMapGenerator.prototype._serializeMappings =
        function SourceMapGenerator_serializeMappings() {
            var previousGeneratedColumn = 0;
            var previousGeneratedLine = 1;
            var previousOriginalColumn = 0;
            var previousOriginalLine = 0;
            var previousName = 0;
            var previousSource = 0;
            var result = '';
            var next;
            var mapping;
            var nameIdx;
            var sourceIdx;
            var mappings = this._mappings.toArray();
            for (var i = 0, len = mappings.length; i < len; i++) {
                mapping = mappings[i];
                next = '';
                if (mapping.generatedLine !== previousGeneratedLine) {
                    previousGeneratedColumn = 0;
                    while (mapping.generatedLine !== previousGeneratedLine) {
                        next += ';';
                        previousGeneratedLine++;
                    }
                }
                else {
                    if (i > 0) {
                        if (!util.compareByGeneratedPositionsInflated(mapping, mappings[i - 1])) {
                            continue;
                        }
                        next += ',';
                    }
                }
                next += base64VLQ.encode(mapping.generatedColumn
                    - previousGeneratedColumn);
                previousGeneratedColumn = mapping.generatedColumn;
                if (mapping.source != null) {
                    sourceIdx = this._sources.indexOf(mapping.source);
                    next += base64VLQ.encode(sourceIdx - previousSource);
                    previousSource = sourceIdx;
                    // lines are stored 0-based in SourceMap spec version 3
                    next += base64VLQ.encode(mapping.originalLine - 1
                        - previousOriginalLine);
                    previousOriginalLine = mapping.originalLine - 1;
                    next += base64VLQ.encode(mapping.originalColumn
                        - previousOriginalColumn);
                    previousOriginalColumn = mapping.originalColumn;
                    if (mapping.name != null) {
                        nameIdx = this._names.indexOf(mapping.name);
                        next += base64VLQ.encode(nameIdx - previousName);
                        previousName = nameIdx;
                    }
                }
                result += next;
            }
            return result;
        };
    SourceMapGenerator.prototype._generateSourcesContent =
        function SourceMapGenerator_generateSourcesContent(aSources, aSourceRoot) {
            return aSources.map(function (source) {
                if (!this._sourcesContents) {
                    return null;
                }
                if (aSourceRoot != null) {
                    source = util.relative(aSourceRoot, source);
                }
                var key = util.toSetString(source);
                return Object.prototype.hasOwnProperty.call(this._sourcesContents, key)
                    ? this._sourcesContents[key]
                    : null;
            }, this);
        };
    /**
     * Externalize the source map.
     */
    SourceMapGenerator.prototype.toJSON =
        function SourceMapGenerator_toJSON() {
            var map = {
                version: this._version,
                sources: this._sources.toArray(),
                names: this._names.toArray(),
                mappings: this._serializeMappings()
            };
            if (this._file != null) {
                map.file = this._file;
            }
            if (this._sourceRoot != null) {
                map.sourceRoot = this._sourceRoot;
            }
            if (this._sourcesContents) {
                map.sourcesContent = this._generateSourcesContent(map.sources, map.sourceRoot);
            }
            return map;
        };
    /**
     * Render the source map being generated to a string.
     */
    SourceMapGenerator.prototype.toString =
        function SourceMapGenerator_toString() {
            return JSON.stringify(this.toJSON());
        };
    exports.SourceMapGenerator = SourceMapGenerator;
},
/* source-map/lib/base64-vlq.js */ function _(require, module, exports, __esModule, __esExport) {/* -*- Mode: js; js-indent-level: 2; -*- */
    /*
     * Copyright 2011 Mozilla Foundation and contributors
     * Licensed under the New BSD license. See LICENSE or:
     * http://opensource.org/licenses/BSD-3-Clause
     *
     * Based on the Base 64 VLQ implementation in Closure Compiler:
     * https://code.google.com/p/closure-compiler/source/browse/trunk/src/com/google/debugging/sourcemap/Base64VLQ.java
     *
     * Copyright 2011 The Closure Compiler Authors. All rights reserved.
     * Redistribution and use in source and binary forms, with or without
     * modification, are permitted provided that the following conditions are
     * met:
     *
     *  * Redistributions of source code must retain the above copyright
     *    notice, this list of conditions and the following disclaimer.
     *  * Redistributions in binary form must reproduce the above
     *    copyright notice, this list of conditions and the following
     *    disclaimer in the documentation and/or other materials provided
     *    with the distribution.
     *  * Neither the name of Google Inc. nor the names of its
     *    contributors may be used to endorse or promote products derived
     *    from this software without specific prior written permission.
     *
     * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
     * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
     * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
     * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
     * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
     * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
     * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
     * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
     * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
     * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
     * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
     */
    var base64 = require(26) /* ./base64 */;
    // A single base 64 digit can contain 6 bits of data. For the base 64 variable
    // length quantities we use in the source map spec, the first bit is the sign,
    // the next four bits are the actual value, and the 6th bit is the
    // continuation bit. The continuation bit tells us whether there are more
    // digits in this value following this digit.
    //
    //   Continuation
    //   |    Sign
    //   |    |
    //   V    V
    //   101011
    var VLQ_BASE_SHIFT = 5;
    // binary: 100000
    var VLQ_BASE = 1 << VLQ_BASE_SHIFT;
    // binary: 011111
    var VLQ_BASE_MASK = VLQ_BASE - 1;
    // binary: 100000
    var VLQ_CONTINUATION_BIT = VLQ_BASE;
    /**
     * Converts from a two-complement value to a value where the sign bit is
     * placed in the least significant bit.  For example, as decimals:
     *   1 becomes 2 (10 binary), -1 becomes 3 (11 binary)
     *   2 becomes 4 (100 binary), -2 becomes 5 (101 binary)
     */
    function toVLQSigned(aValue) {
        return aValue < 0
            ? ((-aValue) << 1) + 1
            : (aValue << 1) + 0;
    }
    /**
     * Converts to a two-complement value from a value where the sign bit is
     * placed in the least significant bit.  For example, as decimals:
     *   2 (10 binary) becomes 1, 3 (11 binary) becomes -1
     *   4 (100 binary) becomes 2, 5 (101 binary) becomes -2
     */
    function fromVLQSigned(aValue) {
        var isNegative = (aValue & 1) === 1;
        var shifted = aValue >> 1;
        return isNegative
            ? -shifted
            : shifted;
    }
    /**
     * Returns the base 64 VLQ encoded value.
     */
    exports.encode = function base64VLQ_encode(aValue) {
        var encoded = "";
        var digit;
        var vlq = toVLQSigned(aValue);
        do {
            digit = vlq & VLQ_BASE_MASK;
            vlq >>>= VLQ_BASE_SHIFT;
            if (vlq > 0) {
                // There are still more digits in this value, so we must make sure the
                // continuation bit is marked.
                digit |= VLQ_CONTINUATION_BIT;
            }
            encoded += base64.encode(digit);
        } while (vlq > 0);
        return encoded;
    };
    /**
     * Decodes the next base 64 VLQ value from the given string and returns the
     * value and the rest of the string via the out parameter.
     */
    exports.decode = function base64VLQ_decode(aStr, aIndex, aOutParam) {
        var strLen = aStr.length;
        var result = 0;
        var shift = 0;
        var continuation, digit;
        do {
            if (aIndex >= strLen) {
                throw new Error("Expected more digits in base 64 VLQ value.");
            }
            digit = base64.decode(aStr.charCodeAt(aIndex++));
            if (digit === -1) {
                throw new Error("Invalid base64 digit: " + aStr.charAt(aIndex - 1));
            }
            continuation = !!(digit & VLQ_CONTINUATION_BIT);
            digit &= VLQ_BASE_MASK;
            result = result + (digit << shift);
            shift += VLQ_BASE_SHIFT;
        } while (continuation);
        aOutParam.value = fromVLQSigned(result);
        aOutParam.rest = aIndex;
    };
},
/* source-map/lib/base64.js */ function _(require, module, exports, __esModule, __esExport) {/* -*- Mode: js; js-indent-level: 2; -*- */
    /*
     * Copyright 2011 Mozilla Foundation and contributors
     * Licensed under the New BSD license. See LICENSE or:
     * http://opensource.org/licenses/BSD-3-Clause
     */
    var intToCharMap = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/'.split('');
    /**
     * Encode an integer in the range of 0 to 63 to a single base 64 digit.
     */
    exports.encode = function (number) {
        if (0 <= number && number < intToCharMap.length) {
            return intToCharMap[number];
        }
        throw new TypeError("Must be between 0 and 63: " + number);
    };
    /**
     * Decode a single base 64 character code digit to an integer. Returns -1 on
     * failure.
     */
    exports.decode = function (charCode) {
        var bigA = 65; // 'A'
        var bigZ = 90; // 'Z'
        var littleA = 97; // 'a'
        var littleZ = 122; // 'z'
        var zero = 48; // '0'
        var nine = 57; // '9'
        var plus = 43; // '+'
        var slash = 47; // '/'
        var littleOffset = 26;
        var numberOffset = 52;
        // 0 - 25: ABCDEFGHIJKLMNOPQRSTUVWXYZ
        if (bigA <= charCode && charCode <= bigZ) {
            return (charCode - bigA);
        }
        // 26 - 51: abcdefghijklmnopqrstuvwxyz
        if (littleA <= charCode && charCode <= littleZ) {
            return (charCode - littleA + littleOffset);
        }
        // 52 - 61: 0123456789
        if (zero <= charCode && charCode <= nine) {
            return (charCode - zero + numberOffset);
        }
        // 62: +
        if (charCode == plus) {
            return 62;
        }
        // 63: /
        if (charCode == slash) {
            return 63;
        }
        // Invalid base64 digit.
        return -1;
    };
},
/* source-map/lib/util.js */ function _(require, module, exports, __esModule, __esExport) {/* -*- Mode: js; js-indent-level: 2; -*- */
    /*
     * Copyright 2011 Mozilla Foundation and contributors
     * Licensed under the New BSD license. See LICENSE or:
     * http://opensource.org/licenses/BSD-3-Clause
     */
    /**
     * This is a helper function for getting values from parameter/options
     * objects.
     *
     * @param args The object we are extracting values from
     * @param name The name of the property we are getting.
     * @param defaultValue An optional value to return if the property is missing
     * from the object. If this is not specified and the property is missing, an
     * error will be thrown.
     */
    function getArg(aArgs, aName, aDefaultValue) {
        if (aName in aArgs) {
            return aArgs[aName];
        }
        else if (arguments.length === 3) {
            return aDefaultValue;
        }
        else {
            throw new Error('"' + aName + '" is a required argument.');
        }
    }
    exports.getArg = getArg;
    var urlRegexp = /^(?:([\w+\-.]+):)?\/\/(?:(\w+:\w+)@)?([\w.-]*)(?::(\d+))?(.*)$/;
    var dataUrlRegexp = /^data:.+\,.+$/;
    function urlParse(aUrl) {
        var match = aUrl.match(urlRegexp);
        if (!match) {
            return null;
        }
        return {
            scheme: match[1],
            auth: match[2],
            host: match[3],
            port: match[4],
            path: match[5]
        };
    }
    exports.urlParse = urlParse;
    function urlGenerate(aParsedUrl) {
        var url = '';
        if (aParsedUrl.scheme) {
            url += aParsedUrl.scheme + ':';
        }
        url += '//';
        if (aParsedUrl.auth) {
            url += aParsedUrl.auth + '@';
        }
        if (aParsedUrl.host) {
            url += aParsedUrl.host;
        }
        if (aParsedUrl.port) {
            url += ":" + aParsedUrl.port;
        }
        if (aParsedUrl.path) {
            url += aParsedUrl.path;
        }
        return url;
    }
    exports.urlGenerate = urlGenerate;
    /**
     * Normalizes a path, or the path portion of a URL:
     *
     * - Replaces consecutive slashes with one slash.
     * - Removes unnecessary '.' parts.
     * - Removes unnecessary '<dir>/..' parts.
     *
     * Based on code in the Node.js 'path' core module.
     *
     * @param aPath The path or url to normalize.
     */
    function normalize(aPath) {
        var path = aPath;
        var url = urlParse(aPath);
        if (url) {
            if (!url.path) {
                return aPath;
            }
            path = url.path;
        }
        var isAbsolute = exports.isAbsolute(path);
        var parts = path.split(/\/+/);
        for (var part, up = 0, i = parts.length - 1; i >= 0; i--) {
            part = parts[i];
            if (part === '.') {
                parts.splice(i, 1);
            }
            else if (part === '..') {
                up++;
            }
            else if (up > 0) {
                if (part === '') {
                    // The first part is blank if the path is absolute. Trying to go
                    // above the root is a no-op. Therefore we can remove all '..' parts
                    // directly after the root.
                    parts.splice(i + 1, up);
                    up = 0;
                }
                else {
                    parts.splice(i, 2);
                    up--;
                }
            }
        }
        path = parts.join('/');
        if (path === '') {
            path = isAbsolute ? '/' : '.';
        }
        if (url) {
            url.path = path;
            return urlGenerate(url);
        }
        return path;
    }
    exports.normalize = normalize;
    /**
     * Joins two paths/URLs.
     *
     * @param aRoot The root path or URL.
     * @param aPath The path or URL to be joined with the root.
     *
     * - If aPath is a URL or a data URI, aPath is returned, unless aPath is a
     *   scheme-relative URL: Then the scheme of aRoot, if any, is prepended
     *   first.
     * - Otherwise aPath is a path. If aRoot is a URL, then its path portion
     *   is updated with the result and aRoot is returned. Otherwise the result
     *   is returned.
     *   - If aPath is absolute, the result is aPath.
     *   - Otherwise the two paths are joined with a slash.
     * - Joining for example 'http://' and 'www.example.com' is also supported.
     */
    function join(aRoot, aPath) {
        if (aRoot === "") {
            aRoot = ".";
        }
        if (aPath === "") {
            aPath = ".";
        }
        var aPathUrl = urlParse(aPath);
        var aRootUrl = urlParse(aRoot);
        if (aRootUrl) {
            aRoot = aRootUrl.path || '/';
        }
        // `join(foo, '//www.example.org')`
        if (aPathUrl && !aPathUrl.scheme) {
            if (aRootUrl) {
                aPathUrl.scheme = aRootUrl.scheme;
            }
            return urlGenerate(aPathUrl);
        }
        if (aPathUrl || aPath.match(dataUrlRegexp)) {
            return aPath;
        }
        // `join('http://', 'www.example.com')`
        if (aRootUrl && !aRootUrl.host && !aRootUrl.path) {
            aRootUrl.host = aPath;
            return urlGenerate(aRootUrl);
        }
        var joined = aPath.charAt(0) === '/'
            ? aPath
            : normalize(aRoot.replace(/\/+$/, '') + '/' + aPath);
        if (aRootUrl) {
            aRootUrl.path = joined;
            return urlGenerate(aRootUrl);
        }
        return joined;
    }
    exports.join = join;
    exports.isAbsolute = function (aPath) {
        return aPath.charAt(0) === '/' || urlRegexp.test(aPath);
    };
    /**
     * Make a path relative to a URL or another path.
     *
     * @param aRoot The root path or URL.
     * @param aPath The path or URL to be made relative to aRoot.
     */
    function relative(aRoot, aPath) {
        if (aRoot === "") {
            aRoot = ".";
        }
        aRoot = aRoot.replace(/\/$/, '');
        // It is possible for the path to be above the root. In this case, simply
        // checking whether the root is a prefix of the path won't work. Instead, we
        // need to remove components from the root one by one, until either we find
        // a prefix that fits, or we run out of components to remove.
        var level = 0;
        while (aPath.indexOf(aRoot + '/') !== 0) {
            var index = aRoot.lastIndexOf("/");
            if (index < 0) {
                return aPath;
            }
            // If the only part of the root that is left is the scheme (i.e. http://,
            // file:///, etc.), one or more slashes (/), or simply nothing at all, we
            // have exhausted all components, so the path is not relative to the root.
            aRoot = aRoot.slice(0, index);
            if (aRoot.match(/^([^\/]+:\/)?\/*$/)) {
                return aPath;
            }
            ++level;
        }
        // Make sure we add a "../" for each component we removed from the root.
        return Array(level + 1).join("../") + aPath.substr(aRoot.length + 1);
    }
    exports.relative = relative;
    var supportsNullProto = (function () {
        var obj = Object.create(null);
        return !('__proto__' in obj);
    }());
    function identity(s) {
        return s;
    }
    /**
     * Because behavior goes wacky when you set `__proto__` on objects, we
     * have to prefix all the strings in our set with an arbitrary character.
     *
     * See https://github.com/mozilla/source-map/pull/31 and
     * https://github.com/mozilla/source-map/issues/30
     *
     * @param String aStr
     */
    function toSetString(aStr) {
        if (isProtoString(aStr)) {
            return '$' + aStr;
        }
        return aStr;
    }
    exports.toSetString = supportsNullProto ? identity : toSetString;
    function fromSetString(aStr) {
        if (isProtoString(aStr)) {
            return aStr.slice(1);
        }
        return aStr;
    }
    exports.fromSetString = supportsNullProto ? identity : fromSetString;
    function isProtoString(s) {
        if (!s) {
            return false;
        }
        var length = s.length;
        if (length < 9 /* "__proto__".length */) {
            return false;
        }
        if (s.charCodeAt(length - 1) !== 95 /* '_' */ ||
            s.charCodeAt(length - 2) !== 95 /* '_' */ ||
            s.charCodeAt(length - 3) !== 111 /* 'o' */ ||
            s.charCodeAt(length - 4) !== 116 /* 't' */ ||
            s.charCodeAt(length - 5) !== 111 /* 'o' */ ||
            s.charCodeAt(length - 6) !== 114 /* 'r' */ ||
            s.charCodeAt(length - 7) !== 112 /* 'p' */ ||
            s.charCodeAt(length - 8) !== 95 /* '_' */ ||
            s.charCodeAt(length - 9) !== 95 /* '_' */) {
            return false;
        }
        for (var i = length - 10; i >= 0; i--) {
            if (s.charCodeAt(i) !== 36 /* '$' */) {
                return false;
            }
        }
        return true;
    }
    /**
     * Comparator between two mappings where the original positions are compared.
     *
     * Optionally pass in `true` as `onlyCompareGenerated` to consider two
     * mappings with the same original source/line/column, but different generated
     * line and column the same. Useful when searching for a mapping with a
     * stubbed out mapping.
     */
    function compareByOriginalPositions(mappingA, mappingB, onlyCompareOriginal) {
        var cmp = strcmp(mappingA.source, mappingB.source);
        if (cmp !== 0) {
            return cmp;
        }
        cmp = mappingA.originalLine - mappingB.originalLine;
        if (cmp !== 0) {
            return cmp;
        }
        cmp = mappingA.originalColumn - mappingB.originalColumn;
        if (cmp !== 0 || onlyCompareOriginal) {
            return cmp;
        }
        cmp = mappingA.generatedColumn - mappingB.generatedColumn;
        if (cmp !== 0) {
            return cmp;
        }
        cmp = mappingA.generatedLine - mappingB.generatedLine;
        if (cmp !== 0) {
            return cmp;
        }
        return strcmp(mappingA.name, mappingB.name);
    }
    exports.compareByOriginalPositions = compareByOriginalPositions;
    /**
     * Comparator between two mappings with deflated source and name indices where
     * the generated positions are compared.
     *
     * Optionally pass in `true` as `onlyCompareGenerated` to consider two
     * mappings with the same generated line and column, but different
     * source/name/original line and column the same. Useful when searching for a
     * mapping with a stubbed out mapping.
     */
    function compareByGeneratedPositionsDeflated(mappingA, mappingB, onlyCompareGenerated) {
        var cmp = mappingA.generatedLine - mappingB.generatedLine;
        if (cmp !== 0) {
            return cmp;
        }
        cmp = mappingA.generatedColumn - mappingB.generatedColumn;
        if (cmp !== 0 || onlyCompareGenerated) {
            return cmp;
        }
        cmp = strcmp(mappingA.source, mappingB.source);
        if (cmp !== 0) {
            return cmp;
        }
        cmp = mappingA.originalLine - mappingB.originalLine;
        if (cmp !== 0) {
            return cmp;
        }
        cmp = mappingA.originalColumn - mappingB.originalColumn;
        if (cmp !== 0) {
            return cmp;
        }
        return strcmp(mappingA.name, mappingB.name);
    }
    exports.compareByGeneratedPositionsDeflated = compareByGeneratedPositionsDeflated;
    function strcmp(aStr1, aStr2) {
        if (aStr1 === aStr2) {
            return 0;
        }
        if (aStr1 === null) {
            return 1; // aStr2 !== null
        }
        if (aStr2 === null) {
            return -1; // aStr1 !== null
        }
        if (aStr1 > aStr2) {
            return 1;
        }
        return -1;
    }
    /**
     * Comparator between two mappings with inflated source and name strings where
     * the generated positions are compared.
     */
    function compareByGeneratedPositionsInflated(mappingA, mappingB) {
        var cmp = mappingA.generatedLine - mappingB.generatedLine;
        if (cmp !== 0) {
            return cmp;
        }
        cmp = mappingA.generatedColumn - mappingB.generatedColumn;
        if (cmp !== 0) {
            return cmp;
        }
        cmp = strcmp(mappingA.source, mappingB.source);
        if (cmp !== 0) {
            return cmp;
        }
        cmp = mappingA.originalLine - mappingB.originalLine;
        if (cmp !== 0) {
            return cmp;
        }
        cmp = mappingA.originalColumn - mappingB.originalColumn;
        if (cmp !== 0) {
            return cmp;
        }
        return strcmp(mappingA.name, mappingB.name);
    }
    exports.compareByGeneratedPositionsInflated = compareByGeneratedPositionsInflated;
    /**
     * Strip any JSON XSSI avoidance prefix from the string (as documented
     * in the source maps specification), and then parse the string as
     * JSON.
     */
    function parseSourceMapInput(str) {
        return JSON.parse(str.replace(/^\)]}'[^\n]*\n/, ''));
    }
    exports.parseSourceMapInput = parseSourceMapInput;
    /**
     * Compute the URL of a source given the the source root, the source's
     * URL, and the source map's URL.
     */
    function computeSourceURL(sourceRoot, sourceURL, sourceMapURL) {
        sourceURL = sourceURL || '';
        if (sourceRoot) {
            // This follows what Chrome does.
            if (sourceRoot[sourceRoot.length - 1] !== '/' && sourceURL[0] !== '/') {
                sourceRoot += '/';
            }
            // The spec says:
            //   Line 4: An optional source root, useful for relocating source
            //   files on a server or removing repeated values in the
            //   “sources” entry.  This value is prepended to the individual
            //   entries in the “source” field.
            sourceURL = sourceRoot + sourceURL;
        }
        // Historically, SourceMapConsumer did not take the sourceMapURL as
        // a parameter.  This mode is still somewhat supported, which is why
        // this code block is conditional.  However, it's preferable to pass
        // the source map URL to SourceMapConsumer, so that this function
        // can implement the source URL resolution algorithm as outlined in
        // the spec.  This block is basically the equivalent of:
        //    new URL(sourceURL, sourceMapURL).toString()
        // ... except it avoids using URL, which wasn't available in the
        // older releases of node still supported by this library.
        //
        // The spec says:
        //   If the sources are not absolute URLs after prepending of the
        //   “sourceRoot”, the sources are resolved relative to the
        //   SourceMap (like resolving script src in a html document).
        if (sourceMapURL) {
            var parsed = urlParse(sourceMapURL);
            if (!parsed) {
                throw new Error("sourceMapURL could not be parsed");
            }
            if (parsed.path) {
                // Strip the last path component, but keep the "/".
                var index = parsed.path.lastIndexOf('/');
                if (index >= 0) {
                    parsed.path = parsed.path.substring(0, index + 1);
                }
            }
            sourceURL = join(urlGenerate(parsed), sourceURL);
        }
        return normalize(sourceURL);
    }
    exports.computeSourceURL = computeSourceURL;
},
/* source-map/lib/array-set.js */ function _(require, module, exports, __esModule, __esExport) {/* -*- Mode: js; js-indent-level: 2; -*- */
    /*
     * Copyright 2011 Mozilla Foundation and contributors
     * Licensed under the New BSD license. See LICENSE or:
     * http://opensource.org/licenses/BSD-3-Clause
     */
    var util = require(27) /* ./util */;
    var has = Object.prototype.hasOwnProperty;
    var hasNativeMap = typeof Map !== "undefined";
    /**
     * A data structure which is a combination of an array and a set. Adding a new
     * member is O(1), testing for membership is O(1), and finding the index of an
     * element is O(1). Removing elements from the set is not supported. Only
     * strings are supported for membership.
     */
    function ArraySet() {
        this._array = [];
        this._set = hasNativeMap ? new Map() : Object.create(null);
    }
    /**
     * Static method for creating ArraySet instances from an existing array.
     */
    ArraySet.fromArray = function ArraySet_fromArray(aArray, aAllowDuplicates) {
        var set = new ArraySet();
        for (var i = 0, len = aArray.length; i < len; i++) {
            set.add(aArray[i], aAllowDuplicates);
        }
        return set;
    };
    /**
     * Return how many unique items are in this ArraySet. If duplicates have been
     * added, than those do not count towards the size.
     *
     * @returns Number
     */
    ArraySet.prototype.size = function ArraySet_size() {
        return hasNativeMap ? this._set.size : Object.getOwnPropertyNames(this._set).length;
    };
    /**
     * Add the given string to this set.
     *
     * @param String aStr
     */
    ArraySet.prototype.add = function ArraySet_add(aStr, aAllowDuplicates) {
        var sStr = hasNativeMap ? aStr : util.toSetString(aStr);
        var isDuplicate = hasNativeMap ? this.has(aStr) : has.call(this._set, sStr);
        var idx = this._array.length;
        if (!isDuplicate || aAllowDuplicates) {
            this._array.push(aStr);
        }
        if (!isDuplicate) {
            if (hasNativeMap) {
                this._set.set(aStr, idx);
            }
            else {
                this._set[sStr] = idx;
            }
        }
    };
    /**
     * Is the given string a member of this set?
     *
     * @param String aStr
     */
    ArraySet.prototype.has = function ArraySet_has(aStr) {
        if (hasNativeMap) {
            return this._set.has(aStr);
        }
        else {
            var sStr = util.toSetString(aStr);
            return has.call(this._set, sStr);
        }
    };
    /**
     * What is the index of the given string in the array?
     *
     * @param String aStr
     */
    ArraySet.prototype.indexOf = function ArraySet_indexOf(aStr) {
        if (hasNativeMap) {
            var idx = this._set.get(aStr);
            if (idx >= 0) {
                return idx;
            }
        }
        else {
            var sStr = util.toSetString(aStr);
            if (has.call(this._set, sStr)) {
                return this._set[sStr];
            }
        }
        throw new Error('"' + aStr + '" is not in the set.');
    };
    /**
     * What is the element at the given index?
     *
     * @param Number aIdx
     */
    ArraySet.prototype.at = function ArraySet_at(aIdx) {
        if (aIdx >= 0 && aIdx < this._array.length) {
            return this._array[aIdx];
        }
        throw new Error('No element indexed by ' + aIdx);
    };
    /**
     * Returns the array representation of this set (which has the proper indices
     * indicated by indexOf). Note that this is a copy of the internal array used
     * for storing the members so that no one can mess with internal state.
     */
    ArraySet.prototype.toArray = function ArraySet_toArray() {
        return this._array.slice();
    };
    exports.ArraySet = ArraySet;
},
/* source-map/lib/mapping-list.js */ function _(require, module, exports, __esModule, __esExport) {/* -*- Mode: js; js-indent-level: 2; -*- */
    /*
     * Copyright 2014 Mozilla Foundation and contributors
     * Licensed under the New BSD license. See LICENSE or:
     * http://opensource.org/licenses/BSD-3-Clause
     */
    var util = require(27) /* ./util */;
    /**
     * Determine whether mappingB is after mappingA with respect to generated
     * position.
     */
    function generatedPositionAfter(mappingA, mappingB) {
        // Optimized for most common case
        var lineA = mappingA.generatedLine;
        var lineB = mappingB.generatedLine;
        var columnA = mappingA.generatedColumn;
        var columnB = mappingB.generatedColumn;
        return lineB > lineA || lineB == lineA && columnB >= columnA ||
            util.compareByGeneratedPositionsInflated(mappingA, mappingB) <= 0;
    }
    /**
     * A data structure to provide a sorted view of accumulated mappings in a
     * performance conscious manner. It trades a neglibable overhead in general
     * case for a large speedup in case of mappings being added in order.
     */
    function MappingList() {
        this._array = [];
        this._sorted = true;
        // Serves as infimum
        this._last = { generatedLine: -1, generatedColumn: 0 };
    }
    /**
     * Iterate through internal items. This method takes the same arguments that
     * `Array.prototype.forEach` takes.
     *
     * NOTE: The order of the mappings is NOT guaranteed.
     */
    MappingList.prototype.unsortedForEach =
        function MappingList_forEach(aCallback, aThisArg) {
            this._array.forEach(aCallback, aThisArg);
        };
    /**
     * Add the given source mapping.
     *
     * @param Object aMapping
     */
    MappingList.prototype.add = function MappingList_add(aMapping) {
        if (generatedPositionAfter(this._last, aMapping)) {
            this._last = aMapping;
            this._array.push(aMapping);
        }
        else {
            this._sorted = false;
            this._array.push(aMapping);
        }
    };
    /**
     * Returns the flat, sorted array of mappings. The mappings are sorted by
     * generated position.
     *
     * WARNING: This method returns internal data without copying, for
     * performance. The return value must NOT be mutated, and should be treated as
     * an immutable borrow. If you want to take ownership, you must make your own
     * copy.
     */
    MappingList.prototype.toArray = function MappingList_toArray() {
        if (!this._sorted) {
            this._array.sort(util.compareByGeneratedPositionsInflated);
            this._sorted = true;
        }
        return this._array;
    };
    exports.MappingList = MappingList;
},
/* source-map/lib/source-map-consumer.js */ function _(require, module, exports, __esModule, __esExport) {/* -*- Mode: js; js-indent-level: 2; -*- */
    /*
     * Copyright 2011 Mozilla Foundation and contributors
     * Licensed under the New BSD license. See LICENSE or:
     * http://opensource.org/licenses/BSD-3-Clause
     */
    var util = require(27) /* ./util */;
    var binarySearch = require(31) /* ./binary-search */;
    var ArraySet = require(28) /* ./array-set */.ArraySet;
    var base64VLQ = require(25) /* ./base64-vlq */;
    var quickSort = require(32) /* ./quick-sort */.quickSort;
    function SourceMapConsumer(aSourceMap, aSourceMapURL) {
        var sourceMap = aSourceMap;
        if (typeof aSourceMap === 'string') {
            sourceMap = util.parseSourceMapInput(aSourceMap);
        }
        return sourceMap.sections != null
            ? new IndexedSourceMapConsumer(sourceMap, aSourceMapURL)
            : new BasicSourceMapConsumer(sourceMap, aSourceMapURL);
    }
    SourceMapConsumer.fromSourceMap = function (aSourceMap, aSourceMapURL) {
        return BasicSourceMapConsumer.fromSourceMap(aSourceMap, aSourceMapURL);
    };
    /**
     * The version of the source mapping spec that we are consuming.
     */
    SourceMapConsumer.prototype._version = 3;
    // `__generatedMappings` and `__originalMappings` are arrays that hold the
    // parsed mapping coordinates from the source map's "mappings" attribute. They
    // are lazily instantiated, accessed via the `_generatedMappings` and
    // `_originalMappings` getters respectively, and we only parse the mappings
    // and create these arrays once queried for a source location. We jump through
    // these hoops because there can be many thousands of mappings, and parsing
    // them is expensive, so we only want to do it if we must.
    //
    // Each object in the arrays is of the form:
    //
    //     {
    //       generatedLine: The line number in the generated code,
    //       generatedColumn: The column number in the generated code,
    //       source: The path to the original source file that generated this
    //               chunk of code,
    //       originalLine: The line number in the original source that
    //                     corresponds to this chunk of generated code,
    //       originalColumn: The column number in the original source that
    //                       corresponds to this chunk of generated code,
    //       name: The name of the original symbol which generated this chunk of
    //             code.
    //     }
    //
    // All properties except for `generatedLine` and `generatedColumn` can be
    // `null`.
    //
    // `_generatedMappings` is ordered by the generated positions.
    //
    // `_originalMappings` is ordered by the original positions.
    SourceMapConsumer.prototype.__generatedMappings = null;
    Object.defineProperty(SourceMapConsumer.prototype, '_generatedMappings', {
        configurable: true,
        enumerable: true,
        get: function () {
            if (!this.__generatedMappings) {
                this._parseMappings(this._mappings, this.sourceRoot);
            }
            return this.__generatedMappings;
        }
    });
    SourceMapConsumer.prototype.__originalMappings = null;
    Object.defineProperty(SourceMapConsumer.prototype, '_originalMappings', {
        configurable: true,
        enumerable: true,
        get: function () {
            if (!this.__originalMappings) {
                this._parseMappings(this._mappings, this.sourceRoot);
            }
            return this.__originalMappings;
        }
    });
    SourceMapConsumer.prototype._charIsMappingSeparator =
        function SourceMapConsumer_charIsMappingSeparator(aStr, index) {
            var c = aStr.charAt(index);
            return c === ";" || c === ",";
        };
    /**
     * Parse the mappings in a string in to a data structure which we can easily
     * query (the ordered arrays in the `this.__generatedMappings` and
     * `this.__originalMappings` properties).
     */
    SourceMapConsumer.prototype._parseMappings =
        function SourceMapConsumer_parseMappings(aStr, aSourceRoot) {
            throw new Error("Subclasses must implement _parseMappings");
        };
    SourceMapConsumer.GENERATED_ORDER = 1;
    SourceMapConsumer.ORIGINAL_ORDER = 2;
    SourceMapConsumer.GREATEST_LOWER_BOUND = 1;
    SourceMapConsumer.LEAST_UPPER_BOUND = 2;
    /**
     * Iterate over each mapping between an original source/line/column and a
     * generated line/column in this source map.
     *
     * @param Function aCallback
     *        The function that is called with each mapping.
     * @param Object aContext
     *        Optional. If specified, this object will be the value of `this` every
     *        time that `aCallback` is called.
     * @param aOrder
     *        Either `SourceMapConsumer.GENERATED_ORDER` or
     *        `SourceMapConsumer.ORIGINAL_ORDER`. Specifies whether you want to
     *        iterate over the mappings sorted by the generated file's line/column
     *        order or the original's source/line/column order, respectively. Defaults to
     *        `SourceMapConsumer.GENERATED_ORDER`.
     */
    SourceMapConsumer.prototype.eachMapping =
        function SourceMapConsumer_eachMapping(aCallback, aContext, aOrder) {
            var context = aContext || null;
            var order = aOrder || SourceMapConsumer.GENERATED_ORDER;
            var mappings;
            switch (order) {
                case SourceMapConsumer.GENERATED_ORDER:
                    mappings = this._generatedMappings;
                    break;
                case SourceMapConsumer.ORIGINAL_ORDER:
                    mappings = this._originalMappings;
                    break;
                default:
                    throw new Error("Unknown order of iteration.");
            }
            var sourceRoot = this.sourceRoot;
            mappings.map(function (mapping) {
                var source = mapping.source === null ? null : this._sources.at(mapping.source);
                source = util.computeSourceURL(sourceRoot, source, this._sourceMapURL);
                return {
                    source: source,
                    generatedLine: mapping.generatedLine,
                    generatedColumn: mapping.generatedColumn,
                    originalLine: mapping.originalLine,
                    originalColumn: mapping.originalColumn,
                    name: mapping.name === null ? null : this._names.at(mapping.name)
                };
            }, this).forEach(aCallback, context);
        };
    /**
     * Returns all generated line and column information for the original source,
     * line, and column provided. If no column is provided, returns all mappings
     * corresponding to a either the line we are searching for or the next
     * closest line that has any mappings. Otherwise, returns all mappings
     * corresponding to the given line and either the column we are searching for
     * or the next closest column that has any offsets.
     *
     * The only argument is an object with the following properties:
     *
     *   - source: The filename of the original source.
     *   - line: The line number in the original source.  The line number is 1-based.
     *   - column: Optional. the column number in the original source.
     *    The column number is 0-based.
     *
     * and an array of objects is returned, each with the following properties:
     *
     *   - line: The line number in the generated source, or null.  The
     *    line number is 1-based.
     *   - column: The column number in the generated source, or null.
     *    The column number is 0-based.
     */
    SourceMapConsumer.prototype.allGeneratedPositionsFor =
        function SourceMapConsumer_allGeneratedPositionsFor(aArgs) {
            var line = util.getArg(aArgs, 'line');
            // When there is no exact match, BasicSourceMapConsumer.prototype._findMapping
            // returns the index of the closest mapping less than the needle. By
            // setting needle.originalColumn to 0, we thus find the last mapping for
            // the given line, provided such a mapping exists.
            var needle = {
                source: util.getArg(aArgs, 'source'),
                originalLine: line,
                originalColumn: util.getArg(aArgs, 'column', 0)
            };
            needle.source = this._findSourceIndex(needle.source);
            if (needle.source < 0) {
                return [];
            }
            var mappings = [];
            var index = this._findMapping(needle, this._originalMappings, "originalLine", "originalColumn", util.compareByOriginalPositions, binarySearch.LEAST_UPPER_BOUND);
            if (index >= 0) {
                var mapping = this._originalMappings[index];
                if (aArgs.column === undefined) {
                    var originalLine = mapping.originalLine;
                    // Iterate until either we run out of mappings, or we run into
                    // a mapping for a different line than the one we found. Since
                    // mappings are sorted, this is guaranteed to find all mappings for
                    // the line we found.
                    while (mapping && mapping.originalLine === originalLine) {
                        mappings.push({
                            line: util.getArg(mapping, 'generatedLine', null),
                            column: util.getArg(mapping, 'generatedColumn', null),
                            lastColumn: util.getArg(mapping, 'lastGeneratedColumn', null)
                        });
                        mapping = this._originalMappings[++index];
                    }
                }
                else {
                    var originalColumn = mapping.originalColumn;
                    // Iterate until either we run out of mappings, or we run into
                    // a mapping for a different line than the one we were searching for.
                    // Since mappings are sorted, this is guaranteed to find all mappings for
                    // the line we are searching for.
                    while (mapping &&
                        mapping.originalLine === line &&
                        mapping.originalColumn == originalColumn) {
                        mappings.push({
                            line: util.getArg(mapping, 'generatedLine', null),
                            column: util.getArg(mapping, 'generatedColumn', null),
                            lastColumn: util.getArg(mapping, 'lastGeneratedColumn', null)
                        });
                        mapping = this._originalMappings[++index];
                    }
                }
            }
            return mappings;
        };
    exports.SourceMapConsumer = SourceMapConsumer;
    /**
     * A BasicSourceMapConsumer instance represents a parsed source map which we can
     * query for information about the original file positions by giving it a file
     * position in the generated source.
     *
     * The first parameter is the raw source map (either as a JSON string, or
     * already parsed to an object). According to the spec, source maps have the
     * following attributes:
     *
     *   - version: Which version of the source map spec this map is following.
     *   - sources: An array of URLs to the original source files.
     *   - names: An array of identifiers which can be referrenced by individual mappings.
     *   - sourceRoot: Optional. The URL root from which all sources are relative.
     *   - sourcesContent: Optional. An array of contents of the original source files.
     *   - mappings: A string of base64 VLQs which contain the actual mappings.
     *   - file: Optional. The generated file this source map is associated with.
     *
     * Here is an example source map, taken from the source map spec[0]:
     *
     *     {
     *       version : 3,
     *       file: "out.js",
     *       sourceRoot : "",
     *       sources: ["foo.js", "bar.js"],
     *       names: ["src", "maps", "are", "fun"],
     *       mappings: "AA,AB;;ABCDE;"
     *     }
     *
     * The second parameter, if given, is a string whose value is the URL
     * at which the source map was found.  This URL is used to compute the
     * sources array.
     *
     * [0]: https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit?pli=1#
     */
    function BasicSourceMapConsumer(aSourceMap, aSourceMapURL) {
        var sourceMap = aSourceMap;
        if (typeof aSourceMap === 'string') {
            sourceMap = util.parseSourceMapInput(aSourceMap);
        }
        var version = util.getArg(sourceMap, 'version');
        var sources = util.getArg(sourceMap, 'sources');
        // Sass 3.3 leaves out the 'names' array, so we deviate from the spec (which
        // requires the array) to play nice here.
        var names = util.getArg(sourceMap, 'names', []);
        var sourceRoot = util.getArg(sourceMap, 'sourceRoot', null);
        var sourcesContent = util.getArg(sourceMap, 'sourcesContent', null);
        var mappings = util.getArg(sourceMap, 'mappings');
        var file = util.getArg(sourceMap, 'file', null);
        // Once again, Sass deviates from the spec and supplies the version as a
        // string rather than a number, so we use loose equality checking here.
        if (version != this._version) {
            throw new Error('Unsupported version: ' + version);
        }
        if (sourceRoot) {
            sourceRoot = util.normalize(sourceRoot);
        }
        sources = sources
            .map(String)
            // Some source maps produce relative source paths like "./foo.js" instead of
            // "foo.js".  Normalize these first so that future comparisons will succeed.
            // See bugzil.la/1090768.
            .map(util.normalize)
            // Always ensure that absolute sources are internally stored relative to
            // the source root, if the source root is absolute. Not doing this would
            // be particularly problematic when the source root is a prefix of the
            // source (valid, but why??). See github issue #199 and bugzil.la/1188982.
            .map(function (source) {
            return sourceRoot && util.isAbsolute(sourceRoot) && util.isAbsolute(source)
                ? util.relative(sourceRoot, source)
                : source;
        });
        // Pass `true` below to allow duplicate names and sources. While source maps
        // are intended to be compressed and deduplicated, the TypeScript compiler
        // sometimes generates source maps with duplicates in them. See Github issue
        // #72 and bugzil.la/889492.
        this._names = ArraySet.fromArray(names.map(String), true);
        this._sources = ArraySet.fromArray(sources, true);
        this._absoluteSources = this._sources.toArray().map(function (s) {
            return util.computeSourceURL(sourceRoot, s, aSourceMapURL);
        });
        this.sourceRoot = sourceRoot;
        this.sourcesContent = sourcesContent;
        this._mappings = mappings;
        this._sourceMapURL = aSourceMapURL;
        this.file = file;
    }
    BasicSourceMapConsumer.prototype = Object.create(SourceMapConsumer.prototype);
    BasicSourceMapConsumer.prototype.consumer = SourceMapConsumer;
    /**
     * Utility function to find the index of a source.  Returns -1 if not
     * found.
     */
    BasicSourceMapConsumer.prototype._findSourceIndex = function (aSource) {
        var relativeSource = aSource;
        if (this.sourceRoot != null) {
            relativeSource = util.relative(this.sourceRoot, relativeSource);
        }
        if (this._sources.has(relativeSource)) {
            return this._sources.indexOf(relativeSource);
        }
        // Maybe aSource is an absolute URL as returned by |sources|.  In
        // this case we can't simply undo the transform.
        var i;
        for (i = 0; i < this._absoluteSources.length; ++i) {
            if (this._absoluteSources[i] == aSource) {
                return i;
            }
        }
        return -1;
    };
    /**
     * Create a BasicSourceMapConsumer from a SourceMapGenerator.
     *
     * @param SourceMapGenerator aSourceMap
     *        The source map that will be consumed.
     * @param String aSourceMapURL
     *        The URL at which the source map can be found (optional)
     * @returns BasicSourceMapConsumer
     */
    BasicSourceMapConsumer.fromSourceMap =
        function SourceMapConsumer_fromSourceMap(aSourceMap, aSourceMapURL) {
            var smc = Object.create(BasicSourceMapConsumer.prototype);
            var names = smc._names = ArraySet.fromArray(aSourceMap._names.toArray(), true);
            var sources = smc._sources = ArraySet.fromArray(aSourceMap._sources.toArray(), true);
            smc.sourceRoot = aSourceMap._sourceRoot;
            smc.sourcesContent = aSourceMap._generateSourcesContent(smc._sources.toArray(), smc.sourceRoot);
            smc.file = aSourceMap._file;
            smc._sourceMapURL = aSourceMapURL;
            smc._absoluteSources = smc._sources.toArray().map(function (s) {
                return util.computeSourceURL(smc.sourceRoot, s, aSourceMapURL);
            });
            // Because we are modifying the entries (by converting string sources and
            // names to indices into the sources and names ArraySets), we have to make
            // a copy of the entry or else bad things happen. Shared mutable state
            // strikes again! See github issue #191.
            var generatedMappings = aSourceMap._mappings.toArray().slice();
            var destGeneratedMappings = smc.__generatedMappings = [];
            var destOriginalMappings = smc.__originalMappings = [];
            for (var i = 0, length = generatedMappings.length; i < length; i++) {
                var srcMapping = generatedMappings[i];
                var destMapping = new Mapping;
                destMapping.generatedLine = srcMapping.generatedLine;
                destMapping.generatedColumn = srcMapping.generatedColumn;
                if (srcMapping.source) {
                    destMapping.source = sources.indexOf(srcMapping.source);
                    destMapping.originalLine = srcMapping.originalLine;
                    destMapping.originalColumn = srcMapping.originalColumn;
                    if (srcMapping.name) {
                        destMapping.name = names.indexOf(srcMapping.name);
                    }
                    destOriginalMappings.push(destMapping);
                }
                destGeneratedMappings.push(destMapping);
            }
            quickSort(smc.__originalMappings, util.compareByOriginalPositions);
            return smc;
        };
    /**
     * The version of the source mapping spec that we are consuming.
     */
    BasicSourceMapConsumer.prototype._version = 3;
    /**
     * The list of original sources.
     */
    Object.defineProperty(BasicSourceMapConsumer.prototype, 'sources', {
        get: function () {
            return this._absoluteSources.slice();
        }
    });
    /**
     * Provide the JIT with a nice shape / hidden class.
     */
    function Mapping() {
        this.generatedLine = 0;
        this.generatedColumn = 0;
        this.source = null;
        this.originalLine = null;
        this.originalColumn = null;
        this.name = null;
    }
    /**
     * Parse the mappings in a string in to a data structure which we can easily
     * query (the ordered arrays in the `this.__generatedMappings` and
     * `this.__originalMappings` properties).
     */
    BasicSourceMapConsumer.prototype._parseMappings =
        function SourceMapConsumer_parseMappings(aStr, aSourceRoot) {
            var generatedLine = 1;
            var previousGeneratedColumn = 0;
            var previousOriginalLine = 0;
            var previousOriginalColumn = 0;
            var previousSource = 0;
            var previousName = 0;
            var length = aStr.length;
            var index = 0;
            var cachedSegments = {};
            var temp = {};
            var originalMappings = [];
            var generatedMappings = [];
            var mapping, str, segment, end, value;
            while (index < length) {
                if (aStr.charAt(index) === ';') {
                    generatedLine++;
                    index++;
                    previousGeneratedColumn = 0;
                }
                else if (aStr.charAt(index) === ',') {
                    index++;
                }
                else {
                    mapping = new Mapping();
                    mapping.generatedLine = generatedLine;
                    // Because each offset is encoded relative to the previous one,
                    // many segments often have the same encoding. We can exploit this
                    // fact by caching the parsed variable length fields of each segment,
                    // allowing us to avoid a second parse if we encounter the same
                    // segment again.
                    for (end = index; end < length; end++) {
                        if (this._charIsMappingSeparator(aStr, end)) {
                            break;
                        }
                    }
                    str = aStr.slice(index, end);
                    segment = cachedSegments[str];
                    if (segment) {
                        index += str.length;
                    }
                    else {
                        segment = [];
                        while (index < end) {
                            base64VLQ.decode(aStr, index, temp);
                            value = temp.value;
                            index = temp.rest;
                            segment.push(value);
                        }
                        if (segment.length === 2) {
                            throw new Error('Found a source, but no line and column');
                        }
                        if (segment.length === 3) {
                            throw new Error('Found a source and line, but no column');
                        }
                        cachedSegments[str] = segment;
                    }
                    // Generated column.
                    mapping.generatedColumn = previousGeneratedColumn + segment[0];
                    previousGeneratedColumn = mapping.generatedColumn;
                    if (segment.length > 1) {
                        // Original source.
                        mapping.source = previousSource + segment[1];
                        previousSource += segment[1];
                        // Original line.
                        mapping.originalLine = previousOriginalLine + segment[2];
                        previousOriginalLine = mapping.originalLine;
                        // Lines are stored 0-based
                        mapping.originalLine += 1;
                        // Original column.
                        mapping.originalColumn = previousOriginalColumn + segment[3];
                        previousOriginalColumn = mapping.originalColumn;
                        if (segment.length > 4) {
                            // Original name.
                            mapping.name = previousName + segment[4];
                            previousName += segment[4];
                        }
                    }
                    generatedMappings.push(mapping);
                    if (typeof mapping.originalLine === 'number') {
                        originalMappings.push(mapping);
                    }
                }
            }
            quickSort(generatedMappings, util.compareByGeneratedPositionsDeflated);
            this.__generatedMappings = generatedMappings;
            quickSort(originalMappings, util.compareByOriginalPositions);
            this.__originalMappings = originalMappings;
        };
    /**
     * Find the mapping that best matches the hypothetical "needle" mapping that
     * we are searching for in the given "haystack" of mappings.
     */
    BasicSourceMapConsumer.prototype._findMapping =
        function SourceMapConsumer_findMapping(aNeedle, aMappings, aLineName, aColumnName, aComparator, aBias) {
            // To return the position we are searching for, we must first find the
            // mapping for the given position and then return the opposite position it
            // points to. Because the mappings are sorted, we can use binary search to
            // find the best mapping.
            if (aNeedle[aLineName] <= 0) {
                throw new TypeError('Line must be greater than or equal to 1, got '
                    + aNeedle[aLineName]);
            }
            if (aNeedle[aColumnName] < 0) {
                throw new TypeError('Column must be greater than or equal to 0, got '
                    + aNeedle[aColumnName]);
            }
            return binarySearch.search(aNeedle, aMappings, aComparator, aBias);
        };
    /**
     * Compute the last column for each generated mapping. The last column is
     * inclusive.
     */
    BasicSourceMapConsumer.prototype.computeColumnSpans =
        function SourceMapConsumer_computeColumnSpans() {
            for (var index = 0; index < this._generatedMappings.length; ++index) {
                var mapping = this._generatedMappings[index];
                // Mappings do not contain a field for the last generated columnt. We
                // can come up with an optimistic estimate, however, by assuming that
                // mappings are contiguous (i.e. given two consecutive mappings, the
                // first mapping ends where the second one starts).
                if (index + 1 < this._generatedMappings.length) {
                    var nextMapping = this._generatedMappings[index + 1];
                    if (mapping.generatedLine === nextMapping.generatedLine) {
                        mapping.lastGeneratedColumn = nextMapping.generatedColumn - 1;
                        continue;
                    }
                }
                // The last mapping for each line spans the entire line.
                mapping.lastGeneratedColumn = Infinity;
            }
        };
    /**
     * Returns the original source, line, and column information for the generated
     * source's line and column positions provided. The only argument is an object
     * with the following properties:
     *
     *   - line: The line number in the generated source.  The line number
     *     is 1-based.
     *   - column: The column number in the generated source.  The column
     *     number is 0-based.
     *   - bias: Either 'SourceMapConsumer.GREATEST_LOWER_BOUND' or
     *     'SourceMapConsumer.LEAST_UPPER_BOUND'. Specifies whether to return the
     *     closest element that is smaller than or greater than the one we are
     *     searching for, respectively, if the exact element cannot be found.
     *     Defaults to 'SourceMapConsumer.GREATEST_LOWER_BOUND'.
     *
     * and an object is returned with the following properties:
     *
     *   - source: The original source file, or null.
     *   - line: The line number in the original source, or null.  The
     *     line number is 1-based.
     *   - column: The column number in the original source, or null.  The
     *     column number is 0-based.
     *   - name: The original identifier, or null.
     */
    BasicSourceMapConsumer.prototype.originalPositionFor =
        function SourceMapConsumer_originalPositionFor(aArgs) {
            var needle = {
                generatedLine: util.getArg(aArgs, 'line'),
                generatedColumn: util.getArg(aArgs, 'column')
            };
            var index = this._findMapping(needle, this._generatedMappings, "generatedLine", "generatedColumn", util.compareByGeneratedPositionsDeflated, util.getArg(aArgs, 'bias', SourceMapConsumer.GREATEST_LOWER_BOUND));
            if (index >= 0) {
                var mapping = this._generatedMappings[index];
                if (mapping.generatedLine === needle.generatedLine) {
                    var source = util.getArg(mapping, 'source', null);
                    if (source !== null) {
                        source = this._sources.at(source);
                        source = util.computeSourceURL(this.sourceRoot, source, this._sourceMapURL);
                    }
                    var name = util.getArg(mapping, 'name', null);
                    if (name !== null) {
                        name = this._names.at(name);
                    }
                    return {
                        source: source,
                        line: util.getArg(mapping, 'originalLine', null),
                        column: util.getArg(mapping, 'originalColumn', null),
                        name: name
                    };
                }
            }
            return {
                source: null,
                line: null,
                column: null,
                name: null
            };
        };
    /**
     * Return true if we have the source content for every source in the source
     * map, false otherwise.
     */
    BasicSourceMapConsumer.prototype.hasContentsOfAllSources =
        function BasicSourceMapConsumer_hasContentsOfAllSources() {
            if (!this.sourcesContent) {
                return false;
            }
            return this.sourcesContent.length >= this._sources.size() &&
                !this.sourcesContent.some(function (sc) { return sc == null; });
        };
    /**
     * Returns the original source content. The only argument is the url of the
     * original source file. Returns null if no original source content is
     * available.
     */
    BasicSourceMapConsumer.prototype.sourceContentFor =
        function SourceMapConsumer_sourceContentFor(aSource, nullOnMissing) {
            if (!this.sourcesContent) {
                return null;
            }
            var index = this._findSourceIndex(aSource);
            if (index >= 0) {
                return this.sourcesContent[index];
            }
            var relativeSource = aSource;
            if (this.sourceRoot != null) {
                relativeSource = util.relative(this.sourceRoot, relativeSource);
            }
            var url;
            if (this.sourceRoot != null
                && (url = util.urlParse(this.sourceRoot))) {
                // XXX: file:// URIs and absolute paths lead to unexpected behavior for
                // many users. We can help them out when they expect file:// URIs to
                // behave like it would if they were running a local HTTP server. See
                // https://bugzilla.mozilla.org/show_bug.cgi?id=885597.
                var fileUriAbsPath = relativeSource.replace(/^file:\/\//, "");
                if (url.scheme == "file"
                    && this._sources.has(fileUriAbsPath)) {
                    return this.sourcesContent[this._sources.indexOf(fileUriAbsPath)];
                }
                if ((!url.path || url.path == "/")
                    && this._sources.has("/" + relativeSource)) {
                    return this.sourcesContent[this._sources.indexOf("/" + relativeSource)];
                }
            }
            // This function is used recursively from
            // IndexedSourceMapConsumer.prototype.sourceContentFor. In that case, we
            // don't want to throw if we can't find the source - we just want to
            // return null, so we provide a flag to exit gracefully.
            if (nullOnMissing) {
                return null;
            }
            else {
                throw new Error('"' + relativeSource + '" is not in the SourceMap.');
            }
        };
    /**
     * Returns the generated line and column information for the original source,
     * line, and column positions provided. The only argument is an object with
     * the following properties:
     *
     *   - source: The filename of the original source.
     *   - line: The line number in the original source.  The line number
     *     is 1-based.
     *   - column: The column number in the original source.  The column
     *     number is 0-based.
     *   - bias: Either 'SourceMapConsumer.GREATEST_LOWER_BOUND' or
     *     'SourceMapConsumer.LEAST_UPPER_BOUND'. Specifies whether to return the
     *     closest element that is smaller than or greater than the one we are
     *     searching for, respectively, if the exact element cannot be found.
     *     Defaults to 'SourceMapConsumer.GREATEST_LOWER_BOUND'.
     *
     * and an object is returned with the following properties:
     *
     *   - line: The line number in the generated source, or null.  The
     *     line number is 1-based.
     *   - column: The column number in the generated source, or null.
     *     The column number is 0-based.
     */
    BasicSourceMapConsumer.prototype.generatedPositionFor =
        function SourceMapConsumer_generatedPositionFor(aArgs) {
            var source = util.getArg(aArgs, 'source');
            source = this._findSourceIndex(source);
            if (source < 0) {
                return {
                    line: null,
                    column: null,
                    lastColumn: null
                };
            }
            var needle = {
                source: source,
                originalLine: util.getArg(aArgs, 'line'),
                originalColumn: util.getArg(aArgs, 'column')
            };
            var index = this._findMapping(needle, this._originalMappings, "originalLine", "originalColumn", util.compareByOriginalPositions, util.getArg(aArgs, 'bias', SourceMapConsumer.GREATEST_LOWER_BOUND));
            if (index >= 0) {
                var mapping = this._originalMappings[index];
                if (mapping.source === needle.source) {
                    return {
                        line: util.getArg(mapping, 'generatedLine', null),
                        column: util.getArg(mapping, 'generatedColumn', null),
                        lastColumn: util.getArg(mapping, 'lastGeneratedColumn', null)
                    };
                }
            }
            return {
                line: null,
                column: null,
                lastColumn: null
            };
        };
    exports.BasicSourceMapConsumer = BasicSourceMapConsumer;
    /**
     * An IndexedSourceMapConsumer instance represents a parsed source map which
     * we can query for information. It differs from BasicSourceMapConsumer in
     * that it takes "indexed" source maps (i.e. ones with a "sections" field) as
     * input.
     *
     * The first parameter is a raw source map (either as a JSON string, or already
     * parsed to an object). According to the spec for indexed source maps, they
     * have the following attributes:
     *
     *   - version: Which version of the source map spec this map is following.
     *   - file: Optional. The generated file this source map is associated with.
     *   - sections: A list of section definitions.
     *
     * Each value under the "sections" field has two fields:
     *   - offset: The offset into the original specified at which this section
     *       begins to apply, defined as an object with a "line" and "column"
     *       field.
     *   - map: A source map definition. This source map could also be indexed,
     *       but doesn't have to be.
     *
     * Instead of the "map" field, it's also possible to have a "url" field
     * specifying a URL to retrieve a source map from, but that's currently
     * unsupported.
     *
     * Here's an example source map, taken from the source map spec[0], but
     * modified to omit a section which uses the "url" field.
     *
     *  {
     *    version : 3,
     *    file: "app.js",
     *    sections: [{
     *      offset: {line:100, column:10},
     *      map: {
     *        version : 3,
     *        file: "section.js",
     *        sources: ["foo.js", "bar.js"],
     *        names: ["src", "maps", "are", "fun"],
     *        mappings: "AAAA,E;;ABCDE;"
     *      }
     *    }],
     *  }
     *
     * The second parameter, if given, is a string whose value is the URL
     * at which the source map was found.  This URL is used to compute the
     * sources array.
     *
     * [0]: https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit#heading=h.535es3xeprgt
     */
    function IndexedSourceMapConsumer(aSourceMap, aSourceMapURL) {
        var sourceMap = aSourceMap;
        if (typeof aSourceMap === 'string') {
            sourceMap = util.parseSourceMapInput(aSourceMap);
        }
        var version = util.getArg(sourceMap, 'version');
        var sections = util.getArg(sourceMap, 'sections');
        if (version != this._version) {
            throw new Error('Unsupported version: ' + version);
        }
        this._sources = new ArraySet();
        this._names = new ArraySet();
        var lastOffset = {
            line: -1,
            column: 0
        };
        this._sections = sections.map(function (s) {
            if (s.url) {
                // The url field will require support for asynchronicity.
                // See https://github.com/mozilla/source-map/issues/16
                throw new Error('Support for url field in sections not implemented.');
            }
            var offset = util.getArg(s, 'offset');
            var offsetLine = util.getArg(offset, 'line');
            var offsetColumn = util.getArg(offset, 'column');
            if (offsetLine < lastOffset.line ||
                (offsetLine === lastOffset.line && offsetColumn < lastOffset.column)) {
                throw new Error('Section offsets must be ordered and non-overlapping.');
            }
            lastOffset = offset;
            return {
                generatedOffset: {
                    // The offset fields are 0-based, but we use 1-based indices when
                    // encoding/decoding from VLQ.
                    generatedLine: offsetLine + 1,
                    generatedColumn: offsetColumn + 1
                },
                consumer: new SourceMapConsumer(util.getArg(s, 'map'), aSourceMapURL)
            };
        });
    }
    IndexedSourceMapConsumer.prototype = Object.create(SourceMapConsumer.prototype);
    IndexedSourceMapConsumer.prototype.constructor = SourceMapConsumer;
    /**
     * The version of the source mapping spec that we are consuming.
     */
    IndexedSourceMapConsumer.prototype._version = 3;
    /**
     * The list of original sources.
     */
    Object.defineProperty(IndexedSourceMapConsumer.prototype, 'sources', {
        get: function () {
            var sources = [];
            for (var i = 0; i < this._sections.length; i++) {
                for (var j = 0; j < this._sections[i].consumer.sources.length; j++) {
                    sources.push(this._sections[i].consumer.sources[j]);
                }
            }
            return sources;
        }
    });
    /**
     * Returns the original source, line, and column information for the generated
     * source's line and column positions provided. The only argument is an object
     * with the following properties:
     *
     *   - line: The line number in the generated source.  The line number
     *     is 1-based.
     *   - column: The column number in the generated source.  The column
     *     number is 0-based.
     *
     * and an object is returned with the following properties:
     *
     *   - source: The original source file, or null.
     *   - line: The line number in the original source, or null.  The
     *     line number is 1-based.
     *   - column: The column number in the original source, or null.  The
     *     column number is 0-based.
     *   - name: The original identifier, or null.
     */
    IndexedSourceMapConsumer.prototype.originalPositionFor =
        function IndexedSourceMapConsumer_originalPositionFor(aArgs) {
            var needle = {
                generatedLine: util.getArg(aArgs, 'line'),
                generatedColumn: util.getArg(aArgs, 'column')
            };
            // Find the section containing the generated position we're trying to map
            // to an original position.
            var sectionIndex = binarySearch.search(needle, this._sections, function (needle, section) {
                var cmp = needle.generatedLine - section.generatedOffset.generatedLine;
                if (cmp) {
                    return cmp;
                }
                return (needle.generatedColumn -
                    section.generatedOffset.generatedColumn);
            });
            var section = this._sections[sectionIndex];
            if (!section) {
                return {
                    source: null,
                    line: null,
                    column: null,
                    name: null
                };
            }
            return section.consumer.originalPositionFor({
                line: needle.generatedLine -
                    (section.generatedOffset.generatedLine - 1),
                column: needle.generatedColumn -
                    (section.generatedOffset.generatedLine === needle.generatedLine
                        ? section.generatedOffset.generatedColumn - 1
                        : 0),
                bias: aArgs.bias
            });
        };
    /**
     * Return true if we have the source content for every source in the source
     * map, false otherwise.
     */
    IndexedSourceMapConsumer.prototype.hasContentsOfAllSources =
        function IndexedSourceMapConsumer_hasContentsOfAllSources() {
            return this._sections.every(function (s) {
                return s.consumer.hasContentsOfAllSources();
            });
        };
    /**
     * Returns the original source content. The only argument is the url of the
     * original source file. Returns null if no original source content is
     * available.
     */
    IndexedSourceMapConsumer.prototype.sourceContentFor =
        function IndexedSourceMapConsumer_sourceContentFor(aSource, nullOnMissing) {
            for (var i = 0; i < this._sections.length; i++) {
                var section = this._sections[i];
                var content = section.consumer.sourceContentFor(aSource, true);
                if (content) {
                    return content;
                }
            }
            if (nullOnMissing) {
                return null;
            }
            else {
                throw new Error('"' + aSource + '" is not in the SourceMap.');
            }
        };
    /**
     * Returns the generated line and column information for the original source,
     * line, and column positions provided. The only argument is an object with
     * the following properties:
     *
     *   - source: The filename of the original source.
     *   - line: The line number in the original source.  The line number
     *     is 1-based.
     *   - column: The column number in the original source.  The column
     *     number is 0-based.
     *
     * and an object is returned with the following properties:
     *
     *   - line: The line number in the generated source, or null.  The
     *     line number is 1-based.
     *   - column: The column number in the generated source, or null.
     *     The column number is 0-based.
     */
    IndexedSourceMapConsumer.prototype.generatedPositionFor =
        function IndexedSourceMapConsumer_generatedPositionFor(aArgs) {
            for (var i = 0; i < this._sections.length; i++) {
                var section = this._sections[i];
                // Only consider this section if the requested source is in the list of
                // sources of the consumer.
                if (section.consumer._findSourceIndex(util.getArg(aArgs, 'source')) === -1) {
                    continue;
                }
                var generatedPosition = section.consumer.generatedPositionFor(aArgs);
                if (generatedPosition) {
                    var ret = {
                        line: generatedPosition.line +
                            (section.generatedOffset.generatedLine - 1),
                        column: generatedPosition.column +
                            (section.generatedOffset.generatedLine === generatedPosition.line
                                ? section.generatedOffset.generatedColumn - 1
                                : 0)
                    };
                    return ret;
                }
            }
            return {
                line: null,
                column: null
            };
        };
    /**
     * Parse the mappings in a string in to a data structure which we can easily
     * query (the ordered arrays in the `this.__generatedMappings` and
     * `this.__originalMappings` properties).
     */
    IndexedSourceMapConsumer.prototype._parseMappings =
        function IndexedSourceMapConsumer_parseMappings(aStr, aSourceRoot) {
            this.__generatedMappings = [];
            this.__originalMappings = [];
            for (var i = 0; i < this._sections.length; i++) {
                var section = this._sections[i];
                var sectionMappings = section.consumer._generatedMappings;
                for (var j = 0; j < sectionMappings.length; j++) {
                    var mapping = sectionMappings[j];
                    var source = section.consumer._sources.at(mapping.source);
                    source = util.computeSourceURL(section.consumer.sourceRoot, source, this._sourceMapURL);
                    this._sources.add(source);
                    source = this._sources.indexOf(source);
                    var name = null;
                    if (mapping.name) {
                        name = section.consumer._names.at(mapping.name);
                        this._names.add(name);
                        name = this._names.indexOf(name);
                    }
                    // The mappings coming from the consumer for the section have
                    // generated positions relative to the start of the section, so we
                    // need to offset them to be relative to the start of the concatenated
                    // generated file.
                    var adjustedMapping = {
                        source: source,
                        generatedLine: mapping.generatedLine +
                            (section.generatedOffset.generatedLine - 1),
                        generatedColumn: mapping.generatedColumn +
                            (section.generatedOffset.generatedLine === mapping.generatedLine
                                ? section.generatedOffset.generatedColumn - 1
                                : 0),
                        originalLine: mapping.originalLine,
                        originalColumn: mapping.originalColumn,
                        name: name
                    };
                    this.__generatedMappings.push(adjustedMapping);
                    if (typeof adjustedMapping.originalLine === 'number') {
                        this.__originalMappings.push(adjustedMapping);
                    }
                }
            }
            quickSort(this.__generatedMappings, util.compareByGeneratedPositionsDeflated);
            quickSort(this.__originalMappings, util.compareByOriginalPositions);
        };
    exports.IndexedSourceMapConsumer = IndexedSourceMapConsumer;
},
/* source-map/lib/binary-search.js */ function _(require, module, exports, __esModule, __esExport) {/* -*- Mode: js; js-indent-level: 2; -*- */
    /*
     * Copyright 2011 Mozilla Foundation and contributors
     * Licensed under the New BSD license. See LICENSE or:
     * http://opensource.org/licenses/BSD-3-Clause
     */
    exports.GREATEST_LOWER_BOUND = 1;
    exports.LEAST_UPPER_BOUND = 2;
    /**
     * Recursive implementation of binary search.
     *
     * @param aLow Indices here and lower do not contain the needle.
     * @param aHigh Indices here and higher do not contain the needle.
     * @param aNeedle The element being searched for.
     * @param aHaystack The non-empty array being searched.
     * @param aCompare Function which takes two elements and returns -1, 0, or 1.
     * @param aBias Either 'binarySearch.GREATEST_LOWER_BOUND' or
     *     'binarySearch.LEAST_UPPER_BOUND'. Specifies whether to return the
     *     closest element that is smaller than or greater than the one we are
     *     searching for, respectively, if the exact element cannot be found.
     */
    function recursiveSearch(aLow, aHigh, aNeedle, aHaystack, aCompare, aBias) {
        // This function terminates when one of the following is true:
        //
        //   1. We find the exact element we are looking for.
        //
        //   2. We did not find the exact element, but we can return the index of
        //      the next-closest element.
        //
        //   3. We did not find the exact element, and there is no next-closest
        //      element than the one we are searching for, so we return -1.
        var mid = Math.floor((aHigh - aLow) / 2) + aLow;
        var cmp = aCompare(aNeedle, aHaystack[mid], true);
        if (cmp === 0) {
            // Found the element we are looking for.
            return mid;
        }
        else if (cmp > 0) {
            // Our needle is greater than aHaystack[mid].
            if (aHigh - mid > 1) {
                // The element is in the upper half.
                return recursiveSearch(mid, aHigh, aNeedle, aHaystack, aCompare, aBias);
            }
            // The exact needle element was not found in this haystack. Determine if
            // we are in termination case (3) or (2) and return the appropriate thing.
            if (aBias == exports.LEAST_UPPER_BOUND) {
                return aHigh < aHaystack.length ? aHigh : -1;
            }
            else {
                return mid;
            }
        }
        else {
            // Our needle is less than aHaystack[mid].
            if (mid - aLow > 1) {
                // The element is in the lower half.
                return recursiveSearch(aLow, mid, aNeedle, aHaystack, aCompare, aBias);
            }
            // we are in termination case (3) or (2) and return the appropriate thing.
            if (aBias == exports.LEAST_UPPER_BOUND) {
                return mid;
            }
            else {
                return aLow < 0 ? -1 : aLow;
            }
        }
    }
    /**
     * This is an implementation of binary search which will always try and return
     * the index of the closest element if there is no exact hit. This is because
     * mappings between original and generated line/col pairs are single points,
     * and there is an implicit region between each of them, so a miss just means
     * that you aren't on the very start of a region.
     *
     * @param aNeedle The element you are looking for.
     * @param aHaystack The array that is being searched.
     * @param aCompare A function which takes the needle and an element in the
     *     array and returns -1, 0, or 1 depending on whether the needle is less
     *     than, equal to, or greater than the element, respectively.
     * @param aBias Either 'binarySearch.GREATEST_LOWER_BOUND' or
     *     'binarySearch.LEAST_UPPER_BOUND'. Specifies whether to return the
     *     closest element that is smaller than or greater than the one we are
     *     searching for, respectively, if the exact element cannot be found.
     *     Defaults to 'binarySearch.GREATEST_LOWER_BOUND'.
     */
    exports.search = function search(aNeedle, aHaystack, aCompare, aBias) {
        if (aHaystack.length === 0) {
            return -1;
        }
        var index = recursiveSearch(-1, aHaystack.length, aNeedle, aHaystack, aCompare, aBias || exports.GREATEST_LOWER_BOUND);
        if (index < 0) {
            return -1;
        }
        // We have found either the exact element, or the next-closest element than
        // the one we are searching for. However, there may be more than one such
        // element. Make sure we always return the smallest of these.
        while (index - 1 >= 0) {
            if (aCompare(aHaystack[index], aHaystack[index - 1], true) !== 0) {
                break;
            }
            --index;
        }
        return index;
    };
},
/* source-map/lib/quick-sort.js */ function _(require, module, exports, __esModule, __esExport) {/* -*- Mode: js; js-indent-level: 2; -*- */
    /*
     * Copyright 2011 Mozilla Foundation and contributors
     * Licensed under the New BSD license. See LICENSE or:
     * http://opensource.org/licenses/BSD-3-Clause
     */
    // It turns out that some (most?) JavaScript engines don't self-host
    // `Array.prototype.sort`. This makes sense because C++ will likely remain
    // faster than JS when doing raw CPU-intensive sorting. However, when using a
    // custom comparator function, calling back and forth between the VM's C++ and
    // JIT'd JS is rather slow *and* loses JIT type information, resulting in
    // worse generated code for the comparator function than would be optimal. In
    // fact, when sorting with a comparator, these costs outweigh the benefits of
    // sorting in C++. By using our own JS-implemented Quick Sort (below), we get
    // a ~3500ms mean speed-up in `bench/bench.html`.
    /**
     * Swap the elements indexed by `x` and `y` in the array `ary`.
     *
     * @param {Array} ary
     *        The array.
     * @param {Number} x
     *        The index of the first item.
     * @param {Number} y
     *        The index of the second item.
     */
    function swap(ary, x, y) {
        var temp = ary[x];
        ary[x] = ary[y];
        ary[y] = temp;
    }
    /**
     * Returns a random integer within the range `low .. high` inclusive.
     *
     * @param {Number} low
     *        The lower bound on the range.
     * @param {Number} high
     *        The upper bound on the range.
     */
    function randomIntInRange(low, high) {
        return Math.round(low + (Math.random() * (high - low)));
    }
    /**
     * The Quick Sort algorithm.
     *
     * @param {Array} ary
     *        An array to sort.
     * @param {function} comparator
     *        Function to use to compare two items.
     * @param {Number} p
     *        Start index of the array
     * @param {Number} r
     *        End index of the array
     */
    function doQuickSort(ary, comparator, p, r) {
        // If our lower bound is less than our upper bound, we (1) partition the
        // array into two pieces and (2) recurse on each half. If it is not, this is
        // the empty array and our base case.
        if (p < r) {
            // (1) Partitioning.
            //
            // The partitioning chooses a pivot between `p` and `r` and moves all
            // elements that are less than or equal to the pivot to the before it, and
            // all the elements that are greater than it after it. The effect is that
            // once partition is done, the pivot is in the exact place it will be when
            // the array is put in sorted order, and it will not need to be moved
            // again. This runs in O(n) time.
            // Always choose a random pivot so that an input array which is reverse
            // sorted does not cause O(n^2) running time.
            var pivotIndex = randomIntInRange(p, r);
            var i = p - 1;
            swap(ary, pivotIndex, r);
            var pivot = ary[r];
            // Immediately after `j` is incremented in this loop, the following hold
            // true:
            //
            //   * Every element in `ary[p .. i]` is less than or equal to the pivot.
            //
            //   * Every element in `ary[i+1 .. j-1]` is greater than the pivot.
            for (var j = p; j < r; j++) {
                if (comparator(ary[j], pivot) <= 0) {
                    i += 1;
                    swap(ary, i, j);
                }
            }
            swap(ary, i + 1, j);
            var q = i + 1;
            // (2) Recurse on each half.
            doQuickSort(ary, comparator, p, q - 1);
            doQuickSort(ary, comparator, q + 1, r);
        }
    }
    /**
     * Sort the given array in-place with the given comparator function.
     *
     * @param {Array} ary
     *        An array to sort.
     * @param {function} comparator
     *        Function to use to compare two items.
     */
    exports.quickSort = function (ary, comparator) {
        doQuickSort(ary, comparator, 0, ary.length - 1);
    };
},
/* source-map/lib/source-node.js */ function _(require, module, exports, __esModule, __esExport) {/* -*- Mode: js; js-indent-level: 2; -*- */
    /*
     * Copyright 2011 Mozilla Foundation and contributors
     * Licensed under the New BSD license. See LICENSE or:
     * http://opensource.org/licenses/BSD-3-Clause
     */
    var SourceMapGenerator = require(24) /* ./source-map-generator */.SourceMapGenerator;
    var util = require(27) /* ./util */;
    // Matches a Windows-style `\r\n` newline or a `\n` newline used by all other
    // operating systems these days (capturing the result).
    var REGEX_NEWLINE = /(\r?\n)/;
    // Newline character code for charCodeAt() comparisons
    var NEWLINE_CODE = 10;
    // Private symbol for identifying `SourceNode`s when multiple versions of
    // the source-map library are loaded. This MUST NOT CHANGE across
    // versions!
    var isSourceNode = "$$$isSourceNode$$$";
    /**
     * SourceNodes provide a way to abstract over interpolating/concatenating
     * snippets of generated JavaScript source code while maintaining the line and
     * column information associated with the original source code.
     *
     * @param aLine The original line number.
     * @param aColumn The original column number.
     * @param aSource The original source's filename.
     * @param aChunks Optional. An array of strings which are snippets of
     *        generated JS, or other SourceNodes.
     * @param aName The original identifier.
     */
    function SourceNode(aLine, aColumn, aSource, aChunks, aName) {
        this.children = [];
        this.sourceContents = {};
        this.line = aLine == null ? null : aLine;
        this.column = aColumn == null ? null : aColumn;
        this.source = aSource == null ? null : aSource;
        this.name = aName == null ? null : aName;
        this[isSourceNode] = true;
        if (aChunks != null)
            this.add(aChunks);
    }
    /**
     * Creates a SourceNode from generated code and a SourceMapConsumer.
     *
     * @param aGeneratedCode The generated code
     * @param aSourceMapConsumer The SourceMap for the generated code
     * @param aRelativePath Optional. The path that relative sources in the
     *        SourceMapConsumer should be relative to.
     */
    SourceNode.fromStringWithSourceMap =
        function SourceNode_fromStringWithSourceMap(aGeneratedCode, aSourceMapConsumer, aRelativePath) {
            // The SourceNode we want to fill with the generated code
            // and the SourceMap
            var node = new SourceNode();
            // All even indices of this array are one line of the generated code,
            // while all odd indices are the newlines between two adjacent lines
            // (since `REGEX_NEWLINE` captures its match).
            // Processed fragments are accessed by calling `shiftNextLine`.
            var remainingLines = aGeneratedCode.split(REGEX_NEWLINE);
            var remainingLinesIndex = 0;
            var shiftNextLine = function () {
                var lineContents = getNextLine();
                // The last line of a file might not have a newline.
                var newLine = getNextLine() || "";
                return lineContents + newLine;
                function getNextLine() {
                    return remainingLinesIndex < remainingLines.length ?
                        remainingLines[remainingLinesIndex++] : undefined;
                }
            };
            // We need to remember the position of "remainingLines"
            var lastGeneratedLine = 1, lastGeneratedColumn = 0;
            // The generate SourceNodes we need a code range.
            // To extract it current and last mapping is used.
            // Here we store the last mapping.
            var lastMapping = null;
            aSourceMapConsumer.eachMapping(function (mapping) {
                if (lastMapping !== null) {
                    // We add the code from "lastMapping" to "mapping":
                    // First check if there is a new line in between.
                    if (lastGeneratedLine < mapping.generatedLine) {
                        // Associate first line with "lastMapping"
                        addMappingWithCode(lastMapping, shiftNextLine());
                        lastGeneratedLine++;
                        lastGeneratedColumn = 0;
                        // The remaining code is added without mapping
                    }
                    else {
                        // There is no new line in between.
                        // Associate the code between "lastGeneratedColumn" and
                        // "mapping.generatedColumn" with "lastMapping"
                        var nextLine = remainingLines[remainingLinesIndex] || '';
                        var code = nextLine.substr(0, mapping.generatedColumn -
                            lastGeneratedColumn);
                        remainingLines[remainingLinesIndex] = nextLine.substr(mapping.generatedColumn -
                            lastGeneratedColumn);
                        lastGeneratedColumn = mapping.generatedColumn;
                        addMappingWithCode(lastMapping, code);
                        // No more remaining code, continue
                        lastMapping = mapping;
                        return;
                    }
                }
                // We add the generated code until the first mapping
                // to the SourceNode without any mapping.
                // Each line is added as separate string.
                while (lastGeneratedLine < mapping.generatedLine) {
                    node.add(shiftNextLine());
                    lastGeneratedLine++;
                }
                if (lastGeneratedColumn < mapping.generatedColumn) {
                    var nextLine = remainingLines[remainingLinesIndex] || '';
                    node.add(nextLine.substr(0, mapping.generatedColumn));
                    remainingLines[remainingLinesIndex] = nextLine.substr(mapping.generatedColumn);
                    lastGeneratedColumn = mapping.generatedColumn;
                }
                lastMapping = mapping;
            }, this);
            // We have processed all mappings.
            if (remainingLinesIndex < remainingLines.length) {
                if (lastMapping) {
                    // Associate the remaining code in the current line with "lastMapping"
                    addMappingWithCode(lastMapping, shiftNextLine());
                }
                // and add the remaining lines without any mapping
                node.add(remainingLines.splice(remainingLinesIndex).join(""));
            }
            // Copy sourcesContent into SourceNode
            aSourceMapConsumer.sources.forEach(function (sourceFile) {
                var content = aSourceMapConsumer.sourceContentFor(sourceFile);
                if (content != null) {
                    if (aRelativePath != null) {
                        sourceFile = util.join(aRelativePath, sourceFile);
                    }
                    node.setSourceContent(sourceFile, content);
                }
            });
            return node;
            function addMappingWithCode(mapping, code) {
                if (mapping === null || mapping.source === undefined) {
                    node.add(code);
                }
                else {
                    var source = aRelativePath
                        ? util.join(aRelativePath, mapping.source)
                        : mapping.source;
                    node.add(new SourceNode(mapping.originalLine, mapping.originalColumn, source, code, mapping.name));
                }
            }
        };
    /**
     * Add a chunk of generated JS to this source node.
     *
     * @param aChunk A string snippet of generated JS code, another instance of
     *        SourceNode, or an array where each member is one of those things.
     */
    SourceNode.prototype.add = function SourceNode_add(aChunk) {
        if (Array.isArray(aChunk)) {
            aChunk.forEach(function (chunk) {
                this.add(chunk);
            }, this);
        }
        else if (aChunk[isSourceNode] || typeof aChunk === "string") {
            if (aChunk) {
                this.children.push(aChunk);
            }
        }
        else {
            throw new TypeError("Expected a SourceNode, string, or an array of SourceNodes and strings. Got " + aChunk);
        }
        return this;
    };
    /**
     * Add a chunk of generated JS to the beginning of this source node.
     *
     * @param aChunk A string snippet of generated JS code, another instance of
     *        SourceNode, or an array where each member is one of those things.
     */
    SourceNode.prototype.prepend = function SourceNode_prepend(aChunk) {
        if (Array.isArray(aChunk)) {
            for (var i = aChunk.length - 1; i >= 0; i--) {
                this.prepend(aChunk[i]);
            }
        }
        else if (aChunk[isSourceNode] || typeof aChunk === "string") {
            this.children.unshift(aChunk);
        }
        else {
            throw new TypeError("Expected a SourceNode, string, or an array of SourceNodes and strings. Got " + aChunk);
        }
        return this;
    };
    /**
     * Walk over the tree of JS snippets in this node and its children. The
     * walking function is called once for each snippet of JS and is passed that
     * snippet and the its original associated source's line/column location.
     *
     * @param aFn The traversal function.
     */
    SourceNode.prototype.walk = function SourceNode_walk(aFn) {
        var chunk;
        for (var i = 0, len = this.children.length; i < len; i++) {
            chunk = this.children[i];
            if (chunk[isSourceNode]) {
                chunk.walk(aFn);
            }
            else {
                if (chunk !== '') {
                    aFn(chunk, { source: this.source,
                        line: this.line,
                        column: this.column,
                        name: this.name });
                }
            }
        }
    };
    /**
     * Like `String.prototype.join` except for SourceNodes. Inserts `aStr` between
     * each of `this.children`.
     *
     * @param aSep The separator.
     */
    SourceNode.prototype.join = function SourceNode_join(aSep) {
        var newChildren;
        var i;
        var len = this.children.length;
        if (len > 0) {
            newChildren = [];
            for (i = 0; i < len - 1; i++) {
                newChildren.push(this.children[i]);
                newChildren.push(aSep);
            }
            newChildren.push(this.children[i]);
            this.children = newChildren;
        }
        return this;
    };
    /**
     * Call String.prototype.replace on the very right-most source snippet. Useful
     * for trimming whitespace from the end of a source node, etc.
     *
     * @param aPattern The pattern to replace.
     * @param aReplacement The thing to replace the pattern with.
     */
    SourceNode.prototype.replaceRight = function SourceNode_replaceRight(aPattern, aReplacement) {
        var lastChild = this.children[this.children.length - 1];
        if (lastChild[isSourceNode]) {
            lastChild.replaceRight(aPattern, aReplacement);
        }
        else if (typeof lastChild === 'string') {
            this.children[this.children.length - 1] = lastChild.replace(aPattern, aReplacement);
        }
        else {
            this.children.push(''.replace(aPattern, aReplacement));
        }
        return this;
    };
    /**
     * Set the source content for a source file. This will be added to the SourceMapGenerator
     * in the sourcesContent field.
     *
     * @param aSourceFile The filename of the source file
     * @param aSourceContent The content of the source file
     */
    SourceNode.prototype.setSourceContent =
        function SourceNode_setSourceContent(aSourceFile, aSourceContent) {
            this.sourceContents[util.toSetString(aSourceFile)] = aSourceContent;
        };
    /**
     * Walk over the tree of SourceNodes. The walking function is called for each
     * source file content and is passed the filename and source content.
     *
     * @param aFn The traversal function.
     */
    SourceNode.prototype.walkSourceContents =
        function SourceNode_walkSourceContents(aFn) {
            for (var i = 0, len = this.children.length; i < len; i++) {
                if (this.children[i][isSourceNode]) {
                    this.children[i].walkSourceContents(aFn);
                }
            }
            var sources = Object.keys(this.sourceContents);
            for (var i = 0, len = sources.length; i < len; i++) {
                aFn(util.fromSetString(sources[i]), this.sourceContents[sources[i]]);
            }
        };
    /**
     * Return the string representation of this source node. Walks over the tree
     * and concatenates all the various snippets together to one string.
     */
    SourceNode.prototype.toString = function SourceNode_toString() {
        var str = "";
        this.walk(function (chunk) {
            str += chunk;
        });
        return str;
    };
    /**
     * Returns the string representation of this source node along with a source
     * map.
     */
    SourceNode.prototype.toStringWithSourceMap = function SourceNode_toStringWithSourceMap(aArgs) {
        var generated = {
            code: "",
            line: 1,
            column: 0
        };
        var map = new SourceMapGenerator(aArgs);
        var sourceMappingActive = false;
        var lastOriginalSource = null;
        var lastOriginalLine = null;
        var lastOriginalColumn = null;
        var lastOriginalName = null;
        this.walk(function (chunk, original) {
            generated.code += chunk;
            if (original.source !== null
                && original.line !== null
                && original.column !== null) {
                if (lastOriginalSource !== original.source
                    || lastOriginalLine !== original.line
                    || lastOriginalColumn !== original.column
                    || lastOriginalName !== original.name) {
                    map.addMapping({
                        source: original.source,
                        original: {
                            line: original.line,
                            column: original.column
                        },
                        generated: {
                            line: generated.line,
                            column: generated.column
                        },
                        name: original.name
                    });
                }
                lastOriginalSource = original.source;
                lastOriginalLine = original.line;
                lastOriginalColumn = original.column;
                lastOriginalName = original.name;
                sourceMappingActive = true;
            }
            else if (sourceMappingActive) {
                map.addMapping({
                    generated: {
                        line: generated.line,
                        column: generated.column
                    }
                });
                lastOriginalSource = null;
                sourceMappingActive = false;
            }
            for (var idx = 0, length = chunk.length; idx < length; idx++) {
                if (chunk.charCodeAt(idx) === NEWLINE_CODE) {
                    generated.line++;
                    generated.column = 0;
                    // Mappings end at eol
                    if (idx + 1 === length) {
                        lastOriginalSource = null;
                        sourceMappingActive = false;
                    }
                    else if (sourceMappingActive) {
                        map.addMapping({
                            source: original.source,
                            original: {
                                line: original.line,
                                column: original.column
                            },
                            generated: {
                                line: generated.line,
                                column: generated.column
                            },
                            name: original.name
                        });
                    }
                }
                else {
                    generated.column++;
                }
            }
        });
        this.walkSourceContents(function (sourceFile, sourceContent) {
            map.setSourceContent(sourceFile, sourceContent);
        });
        return { code: generated.code, map: map };
    };
    exports.SourceNode = SourceNode;
},
/* buffer-from/index.js */ function _(require, module, exports, __esModule, __esExport) {/* eslint-disable node/no-deprecated-api */
    var toString = Object.prototype.toString;
    var isModern = (typeof Buffer !== 'undefined' &&
        typeof Buffer.alloc === 'function' &&
        typeof Buffer.allocUnsafe === 'function' &&
        typeof Buffer.from === 'function');
    function isArrayBuffer(input) {
        return toString.call(input).slice(8, -1) === 'ArrayBuffer';
    }
    function fromArrayBuffer(obj, byteOffset, length) {
        byteOffset >>>= 0;
        var maxLength = obj.byteLength - byteOffset;
        if (maxLength < 0) {
            throw new RangeError("'offset' is out of bounds");
        }
        if (length === undefined) {
            length = maxLength;
        }
        else {
            length >>>= 0;
            if (length > maxLength) {
                throw new RangeError("'length' is out of bounds");
            }
        }
        return isModern
            ? Buffer.from(obj.slice(byteOffset, byteOffset + length))
            : new Buffer(new Uint8Array(obj.slice(byteOffset, byteOffset + length)));
    }
    function fromString(string, encoding) {
        if (typeof encoding !== 'string' || encoding === '') {
            encoding = 'utf8';
        }
        if (!Buffer.isEncoding(encoding)) {
            throw new TypeError('"encoding" must be a valid string encoding');
        }
        return isModern
            ? Buffer.from(string, encoding)
            : new Buffer(string, encoding);
    }
    function bufferFrom(value, encodingOrOffset, length) {
        if (typeof value === 'number') {
            throw new TypeError('"value" argument must not be a number');
        }
        if (isArrayBuffer(value)) {
            return fromArrayBuffer(value, encodingOrOffset, length);
        }
        if (typeof value === 'string') {
            return fromString(value, encodingOrOffset);
        }
        return isModern
            ? Buffer.from(value)
            : new Buffer(value);
    }
    module.exports = bufferFrom;
},
/* build.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.build = exports.init = exports.isPlainObject = exports.isObject = exports.isString = void 0;
    const cp = __importStar(require("child_process"));
    const path_1 = require("path");
    const sys_1 = require(20) /* ./sys */;
    const compiler_1 = require(36) /* ./compiler */;
    const linker_1 = require(44) /* ./linker */;
    const styles_1 = require(60) /* ./styles */;
    const preludes = __importStar(require(218) /* ./prelude */);
    const tsconfig_json = __importStar(require(219) /* ./tsconfig.ext.json */);
    const chalk_1 = __importDefault(require(37) /* chalk */);
    const { cyan, magenta, red } = chalk_1.default;
    const readline = __importStar(require("readline"));
    const toString = Object.prototype.toString;
    function isString(obj) {
        return toString.call(obj) === "[object String]";
    }
    exports.isString = isString;
    function isObject(obj) {
        const tp = typeof obj;
        return tp === "function" || tp === "object" && !!obj;
    }
    exports.isObject = isObject;
    function isPlainObject(obj) {
        return isObject(obj) && (typeof obj.constructor == "undefined" || obj.constructor === Object);
    }
    exports.isPlainObject = isPlainObject;
    function print(str) {
        console.log(str);
    }
    function print_files(files) {
        for (const file of files) {
            print(`  ${file}`);
        }
    }
    function count_files(files) {
        const n = files.length;
        const str = `${n} file`;
        return n == 1 ? str : `${str}s`;
    }
    const node_version = process.version;
    function npm_version(base_dir) {
        return cp.execSync("npm --version", { cwd: base_dir }).toString().trim();
    }
    function npm_install(base_dir) {
        const is_windows = process.platform == "win32";
        const npm = is_windows ? "npm.cmd" : "npm";
        const { status } = cp.spawnSync(npm, ["install"], { stdio: "inherit", cwd: base_dir, shell: is_windows });
        if (status != null && status != 0) {
            print(`${cyan("npm install")} failed with exit code ${red(`${status}`)}.`);
            process.exit(status);
        }
    }
    function preamble(base_dir) {
        print(`Using nodejs ${magenta(node_version)} and npm ${magenta(npm_version(base_dir))}`);
        print(`Working directory: ${cyan(base_dir)}`);
    }
    function is_up_to_date(base_dir, file, metadata) {
        const contents = (0, sys_1.read)((0, path_1.join)(base_dir, file));
        if (contents == null) {
            return false;
        }
        const old_hash = metadata.signatures[file];
        if (old_hash == null) {
            return false;
        }
        const new_hash = (0, sys_1.hash)(contents);
        return old_hash == new_hash;
    }
    function needs_install(base_dir, metadata) {
        if (!(0, sys_1.directory_exists)((0, path_1.join)(base_dir, "node_modules"))) {
            return "New development environment.";
        }
        else if (!is_up_to_date(base_dir, "package.json", metadata)) {
            return "package.json has changed.";
        }
        else if (!is_up_to_date(base_dir, "package-lock.json", metadata)) {
            return "package-lock.json has changed.";
        }
        else {
            return null;
        }
    }
    async function init(base_dir, _bokehjs_dir, base_setup) {
        preamble(base_dir);
        const setup = {
            interactive: base_setup.interactive ?? false,
            bokehjs_version: base_setup.bokehjs_version ?? base_setup.bokeh_version.split("-")[0],
            bokeh_version: base_setup.bokeh_version,
        };
        const paths = {
            bokeh_ext: (0, path_1.join)(base_dir, "bokeh.ext.json"),
            package: (0, path_1.join)(base_dir, "package.json"),
            package_lock: (0, path_1.join)(base_dir, "package-lock.json"),
            tsconfig: (0, path_1.join)(base_dir, "tsconfig.json"),
            index: (0, path_1.join)(base_dir, "index.ts"),
        };
        const is_extension = (0, sys_1.file_exists)(paths.bokeh_ext);
        if (is_extension) {
            print("Already a bokeh extension. Quitting.");
            return false;
        }
        function write_json(path, json) {
            (0, sys_1.write)(path, JSON.stringify(json, undefined, 2));
            print(`Wrote ${cyan(path)}`);
        }
        const bokeh_ext_json = {};
        write_json(paths.bokeh_ext, bokeh_ext_json);
        const package_json = {
            name: (0, path_1.basename)(base_dir),
            version: "0.0.1",
            description: "",
            license: "BSD-3-Clause",
            keywords: [],
            repository: {},
            dependencies: {
                "@bokeh/bokehjs": `^${setup.bokehjs_version}`,
            },
            devDependencies: {},
        };
        if (setup.interactive) {
            const rl = readline.createInterface({ input: process.stdin, output: process.stdout });
            async function ask(question, default_value) {
                return new Promise((resolve, _reject) => {
                    rl.question(`${question} `, (answer) => {
                        resolve(answer.length != 0 ? answer : default_value);
                    });
                });
            }
            async function ask_yn(question) {
                const ret = await ask(`${question} [y/n]`, "y");
                switch (ret) {
                    case "y":
                        return true;
                    case "n":
                        return false;
                    default: {
                        print(`${red("Invalid input")}. Assuming no.`);
                        return false;
                    }
                }
            }
            if (await ask_yn(`Create ${cyan("package.json")}? This will allow you to specify external dependencies.`)) {
                const { name } = package_json;
                package_json.name = await ask(`  What's the extension's name? [${name}]`, name);
                const { version } = package_json;
                package_json.version = await ask(`  What's the extension's version? [${version}]`, version);
                const { description } = package_json;
                package_json.description = await ask(`  What's the extension's description? [${description}]`, description);
                write_json(paths.package, package_json);
            }
            if (await ask_yn(`Create ${cyan("tsconfig.json")}? This will allow for customized configuration and improved IDE experience.`)) {
                write_json(paths.tsconfig, tsconfig_json);
            }
            rl.close();
        }
        else {
            write_json(paths.package, package_json);
            write_json(paths.tsconfig, tsconfig_json);
        }
        (0, sys_1.write)(paths.index, "export {}");
        print(`Created empty ${cyan("index.ts")}. This is the entry point of your extension.`);
        const rel = (0, path_1.relative)(process.cwd(), base_dir);
        print(`You can build your extension with ${magenta(`bokeh build ${rel}`)}`);
        print("All done.");
        return true;
    }
    exports.init = init;
    async function build(base_dir, bokehjs_dir, base_setup) {
        preamble(base_dir);
        const setup = {
            verbose: base_setup.verbose ?? false,
            rebuild: base_setup.rebuild ?? false,
            bokeh_version: base_setup.bokeh_version,
        };
        const bokeh_ext_json_path = (0, path_1.join)(base_dir, "bokeh.ext.json");
        const bokeh_ext = (0, sys_1.read_json)(bokeh_ext_json_path);
        if (!isPlainObject(bokeh_ext)) {
            print("Not a bokeh extension. Quitting.");
            return false;
        }
        const metadata_path = (0, path_1.join)(base_dir, ".bokeh");
        const metadata = (() => {
            let obj = (0, sys_1.read_json)(metadata_path);
            if (obj == null) {
                obj = {};
            }
            if (obj.signatures == null) {
                obj.signatures = {};
            }
            return obj;
        })();
        if (metadata.bokeh_version != setup.bokeh_version) {
            print("Using different version of bokeh, rebuilding from scratch.");
            setup.rebuild = true;
        }
        const package_json_path = (0, path_1.join)(base_dir, "package.json");
        const package_lock_json_path = (0, path_1.join)(base_dir, "package-lock.json");
        const is_package = (0, sys_1.file_exists)(package_json_path);
        if (!is_package) {
            print(`${cyan(package_json_path)} doesn't exist. Not a npm package.`);
        }
        else {
            if (setup.rebuild) {
                print(`Running ${cyan("npm install")}.`);
                npm_install(base_dir);
            }
            else {
                const result = needs_install(base_dir, metadata);
                if (result != null) {
                    print(`${result} Running ${cyan("npm install")}.`);
                    npm_install(base_dir);
                }
            }
        }
        const package_json = (is_package ? (0, sys_1.read_json)(package_json_path) : {});
        const is_static_dir = (0, path_1.basename)(bokehjs_dir) == "static";
        const tslib_dir = (() => {
            if (package_json.devDependencies?.typescript != null) {
                return (0, path_1.join)(base_dir, "node_modules", "typescript", "lib");
            }
            else {
                // bokeh/server/static or bokehjs/build
                if (is_static_dir) {
                    return (0, path_1.join)(bokehjs_dir, "lib");
                }
                else {
                    return (0, path_1.join)((0, path_1.dirname)(bokehjs_dir), "node_modules", "typescript", "lib");
                }
            }
        })();
        print(`TypeScript lib: ${cyan(tslib_dir)}`);
        const tsconfig_path = (0, path_1.join)(base_dir, "tsconfig.json");
        if ((0, sys_1.file_exists)(tsconfig_path)) {
            print(`Using ${cyan(tsconfig_path)}`);
        }
        const preconfigure = {
            baseUrl: base_dir,
            paths: {
                "@bokehjs/*": [
                    (0, path_1.join)(bokehjs_dir, "js/lib/*"),
                ],
            },
        };
        function load_tsconfig() {
            if ((0, sys_1.file_exists)(tsconfig_path)) {
                return (0, compiler_1.read_tsconfig)(tsconfig_path, is_package ? undefined : preconfigure);
            }
            else {
                return (0, compiler_1.parse_tsconfig)(tsconfig_json, base_dir, preconfigure);
            }
        }
        const tsconfig = load_tsconfig();
        if ((0, compiler_1.is_failed)(tsconfig)) {
            print((0, compiler_1.report_diagnostics)(tsconfig.diagnostics).text);
            return false;
        }
        let success = true;
        const { options } = tsconfig;
        const dist_dir = (0, path_1.join)(base_dir, "dist");
        const lib_dir = options.outDir ?? (0, path_1.join)(dist_dir, "lib");
        const dts_dir = options.declarationDir ?? lib_dir;
        const dts_internal_dir = (0, path_1.join)(dist_dir, "dts");
        const styles_dir = (0, path_1.join)(base_dir, "styles");
        const css_dir = (0, path_1.join)(dist_dir, "css");
        const styles = (0, styles_1.collect_styles)(styles_dir);
        print(`Compiling styles (${magenta(count_files(styles))})`);
        if (setup.verbose) {
            print_files(styles);
        }
        if (!await (0, styles_1.compile_styles)(styles, styles_dir, css_dir)) {
            success = false;
        }
        (0, styles_1.wrap_css_modules)(css_dir, lib_dir, dts_dir, dts_internal_dir);
        // load tsconfig.json again to include generated source files
        const tsconfig2 = load_tsconfig();
        if ((0, compiler_1.is_failed)(tsconfig2)) {
            print((0, compiler_1.report_diagnostics)(tsconfig2.diagnostics).text);
            return false;
        }
        const { files } = tsconfig2;
        const transformers = (0, compiler_1.default_transformers)(options);
        const host = (0, compiler_1.compiler_host)(new Map(), options, tslib_dir);
        print(`Compiling TypeScript (${magenta(count_files(files))})`);
        if (setup.verbose) {
            print_files(files);
        }
        const tsoutput = (0, compiler_1.compile_files)(files, options, transformers, host);
        if ((0, compiler_1.is_failed)(tsoutput)) {
            print((0, compiler_1.report_diagnostics)(tsoutput.diagnostics).text);
            if (options.noEmitOnError ?? false) {
                return false;
            }
        }
        const artifact = (0, path_1.basename)(base_dir);
        const bases = [lib_dir];
        if (is_package) {
            bases.push((0, path_1.join)(base_dir, "node_modules"));
        }
        const linker = new linker_1.Linker({
            entries: [(0, path_1.join)(lib_dir, "index.js")],
            bases,
            cache: (0, path_1.join)(dist_dir, `${artifact}.json`),
            excluded: (dep) => dep == "tslib" || dep.startsWith("@bokehjs/"),
            plugin: true,
            target: "ES2020",
        });
        print("Linking modules");
        if (!setup.rebuild) {
            linker.load_cache();
        }
        const { bundles, status } = await linker.link();
        if (!status) {
            success = false;
        }
        linker.store_cache();
        const outputs = [(0, path_1.join)(dist_dir, `${artifact}.js`)];
        const min_js = (js) => (0, sys_1.rename)(js, { ext: ".min.js" });
        const license = (() => {
            if (isPlainObject(bokeh_ext.license)) {
                if (isString(bokeh_ext.license.file)) {
                    const license_path = (0, path_1.join)(base_dir, bokeh_ext.license.file);
                    const text = (0, sys_1.read)(license_path);
                    if (text != null) {
                        return text;
                    }
                    else {
                        print(`Failed to license text from ${magenta(license_path)}`);
                    }
                }
                if (isString(bokeh_ext.license.text)) {
                    return bokeh_ext.license.text;
                }
            }
            return null;
        })();
        const license_text = license != null ? `${preludes.comment(license)}\n` : "";
        const prelude_base = `${license_text}${preludes.plugin_prelude()}`;
        const prelude = { main: prelude_base, plugin: prelude_base };
        const postlude_base = preludes.plugin_postlude();
        const postlude = { main: postlude_base, plugin: postlude_base };
        // HACK {{{
        for (const bundle of bundles) {
            bundle.bases.push({});
        }
        // }}}
        function bundle(minified, outputs) {
            bundles
                .map((bundle) => bundle.assemble({ prelude, postlude, minified }))
                .map((artifact, i) => artifact.write(outputs[i]));
        }
        bundle(false, outputs);
        bundle(true, outputs.map(min_js));
        (0, sys_1.write)(metadata_path, JSON.stringify({
            bokeh_version: setup.bokeh_version,
            signatures: {
                "package.json": (0, sys_1.hash_file)(package_json_path),
                "package-lock.json": (0, sys_1.hash_file)(package_lock_json_path),
                "tsconfig.json": (0, sys_1.hash_file)(tsconfig_path),
            },
        }));
        print(`Output written to ${cyan(dist_dir)}`);
        print("All done.");
        return !(0, compiler_1.is_failed)(tsoutput) && success;
    }
    exports.build = build;
    
},
/* compiler.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.compile_typescript = exports.read_tsconfig = exports.parse_tsconfig = exports.compile_files = exports.default_transformers = exports.compiler_host = exports.report_diagnostics = exports.is_failed = void 0;
    const chalk_1 = __importDefault(require(37) /* chalk */);
    const typescript_1 = __importDefault(require(21) /* typescript */);
    const path_1 = require("path");
    const transforms = __importStar(require(42) /* ./transforms */);
    const error_1 = require(43) /* ./error */;
    function is_failed(obj) {
        return typeof obj == "object" && obj != null && "diagnostics" in obj && obj.diagnostics != null;
    }
    exports.is_failed = is_failed;
    function normalize(path) {
        return path.replace(/\\/g, "/");
    }
    const diagnostics_host = {
        getCanonicalFileName: (path) => path,
        getCurrentDirectory: typescript_1.default.sys.getCurrentDirectory,
        getNewLine: () => typescript_1.default.sys.newLine,
    };
    function report_diagnostics(diagnostics) {
        const errors = typescript_1.default.sortAndDeduplicateDiagnostics(diagnostics);
        const text = typescript_1.default.formatDiagnosticsWithColorAndContext(errors, diagnostics_host);
        return { count: errors.length, text };
    }
    exports.report_diagnostics = report_diagnostics;
    function compiler_host(inputs, options, tslib_dir) {
        const default_host = typescript_1.default.createIncrementalCompilerHost(options);
        const host = {
            ...default_host,
            fileExists(name) {
                return inputs.get(name) != null || default_host.fileExists(name);
            },
            readFile(name) {
                return inputs.get(name) != null ? inputs.get(name) : default_host.readFile(name);
            },
            getSourceFile(name, target, _onError) {
                const source = inputs.get(name);
                if (source != null) {
                    const sf = typescript_1.default.createSourceFile(name, source, target);
                    const version = default_host.createHash(source);
                    return { ...sf, version }; // version is internal to the compiler
                }
                else {
                    return default_host.getSourceFile(name, target, _onError);
                }
            },
        };
        if (tslib_dir != null) {
            host.getDefaultLibLocation = () => tslib_dir;
        }
        return host;
    }
    exports.compiler_host = compiler_host;
    function default_transformers(options) {
        const transformers = {
            before: [],
            after: [],
            afterDeclarations: [],
        };
        const insert_class_name = transforms.insert_class_name();
        transformers.before.push(insert_class_name);
        const base = options.baseUrl;
        if (base != null) {
            const relativize_modules = transforms.relativize_modules((file, module_path) => {
                if (!module_path.startsWith(".") && !module_path.startsWith("/")) {
                    const module_file = (0, path_1.join)(base, module_path);
                    if (typescript_1.default.sys.fileExists(module_file) ||
                        typescript_1.default.sys.fileExists(`${module_file}.ts`) ||
                        typescript_1.default.sys.fileExists((0, path_1.join)(module_file, "index.ts")) ||
                        options.outDir != null && typescript_1.default.sys.fileExists((0, path_1.join)(options.outDir, `${module_path}.js`))) {
                        const rel_path = normalize((0, path_1.relative)((0, path_1.dirname)(file), module_file));
                        return rel_path.startsWith(".") ? rel_path : `./${rel_path}`;
                    }
                }
                return null;
            });
            transformers.after.push(relativize_modules);
            transformers.afterDeclarations.push(relativize_modules);
        }
        return transformers;
    }
    exports.default_transformers = default_transformers;
    function compile_files(inputs, options, transformers, host) {
        const program = typescript_1.default.createIncrementalProgram({ rootNames: inputs, options, host });
        const emitted = program.emit(undefined, undefined, undefined, false, transformers);
        const diagnostics = [
            ...program.getConfigFileParsingDiagnostics(),
            ...program.getSyntacticDiagnostics(),
            ...program.getOptionsDiagnostics(),
            ...program.getGlobalDiagnostics(),
            ...program.getSemanticDiagnostics(),
            ...emitted.diagnostics,
        ];
        return diagnostics.length != 0 ? { diagnostics } : {};
    }
    exports.compile_files = compile_files;
    function parse_tsconfig(tsconfig_json, base_dir, preconfigure) {
        const host = {
            useCaseSensitiveFileNames: typescript_1.default.sys.useCaseSensitiveFileNames,
            readDirectory: typescript_1.default.sys.readDirectory,
            fileExists: typescript_1.default.sys.fileExists,
            readFile: typescript_1.default.sys.readFile,
        };
        const tsconfig = typescript_1.default.parseJsonConfigFileContent(tsconfig_json, host, base_dir, preconfigure);
        if (tsconfig.errors.length != 0) {
            return { diagnostics: tsconfig.errors };
        }
        return { files: tsconfig.fileNames, options: tsconfig.options };
    }
    exports.parse_tsconfig = parse_tsconfig;
    function read_tsconfig(tsconfig_path, preconfigure) {
        const tsconfig_file = typescript_1.default.readConfigFile(tsconfig_path, typescript_1.default.sys.readFile);
        if (tsconfig_file.error != null) {
            return { diagnostics: [tsconfig_file.error] };
        }
        return parse_tsconfig(tsconfig_file.config, (0, path_1.dirname)(tsconfig_path), preconfigure);
    }
    exports.read_tsconfig = read_tsconfig;
    function compile_project(tsconfig_path, config) {
        const tsconfig = read_tsconfig(tsconfig_path);
        if (is_failed(tsconfig)) {
            return { diagnostics: tsconfig.diagnostics };
        }
        const { files, options } = tsconfig;
        const transformers = default_transformers(tsconfig.options);
        const inputs = config.inputs?.(files) ?? new Map();
        const host = compiler_host(inputs, options, config.tslib_dir);
        const input_files = [...inputs.keys(), ...files];
        return compile_files(input_files, options, transformers, host);
    }
    function compile_typescript(tsconfig_path, config = {}) {
        const result = compile_project(tsconfig_path, config);
        if (is_failed(result)) {
            const { count, text } = report_diagnostics(result.diagnostics);
            throw new error_1.BuildError("typescript", `There were ${chalk_1.default.red(`${count}`)} TypeScript errors:\n${text}`);
        }
    }
    exports.compile_typescript = compile_typescript;
    
},
/* chalk/source/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const ansiStyles = require(12) /* ansi-styles */;
    const { stdout: stdoutColor, stderr: stderrColor } = require(38) /* supports-color */;
    const { stringReplaceAll, stringEncaseCRLFWithFirstIndex } = require(40) /* ./util */;
    const { isArray } = Array;
    // `supportsColor.level` → `ansiStyles.color[name]` mapping
    const levelMapping = [
        'ansi',
        'ansi',
        'ansi256',
        'ansi16m'
    ];
    const styles = Object.create(null);
    const applyOptions = (object, options = {}) => {
        if (options.level && !(Number.isInteger(options.level) && options.level >= 0 && options.level <= 3)) {
            throw new Error('The `level` option should be an integer from 0 to 3');
        }
        // Detect level if not set manually
        const colorLevel = stdoutColor ? stdoutColor.level : 0;
        object.level = options.level === undefined ? colorLevel : options.level;
    };
    class ChalkClass {
        constructor(options) {
            // eslint-disable-next-line no-constructor-return
            return chalkFactory(options);
        }
    }
    const chalkFactory = options => {
        const chalk = {};
        applyOptions(chalk, options);
        chalk.template = (...arguments_) => chalkTag(chalk.template, ...arguments_);
        Object.setPrototypeOf(chalk, Chalk.prototype);
        Object.setPrototypeOf(chalk.template, chalk);
        chalk.template.constructor = () => {
            throw new Error('`chalk.constructor()` is deprecated. Use `new chalk.Instance()` instead.');
        };
        chalk.template.Instance = ChalkClass;
        return chalk.template;
    };
    function Chalk(options) {
        return chalkFactory(options);
    }
    for (const [styleName, style] of Object.entries(ansiStyles)) {
        styles[styleName] = {
            get() {
                const builder = createBuilder(this, createStyler(style.open, style.close, this._styler), this._isEmpty);
                Object.defineProperty(this, styleName, { value: builder });
                return builder;
            }
        };
    }
    styles.visible = {
        get() {
            const builder = createBuilder(this, this._styler, true);
            Object.defineProperty(this, 'visible', { value: builder });
            return builder;
        }
    };
    const usedModels = ['rgb', 'hex', 'keyword', 'hsl', 'hsv', 'hwb', 'ansi', 'ansi256'];
    for (const model of usedModels) {
        styles[model] = {
            get() {
                const { level } = this;
                return function (...arguments_) {
                    const styler = createStyler(ansiStyles.color[levelMapping[level]][model](...arguments_), ansiStyles.color.close, this._styler);
                    return createBuilder(this, styler, this._isEmpty);
                };
            }
        };
    }
    for (const model of usedModels) {
        const bgModel = 'bg' + model[0].toUpperCase() + model.slice(1);
        styles[bgModel] = {
            get() {
                const { level } = this;
                return function (...arguments_) {
                    const styler = createStyler(ansiStyles.bgColor[levelMapping[level]][model](...arguments_), ansiStyles.bgColor.close, this._styler);
                    return createBuilder(this, styler, this._isEmpty);
                };
            }
        };
    }
    const proto = Object.defineProperties(() => { }, {
        ...styles,
        level: {
            enumerable: true,
            get() {
                return this._generator.level;
            },
            set(level) {
                this._generator.level = level;
            }
        }
    });
    const createStyler = (open, close, parent) => {
        let openAll;
        let closeAll;
        if (parent === undefined) {
            openAll = open;
            closeAll = close;
        }
        else {
            openAll = parent.openAll + open;
            closeAll = close + parent.closeAll;
        }
        return {
            open,
            close,
            openAll,
            closeAll,
            parent
        };
    };
    const createBuilder = (self, _styler, _isEmpty) => {
        const builder = (...arguments_) => {
            if (isArray(arguments_[0]) && isArray(arguments_[0].raw)) {
                // Called as a template literal, for example: chalk.red`2 + 3 = {bold ${2+3}}`
                return applyStyle(builder, chalkTag(builder, ...arguments_));
            }
            // Single argument is hot path, implicit coercion is faster than anything
            // eslint-disable-next-line no-implicit-coercion
            return applyStyle(builder, (arguments_.length === 1) ? ('' + arguments_[0]) : arguments_.join(' '));
        };
        // We alter the prototype because we must return a function, but there is
        // no way to create a function with a different prototype
        Object.setPrototypeOf(builder, proto);
        builder._generator = self;
        builder._styler = _styler;
        builder._isEmpty = _isEmpty;
        return builder;
    };
    const applyStyle = (self, string) => {
        if (self.level <= 0 || !string) {
            return self._isEmpty ? '' : string;
        }
        let styler = self._styler;
        if (styler === undefined) {
            return string;
        }
        const { openAll, closeAll } = styler;
        if (string.indexOf('\u001B') !== -1) {
            while (styler !== undefined) {
                // Replace any instances already present with a re-opening code
                // otherwise only the part of the string until said closing code
                // will be colored, and the rest will simply be 'plain'.
                string = stringReplaceAll(string, styler.close, styler.open);
                styler = styler.parent;
            }
        }
        // We can move both next actions out of loop, because remaining actions in loop won't have
        // any/visible effect on parts we add here. Close the styling before a linebreak and reopen
        // after next line to fix a bleed issue on macOS: https://github.com/chalk/chalk/pull/92
        const lfIndex = string.indexOf('\n');
        if (lfIndex !== -1) {
            string = stringEncaseCRLFWithFirstIndex(string, closeAll, openAll, lfIndex);
        }
        return openAll + string + closeAll;
    };
    let template;
    const chalkTag = (chalk, ...strings) => {
        const [firstString] = strings;
        if (!isArray(firstString) || !isArray(firstString.raw)) {
            // If chalk() was called by itself or with a string,
            // return the string itself as a string.
            return strings.join(' ');
        }
        const arguments_ = strings.slice(1);
        const parts = [firstString.raw[0]];
        for (let i = 1; i < firstString.length; i++) {
            parts.push(String(arguments_[i - 1]).replace(/[{}\\]/g, '\\$&'), String(firstString.raw[i]));
        }
        if (template === undefined) {
            template = require(41) /* ./templates */;
        }
        return template(chalk, parts.join(''));
    };
    Object.defineProperties(Chalk.prototype, styles);
    const chalk = Chalk(); // eslint-disable-line new-cap
    chalk.supportsColor = stdoutColor;
    chalk.stderr = Chalk({ level: stderrColor ? stderrColor.level : 0 }); // eslint-disable-line new-cap
    chalk.stderr.supportsColor = stderrColor;
    module.exports = chalk;
},
/* supports-color/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const os = require('os');
    const tty = require('tty');
    const hasFlag = require(39) /* has-flag */;
    const { env } = process;
    let forceColor;
    if (hasFlag('no-color') ||
        hasFlag('no-colors') ||
        hasFlag('color=false') ||
        hasFlag('color=never')) {
        forceColor = 0;
    }
    else if (hasFlag('color') ||
        hasFlag('colors') ||
        hasFlag('color=true') ||
        hasFlag('color=always')) {
        forceColor = 1;
    }
    if ('FORCE_COLOR' in env) {
        if (env.FORCE_COLOR === 'true') {
            forceColor = 1;
        }
        else if (env.FORCE_COLOR === 'false') {
            forceColor = 0;
        }
        else {
            forceColor = env.FORCE_COLOR.length === 0 ? 1 : Math.min(parseInt(env.FORCE_COLOR, 10), 3);
        }
    }
    function translateLevel(level) {
        if (level === 0) {
            return false;
        }
        return {
            level,
            hasBasic: true,
            has256: level >= 2,
            has16m: level >= 3
        };
    }
    function supportsColor(haveStream, streamIsTTY) {
        if (forceColor === 0) {
            return 0;
        }
        if (hasFlag('color=16m') ||
            hasFlag('color=full') ||
            hasFlag('color=truecolor')) {
            return 3;
        }
        if (hasFlag('color=256')) {
            return 2;
        }
        if (haveStream && !streamIsTTY && forceColor === undefined) {
            return 0;
        }
        const min = forceColor || 0;
        if (env.TERM === 'dumb') {
            return min;
        }
        if (process.platform === 'win32') {
            // Windows 10 build 10586 is the first Windows release that supports 256 colors.
            // Windows 10 build 14931 is the first release that supports 16m/TrueColor.
            const osRelease = os.release().split('.');
            if (Number(osRelease[0]) >= 10 &&
                Number(osRelease[2]) >= 10586) {
                return Number(osRelease[2]) >= 14931 ? 3 : 2;
            }
            return 1;
        }
        if ('CI' in env) {
            if (['TRAVIS', 'CIRCLECI', 'APPVEYOR', 'GITLAB_CI', 'GITHUB_ACTIONS', 'BUILDKITE'].some(sign => sign in env) || env.CI_NAME === 'codeship') {
                return 1;
            }
            return min;
        }
        if ('TEAMCITY_VERSION' in env) {
            return /^(9\.(0*[1-9]\d*)\.|\d{2,}\.)/.test(env.TEAMCITY_VERSION) ? 1 : 0;
        }
        if (env.COLORTERM === 'truecolor') {
            return 3;
        }
        if ('TERM_PROGRAM' in env) {
            const version = parseInt((env.TERM_PROGRAM_VERSION || '').split('.')[0], 10);
            switch (env.TERM_PROGRAM) {
                case 'iTerm.app':
                    return version >= 3 ? 3 : 2;
                case 'Apple_Terminal':
                    return 2;
                // No default
            }
        }
        if (/-256(color)?$/i.test(env.TERM)) {
            return 2;
        }
        if (/^screen|^xterm|^vt100|^vt220|^rxvt|color|ansi|cygwin|linux/i.test(env.TERM)) {
            return 1;
        }
        if ('COLORTERM' in env) {
            return 1;
        }
        return min;
    }
    function getSupportLevel(stream) {
        const level = supportsColor(stream, stream && stream.isTTY);
        return translateLevel(level);
    }
    module.exports = {
        supportsColor: getSupportLevel,
        stdout: translateLevel(supportsColor(true, tty.isatty(1))),
        stderr: translateLevel(supportsColor(true, tty.isatty(2)))
    };
},
/* has-flag/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = (flag, argv = process.argv) => {
        const prefix = flag.startsWith('-') ? '' : (flag.length === 1 ? '-' : '--');
        const position = argv.indexOf(prefix + flag);
        const terminatorPosition = argv.indexOf('--');
        return position !== -1 && (terminatorPosition === -1 || position < terminatorPosition);
    };
},
/* chalk/source/util.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const stringReplaceAll = (string, substring, replacer) => {
        let index = string.indexOf(substring);
        if (index === -1) {
            return string;
        }
        const substringLength = substring.length;
        let endIndex = 0;
        let returnValue = '';
        do {
            returnValue += string.substr(endIndex, index - endIndex) + substring + replacer;
            endIndex = index + substringLength;
            index = string.indexOf(substring, endIndex);
        } while (index !== -1);
        returnValue += string.substr(endIndex);
        return returnValue;
    };
    const stringEncaseCRLFWithFirstIndex = (string, prefix, postfix, index) => {
        let endIndex = 0;
        let returnValue = '';
        do {
            const gotCR = string[index - 1] === '\r';
            returnValue += string.substr(endIndex, (gotCR ? index - 1 : index) - endIndex) + prefix + (gotCR ? '\r\n' : '\n') + postfix;
            endIndex = index + 1;
            index = string.indexOf('\n', endIndex);
        } while (index !== -1);
        returnValue += string.substr(endIndex);
        return returnValue;
    };
    module.exports = {
        stringReplaceAll,
        stringEncaseCRLFWithFirstIndex
    };
},
/* chalk/source/templates.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    const TEMPLATE_REGEX = /(?:\\(u(?:[a-f\d]{4}|\{[a-f\d]{1,6}\})|x[a-f\d]{2}|.))|(?:\{(~)?(\w+(?:\([^)]*\))?(?:\.\w+(?:\([^)]*\))?)*)(?:[ \t]|(?=\r?\n)))|(\})|((?:.|[\r\n\f])+?)/gi;
    const STYLE_REGEX = /(?:^|\.)(\w+)(?:\(([^)]*)\))?/g;
    const STRING_REGEX = /^(['"])((?:\\.|(?!\1)[^\\])*)\1$/;
    const ESCAPE_REGEX = /\\(u(?:[a-f\d]{4}|{[a-f\d]{1,6}})|x[a-f\d]{2}|.)|([^\\])/gi;
    const ESCAPES = new Map([
        ['n', '\n'],
        ['r', '\r'],
        ['t', '\t'],
        ['b', '\b'],
        ['f', '\f'],
        ['v', '\v'],
        ['0', '\0'],
        ['\\', '\\'],
        ['e', '\u001B'],
        ['a', '\u0007']
    ]);
    function unescape(c) {
        const u = c[0] === 'u';
        const bracket = c[1] === '{';
        if ((u && !bracket && c.length === 5) || (c[0] === 'x' && c.length === 3)) {
            return String.fromCharCode(parseInt(c.slice(1), 16));
        }
        if (u && bracket) {
            return String.fromCodePoint(parseInt(c.slice(2, -1), 16));
        }
        return ESCAPES.get(c) || c;
    }
    function parseArguments(name, arguments_) {
        const results = [];
        const chunks = arguments_.trim().split(/\s*,\s*/g);
        let matches;
        for (const chunk of chunks) {
            const number = Number(chunk);
            if (!Number.isNaN(number)) {
                results.push(number);
            }
            else if ((matches = chunk.match(STRING_REGEX))) {
                results.push(matches[2].replace(ESCAPE_REGEX, (m, escape, character) => escape ? unescape(escape) : character));
            }
            else {
                throw new Error(`Invalid Chalk template style argument: ${chunk} (in style '${name}')`);
            }
        }
        return results;
    }
    function parseStyle(style) {
        STYLE_REGEX.lastIndex = 0;
        const results = [];
        let matches;
        while ((matches = STYLE_REGEX.exec(style)) !== null) {
            const name = matches[1];
            if (matches[2]) {
                const args = parseArguments(name, matches[2]);
                results.push([name].concat(args));
            }
            else {
                results.push([name]);
            }
        }
        return results;
    }
    function buildStyle(chalk, styles) {
        const enabled = {};
        for (const layer of styles) {
            for (const style of layer.styles) {
                enabled[style[0]] = layer.inverse ? null : style.slice(1);
            }
        }
        let current = chalk;
        for (const [styleName, styles] of Object.entries(enabled)) {
            if (!Array.isArray(styles)) {
                continue;
            }
            if (!(styleName in current)) {
                throw new Error(`Unknown Chalk style: ${styleName}`);
            }
            current = styles.length > 0 ? current[styleName](...styles) : current[styleName];
        }
        return current;
    }
    module.exports = (chalk, temporary) => {
        const styles = [];
        const chunks = [];
        let chunk = [];
        // eslint-disable-next-line max-params
        temporary.replace(TEMPLATE_REGEX, (m, escapeCharacter, inverse, style, close, character) => {
            if (escapeCharacter) {
                chunk.push(unescape(escapeCharacter));
            }
            else if (style) {
                const string = chunk.join('');
                chunk = [];
                chunks.push(styles.length === 0 ? string : buildStyle(chalk, styles)(string));
                styles.push({ inverse, styles: parseStyle(style) });
            }
            else if (close) {
                if (styles.length === 0) {
                    throw new Error('Found extraneous } in Chalk template literal');
                }
                chunks.push(buildStyle(chalk, styles)(chunk.join('')));
                chunk = [];
                styles.pop();
            }
            else {
                chunk.push(character);
            }
        });
        chunks.push(chunk.join(''));
        if (styles.length > 0) {
            const errMessage = `Chalk template literal is missing ${styles.length} closing bracket${styles.length === 1 ? '' : 's'} (\`}\`)`;
            throw new Error(errMessage);
        }
        return chunks.join('');
    };
},
/* transforms.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.print_es = exports.parse_es = exports.wrap_in_function = exports.fix_regl = exports.fix_esexports = exports.remove_void0 = exports.fix_esmodule = exports.rename_exports = exports.rewrite_deps = exports.collect_deps = exports.collect_imports = exports.collect_exports = exports.remove_use_strict = exports.insert_class_name = exports.relativize_modules = exports.apply = void 0;
    const typescript_1 = __importDefault(require(21) /* typescript */);
    function apply(node, ...transforms) {
        const result = typescript_1.default.transform(node, transforms);
        return result.transformed[0];
    }
    exports.apply = apply;
    function is_require(node) {
        return typescript_1.default.isCallExpression(node) &&
            typescript_1.default.isIdentifier(node.expression) &&
            node.expression.text === "require" &&
            node.arguments.length === 1;
    }
    function isImportCall(node) {
        return typescript_1.default.isCallExpression(node) && node.expression.kind == typescript_1.default.SyntaxKind.ImportKeyword;
    }
    function relativize_modules(relativize) {
        function relativize_specifier(context, source, expr) {
            const { factory } = context;
            if (expr != null && typescript_1.default.isStringLiteralLike(expr) && expr.text.length > 0) {
                const relative = relativize(source.fileName, expr.text);
                if (relative != null) {
                    return factory.createStringLiteral(relative);
                }
            }
            return null;
        }
        return (context) => {
            return {
                transformSourceFile(root) {
                    const { factory } = context;
                    function visit(node) {
                        if (typescript_1.default.isImportDeclaration(node)) {
                            const moduleSpecifier = relativize_specifier(context, root, node.moduleSpecifier);
                            if (moduleSpecifier != null) {
                                const { modifiers, importClause, assertClause } = node;
                                return factory.updateImportDeclaration(node, modifiers, importClause, moduleSpecifier, assertClause);
                            }
                        }
                        else if (typescript_1.default.isExportDeclaration(node)) {
                            const moduleSpecifier = relativize_specifier(context, root, node.moduleSpecifier);
                            if (moduleSpecifier != null) {
                                const { modifiers, isTypeOnly, exportClause, assertClause } = node;
                                return factory.updateExportDeclaration(node, modifiers, isTypeOnly, exportClause, moduleSpecifier, assertClause);
                            }
                        }
                        else if (is_require(node)) {
                            const moduleSpecifier = relativize_specifier(context, root, node.arguments[0]);
                            if (moduleSpecifier != null) {
                                const { expression, typeArguments } = node;
                                return factory.updateCallExpression(node, expression, typeArguments, [moduleSpecifier]);
                            }
                        }
                        else if (isImportCall(node)) {
                            const moduleSpecifier = relativize_specifier(context, root, node.arguments[0]);
                            if (moduleSpecifier != null) {
                                const { expression, typeArguments } = node;
                                return factory.updateCallExpression(node, expression, typeArguments, [moduleSpecifier]);
                            }
                        }
                        else if (typescript_1.default.isImportTypeNode(node) && typescript_1.default.isLiteralTypeNode(node.argument)) {
                            const literal = relativize_specifier(context, root, node.argument.literal);
                            if (literal != null) {
                                const argument = factory.updateLiteralTypeNode(node.argument, literal);
                                return factory.updateImportTypeNode(node, argument, node.attributes, node.qualifier, node.typeArguments, node.isTypeOf);
                            }
                        }
                        return typescript_1.default.visitEachChild(node, visit, context);
                    }
                    return typescript_1.default.visitEachChild(root, visit, context);
                },
                transformBundle(_root) {
                    throw new Error("unsupported");
                },
            };
        };
    }
    exports.relativize_modules = relativize_modules;
    function is_static(node) {
        return typescript_1.default.canHaveModifiers(node) && typescript_1.default.getModifiers(node)?.find((modifier) => modifier.kind == typescript_1.default.SyntaxKind.StaticKeyword) != null;
    }
    function insert_class_name() {
        function has__name__(node) {
            return node.members.find((member) => typescript_1.default.isPropertyDeclaration(member) && member.name.getText() == "__name__" && is_static(member)) != null;
        }
        return (context) => (root) => {
            const { factory } = context;
            function visit(node) {
                node = typescript_1.default.visitEachChild(node, visit, context);
                if (typescript_1.default.isClassDeclaration(node) && node.name != null && !has__name__(node)) {
                    const property = factory.createPropertyDeclaration(factory.createModifiersFromModifierFlags(typescript_1.default.ModifierFlags.Static), "__name__", undefined, undefined, factory.createStringLiteral(node.name.text));
                    node = factory.updateClassDeclaration(node, node.modifiers, node.name, node.typeParameters, node.heritageClauses, [property, ...node.members]);
                }
                return node;
            }
            return typescript_1.default.visitEachChild(root, visit, context);
        };
    }
    exports.insert_class_name = insert_class_name;
    function remove_use_strict() {
        return (context) => (root) => {
            const { factory } = context;
            const statements = root.statements.filter((node) => {
                if (typescript_1.default.isExpressionStatement(node)) {
                    const expr = node.expression;
                    if (typescript_1.default.isStringLiteral(expr) && expr.text == "use strict") {
                        return false;
                    }
                }
                return true;
            });
            return factory.updateSourceFile(root, statements);
        };
    }
    exports.remove_use_strict = remove_use_strict;
    function collect_exports(exported) {
        return (_context) => (root) => {
            for (const statement of root.statements) {
                if (typescript_1.default.isExportDeclaration(statement)) {
                    if (statement.isTypeOnly) {
                        continue;
                    }
                    const { exportClause, moduleSpecifier } = statement;
                    if (moduleSpecifier == null || !typescript_1.default.isStringLiteral(moduleSpecifier)) {
                        continue;
                    }
                    const module = moduleSpecifier.text;
                    if (exportClause == null) {
                        // export * from "module"
                        exported.push({ type: "namespace", module });
                    }
                    else if (typescript_1.default.isNamespaceExport(exportClause)) {
                        // export * as name from "module"
                        const name = exportClause.name.text;
                        exported.push({ type: "namespace", name, module });
                    }
                    else if (typescript_1.default.isNamedExports(exportClause)) {
                        // export {name0, name1 as nameA} from "module"
                        const bindings = [];
                        for (const elem of exportClause.elements) {
                            bindings.push([elem.propertyName?.text, elem.name.text]);
                        }
                        exported.push({ type: "bindings", bindings, module });
                    }
                }
                else if (typescript_1.default.isExportAssignment(statement) && !(statement.isExportEquals ?? false)) {
                    // export default name
                    exported.push({ type: "named", name: "default" });
                }
                else if (typescript_1.default.isClassDeclaration(statement) || typescript_1.default.isFunctionDeclaration(statement)) {
                    const flags = typescript_1.default.getCombinedModifierFlags(statement);
                    if ((flags & typescript_1.default.ModifierFlags.Export) != 0) {
                        // export class X {}
                        // export function f() {}
                        if (statement.name != null) {
                            const name = statement.name.text;
                            exported.push({ type: "named", name });
                        }
                    }
                    else if ((flags & typescript_1.default.ModifierFlags.ExportDefault) != 0) {
                        // export default class X {}
                        // export function f() {}
                        exported.push({ type: "named", name: "default" });
                    }
                }
            }
            return root;
        };
    }
    exports.collect_exports = collect_exports;
    function collect_imports(imports) {
        return (context) => (root) => {
            function visit(node) {
                if (typescript_1.default.isImportDeclaration(node) || typescript_1.default.isExportDeclaration(node)) {
                    const name = node.moduleSpecifier;
                    if (name != null && typescript_1.default.isStringLiteral(name) && name.text.length != 0) {
                        imports.add(name.text);
                    }
                }
                else if (isImportCall(node)) {
                    const [name] = node.arguments;
                    if (typescript_1.default.isStringLiteral(name) && name.text.length != 0) {
                        imports.add(name.text);
                    }
                }
                return typescript_1.default.visitEachChild(node, visit, context);
            }
            return typescript_1.default.visitEachChild(root, visit, context);
        };
    }
    exports.collect_imports = collect_imports;
    function collect_deps(source) {
        function traverse(node) {
            if (is_require(node)) {
                const [arg] = node.arguments;
                if (typescript_1.default.isStringLiteral(arg) && arg.text.length > 0) {
                    deps.add(arg.text);
                }
            }
            typescript_1.default.forEachChild(node, traverse);
        }
        const deps = new Set();
        traverse(source);
        return [...deps];
    }
    exports.collect_deps = collect_deps;
    function rewrite_deps(resolve) {
        return (context) => (root) => {
            const { factory } = context;
            function visit(node) {
                if (is_require(node)) {
                    const [arg] = node.arguments;
                    if (typescript_1.default.isStringLiteral(arg) && arg.text.length > 0) {
                        const dep = arg.text;
                        const val = resolve(dep);
                        if (val != null) {
                            const literal = typeof val == "string" ? factory.createStringLiteral(val) : factory.createNumericLiteral(val);
                            node = factory.updateCallExpression(node, node.expression, node.typeArguments, [literal]);
                            typescript_1.default.addSyntheticTrailingComment(node, typescript_1.default.SyntaxKind.MultiLineCommentTrivia, ` ${dep} `, false);
                        }
                        return node;
                    }
                }
                return typescript_1.default.visitEachChild(node, visit, context);
            }
            return typescript_1.default.visitEachChild(root, visit, context);
        };
    }
    exports.rewrite_deps = rewrite_deps;
    // XXX: this is pretty naive, but affects very litte code
    function rename_exports() {
        return (context) => (root) => {
            const { factory } = context;
            function is_exports(node) {
                return typescript_1.default.isIdentifier(node) && node.text == "exports";
            }
            const has_exports = root.statements.some((stmt) => {
                return typescript_1.default.isVariableStatement(stmt) && stmt.declarationList.declarations.some((decl) => is_exports(decl.name));
            });
            if (has_exports) {
                function visit(node) {
                    if (is_exports(node)) {
                        const updated = factory.createIdentifier("exports$1");
                        const original = node;
                        typescript_1.default.setOriginalNode(updated, original);
                        typescript_1.default.setTextRange(updated, original);
                        return updated;
                    }
                    return typescript_1.default.visitEachChild(node, visit, context);
                }
                return typescript_1.default.visitEachChild(root, visit, context);
            }
            else {
                return root;
            }
        };
    }
    exports.rename_exports = rename_exports;
    function fix_esmodule() {
        return (context) => (root) => {
            const { factory } = context;
            let found = false;
            const statements = root.statements.map((node) => {
                if (!found && typescript_1.default.isExpressionStatement(node)) {
                    const expr = node.expression;
                    if (typescript_1.default.isCallExpression(expr) && expr.arguments.length == 3) {
                        const [, arg] = expr.arguments;
                        if (typescript_1.default.isStringLiteral(arg) && arg.text == "__esModule") {
                            found = true;
                            const es_module = factory.createIdentifier("__esModule");
                            const call = factory.createCallExpression(es_module, [], []);
                            return factory.createExpressionStatement(call);
                        }
                    }
                }
                return node;
            });
            return factory.updateSourceFile(root, statements);
        };
    }
    exports.fix_esmodule = fix_esmodule;
    function remove_void0() {
        return (context) => (root) => {
            const { factory } = context;
            let found = false;
            const statements = root.statements.filter((node) => {
                if (!found && typescript_1.default.isExpressionStatement(node)) {
                    let { expression } = node;
                    while (typescript_1.default.isBinaryExpression(expression) &&
                        typescript_1.default.isPropertyAccessExpression(expression.left) &&
                        typescript_1.default.isIdentifier(expression.left.expression) &&
                        expression.left.expression.text == "exports") {
                        expression = expression.right;
                    }
                    if (typescript_1.default.isVoidExpression(expression)) {
                        found = true;
                        return false;
                    }
                }
                return true;
            });
            return factory.updateSourceFile(root, statements);
        };
    }
    exports.remove_void0 = remove_void0;
    function fix_esexports() {
        return (context) => (root) => {
            const { factory } = context;
            const statements = root.statements.map((node) => {
                if (typescript_1.default.isExpressionStatement(node)) {
                    const expr = node.expression;
                    if (typescript_1.default.isCallExpression(expr) && typescript_1.default.isPropertyAccessExpression(expr.expression) && expr.arguments.length == 3) {
                        const { expression, name } = expr.expression;
                        if (typescript_1.default.isIdentifier(expression) && expression.text == "Object" &&
                            typescript_1.default.isIdentifier(name) && name.text == "defineProperty") {
                            const [exports, name, config] = expr.arguments;
                            if (typescript_1.default.isIdentifier(exports) && exports.text == "exports" &&
                                typescript_1.default.isStringLiteral(name) &&
                                typescript_1.default.isObjectLiteralExpression(config)) {
                                for (const item of config.properties) {
                                    if (typescript_1.default.isPropertyAssignment(item) &&
                                        typescript_1.default.isIdentifier(item.name) && item.name.text == "get" &&
                                        typescript_1.default.isFunctionExpression(item.initializer)) {
                                        const { statements } = item.initializer.body;
                                        if (statements.length == 1) {
                                            const [stmt] = statements;
                                            if (typescript_1.default.isReturnStatement(stmt) && stmt.expression != null) {
                                                const es_export = factory.createIdentifier("__esExport");
                                                const call = factory.createCallExpression(es_export, [], [name, stmt.expression]);
                                                return factory.createExpressionStatement(call);
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
                return node;
            });
            return factory.updateSourceFile(root, statements);
        };
    }
    exports.fix_esexports = fix_esexports;
    function fix_regl() {
        return (context) => (root) => {
            if (!root.fileName.endsWith("regl.js")) {
                return root;
            }
            const { factory } = context;
            function visit(node) {
                if (typescript_1.default.isFunctionDeclaration(node) && node.name != null && typescript_1.default.isIdentifier(node.name)) {
                    if (node.name.text == "guessCommand" || node.name.text == "guessCallSite") {
                        const value = factory.createStringLiteral("unknown");
                        const body = factory.createBlock([factory.createReturnStatement(value)]);
                        return factory.createFunctionDeclaration(undefined, undefined, node.name, undefined, [], undefined, body);
                    }
                }
                return typescript_1.default.visitEachChild(node, visit, context);
            }
            return typescript_1.default.visitEachChild(root, visit, context);
        };
    }
    exports.fix_regl = fix_regl;
    function wrap_in_function(module_name) {
        return (context) => (root) => {
            const { factory } = context;
            const p = (name) => factory.createParameterDeclaration(undefined, undefined, name);
            const params = [p("require"), p("module"), p("exports"), p("__esModule"), p("__esExport")];
            const block = factory.createBlock(root.statements, true);
            const func = factory.createFunctionDeclaration(undefined, undefined, "_", undefined, params, undefined, block);
            typescript_1.default.addSyntheticLeadingComment(func, typescript_1.default.SyntaxKind.MultiLineCommentTrivia, ` ${module_name} `, false);
            return factory.updateSourceFile(root, [func]);
        };
    }
    exports.wrap_in_function = wrap_in_function;
    function parse_es(file, code, target = typescript_1.default.ScriptTarget.ES2020) {
        return typescript_1.default.createSourceFile(file, code != null ? code : typescript_1.default.sys.readFile(file), target, true, typescript_1.default.ScriptKind.JS);
    }
    exports.parse_es = parse_es;
    function print_es(source) {
        const printer = typescript_1.default.createPrinter();
        return printer.printNode(typescript_1.default.EmitHint.SourceFile, source, source);
    }
    exports.print_es = print_es;
    
},
/* error.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.BuildError = void 0;
    class BuildError extends Error {
        component;
        static __name__ = "BuildError";
        constructor(component, message) {
            super(message);
            this.component = component;
        }
    }
    exports.BuildError = BuildError;
    
},
/* linker.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.minify = exports.transpile = exports.Linker = exports.Artifact = exports.Bundle = void 0;
    const path_1 = require("path");
    const module_1 = __importDefault(require("module"));
    const crypto_1 = __importDefault(require("crypto"));
    const typescript_1 = __importDefault(require(21) /* typescript */);
    const terser = __importStar(require(45) /* terser */);
    const chalk_1 = __importDefault(require(37) /* chalk */);
    const combine = __importStar(require(53) /* combine-source-map */);
    const convert = __importStar(require(54) /* convert-source-map */);
    const sys_1 = require(20) /* ./sys */;
    const compiler_1 = require(36) /* ./compiler */;
    const transforms = __importStar(require(42) /* ./transforms */);
    const error_1 = require(43) /* ./error */;
    const graph_1 = require(59) /* ./graph */;
    const root_path = process.cwd();
    const cache_version = 4;
    const to_obj = (map) => {
        const obj = Object.create(null);
        for (const [key, val] of map) {
            obj[key] = val;
        }
        return obj;
    };
    const dense_assembly = {
        prefix: "[",
        suffix: "]",
        wrap: (_, source) => source,
    };
    const sparse_assembly = {
        prefix: "{",
        suffix: "}",
        wrap: (id, source) => `${id}: ${source}`,
    };
    class Bundle {
        entry;
        artifacts;
        builtins;
        bases;
        static __name__ = "Bundle";
        constructor(entry, artifacts, builtins, bases = []) {
            this.entry = entry;
            this.artifacts = artifacts;
            this.builtins = builtins;
            this.bases = bases;
        }
        assemble(options) {
            let line = 0;
            let sources = "";
            const sourcemap = combine.create();
            const aliases = new Map();
            const externals = new Map();
            const newlines = (source) => {
                const result = source.match(/\n/g);
                return result != null ? result.length : 0;
            };
            const safe_id = (module) => {
                const { id } = module;
                return typeof id == "number" ? id.toString() : JSON.stringify(id);
            };
            const { entry, artifacts, bases } = this;
            const minified = options.minified ?? false;
            const plugin = bases.length != 0;
            const { prefix, suffix, wrap } = !plugin ? dense_assembly : sparse_assembly;
            const prelude = !plugin ? options.prelude.main : options.prelude.plugin;
            const postlude = !plugin ? options.postlude.main : options.postlude.plugin;
            sources += `${prelude}(${prefix}\n`;
            line += newlines(sources);
            for (const artifact of artifacts) {
                const { module } = artifact;
                if (module.canonical != null) {
                    aliases.set(module.canonical, module.id);
                }
                for (const external of module.externals) {
                    externals.set(external, true);
                }
                for (const external of module.shims) {
                    externals.set(external, false);
                }
                const start = wrap(safe_id(module), "");
                sources += start;
                line += newlines(start);
                const source_with_sourcemap = minified ? artifact.code.min_source : artifact.code.source;
                const source = combine.removeComments(source_with_sourcemap).trimEnd();
                sources += source;
                const map_path = (0, path_1.join)("@@", (0, path_1.relative)(root_path, module.file));
                sourcemap.addFile({ source: source_with_sourcemap, sourceFile: map_path }, { line });
                line += newlines(source);
                const end = ",\n";
                sources += end;
                line += newlines(end);
            }
            const aliases_json = JSON.stringify(to_obj(aliases));
            const externals_json = JSON.stringify(to_obj(externals));
            sources += `${suffix}, ${safe_id(entry)}, ${aliases_json}, ${externals_json});${postlude}`;
            const source_map = convert.fromBase64(sourcemap.base64()).toObject();
            return new Artifact(sources, minified ? null : source_map, aliases);
        }
        *collect_exported(entry) {
            for (const item of entry.exported) {
                switch (item.type) {
                    case "bindings": {
                        for (const [, name] of item.bindings) {
                            yield name;
                        }
                        break;
                    }
                    case "named": {
                        yield item.name;
                        break;
                    }
                    case "namespace": {
                        const { name } = item;
                        if (name != null) {
                            yield name;
                        }
                        else {
                            const module = entry.dependencies.get(item.module);
                            if (module != null) {
                                yield* this.collect_exported(module);
                            }
                        }
                        break;
                    }
                }
            }
        }
    }
    exports.Bundle = Bundle;
    class Artifact {
        source;
        sourcemap;
        exported;
        static __name__ = "Artifact";
        constructor(source, sourcemap, exported) {
            this.source = source;
            this.sourcemap = sourcemap;
            this.exported = exported;
        }
        full_source(name) {
            if (this.sourcemap != null) {
                return `${this.source}\n${convert.generateMapFileComment(name)}\n`;
            }
            else {
                return `${this.source}\n`;
            }
        }
        get module_names() {
            return Array.from(this.exported.keys());
        }
        write(path) {
            const dir = (0, path_1.dirname)(path);
            const name = (0, path_1.basename)(path, ".js");
            (0, sys_1.write)(path, this.full_source(`${name}.js.map`));
            if (this.sourcemap != null) {
                (0, sys_1.write)((0, path_1.join)(dir, `${name}.js.map`), JSON.stringify(this.sourcemap));
            }
        }
    }
    exports.Artifact = Artifact;
    class Linker {
        static __name__ = "Linker";
        entries;
        bases;
        excludes;
        external_modules;
        external_regex;
        excluded;
        builtins;
        cache_path;
        cache;
        target;
        es_modules;
        minify;
        plugin;
        exports;
        shims;
        detect_cycles;
        overrides;
        apply_transforms;
        constructor(opts) {
            this.entries = opts.entries.map((path) => (0, path_1.resolve)(path));
            this.bases = (opts.bases ?? []).map((path) => (0, path_1.resolve)(path));
            this.excludes = new Set((opts.excludes ?? []).map((path) => (0, path_1.resolve)(path)));
            this.external_modules = new Set((opts.externals ?? []).filter((s) => typeof s === "string"));
            this.external_regex = (opts.externals ?? []).filter((s) => s instanceof RegExp);
            this.excluded = opts.excluded ?? (() => false);
            this.builtins = opts.builtins ?? false;
            this.exports = new Set(opts.exports ?? []);
            if (this.builtins) {
                this.external_modules.add("module");
                this.external_modules.add("constants");
                for (const lib of module_1.default.builtinModules) {
                    this.external_modules.add(lib);
                }
            }
            for (const entry of this.entries) {
                if (!(0, sys_1.file_exists)(entry)) {
                    throw new error_1.BuildError("linker", `entry path ${entry} doesn't exist or isn't a file`);
                }
            }
            for (const base of this.bases) {
                if (!(0, sys_1.directory_exists)(base)) {
                    throw new error_1.BuildError("linker", `base path ${base} doesn't exist or isn't a directory`);
                }
            }
            this.cache_path = opts.cache;
            this.cache = new Map();
            this.target = opts.target ?? null;
            this.es_modules = opts.es_modules ?? true;
            this.minify = opts.minify ?? true;
            this.plugin = opts.plugin ?? false;
            this.shims = new Set(opts.shims ?? []);
            this.detect_cycles = opts.detect_cycles ?? true;
            this.overrides = new Map(Object.entries(opts.overrides ?? {}));
            this.apply_transforms = opts.apply_transforms ?? true;
        }
        is_external(dep) {
            return this.external_modules.has(dep) || this.external_regex.some((re) => re.test(dep));
        }
        is_shimmed(dep) {
            return this.shims.has(dep);
        }
        async link() {
            let status = true;
            const [entries] = this.resolve(this.entries);
            const [main, ...plugins] = entries;
            const dirnames = plugins.map((plugin) => (0, path_1.dirname)(plugin.file));
            const is_excluded = (module) => {
                return dirnames.find((e) => module.file.startsWith(e)) != null;
            };
            const main_modules = this.reachable(main, is_excluded);
            const parents = new Set(main_modules);
            const plugin_modules = [];
            for (const plugin of plugins) {
                const files = this.reachable(plugin, (module) => parents.has(module));
                plugin_modules.push(files);
            }
            const all_modules = main_modules.concat(...plugin_modules);
            if (!this.plugin) {
                all_modules.forEach((module, i) => module.id = i);
            }
            else {
                all_modules.forEach((module) => module.id = module.hash.slice(0, 10));
            }
            if (this.detect_cycles) {
                function is_internal(module) {
                    return module.canonical != null;
                }
                const nodes = all_modules.filter(is_internal);
                const graph = new Map();
                for (const node of nodes) {
                    const deps = [...node.dependencies.values()];
                    graph.set(node, deps.filter(is_internal));
                }
                const cycles = (0, graph_1.detect_cycles)(graph);
                if (cycles.length != 0) {
                    status = false;
                    for (const cycle of cycles) {
                        console.log(`${chalk_1.default.red("\u2717")} cycle detected:`);
                        for (const module of cycle) {
                            const is_last = cycle[cycle.length - 1] == module;
                            console.log(`${is_last ? "\u2514" : "\u251c"}\u2500 ${module.canonical ?? module.base_path}`);
                        }
                    }
                }
            }
            const transformers = (module) => {
                const transformers = [];
                if (this.apply_transforms) {
                    const remove_use_strict = transforms.remove_use_strict();
                    transformers.push(remove_use_strict);
                    const fix_esmodule = transforms.fix_esmodule();
                    transformers.push(fix_esmodule);
                    const remove_void0 = transforms.remove_void0();
                    transformers.push(remove_void0);
                    const fix_esexports = transforms.fix_esexports();
                    transformers.push(fix_esexports);
                    const fix_regl = transforms.fix_regl();
                    transformers.push(fix_regl);
                }
                const rewrite_deps = transforms.rewrite_deps((dep) => {
                    const module_dep = module.dependencies.get(dep);
                    return module_dep != null ? module_dep.id : undefined;
                });
                transformers.push(rewrite_deps);
                transformers.push(transforms.wrap_in_function(module.base_path));
                return transformers;
            };
            const print = (module) => {
                let ast = module.ast ?? this.parse_module(module);
                ast = transforms.apply(ast, ...transformers(module));
                const source = transforms.print_es(ast);
                return convert.removeMapFileComments(source);
            };
            const deps_changed = (module, cached) => {
                if (module.dependencies.size != cached.dependencies.size) {
                    return false;
                }
                for (const [dep, module_dep] of module.dependencies) {
                    const cached_dep = cached.dependencies.get(dep);
                    if (cached_dep == null || cached_dep.id != module_dep.id) {
                        return true;
                    }
                }
                return false;
            };
            const artifacts = async (modules) => {
                const result = [];
                for (const module of modules) {
                    const cached = this.cache.get(module.file);
                    let code;
                    if (module.changed || (cached != null && deps_changed(module, cached.module))) {
                        const source = print(module);
                        const ecma = (() => {
                            switch (this.target) {
                                case "ES2022": return 2020; // TODO: 2022
                                case null:
                                case "ES2020": return 2020;
                                case "ES2017": return 2017;
                                case "ES2015": return 5;
                            }
                        })();
                        const minified = this.minify ? await minify(module, source, ecma) : { min_source: source };
                        code = { source, ...minified };
                    }
                    else {
                        code = cached.code;
                    }
                    result.push({ module, code });
                }
                return result;
            };
            const main_bundle = new Bundle(main, await artifacts(main_modules), this.builtins);
            const plugin_bundles = [];
            for (let j = 0; j < plugins.length; j++) {
                const plugin_bundle = new Bundle(plugins[j], await artifacts(plugin_modules[j]), this.builtins, [main_bundle]);
                plugin_bundles.push(plugin_bundle);
            }
            const bundles = [main_bundle, ...plugin_bundles];
            this.cache.clear();
            for (const bundle of bundles) {
                for (const artifact of bundle.artifacts) {
                    this.cache.set(artifact.module.file, artifact);
                }
            }
            return { bundles, status };
        }
        load_cache() {
            const { cache_path } = this;
            if (cache_path == null || !(0, sys_1.file_exists)(cache_path)) {
                return;
            }
            this.cache.clear();
            const json = JSON.parse((0, sys_1.read)(cache_path));
            if (json.version !== cache_version) {
                console.warn("ignoring cache due to format version mismatch");
                return;
            }
            for (const { module, code } of json.artifacts) {
                const artifact = {
                    module: {
                        ...module,
                        ast: undefined,
                        changed: false,
                        dependencies: new Map(),
                        dependency_map: new Map(module.dependency_map),
                        dependency_paths: new Map(module.dependency_paths),
                        externals: new Set(module.externals),
                        shims: new Set(module.shims),
                    },
                    code,
                };
                this.cache.set(artifact.module.file, artifact);
            }
            for (const { module } of this.cache.values()) {
                for (const [dep, file] of module.dependency_paths) {
                    const file_entry = this.cache.get(file);
                    if (file_entry == null) {
                        throw new Error(`${file} not in cache`);
                    }
                    module.dependencies.set(dep, file_entry.module);
                }
            }
        }
        store_cache() {
            if (this.cache_path == null) {
                return;
            }
            const artifacts = [];
            for (const artifact of this.cache.values()) {
                const module = {
                    ...artifact.module,
                    changed: undefined,
                    ast: undefined,
                    dependencies: undefined,
                };
                artifacts.push({
                    module: {
                        ...module,
                        dependency_map: [...module.dependency_map.entries()],
                        dependency_paths: [...module.dependency_paths.entries()],
                        externals: [...module.externals.values()],
                        shims: [...module.shims.values()],
                    },
                    code: artifact.code,
                });
            }
            const json = JSON.stringify({ version: cache_version, artifacts });
            (0, sys_1.write)(this.cache_path, json);
        }
        ext = ".js";
        get_package(dir) {
            const pkg_path = (0, path_1.join)(dir, "package.json");
            if ((0, sys_1.file_exists)(pkg_path)) {
                return JSON.parse((0, sys_1.read)(pkg_path));
            }
            else {
                return {};
            }
        }
        resolve_export_map(dir, subpath) {
            const pkg = this.get_package(dir);
            const export_map = (pkg.exports ?? {});
            const path = (0, path_1.join)(dir, subpath);
            for (const [key, val] of Object.entries(export_map)) {
                if ((0, path_1.join)(dir, key) == path) {
                    return (0, path_1.join)(dir, val);
                }
            }
            return null;
        }
        resolve_package(dir) {
            const pkg = this.get_package(dir);
            const index = (() => {
                if (this.target != null && pkg.module != null) {
                    return pkg.module;
                }
                else if (pkg.main != null) {
                    return pkg.main;
                }
                else {
                    return "index.js";
                }
            })();
            const path = (0, path_1.join)(dir, index);
            if ((0, sys_1.file_exists)(path)) {
                return path;
            }
            const js_file = `${path}.js`;
            if ((0, sys_1.file_exists)(js_file)) {
                return js_file;
            }
            const json_file = `${path}.json`;
            if ((0, sys_1.file_exists)(json_file)) {
                return json_file;
            }
            if ((0, sys_1.directory_exists)(path)) {
                const index = (0, path_1.join)(path, "index.js");
                if ((0, sys_1.file_exists)(index)) {
                    return index;
                }
            }
            return null;
        }
        resolve_relative(dep, parent) {
            const path = (0, path_1.resolve)((0, path_1.dirname)(parent.file), dep);
            if ((0, sys_1.file_exists)(path)) {
                return path;
            }
            const js_file = `${path}.js`;
            const json_file = `${path}.json`;
            const has_js_file = (0, sys_1.file_exists)(js_file);
            const has_json_file = (0, sys_1.file_exists)(json_file);
            const has_file = has_js_file || has_json_file;
            if ((0, sys_1.directory_exists)(path)) {
                const pkg_file = this.resolve_package(path);
                if (pkg_file != null) {
                    if (!has_file) {
                        return pkg_file;
                    }
                    else {
                        return new error_1.BuildError("linker", `both ${has_js_file ? js_file : json_file} and ${pkg_file} exist`);
                    }
                }
            }
            if (has_js_file) {
                return js_file;
            }
            else if (has_json_file) {
                return json_file;
            }
            else {
                return new error_1.BuildError("linker", `can't resolve '${dep}' from '${parent.file}'`);
            }
        }
        resolve_absolute(dep, parent) {
            for (const base of this.bases) {
                let path = (0, path_1.join)(base, dep);
                if ((0, sys_1.file_exists)(path)) {
                    return path;
                }
                const js_file = `${path}.js`;
                if ((0, sys_1.file_exists)(js_file)) {
                    return js_file;
                }
                const json_file = `${path}.json`;
                if ((0, sys_1.file_exists)(json_file)) {
                    return json_file;
                }
                if ((0, sys_1.directory_exists)(path)) {
                    const file = this.resolve_package(path);
                    if (file != null) {
                        return file;
                    }
                }
                const [dir, ...rest] = dep.split(path_1.sep);
                if (rest.length >= 1) {
                    const path = (0, path_1.join)(base, dir);
                    if ((0, sys_1.directory_exists)(path)) {
                        const file = this.resolve_export_map(path, rest.join(path_1.sep));
                        if (file != null) {
                            return file;
                        }
                    }
                }
                if (parent.file.startsWith(base)) {
                    let base_path = parent.file;
                    while (true) {
                        base_path = (0, path_1.dirname)(base_path);
                        if (base_path == base) {
                            break;
                        }
                        path = (0, path_1.join)(base_path, "node_modules", dep);
                        if ((0, sys_1.directory_exists)(path)) {
                            const file = this.resolve_package(path);
                            if (file != null) {
                                return file;
                            }
                        }
                    }
                }
            }
            return new error_1.BuildError("linker", `can't resolve '${dep}' from '${parent.file}'`);
        }
        resolve_file(dep, parent) {
            if (dep.startsWith(".")) {
                return this.resolve_relative(dep, parent);
            }
            else {
                return this.resolve_absolute(dep, parent);
            }
        }
        parse_module({ file, source }) {
            return transforms.parse_es(file, source);
        }
        new_module(file) {
            let source = (0, sys_1.read)(file);
            if (source == null) {
                throw new error_1.BuildError("linker", `'${file} doesn't exist`);
            }
            for (const [path, override] of this.overrides) {
                if (file.endsWith((0, path_1.normalize)(path))) {
                    source = override;
                    break;
                }
            }
            const hash = crypto_1.default.createHash("sha256").update(source).digest("hex");
            const type = (() => {
                switch ((0, path_1.extname)(file)) {
                    case ".json": return "json";
                    case ".json5": return "json5";
                    case ".yaml": return "yaml";
                    case ".css": return "css";
                    case ".mjs": return "js";
                    case ".cjs": return "js";
                    case ".js": return "js";
                    default:
                        throw new error_1.BuildError("linker", `unsupported extension of ${file}`);
                }
            })();
            const export_type = this.es_modules ? "default" : "=";
            switch (type) {
                case "json": {
                    source = `\
const json = ${source};
export ${export_type} json;
`;
                    break;
                }
                case "json5": {
                    source = `\
const json5 = \`
${source.replaceAll("\\", "\\\\")}
\`;
export ${export_type} json5;
`;
                    break;
                }
                case "css": {
                    source = `\
const css = \`${source}\`;
export ${export_type} css;
`;
                    break;
                }
                case "yaml": {
                    source = `\
const yaml = \`
${source}
\`;
export ${export_type} yaml;
`;
                    break;
                }
                case "js": {
                    break;
                }
            }
            const [base, base_path, canonical, resolution] = (() => {
                const [primary, ...secondary] = this.bases;
                function canonicalize(path) {
                    return path.replace(/\.js$/, "").replace(/\\/g, "/");
                }
                function get_package(base, path) {
                    const root = (0, path_1.join)(base, path);
                    base = (0, path_1.normalize)(base);
                    path = (0, path_1.normalize)(root);
                    while (path != base) {
                        if ((0, sys_1.directory_exists)(path)) {
                            const pkg_path = (0, path_1.join)(path, "package.json");
                            if ((0, sys_1.file_exists)(pkg_path)) {
                                return { dir: path, pkg: JSON.parse((0, sys_1.read)(pkg_path)) };
                            }
                        }
                        path = (0, path_1.dirname)(path);
                    }
                    throw new error_1.BuildError("linker", `can't resolve package.json for ${root}`);
                }
                const path = (0, path_1.relative)(primary, file);
                if (!path.startsWith("..")) {
                    return [primary, path, canonicalize(path), "ESM"];
                }
                for (const base of secondary) {
                    const path = (0, path_1.relative)(base, file);
                    if (!path.startsWith("..")) {
                        if (type == "js") {
                            const { dir, pkg } = get_package(base, path);
                            const reso = pkg.type == "module" || pkg.module != null ? "ESM" : "CJS";
                            const entry = pkg.module ?? pkg.name;
                            const primary = entry != null && (0, path_1.join)(dir, entry) == (0, path_1.join)(base, path);
                            const name = canonicalize(primary ? (0, path_1.basename)(dir) : path);
                            const exported = this.exports.has(name);
                            return [base, path, exported ? name : undefined, reso];
                        }
                        else {
                            return [base, path, undefined, "ESM"];
                        }
                    }
                }
                throw new error_1.BuildError("linker", `${file} is not under any of base paths`);
            })();
            const cached = this.cache.get(file);
            let ast;
            let dependency_paths;
            let externals;
            let shims;
            let exported = [];
            const changed = cached == null || cached.module.hash != hash;
            if (changed) {
                let collected = null;
                if ((this.target != null && resolution == "ESM") || type == "json") {
                    const { ES2022, ES2020, ES2017, ES2015 } = typescript_1.default.ScriptTarget;
                    const target = (() => {
                        switch (this.target) {
                            case "ES2022": return ES2022;
                            case null:
                            case "ES2020": return ES2020;
                            case "ES2017": return ES2017;
                            case "ES2015": return ES2015;
                        }
                    })();
                    const imports = new Set();
                    if (canonical != "tslib") {
                        imports.add("tslib");
                    }
                    const transform = {
                        before: [transforms.collect_imports(imports), transforms.rename_exports(), transforms.collect_exports(exported)],
                        after: [],
                    };
                    // XXX: .json extension will cause an internal error
                    const { output, error } = transpile(type == "json" ? `${file}.ts` : file, source, target, transform);
                    if (error != null) {
                        throw new error_1.BuildError("linker", error);
                    }
                    else {
                        source = output;
                        collected = [...imports];
                    }
                }
                ast = this.parse_module({ file, source });
                if (collected == null) {
                    collected = transforms.collect_deps(ast);
                }
                const filtered = collected.filter((dep) => !this.is_external(dep) && !this.excluded(dep) && !this.is_shimmed(dep));
                dependency_paths = new Map();
                for (const dep of filtered) {
                    const resolved = this.resolve_file(dep, { file });
                    if (resolved instanceof Error) {
                        console.log(resolved);
                    }
                    else {
                        dependency_paths.set(dep, resolved);
                    }
                }
                externals = new Set(collected.filter((dep) => this.is_external(dep)));
                shims = new Set(collected.filter((dep) => this.is_shimmed(dep)));
            }
            else {
                dependency_paths = cached.module.dependency_paths;
                exported = cached.module.exported;
                externals = cached.module.externals;
                shims = cached.module.shims;
                source = cached.module.source;
            }
            return {
                file,
                base,
                base_path,
                canonical,
                resolution,
                id: NaN,
                hash,
                changed,
                source,
                ast,
                type,
                dependency_paths,
                dependency_map: new Map(),
                dependencies: new Map(),
                exported,
                externals,
                shims,
            };
        }
        resolve(files) {
            const visited = new Map();
            const pending = [...files];
            for (;;) {
                const file = pending.shift();
                if (file == null) {
                    break;
                }
                if (visited.has(file) || this.excludes.has(file)) {
                    continue;
                }
                const module = this.new_module(file);
                visited.set(module.file, module);
                pending.unshift(...module.dependency_paths.values());
            }
            for (const module of visited.values()) {
                for (const [dep, file] of module.dependency_paths) {
                    module.dependencies.set(dep, visited.get(file));
                }
            }
            const entries = files.map((file) => visited.get(file));
            return [entries, [...visited.values()]];
        }
        reachable(entry, is_excluded) {
            const reached = new Set();
            const pending = [entry];
            for (;;) {
                const module = pending.shift();
                if (module == null) {
                    break;
                }
                if (reached.has(module) || this.excludes.has(module.file) || is_excluded(module)) {
                    continue;
                }
                reached.add(module);
                pending.unshift(...module.dependencies.values());
            }
            return [...reached.values()];
        }
    }
    exports.Linker = Linker;
    function transpile(file, source, target, transformers) {
        const { outputText: output, diagnostics } = typescript_1.default.transpileModule(source, {
            fileName: file,
            reportDiagnostics: true,
            compilerOptions: {
                target,
                module: typescript_1.default.ModuleKind.CommonJS,
                esModuleInterop: true,
                importHelpers: true,
                downlevelIteration: true,
            },
            transformers,
        });
        if (diagnostics == null || diagnostics.length == 0) {
            return { output };
        }
        else {
            const { text } = (0, compiler_1.report_diagnostics)(diagnostics);
            return { output, error: text };
        }
    }
    exports.transpile = transpile;
    async function minify(module, source, ecma) {
        const name = (0, path_1.basename)(module.file);
        const min_js = (0, sys_1.rename)(name, { ext: ".min.js" });
        const min_js_map = (0, sys_1.rename)(name, { ext: ".min.js.map" });
        const minify_opts = {
            ecma,
            format: {
                comments: /^!|copyright|license|\(c\)/i,
                // https://github.com/terser/terser/issues/410
                ascii_only: true,
            },
            sourceMap: {
                filename: (0, path_1.basename)(min_js),
                url: (0, path_1.basename)(min_js_map),
            },
        };
        try {
            const { code, map } = await terser.minify(source, minify_opts);
            return {
                min_source: code ?? "",
                min_map: typeof map === "string" ? map : undefined,
            };
        }
        catch (error) {
            throw new error_1.BuildError("linker", `${error}`);
        }
    }
    exports.minify = minify;
    
},
/* terser/dist/bundle.min.js */ function _(require, module, exports, __esModule, __esExport) {
    (function (global, factory) {
        typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require(46) /* @jridgewell/source-map */) :
            typeof define === 'function' && define.amd ? define(['exports', '@jridgewell/source-map'], factory) :
                (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.Terser = {}, global.sourceMap));
    })(this, (function (exports, sourceMap) {
        'use strict';
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        function characters(str) {
            return str.split("");
        }
        function member(name, array) {
            return array.includes(name);
        }
        class DefaultsError extends Error {
            constructor(msg, defs) {
                super();
                this.name = "DefaultsError";
                this.message = msg;
                this.defs = defs;
            }
        }
        function defaults(args, defs, croak) {
            if (args === true) {
                args = {};
            }
            else if (args != null && typeof args === "object") {
                args = { ...args };
            }
            const ret = args || {};
            if (croak)
                for (const i in ret)
                    if (HOP(ret, i) && !HOP(defs, i)) {
                        throw new DefaultsError("`" + i + "` is not a supported option", defs);
                    }
            for (const i in defs)
                if (HOP(defs, i)) {
                    if (!args || !HOP(args, i)) {
                        ret[i] = defs[i];
                    }
                    else if (i === "ecma") {
                        let ecma = args[i] | 0;
                        if (ecma > 5 && ecma < 2015)
                            ecma += 2009;
                        ret[i] = ecma;
                    }
                    else {
                        ret[i] = (args && HOP(args, i)) ? args[i] : defs[i];
                    }
                }
            return ret;
        }
        function noop() { }
        function return_false() { return false; }
        function return_true() { return true; }
        function return_this() { return this; }
        function return_null() { return null; }
        var MAP = (function () {
            function MAP(a, tw, allow_splicing = true) {
                const new_a = [];
                for (let i = 0; i < a.length; ++i) {
                    let item = a[i];
                    let ret = item.transform(tw, allow_splicing);
                    if (ret instanceof AST_Node) {
                        new_a.push(ret);
                    }
                    else if (ret instanceof Splice) {
                        new_a.push(...ret.v);
                    }
                }
                return new_a;
            }
            MAP.splice = function (val) { return new Splice(val); };
            MAP.skip = {};
            function Splice(val) { this.v = val; }
            return MAP;
        })();
        function make_node(ctor, orig, props) {
            if (!props)
                props = {};
            if (orig) {
                if (!props.start)
                    props.start = orig.start;
                if (!props.end)
                    props.end = orig.end;
            }
            return new ctor(props);
        }
        function push_uniq(array, el) {
            if (!array.includes(el))
                array.push(el);
        }
        function string_template(text, props) {
            return text.replace(/{(.+?)}/g, function (str, p) {
                return props && props[p];
            });
        }
        function remove(array, el) {
            for (var i = array.length; --i >= 0;) {
                if (array[i] === el)
                    array.splice(i, 1);
            }
        }
        function mergeSort(array, cmp) {
            if (array.length < 2)
                return array.slice();
            function merge(a, b) {
                var r = [], ai = 0, bi = 0, i = 0;
                while (ai < a.length && bi < b.length) {
                    cmp(a[ai], b[bi]) <= 0
                        ? r[i++] = a[ai++]
                        : r[i++] = b[bi++];
                }
                if (ai < a.length)
                    r.push.apply(r, a.slice(ai));
                if (bi < b.length)
                    r.push.apply(r, b.slice(bi));
                return r;
            }
            function _ms(a) {
                if (a.length <= 1)
                    return a;
                var m = Math.floor(a.length / 2), left = a.slice(0, m), right = a.slice(m);
                left = _ms(left);
                right = _ms(right);
                return merge(left, right);
            }
            return _ms(array);
        }
        function makePredicate(words) {
            if (!Array.isArray(words))
                words = words.split(" ");
            return new Set(words.sort());
        }
        function map_add(map, key, value) {
            if (map.has(key)) {
                map.get(key).push(value);
            }
            else {
                map.set(key, [value]);
            }
        }
        function map_from_object(obj) {
            var map = new Map();
            for (var key in obj) {
                if (HOP(obj, key) && key.charAt(0) === "$") {
                    map.set(key.substr(1), obj[key]);
                }
            }
            return map;
        }
        function map_to_object(map) {
            var obj = Object.create(null);
            map.forEach(function (value, key) {
                obj["$" + key] = value;
            });
            return obj;
        }
        function HOP(obj, prop) {
            return Object.prototype.hasOwnProperty.call(obj, prop);
        }
        function keep_name(keep_setting, name) {
            return keep_setting === true
                || (keep_setting instanceof RegExp && keep_setting.test(name));
        }
        var lineTerminatorEscape = {
            "\0": "0",
            "\n": "n",
            "\r": "r",
            "\u2028": "u2028",
            "\u2029": "u2029",
        };
        function regexp_source_fix(source) {
            // V8 does not escape line terminators in regexp patterns in node 12
            // We'll also remove literal \0
            return source.replace(/[\0\n\r\u2028\u2029]/g, function (match, offset) {
                var escaped = source[offset - 1] == "\\"
                    && (source[offset - 2] != "\\"
                        || /(?:^|[^\\])(?:\\{2})*$/.test(source.slice(0, offset - 1)));
                return (escaped ? "" : "\\") + lineTerminatorEscape[match];
            });
        }
        // Subset of regexps that is not going to cause regexp based DDOS
        // https://owasp.org/www-community/attacks/Regular_expression_Denial_of_Service_-_ReDoS
        const re_safe_regexp = /^[\\/|\0\s\w^$.[\]()]*$/;
        /** Check if the regexp is safe for Terser to create without risking a RegExp DOS */
        const regexp_is_safe = (source) => re_safe_regexp.test(source);
        const all_flags = "dgimsuyv";
        function sort_regexp_flags(flags) {
            const existing_flags = new Set(flags.split(""));
            let out = "";
            for (const flag of all_flags) {
                if (existing_flags.has(flag)) {
                    out += flag;
                    existing_flags.delete(flag);
                }
            }
            if (existing_flags.size) {
                // Flags Terser doesn't know about
                existing_flags.forEach(flag => { out += flag; });
            }
            return out;
        }
        function has_annotation(node, annotation) {
            return node._annotations & annotation;
        }
        function set_annotation(node, annotation) {
            node._annotations |= annotation;
        }
        function clear_annotation(node, annotation) {
            node._annotations &= ~annotation;
        }
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
            Parser based on parse-js (http://marijn.haverbeke.nl/parse-js/).
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        var LATEST_RAW = ""; // Only used for numbers and template strings
        var TEMPLATE_RAWS = new Map(); // Raw template strings
        var KEYWORDS = "break case catch class const continue debugger default delete do else export extends finally for function if in instanceof let new return switch throw try typeof var void while with";
        var KEYWORDS_ATOM = "false null true";
        var RESERVED_WORDS = "enum import super this " + KEYWORDS_ATOM + " " + KEYWORDS;
        var ALL_RESERVED_WORDS = "implements interface package private protected public static " + RESERVED_WORDS;
        var KEYWORDS_BEFORE_EXPRESSION = "return new delete throw else case yield await";
        KEYWORDS = makePredicate(KEYWORDS);
        RESERVED_WORDS = makePredicate(RESERVED_WORDS);
        KEYWORDS_BEFORE_EXPRESSION = makePredicate(KEYWORDS_BEFORE_EXPRESSION);
        KEYWORDS_ATOM = makePredicate(KEYWORDS_ATOM);
        ALL_RESERVED_WORDS = makePredicate(ALL_RESERVED_WORDS);
        var OPERATOR_CHARS = makePredicate(characters("+-*&%=<>!?|~^"));
        var RE_NUM_LITERAL = /[0-9a-f]/i;
        var RE_HEX_NUMBER = /^0x[0-9a-f]+$/i;
        var RE_OCT_NUMBER = /^0[0-7]+$/;
        var RE_ES6_OCT_NUMBER = /^0o[0-7]+$/i;
        var RE_BIN_NUMBER = /^0b[01]+$/i;
        var RE_DEC_NUMBER = /^\d*\.?\d*(?:e[+-]?\d*(?:\d\.?|\.?\d)\d*)?$/i;
        var RE_BIG_INT = /^(0[xob])?[0-9a-f]+n$/i;
        var OPERATORS = makePredicate([
            "in",
            "instanceof",
            "typeof",
            "new",
            "void",
            "delete",
            "++",
            "--",
            "+",
            "-",
            "!",
            "~",
            "&",
            "|",
            "^",
            "*",
            "**",
            "/",
            "%",
            ">>",
            "<<",
            ">>>",
            "<",
            ">",
            "<=",
            ">=",
            "==",
            "===",
            "!=",
            "!==",
            "?",
            "=",
            "+=",
            "-=",
            "||=",
            "&&=",
            "??=",
            "/=",
            "*=",
            "**=",
            "%=",
            ">>=",
            "<<=",
            ">>>=",
            "|=",
            "^=",
            "&=",
            "&&",
            "??",
            "||",
        ]);
        var WHITESPACE_CHARS = makePredicate(characters(" \u00a0\n\r\t\f\u000b\u200b\u2000\u2001\u2002\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200a\u2028\u2029\u202f\u205f\u3000\uFEFF"));
        var NEWLINE_CHARS = makePredicate(characters("\n\r\u2028\u2029"));
        var PUNC_AFTER_EXPRESSION = makePredicate(characters(";]),:"));
        var PUNC_BEFORE_EXPRESSION = makePredicate(characters("[{(,;:"));
        var PUNC_CHARS = makePredicate(characters("[]{}(),;:"));
        /* -----[ Tokenizer ]----- */
        // surrogate safe regexps adapted from https://github.com/mathiasbynens/unicode-8.0.0/tree/89b412d8a71ecca9ed593d9e9fa073ab64acfebe/Binary_Property
        var UNICODE = {
            ID_Start: /[$A-Z_a-z\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u08A0-\u08B4\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0AF9\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58-\u0C5A\u0C60\u0C61\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D5F-\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2118-\u211D\u2124\u2126\u2128\u212A-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303C\u3041-\u3096\u309B-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FD5\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6EF\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AD\uA7B0-\uA7B7\uA7F7-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA8FD\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uA9E0-\uA9E4\uA9E6-\uA9EF\uA9FA-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDD40-\uDD74\uDE80-\uDE9C\uDEA0-\uDED0\uDF00-\uDF1F\uDF30-\uDF4A\uDF50-\uDF75\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF\uDFD1-\uDFD5]|\uD801[\uDC00-\uDC9D\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC60-\uDC76\uDC80-\uDC9E\uDCE0-\uDCF2\uDCF4\uDCF5\uDD00-\uDD15\uDD20-\uDD39\uDD80-\uDDB7\uDDBE\uDDBF\uDE00\uDE10-\uDE13\uDE15-\uDE17\uDE19-\uDE33\uDE60-\uDE7C\uDE80-\uDE9C\uDEC0-\uDEC7\uDEC9-\uDEE4\uDF00-\uDF35\uDF40-\uDF55\uDF60-\uDF72\uDF80-\uDF91]|\uD803[\uDC00-\uDC48\uDC80-\uDCB2\uDCC0-\uDCF2]|\uD804[\uDC03-\uDC37\uDC83-\uDCAF\uDCD0-\uDCE8\uDD03-\uDD26\uDD50-\uDD72\uDD76\uDD83-\uDDB2\uDDC1-\uDDC4\uDDDA\uDDDC\uDE00-\uDE11\uDE13-\uDE2B\uDE80-\uDE86\uDE88\uDE8A-\uDE8D\uDE8F-\uDE9D\uDE9F-\uDEA8\uDEB0-\uDEDE\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3D\uDF50\uDF5D-\uDF61]|\uD805[\uDC80-\uDCAF\uDCC4\uDCC5\uDCC7\uDD80-\uDDAE\uDDD8-\uDDDB\uDE00-\uDE2F\uDE44\uDE80-\uDEAA\uDF00-\uDF19]|\uD806[\uDCA0-\uDCDF\uDCFF\uDEC0-\uDEF8]|\uD808[\uDC00-\uDF99]|\uD809[\uDC00-\uDC6E\uDC80-\uDD43]|[\uD80C\uD840-\uD868\uD86A-\uD86C\uD86F-\uD872][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD811[\uDC00-\uDE46]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDED0-\uDEED\uDF00-\uDF2F\uDF40-\uDF43\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDF00-\uDF44\uDF50\uDF93-\uDF9F]|\uD82C[\uDC00\uDC01]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB]|\uD83A[\uDC00-\uDCC4]|\uD83B[\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD869[\uDC00-\uDED6\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D\uDC20-\uDFFF]|\uD873[\uDC00-\uDEA1]|\uD87E[\uDC00-\uDE1D]/,
            ID_Continue: /(?:[$0-9A-Z_a-z\xAA\xB5\xB7\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0300-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u0483-\u0487\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u0591-\u05BD\u05BF\u05C1\u05C2\u05C4\u05C5\u05C7\u05D0-\u05EA\u05F0-\u05F2\u0610-\u061A\u0620-\u0669\u066E-\u06D3\u06D5-\u06DC\u06DF-\u06E8\u06EA-\u06FC\u06FF\u0710-\u074A\u074D-\u07B1\u07C0-\u07F5\u07FA\u0800-\u082D\u0840-\u085B\u08A0-\u08B4\u08E3-\u0963\u0966-\u096F\u0971-\u0983\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BC-\u09C4\u09C7\u09C8\u09CB-\u09CE\u09D7\u09DC\u09DD\u09DF-\u09E3\u09E6-\u09F1\u0A01-\u0A03\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A3C\u0A3E-\u0A42\u0A47\u0A48\u0A4B-\u0A4D\u0A51\u0A59-\u0A5C\u0A5E\u0A66-\u0A75\u0A81-\u0A83\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABC-\u0AC5\u0AC7-\u0AC9\u0ACB-\u0ACD\u0AD0\u0AE0-\u0AE3\u0AE6-\u0AEF\u0AF9\u0B01-\u0B03\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3C-\u0B44\u0B47\u0B48\u0B4B-\u0B4D\u0B56\u0B57\u0B5C\u0B5D\u0B5F-\u0B63\u0B66-\u0B6F\u0B71\u0B82\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BBE-\u0BC2\u0BC6-\u0BC8\u0BCA-\u0BCD\u0BD0\u0BD7\u0BE6-\u0BEF\u0C00-\u0C03\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D-\u0C44\u0C46-\u0C48\u0C4A-\u0C4D\u0C55\u0C56\u0C58-\u0C5A\u0C60-\u0C63\u0C66-\u0C6F\u0C81-\u0C83\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBC-\u0CC4\u0CC6-\u0CC8\u0CCA-\u0CCD\u0CD5\u0CD6\u0CDE\u0CE0-\u0CE3\u0CE6-\u0CEF\u0CF1\u0CF2\u0D01-\u0D03\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D-\u0D44\u0D46-\u0D48\u0D4A-\u0D4E\u0D57\u0D5F-\u0D63\u0D66-\u0D6F\u0D7A-\u0D7F\u0D82\u0D83\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0DCA\u0DCF-\u0DD4\u0DD6\u0DD8-\u0DDF\u0DE6-\u0DEF\u0DF2\u0DF3\u0E01-\u0E3A\u0E40-\u0E4E\u0E50-\u0E59\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB9\u0EBB-\u0EBD\u0EC0-\u0EC4\u0EC6\u0EC8-\u0ECD\u0ED0-\u0ED9\u0EDC-\u0EDF\u0F00\u0F18\u0F19\u0F20-\u0F29\u0F35\u0F37\u0F39\u0F3E-\u0F47\u0F49-\u0F6C\u0F71-\u0F84\u0F86-\u0F97\u0F99-\u0FBC\u0FC6\u1000-\u1049\u1050-\u109D\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u135D-\u135F\u1369-\u1371\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1714\u1720-\u1734\u1740-\u1753\u1760-\u176C\u176E-\u1770\u1772\u1773\u1780-\u17D3\u17D7\u17DC\u17DD\u17E0-\u17E9\u180B-\u180D\u1810-\u1819\u1820-\u1877\u1880-\u18AA\u18B0-\u18F5\u1900-\u191E\u1920-\u192B\u1930-\u193B\u1946-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u19D0-\u19DA\u1A00-\u1A1B\u1A20-\u1A5E\u1A60-\u1A7C\u1A7F-\u1A89\u1A90-\u1A99\u1AA7\u1AB0-\u1ABD\u1B00-\u1B4B\u1B50-\u1B59\u1B6B-\u1B73\u1B80-\u1BF3\u1C00-\u1C37\u1C40-\u1C49\u1C4D-\u1C7D\u1CD0-\u1CD2\u1CD4-\u1CF6\u1CF8\u1CF9\u1D00-\u1DF5\u1DFC-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u200C\u200D\u203F\u2040\u2054\u2071\u207F\u2090-\u209C\u20D0-\u20DC\u20E1\u20E5-\u20F0\u2102\u2107\u210A-\u2113\u2115\u2118-\u211D\u2124\u2126\u2128\u212A-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D7F-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2DE0-\u2DFF\u3005-\u3007\u3021-\u302F\u3031-\u3035\u3038-\u303C\u3041-\u3096\u3099-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FD5\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA62B\uA640-\uA66F\uA674-\uA67D\uA67F-\uA6F1\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AD\uA7B0-\uA7B7\uA7F7-\uA827\uA840-\uA873\uA880-\uA8C4\uA8D0-\uA8D9\uA8E0-\uA8F7\uA8FB\uA8FD\uA900-\uA92D\uA930-\uA953\uA960-\uA97C\uA980-\uA9C0\uA9CF-\uA9D9\uA9E0-\uA9FE\uAA00-\uAA36\uAA40-\uAA4D\uAA50-\uAA59\uAA60-\uAA76\uAA7A-\uAAC2\uAADB-\uAADD\uAAE0-\uAAEF\uAAF2-\uAAF6\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABEA\uABEC\uABED\uABF0-\uABF9\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE00-\uFE0F\uFE20-\uFE2F\uFE33\uFE34\uFE4D-\uFE4F\uFE70-\uFE74\uFE76-\uFEFC\uFF10-\uFF19\uFF21-\uFF3A\uFF3F\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDD40-\uDD74\uDDFD\uDE80-\uDE9C\uDEA0-\uDED0\uDEE0\uDF00-\uDF1F\uDF30-\uDF4A\uDF50-\uDF7A\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF\uDFD1-\uDFD5]|\uD801[\uDC00-\uDC9D\uDCA0-\uDCA9\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC60-\uDC76\uDC80-\uDC9E\uDCE0-\uDCF2\uDCF4\uDCF5\uDD00-\uDD15\uDD20-\uDD39\uDD80-\uDDB7\uDDBE\uDDBF\uDE00-\uDE03\uDE05\uDE06\uDE0C-\uDE13\uDE15-\uDE17\uDE19-\uDE33\uDE38-\uDE3A\uDE3F\uDE60-\uDE7C\uDE80-\uDE9C\uDEC0-\uDEC7\uDEC9-\uDEE6\uDF00-\uDF35\uDF40-\uDF55\uDF60-\uDF72\uDF80-\uDF91]|\uD803[\uDC00-\uDC48\uDC80-\uDCB2\uDCC0-\uDCF2]|\uD804[\uDC00-\uDC46\uDC66-\uDC6F\uDC7F-\uDCBA\uDCD0-\uDCE8\uDCF0-\uDCF9\uDD00-\uDD34\uDD36-\uDD3F\uDD50-\uDD73\uDD76\uDD80-\uDDC4\uDDCA-\uDDCC\uDDD0-\uDDDA\uDDDC\uDE00-\uDE11\uDE13-\uDE37\uDE80-\uDE86\uDE88\uDE8A-\uDE8D\uDE8F-\uDE9D\uDE9F-\uDEA8\uDEB0-\uDEEA\uDEF0-\uDEF9\uDF00-\uDF03\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3C-\uDF44\uDF47\uDF48\uDF4B-\uDF4D\uDF50\uDF57\uDF5D-\uDF63\uDF66-\uDF6C\uDF70-\uDF74]|\uD805[\uDC80-\uDCC5\uDCC7\uDCD0-\uDCD9\uDD80-\uDDB5\uDDB8-\uDDC0\uDDD8-\uDDDD\uDE00-\uDE40\uDE44\uDE50-\uDE59\uDE80-\uDEB7\uDEC0-\uDEC9\uDF00-\uDF19\uDF1D-\uDF2B\uDF30-\uDF39]|\uD806[\uDCA0-\uDCE9\uDCFF\uDEC0-\uDEF8]|\uD808[\uDC00-\uDF99]|\uD809[\uDC00-\uDC6E\uDC80-\uDD43]|[\uD80C\uD840-\uD868\uD86A-\uD86C\uD86F-\uD872][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD811[\uDC00-\uDE46]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDE60-\uDE69\uDED0-\uDEED\uDEF0-\uDEF4\uDF00-\uDF36\uDF40-\uDF43\uDF50-\uDF59\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDF00-\uDF44\uDF50-\uDF7E\uDF8F-\uDF9F]|\uD82C[\uDC00\uDC01]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99\uDC9D\uDC9E]|\uD834[\uDD65-\uDD69\uDD6D-\uDD72\uDD7B-\uDD82\uDD85-\uDD8B\uDDAA-\uDDAD\uDE42-\uDE44]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB\uDFCE-\uDFFF]|\uD836[\uDE00-\uDE36\uDE3B-\uDE6C\uDE75\uDE84\uDE9B-\uDE9F\uDEA1-\uDEAF]|\uD83A[\uDC00-\uDCC4\uDCD0-\uDCD6]|\uD83B[\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD869[\uDC00-\uDED6\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D\uDC20-\uDFFF]|\uD873[\uDC00-\uDEA1]|\uD87E[\uDC00-\uDE1D]|\uDB40[\uDD00-\uDDEF])+/,
        };
        function get_full_char(str, pos) {
            if (is_surrogate_pair_head(str.charCodeAt(pos))) {
                if (is_surrogate_pair_tail(str.charCodeAt(pos + 1))) {
                    return str.charAt(pos) + str.charAt(pos + 1);
                }
            }
            else if (is_surrogate_pair_tail(str.charCodeAt(pos))) {
                if (is_surrogate_pair_head(str.charCodeAt(pos - 1))) {
                    return str.charAt(pos - 1) + str.charAt(pos);
                }
            }
            return str.charAt(pos);
        }
        function get_full_char_code(str, pos) {
            // https://en.wikipedia.org/wiki/Universal_Character_Set_characters#Surrogates
            if (is_surrogate_pair_head(str.charCodeAt(pos))) {
                return 0x10000 + (str.charCodeAt(pos) - 0xd800 << 10) + str.charCodeAt(pos + 1) - 0xdc00;
            }
            return str.charCodeAt(pos);
        }
        function get_full_char_length(str) {
            var surrogates = 0;
            for (var i = 0; i < str.length; i++) {
                if (is_surrogate_pair_head(str.charCodeAt(i)) && is_surrogate_pair_tail(str.charCodeAt(i + 1))) {
                    surrogates++;
                    i++;
                }
            }
            return str.length - surrogates;
        }
        function from_char_code(code) {
            // Based on https://github.com/mathiasbynens/String.fromCodePoint/blob/master/fromcodepoint.js
            if (code > 0xFFFF) {
                code -= 0x10000;
                return (String.fromCharCode((code >> 10) + 0xD800) +
                    String.fromCharCode((code % 0x400) + 0xDC00));
            }
            return String.fromCharCode(code);
        }
        function is_surrogate_pair_head(code) {
            return code >= 0xd800 && code <= 0xdbff;
        }
        function is_surrogate_pair_tail(code) {
            return code >= 0xdc00 && code <= 0xdfff;
        }
        function is_digit(code) {
            return code >= 48 && code <= 57;
        }
        function is_identifier_start(ch) {
            return UNICODE.ID_Start.test(ch);
        }
        function is_identifier_char(ch) {
            return UNICODE.ID_Continue.test(ch);
        }
        const BASIC_IDENT = /^[a-z_$][a-z0-9_$]*$/i;
        function is_basic_identifier_string(str) {
            return BASIC_IDENT.test(str);
        }
        function is_identifier_string(str, allow_surrogates) {
            if (BASIC_IDENT.test(str)) {
                return true;
            }
            if (!allow_surrogates && /[\ud800-\udfff]/.test(str)) {
                return false;
            }
            var match = UNICODE.ID_Start.exec(str);
            if (!match || match.index !== 0) {
                return false;
            }
            str = str.slice(match[0].length);
            if (!str) {
                return true;
            }
            match = UNICODE.ID_Continue.exec(str);
            return !!match && match[0].length === str.length;
        }
        function parse_js_number(num, allow_e = true) {
            if (!allow_e && num.includes("e")) {
                return NaN;
            }
            if (RE_HEX_NUMBER.test(num)) {
                return parseInt(num.substr(2), 16);
            }
            else if (RE_OCT_NUMBER.test(num)) {
                return parseInt(num.substr(1), 8);
            }
            else if (RE_ES6_OCT_NUMBER.test(num)) {
                return parseInt(num.substr(2), 8);
            }
            else if (RE_BIN_NUMBER.test(num)) {
                return parseInt(num.substr(2), 2);
            }
            else if (RE_DEC_NUMBER.test(num)) {
                return parseFloat(num);
            }
            else {
                var val = parseFloat(num);
                if (val == num)
                    return val;
            }
        }
        class JS_Parse_Error extends Error {
            constructor(message, filename, line, col, pos) {
                super();
                this.name = "SyntaxError";
                this.message = message;
                this.filename = filename;
                this.line = line;
                this.col = col;
                this.pos = pos;
            }
        }
        function js_error(message, filename, line, col, pos) {
            throw new JS_Parse_Error(message, filename, line, col, pos);
        }
        function is_token(token, type, val) {
            return token.type == type && (val == null || token.value == val);
        }
        var EX_EOF = {};
        function tokenizer($TEXT, filename, html5_comments, shebang) {
            var S = {
                text: $TEXT,
                filename: filename,
                pos: 0,
                tokpos: 0,
                line: 1,
                tokline: 0,
                col: 0,
                tokcol: 0,
                newline_before: false,
                regex_allowed: false,
                brace_counter: 0,
                template_braces: [],
                comments_before: [],
                directives: {},
                directive_stack: []
            };
            function peek() { return get_full_char(S.text, S.pos); }
            // Used because parsing ?. involves a lookahead for a digit
            function is_option_chain_op() {
                const must_be_dot = S.text.charCodeAt(S.pos + 1) === 46;
                if (!must_be_dot)
                    return false;
                const cannot_be_digit = S.text.charCodeAt(S.pos + 2);
                return cannot_be_digit < 48 || cannot_be_digit > 57;
            }
            function next(signal_eof, in_string) {
                var ch = get_full_char(S.text, S.pos++);
                if (signal_eof && !ch)
                    throw EX_EOF;
                if (NEWLINE_CHARS.has(ch)) {
                    S.newline_before = S.newline_before || !in_string;
                    ++S.line;
                    S.col = 0;
                    if (ch == "\r" && peek() == "\n") {
                        // treat a \r\n sequence as a single \n
                        ++S.pos;
                        ch = "\n";
                    }
                }
                else {
                    if (ch.length > 1) {
                        ++S.pos;
                        ++S.col;
                    }
                    ++S.col;
                }
                return ch;
            }
            function forward(i) {
                while (i--)
                    next();
            }
            function looking_at(str) {
                return S.text.substr(S.pos, str.length) == str;
            }
            function find_eol() {
                var text = S.text;
                for (var i = S.pos, n = S.text.length; i < n; ++i) {
                    var ch = text[i];
                    if (NEWLINE_CHARS.has(ch))
                        return i;
                }
                return -1;
            }
            function find(what, signal_eof) {
                var pos = S.text.indexOf(what, S.pos);
                if (signal_eof && pos == -1)
                    throw EX_EOF;
                return pos;
            }
            function start_token() {
                S.tokline = S.line;
                S.tokcol = S.col;
                S.tokpos = S.pos;
            }
            var prev_was_dot = false;
            var previous_token = null;
            function token(type, value, is_comment) {
                S.regex_allowed = ((type == "operator" && !UNARY_POSTFIX.has(value)) ||
                    (type == "keyword" && KEYWORDS_BEFORE_EXPRESSION.has(value)) ||
                    (type == "punc" && PUNC_BEFORE_EXPRESSION.has(value))) ||
                    (type == "arrow");
                if (type == "punc" && (value == "." || value == "?.")) {
                    prev_was_dot = true;
                }
                else if (!is_comment) {
                    prev_was_dot = false;
                }
                const line = S.tokline;
                const col = S.tokcol;
                const pos = S.tokpos;
                const nlb = S.newline_before;
                const file = filename;
                let comments_before = [];
                let comments_after = [];
                if (!is_comment) {
                    comments_before = S.comments_before;
                    comments_after = S.comments_before = [];
                }
                S.newline_before = false;
                const tok = new AST_Token(type, value, line, col, pos, nlb, comments_before, comments_after, file);
                if (!is_comment)
                    previous_token = tok;
                return tok;
            }
            function skip_whitespace() {
                while (WHITESPACE_CHARS.has(peek()))
                    next();
            }
            function read_while(pred) {
                var ret = "", ch, i = 0;
                while ((ch = peek()) && pred(ch, i++))
                    ret += next();
                return ret;
            }
            function parse_error(err) {
                js_error(err, filename, S.tokline, S.tokcol, S.tokpos);
            }
            function read_num(prefix) {
                var has_e = false, after_e = false, has_x = false, has_dot = prefix == ".", is_big_int = false, numeric_separator = false;
                var num = read_while(function (ch, i) {
                    if (is_big_int)
                        return false;
                    var code = ch.charCodeAt(0);
                    switch (code) {
                        case 95: // _
                            return (numeric_separator = true);
                        case 98:
                        case 66: // bB
                            return (has_x = true); // Can occur in hex sequence, don't return false yet
                        case 111:
                        case 79: // oO
                        case 120:
                        case 88: // xX
                            return has_x ? false : (has_x = true);
                        case 101:
                        case 69: // eE
                            return has_x ? true : has_e ? false : (has_e = after_e = true);
                        case 45: // -
                            return after_e || (i == 0 && !prefix);
                        case 43: // +
                            return after_e;
                        case (after_e = false, 46): // .
                            return (!has_dot && !has_x && !has_e) ? (has_dot = true) : false;
                    }
                    if (ch === "n") {
                        is_big_int = true;
                        return true;
                    }
                    return RE_NUM_LITERAL.test(ch);
                });
                if (prefix)
                    num = prefix + num;
                LATEST_RAW = num;
                if (RE_OCT_NUMBER.test(num) && next_token.has_directive("use strict")) {
                    parse_error("Legacy octal literals are not allowed in strict mode");
                }
                if (numeric_separator) {
                    if (num.endsWith("_")) {
                        parse_error("Numeric separators are not allowed at the end of numeric literals");
                    }
                    else if (num.includes("__")) {
                        parse_error("Only one underscore is allowed as numeric separator");
                    }
                    num = num.replace(/_/g, "");
                }
                if (num.endsWith("n")) {
                    const without_n = num.slice(0, -1);
                    const allow_e = RE_HEX_NUMBER.test(without_n);
                    const valid = parse_js_number(without_n, allow_e);
                    if (!has_dot && RE_BIG_INT.test(num) && !isNaN(valid))
                        return token("big_int", without_n);
                    parse_error("Invalid or unexpected token");
                }
                var valid = parse_js_number(num);
                if (!isNaN(valid)) {
                    return token("num", valid);
                }
                else {
                    parse_error("Invalid syntax: " + num);
                }
            }
            function is_octal(ch) {
                return ch >= "0" && ch <= "7";
            }
            function read_escaped_char(in_string, strict_hex, template_string) {
                var ch = next(true, in_string);
                switch (ch.charCodeAt(0)) {
                    case 110: return "\n";
                    case 114: return "\r";
                    case 116: return "\t";
                    case 98: return "\b";
                    case 118: return "\u000b"; // \v
                    case 102: return "\f";
                    case 120: return String.fromCharCode(hex_bytes(2, strict_hex)); // \x
                    case 117: // \u
                        if (peek() == "{") {
                            next(true);
                            if (peek() === "}")
                                parse_error("Expecting hex-character between {}");
                            while (peek() == "0")
                                next(true); // No significance
                            var result, length = find("}", true) - S.pos;
                            // Avoid 32 bit integer overflow (1 << 32 === 1)
                            // We know first character isn't 0 and thus out of range anyway
                            if (length > 6 || (result = hex_bytes(length, strict_hex)) > 0x10FFFF) {
                                parse_error("Unicode reference out of bounds");
                            }
                            next(true);
                            return from_char_code(result);
                        }
                        return String.fromCharCode(hex_bytes(4, strict_hex));
                    case 10: return ""; // newline
                    case 13: // \r
                        if (peek() == "\n") { // DOS newline
                            next(true, in_string);
                            return "";
                        }
                }
                if (is_octal(ch)) {
                    if (template_string && strict_hex) {
                        const represents_null_character = ch === "0" && !is_octal(peek());
                        if (!represents_null_character) {
                            parse_error("Octal escape sequences are not allowed in template strings");
                        }
                    }
                    return read_octal_escape_sequence(ch, strict_hex);
                }
                return ch;
            }
            function read_octal_escape_sequence(ch, strict_octal) {
                // Read
                var p = peek();
                if (p >= "0" && p <= "7") {
                    ch += next(true);
                    if (ch[0] <= "3" && (p = peek()) >= "0" && p <= "7")
                        ch += next(true);
                }
                // Parse
                if (ch === "0")
                    return "\0";
                if (ch.length > 0 && next_token.has_directive("use strict") && strict_octal)
                    parse_error("Legacy octal escape sequences are not allowed in strict mode");
                return String.fromCharCode(parseInt(ch, 8));
            }
            function hex_bytes(n, strict_hex) {
                var num = 0;
                for (; n > 0; --n) {
                    if (!strict_hex && isNaN(parseInt(peek(), 16))) {
                        return parseInt(num, 16) || "";
                    }
                    var digit = next(true);
                    if (isNaN(parseInt(digit, 16)))
                        parse_error("Invalid hex-character pattern in string");
                    num += digit;
                }
                return parseInt(num, 16);
            }
            var read_string = with_eof_error("Unterminated string constant", function () {
                const start_pos = S.pos;
                var quote = next(), ret = [];
                for (;;) {
                    var ch = next(true, true);
                    if (ch == "\\")
                        ch = read_escaped_char(true, true);
                    else if (ch == "\r" || ch == "\n")
                        parse_error("Unterminated string constant");
                    else if (ch == quote)
                        break;
                    ret.push(ch);
                }
                var tok = token("string", ret.join(""));
                LATEST_RAW = S.text.slice(start_pos, S.pos);
                tok.quote = quote;
                return tok;
            });
            var read_template_characters = with_eof_error("Unterminated template", function (begin) {
                if (begin) {
                    S.template_braces.push(S.brace_counter);
                }
                var content = "", raw = "", ch, tok;
                next(true, true);
                while ((ch = next(true, true)) != "`") {
                    if (ch == "\r") {
                        if (peek() == "\n")
                            ++S.pos;
                        ch = "\n";
                    }
                    else if (ch == "$" && peek() == "{") {
                        next(true, true);
                        S.brace_counter++;
                        tok = token(begin ? "template_head" : "template_substitution", content);
                        TEMPLATE_RAWS.set(tok, raw);
                        tok.template_end = false;
                        return tok;
                    }
                    raw += ch;
                    if (ch == "\\") {
                        var tmp = S.pos;
                        var prev_is_tag = previous_token && (previous_token.type === "name" || previous_token.type === "punc" && (previous_token.value === ")" || previous_token.value === "]"));
                        ch = read_escaped_char(true, !prev_is_tag, true);
                        raw += S.text.substr(tmp, S.pos - tmp);
                    }
                    content += ch;
                }
                S.template_braces.pop();
                tok = token(begin ? "template_head" : "template_substitution", content);
                TEMPLATE_RAWS.set(tok, raw);
                tok.template_end = true;
                return tok;
            });
            function skip_line_comment(type) {
                var regex_allowed = S.regex_allowed;
                var i = find_eol(), ret;
                if (i == -1) {
                    ret = S.text.substr(S.pos);
                    S.pos = S.text.length;
                }
                else {
                    ret = S.text.substring(S.pos, i);
                    S.pos = i;
                }
                S.col = S.tokcol + (S.pos - S.tokpos);
                S.comments_before.push(token(type, ret, true));
                S.regex_allowed = regex_allowed;
                return next_token;
            }
            var skip_multiline_comment = with_eof_error("Unterminated multiline comment", function () {
                var regex_allowed = S.regex_allowed;
                var i = find("*/", true);
                var text = S.text.substring(S.pos, i).replace(/\r\n|\r|\u2028|\u2029/g, "\n");
                // update stream position
                forward(get_full_char_length(text) /* text length doesn't count \r\n as 2 char while S.pos - i does */ + 2);
                S.comments_before.push(token("comment2", text, true));
                S.newline_before = S.newline_before || text.includes("\n");
                S.regex_allowed = regex_allowed;
                return next_token;
            });
            var read_name = with_eof_error("Unterminated identifier name", function () {
                var name = [], ch, escaped = false;
                var read_escaped_identifier_char = function () {
                    escaped = true;
                    next();
                    if (peek() !== "u") {
                        parse_error("Expecting UnicodeEscapeSequence -- uXXXX or u{XXXX}");
                    }
                    return read_escaped_char(false, true);
                };
                // Read first character (ID_Start)
                if ((ch = peek()) === "\\") {
                    ch = read_escaped_identifier_char();
                    if (!is_identifier_start(ch)) {
                        parse_error("First identifier char is an invalid identifier char");
                    }
                }
                else if (is_identifier_start(ch)) {
                    next();
                }
                else {
                    return "";
                }
                name.push(ch);
                // Read ID_Continue
                while ((ch = peek()) != null) {
                    if ((ch = peek()) === "\\") {
                        ch = read_escaped_identifier_char();
                        if (!is_identifier_char(ch)) {
                            parse_error("Invalid escaped identifier char");
                        }
                    }
                    else {
                        if (!is_identifier_char(ch)) {
                            break;
                        }
                        next();
                    }
                    name.push(ch);
                }
                const name_str = name.join("");
                if (RESERVED_WORDS.has(name_str) && escaped) {
                    parse_error("Escaped characters are not allowed in keywords");
                }
                return name_str;
            });
            var read_regexp = with_eof_error("Unterminated regular expression", function (source) {
                var prev_backslash = false, ch, in_class = false;
                while ((ch = next(true)))
                    if (NEWLINE_CHARS.has(ch)) {
                        parse_error("Unexpected line terminator");
                    }
                    else if (prev_backslash) {
                        if (/^[\u0000-\u007F]$/.test(ch)) {
                            source += "\\" + ch;
                        }
                        else {
                            // Remove the useless slash before the escape, but only for characters that won't be added to regexp syntax
                            source += ch;
                        }
                        prev_backslash = false;
                    }
                    else if (ch == "[") {
                        in_class = true;
                        source += ch;
                    }
                    else if (ch == "]" && in_class) {
                        in_class = false;
                        source += ch;
                    }
                    else if (ch == "/" && !in_class) {
                        break;
                    }
                    else if (ch == "\\") {
                        prev_backslash = true;
                    }
                    else {
                        source += ch;
                    }
                const flags = read_name();
                return token("regexp", "/" + source + "/" + flags);
            });
            function read_operator(prefix) {
                function grow(op) {
                    if (!peek())
                        return op;
                    var bigger = op + peek();
                    if (OPERATORS.has(bigger)) {
                        next();
                        return grow(bigger);
                    }
                    else {
                        return op;
                    }
                }
                return token("operator", grow(prefix || next()));
            }
            function handle_slash() {
                next();
                switch (peek()) {
                    case "/":
                        next();
                        return skip_line_comment("comment1");
                    case "*":
                        next();
                        return skip_multiline_comment();
                }
                return S.regex_allowed ? read_regexp("") : read_operator("/");
            }
            function handle_eq_sign() {
                next();
                if (peek() === ">") {
                    next();
                    return token("arrow", "=>");
                }
                else {
                    return read_operator("=");
                }
            }
            function handle_dot() {
                next();
                if (is_digit(peek().charCodeAt(0))) {
                    return read_num(".");
                }
                if (peek() === ".") {
                    next(); // Consume second dot
                    next(); // Consume third dot
                    return token("expand", "...");
                }
                return token("punc", ".");
            }
            function read_word() {
                var word = read_name();
                if (prev_was_dot)
                    return token("name", word);
                return KEYWORDS_ATOM.has(word) ? token("atom", word)
                    : !KEYWORDS.has(word) ? token("name", word)
                        : OPERATORS.has(word) ? token("operator", word)
                            : token("keyword", word);
            }
            function read_private_word() {
                next();
                return token("privatename", read_name());
            }
            function with_eof_error(eof_error, cont) {
                return function (x) {
                    try {
                        return cont(x);
                    }
                    catch (ex) {
                        if (ex === EX_EOF)
                            parse_error(eof_error);
                        else
                            throw ex;
                    }
                };
            }
            function next_token(force_regexp) {
                if (force_regexp != null)
                    return read_regexp(force_regexp);
                if (shebang && S.pos == 0 && looking_at("#!")) {
                    start_token();
                    forward(2);
                    skip_line_comment("comment5");
                }
                for (;;) {
                    skip_whitespace();
                    start_token();
                    if (html5_comments) {
                        if (looking_at("<!--")) {
                            forward(4);
                            skip_line_comment("comment3");
                            continue;
                        }
                        if (looking_at("-->") && S.newline_before) {
                            forward(3);
                            skip_line_comment("comment4");
                            continue;
                        }
                    }
                    var ch = peek();
                    if (!ch)
                        return token("eof");
                    var code = ch.charCodeAt(0);
                    switch (code) {
                        case 34:
                        case 39: return read_string();
                        case 46: return handle_dot();
                        case 47: {
                            var tok = handle_slash();
                            if (tok === next_token)
                                continue;
                            return tok;
                        }
                        case 61: return handle_eq_sign();
                        case 63: {
                            if (!is_option_chain_op())
                                break; // Handled below
                            next(); // ?
                            next(); // .
                            return token("punc", "?.");
                        }
                        case 96: return read_template_characters(true);
                        case 123:
                            S.brace_counter++;
                            break;
                        case 125:
                            S.brace_counter--;
                            if (S.template_braces.length > 0
                                && S.template_braces[S.template_braces.length - 1] === S.brace_counter)
                                return read_template_characters(false);
                            break;
                    }
                    if (is_digit(code))
                        return read_num();
                    if (PUNC_CHARS.has(ch))
                        return token("punc", next());
                    if (OPERATOR_CHARS.has(ch))
                        return read_operator();
                    if (code == 92 || is_identifier_start(ch))
                        return read_word();
                    if (code == 35)
                        return read_private_word();
                    break;
                }
                parse_error("Unexpected character '" + ch + "'");
            }
            next_token.next = next;
            next_token.peek = peek;
            next_token.context = function (nc) {
                if (nc)
                    S = nc;
                return S;
            };
            next_token.add_directive = function (directive) {
                S.directive_stack[S.directive_stack.length - 1].push(directive);
                if (S.directives[directive] === undefined) {
                    S.directives[directive] = 1;
                }
                else {
                    S.directives[directive]++;
                }
            };
            next_token.push_directives_stack = function () {
                S.directive_stack.push([]);
            };
            next_token.pop_directives_stack = function () {
                var directives = S.directive_stack[S.directive_stack.length - 1];
                for (var i = 0; i < directives.length; i++) {
                    S.directives[directives[i]]--;
                }
                S.directive_stack.pop();
            };
            next_token.has_directive = function (directive) {
                return S.directives[directive] > 0;
            };
            return next_token;
        }
        /* -----[ Parser (constants) ]----- */
        var UNARY_PREFIX = makePredicate([
            "typeof",
            "void",
            "delete",
            "--",
            "++",
            "!",
            "~",
            "-",
            "+"
        ]);
        var UNARY_POSTFIX = makePredicate(["--", "++"]);
        var ASSIGNMENT = makePredicate(["=", "+=", "-=", "??=", "&&=", "||=", "/=", "*=", "**=", "%=", ">>=", "<<=", ">>>=", "|=", "^=", "&="]);
        var LOGICAL_ASSIGNMENT = makePredicate(["??=", "&&=", "||="]);
        var PRECEDENCE = (function (a, ret) {
            for (var i = 0; i < a.length; ++i) {
                for (const op of a[i]) {
                    ret[op] = i + 1;
                }
            }
            return ret;
        })([
            ["||"],
            ["??"],
            ["&&"],
            ["|"],
            ["^"],
            ["&"],
            ["==", "===", "!=", "!=="],
            ["<", ">", "<=", ">=", "in", "instanceof"],
            [">>", "<<", ">>>"],
            ["+", "-"],
            ["*", "/", "%"],
            ["**"]
        ], {});
        var ATOMIC_START_TOKEN = makePredicate(["atom", "num", "big_int", "string", "regexp", "name"]);
        /* -----[ Parser ]----- */
        function parse($TEXT, options) {
            // maps start tokens to count of comments found outside of their parens
            // Example: /* I count */ ( /* I don't */ foo() )
            // Useful because comments_before property of call with parens outside
            // contains both comments inside and outside these parens. Used to find the
            const outer_comments_before_counts = new WeakMap();
            options = defaults(options, {
                bare_returns: false,
                ecma: null, // Legacy
                expression: false,
                filename: null,
                html5_comments: true,
                module: false,
                shebang: true,
                strict: false,
                toplevel: null,
            }, true);
            var S = {
                input: (typeof $TEXT == "string"
                    ? tokenizer($TEXT, options.filename, options.html5_comments, options.shebang)
                    : $TEXT),
                token: null,
                prev: null,
                peeked: null,
                in_function: 0,
                in_async: -1,
                in_generator: -1,
                in_directives: true,
                in_loop: 0,
                labels: []
            };
            S.token = next();
            function is(type, value) {
                return is_token(S.token, type, value);
            }
            function peek() { return S.peeked || (S.peeked = S.input()); }
            function next() {
                S.prev = S.token;
                if (!S.peeked)
                    peek();
                S.token = S.peeked;
                S.peeked = null;
                S.in_directives = S.in_directives && (S.token.type == "string" || is("punc", ";"));
                return S.token;
            }
            function prev() {
                return S.prev;
            }
            function croak(msg, line, col, pos) {
                var ctx = S.input.context();
                js_error(msg, ctx.filename, line != null ? line : ctx.tokline, col != null ? col : ctx.tokcol, pos != null ? pos : ctx.tokpos);
            }
            function token_error(token, msg) {
                croak(msg, token.line, token.col);
            }
            function unexpected(token) {
                if (token == null)
                    token = S.token;
                token_error(token, "Unexpected token: " + token.type + " (" + token.value + ")");
            }
            function expect_token(type, val) {
                if (is(type, val)) {
                    return next();
                }
                token_error(S.token, "Unexpected token " + S.token.type + " «" + S.token.value + "»" + ", expected " + type + " «" + val + "»");
            }
            function expect(punc) { return expect_token("punc", punc); }
            function has_newline_before(token) {
                return token.nlb || !token.comments_before.every((comment) => !comment.nlb);
            }
            function can_insert_semicolon() {
                return !options.strict
                    && (is("eof") || is("punc", "}") || has_newline_before(S.token));
            }
            function is_in_generator() {
                return S.in_generator === S.in_function;
            }
            function is_in_async() {
                return S.in_async === S.in_function;
            }
            function can_await() {
                return (S.in_async === S.in_function
                    || S.in_function === 0 && S.input.has_directive("use strict"));
            }
            function semicolon(optional) {
                if (is("punc", ";"))
                    next();
                else if (!optional && !can_insert_semicolon())
                    unexpected();
            }
            function parenthesised() {
                expect("(");
                var exp = expression(true);
                expect(")");
                return exp;
            }
            function embed_tokens(parser) {
                return function _embed_tokens_wrapper(...args) {
                    const start = S.token;
                    const expr = parser(...args);
                    expr.start = start;
                    expr.end = prev();
                    return expr;
                };
            }
            function handle_regexp() {
                if (is("operator", "/") || is("operator", "/=")) {
                    S.peeked = null;
                    S.token = S.input(S.token.value.substr(1)); // force regexp
                }
            }
            var statement = embed_tokens(function statement(is_export_default, is_for_body, is_if_body) {
                handle_regexp();
                switch (S.token.type) {
                    case "string":
                        if (S.in_directives) {
                            var token = peek();
                            if (!LATEST_RAW.includes("\\")
                                && (is_token(token, "punc", ";")
                                    || is_token(token, "punc", "}")
                                    || has_newline_before(token)
                                    || is_token(token, "eof"))) {
                                S.input.add_directive(S.token.value);
                            }
                            else {
                                S.in_directives = false;
                            }
                        }
                        var dir = S.in_directives, stat = simple_statement();
                        return dir && stat.body instanceof AST_String ? new AST_Directive(stat.body) : stat;
                    case "template_head":
                    case "num":
                    case "big_int":
                    case "regexp":
                    case "operator":
                    case "atom":
                        return simple_statement();
                    case "name":
                    case "privatename":
                        if (is("privatename") && !S.in_class)
                            croak("Private field must be used in an enclosing class");
                        if (S.token.value == "async" && is_token(peek(), "keyword", "function")) {
                            next();
                            next();
                            if (is_for_body) {
                                croak("functions are not allowed as the body of a loop");
                            }
                            return function_(AST_Defun, false, true, is_export_default);
                        }
                        if (S.token.value == "import" && !is_token(peek(), "punc", "(") && !is_token(peek(), "punc", ".")) {
                            next();
                            var node = import_statement();
                            semicolon();
                            return node;
                        }
                        return is_token(peek(), "punc", ":")
                            ? labeled_statement()
                            : simple_statement();
                    case "punc":
                        switch (S.token.value) {
                            case "{":
                                return new AST_BlockStatement({
                                    start: S.token,
                                    body: block_(),
                                    end: prev()
                                });
                            case "[":
                            case "(":
                                return simple_statement();
                            case ";":
                                S.in_directives = false;
                                next();
                                return new AST_EmptyStatement();
                            default:
                                unexpected();
                        }
                    case "keyword":
                        switch (S.token.value) {
                            case "break":
                                next();
                                return break_cont(AST_Break);
                            case "continue":
                                next();
                                return break_cont(AST_Continue);
                            case "debugger":
                                next();
                                semicolon();
                                return new AST_Debugger();
                            case "do":
                                next();
                                var body = in_loop(statement);
                                expect_token("keyword", "while");
                                var condition = parenthesised();
                                semicolon(true);
                                return new AST_Do({
                                    body: body,
                                    condition: condition
                                });
                            case "while":
                                next();
                                return new AST_While({
                                    condition: parenthesised(),
                                    body: in_loop(function () { return statement(false, true); })
                                });
                            case "for":
                                next();
                                return for_();
                            case "class":
                                next();
                                if (is_for_body) {
                                    croak("classes are not allowed as the body of a loop");
                                }
                                if (is_if_body) {
                                    croak("classes are not allowed as the body of an if");
                                }
                                return class_(AST_DefClass, is_export_default);
                            case "function":
                                next();
                                if (is_for_body) {
                                    croak("functions are not allowed as the body of a loop");
                                }
                                return function_(AST_Defun, false, false, is_export_default);
                            case "if":
                                next();
                                return if_();
                            case "return":
                                if (S.in_function == 0 && !options.bare_returns)
                                    croak("'return' outside of function");
                                next();
                                var value = null;
                                if (is("punc", ";")) {
                                    next();
                                }
                                else if (!can_insert_semicolon()) {
                                    value = expression(true);
                                    semicolon();
                                }
                                return new AST_Return({
                                    value: value
                                });
                            case "switch":
                                next();
                                return new AST_Switch({
                                    expression: parenthesised(),
                                    body: in_loop(switch_body_)
                                });
                            case "throw":
                                next();
                                if (has_newline_before(S.token))
                                    croak("Illegal newline after 'throw'");
                                var value = expression(true);
                                semicolon();
                                return new AST_Throw({
                                    value: value
                                });
                            case "try":
                                next();
                                return try_();
                            case "var":
                                next();
                                var node = var_();
                                semicolon();
                                return node;
                            case "let":
                                next();
                                var node = let_();
                                semicolon();
                                return node;
                            case "const":
                                next();
                                var node = const_();
                                semicolon();
                                return node;
                            case "with":
                                if (S.input.has_directive("use strict")) {
                                    croak("Strict mode may not include a with statement");
                                }
                                next();
                                return new AST_With({
                                    expression: parenthesised(),
                                    body: statement()
                                });
                            case "export":
                                if (!is_token(peek(), "punc", "(")) {
                                    next();
                                    var node = export_statement();
                                    if (is("punc", ";"))
                                        semicolon();
                                    return node;
                                }
                        }
                }
                unexpected();
            });
            function labeled_statement() {
                var label = as_symbol(AST_Label);
                if (label.name === "await" && is_in_async()) {
                    token_error(S.prev, "await cannot be used as label inside async function");
                }
                if (S.labels.some((l) => l.name === label.name)) {
                    // ECMA-262, 12.12: An ECMAScript program is considered
                    // syntactically incorrect if it contains a
                    // LabelledStatement that is enclosed by a
                    // LabelledStatement with the same Identifier as label.
                    croak("Label " + label.name + " defined twice");
                }
                expect(":");
                S.labels.push(label);
                var stat = statement();
                S.labels.pop();
                if (!(stat instanceof AST_IterationStatement)) {
                    // check for `continue` that refers to this label.
                    // those should be reported as syntax errors.
                    // https://github.com/mishoo/UglifyJS2/issues/287
                    label.references.forEach(function (ref) {
                        if (ref instanceof AST_Continue) {
                            ref = ref.label.start;
                            croak("Continue label `" + label.name + "` refers to non-IterationStatement.", ref.line, ref.col, ref.pos);
                        }
                    });
                }
                return new AST_LabeledStatement({ body: stat, label: label });
            }
            function simple_statement(tmp) {
                return new AST_SimpleStatement({ body: (tmp = expression(true), semicolon(), tmp) });
            }
            function break_cont(type) {
                var label = null, ldef;
                if (!can_insert_semicolon()) {
                    label = as_symbol(AST_LabelRef, true);
                }
                if (label != null) {
                    ldef = S.labels.find((l) => l.name === label.name);
                    if (!ldef)
                        croak("Undefined label " + label.name);
                    label.thedef = ldef;
                }
                else if (S.in_loop == 0)
                    croak(type.TYPE + " not inside a loop or switch");
                semicolon();
                var stat = new type({ label: label });
                if (ldef)
                    ldef.references.push(stat);
                return stat;
            }
            function for_() {
                var for_await_error = "`for await` invalid in this context";
                var await_tok = S.token;
                if (await_tok.type == "name" && await_tok.value == "await") {
                    if (!can_await()) {
                        token_error(await_tok, for_await_error);
                    }
                    next();
                }
                else {
                    await_tok = false;
                }
                expect("(");
                var init = null;
                if (!is("punc", ";")) {
                    init =
                        is("keyword", "var") ? (next(), var_(true)) :
                            is("keyword", "let") ? (next(), let_(true)) :
                                is("keyword", "const") ? (next(), const_(true)) :
                                    expression(true, true);
                    var is_in = is("operator", "in");
                    var is_of = is("name", "of");
                    if (await_tok && !is_of) {
                        token_error(await_tok, for_await_error);
                    }
                    if (is_in || is_of) {
                        if (init instanceof AST_Definitions) {
                            if (init.definitions.length > 1)
                                token_error(init.start, "Only one variable declaration allowed in for..in loop");
                        }
                        else if (!(is_assignable(init) || (init = to_destructuring(init)) instanceof AST_Destructuring)) {
                            token_error(init.start, "Invalid left-hand side in for..in loop");
                        }
                        next();
                        if (is_in) {
                            return for_in(init);
                        }
                        else {
                            return for_of(init, !!await_tok);
                        }
                    }
                }
                else if (await_tok) {
                    token_error(await_tok, for_await_error);
                }
                return regular_for(init);
            }
            function regular_for(init) {
                expect(";");
                var test = is("punc", ";") ? null : expression(true);
                expect(";");
                var step = is("punc", ")") ? null : expression(true);
                expect(")");
                return new AST_For({
                    init: init,
                    condition: test,
                    step: step,
                    body: in_loop(function () { return statement(false, true); })
                });
            }
            function for_of(init, is_await) {
                var lhs = init instanceof AST_Definitions ? init.definitions[0].name : null;
                var obj = expression(true);
                expect(")");
                return new AST_ForOf({
                    await: is_await,
                    init: init,
                    name: lhs,
                    object: obj,
                    body: in_loop(function () { return statement(false, true); })
                });
            }
            function for_in(init) {
                var obj = expression(true);
                expect(")");
                return new AST_ForIn({
                    init: init,
                    object: obj,
                    body: in_loop(function () { return statement(false, true); })
                });
            }
            var arrow_function = function (start, argnames, is_async) {
                if (has_newline_before(S.token)) {
                    croak("Unexpected newline before arrow (=>)");
                }
                expect_token("arrow", "=>");
                var body = _function_body(is("punc", "{"), false, is_async);
                var end = body instanceof Array && body.length ? body[body.length - 1].end :
                    body instanceof Array ? start :
                        body.end;
                return new AST_Arrow({
                    start: start,
                    end: end,
                    async: is_async,
                    argnames: argnames,
                    body: body
                });
            };
            var function_ = function (ctor, is_generator_property, is_async, is_export_default) {
                var in_statement = ctor === AST_Defun;
                var is_generator = is("operator", "*");
                if (is_generator) {
                    next();
                }
                var name = is("name") ? as_symbol(in_statement ? AST_SymbolDefun : AST_SymbolLambda) : null;
                if (in_statement && !name) {
                    if (is_export_default) {
                        ctor = AST_Function;
                    }
                    else {
                        unexpected();
                    }
                }
                if (name && ctor !== AST_Accessor && !(name instanceof AST_SymbolDeclaration))
                    unexpected(prev());
                var args = [];
                var body = _function_body(true, is_generator || is_generator_property, is_async, name, args);
                return new ctor({
                    start: args.start,
                    end: body.end,
                    is_generator: is_generator,
                    async: is_async,
                    name: name,
                    argnames: args,
                    body: body
                });
            };
            class UsedParametersTracker {
                constructor(is_parameter, strict, duplicates_ok = false) {
                    this.is_parameter = is_parameter;
                    this.duplicates_ok = duplicates_ok;
                    this.parameters = new Set();
                    this.duplicate = null;
                    this.default_assignment = false;
                    this.spread = false;
                    this.strict_mode = !!strict;
                }
                add_parameter(token) {
                    if (this.parameters.has(token.value)) {
                        if (this.duplicate === null) {
                            this.duplicate = token;
                        }
                        this.check_strict();
                    }
                    else {
                        this.parameters.add(token.value);
                        if (this.is_parameter) {
                            switch (token.value) {
                                case "arguments":
                                case "eval":
                                case "yield":
                                    if (this.strict_mode) {
                                        token_error(token, "Unexpected " + token.value + " identifier as parameter inside strict mode");
                                    }
                                    break;
                                default:
                                    if (RESERVED_WORDS.has(token.value)) {
                                        unexpected();
                                    }
                            }
                        }
                    }
                }
                mark_default_assignment(token) {
                    if (this.default_assignment === false) {
                        this.default_assignment = token;
                    }
                }
                mark_spread(token) {
                    if (this.spread === false) {
                        this.spread = token;
                    }
                }
                mark_strict_mode() {
                    this.strict_mode = true;
                }
                is_strict() {
                    return this.default_assignment !== false || this.spread !== false || this.strict_mode;
                }
                check_strict() {
                    if (this.is_strict() && this.duplicate !== null && !this.duplicates_ok) {
                        token_error(this.duplicate, "Parameter " + this.duplicate.value + " was used already");
                    }
                }
            }
            function parameters(params) {
                var used_parameters = new UsedParametersTracker(true, S.input.has_directive("use strict"));
                expect("(");
                while (!is("punc", ")")) {
                    var param = parameter(used_parameters);
                    params.push(param);
                    if (!is("punc", ")")) {
                        expect(",");
                    }
                    if (param instanceof AST_Expansion) {
                        break;
                    }
                }
                next();
            }
            function parameter(used_parameters, symbol_type) {
                var param;
                var expand = false;
                if (used_parameters === undefined) {
                    used_parameters = new UsedParametersTracker(true, S.input.has_directive("use strict"));
                }
                if (is("expand", "...")) {
                    expand = S.token;
                    used_parameters.mark_spread(S.token);
                    next();
                }
                param = binding_element(used_parameters, symbol_type);
                if (is("operator", "=") && expand === false) {
                    used_parameters.mark_default_assignment(S.token);
                    next();
                    param = new AST_DefaultAssign({
                        start: param.start,
                        left: param,
                        operator: "=",
                        right: expression(false),
                        end: S.token
                    });
                }
                if (expand !== false) {
                    if (!is("punc", ")")) {
                        unexpected();
                    }
                    param = new AST_Expansion({
                        start: expand,
                        expression: param,
                        end: expand
                    });
                }
                used_parameters.check_strict();
                return param;
            }
            function binding_element(used_parameters, symbol_type) {
                var elements = [];
                var first = true;
                var is_expand = false;
                var expand_token;
                var first_token = S.token;
                if (used_parameters === undefined) {
                    const strict = S.input.has_directive("use strict");
                    const duplicates_ok = symbol_type === AST_SymbolVar;
                    used_parameters = new UsedParametersTracker(false, strict, duplicates_ok);
                }
                symbol_type = symbol_type === undefined ? AST_SymbolFunarg : symbol_type;
                if (is("punc", "[")) {
                    next();
                    while (!is("punc", "]")) {
                        if (first) {
                            first = false;
                        }
                        else {
                            expect(",");
                        }
                        if (is("expand", "...")) {
                            is_expand = true;
                            expand_token = S.token;
                            used_parameters.mark_spread(S.token);
                            next();
                        }
                        if (is("punc")) {
                            switch (S.token.value) {
                                case ",":
                                    elements.push(new AST_Hole({
                                        start: S.token,
                                        end: S.token
                                    }));
                                    continue;
                                case "]": // Trailing comma after last element
                                    break;
                                case "[":
                                case "{":
                                    elements.push(binding_element(used_parameters, symbol_type));
                                    break;
                                default:
                                    unexpected();
                            }
                        }
                        else if (is("name")) {
                            used_parameters.add_parameter(S.token);
                            elements.push(as_symbol(symbol_type));
                        }
                        else {
                            croak("Invalid function parameter");
                        }
                        if (is("operator", "=") && is_expand === false) {
                            used_parameters.mark_default_assignment(S.token);
                            next();
                            elements[elements.length - 1] = new AST_DefaultAssign({
                                start: elements[elements.length - 1].start,
                                left: elements[elements.length - 1],
                                operator: "=",
                                right: expression(false),
                                end: S.token
                            });
                        }
                        if (is_expand) {
                            if (!is("punc", "]")) {
                                croak("Rest element must be last element");
                            }
                            elements[elements.length - 1] = new AST_Expansion({
                                start: expand_token,
                                expression: elements[elements.length - 1],
                                end: expand_token
                            });
                        }
                    }
                    expect("]");
                    used_parameters.check_strict();
                    return new AST_Destructuring({
                        start: first_token,
                        names: elements,
                        is_array: true,
                        end: prev()
                    });
                }
                else if (is("punc", "{")) {
                    next();
                    while (!is("punc", "}")) {
                        if (first) {
                            first = false;
                        }
                        else {
                            expect(",");
                        }
                        if (is("expand", "...")) {
                            is_expand = true;
                            expand_token = S.token;
                            used_parameters.mark_spread(S.token);
                            next();
                        }
                        if (is("name") && (is_token(peek(), "punc") || is_token(peek(), "operator")) && [",", "}", "="].includes(peek().value)) {
                            used_parameters.add_parameter(S.token);
                            var start = prev();
                            var value = as_symbol(symbol_type);
                            if (is_expand) {
                                elements.push(new AST_Expansion({
                                    start: expand_token,
                                    expression: value,
                                    end: value.end,
                                }));
                            }
                            else {
                                elements.push(new AST_ObjectKeyVal({
                                    start: start,
                                    key: value.name,
                                    value: value,
                                    end: value.end,
                                }));
                            }
                        }
                        else if (is("punc", "}")) {
                            continue; // Allow trailing hole
                        }
                        else {
                            var property_token = S.token;
                            var property = as_property_name();
                            if (property === null) {
                                unexpected(prev());
                            }
                            else if (prev().type === "name" && !is("punc", ":")) {
                                elements.push(new AST_ObjectKeyVal({
                                    start: prev(),
                                    key: property,
                                    value: new symbol_type({
                                        start: prev(),
                                        name: property,
                                        end: prev()
                                    }),
                                    end: prev()
                                }));
                            }
                            else {
                                expect(":");
                                elements.push(new AST_ObjectKeyVal({
                                    start: property_token,
                                    quote: property_token.quote,
                                    key: property,
                                    value: binding_element(used_parameters, symbol_type),
                                    end: prev()
                                }));
                            }
                        }
                        if (is_expand) {
                            if (!is("punc", "}")) {
                                croak("Rest element must be last element");
                            }
                        }
                        else if (is("operator", "=")) {
                            used_parameters.mark_default_assignment(S.token);
                            next();
                            elements[elements.length - 1].value = new AST_DefaultAssign({
                                start: elements[elements.length - 1].value.start,
                                left: elements[elements.length - 1].value,
                                operator: "=",
                                right: expression(false),
                                end: S.token
                            });
                        }
                    }
                    expect("}");
                    used_parameters.check_strict();
                    return new AST_Destructuring({
                        start: first_token,
                        names: elements,
                        is_array: false,
                        end: prev()
                    });
                }
                else if (is("name")) {
                    used_parameters.add_parameter(S.token);
                    return as_symbol(symbol_type);
                }
                else {
                    croak("Invalid function parameter");
                }
            }
            function params_or_seq_(allow_arrows, maybe_sequence) {
                var spread_token;
                var invalid_sequence;
                var trailing_comma;
                var a = [];
                expect("(");
                while (!is("punc", ")")) {
                    if (spread_token)
                        unexpected(spread_token);
                    if (is("expand", "...")) {
                        spread_token = S.token;
                        if (maybe_sequence)
                            invalid_sequence = S.token;
                        next();
                        a.push(new AST_Expansion({
                            start: prev(),
                            expression: expression(),
                            end: S.token,
                        }));
                    }
                    else {
                        a.push(expression());
                    }
                    if (!is("punc", ")")) {
                        expect(",");
                        if (is("punc", ")")) {
                            trailing_comma = prev();
                            if (maybe_sequence)
                                invalid_sequence = trailing_comma;
                        }
                    }
                }
                expect(")");
                if (allow_arrows && is("arrow", "=>")) {
                    if (spread_token && trailing_comma)
                        unexpected(trailing_comma);
                }
                else if (invalid_sequence) {
                    unexpected(invalid_sequence);
                }
                return a;
            }
            function _function_body(block, generator, is_async, name, args) {
                var loop = S.in_loop;
                var labels = S.labels;
                var current_generator = S.in_generator;
                var current_async = S.in_async;
                ++S.in_function;
                if (generator)
                    S.in_generator = S.in_function;
                if (is_async)
                    S.in_async = S.in_function;
                if (args)
                    parameters(args);
                if (block)
                    S.in_directives = true;
                S.in_loop = 0;
                S.labels = [];
                if (block) {
                    S.input.push_directives_stack();
                    var a = block_();
                    if (name)
                        _verify_symbol(name);
                    if (args)
                        args.forEach(_verify_symbol);
                    S.input.pop_directives_stack();
                }
                else {
                    var a = [new AST_Return({
                            start: S.token,
                            value: expression(false),
                            end: S.token
                        })];
                }
                --S.in_function;
                S.in_loop = loop;
                S.labels = labels;
                S.in_generator = current_generator;
                S.in_async = current_async;
                return a;
            }
            function _await_expression() {
                // Previous token must be "await" and not be interpreted as an identifier
                if (!can_await()) {
                    croak("Unexpected await expression outside async function", S.prev.line, S.prev.col, S.prev.pos);
                }
                // the await expression is parsed as a unary expression in Babel
                return new AST_Await({
                    start: prev(),
                    end: S.token,
                    expression: maybe_unary(true),
                });
            }
            function _yield_expression() {
                // Previous token must be keyword yield and not be interpret as an identifier
                if (!is_in_generator()) {
                    croak("Unexpected yield expression outside generator function", S.prev.line, S.prev.col, S.prev.pos);
                }
                var start = S.token;
                var star = false;
                var has_expression = true;
                // Attempt to get expression or star (and then the mandatory expression)
                // behind yield on the same line.
                //
                // If nothing follows on the same line of the yieldExpression,
                // it should default to the value `undefined` for yield to return.
                // In that case, the `undefined` stored as `null` in ast.
                //
                // Note 1: It isn't allowed for yield* to close without an expression
                // Note 2: If there is a nlb between yield and star, it is interpret as
                //         yield <explicit undefined> <inserted automatic semicolon> *
                if (can_insert_semicolon() ||
                    (is("punc") && PUNC_AFTER_EXPRESSION.has(S.token.value))) {
                    has_expression = false;
                }
                else if (is("operator", "*")) {
                    star = true;
                    next();
                }
                return new AST_Yield({
                    start: start,
                    is_star: star,
                    expression: has_expression ? expression() : null,
                    end: prev()
                });
            }
            function if_() {
                var cond = parenthesised(), body = statement(false, false, true), belse = null;
                if (is("keyword", "else")) {
                    next();
                    belse = statement(false, false, true);
                }
                return new AST_If({
                    condition: cond,
                    body: body,
                    alternative: belse
                });
            }
            function block_() {
                expect("{");
                var a = [];
                while (!is("punc", "}")) {
                    if (is("eof"))
                        unexpected();
                    a.push(statement());
                }
                next();
                return a;
            }
            function switch_body_() {
                expect("{");
                var a = [], cur = null, branch = null, tmp;
                while (!is("punc", "}")) {
                    if (is("eof"))
                        unexpected();
                    if (is("keyword", "case")) {
                        if (branch)
                            branch.end = prev();
                        cur = [];
                        branch = new AST_Case({
                            start: (tmp = S.token, next(), tmp),
                            expression: expression(true),
                            body: cur
                        });
                        a.push(branch);
                        expect(":");
                    }
                    else if (is("keyword", "default")) {
                        if (branch)
                            branch.end = prev();
                        cur = [];
                        branch = new AST_Default({
                            start: (tmp = S.token, next(), expect(":"), tmp),
                            body: cur
                        });
                        a.push(branch);
                    }
                    else {
                        if (!cur)
                            unexpected();
                        cur.push(statement());
                    }
                }
                if (branch)
                    branch.end = prev();
                next();
                return a;
            }
            function try_() {
                var body, bcatch = null, bfinally = null;
                body = new AST_TryBlock({
                    start: S.token,
                    body: block_(),
                    end: prev(),
                });
                if (is("keyword", "catch")) {
                    var start = S.token;
                    next();
                    if (is("punc", "{")) {
                        var name = null;
                    }
                    else {
                        expect("(");
                        var name = parameter(undefined, AST_SymbolCatch);
                        expect(")");
                    }
                    bcatch = new AST_Catch({
                        start: start,
                        argname: name,
                        body: block_(),
                        end: prev()
                    });
                }
                if (is("keyword", "finally")) {
                    var start = S.token;
                    next();
                    bfinally = new AST_Finally({
                        start: start,
                        body: block_(),
                        end: prev()
                    });
                }
                if (!bcatch && !bfinally)
                    croak("Missing catch/finally blocks");
                return new AST_Try({
                    body: body,
                    bcatch: bcatch,
                    bfinally: bfinally
                });
            }
            /**
             * var
             *   vardef1 = 2,
             *   vardef2 = 3;
             */
            function vardefs(no_in, kind) {
                var var_defs = [];
                var def;
                for (;;) {
                    var sym_type = kind === "var" ? AST_SymbolVar :
                        kind === "const" ? AST_SymbolConst :
                            kind === "let" ? AST_SymbolLet : null;
                    // var { a } = b
                    if (is("punc", "{") || is("punc", "[")) {
                        def = new AST_VarDef({
                            start: S.token,
                            name: binding_element(undefined, sym_type),
                            value: is("operator", "=") ? (expect_token("operator", "="), expression(false, no_in)) : null,
                            end: prev()
                        });
                    }
                    else {
                        def = new AST_VarDef({
                            start: S.token,
                            name: as_symbol(sym_type),
                            value: is("operator", "=")
                                ? (next(), expression(false, no_in))
                                : !no_in && kind === "const"
                                    ? croak("Missing initializer in const declaration") : null,
                            end: prev()
                        });
                        if (def.name.name == "import")
                            croak("Unexpected token: import");
                    }
                    var_defs.push(def);
                    if (!is("punc", ","))
                        break;
                    next();
                }
                return var_defs;
            }
            var var_ = function (no_in) {
                return new AST_Var({
                    start: prev(),
                    definitions: vardefs(no_in, "var"),
                    end: prev()
                });
            };
            var let_ = function (no_in) {
                return new AST_Let({
                    start: prev(),
                    definitions: vardefs(no_in, "let"),
                    end: prev()
                });
            };
            var const_ = function (no_in) {
                return new AST_Const({
                    start: prev(),
                    definitions: vardefs(no_in, "const"),
                    end: prev()
                });
            };
            var new_ = function (allow_calls) {
                var start = S.token;
                expect_token("operator", "new");
                if (is("punc", ".")) {
                    next();
                    expect_token("name", "target");
                    return subscripts(new AST_NewTarget({
                        start: start,
                        end: prev()
                    }), allow_calls);
                }
                var newexp = expr_atom(false), args;
                if (is("punc", "(")) {
                    next();
                    args = expr_list(")", true);
                }
                else {
                    args = [];
                }
                var call = new AST_New({
                    start: start,
                    expression: newexp,
                    args: args,
                    end: prev()
                });
                annotate(call);
                return subscripts(call, allow_calls);
            };
            function as_atom_node() {
                var tok = S.token, ret;
                switch (tok.type) {
                    case "name":
                        ret = _make_symbol(AST_SymbolRef);
                        break;
                    case "num":
                        ret = new AST_Number({
                            start: tok,
                            end: tok,
                            value: tok.value,
                            raw: LATEST_RAW
                        });
                        break;
                    case "big_int":
                        ret = new AST_BigInt({ start: tok, end: tok, value: tok.value });
                        break;
                    case "string":
                        ret = new AST_String({
                            start: tok,
                            end: tok,
                            value: tok.value,
                            quote: tok.quote
                        });
                        annotate(ret);
                        break;
                    case "regexp":
                        const [_, source, flags] = tok.value.match(/^\/(.*)\/(\w*)$/);
                        ret = new AST_RegExp({ start: tok, end: tok, value: { source, flags } });
                        break;
                    case "atom":
                        switch (tok.value) {
                            case "false":
                                ret = new AST_False({ start: tok, end: tok });
                                break;
                            case "true":
                                ret = new AST_True({ start: tok, end: tok });
                                break;
                            case "null":
                                ret = new AST_Null({ start: tok, end: tok });
                                break;
                        }
                        break;
                }
                next();
                return ret;
            }
            function to_fun_args(ex, default_seen_above) {
                var insert_default = function (ex, default_value) {
                    if (default_value) {
                        return new AST_DefaultAssign({
                            start: ex.start,
                            left: ex,
                            operator: "=",
                            right: default_value,
                            end: default_value.end
                        });
                    }
                    return ex;
                };
                if (ex instanceof AST_Object) {
                    return insert_default(new AST_Destructuring({
                        start: ex.start,
                        end: ex.end,
                        is_array: false,
                        names: ex.properties.map(prop => to_fun_args(prop))
                    }), default_seen_above);
                }
                else if (ex instanceof AST_ObjectKeyVal) {
                    ex.value = to_fun_args(ex.value);
                    return insert_default(ex, default_seen_above);
                }
                else if (ex instanceof AST_Hole) {
                    return ex;
                }
                else if (ex instanceof AST_Destructuring) {
                    ex.names = ex.names.map(name => to_fun_args(name));
                    return insert_default(ex, default_seen_above);
                }
                else if (ex instanceof AST_SymbolRef) {
                    return insert_default(new AST_SymbolFunarg({
                        name: ex.name,
                        start: ex.start,
                        end: ex.end
                    }), default_seen_above);
                }
                else if (ex instanceof AST_Expansion) {
                    ex.expression = to_fun_args(ex.expression);
                    return insert_default(ex, default_seen_above);
                }
                else if (ex instanceof AST_Array) {
                    return insert_default(new AST_Destructuring({
                        start: ex.start,
                        end: ex.end,
                        is_array: true,
                        names: ex.elements.map(elm => to_fun_args(elm))
                    }), default_seen_above);
                }
                else if (ex instanceof AST_Assign) {
                    return insert_default(to_fun_args(ex.left, ex.right), default_seen_above);
                }
                else if (ex instanceof AST_DefaultAssign) {
                    ex.left = to_fun_args(ex.left);
                    return ex;
                }
                else {
                    croak("Invalid function parameter", ex.start.line, ex.start.col);
                }
            }
            var expr_atom = function (allow_calls, allow_arrows) {
                if (is("operator", "new")) {
                    return new_(allow_calls);
                }
                if (is("name", "import") && is_token(peek(), "punc", ".")) {
                    return import_meta(allow_calls);
                }
                var start = S.token;
                var peeked;
                var async = is("name", "async")
                    && (peeked = peek()).value != "["
                    && peeked.type != "arrow"
                    && as_atom_node();
                if (is("punc")) {
                    switch (S.token.value) {
                        case "(":
                            if (async && !allow_calls)
                                break;
                            var exprs = params_or_seq_(allow_arrows, !async);
                            if (allow_arrows && is("arrow", "=>")) {
                                return arrow_function(start, exprs.map(e => to_fun_args(e)), !!async);
                            }
                            var ex = async ? new AST_Call({
                                expression: async,
                                args: exprs
                            }) : to_expr_or_sequence(start, exprs);
                            if (ex.start) {
                                const outer_comments_before = start.comments_before.length;
                                outer_comments_before_counts.set(start, outer_comments_before);
                                ex.start.comments_before.unshift(...start.comments_before);
                                start.comments_before = ex.start.comments_before;
                                if (outer_comments_before == 0 && start.comments_before.length > 0) {
                                    var comment = start.comments_before[0];
                                    if (!comment.nlb) {
                                        comment.nlb = start.nlb;
                                        start.nlb = false;
                                    }
                                }
                                start.comments_after = ex.start.comments_after;
                            }
                            ex.start = start;
                            var end = prev();
                            if (ex.end) {
                                end.comments_before = ex.end.comments_before;
                                ex.end.comments_after.push(...end.comments_after);
                                end.comments_after = ex.end.comments_after;
                            }
                            ex.end = end;
                            if (ex instanceof AST_Call)
                                annotate(ex);
                            return subscripts(ex, allow_calls);
                        case "[":
                            return subscripts(array_(), allow_calls);
                        case "{":
                            return subscripts(object_or_destructuring_(), allow_calls);
                    }
                    if (!async)
                        unexpected();
                }
                if (allow_arrows && is("name") && is_token(peek(), "arrow")) {
                    var param = new AST_SymbolFunarg({
                        name: S.token.value,
                        start: start,
                        end: start,
                    });
                    next();
                    return arrow_function(start, [param], !!async);
                }
                if (is("keyword", "function")) {
                    next();
                    var func = function_(AST_Function, false, !!async);
                    func.start = start;
                    func.end = prev();
                    return subscripts(func, allow_calls);
                }
                if (async)
                    return subscripts(async, allow_calls);
                if (is("keyword", "class")) {
                    next();
                    var cls = class_(AST_ClassExpression);
                    cls.start = start;
                    cls.end = prev();
                    return subscripts(cls, allow_calls);
                }
                if (is("template_head")) {
                    return subscripts(template_string(), allow_calls);
                }
                if (ATOMIC_START_TOKEN.has(S.token.type)) {
                    return subscripts(as_atom_node(), allow_calls);
                }
                unexpected();
            };
            function template_string() {
                var segments = [], start = S.token;
                segments.push(new AST_TemplateSegment({
                    start: S.token,
                    raw: TEMPLATE_RAWS.get(S.token),
                    value: S.token.value,
                    end: S.token
                }));
                while (!S.token.template_end) {
                    next();
                    handle_regexp();
                    segments.push(expression(true));
                    segments.push(new AST_TemplateSegment({
                        start: S.token,
                        raw: TEMPLATE_RAWS.get(S.token),
                        value: S.token.value,
                        end: S.token
                    }));
                }
                next();
                return new AST_TemplateString({
                    start: start,
                    segments: segments,
                    end: S.token
                });
            }
            function expr_list(closing, allow_trailing_comma, allow_empty) {
                var first = true, a = [];
                while (!is("punc", closing)) {
                    if (first)
                        first = false;
                    else
                        expect(",");
                    if (allow_trailing_comma && is("punc", closing))
                        break;
                    if (is("punc", ",") && allow_empty) {
                        a.push(new AST_Hole({ start: S.token, end: S.token }));
                    }
                    else if (is("expand", "...")) {
                        next();
                        a.push(new AST_Expansion({ start: prev(), expression: expression(), end: S.token }));
                    }
                    else {
                        a.push(expression(false));
                    }
                }
                next();
                return a;
            }
            var array_ = embed_tokens(function () {
                expect("[");
                return new AST_Array({
                    elements: expr_list("]", !options.strict, true)
                });
            });
            var create_accessor = embed_tokens((is_generator, is_async) => {
                return function_(AST_Accessor, is_generator, is_async);
            });
            var object_or_destructuring_ = embed_tokens(function object_or_destructuring_() {
                var start = S.token, first = true, a = [];
                expect("{");
                while (!is("punc", "}")) {
                    if (first)
                        first = false;
                    else
                        expect(",");
                    if (!options.strict && is("punc", "}"))
                        // allow trailing comma
                        break;
                    start = S.token;
                    if (start.type == "expand") {
                        next();
                        a.push(new AST_Expansion({
                            start: start,
                            expression: expression(false),
                            end: prev(),
                        }));
                        continue;
                    }
                    if (is("privatename")) {
                        croak("private fields are not allowed in an object");
                    }
                    var name = as_property_name();
                    var value;
                    // Check property and fetch value
                    if (!is("punc", ":")) {
                        var concise = concise_method_or_getset(name, start);
                        if (concise) {
                            a.push(concise);
                            continue;
                        }
                        value = new AST_SymbolRef({
                            start: prev(),
                            name: name,
                            end: prev()
                        });
                    }
                    else if (name === null) {
                        unexpected(prev());
                    }
                    else {
                        next(); // `:` - see first condition
                        value = expression(false);
                    }
                    // Check for default value and alter value accordingly if necessary
                    if (is("operator", "=")) {
                        next();
                        value = new AST_Assign({
                            start: start,
                            left: value,
                            operator: "=",
                            right: expression(false),
                            logical: false,
                            end: prev()
                        });
                    }
                    // Create property
                    const kv = new AST_ObjectKeyVal({
                        start: start,
                        quote: start.quote,
                        key: name instanceof AST_Node ? name : "" + name,
                        value: value,
                        end: prev()
                    });
                    a.push(annotate(kv));
                }
                next();
                return new AST_Object({ properties: a });
            });
            function class_(KindOfClass, is_export_default) {
                var start, method, class_name, extends_, a = [];
                S.input.push_directives_stack(); // Push directive stack, but not scope stack
                S.input.add_directive("use strict");
                if (S.token.type == "name" && S.token.value != "extends") {
                    class_name = as_symbol(KindOfClass === AST_DefClass ? AST_SymbolDefClass : AST_SymbolClass);
                }
                if (KindOfClass === AST_DefClass && !class_name) {
                    if (is_export_default) {
                        KindOfClass = AST_ClassExpression;
                    }
                    else {
                        unexpected();
                    }
                }
                if (S.token.value == "extends") {
                    next();
                    extends_ = expression(true);
                }
                expect("{");
                // mark in class feild,
                const save_in_class = S.in_class;
                S.in_class = true;
                while (is("punc", ";")) {
                    next();
                } // Leading semicolons are okay in class bodies.
                while (!is("punc", "}")) {
                    start = S.token;
                    method = concise_method_or_getset(as_property_name(), start, true);
                    if (!method) {
                        unexpected();
                    }
                    a.push(method);
                    while (is("punc", ";")) {
                        next();
                    }
                }
                // mark in class feild,
                S.in_class = save_in_class;
                S.input.pop_directives_stack();
                next();
                return new KindOfClass({
                    start: start,
                    name: class_name,
                    extends: extends_,
                    properties: a,
                    end: prev(),
                });
            }
            function concise_method_or_getset(name, start, is_class) {
                const get_symbol_ast = (name, SymbolClass = AST_SymbolMethod) => {
                    if (typeof name === "string" || typeof name === "number") {
                        return new SymbolClass({
                            start,
                            name: "" + name,
                            end: prev()
                        });
                    }
                    else if (name === null) {
                        unexpected();
                    }
                    return name;
                };
                const is_not_method_start = () => !is("punc", "(") && !is("punc", ",") && !is("punc", "}") && !is("punc", ";") && !is("operator", "=");
                var is_async = false;
                var is_static = false;
                var is_generator = false;
                var is_private = false;
                var accessor_type = null;
                if (is_class && name === "static" && is_not_method_start()) {
                    const static_block = class_static_block();
                    if (static_block != null) {
                        return static_block;
                    }
                    is_static = true;
                    name = as_property_name();
                }
                if (name === "async" && is_not_method_start()) {
                    is_async = true;
                    name = as_property_name();
                }
                if (prev().type === "operator" && prev().value === "*") {
                    is_generator = true;
                    name = as_property_name();
                }
                if ((name === "get" || name === "set") && is_not_method_start()) {
                    accessor_type = name;
                    name = as_property_name();
                }
                if (prev().type === "privatename") {
                    is_private = true;
                }
                const property_token = prev();
                if (accessor_type != null) {
                    if (!is_private) {
                        const AccessorClass = accessor_type === "get"
                            ? AST_ObjectGetter
                            : AST_ObjectSetter;
                        name = get_symbol_ast(name);
                        return annotate(new AccessorClass({
                            start,
                            static: is_static,
                            key: name,
                            quote: name instanceof AST_SymbolMethod ? property_token.quote : undefined,
                            value: create_accessor(),
                            end: prev()
                        }));
                    }
                    else {
                        const AccessorClass = accessor_type === "get"
                            ? AST_PrivateGetter
                            : AST_PrivateSetter;
                        return annotate(new AccessorClass({
                            start,
                            static: is_static,
                            key: get_symbol_ast(name),
                            value: create_accessor(),
                            end: prev(),
                        }));
                    }
                }
                if (is("punc", "(")) {
                    name = get_symbol_ast(name);
                    const AST_MethodVariant = is_private
                        ? AST_PrivateMethod
                        : AST_ConciseMethod;
                    var node = new AST_MethodVariant({
                        start: start,
                        static: is_static,
                        is_generator: is_generator,
                        async: is_async,
                        key: name,
                        quote: name instanceof AST_SymbolMethod ?
                            property_token.quote : undefined,
                        value: create_accessor(is_generator, is_async),
                        end: prev()
                    });
                    return annotate(node);
                }
                if (is_class) {
                    const key = get_symbol_ast(name, AST_SymbolClassProperty);
                    const quote = key instanceof AST_SymbolClassProperty
                        ? property_token.quote
                        : undefined;
                    const AST_ClassPropertyVariant = is_private
                        ? AST_ClassPrivateProperty
                        : AST_ClassProperty;
                    if (is("operator", "=")) {
                        next();
                        return annotate(new AST_ClassPropertyVariant({
                            start,
                            static: is_static,
                            quote,
                            key,
                            value: expression(false),
                            end: prev()
                        }));
                    }
                    else if (is("name")
                        || is("privatename")
                        || is("operator", "*")
                        || is("punc", ";")
                        || is("punc", "}")) {
                        return annotate(new AST_ClassPropertyVariant({
                            start,
                            static: is_static,
                            quote,
                            key,
                            end: prev()
                        }));
                    }
                }
            }
            function class_static_block() {
                if (!is("punc", "{")) {
                    return null;
                }
                const start = S.token;
                const body = [];
                next();
                while (!is("punc", "}")) {
                    body.push(statement());
                }
                next();
                return new AST_ClassStaticBlock({ start, body, end: prev() });
            }
            function maybe_import_assertion() {
                if (is("name", "assert") && !has_newline_before(S.token)) {
                    next();
                    return object_or_destructuring_();
                }
                return null;
            }
            function import_statement() {
                var start = prev();
                var imported_name;
                var imported_names;
                if (is("name")) {
                    imported_name = as_symbol(AST_SymbolImport);
                }
                if (is("punc", ",")) {
                    next();
                }
                imported_names = map_names(true);
                if (imported_names || imported_name) {
                    expect_token("name", "from");
                }
                var mod_str = S.token;
                if (mod_str.type !== "string") {
                    unexpected();
                }
                next();
                const assert_clause = maybe_import_assertion();
                return new AST_Import({
                    start,
                    imported_name,
                    imported_names,
                    module_name: new AST_String({
                        start: mod_str,
                        value: mod_str.value,
                        quote: mod_str.quote,
                        end: mod_str,
                    }),
                    assert_clause,
                    end: S.token,
                });
            }
            function import_meta(allow_calls) {
                var start = S.token;
                expect_token("name", "import");
                expect_token("punc", ".");
                expect_token("name", "meta");
                return subscripts(new AST_ImportMeta({
                    start: start,
                    end: prev()
                }), allow_calls);
            }
            function map_name(is_import) {
                function make_symbol(type, quote) {
                    return new type({
                        name: as_property_name(),
                        quote: quote || undefined,
                        start: prev(),
                        end: prev()
                    });
                }
                var foreign_type = is_import ? AST_SymbolImportForeign : AST_SymbolExportForeign;
                var type = is_import ? AST_SymbolImport : AST_SymbolExport;
                var start = S.token;
                var foreign_name;
                var name;
                if (is_import) {
                    foreign_name = make_symbol(foreign_type, start.quote);
                }
                else {
                    name = make_symbol(type, start.quote);
                }
                if (is("name", "as")) {
                    next(); // The "as" word
                    if (is_import) {
                        name = make_symbol(type);
                    }
                    else {
                        foreign_name = make_symbol(foreign_type, S.token.quote);
                    }
                }
                else if (is_import) {
                    name = new type(foreign_name);
                }
                else {
                    foreign_name = new foreign_type(name);
                }
                return new AST_NameMapping({
                    start: start,
                    foreign_name: foreign_name,
                    name: name,
                    end: prev(),
                });
            }
            function map_nameAsterisk(is_import, import_or_export_foreign_name) {
                var foreign_type = is_import ? AST_SymbolImportForeign : AST_SymbolExportForeign;
                var type = is_import ? AST_SymbolImport : AST_SymbolExport;
                var start = S.token;
                var name, foreign_name;
                var end = prev();
                if (is_import) {
                    name = import_or_export_foreign_name;
                }
                else {
                    foreign_name = import_or_export_foreign_name;
                }
                name = name || new type({
                    start: start,
                    name: "*",
                    end: end,
                });
                foreign_name = foreign_name || new foreign_type({
                    start: start,
                    name: "*",
                    end: end,
                });
                return new AST_NameMapping({
                    start: start,
                    foreign_name: foreign_name,
                    name: name,
                    end: end,
                });
            }
            function map_names(is_import) {
                var names;
                if (is("punc", "{")) {
                    next();
                    names = [];
                    while (!is("punc", "}")) {
                        names.push(map_name(is_import));
                        if (is("punc", ",")) {
                            next();
                        }
                    }
                    next();
                }
                else if (is("operator", "*")) {
                    var name;
                    next();
                    if (is("name", "as")) {
                        next(); // The "as" word
                        name = is_import ? as_symbol(AST_SymbolImport) : as_symbol_or_string(AST_SymbolExportForeign);
                    }
                    names = [map_nameAsterisk(is_import, name)];
                }
                return names;
            }
            function export_statement() {
                var start = S.token;
                var is_default;
                var exported_names;
                if (is("keyword", "default")) {
                    is_default = true;
                    next();
                }
                else if (exported_names = map_names(false)) {
                    if (is("name", "from")) {
                        next();
                        var mod_str = S.token;
                        if (mod_str.type !== "string") {
                            unexpected();
                        }
                        next();
                        const assert_clause = maybe_import_assertion();
                        return new AST_Export({
                            start: start,
                            is_default: is_default,
                            exported_names: exported_names,
                            module_name: new AST_String({
                                start: mod_str,
                                value: mod_str.value,
                                quote: mod_str.quote,
                                end: mod_str,
                            }),
                            end: prev(),
                            assert_clause
                        });
                    }
                    else {
                        return new AST_Export({
                            start: start,
                            is_default: is_default,
                            exported_names: exported_names,
                            end: prev(),
                        });
                    }
                }
                var node;
                var exported_value;
                var exported_definition;
                if (is("punc", "{")
                    || is_default
                        && (is("keyword", "class") || is("keyword", "function"))
                        && is_token(peek(), "punc")) {
                    exported_value = expression(false);
                    semicolon();
                }
                else if ((node = statement(is_default)) instanceof AST_Definitions && is_default) {
                    unexpected(node.start);
                }
                else if (node instanceof AST_Definitions
                    || node instanceof AST_Defun
                    || node instanceof AST_DefClass) {
                    exported_definition = node;
                }
                else if (node instanceof AST_ClassExpression
                    || node instanceof AST_Function) {
                    exported_value = node;
                }
                else if (node instanceof AST_SimpleStatement) {
                    exported_value = node.body;
                }
                else {
                    unexpected(node.start);
                }
                return new AST_Export({
                    start: start,
                    is_default: is_default,
                    exported_value: exported_value,
                    exported_definition: exported_definition,
                    end: prev(),
                    assert_clause: null
                });
            }
            function as_property_name() {
                var tmp = S.token;
                switch (tmp.type) {
                    case "punc":
                        if (tmp.value === "[") {
                            next();
                            var ex = expression(false);
                            expect("]");
                            return ex;
                        }
                        else
                            unexpected(tmp);
                    case "operator":
                        if (tmp.value === "*") {
                            next();
                            return null;
                        }
                        if (!["delete", "in", "instanceof", "new", "typeof", "void"].includes(tmp.value)) {
                            unexpected(tmp);
                        }
                    /* falls through */
                    case "name":
                    case "privatename":
                    case "string":
                    case "num":
                    case "big_int":
                    case "keyword":
                    case "atom":
                        next();
                        return tmp.value;
                    default:
                        unexpected(tmp);
                }
            }
            function as_name() {
                var tmp = S.token;
                if (tmp.type != "name" && tmp.type != "privatename")
                    unexpected();
                next();
                return tmp.value;
            }
            function _make_symbol(type) {
                var name = S.token.value;
                return new (name == "this" ? AST_This :
                    name == "super" ? AST_Super :
                        type)({
                    name: String(name),
                    start: S.token,
                    end: S.token
                });
            }
            function _verify_symbol(sym) {
                var name = sym.name;
                if (is_in_generator() && name == "yield") {
                    token_error(sym.start, "Yield cannot be used as identifier inside generators");
                }
                if (S.input.has_directive("use strict")) {
                    if (name == "yield") {
                        token_error(sym.start, "Unexpected yield identifier inside strict mode");
                    }
                    if (sym instanceof AST_SymbolDeclaration && (name == "arguments" || name == "eval")) {
                        token_error(sym.start, "Unexpected " + name + " in strict mode");
                    }
                }
            }
            function as_symbol(type, noerror) {
                if (!is("name")) {
                    if (!noerror)
                        croak("Name expected");
                    return null;
                }
                var sym = _make_symbol(type);
                _verify_symbol(sym);
                next();
                return sym;
            }
            function as_symbol_or_string(type) {
                if (!is("name")) {
                    if (!is("string")) {
                        croak("Name or string expected");
                    }
                    var tok = S.token;
                    var ret = new type({
                        start: tok,
                        end: tok,
                        name: tok.value,
                        quote: tok.quote
                    });
                    next();
                    return ret;
                }
                var sym = _make_symbol(type);
                _verify_symbol(sym);
                next();
                return sym;
            }
            // Annotate AST_Call, AST_Lambda or AST_New with the special comments
            function annotate(node, before_token = node.start) {
                var comments = before_token.comments_before;
                const comments_outside_parens = outer_comments_before_counts.get(before_token);
                var i = comments_outside_parens != null ? comments_outside_parens : comments.length;
                while (--i >= 0) {
                    var comment = comments[i];
                    if (/[@#]__/.test(comment.value)) {
                        if (/[@#]__PURE__/.test(comment.value)) {
                            set_annotation(node, _PURE);
                            break;
                        }
                        if (/[@#]__INLINE__/.test(comment.value)) {
                            set_annotation(node, _INLINE);
                            break;
                        }
                        if (/[@#]__NOINLINE__/.test(comment.value)) {
                            set_annotation(node, _NOINLINE);
                            break;
                        }
                        if (/[@#]__KEY__/.test(comment.value)) {
                            set_annotation(node, _KEY);
                            break;
                        }
                        if (/[@#]__MANGLE_PROP__/.test(comment.value)) {
                            set_annotation(node, _MANGLEPROP);
                            break;
                        }
                    }
                }
                return node;
            }
            var subscripts = function (expr, allow_calls, is_chain) {
                var start = expr.start;
                if (is("punc", ".")) {
                    next();
                    if (is("privatename") && !S.in_class)
                        croak("Private field must be used in an enclosing class");
                    const AST_DotVariant = is("privatename") ? AST_DotHash : AST_Dot;
                    return annotate(subscripts(new AST_DotVariant({
                        start: start,
                        expression: expr,
                        optional: false,
                        property: as_name(),
                        end: prev()
                    }), allow_calls, is_chain));
                }
                if (is("punc", "[")) {
                    next();
                    var prop = expression(true);
                    expect("]");
                    return annotate(subscripts(new AST_Sub({
                        start: start,
                        expression: expr,
                        optional: false,
                        property: prop,
                        end: prev()
                    }), allow_calls, is_chain));
                }
                if (allow_calls && is("punc", "(")) {
                    next();
                    var call = new AST_Call({
                        start: start,
                        expression: expr,
                        optional: false,
                        args: call_args(),
                        end: prev()
                    });
                    annotate(call);
                    return subscripts(call, true, is_chain);
                }
                if (is("punc", "?.")) {
                    next();
                    let chain_contents;
                    if (allow_calls && is("punc", "(")) {
                        next();
                        const call = new AST_Call({
                            start,
                            optional: true,
                            expression: expr,
                            args: call_args(),
                            end: prev()
                        });
                        annotate(call);
                        chain_contents = subscripts(call, true, true);
                    }
                    else if (is("name") || is("privatename")) {
                        if (is("privatename") && !S.in_class)
                            croak("Private field must be used in an enclosing class");
                        const AST_DotVariant = is("privatename") ? AST_DotHash : AST_Dot;
                        chain_contents = annotate(subscripts(new AST_DotVariant({
                            start,
                            expression: expr,
                            optional: true,
                            property: as_name(),
                            end: prev()
                        }), allow_calls, true));
                    }
                    else if (is("punc", "[")) {
                        next();
                        const property = expression(true);
                        expect("]");
                        chain_contents = annotate(subscripts(new AST_Sub({
                            start,
                            expression: expr,
                            optional: true,
                            property,
                            end: prev()
                        }), allow_calls, true));
                    }
                    if (!chain_contents)
                        unexpected();
                    if (chain_contents instanceof AST_Chain)
                        return chain_contents;
                    return new AST_Chain({
                        start,
                        expression: chain_contents,
                        end: prev()
                    });
                }
                if (is("template_head")) {
                    if (is_chain) {
                        // a?.b`c` is a syntax error
                        unexpected();
                    }
                    return subscripts(new AST_PrefixedTemplateString({
                        start: start,
                        prefix: expr,
                        template_string: template_string(),
                        end: prev()
                    }), allow_calls);
                }
                return expr;
            };
            function call_args() {
                var args = [];
                while (!is("punc", ")")) {
                    if (is("expand", "...")) {
                        next();
                        args.push(new AST_Expansion({
                            start: prev(),
                            expression: expression(false),
                            end: prev()
                        }));
                    }
                    else {
                        args.push(expression(false));
                    }
                    if (!is("punc", ")")) {
                        expect(",");
                    }
                }
                next();
                return args;
            }
            var maybe_unary = function (allow_calls, allow_arrows) {
                var start = S.token;
                if (start.type == "name" && start.value == "await" && can_await()) {
                    next();
                    return _await_expression();
                }
                if (is("operator") && UNARY_PREFIX.has(start.value)) {
                    next();
                    handle_regexp();
                    var ex = make_unary(AST_UnaryPrefix, start, maybe_unary(allow_calls));
                    ex.start = start;
                    ex.end = prev();
                    return ex;
                }
                var val = expr_atom(allow_calls, allow_arrows);
                while (is("operator") && UNARY_POSTFIX.has(S.token.value) && !has_newline_before(S.token)) {
                    if (val instanceof AST_Arrow)
                        unexpected();
                    val = make_unary(AST_UnaryPostfix, S.token, val);
                    val.start = start;
                    val.end = S.token;
                    next();
                }
                return val;
            };
            function make_unary(ctor, token, expr) {
                var op = token.value;
                switch (op) {
                    case "++":
                    case "--":
                        if (!is_assignable(expr))
                            croak("Invalid use of " + op + " operator", token.line, token.col, token.pos);
                        break;
                    case "delete":
                        if (expr instanceof AST_SymbolRef && S.input.has_directive("use strict"))
                            croak("Calling delete on expression not allowed in strict mode", expr.start.line, expr.start.col, expr.start.pos);
                        break;
                }
                return new ctor({ operator: op, expression: expr });
            }
            var expr_op = function (left, min_prec, no_in) {
                var op = is("operator") ? S.token.value : null;
                if (op == "in" && no_in)
                    op = null;
                if (op == "**" && left instanceof AST_UnaryPrefix
                    /* unary token in front not allowed - parenthesis required */
                    && !is_token(left.start, "punc", "(")
                    && left.operator !== "--" && left.operator !== "++")
                    unexpected(left.start);
                var prec = op != null ? PRECEDENCE[op] : null;
                if (prec != null && (prec > min_prec || (op === "**" && min_prec === prec))) {
                    next();
                    var right = expr_op(maybe_unary(true), prec, no_in);
                    return expr_op(new AST_Binary({
                        start: left.start,
                        left: left,
                        operator: op,
                        right: right,
                        end: right.end
                    }), min_prec, no_in);
                }
                return left;
            };
            function expr_ops(no_in) {
                // maybe_unary won't return us a AST_SymbolPrivateProperty
                if (!no_in && is("privatename")) {
                    if (!S.in_class) {
                        croak("Private field must be used in an enclosing class");
                    }
                    const start = S.token;
                    const key = new AST_SymbolPrivateProperty({
                        start,
                        name: start.value,
                        end: start
                    });
                    next();
                    expect_token("operator", "in");
                    const private_in = new AST_PrivateIn({
                        start,
                        key,
                        value: expr_op(maybe_unary(true), PRECEDENCE["in"], no_in),
                        end: prev()
                    });
                    return expr_op(private_in, 0, no_in);
                }
                else {
                    return expr_op(maybe_unary(true, true), 0, no_in);
                }
            }
            var maybe_conditional = function (no_in) {
                var start = S.token;
                var expr = expr_ops(no_in);
                if (is("operator", "?")) {
                    next();
                    var yes = expression(false);
                    expect(":");
                    return new AST_Conditional({
                        start: start,
                        condition: expr,
                        consequent: yes,
                        alternative: expression(false, no_in),
                        end: prev()
                    });
                }
                return expr;
            };
            function is_assignable(expr) {
                return expr instanceof AST_PropAccess || expr instanceof AST_SymbolRef;
            }
            function to_destructuring(node) {
                if (node instanceof AST_Object) {
                    node = new AST_Destructuring({
                        start: node.start,
                        names: node.properties.map(to_destructuring),
                        is_array: false,
                        end: node.end
                    });
                }
                else if (node instanceof AST_Array) {
                    var names = [];
                    for (var i = 0; i < node.elements.length; i++) {
                        // Only allow expansion as last element
                        if (node.elements[i] instanceof AST_Expansion) {
                            if (i + 1 !== node.elements.length) {
                                token_error(node.elements[i].start, "Spread must the be last element in destructuring array");
                            }
                            node.elements[i].expression = to_destructuring(node.elements[i].expression);
                        }
                        names.push(to_destructuring(node.elements[i]));
                    }
                    node = new AST_Destructuring({
                        start: node.start,
                        names: names,
                        is_array: true,
                        end: node.end
                    });
                }
                else if (node instanceof AST_ObjectProperty) {
                    node.value = to_destructuring(node.value);
                }
                else if (node instanceof AST_Assign) {
                    node = new AST_DefaultAssign({
                        start: node.start,
                        left: node.left,
                        operator: "=",
                        right: node.right,
                        end: node.end
                    });
                }
                return node;
            }
            // In ES6, AssignmentExpression can also be an ArrowFunction
            var maybe_assign = function (no_in) {
                handle_regexp();
                var start = S.token;
                if (start.type == "name" && start.value == "yield") {
                    if (is_in_generator()) {
                        next();
                        return _yield_expression();
                    }
                    else if (S.input.has_directive("use strict")) {
                        token_error(S.token, "Unexpected yield identifier inside strict mode");
                    }
                }
                var left = maybe_conditional(no_in);
                var val = S.token.value;
                if (is("operator") && ASSIGNMENT.has(val)) {
                    if (is_assignable(left) || (left = to_destructuring(left)) instanceof AST_Destructuring) {
                        next();
                        return new AST_Assign({
                            start: start,
                            left: left,
                            operator: val,
                            right: maybe_assign(no_in),
                            logical: LOGICAL_ASSIGNMENT.has(val),
                            end: prev()
                        });
                    }
                    croak("Invalid assignment");
                }
                return left;
            };
            var to_expr_or_sequence = function (start, exprs) {
                if (exprs.length === 1) {
                    return exprs[0];
                }
                else if (exprs.length > 1) {
                    return new AST_Sequence({ start, expressions: exprs, end: peek() });
                }
                else {
                    croak("Invalid parenthesized expression");
                }
            };
            var expression = function (commas, no_in) {
                var start = S.token;
                var exprs = [];
                while (true) {
                    exprs.push(maybe_assign(no_in));
                    if (!commas || !is("punc", ","))
                        break;
                    next();
                    commas = true;
                }
                return to_expr_or_sequence(start, exprs);
            };
            function in_loop(cont) {
                ++S.in_loop;
                var ret = cont();
                --S.in_loop;
                return ret;
            }
            if (options.expression) {
                return expression(true);
            }
            return (function parse_toplevel() {
                var start = S.token;
                var body = [];
                S.input.push_directives_stack();
                if (options.module)
                    S.input.add_directive("use strict");
                while (!is("eof")) {
                    body.push(statement());
                }
                S.input.pop_directives_stack();
                var end = prev();
                var toplevel = options.toplevel;
                if (toplevel) {
                    toplevel.body = toplevel.body.concat(body);
                    toplevel.end = end;
                }
                else {
                    toplevel = new AST_Toplevel({ start: start, body: body, end: end });
                }
                TEMPLATE_RAWS = new Map();
                return toplevel;
            })();
        }
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        function DEFNODE(type, props, ctor, methods, base = AST_Node) {
            if (!props)
                props = [];
            else
                props = props.split(/\s+/);
            var self_props = props;
            if (base && base.PROPS)
                props = props.concat(base.PROPS);
            const proto = base && Object.create(base.prototype);
            if (proto) {
                ctor.prototype = proto;
                ctor.BASE = base;
            }
            if (base)
                base.SUBCLASSES.push(ctor);
            ctor.prototype.CTOR = ctor;
            ctor.prototype.constructor = ctor;
            ctor.PROPS = props || null;
            ctor.SELF_PROPS = self_props;
            ctor.SUBCLASSES = [];
            if (type) {
                ctor.prototype.TYPE = ctor.TYPE = type;
            }
            if (methods)
                for (let i in methods)
                    if (HOP(methods, i)) {
                        if (i[0] === "$") {
                            ctor[i.substr(1)] = methods[i];
                        }
                        else {
                            ctor.prototype[i] = methods[i];
                        }
                    }
            ctor.DEFMETHOD = function (name, method) {
                this.prototype[name] = method;
            };
            return ctor;
        }
        const has_tok_flag = (tok, flag) => Boolean(tok.flags & flag);
        const set_tok_flag = (tok, flag, truth) => {
            if (truth) {
                tok.flags |= flag;
            }
            else {
                tok.flags &= ~flag;
            }
        };
        const TOK_FLAG_NLB = 0b0001;
        const TOK_FLAG_QUOTE_SINGLE = 0b0010;
        const TOK_FLAG_QUOTE_EXISTS = 0b0100;
        const TOK_FLAG_TEMPLATE_END = 0b1000;
        class AST_Token {
            constructor(type, value, line, col, pos, nlb, comments_before, comments_after, file) {
                this.flags = (nlb ? 1 : 0);
                this.type = type;
                this.value = value;
                this.line = line;
                this.col = col;
                this.pos = pos;
                this.comments_before = comments_before;
                this.comments_after = comments_after;
                this.file = file;
                Object.seal(this);
            }
            // Return a string summary of the token for node.js console.log
            [Symbol.for("nodejs.util.inspect.custom")](_depth, options) {
                const special = str => options.stylize(str, "special");
                const quote = typeof this.value === "string" && this.value.includes("`") ? "'" : "`";
                const value = `${quote}${this.value}${quote}`;
                return `${special("[AST_Token")} ${value} at ${this.line}:${this.col}${special("]")}`;
            }
            get nlb() {
                return has_tok_flag(this, TOK_FLAG_NLB);
            }
            set nlb(new_nlb) {
                set_tok_flag(this, TOK_FLAG_NLB, new_nlb);
            }
            get quote() {
                return !has_tok_flag(this, TOK_FLAG_QUOTE_EXISTS)
                    ? ""
                    : (has_tok_flag(this, TOK_FLAG_QUOTE_SINGLE) ? "'" : '"');
            }
            set quote(quote_type) {
                set_tok_flag(this, TOK_FLAG_QUOTE_SINGLE, quote_type === "'");
                set_tok_flag(this, TOK_FLAG_QUOTE_EXISTS, !!quote_type);
            }
            get template_end() {
                return has_tok_flag(this, TOK_FLAG_TEMPLATE_END);
            }
            set template_end(new_template_end) {
                set_tok_flag(this, TOK_FLAG_TEMPLATE_END, new_template_end);
            }
        }
        var AST_Node = DEFNODE("Node", "start end", function AST_Node(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            _clone: function (deep) {
                if (deep) {
                    var self = this.clone();
                    return self.transform(new TreeTransformer(function (node) {
                        if (node !== self) {
                            return node.clone(true);
                        }
                    }));
                }
                return new this.CTOR(this);
            },
            clone: function (deep) {
                return this._clone(deep);
            },
            $documentation: "Base class of all AST nodes",
            $propdoc: {
                start: "[AST_Token] The first token of this node",
                end: "[AST_Token] The last token of this node"
            },
            _walk: function (visitor) {
                return visitor._visit(this);
            },
            walk: function (visitor) {
                return this._walk(visitor); // not sure the indirection will be any help
            },
            _children_backwards: () => { }
        }, null);
        /* -----[ statements ]----- */
        var AST_Statement = DEFNODE("Statement", null, function AST_Statement(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class of all statements",
        });
        var AST_Debugger = DEFNODE("Debugger", null, function AST_Debugger(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Represents a debugger statement",
        }, AST_Statement);
        var AST_Directive = DEFNODE("Directive", "value quote", function AST_Directive(props) {
            if (props) {
                this.value = props.value;
                this.quote = props.quote;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Represents a directive, like \"use strict\";",
            $propdoc: {
                value: "[string] The value of this directive as a plain string (it's not an AST_String!)",
                quote: "[string] the original quote character"
            },
        }, AST_Statement);
        var AST_SimpleStatement = DEFNODE("SimpleStatement", "body", function AST_SimpleStatement(props) {
            if (props) {
                this.body = props.body;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A statement consisting of an expression, i.e. a = 1 + 2",
            $propdoc: {
                body: "[AST_Node] an expression node (should not be instanceof AST_Statement)"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.body._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.body);
            }
        }, AST_Statement);
        function walk_body(node, visitor) {
            const body = node.body;
            for (var i = 0, len = body.length; i < len; i++) {
                body[i]._walk(visitor);
            }
        }
        function clone_block_scope(deep) {
            var clone = this._clone(deep);
            if (this.block_scope) {
                clone.block_scope = this.block_scope.clone();
            }
            return clone;
        }
        var AST_Block = DEFNODE("Block", "body block_scope", function AST_Block(props) {
            if (props) {
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A body of statements (usually braced)",
            $propdoc: {
                body: "[AST_Statement*] an array of statements",
                block_scope: "[AST_Scope] the block scope"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    walk_body(this, visitor);
                });
            },
            _children_backwards(push) {
                let i = this.body.length;
                while (i--)
                    push(this.body[i]);
            },
            clone: clone_block_scope
        }, AST_Statement);
        var AST_BlockStatement = DEFNODE("BlockStatement", null, function AST_BlockStatement(props) {
            if (props) {
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A block statement",
        }, AST_Block);
        var AST_EmptyStatement = DEFNODE("EmptyStatement", null, function AST_EmptyStatement(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "The empty statement (empty block or simply a semicolon)"
        }, AST_Statement);
        var AST_StatementWithBody = DEFNODE("StatementWithBody", "body", function AST_StatementWithBody(props) {
            if (props) {
                this.body = props.body;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for all statements that contain one nested body: `For`, `ForIn`, `Do`, `While`, `With`",
            $propdoc: {
                body: "[AST_Statement] the body; this should always be present, even if it's an AST_EmptyStatement"
            }
        }, AST_Statement);
        var AST_LabeledStatement = DEFNODE("LabeledStatement", "label", function AST_LabeledStatement(props) {
            if (props) {
                this.label = props.label;
                this.body = props.body;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Statement with a label",
            $propdoc: {
                label: "[AST_Label] a label definition"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.label._walk(visitor);
                    this.body._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.body);
                push(this.label);
            },
            clone: function (deep) {
                var node = this._clone(deep);
                if (deep) {
                    var label = node.label;
                    var def = this.label;
                    node.walk(new TreeWalker(function (node) {
                        if (node instanceof AST_LoopControl
                            && node.label && node.label.thedef === def) {
                            node.label.thedef = label;
                            label.references.push(node);
                        }
                    }));
                }
                return node;
            }
        }, AST_StatementWithBody);
        var AST_IterationStatement = DEFNODE("IterationStatement", "block_scope", function AST_IterationStatement(props) {
            if (props) {
                this.block_scope = props.block_scope;
                this.body = props.body;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Internal class.  All loops inherit from it.",
            $propdoc: {
                block_scope: "[AST_Scope] the block scope for this iteration statement."
            },
            clone: clone_block_scope
        }, AST_StatementWithBody);
        var AST_DWLoop = DEFNODE("DWLoop", "condition", function AST_DWLoop(props) {
            if (props) {
                this.condition = props.condition;
                this.block_scope = props.block_scope;
                this.body = props.body;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for do/while statements",
            $propdoc: {
                condition: "[AST_Node] the loop condition.  Should not be instanceof AST_Statement"
            }
        }, AST_IterationStatement);
        var AST_Do = DEFNODE("Do", null, function AST_Do(props) {
            if (props) {
                this.condition = props.condition;
                this.block_scope = props.block_scope;
                this.body = props.body;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `do` statement",
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.body._walk(visitor);
                    this.condition._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.condition);
                push(this.body);
            }
        }, AST_DWLoop);
        var AST_While = DEFNODE("While", null, function AST_While(props) {
            if (props) {
                this.condition = props.condition;
                this.block_scope = props.block_scope;
                this.body = props.body;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `while` statement",
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.condition._walk(visitor);
                    this.body._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.body);
                push(this.condition);
            },
        }, AST_DWLoop);
        var AST_For = DEFNODE("For", "init condition step", function AST_For(props) {
            if (props) {
                this.init = props.init;
                this.condition = props.condition;
                this.step = props.step;
                this.block_scope = props.block_scope;
                this.body = props.body;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `for` statement",
            $propdoc: {
                init: "[AST_Node?] the `for` initialization code, or null if empty",
                condition: "[AST_Node?] the `for` termination clause, or null if empty",
                step: "[AST_Node?] the `for` update clause, or null if empty"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    if (this.init)
                        this.init._walk(visitor);
                    if (this.condition)
                        this.condition._walk(visitor);
                    if (this.step)
                        this.step._walk(visitor);
                    this.body._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.body);
                if (this.step)
                    push(this.step);
                if (this.condition)
                    push(this.condition);
                if (this.init)
                    push(this.init);
            },
        }, AST_IterationStatement);
        var AST_ForIn = DEFNODE("ForIn", "init object", function AST_ForIn(props) {
            if (props) {
                this.init = props.init;
                this.object = props.object;
                this.block_scope = props.block_scope;
                this.body = props.body;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `for ... in` statement",
            $propdoc: {
                init: "[AST_Node] the `for/in` initialization code",
                object: "[AST_Node] the object that we're looping through"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.init._walk(visitor);
                    this.object._walk(visitor);
                    this.body._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.body);
                if (this.object)
                    push(this.object);
                if (this.init)
                    push(this.init);
            },
        }, AST_IterationStatement);
        var AST_ForOf = DEFNODE("ForOf", "await", function AST_ForOf(props) {
            if (props) {
                this.await = props.await;
                this.init = props.init;
                this.object = props.object;
                this.block_scope = props.block_scope;
                this.body = props.body;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `for ... of` statement",
        }, AST_ForIn);
        var AST_With = DEFNODE("With", "expression", function AST_With(props) {
            if (props) {
                this.expression = props.expression;
                this.body = props.body;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `with` statement",
            $propdoc: {
                expression: "[AST_Node] the `with` expression"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.expression._walk(visitor);
                    this.body._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.body);
                push(this.expression);
            },
        }, AST_StatementWithBody);
        /* -----[ scope and functions ]----- */
        var AST_Scope = DEFNODE("Scope", "variables uses_with uses_eval parent_scope enclosed cname", function AST_Scope(props) {
            if (props) {
                this.variables = props.variables;
                this.uses_with = props.uses_with;
                this.uses_eval = props.uses_eval;
                this.parent_scope = props.parent_scope;
                this.enclosed = props.enclosed;
                this.cname = props.cname;
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for all statements introducing a lexical scope",
            $propdoc: {
                variables: "[Map/S] a map of name -> SymbolDef for all variables/functions defined in this scope",
                uses_with: "[boolean/S] tells whether this scope uses the `with` statement",
                uses_eval: "[boolean/S] tells whether this scope contains a direct call to the global `eval`",
                parent_scope: "[AST_Scope?/S] link to the parent scope",
                enclosed: "[SymbolDef*/S] a list of all symbol definitions that are accessed from this scope or any subscopes",
                cname: "[integer/S] current index for mangling variables (used internally by the mangler)",
            },
            get_defun_scope: function () {
                var self = this;
                while (self.is_block_scope()) {
                    self = self.parent_scope;
                }
                return self;
            },
            clone: function (deep, toplevel) {
                var node = this._clone(deep);
                if (deep && this.variables && toplevel && !this._block_scope) {
                    node.figure_out_scope({}, {
                        toplevel: toplevel,
                        parent_scope: this.parent_scope
                    });
                }
                else {
                    if (this.variables)
                        node.variables = new Map(this.variables);
                    if (this.enclosed)
                        node.enclosed = this.enclosed.slice();
                    if (this._block_scope)
                        node._block_scope = this._block_scope;
                }
                return node;
            },
            pinned: function () {
                return this.uses_eval || this.uses_with;
            }
        }, AST_Block);
        var AST_Toplevel = DEFNODE("Toplevel", "globals", function AST_Toplevel(props) {
            if (props) {
                this.globals = props.globals;
                this.variables = props.variables;
                this.uses_with = props.uses_with;
                this.uses_eval = props.uses_eval;
                this.parent_scope = props.parent_scope;
                this.enclosed = props.enclosed;
                this.cname = props.cname;
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "The toplevel scope",
            $propdoc: {
                globals: "[Map/S] a map of name -> SymbolDef for all undeclared names",
            },
            wrap_commonjs: function (name) {
                var body = this.body;
                var wrapped_tl = "(function(exports){'$ORIG';})(typeof " + name + "=='undefined'?(" + name + "={}):" + name + ");";
                wrapped_tl = parse(wrapped_tl);
                wrapped_tl = wrapped_tl.transform(new TreeTransformer(function (node) {
                    if (node instanceof AST_Directive && node.value == "$ORIG") {
                        return MAP.splice(body);
                    }
                }));
                return wrapped_tl;
            },
            wrap_enclose: function (args_values) {
                if (typeof args_values != "string")
                    args_values = "";
                var index = args_values.indexOf(":");
                if (index < 0)
                    index = args_values.length;
                var body = this.body;
                return parse([
                    "(function(",
                    args_values.slice(0, index),
                    '){"$ORIG"})(',
                    args_values.slice(index + 1),
                    ")"
                ].join("")).transform(new TreeTransformer(function (node) {
                    if (node instanceof AST_Directive && node.value == "$ORIG") {
                        return MAP.splice(body);
                    }
                }));
            }
        }, AST_Scope);
        var AST_Expansion = DEFNODE("Expansion", "expression", function AST_Expansion(props) {
            if (props) {
                this.expression = props.expression;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "An expandible argument, such as ...rest, a splat, such as [1,2,...all], or an expansion in a variable declaration, such as var [first, ...rest] = list",
            $propdoc: {
                expression: "[AST_Node] the thing to be expanded"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.expression.walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.expression);
            },
        });
        var AST_Lambda = DEFNODE("Lambda", "name argnames uses_arguments is_generator async", function AST_Lambda(props) {
            if (props) {
                this.name = props.name;
                this.argnames = props.argnames;
                this.uses_arguments = props.uses_arguments;
                this.is_generator = props.is_generator;
                this.async = props.async;
                this.variables = props.variables;
                this.uses_with = props.uses_with;
                this.uses_eval = props.uses_eval;
                this.parent_scope = props.parent_scope;
                this.enclosed = props.enclosed;
                this.cname = props.cname;
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for functions",
            $propdoc: {
                name: "[AST_SymbolDeclaration?] the name of this function",
                argnames: "[AST_SymbolFunarg|AST_Destructuring|AST_Expansion|AST_DefaultAssign*] array of function arguments, destructurings, or expanding arguments",
                uses_arguments: "[boolean/S] tells whether this function accesses the arguments array",
                is_generator: "[boolean] is this a generator method",
                async: "[boolean] is this method async",
            },
            args_as_names: function () {
                var out = [];
                for (var i = 0; i < this.argnames.length; i++) {
                    if (this.argnames[i] instanceof AST_Destructuring) {
                        out.push(...this.argnames[i].all_symbols());
                    }
                    else {
                        out.push(this.argnames[i]);
                    }
                }
                return out;
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    if (this.name)
                        this.name._walk(visitor);
                    var argnames = this.argnames;
                    for (var i = 0, len = argnames.length; i < len; i++) {
                        argnames[i]._walk(visitor);
                    }
                    walk_body(this, visitor);
                });
            },
            _children_backwards(push) {
                let i = this.body.length;
                while (i--)
                    push(this.body[i]);
                i = this.argnames.length;
                while (i--)
                    push(this.argnames[i]);
                if (this.name)
                    push(this.name);
            },
            is_braceless() {
                return this.body[0] instanceof AST_Return && this.body[0].value;
            },
            // Default args and expansion don't count, so .argnames.length doesn't cut it
            length_property() {
                let length = 0;
                for (const arg of this.argnames) {
                    if (arg instanceof AST_SymbolFunarg || arg instanceof AST_Destructuring) {
                        length++;
                    }
                }
                return length;
            }
        }, AST_Scope);
        var AST_Accessor = DEFNODE("Accessor", null, function AST_Accessor(props) {
            if (props) {
                this.name = props.name;
                this.argnames = props.argnames;
                this.uses_arguments = props.uses_arguments;
                this.is_generator = props.is_generator;
                this.async = props.async;
                this.variables = props.variables;
                this.uses_with = props.uses_with;
                this.uses_eval = props.uses_eval;
                this.parent_scope = props.parent_scope;
                this.enclosed = props.enclosed;
                this.cname = props.cname;
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A setter/getter function.  The `name` property is always null."
        }, AST_Lambda);
        var AST_Function = DEFNODE("Function", null, function AST_Function(props) {
            if (props) {
                this.name = props.name;
                this.argnames = props.argnames;
                this.uses_arguments = props.uses_arguments;
                this.is_generator = props.is_generator;
                this.async = props.async;
                this.variables = props.variables;
                this.uses_with = props.uses_with;
                this.uses_eval = props.uses_eval;
                this.parent_scope = props.parent_scope;
                this.enclosed = props.enclosed;
                this.cname = props.cname;
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A function expression"
        }, AST_Lambda);
        var AST_Arrow = DEFNODE("Arrow", null, function AST_Arrow(props) {
            if (props) {
                this.name = props.name;
                this.argnames = props.argnames;
                this.uses_arguments = props.uses_arguments;
                this.is_generator = props.is_generator;
                this.async = props.async;
                this.variables = props.variables;
                this.uses_with = props.uses_with;
                this.uses_eval = props.uses_eval;
                this.parent_scope = props.parent_scope;
                this.enclosed = props.enclosed;
                this.cname = props.cname;
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "An ES6 Arrow function ((a) => b)"
        }, AST_Lambda);
        var AST_Defun = DEFNODE("Defun", null, function AST_Defun(props) {
            if (props) {
                this.name = props.name;
                this.argnames = props.argnames;
                this.uses_arguments = props.uses_arguments;
                this.is_generator = props.is_generator;
                this.async = props.async;
                this.variables = props.variables;
                this.uses_with = props.uses_with;
                this.uses_eval = props.uses_eval;
                this.parent_scope = props.parent_scope;
                this.enclosed = props.enclosed;
                this.cname = props.cname;
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A function definition"
        }, AST_Lambda);
        /* -----[ DESTRUCTURING ]----- */
        var AST_Destructuring = DEFNODE("Destructuring", "names is_array", function AST_Destructuring(props) {
            if (props) {
                this.names = props.names;
                this.is_array = props.is_array;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A destructuring of several names. Used in destructuring assignment and with destructuring function argument names",
            $propdoc: {
                "names": "[AST_Node*] Array of properties or elements",
                "is_array": "[Boolean] Whether the destructuring represents an object or array"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.names.forEach(function (name) {
                        name._walk(visitor);
                    });
                });
            },
            _children_backwards(push) {
                let i = this.names.length;
                while (i--)
                    push(this.names[i]);
            },
            all_symbols: function () {
                var out = [];
                walk(this, node => {
                    if (node instanceof AST_SymbolDeclaration) {
                        out.push(node);
                    }
                    if (node instanceof AST_Lambda) {
                        return true;
                    }
                });
                return out;
            }
        });
        var AST_PrefixedTemplateString = DEFNODE("PrefixedTemplateString", "template_string prefix", function AST_PrefixedTemplateString(props) {
            if (props) {
                this.template_string = props.template_string;
                this.prefix = props.prefix;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A templatestring with a prefix, such as String.raw`foobarbaz`",
            $propdoc: {
                template_string: "[AST_TemplateString] The template string",
                prefix: "[AST_Node] The prefix, which will get called."
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.prefix._walk(visitor);
                    this.template_string._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.template_string);
                push(this.prefix);
            },
        });
        var AST_TemplateString = DEFNODE("TemplateString", "segments", function AST_TemplateString(props) {
            if (props) {
                this.segments = props.segments;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A template string literal",
            $propdoc: {
                segments: "[AST_Node*] One or more segments, starting with AST_TemplateSegment. AST_Node may follow AST_TemplateSegment, but each AST_Node must be followed by AST_TemplateSegment."
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.segments.forEach(function (seg) {
                        seg._walk(visitor);
                    });
                });
            },
            _children_backwards(push) {
                let i = this.segments.length;
                while (i--)
                    push(this.segments[i]);
            }
        });
        var AST_TemplateSegment = DEFNODE("TemplateSegment", "value raw", function AST_TemplateSegment(props) {
            if (props) {
                this.value = props.value;
                this.raw = props.raw;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A segment of a template string literal",
            $propdoc: {
                value: "Content of the segment",
                raw: "Raw source of the segment",
            }
        });
        /* -----[ JUMPS ]----- */
        var AST_Jump = DEFNODE("Jump", null, function AST_Jump(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for “jumps” (for now that's `return`, `throw`, `break` and `continue`)"
        }, AST_Statement);
        /** Base class for “exits” (`return` and `throw`) */
        var AST_Exit = DEFNODE("Exit", "value", function AST_Exit(props) {
            if (props) {
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for “exits” (`return` and `throw`)",
            $propdoc: {
                value: "[AST_Node?] the value returned or thrown by this statement; could be null for AST_Return"
            },
            _walk: function (visitor) {
                return visitor._visit(this, this.value && function () {
                    this.value._walk(visitor);
                });
            },
            _children_backwards(push) {
                if (this.value)
                    push(this.value);
            },
        }, AST_Jump);
        var AST_Return = DEFNODE("Return", null, function AST_Return(props) {
            if (props) {
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `return` statement"
        }, AST_Exit);
        var AST_Throw = DEFNODE("Throw", null, function AST_Throw(props) {
            if (props) {
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `throw` statement"
        }, AST_Exit);
        var AST_LoopControl = DEFNODE("LoopControl", "label", function AST_LoopControl(props) {
            if (props) {
                this.label = props.label;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for loop control statements (`break` and `continue`)",
            $propdoc: {
                label: "[AST_LabelRef?] the label, or null if none",
            },
            _walk: function (visitor) {
                return visitor._visit(this, this.label && function () {
                    this.label._walk(visitor);
                });
            },
            _children_backwards(push) {
                if (this.label)
                    push(this.label);
            },
        }, AST_Jump);
        var AST_Break = DEFNODE("Break", null, function AST_Break(props) {
            if (props) {
                this.label = props.label;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `break` statement"
        }, AST_LoopControl);
        var AST_Continue = DEFNODE("Continue", null, function AST_Continue(props) {
            if (props) {
                this.label = props.label;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `continue` statement"
        }, AST_LoopControl);
        var AST_Await = DEFNODE("Await", "expression", function AST_Await(props) {
            if (props) {
                this.expression = props.expression;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "An `await` statement",
            $propdoc: {
                expression: "[AST_Node] the mandatory expression being awaited",
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.expression._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.expression);
            },
        });
        var AST_Yield = DEFNODE("Yield", "expression is_star", function AST_Yield(props) {
            if (props) {
                this.expression = props.expression;
                this.is_star = props.is_star;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `yield` statement",
            $propdoc: {
                expression: "[AST_Node?] the value returned or thrown by this statement; could be null (representing undefined) but only when is_star is set to false",
                is_star: "[Boolean] Whether this is a yield or yield* statement"
            },
            _walk: function (visitor) {
                return visitor._visit(this, this.expression && function () {
                    this.expression._walk(visitor);
                });
            },
            _children_backwards(push) {
                if (this.expression)
                    push(this.expression);
            }
        });
        /* -----[ IF ]----- */
        var AST_If = DEFNODE("If", "condition alternative", function AST_If(props) {
            if (props) {
                this.condition = props.condition;
                this.alternative = props.alternative;
                this.body = props.body;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `if` statement",
            $propdoc: {
                condition: "[AST_Node] the `if` condition",
                alternative: "[AST_Statement?] the `else` part, or null if not present"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.condition._walk(visitor);
                    this.body._walk(visitor);
                    if (this.alternative)
                        this.alternative._walk(visitor);
                });
            },
            _children_backwards(push) {
                if (this.alternative) {
                    push(this.alternative);
                }
                push(this.body);
                push(this.condition);
            }
        }, AST_StatementWithBody);
        /* -----[ SWITCH ]----- */
        var AST_Switch = DEFNODE("Switch", "expression", function AST_Switch(props) {
            if (props) {
                this.expression = props.expression;
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `switch` statement",
            $propdoc: {
                expression: "[AST_Node] the `switch` “discriminant”"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.expression._walk(visitor);
                    walk_body(this, visitor);
                });
            },
            _children_backwards(push) {
                let i = this.body.length;
                while (i--)
                    push(this.body[i]);
                push(this.expression);
            }
        }, AST_Block);
        var AST_SwitchBranch = DEFNODE("SwitchBranch", null, function AST_SwitchBranch(props) {
            if (props) {
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for `switch` branches",
        }, AST_Block);
        var AST_Default = DEFNODE("Default", null, function AST_Default(props) {
            if (props) {
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `default` switch branch",
        }, AST_SwitchBranch);
        var AST_Case = DEFNODE("Case", "expression", function AST_Case(props) {
            if (props) {
                this.expression = props.expression;
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `case` switch branch",
            $propdoc: {
                expression: "[AST_Node] the `case` expression"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.expression._walk(visitor);
                    walk_body(this, visitor);
                });
            },
            _children_backwards(push) {
                let i = this.body.length;
                while (i--)
                    push(this.body[i]);
                push(this.expression);
            },
        }, AST_SwitchBranch);
        /* -----[ EXCEPTIONS ]----- */
        var AST_Try = DEFNODE("Try", "body bcatch bfinally", function AST_Try(props) {
            if (props) {
                this.body = props.body;
                this.bcatch = props.bcatch;
                this.bfinally = props.bfinally;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `try` statement",
            $propdoc: {
                body: "[AST_TryBlock] the try block",
                bcatch: "[AST_Catch?] the catch block, or null if not present",
                bfinally: "[AST_Finally?] the finally block, or null if not present"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.body._walk(visitor);
                    if (this.bcatch)
                        this.bcatch._walk(visitor);
                    if (this.bfinally)
                        this.bfinally._walk(visitor);
                });
            },
            _children_backwards(push) {
                if (this.bfinally)
                    push(this.bfinally);
                if (this.bcatch)
                    push(this.bcatch);
                push(this.body);
            },
        }, AST_Statement);
        var AST_TryBlock = DEFNODE("TryBlock", null, function AST_TryBlock(props) {
            if (props) {
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "The `try` block of a try statement"
        }, AST_Block);
        var AST_Catch = DEFNODE("Catch", "argname", function AST_Catch(props) {
            if (props) {
                this.argname = props.argname;
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `catch` node; only makes sense as part of a `try` statement",
            $propdoc: {
                argname: "[AST_SymbolCatch|AST_Destructuring|AST_Expansion|AST_DefaultAssign] symbol for the exception"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    if (this.argname)
                        this.argname._walk(visitor);
                    walk_body(this, visitor);
                });
            },
            _children_backwards(push) {
                let i = this.body.length;
                while (i--)
                    push(this.body[i]);
                if (this.argname)
                    push(this.argname);
            },
        }, AST_Block);
        var AST_Finally = DEFNODE("Finally", null, function AST_Finally(props) {
            if (props) {
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `finally` node; only makes sense as part of a `try` statement"
        }, AST_Block);
        /* -----[ VAR/CONST ]----- */
        var AST_Definitions = DEFNODE("Definitions", "definitions", function AST_Definitions(props) {
            if (props) {
                this.definitions = props.definitions;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for `var` or `const` nodes (variable declarations/initializations)",
            $propdoc: {
                definitions: "[AST_VarDef*] array of variable definitions"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    var definitions = this.definitions;
                    for (var i = 0, len = definitions.length; i < len; i++) {
                        definitions[i]._walk(visitor);
                    }
                });
            },
            _children_backwards(push) {
                let i = this.definitions.length;
                while (i--)
                    push(this.definitions[i]);
            },
        }, AST_Statement);
        var AST_Var = DEFNODE("Var", null, function AST_Var(props) {
            if (props) {
                this.definitions = props.definitions;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `var` statement"
        }, AST_Definitions);
        var AST_Let = DEFNODE("Let", null, function AST_Let(props) {
            if (props) {
                this.definitions = props.definitions;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `let` statement"
        }, AST_Definitions);
        var AST_Const = DEFNODE("Const", null, function AST_Const(props) {
            if (props) {
                this.definitions = props.definitions;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A `const` statement"
        }, AST_Definitions);
        var AST_VarDef = DEFNODE("VarDef", "name value", function AST_VarDef(props) {
            if (props) {
                this.name = props.name;
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A variable declaration; only appears in a AST_Definitions node",
            $propdoc: {
                name: "[AST_Destructuring|AST_SymbolConst|AST_SymbolLet|AST_SymbolVar] name of the variable",
                value: "[AST_Node?] initializer, or null of there's no initializer"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.name._walk(visitor);
                    if (this.value)
                        this.value._walk(visitor);
                });
            },
            _children_backwards(push) {
                if (this.value)
                    push(this.value);
                push(this.name);
            },
            declarations_as_names() {
                if (this.name instanceof AST_SymbolDeclaration) {
                    return [this];
                }
                else {
                    return this.name.all_symbols();
                }
            }
        });
        var AST_NameMapping = DEFNODE("NameMapping", "foreign_name name", function AST_NameMapping(props) {
            if (props) {
                this.foreign_name = props.foreign_name;
                this.name = props.name;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "The part of the export/import statement that declare names from a module.",
            $propdoc: {
                foreign_name: "[AST_SymbolExportForeign|AST_SymbolImportForeign] The name being exported/imported (as specified in the module)",
                name: "[AST_SymbolExport|AST_SymbolImport] The name as it is visible to this module."
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.foreign_name._walk(visitor);
                    this.name._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.name);
                push(this.foreign_name);
            },
        });
        var AST_Import = DEFNODE("Import", "imported_name imported_names module_name assert_clause", function AST_Import(props) {
            if (props) {
                this.imported_name = props.imported_name;
                this.imported_names = props.imported_names;
                this.module_name = props.module_name;
                this.assert_clause = props.assert_clause;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "An `import` statement",
            $propdoc: {
                imported_name: "[AST_SymbolImport] The name of the variable holding the module's default export.",
                imported_names: "[AST_NameMapping*] The names of non-default imported variables",
                module_name: "[AST_String] String literal describing where this module came from",
                assert_clause: "[AST_Object?] The import assertion"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    if (this.imported_name) {
                        this.imported_name._walk(visitor);
                    }
                    if (this.imported_names) {
                        this.imported_names.forEach(function (name_import) {
                            name_import._walk(visitor);
                        });
                    }
                    this.module_name._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.module_name);
                if (this.imported_names) {
                    let i = this.imported_names.length;
                    while (i--)
                        push(this.imported_names[i]);
                }
                if (this.imported_name)
                    push(this.imported_name);
            },
        });
        var AST_ImportMeta = DEFNODE("ImportMeta", null, function AST_ImportMeta(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A reference to import.meta",
        });
        var AST_Export = DEFNODE("Export", "exported_definition exported_value is_default exported_names module_name assert_clause", function AST_Export(props) {
            if (props) {
                this.exported_definition = props.exported_definition;
                this.exported_value = props.exported_value;
                this.is_default = props.is_default;
                this.exported_names = props.exported_names;
                this.module_name = props.module_name;
                this.assert_clause = props.assert_clause;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "An `export` statement",
            $propdoc: {
                exported_definition: "[AST_Defun|AST_Definitions|AST_DefClass?] An exported definition",
                exported_value: "[AST_Node?] An exported value",
                exported_names: "[AST_NameMapping*?] List of exported names",
                module_name: "[AST_String?] Name of the file to load exports from",
                is_default: "[Boolean] Whether this is the default exported value of this module",
                assert_clause: "[AST_Object?] The import assertion"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    if (this.exported_definition) {
                        this.exported_definition._walk(visitor);
                    }
                    if (this.exported_value) {
                        this.exported_value._walk(visitor);
                    }
                    if (this.exported_names) {
                        this.exported_names.forEach(function (name_export) {
                            name_export._walk(visitor);
                        });
                    }
                    if (this.module_name) {
                        this.module_name._walk(visitor);
                    }
                });
            },
            _children_backwards(push) {
                if (this.module_name)
                    push(this.module_name);
                if (this.exported_names) {
                    let i = this.exported_names.length;
                    while (i--)
                        push(this.exported_names[i]);
                }
                if (this.exported_value)
                    push(this.exported_value);
                if (this.exported_definition)
                    push(this.exported_definition);
            }
        }, AST_Statement);
        /* -----[ OTHER ]----- */
        var AST_Call = DEFNODE("Call", "expression args optional _annotations", function AST_Call(props) {
            if (props) {
                this.expression = props.expression;
                this.args = props.args;
                this.optional = props.optional;
                this._annotations = props._annotations;
                this.start = props.start;
                this.end = props.end;
                this.initialize();
            }
            this.flags = 0;
        }, {
            $documentation: "A function call expression",
            $propdoc: {
                expression: "[AST_Node] expression to invoke as function",
                args: "[AST_Node*] array of arguments",
                optional: "[boolean] whether this is an optional call (IE ?.() )",
                _annotations: "[number] bitfield containing information about the call"
            },
            initialize() {
                if (this._annotations == null)
                    this._annotations = 0;
            },
            _walk(visitor) {
                return visitor._visit(this, function () {
                    var args = this.args;
                    for (var i = 0, len = args.length; i < len; i++) {
                        args[i]._walk(visitor);
                    }
                    this.expression._walk(visitor); // TODO why do we need to crawl this last?
                });
            },
            _children_backwards(push) {
                let i = this.args.length;
                while (i--)
                    push(this.args[i]);
                push(this.expression);
            },
        });
        var AST_New = DEFNODE("New", null, function AST_New(props) {
            if (props) {
                this.expression = props.expression;
                this.args = props.args;
                this.optional = props.optional;
                this._annotations = props._annotations;
                this.start = props.start;
                this.end = props.end;
                this.initialize();
            }
            this.flags = 0;
        }, {
            $documentation: "An object instantiation.  Derives from a function call since it has exactly the same properties"
        }, AST_Call);
        var AST_Sequence = DEFNODE("Sequence", "expressions", function AST_Sequence(props) {
            if (props) {
                this.expressions = props.expressions;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A sequence expression (comma-separated expressions)",
            $propdoc: {
                expressions: "[AST_Node*] array of expressions (at least two)"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.expressions.forEach(function (node) {
                        node._walk(visitor);
                    });
                });
            },
            _children_backwards(push) {
                let i = this.expressions.length;
                while (i--)
                    push(this.expressions[i]);
            },
        });
        var AST_PropAccess = DEFNODE("PropAccess", "expression property optional", function AST_PropAccess(props) {
            if (props) {
                this.expression = props.expression;
                this.property = props.property;
                this.optional = props.optional;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for property access expressions, i.e. `a.foo` or `a[\"foo\"]`",
            $propdoc: {
                expression: "[AST_Node] the “container” expression",
                property: "[AST_Node|string] the property to access.  For AST_Dot & AST_DotHash this is always a plain string, while for AST_Sub it's an arbitrary AST_Node",
                optional: "[boolean] whether this is an optional property access (IE ?.)"
            }
        });
        var AST_Dot = DEFNODE("Dot", "quote", function AST_Dot(props) {
            if (props) {
                this.quote = props.quote;
                this.expression = props.expression;
                this.property = props.property;
                this.optional = props.optional;
                this._annotations = props._annotations;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A dotted property access expression",
            $propdoc: {
                quote: "[string] the original quote character when transformed from AST_Sub",
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.expression._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.expression);
            },
        }, AST_PropAccess);
        var AST_DotHash = DEFNODE("DotHash", "", function AST_DotHash(props) {
            if (props) {
                this.expression = props.expression;
                this.property = props.property;
                this.optional = props.optional;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A dotted property access to a private property",
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.expression._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.expression);
            },
        }, AST_PropAccess);
        var AST_Sub = DEFNODE("Sub", null, function AST_Sub(props) {
            if (props) {
                this.expression = props.expression;
                this.property = props.property;
                this.optional = props.optional;
                this._annotations = props._annotations;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Index-style property access, i.e. `a[\"foo\"]`",
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.expression._walk(visitor);
                    this.property._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.property);
                push(this.expression);
            },
        }, AST_PropAccess);
        var AST_Chain = DEFNODE("Chain", "expression", function AST_Chain(props) {
            if (props) {
                this.expression = props.expression;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A chain expression like a?.b?.(c)?.[d]",
            $propdoc: {
                expression: "[AST_Call|AST_Dot|AST_DotHash|AST_Sub] chain element."
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.expression._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.expression);
            },
        });
        var AST_Unary = DEFNODE("Unary", "operator expression", function AST_Unary(props) {
            if (props) {
                this.operator = props.operator;
                this.expression = props.expression;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for unary expressions",
            $propdoc: {
                operator: "[string] the operator",
                expression: "[AST_Node] expression that this unary operator applies to"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.expression._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.expression);
            },
        });
        var AST_UnaryPrefix = DEFNODE("UnaryPrefix", null, function AST_UnaryPrefix(props) {
            if (props) {
                this.operator = props.operator;
                this.expression = props.expression;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Unary prefix expression, i.e. `typeof i` or `++i`"
        }, AST_Unary);
        var AST_UnaryPostfix = DEFNODE("UnaryPostfix", null, function AST_UnaryPostfix(props) {
            if (props) {
                this.operator = props.operator;
                this.expression = props.expression;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Unary postfix expression, i.e. `i++`"
        }, AST_Unary);
        var AST_Binary = DEFNODE("Binary", "operator left right", function AST_Binary(props) {
            if (props) {
                this.operator = props.operator;
                this.left = props.left;
                this.right = props.right;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Binary expression, i.e. `a + b`",
            $propdoc: {
                left: "[AST_Node] left-hand side expression",
                operator: "[string] the operator",
                right: "[AST_Node] right-hand side expression"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.left._walk(visitor);
                    this.right._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.right);
                push(this.left);
            },
        });
        var AST_Conditional = DEFNODE("Conditional", "condition consequent alternative", function AST_Conditional(props) {
            if (props) {
                this.condition = props.condition;
                this.consequent = props.consequent;
                this.alternative = props.alternative;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Conditional expression using the ternary operator, i.e. `a ? b : c`",
            $propdoc: {
                condition: "[AST_Node]",
                consequent: "[AST_Node]",
                alternative: "[AST_Node]"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.condition._walk(visitor);
                    this.consequent._walk(visitor);
                    this.alternative._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.alternative);
                push(this.consequent);
                push(this.condition);
            },
        });
        var AST_Assign = DEFNODE("Assign", "logical", function AST_Assign(props) {
            if (props) {
                this.logical = props.logical;
                this.operator = props.operator;
                this.left = props.left;
                this.right = props.right;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "An assignment expression — `a = b + 5`",
            $propdoc: {
                logical: "Whether it's a logical assignment"
            }
        }, AST_Binary);
        var AST_DefaultAssign = DEFNODE("DefaultAssign", null, function AST_DefaultAssign(props) {
            if (props) {
                this.operator = props.operator;
                this.left = props.left;
                this.right = props.right;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A default assignment expression like in `(a = 3) => a`"
        }, AST_Binary);
        /* -----[ LITERALS ]----- */
        var AST_Array = DEFNODE("Array", "elements", function AST_Array(props) {
            if (props) {
                this.elements = props.elements;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "An array literal",
            $propdoc: {
                elements: "[AST_Node*] array of elements"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    var elements = this.elements;
                    for (var i = 0, len = elements.length; i < len; i++) {
                        elements[i]._walk(visitor);
                    }
                });
            },
            _children_backwards(push) {
                let i = this.elements.length;
                while (i--)
                    push(this.elements[i]);
            },
        });
        var AST_Object = DEFNODE("Object", "properties", function AST_Object(props) {
            if (props) {
                this.properties = props.properties;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "An object literal",
            $propdoc: {
                properties: "[AST_ObjectProperty*] array of properties"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    var properties = this.properties;
                    for (var i = 0, len = properties.length; i < len; i++) {
                        properties[i]._walk(visitor);
                    }
                });
            },
            _children_backwards(push) {
                let i = this.properties.length;
                while (i--)
                    push(this.properties[i]);
            },
        });
        var AST_ObjectProperty = DEFNODE("ObjectProperty", "key value", function AST_ObjectProperty(props) {
            if (props) {
                this.key = props.key;
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
                this._annotations = props._annotations;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for literal object properties",
            $propdoc: {
                key: "[string|AST_Node] property name. For ObjectKeyVal this is a string. For getters, setters and computed property this is an AST_Node.",
                value: "[AST_Node] property value.  For getters and setters this is an AST_Accessor."
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    if (this.key instanceof AST_Node)
                        this.key._walk(visitor);
                    this.value._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.value);
                if (this.key instanceof AST_Node)
                    push(this.key);
            }
        });
        var AST_ObjectKeyVal = DEFNODE("ObjectKeyVal", "quote", function AST_ObjectKeyVal(props) {
            if (props) {
                this.quote = props.quote;
                this.key = props.key;
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
                this._annotations = props._annotations;
            }
            this.flags = 0;
        }, {
            $documentation: "A key: value object property",
            $propdoc: {
                quote: "[string] the original quote character"
            },
            computed_key() {
                return this.key instanceof AST_Node;
            }
        }, AST_ObjectProperty);
        var AST_PrivateSetter = DEFNODE("PrivateSetter", "static", function AST_PrivateSetter(props) {
            if (props) {
                this.static = props.static;
                this.key = props.key;
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $propdoc: {
                static: "[boolean] whether this is a static private setter"
            },
            $documentation: "A private setter property",
            computed_key() {
                return false;
            }
        }, AST_ObjectProperty);
        var AST_PrivateGetter = DEFNODE("PrivateGetter", "static", function AST_PrivateGetter(props) {
            if (props) {
                this.static = props.static;
                this.key = props.key;
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $propdoc: {
                static: "[boolean] whether this is a static private getter"
            },
            $documentation: "A private getter property",
            computed_key() {
                return false;
            }
        }, AST_ObjectProperty);
        var AST_ObjectSetter = DEFNODE("ObjectSetter", "quote static", function AST_ObjectSetter(props) {
            if (props) {
                this.quote = props.quote;
                this.static = props.static;
                this.key = props.key;
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
                this._annotations = props._annotations;
            }
            this.flags = 0;
        }, {
            $propdoc: {
                quote: "[string|undefined] the original quote character, if any",
                static: "[boolean] whether this is a static setter (classes only)"
            },
            $documentation: "An object setter property",
            computed_key() {
                return !(this.key instanceof AST_SymbolMethod);
            }
        }, AST_ObjectProperty);
        var AST_ObjectGetter = DEFNODE("ObjectGetter", "quote static", function AST_ObjectGetter(props) {
            if (props) {
                this.quote = props.quote;
                this.static = props.static;
                this.key = props.key;
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
                this._annotations = props._annotations;
            }
            this.flags = 0;
        }, {
            $propdoc: {
                quote: "[string|undefined] the original quote character, if any",
                static: "[boolean] whether this is a static getter (classes only)"
            },
            $documentation: "An object getter property",
            computed_key() {
                return !(this.key instanceof AST_SymbolMethod);
            }
        }, AST_ObjectProperty);
        var AST_ConciseMethod = DEFNODE("ConciseMethod", "quote static is_generator async", function AST_ConciseMethod(props) {
            if (props) {
                this.quote = props.quote;
                this.static = props.static;
                this.is_generator = props.is_generator;
                this.async = props.async;
                this.key = props.key;
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
                this._annotations = props._annotations;
            }
            this.flags = 0;
        }, {
            $propdoc: {
                quote: "[string|undefined] the original quote character, if any",
                static: "[boolean] is this method static (classes only)",
                is_generator: "[boolean] is this a generator method",
                async: "[boolean] is this method async",
            },
            $documentation: "An ES6 concise method inside an object or class",
            computed_key() {
                return !(this.key instanceof AST_SymbolMethod);
            }
        }, AST_ObjectProperty);
        var AST_PrivateMethod = DEFNODE("PrivateMethod", "", function AST_PrivateMethod(props) {
            if (props) {
                this.quote = props.quote;
                this.static = props.static;
                this.is_generator = props.is_generator;
                this.async = props.async;
                this.key = props.key;
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A private class method inside a class",
        }, AST_ConciseMethod);
        var AST_Class = DEFNODE("Class", "name extends properties", function AST_Class(props) {
            if (props) {
                this.name = props.name;
                this.extends = props.extends;
                this.properties = props.properties;
                this.variables = props.variables;
                this.uses_with = props.uses_with;
                this.uses_eval = props.uses_eval;
                this.parent_scope = props.parent_scope;
                this.enclosed = props.enclosed;
                this.cname = props.cname;
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $propdoc: {
                name: "[AST_SymbolClass|AST_SymbolDefClass?] optional class name.",
                extends: "[AST_Node]? optional parent class",
                properties: "[AST_ObjectProperty*] array of properties"
            },
            $documentation: "An ES6 class",
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    if (this.name) {
                        this.name._walk(visitor);
                    }
                    if (this.extends) {
                        this.extends._walk(visitor);
                    }
                    this.properties.forEach((prop) => prop._walk(visitor));
                });
            },
            _children_backwards(push) {
                let i = this.properties.length;
                while (i--)
                    push(this.properties[i]);
                if (this.extends)
                    push(this.extends);
                if (this.name)
                    push(this.name);
            },
            /** go through the bits that are executed instantly, not when the class is `new`'d. Doesn't walk the name. */
            visit_nondeferred_class_parts(visitor) {
                if (this.extends) {
                    this.extends._walk(visitor);
                }
                this.properties.forEach((prop) => {
                    if (prop instanceof AST_ClassStaticBlock) {
                        prop._walk(visitor);
                        return;
                    }
                    if (prop.computed_key()) {
                        visitor.push(prop);
                        prop.key._walk(visitor);
                        visitor.pop();
                    }
                    if ((prop instanceof AST_ClassPrivateProperty || prop instanceof AST_ClassProperty) && prop.static && prop.value) {
                        visitor.push(prop);
                        prop.value._walk(visitor);
                        visitor.pop();
                    }
                });
            },
            /** go through the bits that are executed later, when the class is `new`'d or a static method is called */
            visit_deferred_class_parts(visitor) {
                this.properties.forEach((prop) => {
                    if (prop instanceof AST_ConciseMethod) {
                        prop.walk(visitor);
                    }
                    else if (prop instanceof AST_ClassProperty && !prop.static && prop.value) {
                        visitor.push(prop);
                        prop.value._walk(visitor);
                        visitor.pop();
                    }
                });
            },
            is_self_referential: function () {
                const this_id = this.name && this.name.definition().id;
                let found = false;
                let class_this = true;
                this.visit_nondeferred_class_parts(new TreeWalker((node, descend) => {
                    if (found)
                        return true;
                    if (node instanceof AST_This)
                        return (found = class_this);
                    if (node instanceof AST_SymbolRef)
                        return (found = node.definition().id === this_id);
                    if (node instanceof AST_Lambda && !(node instanceof AST_Arrow)) {
                        const class_this_save = class_this;
                        class_this = false;
                        descend();
                        class_this = class_this_save;
                        return true;
                    }
                }));
                return found;
            },
        }, AST_Scope /* TODO a class might have a scope but it's not a scope */);
        var AST_ClassProperty = DEFNODE("ClassProperty", "static quote", function AST_ClassProperty(props) {
            if (props) {
                this.static = props.static;
                this.quote = props.quote;
                this.key = props.key;
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
                this._annotations = props._annotations;
            }
            this.flags = 0;
        }, {
            $documentation: "A class property",
            $propdoc: {
                static: "[boolean] whether this is a static key",
                quote: "[string] which quote is being used"
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    if (this.key instanceof AST_Node)
                        this.key._walk(visitor);
                    if (this.value instanceof AST_Node)
                        this.value._walk(visitor);
                });
            },
            _children_backwards(push) {
                if (this.value instanceof AST_Node)
                    push(this.value);
                if (this.key instanceof AST_Node)
                    push(this.key);
            },
            computed_key() {
                return !(this.key instanceof AST_SymbolClassProperty);
            }
        }, AST_ObjectProperty);
        var AST_ClassPrivateProperty = DEFNODE("ClassPrivateProperty", "", function AST_ClassPrivateProperty(props) {
            if (props) {
                this.static = props.static;
                this.quote = props.quote;
                this.key = props.key;
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A class property for a private property",
        }, AST_ClassProperty);
        var AST_PrivateIn = DEFNODE("PrivateIn", "key value", function AST_PrivateIn(props) {
            if (props) {
                this.key = props.key;
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "An `in` binop when the key is private, eg #x in this",
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    this.key._walk(visitor);
                    this.value._walk(visitor);
                });
            },
            _children_backwards(push) {
                push(this.value);
                push(this.key);
            },
        });
        var AST_DefClass = DEFNODE("DefClass", null, function AST_DefClass(props) {
            if (props) {
                this.name = props.name;
                this.extends = props.extends;
                this.properties = props.properties;
                this.variables = props.variables;
                this.uses_with = props.uses_with;
                this.uses_eval = props.uses_eval;
                this.parent_scope = props.parent_scope;
                this.enclosed = props.enclosed;
                this.cname = props.cname;
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A class definition",
        }, AST_Class);
        var AST_ClassStaticBlock = DEFNODE("ClassStaticBlock", "body block_scope", function AST_ClassStaticBlock(props) {
            this.body = props.body;
            this.block_scope = props.block_scope;
            this.start = props.start;
            this.end = props.end;
        }, {
            $documentation: "A block containing statements to be executed in the context of the class",
            $propdoc: {
                body: "[AST_Statement*] an array of statements",
            },
            _walk: function (visitor) {
                return visitor._visit(this, function () {
                    walk_body(this, visitor);
                });
            },
            _children_backwards(push) {
                let i = this.body.length;
                while (i--)
                    push(this.body[i]);
            },
            clone: clone_block_scope,
            computed_key: () => false
        }, AST_Scope);
        var AST_ClassExpression = DEFNODE("ClassExpression", null, function AST_ClassExpression(props) {
            if (props) {
                this.name = props.name;
                this.extends = props.extends;
                this.properties = props.properties;
                this.variables = props.variables;
                this.uses_with = props.uses_with;
                this.uses_eval = props.uses_eval;
                this.parent_scope = props.parent_scope;
                this.enclosed = props.enclosed;
                this.cname = props.cname;
                this.body = props.body;
                this.block_scope = props.block_scope;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A class expression."
        }, AST_Class);
        var AST_Symbol = DEFNODE("Symbol", "scope name thedef", function AST_Symbol(props) {
            if (props) {
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $propdoc: {
                name: "[string] name of this symbol",
                scope: "[AST_Scope/S] the current scope (not necessarily the definition scope)",
                thedef: "[SymbolDef/S] the definition of this symbol"
            },
            $documentation: "Base class for all symbols"
        });
        var AST_NewTarget = DEFNODE("NewTarget", null, function AST_NewTarget(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A reference to new.target"
        });
        var AST_SymbolDeclaration = DEFNODE("SymbolDeclaration", "init", function AST_SymbolDeclaration(props) {
            if (props) {
                this.init = props.init;
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A declaration symbol (symbol in var/const, function name or argument, symbol in catch)",
        }, AST_Symbol);
        var AST_SymbolVar = DEFNODE("SymbolVar", null, function AST_SymbolVar(props) {
            if (props) {
                this.init = props.init;
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Symbol defining a variable",
        }, AST_SymbolDeclaration);
        var AST_SymbolBlockDeclaration = DEFNODE("SymbolBlockDeclaration", null, function AST_SymbolBlockDeclaration(props) {
            if (props) {
                this.init = props.init;
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for block-scoped declaration symbols"
        }, AST_SymbolDeclaration);
        var AST_SymbolConst = DEFNODE("SymbolConst", null, function AST_SymbolConst(props) {
            if (props) {
                this.init = props.init;
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A constant declaration"
        }, AST_SymbolBlockDeclaration);
        var AST_SymbolLet = DEFNODE("SymbolLet", null, function AST_SymbolLet(props) {
            if (props) {
                this.init = props.init;
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A block-scoped `let` declaration"
        }, AST_SymbolBlockDeclaration);
        var AST_SymbolFunarg = DEFNODE("SymbolFunarg", null, function AST_SymbolFunarg(props) {
            if (props) {
                this.init = props.init;
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Symbol naming a function argument",
        }, AST_SymbolVar);
        var AST_SymbolDefun = DEFNODE("SymbolDefun", null, function AST_SymbolDefun(props) {
            if (props) {
                this.init = props.init;
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Symbol defining a function",
        }, AST_SymbolDeclaration);
        var AST_SymbolMethod = DEFNODE("SymbolMethod", null, function AST_SymbolMethod(props) {
            if (props) {
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Symbol in an object defining a method",
        }, AST_Symbol);
        var AST_SymbolClassProperty = DEFNODE("SymbolClassProperty", null, function AST_SymbolClassProperty(props) {
            if (props) {
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Symbol for a class property",
        }, AST_Symbol);
        var AST_SymbolLambda = DEFNODE("SymbolLambda", null, function AST_SymbolLambda(props) {
            if (props) {
                this.init = props.init;
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Symbol naming a function expression",
        }, AST_SymbolDeclaration);
        var AST_SymbolDefClass = DEFNODE("SymbolDefClass", null, function AST_SymbolDefClass(props) {
            if (props) {
                this.init = props.init;
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Symbol naming a class's name in a class declaration. Lexically scoped to its containing scope, and accessible within the class."
        }, AST_SymbolBlockDeclaration);
        var AST_SymbolClass = DEFNODE("SymbolClass", null, function AST_SymbolClass(props) {
            if (props) {
                this.init = props.init;
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Symbol naming a class's name. Lexically scoped to the class."
        }, AST_SymbolDeclaration);
        var AST_SymbolCatch = DEFNODE("SymbolCatch", null, function AST_SymbolCatch(props) {
            if (props) {
                this.init = props.init;
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Symbol naming the exception in catch",
        }, AST_SymbolBlockDeclaration);
        var AST_SymbolImport = DEFNODE("SymbolImport", null, function AST_SymbolImport(props) {
            if (props) {
                this.init = props.init;
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Symbol referring to an imported name",
        }, AST_SymbolBlockDeclaration);
        var AST_SymbolImportForeign = DEFNODE("SymbolImportForeign", null, function AST_SymbolImportForeign(props) {
            if (props) {
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.quote = props.quote;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A symbol imported from a module, but it is defined in the other module, and its real name is irrelevant for this module's purposes",
        }, AST_Symbol);
        var AST_Label = DEFNODE("Label", "references", function AST_Label(props) {
            if (props) {
                this.references = props.references;
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
                this.initialize();
            }
            this.flags = 0;
        }, {
            $documentation: "Symbol naming a label (declaration)",
            $propdoc: {
                references: "[AST_LoopControl*] a list of nodes referring to this label"
            },
            initialize: function () {
                this.references = [];
                this.thedef = this;
            }
        }, AST_Symbol);
        var AST_SymbolRef = DEFNODE("SymbolRef", null, function AST_SymbolRef(props) {
            if (props) {
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Reference to some symbol (not definition/declaration)",
        }, AST_Symbol);
        var AST_SymbolExport = DEFNODE("SymbolExport", null, function AST_SymbolExport(props) {
            if (props) {
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.quote = props.quote;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Symbol referring to a name to export",
        }, AST_SymbolRef);
        var AST_SymbolExportForeign = DEFNODE("SymbolExportForeign", null, function AST_SymbolExportForeign(props) {
            if (props) {
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.quote = props.quote;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A symbol exported from this module, but it is used in the other module, and its real name is irrelevant for this module's purposes",
        }, AST_Symbol);
        var AST_LabelRef = DEFNODE("LabelRef", null, function AST_LabelRef(props) {
            if (props) {
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Reference to a label symbol",
        }, AST_Symbol);
        var AST_SymbolPrivateProperty = DEFNODE("SymbolPrivateProperty", null, function AST_SymbolPrivateProperty(props) {
            if (props) {
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A symbol that refers to a private property",
        }, AST_Symbol);
        var AST_This = DEFNODE("This", null, function AST_This(props) {
            if (props) {
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "The `this` symbol",
        }, AST_Symbol);
        var AST_Super = DEFNODE("Super", null, function AST_Super(props) {
            if (props) {
                this.scope = props.scope;
                this.name = props.name;
                this.thedef = props.thedef;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "The `super` symbol",
        }, AST_This);
        var AST_Constant = DEFNODE("Constant", null, function AST_Constant(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for all constants",
            getValue: function () {
                return this.value;
            }
        });
        var AST_String = DEFNODE("String", "value quote", function AST_String(props) {
            if (props) {
                this.value = props.value;
                this.quote = props.quote;
                this.start = props.start;
                this.end = props.end;
                this._annotations = props._annotations;
            }
            this.flags = 0;
        }, {
            $documentation: "A string literal",
            $propdoc: {
                value: "[string] the contents of this string",
                quote: "[string] the original quote character"
            }
        }, AST_Constant);
        var AST_Number = DEFNODE("Number", "value raw", function AST_Number(props) {
            if (props) {
                this.value = props.value;
                this.raw = props.raw;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A number literal",
            $propdoc: {
                value: "[number] the numeric value",
                raw: "[string] numeric value as string"
            }
        }, AST_Constant);
        var AST_BigInt = DEFNODE("BigInt", "value", function AST_BigInt(props) {
            if (props) {
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A big int literal",
            $propdoc: {
                value: "[string] big int value"
            }
        }, AST_Constant);
        var AST_RegExp = DEFNODE("RegExp", "value", function AST_RegExp(props) {
            if (props) {
                this.value = props.value;
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A regexp literal",
            $propdoc: {
                value: "[RegExp] the actual regexp",
            }
        }, AST_Constant);
        var AST_Atom = DEFNODE("Atom", null, function AST_Atom(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for atoms",
        }, AST_Constant);
        var AST_Null = DEFNODE("Null", null, function AST_Null(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "The `null` atom",
            value: null
        }, AST_Atom);
        var AST_NaN = DEFNODE("NaN", null, function AST_NaN(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "The impossible value",
            value: 0 / 0
        }, AST_Atom);
        var AST_Undefined = DEFNODE("Undefined", null, function AST_Undefined(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "The `undefined` value",
            value: (function () { }())
        }, AST_Atom);
        var AST_Hole = DEFNODE("Hole", null, function AST_Hole(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "A hole in an array",
            value: (function () { }())
        }, AST_Atom);
        var AST_Infinity = DEFNODE("Infinity", null, function AST_Infinity(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "The `Infinity` value",
            value: 1 / 0
        }, AST_Atom);
        var AST_Boolean = DEFNODE("Boolean", null, function AST_Boolean(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "Base class for booleans",
        }, AST_Atom);
        var AST_False = DEFNODE("False", null, function AST_False(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "The `false` atom",
            value: false
        }, AST_Boolean);
        var AST_True = DEFNODE("True", null, function AST_True(props) {
            if (props) {
                this.start = props.start;
                this.end = props.end;
            }
            this.flags = 0;
        }, {
            $documentation: "The `true` atom",
            value: true
        }, AST_Boolean);
        /* -----[ Walk function ]---- */
        /**
         * Walk nodes in depth-first search fashion.
         * Callback can return `walk_abort` symbol to stop iteration.
         * It can also return `true` to stop iteration just for child nodes.
         * Iteration can be stopped and continued by passing the `to_visit` argument,
         * which is given to the callback in the second argument.
         **/
        function walk(node, cb, to_visit = [node]) {
            const push = to_visit.push.bind(to_visit);
            while (to_visit.length) {
                const node = to_visit.pop();
                const ret = cb(node, to_visit);
                if (ret) {
                    if (ret === walk_abort)
                        return true;
                    continue;
                }
                node._children_backwards(push);
            }
            return false;
        }
        /**
         * Walks an AST node and its children.
         *
         * {cb} can return `walk_abort` to interrupt the walk.
         *
         * @param node
         * @param cb {(node, info: { parent: (nth) => any }) => (boolean | undefined)}
         *
         * @returns {boolean} whether the walk was aborted
         *
         * @example
         * const found_some_cond = walk_parent(my_ast_node, (node, { parent }) => {
         *   if (some_cond(node, parent())) return walk_abort
         * });
         */
        function walk_parent(node, cb, initial_stack) {
            const to_visit = [node];
            const push = to_visit.push.bind(to_visit);
            const stack = initial_stack ? initial_stack.slice() : [];
            const parent_pop_indices = [];
            let current;
            const info = {
                parent: (n = 0) => {
                    if (n === -1) {
                        return current;
                    }
                    // [ p1 p0 ] [ 1 0 ]
                    if (initial_stack && n >= stack.length) {
                        n -= stack.length;
                        return initial_stack[initial_stack.length - (n + 1)];
                    }
                    return stack[stack.length - (1 + n)];
                },
            };
            while (to_visit.length) {
                current = to_visit.pop();
                while (parent_pop_indices.length &&
                    to_visit.length == parent_pop_indices[parent_pop_indices.length - 1]) {
                    stack.pop();
                    parent_pop_indices.pop();
                }
                const ret = cb(current, info);
                if (ret) {
                    if (ret === walk_abort)
                        return true;
                    continue;
                }
                const visit_length = to_visit.length;
                current._children_backwards(push);
                // Push only if we're going to traverse the children
                if (to_visit.length > visit_length) {
                    stack.push(current);
                    parent_pop_indices.push(visit_length - 1);
                }
            }
            return false;
        }
        const walk_abort = Symbol("abort walk");
        /* -----[ TreeWalker ]----- */
        class TreeWalker {
            constructor(callback) {
                this.visit = callback;
                this.stack = [];
                this.directives = Object.create(null);
            }
            _visit(node, descend) {
                this.push(node);
                var ret = this.visit(node, descend ? function () {
                    descend.call(node);
                } : noop);
                if (!ret && descend) {
                    descend.call(node);
                }
                this.pop();
                return ret;
            }
            parent(n) {
                return this.stack[this.stack.length - 2 - (n || 0)];
            }
            push(node) {
                if (node instanceof AST_Lambda) {
                    this.directives = Object.create(this.directives);
                }
                else if (node instanceof AST_Directive && !this.directives[node.value]) {
                    this.directives[node.value] = node;
                }
                else if (node instanceof AST_Class) {
                    this.directives = Object.create(this.directives);
                    if (!this.directives["use strict"]) {
                        this.directives["use strict"] = node;
                    }
                }
                this.stack.push(node);
            }
            pop() {
                var node = this.stack.pop();
                if (node instanceof AST_Lambda || node instanceof AST_Class) {
                    this.directives = Object.getPrototypeOf(this.directives);
                }
            }
            self() {
                return this.stack[this.stack.length - 1];
            }
            find_parent(type) {
                var stack = this.stack;
                for (var i = stack.length; --i >= 0;) {
                    var x = stack[i];
                    if (x instanceof type)
                        return x;
                }
            }
            find_scope() {
                var stack = this.stack;
                for (var i = stack.length; --i >= 0;) {
                    const p = stack[i];
                    if (p instanceof AST_Toplevel)
                        return p;
                    if (p instanceof AST_Lambda)
                        return p;
                    if (p.block_scope)
                        return p.block_scope;
                }
            }
            has_directive(type) {
                var dir = this.directives[type];
                if (dir)
                    return dir;
                var node = this.stack[this.stack.length - 1];
                if (node instanceof AST_Scope && node.body) {
                    for (var i = 0; i < node.body.length; ++i) {
                        var st = node.body[i];
                        if (!(st instanceof AST_Directive))
                            break;
                        if (st.value == type)
                            return st;
                    }
                }
            }
            loopcontrol_target(node) {
                var stack = this.stack;
                if (node.label)
                    for (var i = stack.length; --i >= 0;) {
                        var x = stack[i];
                        if (x instanceof AST_LabeledStatement && x.label.name == node.label.name)
                            return x.body;
                    }
                else
                    for (var i = stack.length; --i >= 0;) {
                        var x = stack[i];
                        if (x instanceof AST_IterationStatement
                            || node instanceof AST_Break && x instanceof AST_Switch)
                            return x;
                    }
            }
        }
        // Tree transformer helpers.
        class TreeTransformer extends TreeWalker {
            constructor(before, after) {
                super();
                this.before = before;
                this.after = after;
            }
        }
        const _PURE = 0b00000001;
        const _INLINE = 0b00000010;
        const _NOINLINE = 0b00000100;
        const _KEY = 0b00001000;
        const _MANGLEPROP = 0b00010000;
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        function def_transform(node, descend) {
            node.DEFMETHOD("transform", function (tw, in_list) {
                let transformed = undefined;
                tw.push(this);
                if (tw.before)
                    transformed = tw.before(this, descend, in_list);
                if (transformed === undefined) {
                    transformed = this;
                    descend(transformed, tw);
                    if (tw.after) {
                        const after_ret = tw.after(transformed, in_list);
                        if (after_ret !== undefined)
                            transformed = after_ret;
                    }
                }
                tw.pop();
                return transformed;
            });
        }
        def_transform(AST_Node, noop);
        def_transform(AST_LabeledStatement, function (self, tw) {
            self.label = self.label.transform(tw);
            self.body = self.body.transform(tw);
        });
        def_transform(AST_SimpleStatement, function (self, tw) {
            self.body = self.body.transform(tw);
        });
        def_transform(AST_Block, function (self, tw) {
            self.body = MAP(self.body, tw);
        });
        def_transform(AST_Do, function (self, tw) {
            self.body = self.body.transform(tw);
            self.condition = self.condition.transform(tw);
        });
        def_transform(AST_While, function (self, tw) {
            self.condition = self.condition.transform(tw);
            self.body = self.body.transform(tw);
        });
        def_transform(AST_For, function (self, tw) {
            if (self.init)
                self.init = self.init.transform(tw);
            if (self.condition)
                self.condition = self.condition.transform(tw);
            if (self.step)
                self.step = self.step.transform(tw);
            self.body = self.body.transform(tw);
        });
        def_transform(AST_ForIn, function (self, tw) {
            self.init = self.init.transform(tw);
            self.object = self.object.transform(tw);
            self.body = self.body.transform(tw);
        });
        def_transform(AST_With, function (self, tw) {
            self.expression = self.expression.transform(tw);
            self.body = self.body.transform(tw);
        });
        def_transform(AST_Exit, function (self, tw) {
            if (self.value)
                self.value = self.value.transform(tw);
        });
        def_transform(AST_LoopControl, function (self, tw) {
            if (self.label)
                self.label = self.label.transform(tw);
        });
        def_transform(AST_If, function (self, tw) {
            self.condition = self.condition.transform(tw);
            self.body = self.body.transform(tw);
            if (self.alternative)
                self.alternative = self.alternative.transform(tw);
        });
        def_transform(AST_Switch, function (self, tw) {
            self.expression = self.expression.transform(tw);
            self.body = MAP(self.body, tw);
        });
        def_transform(AST_Case, function (self, tw) {
            self.expression = self.expression.transform(tw);
            self.body = MAP(self.body, tw);
        });
        def_transform(AST_Try, function (self, tw) {
            self.body = self.body.transform(tw);
            if (self.bcatch)
                self.bcatch = self.bcatch.transform(tw);
            if (self.bfinally)
                self.bfinally = self.bfinally.transform(tw);
        });
        def_transform(AST_Catch, function (self, tw) {
            if (self.argname)
                self.argname = self.argname.transform(tw);
            self.body = MAP(self.body, tw);
        });
        def_transform(AST_Definitions, function (self, tw) {
            self.definitions = MAP(self.definitions, tw);
        });
        def_transform(AST_VarDef, function (self, tw) {
            self.name = self.name.transform(tw);
            if (self.value)
                self.value = self.value.transform(tw);
        });
        def_transform(AST_Destructuring, function (self, tw) {
            self.names = MAP(self.names, tw);
        });
        def_transform(AST_Lambda, function (self, tw) {
            if (self.name)
                self.name = self.name.transform(tw);
            self.argnames = MAP(self.argnames, tw, /* allow_splicing */ false);
            if (self.body instanceof AST_Node) {
                self.body = self.body.transform(tw);
            }
            else {
                self.body = MAP(self.body, tw);
            }
        });
        def_transform(AST_Call, function (self, tw) {
            self.expression = self.expression.transform(tw);
            self.args = MAP(self.args, tw, /* allow_splicing */ false);
        });
        def_transform(AST_Sequence, function (self, tw) {
            const result = MAP(self.expressions, tw);
            self.expressions = result.length
                ? result
                : [new AST_Number({ value: 0 })];
        });
        def_transform(AST_PropAccess, function (self, tw) {
            self.expression = self.expression.transform(tw);
        });
        def_transform(AST_Sub, function (self, tw) {
            self.expression = self.expression.transform(tw);
            self.property = self.property.transform(tw);
        });
        def_transform(AST_Chain, function (self, tw) {
            self.expression = self.expression.transform(tw);
        });
        def_transform(AST_Yield, function (self, tw) {
            if (self.expression)
                self.expression = self.expression.transform(tw);
        });
        def_transform(AST_Await, function (self, tw) {
            self.expression = self.expression.transform(tw);
        });
        def_transform(AST_Unary, function (self, tw) {
            self.expression = self.expression.transform(tw);
        });
        def_transform(AST_Binary, function (self, tw) {
            self.left = self.left.transform(tw);
            self.right = self.right.transform(tw);
        });
        def_transform(AST_PrivateIn, function (self, tw) {
            self.key = self.key.transform(tw);
            self.value = self.value.transform(tw);
        });
        def_transform(AST_Conditional, function (self, tw) {
            self.condition = self.condition.transform(tw);
            self.consequent = self.consequent.transform(tw);
            self.alternative = self.alternative.transform(tw);
        });
        def_transform(AST_Array, function (self, tw) {
            self.elements = MAP(self.elements, tw);
        });
        def_transform(AST_Object, function (self, tw) {
            self.properties = MAP(self.properties, tw);
        });
        def_transform(AST_ObjectProperty, function (self, tw) {
            if (self.key instanceof AST_Node) {
                self.key = self.key.transform(tw);
            }
            if (self.value)
                self.value = self.value.transform(tw);
        });
        def_transform(AST_Class, function (self, tw) {
            if (self.name)
                self.name = self.name.transform(tw);
            if (self.extends)
                self.extends = self.extends.transform(tw);
            self.properties = MAP(self.properties, tw);
        });
        def_transform(AST_ClassStaticBlock, function (self, tw) {
            self.body = MAP(self.body, tw);
        });
        def_transform(AST_Expansion, function (self, tw) {
            self.expression = self.expression.transform(tw);
        });
        def_transform(AST_NameMapping, function (self, tw) {
            self.foreign_name = self.foreign_name.transform(tw);
            self.name = self.name.transform(tw);
        });
        def_transform(AST_Import, function (self, tw) {
            if (self.imported_name)
                self.imported_name = self.imported_name.transform(tw);
            if (self.imported_names)
                MAP(self.imported_names, tw);
            self.module_name = self.module_name.transform(tw);
        });
        def_transform(AST_Export, function (self, tw) {
            if (self.exported_definition)
                self.exported_definition = self.exported_definition.transform(tw);
            if (self.exported_value)
                self.exported_value = self.exported_value.transform(tw);
            if (self.exported_names)
                MAP(self.exported_names, tw);
            if (self.module_name)
                self.module_name = self.module_name.transform(tw);
        });
        def_transform(AST_TemplateString, function (self, tw) {
            self.segments = MAP(self.segments, tw);
        });
        def_transform(AST_PrefixedTemplateString, function (self, tw) {
            self.prefix = self.prefix.transform(tw);
            self.template_string = self.template_string.transform(tw);
        });
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        (function () {
            var normalize_directives = function (body) {
                for (var i = 0; i < body.length; i++) {
                    if (body[i] instanceof AST_Statement && body[i].body instanceof AST_String) {
                        body[i] = new AST_Directive({
                            start: body[i].start,
                            end: body[i].end,
                            value: body[i].body.value
                        });
                    }
                    else {
                        return body;
                    }
                }
                return body;
            };
            const assert_clause_from_moz = (assertions) => {
                if (assertions && assertions.length > 0) {
                    return new AST_Object({
                        start: my_start_token(assertions),
                        end: my_end_token(assertions),
                        properties: assertions.map((assertion_kv) => new AST_ObjectKeyVal({
                            start: my_start_token(assertion_kv),
                            end: my_end_token(assertion_kv),
                            key: assertion_kv.key.name || assertion_kv.key.value,
                            value: from_moz(assertion_kv.value)
                        }))
                    });
                }
                return null;
            };
            var MOZ_TO_ME = {
                Program: function (M) {
                    return new AST_Toplevel({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        body: normalize_directives(M.body.map(from_moz))
                    });
                },
                ArrayPattern: function (M) {
                    return new AST_Destructuring({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        names: M.elements.map(function (elm) {
                            if (elm === null) {
                                return new AST_Hole();
                            }
                            return from_moz(elm);
                        }),
                        is_array: true
                    });
                },
                ObjectPattern: function (M) {
                    return new AST_Destructuring({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        names: M.properties.map(from_moz),
                        is_array: false
                    });
                },
                AssignmentPattern: function (M) {
                    return new AST_DefaultAssign({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        left: from_moz(M.left),
                        operator: "=",
                        right: from_moz(M.right)
                    });
                },
                SpreadElement: function (M) {
                    return new AST_Expansion({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        expression: from_moz(M.argument)
                    });
                },
                RestElement: function (M) {
                    return new AST_Expansion({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        expression: from_moz(M.argument)
                    });
                },
                TemplateElement: function (M) {
                    return new AST_TemplateSegment({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        value: M.value.cooked,
                        raw: M.value.raw
                    });
                },
                TemplateLiteral: function (M) {
                    var segments = [];
                    for (var i = 0; i < M.quasis.length; i++) {
                        segments.push(from_moz(M.quasis[i]));
                        if (M.expressions[i]) {
                            segments.push(from_moz(M.expressions[i]));
                        }
                    }
                    return new AST_TemplateString({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        segments: segments
                    });
                },
                TaggedTemplateExpression: function (M) {
                    return new AST_PrefixedTemplateString({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        template_string: from_moz(M.quasi),
                        prefix: from_moz(M.tag)
                    });
                },
                FunctionDeclaration: function (M) {
                    return new AST_Defun({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        name: from_moz(M.id),
                        argnames: M.params.map(from_moz),
                        is_generator: M.generator,
                        async: M.async,
                        body: normalize_directives(from_moz(M.body).body)
                    });
                },
                FunctionExpression: function (M) {
                    return new AST_Function({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        name: from_moz(M.id),
                        argnames: M.params.map(from_moz),
                        is_generator: M.generator,
                        async: M.async,
                        body: normalize_directives(from_moz(M.body).body)
                    });
                },
                ArrowFunctionExpression: function (M) {
                    const body = M.body.type === "BlockStatement"
                        ? from_moz(M.body).body
                        : [make_node(AST_Return, {}, { value: from_moz(M.body) })];
                    return new AST_Arrow({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        argnames: M.params.map(from_moz),
                        body,
                        async: M.async,
                    });
                },
                ExpressionStatement: function (M) {
                    return new AST_SimpleStatement({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        body: from_moz(M.expression)
                    });
                },
                TryStatement: function (M) {
                    var handlers = M.handlers || [M.handler];
                    if (handlers.length > 1 || M.guardedHandlers && M.guardedHandlers.length) {
                        throw new Error("Multiple catch clauses are not supported.");
                    }
                    return new AST_Try({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        body: new AST_TryBlock(from_moz(M.block)),
                        bcatch: from_moz(handlers[0]),
                        bfinally: M.finalizer ? new AST_Finally(from_moz(M.finalizer)) : null
                    });
                },
                Property: function (M) {
                    var key = M.key;
                    var args = {
                        start: my_start_token(key || M.value),
                        end: my_end_token(M.value),
                        key: key.type == "Identifier" ? key.name : key.value,
                        value: from_moz(M.value)
                    };
                    if (M.computed) {
                        args.key = from_moz(M.key);
                    }
                    if (M.method) {
                        args.is_generator = M.value.generator;
                        args.async = M.value.async;
                        if (!M.computed) {
                            args.key = new AST_SymbolMethod({ name: args.key });
                        }
                        else {
                            args.key = from_moz(M.key);
                        }
                        return new AST_ConciseMethod(args);
                    }
                    if (M.kind == "init") {
                        if (key.type != "Identifier" && key.type != "Literal") {
                            args.key = from_moz(key);
                        }
                        return new AST_ObjectKeyVal(args);
                    }
                    if (typeof args.key === "string" || typeof args.key === "number") {
                        args.key = new AST_SymbolMethod({
                            name: args.key
                        });
                    }
                    args.value = new AST_Accessor(args.value);
                    if (M.kind == "get")
                        return new AST_ObjectGetter(args);
                    if (M.kind == "set")
                        return new AST_ObjectSetter(args);
                    if (M.kind == "method") {
                        args.async = M.value.async;
                        args.is_generator = M.value.generator;
                        args.quote = M.computed ? "\"" : null;
                        return new AST_ConciseMethod(args);
                    }
                },
                MethodDefinition: function (M) {
                    const is_private = M.key.type === "PrivateIdentifier";
                    const key = M.computed ? from_moz(M.key) : new AST_SymbolMethod({ name: M.key.name || M.key.value });
                    var args = {
                        start: my_start_token(M),
                        end: my_end_token(M),
                        key,
                        value: from_moz(M.value),
                        static: M.static,
                    };
                    if (M.kind == "get") {
                        return new (is_private ? AST_PrivateGetter : AST_ObjectGetter)(args);
                    }
                    if (M.kind == "set") {
                        return new (is_private ? AST_PrivateSetter : AST_ObjectSetter)(args);
                    }
                    args.is_generator = M.value.generator;
                    args.async = M.value.async;
                    return new (is_private ? AST_PrivateMethod : AST_ConciseMethod)(args);
                },
                FieldDefinition: function (M) {
                    let key;
                    if (M.computed) {
                        key = from_moz(M.key);
                    }
                    else {
                        if (M.key.type !== "Identifier")
                            throw new Error("Non-Identifier key in FieldDefinition");
                        key = from_moz(M.key);
                    }
                    return new AST_ClassProperty({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        key,
                        value: from_moz(M.value),
                        static: M.static,
                    });
                },
                PropertyDefinition: function (M) {
                    let key;
                    if (M.computed) {
                        key = from_moz(M.key);
                    }
                    else if (M.key.type === "PrivateIdentifier") {
                        return new AST_ClassPrivateProperty({
                            start: my_start_token(M),
                            end: my_end_token(M),
                            key: from_moz(M.key),
                            value: from_moz(M.value),
                            static: M.static,
                        });
                    }
                    else {
                        if (M.key.type !== "Identifier") {
                            throw new Error("Non-Identifier key in PropertyDefinition");
                        }
                        key = from_moz(M.key);
                    }
                    return new AST_ClassProperty({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        key,
                        value: from_moz(M.value),
                        static: M.static,
                    });
                },
                PrivateIdentifier: function (M) {
                    return new AST_SymbolPrivateProperty({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        name: M.name
                    });
                },
                StaticBlock: function (M) {
                    return new AST_ClassStaticBlock({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        body: M.body.map(from_moz),
                    });
                },
                ArrayExpression: function (M) {
                    return new AST_Array({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        elements: M.elements.map(function (elem) {
                            return elem === null ? new AST_Hole() : from_moz(elem);
                        })
                    });
                },
                ObjectExpression: function (M) {
                    return new AST_Object({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        properties: M.properties.map(function (prop) {
                            if (prop.type === "SpreadElement") {
                                return from_moz(prop);
                            }
                            prop.type = "Property";
                            return from_moz(prop);
                        })
                    });
                },
                SequenceExpression: function (M) {
                    return new AST_Sequence({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        expressions: M.expressions.map(from_moz)
                    });
                },
                MemberExpression: function (M) {
                    if (M.property.type === "PrivateIdentifier") {
                        return new AST_DotHash({
                            start: my_start_token(M),
                            end: my_end_token(M),
                            property: M.property.name,
                            expression: from_moz(M.object),
                            optional: M.optional || false
                        });
                    }
                    return new (M.computed ? AST_Sub : AST_Dot)({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        property: M.computed ? from_moz(M.property) : M.property.name,
                        expression: from_moz(M.object),
                        optional: M.optional || false
                    });
                },
                ChainExpression: function (M) {
                    return new AST_Chain({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        expression: from_moz(M.expression)
                    });
                },
                SwitchCase: function (M) {
                    return new (M.test ? AST_Case : AST_Default)({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        expression: from_moz(M.test),
                        body: M.consequent.map(from_moz)
                    });
                },
                VariableDeclaration: function (M) {
                    return new (M.kind === "const" ? AST_Const :
                        M.kind === "let" ? AST_Let : AST_Var)({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        definitions: M.declarations.map(from_moz)
                    });
                },
                ImportDeclaration: function (M) {
                    var imported_name = null;
                    var imported_names = null;
                    M.specifiers.forEach(function (specifier) {
                        if (specifier.type === "ImportSpecifier" || specifier.type === "ImportNamespaceSpecifier") {
                            if (!imported_names) {
                                imported_names = [];
                            }
                            imported_names.push(from_moz(specifier));
                        }
                        else if (specifier.type === "ImportDefaultSpecifier") {
                            imported_name = from_moz(specifier);
                        }
                    });
                    return new AST_Import({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        imported_name: imported_name,
                        imported_names: imported_names,
                        module_name: from_moz(M.source),
                        assert_clause: assert_clause_from_moz(M.assertions)
                    });
                },
                ImportSpecifier: function (M) {
                    return new AST_NameMapping({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        foreign_name: from_moz(M.imported),
                        name: from_moz(M.local)
                    });
                },
                ImportDefaultSpecifier: function (M) {
                    return from_moz(M.local);
                },
                ImportNamespaceSpecifier: function (M) {
                    return new AST_NameMapping({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        foreign_name: new AST_SymbolImportForeign({ name: "*" }),
                        name: from_moz(M.local)
                    });
                },
                ExportAllDeclaration: function (M) {
                    var foreign_name = M.exported == null ?
                        new AST_SymbolExportForeign({ name: "*" }) :
                        from_moz(M.exported);
                    return new AST_Export({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        exported_names: [
                            new AST_NameMapping({
                                name: new AST_SymbolExportForeign({ name: "*" }),
                                foreign_name: foreign_name
                            })
                        ],
                        module_name: from_moz(M.source),
                        assert_clause: assert_clause_from_moz(M.assertions)
                    });
                },
                ExportNamedDeclaration: function (M) {
                    return new AST_Export({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        exported_definition: from_moz(M.declaration),
                        exported_names: M.specifiers && M.specifiers.length ? M.specifiers.map(from_moz) : null,
                        module_name: from_moz(M.source),
                        assert_clause: assert_clause_from_moz(M.assertions)
                    });
                },
                ExportDefaultDeclaration: function (M) {
                    return new AST_Export({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        exported_value: from_moz(M.declaration),
                        is_default: true
                    });
                },
                ExportSpecifier: function (M) {
                    return new AST_NameMapping({
                        foreign_name: from_moz(M.exported),
                        name: from_moz(M.local)
                    });
                },
                Literal: function (M) {
                    var val = M.value, args = {
                        start: my_start_token(M),
                        end: my_end_token(M)
                    };
                    var rx = M.regex;
                    if (rx && rx.pattern) {
                        // RegExpLiteral as per ESTree AST spec
                        args.value = {
                            source: rx.pattern,
                            flags: rx.flags
                        };
                        return new AST_RegExp(args);
                    }
                    else if (rx) {
                        // support legacy RegExp
                        const rx_source = M.raw || val;
                        const match = rx_source.match(/^\/(.*)\/(\w*)$/);
                        if (!match)
                            throw new Error("Invalid regex source " + rx_source);
                        const [_, source, flags] = match;
                        args.value = { source, flags };
                        return new AST_RegExp(args);
                    }
                    if (val === null)
                        return new AST_Null(args);
                    switch (typeof val) {
                        case "string":
                            args.quote = "\"";
                            var p = FROM_MOZ_STACK[FROM_MOZ_STACK.length - 2];
                            if (p.type == "ImportSpecifier") {
                                args.name = val;
                                return new AST_SymbolImportForeign(args);
                            }
                            else if (p.type == "ExportSpecifier") {
                                args.name = val;
                                if (M == p.exported) {
                                    return new AST_SymbolExportForeign(args);
                                }
                                else {
                                    return new AST_SymbolExport(args);
                                }
                            }
                            else if (p.type == "ExportAllDeclaration" && M == p.exported) {
                                args.name = val;
                                return new AST_SymbolExportForeign(args);
                            }
                            args.value = val;
                            return new AST_String(args);
                        case "number":
                            args.value = val;
                            args.raw = M.raw || val.toString();
                            return new AST_Number(args);
                        case "boolean":
                            return new (val ? AST_True : AST_False)(args);
                    }
                },
                MetaProperty: function (M) {
                    if (M.meta.name === "new" && M.property.name === "target") {
                        return new AST_NewTarget({
                            start: my_start_token(M),
                            end: my_end_token(M)
                        });
                    }
                    else if (M.meta.name === "import" && M.property.name === "meta") {
                        return new AST_ImportMeta({
                            start: my_start_token(M),
                            end: my_end_token(M)
                        });
                    }
                },
                Identifier: function (M) {
                    var p = FROM_MOZ_STACK[FROM_MOZ_STACK.length - 2];
                    return new (p.type == "LabeledStatement" ? AST_Label
                        : p.type == "VariableDeclarator" && p.id === M ? (p.kind == "const" ? AST_SymbolConst : p.kind == "let" ? AST_SymbolLet : AST_SymbolVar)
                            : /Import.*Specifier/.test(p.type) ? (p.local === M ? AST_SymbolImport : AST_SymbolImportForeign)
                                : p.type == "ExportSpecifier" ? (p.local === M ? AST_SymbolExport : AST_SymbolExportForeign)
                                    : p.type == "FunctionExpression" ? (p.id === M ? AST_SymbolLambda : AST_SymbolFunarg)
                                        : p.type == "FunctionDeclaration" ? (p.id === M ? AST_SymbolDefun : AST_SymbolFunarg)
                                            : p.type == "ArrowFunctionExpression" ? (p.params.includes(M)) ? AST_SymbolFunarg : AST_SymbolRef
                                                : p.type == "ClassExpression" ? (p.id === M ? AST_SymbolClass : AST_SymbolRef)
                                                    : p.type == "Property" ? (p.key === M && p.computed || p.value === M ? AST_SymbolRef : AST_SymbolMethod)
                                                        : p.type == "PropertyDefinition" || p.type === "FieldDefinition" ? (p.key === M && p.computed || p.value === M ? AST_SymbolRef : AST_SymbolClassProperty)
                                                            : p.type == "ClassDeclaration" ? (p.id === M ? AST_SymbolDefClass : AST_SymbolRef)
                                                                : p.type == "MethodDefinition" ? (p.computed ? AST_SymbolRef : AST_SymbolMethod)
                                                                    : p.type == "CatchClause" ? AST_SymbolCatch
                                                                        : p.type == "BreakStatement" || p.type == "ContinueStatement" ? AST_LabelRef
                                                                            : AST_SymbolRef)({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        name: M.name
                    });
                },
                BigIntLiteral(M) {
                    return new AST_BigInt({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        value: M.value
                    });
                },
                EmptyStatement: function (M) {
                    return new AST_EmptyStatement({
                        start: my_start_token(M),
                        end: my_end_token(M)
                    });
                },
                BlockStatement: function (M) {
                    return new AST_BlockStatement({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        body: M.body.map(from_moz)
                    });
                },
                IfStatement: function (M) {
                    return new AST_If({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        condition: from_moz(M.test),
                        body: from_moz(M.consequent),
                        alternative: from_moz(M.alternate)
                    });
                },
                LabeledStatement: function (M) {
                    return new AST_LabeledStatement({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        label: from_moz(M.label),
                        body: from_moz(M.body)
                    });
                },
                BreakStatement: function (M) {
                    return new AST_Break({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        label: from_moz(M.label)
                    });
                },
                ContinueStatement: function (M) {
                    return new AST_Continue({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        label: from_moz(M.label)
                    });
                },
                WithStatement: function (M) {
                    return new AST_With({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        expression: from_moz(M.object),
                        body: from_moz(M.body)
                    });
                },
                SwitchStatement: function (M) {
                    return new AST_Switch({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        expression: from_moz(M.discriminant),
                        body: M.cases.map(from_moz)
                    });
                },
                ReturnStatement: function (M) {
                    return new AST_Return({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        value: from_moz(M.argument)
                    });
                },
                ThrowStatement: function (M) {
                    return new AST_Throw({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        value: from_moz(M.argument)
                    });
                },
                WhileStatement: function (M) {
                    return new AST_While({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        condition: from_moz(M.test),
                        body: from_moz(M.body)
                    });
                },
                DoWhileStatement: function (M) {
                    return new AST_Do({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        condition: from_moz(M.test),
                        body: from_moz(M.body)
                    });
                },
                ForStatement: function (M) {
                    return new AST_For({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        init: from_moz(M.init),
                        condition: from_moz(M.test),
                        step: from_moz(M.update),
                        body: from_moz(M.body)
                    });
                },
                ForInStatement: function (M) {
                    return new AST_ForIn({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        init: from_moz(M.left),
                        object: from_moz(M.right),
                        body: from_moz(M.body)
                    });
                },
                ForOfStatement: function (M) {
                    return new AST_ForOf({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        init: from_moz(M.left),
                        object: from_moz(M.right),
                        body: from_moz(M.body),
                        await: M.await
                    });
                },
                AwaitExpression: function (M) {
                    return new AST_Await({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        expression: from_moz(M.argument)
                    });
                },
                YieldExpression: function (M) {
                    return new AST_Yield({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        expression: from_moz(M.argument),
                        is_star: M.delegate
                    });
                },
                DebuggerStatement: function (M) {
                    return new AST_Debugger({
                        start: my_start_token(M),
                        end: my_end_token(M)
                    });
                },
                VariableDeclarator: function (M) {
                    return new AST_VarDef({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        name: from_moz(M.id),
                        value: from_moz(M.init)
                    });
                },
                CatchClause: function (M) {
                    return new AST_Catch({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        argname: from_moz(M.param),
                        body: from_moz(M.body).body
                    });
                },
                ThisExpression: function (M) {
                    return new AST_This({
                        start: my_start_token(M),
                        end: my_end_token(M)
                    });
                },
                Super: function (M) {
                    return new AST_Super({
                        start: my_start_token(M),
                        end: my_end_token(M)
                    });
                },
                BinaryExpression: function (M) {
                    if (M.left.type === "PrivateIdentifier") {
                        return new AST_PrivateIn({
                            start: my_start_token(M),
                            end: my_end_token(M),
                            key: new AST_SymbolPrivateProperty({
                                start: my_start_token(M.left),
                                end: my_end_token(M.left),
                                name: M.left.name
                            }),
                            value: from_moz(M.right),
                        });
                    }
                    return new AST_Binary({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        operator: M.operator,
                        left: from_moz(M.left),
                        right: from_moz(M.right)
                    });
                },
                LogicalExpression: function (M) {
                    return new AST_Binary({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        operator: M.operator,
                        left: from_moz(M.left),
                        right: from_moz(M.right)
                    });
                },
                AssignmentExpression: function (M) {
                    return new AST_Assign({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        operator: M.operator,
                        left: from_moz(M.left),
                        right: from_moz(M.right)
                    });
                },
                ConditionalExpression: function (M) {
                    return new AST_Conditional({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        condition: from_moz(M.test),
                        consequent: from_moz(M.consequent),
                        alternative: from_moz(M.alternate)
                    });
                },
                NewExpression: function (M) {
                    return new AST_New({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        expression: from_moz(M.callee),
                        args: M.arguments.map(from_moz)
                    });
                },
                CallExpression: function (M) {
                    return new AST_Call({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        expression: from_moz(M.callee),
                        optional: M.optional,
                        args: M.arguments.map(from_moz)
                    });
                }
            };
            MOZ_TO_ME.UpdateExpression =
                MOZ_TO_ME.UnaryExpression = function To_Moz_Unary(M) {
                    var prefix = "prefix" in M ? M.prefix
                        : M.type == "UnaryExpression" ? true : false;
                    return new (prefix ? AST_UnaryPrefix : AST_UnaryPostfix)({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        operator: M.operator,
                        expression: from_moz(M.argument)
                    });
                };
            MOZ_TO_ME.ClassDeclaration =
                MOZ_TO_ME.ClassExpression = function From_Moz_Class(M) {
                    return new (M.type === "ClassDeclaration" ? AST_DefClass : AST_ClassExpression)({
                        start: my_start_token(M),
                        end: my_end_token(M),
                        name: from_moz(M.id),
                        extends: from_moz(M.superClass),
                        properties: M.body.body.map(from_moz)
                    });
                };
            def_to_moz(AST_EmptyStatement, function To_Moz_EmptyStatement() {
                return {
                    type: "EmptyStatement"
                };
            });
            def_to_moz(AST_BlockStatement, function To_Moz_BlockStatement(M) {
                return {
                    type: "BlockStatement",
                    body: M.body.map(to_moz)
                };
            });
            def_to_moz(AST_If, function To_Moz_IfStatement(M) {
                return {
                    type: "IfStatement",
                    test: to_moz(M.condition),
                    consequent: to_moz(M.body),
                    alternate: to_moz(M.alternative)
                };
            });
            def_to_moz(AST_LabeledStatement, function To_Moz_LabeledStatement(M) {
                return {
                    type: "LabeledStatement",
                    label: to_moz(M.label),
                    body: to_moz(M.body)
                };
            });
            def_to_moz(AST_Break, function To_Moz_BreakStatement(M) {
                return {
                    type: "BreakStatement",
                    label: to_moz(M.label)
                };
            });
            def_to_moz(AST_Continue, function To_Moz_ContinueStatement(M) {
                return {
                    type: "ContinueStatement",
                    label: to_moz(M.label)
                };
            });
            def_to_moz(AST_With, function To_Moz_WithStatement(M) {
                return {
                    type: "WithStatement",
                    object: to_moz(M.expression),
                    body: to_moz(M.body)
                };
            });
            def_to_moz(AST_Switch, function To_Moz_SwitchStatement(M) {
                return {
                    type: "SwitchStatement",
                    discriminant: to_moz(M.expression),
                    cases: M.body.map(to_moz)
                };
            });
            def_to_moz(AST_Return, function To_Moz_ReturnStatement(M) {
                return {
                    type: "ReturnStatement",
                    argument: to_moz(M.value)
                };
            });
            def_to_moz(AST_Throw, function To_Moz_ThrowStatement(M) {
                return {
                    type: "ThrowStatement",
                    argument: to_moz(M.value)
                };
            });
            def_to_moz(AST_While, function To_Moz_WhileStatement(M) {
                return {
                    type: "WhileStatement",
                    test: to_moz(M.condition),
                    body: to_moz(M.body)
                };
            });
            def_to_moz(AST_Do, function To_Moz_DoWhileStatement(M) {
                return {
                    type: "DoWhileStatement",
                    test: to_moz(M.condition),
                    body: to_moz(M.body)
                };
            });
            def_to_moz(AST_For, function To_Moz_ForStatement(M) {
                return {
                    type: "ForStatement",
                    init: to_moz(M.init),
                    test: to_moz(M.condition),
                    update: to_moz(M.step),
                    body: to_moz(M.body)
                };
            });
            def_to_moz(AST_ForIn, function To_Moz_ForInStatement(M) {
                return {
                    type: "ForInStatement",
                    left: to_moz(M.init),
                    right: to_moz(M.object),
                    body: to_moz(M.body)
                };
            });
            def_to_moz(AST_ForOf, function To_Moz_ForOfStatement(M) {
                return {
                    type: "ForOfStatement",
                    left: to_moz(M.init),
                    right: to_moz(M.object),
                    body: to_moz(M.body),
                    await: M.await
                };
            });
            def_to_moz(AST_Await, function To_Moz_AwaitExpression(M) {
                return {
                    type: "AwaitExpression",
                    argument: to_moz(M.expression)
                };
            });
            def_to_moz(AST_Yield, function To_Moz_YieldExpression(M) {
                return {
                    type: "YieldExpression",
                    argument: to_moz(M.expression),
                    delegate: M.is_star
                };
            });
            def_to_moz(AST_Debugger, function To_Moz_DebuggerStatement() {
                return {
                    type: "DebuggerStatement"
                };
            });
            def_to_moz(AST_VarDef, function To_Moz_VariableDeclarator(M) {
                return {
                    type: "VariableDeclarator",
                    id: to_moz(M.name),
                    init: to_moz(M.value)
                };
            });
            def_to_moz(AST_Catch, function To_Moz_CatchClause(M) {
                return {
                    type: "CatchClause",
                    param: to_moz(M.argname),
                    body: to_moz_block(M)
                };
            });
            def_to_moz(AST_This, function To_Moz_ThisExpression() {
                return {
                    type: "ThisExpression"
                };
            });
            def_to_moz(AST_Super, function To_Moz_Super() {
                return {
                    type: "Super"
                };
            });
            def_to_moz(AST_Binary, function To_Moz_BinaryExpression(M) {
                return {
                    type: "BinaryExpression",
                    operator: M.operator,
                    left: to_moz(M.left),
                    right: to_moz(M.right)
                };
            });
            def_to_moz(AST_Binary, function To_Moz_LogicalExpression(M) {
                return {
                    type: "LogicalExpression",
                    operator: M.operator,
                    left: to_moz(M.left),
                    right: to_moz(M.right)
                };
            });
            def_to_moz(AST_Assign, function To_Moz_AssignmentExpression(M) {
                return {
                    type: "AssignmentExpression",
                    operator: M.operator,
                    left: to_moz(M.left),
                    right: to_moz(M.right)
                };
            });
            def_to_moz(AST_Conditional, function To_Moz_ConditionalExpression(M) {
                return {
                    type: "ConditionalExpression",
                    test: to_moz(M.condition),
                    consequent: to_moz(M.consequent),
                    alternate: to_moz(M.alternative)
                };
            });
            def_to_moz(AST_New, function To_Moz_NewExpression(M) {
                return {
                    type: "NewExpression",
                    callee: to_moz(M.expression),
                    arguments: M.args.map(to_moz)
                };
            });
            def_to_moz(AST_Call, function To_Moz_CallExpression(M) {
                return {
                    type: "CallExpression",
                    callee: to_moz(M.expression),
                    optional: M.optional,
                    arguments: M.args.map(to_moz)
                };
            });
            def_to_moz(AST_Toplevel, function To_Moz_Program(M) {
                return to_moz_scope("Program", M);
            });
            def_to_moz(AST_Expansion, function To_Moz_Spread(M) {
                return {
                    type: to_moz_in_destructuring() ? "RestElement" : "SpreadElement",
                    argument: to_moz(M.expression)
                };
            });
            def_to_moz(AST_PrefixedTemplateString, function To_Moz_TaggedTemplateExpression(M) {
                return {
                    type: "TaggedTemplateExpression",
                    tag: to_moz(M.prefix),
                    quasi: to_moz(M.template_string)
                };
            });
            def_to_moz(AST_TemplateString, function To_Moz_TemplateLiteral(M) {
                var quasis = [];
                var expressions = [];
                for (var i = 0; i < M.segments.length; i++) {
                    if (i % 2 !== 0) {
                        expressions.push(to_moz(M.segments[i]));
                    }
                    else {
                        quasis.push({
                            type: "TemplateElement",
                            value: {
                                raw: M.segments[i].raw,
                                cooked: M.segments[i].value
                            },
                            tail: i === M.segments.length - 1
                        });
                    }
                }
                return {
                    type: "TemplateLiteral",
                    quasis: quasis,
                    expressions: expressions
                };
            });
            def_to_moz(AST_Defun, function To_Moz_FunctionDeclaration(M) {
                return {
                    type: "FunctionDeclaration",
                    id: to_moz(M.name),
                    params: M.argnames.map(to_moz),
                    generator: M.is_generator,
                    async: M.async,
                    body: to_moz_scope("BlockStatement", M)
                };
            });
            def_to_moz(AST_Function, function To_Moz_FunctionExpression(M, parent) {
                var is_generator = parent.is_generator !== undefined ?
                    parent.is_generator : M.is_generator;
                return {
                    type: "FunctionExpression",
                    id: to_moz(M.name),
                    params: M.argnames.map(to_moz),
                    generator: is_generator,
                    async: M.async,
                    body: to_moz_scope("BlockStatement", M)
                };
            });
            def_to_moz(AST_Arrow, function To_Moz_ArrowFunctionExpression(M) {
                var body = {
                    type: "BlockStatement",
                    body: M.body.map(to_moz)
                };
                return {
                    type: "ArrowFunctionExpression",
                    params: M.argnames.map(to_moz),
                    async: M.async,
                    body: body
                };
            });
            def_to_moz(AST_Destructuring, function To_Moz_ObjectPattern(M) {
                if (M.is_array) {
                    return {
                        type: "ArrayPattern",
                        elements: M.names.map(to_moz)
                    };
                }
                return {
                    type: "ObjectPattern",
                    properties: M.names.map(to_moz)
                };
            });
            def_to_moz(AST_Directive, function To_Moz_Directive(M) {
                return {
                    type: "ExpressionStatement",
                    expression: {
                        type: "Literal",
                        value: M.value,
                        raw: M.print_to_string()
                    },
                    directive: M.value
                };
            });
            def_to_moz(AST_SimpleStatement, function To_Moz_ExpressionStatement(M) {
                return {
                    type: "ExpressionStatement",
                    expression: to_moz(M.body)
                };
            });
            def_to_moz(AST_SwitchBranch, function To_Moz_SwitchCase(M) {
                return {
                    type: "SwitchCase",
                    test: to_moz(M.expression),
                    consequent: M.body.map(to_moz)
                };
            });
            def_to_moz(AST_Try, function To_Moz_TryStatement(M) {
                return {
                    type: "TryStatement",
                    block: to_moz_block(M.body),
                    handler: to_moz(M.bcatch),
                    guardedHandlers: [],
                    finalizer: to_moz(M.bfinally)
                };
            });
            def_to_moz(AST_Catch, function To_Moz_CatchClause(M) {
                return {
                    type: "CatchClause",
                    param: to_moz(M.argname),
                    guard: null,
                    body: to_moz_block(M)
                };
            });
            def_to_moz(AST_Definitions, function To_Moz_VariableDeclaration(M) {
                return {
                    type: "VariableDeclaration",
                    kind: M instanceof AST_Const ? "const" :
                        M instanceof AST_Let ? "let" : "var",
                    declarations: M.definitions.map(to_moz)
                };
            });
            const assert_clause_to_moz = assert_clause => {
                const assertions = [];
                if (assert_clause) {
                    for (const { key, value } of assert_clause.properties) {
                        const key_moz = is_basic_identifier_string(key)
                            ? { type: "Identifier", name: key }
                            : { type: "Literal", value: key, raw: JSON.stringify(key) };
                        assertions.push({
                            type: "ImportAttribute",
                            key: key_moz,
                            value: to_moz(value)
                        });
                    }
                }
                return assertions;
            };
            def_to_moz(AST_Export, function To_Moz_ExportDeclaration(M) {
                if (M.exported_names) {
                    var first_exported = M.exported_names[0];
                    var first_exported_name = first_exported.name;
                    if (first_exported_name.name === "*" && !first_exported_name.quote) {
                        var foreign_name = first_exported.foreign_name;
                        var exported = foreign_name.name === "*" && !foreign_name.quote
                            ? null
                            : to_moz(foreign_name);
                        return {
                            type: "ExportAllDeclaration",
                            source: to_moz(M.module_name),
                            exported: exported,
                            assertions: assert_clause_to_moz(M.assert_clause)
                        };
                    }
                    return {
                        type: "ExportNamedDeclaration",
                        specifiers: M.exported_names.map(function (name_mapping) {
                            return {
                                type: "ExportSpecifier",
                                exported: to_moz(name_mapping.foreign_name),
                                local: to_moz(name_mapping.name)
                            };
                        }),
                        declaration: to_moz(M.exported_definition),
                        source: to_moz(M.module_name),
                        assertions: assert_clause_to_moz(M.assert_clause)
                    };
                }
                return {
                    type: M.is_default ? "ExportDefaultDeclaration" : "ExportNamedDeclaration",
                    declaration: to_moz(M.exported_value || M.exported_definition)
                };
            });
            def_to_moz(AST_Import, function To_Moz_ImportDeclaration(M) {
                var specifiers = [];
                if (M.imported_name) {
                    specifiers.push({
                        type: "ImportDefaultSpecifier",
                        local: to_moz(M.imported_name)
                    });
                }
                if (M.imported_names) {
                    var first_imported_foreign_name = M.imported_names[0].foreign_name;
                    if (first_imported_foreign_name.name === "*" && !first_imported_foreign_name.quote) {
                        specifiers.push({
                            type: "ImportNamespaceSpecifier",
                            local: to_moz(M.imported_names[0].name)
                        });
                    }
                    else {
                        M.imported_names.forEach(function (name_mapping) {
                            specifiers.push({
                                type: "ImportSpecifier",
                                local: to_moz(name_mapping.name),
                                imported: to_moz(name_mapping.foreign_name)
                            });
                        });
                    }
                }
                return {
                    type: "ImportDeclaration",
                    specifiers: specifiers,
                    source: to_moz(M.module_name),
                    assertions: assert_clause_to_moz(M.assert_clause)
                };
            });
            def_to_moz(AST_ImportMeta, function To_Moz_MetaProperty() {
                return {
                    type: "MetaProperty",
                    meta: {
                        type: "Identifier",
                        name: "import"
                    },
                    property: {
                        type: "Identifier",
                        name: "meta"
                    }
                };
            });
            def_to_moz(AST_Sequence, function To_Moz_SequenceExpression(M) {
                return {
                    type: "SequenceExpression",
                    expressions: M.expressions.map(to_moz)
                };
            });
            def_to_moz(AST_DotHash, function To_Moz_PrivateMemberExpression(M) {
                return {
                    type: "MemberExpression",
                    object: to_moz(M.expression),
                    computed: false,
                    property: {
                        type: "PrivateIdentifier",
                        name: M.property
                    },
                    optional: M.optional
                };
            });
            def_to_moz(AST_PropAccess, function To_Moz_MemberExpression(M) {
                var isComputed = M instanceof AST_Sub;
                return {
                    type: "MemberExpression",
                    object: to_moz(M.expression),
                    computed: isComputed,
                    property: isComputed ? to_moz(M.property) : { type: "Identifier", name: M.property },
                    optional: M.optional
                };
            });
            def_to_moz(AST_Chain, function To_Moz_ChainExpression(M) {
                return {
                    type: "ChainExpression",
                    expression: to_moz(M.expression)
                };
            });
            def_to_moz(AST_Unary, function To_Moz_Unary(M) {
                return {
                    type: M.operator == "++" || M.operator == "--" ? "UpdateExpression" : "UnaryExpression",
                    operator: M.operator,
                    prefix: M instanceof AST_UnaryPrefix,
                    argument: to_moz(M.expression)
                };
            });
            def_to_moz(AST_Binary, function To_Moz_BinaryExpression(M) {
                if (M.operator == "=" && to_moz_in_destructuring()) {
                    return {
                        type: "AssignmentPattern",
                        left: to_moz(M.left),
                        right: to_moz(M.right)
                    };
                }
                const type = M.operator == "&&" || M.operator == "||" || M.operator === "??"
                    ? "LogicalExpression"
                    : "BinaryExpression";
                return {
                    type,
                    left: to_moz(M.left),
                    operator: M.operator,
                    right: to_moz(M.right)
                };
            });
            def_to_moz(AST_PrivateIn, function To_Moz_BinaryExpression_PrivateIn(M) {
                return {
                    type: "BinaryExpression",
                    left: { type: "PrivateIdentifier", name: M.key.name },
                    operator: "in",
                    right: to_moz(M.value),
                };
            });
            def_to_moz(AST_Array, function To_Moz_ArrayExpression(M) {
                return {
                    type: "ArrayExpression",
                    elements: M.elements.map(to_moz)
                };
            });
            def_to_moz(AST_Object, function To_Moz_ObjectExpression(M) {
                return {
                    type: "ObjectExpression",
                    properties: M.properties.map(to_moz)
                };
            });
            def_to_moz(AST_ObjectProperty, function To_Moz_Property(M, parent) {
                var key = M.key instanceof AST_Node ? to_moz(M.key) : {
                    type: "Identifier",
                    value: M.key
                };
                if (typeof M.key === "number") {
                    key = {
                        type: "Literal",
                        value: Number(M.key)
                    };
                }
                if (typeof M.key === "string") {
                    key = {
                        type: "Identifier",
                        name: M.key
                    };
                }
                var kind;
                var string_or_num = typeof M.key === "string" || typeof M.key === "number";
                var computed = string_or_num ? false : !(M.key instanceof AST_Symbol) || M.key instanceof AST_SymbolRef;
                if (M instanceof AST_ObjectKeyVal) {
                    kind = "init";
                    computed = !string_or_num;
                }
                else if (M instanceof AST_ObjectGetter) {
                    kind = "get";
                }
                else if (M instanceof AST_ObjectSetter) {
                    kind = "set";
                }
                if (M instanceof AST_PrivateGetter || M instanceof AST_PrivateSetter) {
                    const kind = M instanceof AST_PrivateGetter ? "get" : "set";
                    return {
                        type: "MethodDefinition",
                        computed: false,
                        kind: kind,
                        static: M.static,
                        key: {
                            type: "PrivateIdentifier",
                            name: M.key.name
                        },
                        value: to_moz(M.value)
                    };
                }
                if (M instanceof AST_ClassPrivateProperty) {
                    return {
                        type: "PropertyDefinition",
                        key: {
                            type: "PrivateIdentifier",
                            name: M.key.name
                        },
                        value: to_moz(M.value),
                        computed: false,
                        static: M.static
                    };
                }
                if (M instanceof AST_ClassProperty) {
                    return {
                        type: "PropertyDefinition",
                        key,
                        value: to_moz(M.value),
                        computed,
                        static: M.static
                    };
                }
                if (parent instanceof AST_Class) {
                    return {
                        type: "MethodDefinition",
                        computed: computed,
                        kind: kind,
                        static: M.static,
                        key: to_moz(M.key),
                        value: to_moz(M.value)
                    };
                }
                return {
                    type: "Property",
                    computed: computed,
                    kind: kind,
                    key: key,
                    value: to_moz(M.value)
                };
            });
            def_to_moz(AST_ConciseMethod, function To_Moz_MethodDefinition(M, parent) {
                if (parent instanceof AST_Object) {
                    return {
                        type: "Property",
                        computed: !(M.key instanceof AST_Symbol) || M.key instanceof AST_SymbolRef,
                        kind: "init",
                        method: true,
                        shorthand: false,
                        key: to_moz(M.key),
                        value: to_moz(M.value)
                    };
                }
                const key = M instanceof AST_PrivateMethod
                    ? {
                        type: "PrivateIdentifier",
                        name: M.key.name
                    }
                    : to_moz(M.key);
                return {
                    type: "MethodDefinition",
                    kind: M.key === "constructor" ? "constructor" : "method",
                    key,
                    value: to_moz(M.value),
                    computed: !(M.key instanceof AST_Symbol) || M.key instanceof AST_SymbolRef,
                    static: M.static,
                };
            });
            def_to_moz(AST_Class, function To_Moz_Class(M) {
                var type = M instanceof AST_ClassExpression ? "ClassExpression" : "ClassDeclaration";
                return {
                    type: type,
                    superClass: to_moz(M.extends),
                    id: M.name ? to_moz(M.name) : null,
                    body: {
                        type: "ClassBody",
                        body: M.properties.map(to_moz)
                    }
                };
            });
            def_to_moz(AST_ClassStaticBlock, function To_Moz_StaticBlock(M) {
                return {
                    type: "StaticBlock",
                    body: M.body.map(to_moz),
                };
            });
            def_to_moz(AST_NewTarget, function To_Moz_MetaProperty() {
                return {
                    type: "MetaProperty",
                    meta: {
                        type: "Identifier",
                        name: "new"
                    },
                    property: {
                        type: "Identifier",
                        name: "target"
                    }
                };
            });
            def_to_moz(AST_Symbol, function To_Moz_Identifier(M, parent) {
                if ((M instanceof AST_SymbolMethod && parent.quote) ||
                    ((M instanceof AST_SymbolImportForeign ||
                        M instanceof AST_SymbolExportForeign ||
                        M instanceof AST_SymbolExport) && M.quote)) {
                    return {
                        type: "Literal",
                        value: M.name
                    };
                }
                var def = M.definition();
                return {
                    type: "Identifier",
                    name: def ? def.mangled_name || def.name : M.name
                };
            });
            def_to_moz(AST_RegExp, function To_Moz_RegExpLiteral(M) {
                const pattern = M.value.source;
                const flags = M.value.flags;
                return {
                    type: "Literal",
                    value: null,
                    raw: M.print_to_string(),
                    regex: { pattern, flags }
                };
            });
            def_to_moz(AST_Constant, function To_Moz_Literal(M) {
                var value = M.value;
                return {
                    type: "Literal",
                    value: value,
                    raw: M.raw || M.print_to_string()
                };
            });
            def_to_moz(AST_Atom, function To_Moz_Atom(M) {
                return {
                    type: "Identifier",
                    name: String(M.value)
                };
            });
            def_to_moz(AST_BigInt, M => ({
                type: "BigIntLiteral",
                value: M.value
            }));
            AST_Boolean.DEFMETHOD("to_mozilla_ast", AST_Constant.prototype.to_mozilla_ast);
            AST_Null.DEFMETHOD("to_mozilla_ast", AST_Constant.prototype.to_mozilla_ast);
            AST_Hole.DEFMETHOD("to_mozilla_ast", function To_Moz_ArrayHole() { return null; });
            AST_Block.DEFMETHOD("to_mozilla_ast", AST_BlockStatement.prototype.to_mozilla_ast);
            AST_Lambda.DEFMETHOD("to_mozilla_ast", AST_Function.prototype.to_mozilla_ast);
            /* -----[ tools ]----- */
            function my_start_token(moznode) {
                var loc = moznode.loc, start = loc && loc.start;
                var range = moznode.range;
                return new AST_Token("", "", start && start.line || 0, start && start.column || 0, range ? range[0] : moznode.start, false, [], [], loc && loc.source);
            }
            function my_end_token(moznode) {
                var loc = moznode.loc, end = loc && loc.end;
                var range = moznode.range;
                return new AST_Token("", "", end && end.line || 0, end && end.column || 0, range ? range[0] : moznode.end, false, [], [], loc && loc.source);
            }
            var FROM_MOZ_STACK = null;
            function from_moz(node) {
                FROM_MOZ_STACK.push(node);
                var ret = node != null ? MOZ_TO_ME[node.type](node) : null;
                FROM_MOZ_STACK.pop();
                return ret;
            }
            AST_Node.from_mozilla_ast = function (node) {
                var save_stack = FROM_MOZ_STACK;
                FROM_MOZ_STACK = [];
                var ast = from_moz(node);
                FROM_MOZ_STACK = save_stack;
                return ast;
            };
            function set_moz_loc(mynode, moznode) {
                var start = mynode.start;
                var end = mynode.end;
                if (!(start && end)) {
                    return moznode;
                }
                if (start.pos != null && end.endpos != null) {
                    moznode.range = [start.pos, end.endpos];
                }
                if (start.line) {
                    moznode.loc = {
                        start: { line: start.line, column: start.col },
                        end: end.endline ? { line: end.endline, column: end.endcol } : null
                    };
                    if (start.file) {
                        moznode.loc.source = start.file;
                    }
                }
                return moznode;
            }
            function def_to_moz(mytype, handler) {
                mytype.DEFMETHOD("to_mozilla_ast", function (parent) {
                    return set_moz_loc(this, handler(this, parent));
                });
            }
            var TO_MOZ_STACK = null;
            function to_moz(node) {
                if (TO_MOZ_STACK === null) {
                    TO_MOZ_STACK = [];
                }
                TO_MOZ_STACK.push(node);
                var ast = node != null ? node.to_mozilla_ast(TO_MOZ_STACK[TO_MOZ_STACK.length - 2]) : null;
                TO_MOZ_STACK.pop();
                if (TO_MOZ_STACK.length === 0) {
                    TO_MOZ_STACK = null;
                }
                return ast;
            }
            function to_moz_in_destructuring() {
                var i = TO_MOZ_STACK.length;
                while (i--) {
                    if (TO_MOZ_STACK[i] instanceof AST_Destructuring) {
                        return true;
                    }
                }
                return false;
            }
            function to_moz_block(node) {
                return {
                    type: "BlockStatement",
                    body: node.body.map(to_moz)
                };
            }
            function to_moz_scope(type, node) {
                var body = node.body.map(to_moz);
                if (node.body[0] instanceof AST_SimpleStatement && node.body[0].body instanceof AST_String) {
                    body.unshift(to_moz(new AST_EmptyStatement(node.body[0])));
                }
                return {
                    type: type,
                    body: body
                };
            }
        })();
        // return true if the node at the top of the stack (that means the
        // innermost node in the current output) is lexically the first in
        // a statement.
        function first_in_statement(stack) {
            let node = stack.parent(-1);
            for (let i = 0, p; p = stack.parent(i); i++) {
                if (p instanceof AST_Statement && p.body === node)
                    return true;
                if ((p instanceof AST_Sequence && p.expressions[0] === node) ||
                    (p.TYPE === "Call" && p.expression === node) ||
                    (p instanceof AST_PrefixedTemplateString && p.prefix === node) ||
                    (p instanceof AST_Dot && p.expression === node) ||
                    (p instanceof AST_Sub && p.expression === node) ||
                    (p instanceof AST_Chain && p.expression === node) ||
                    (p instanceof AST_Conditional && p.condition === node) ||
                    (p instanceof AST_Binary && p.left === node) ||
                    (p instanceof AST_UnaryPostfix && p.expression === node)) {
                    node = p;
                }
                else {
                    return false;
                }
            }
        }
        // Returns whether the leftmost item in the expression is an object
        function left_is_object(node) {
            if (node instanceof AST_Object)
                return true;
            if (node instanceof AST_Sequence)
                return left_is_object(node.expressions[0]);
            if (node.TYPE === "Call")
                return left_is_object(node.expression);
            if (node instanceof AST_PrefixedTemplateString)
                return left_is_object(node.prefix);
            if (node instanceof AST_Dot || node instanceof AST_Sub)
                return left_is_object(node.expression);
            if (node instanceof AST_Chain)
                return left_is_object(node.expression);
            if (node instanceof AST_Conditional)
                return left_is_object(node.condition);
            if (node instanceof AST_Binary)
                return left_is_object(node.left);
            if (node instanceof AST_UnaryPostfix)
                return left_is_object(node.expression);
            return false;
        }
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        const CODE_LINE_BREAK = 10;
        const CODE_SPACE = 32;
        const r_annotation = /[@#]__(PURE|INLINE|NOINLINE)__/;
        function is_some_comments(comment) {
            // multiline comment
            return ((comment.type === "comment2" || comment.type === "comment1")
                && /@preserve|@copyright|@lic|@cc_on|^\**!/i.test(comment.value));
        }
        const ROPE_COMMIT_WHEN = 8 * 1000;
        class Rope {
            constructor() {
                this.committed = "";
                this.current = "";
            }
            append(str) {
                /** When `this.current` is too long, commit it. */
                if (this.current.length > ROPE_COMMIT_WHEN) {
                    this.committed += this.current + str;
                    this.current = "";
                }
                else {
                    this.current += str;
                }
            }
            insertAt(char, index) {
                const { committed, current } = this;
                if (index < committed.length) {
                    this.committed = committed.slice(0, index) + char + committed.slice(index);
                }
                else if (index === committed.length) {
                    this.committed += char;
                }
                else {
                    index -= committed.length;
                    this.committed += current.slice(0, index) + char;
                    this.current = current.slice(index);
                }
            }
            charAt(index) {
                const { committed } = this;
                if (index < committed.length)
                    return committed[index];
                return this.current[index - committed.length];
            }
            charCodeAt(index) {
                const { committed } = this;
                if (index < committed.length)
                    return committed.charCodeAt(index);
                return this.current.charCodeAt(index - committed.length);
            }
            length() {
                return this.committed.length + this.current.length;
            }
            expectDirective() {
                // /^$|[;{][\s\n]*$/
                let ch, n = this.length();
                if (n <= 0)
                    return true;
                // Skip N whitespace from the end
                while ((ch = this.charCodeAt(--n))
                    && (ch == CODE_SPACE || ch == CODE_LINE_BREAK))
                    ;
                // either ";", or "{", or the string ended
                return !ch || ch === 59 || ch === 123;
            }
            hasNLB() {
                let n = this.length() - 1;
                while (n >= 0) {
                    const code = this.charCodeAt(n--);
                    if (code === CODE_LINE_BREAK)
                        return true;
                    if (code !== CODE_SPACE)
                        return false;
                }
                return true;
            }
            toString() {
                return this.committed + this.current;
            }
        }
        function OutputStream(options) {
            var readonly = !options;
            options = defaults(options, {
                ascii_only: false,
                beautify: false,
                braces: false,
                comments: "some",
                ecma: 5,
                ie8: false,
                indent_level: 4,
                indent_start: 0,
                inline_script: true,
                keep_numbers: false,
                keep_quoted_props: false,
                max_line_len: false,
                preamble: null,
                preserve_annotations: false,
                quote_keys: false,
                quote_style: 0,
                safari10: false,
                semicolons: true,
                shebang: true,
                shorthand: undefined,
                source_map: null,
                webkit: false,
                width: 80,
                wrap_iife: false,
                wrap_func_args: true,
                _destroy_ast: false
            }, true);
            if (options.shorthand === undefined)
                options.shorthand = options.ecma > 5;
            // Convert comment option to RegExp if necessary and set up comments filter
            var comment_filter = return_false; // Default case, throw all comments away
            if (options.comments) {
                let comments = options.comments;
                if (typeof options.comments === "string" && /^\/.*\/[a-zA-Z]*$/.test(options.comments)) {
                    var regex_pos = options.comments.lastIndexOf("/");
                    comments = new RegExp(options.comments.substr(1, regex_pos - 1), options.comments.substr(regex_pos + 1));
                }
                if (comments instanceof RegExp) {
                    comment_filter = function (comment) {
                        return comment.type != "comment5" && comments.test(comment.value);
                    };
                }
                else if (typeof comments === "function") {
                    comment_filter = function (comment) {
                        return comment.type != "comment5" && comments(this, comment);
                    };
                }
                else if (comments === "some") {
                    comment_filter = is_some_comments;
                }
                else { // NOTE includes "all" option
                    comment_filter = return_true;
                }
            }
            if (options.preserve_annotations) {
                let prev_comment_filter = comment_filter;
                comment_filter = function (comment) {
                    return r_annotation.test(comment.value) || prev_comment_filter.apply(this, arguments);
                };
            }
            var indentation = 0;
            var current_col = 0;
            var current_line = 1;
            var current_pos = 0;
            var OUTPUT = new Rope();
            let printed_comments = new Set();
            var to_utf8 = options.ascii_only ? function (str, identifier = false, regexp = false) {
                if (options.ecma >= 2015 && !options.safari10 && !regexp) {
                    str = str.replace(/[\ud800-\udbff][\udc00-\udfff]/g, function (ch) {
                        var code = get_full_char_code(ch, 0).toString(16);
                        return "\\u{" + code + "}";
                    });
                }
                return str.replace(/[\u0000-\u001f\u007f-\uffff]/g, function (ch) {
                    var code = ch.charCodeAt(0).toString(16);
                    if (code.length <= 2 && !identifier) {
                        while (code.length < 2)
                            code = "0" + code;
                        return "\\x" + code;
                    }
                    else {
                        while (code.length < 4)
                            code = "0" + code;
                        return "\\u" + code;
                    }
                });
            } : function (str) {
                return str.replace(/[\ud800-\udbff][\udc00-\udfff]|([\ud800-\udbff]|[\udc00-\udfff])/g, function (match, lone) {
                    if (lone) {
                        return "\\u" + lone.charCodeAt(0).toString(16);
                    }
                    return match;
                });
            };
            function make_string(str, quote) {
                var dq = 0, sq = 0;
                str = str.replace(/[\\\b\f\n\r\v\t\x22\x27\u2028\u2029\0\ufeff]/g, function (s, i) {
                    switch (s) {
                        case '"':
                            ++dq;
                            return '"';
                        case "'":
                            ++sq;
                            return "'";
                        case "\\": return "\\\\";
                        case "\n": return "\\n";
                        case "\r": return "\\r";
                        case "\t": return "\\t";
                        case "\b": return "\\b";
                        case "\f": return "\\f";
                        case "\x0B": return options.ie8 ? "\\x0B" : "\\v";
                        case "\u2028": return "\\u2028";
                        case "\u2029": return "\\u2029";
                        case "\ufeff": return "\\ufeff";
                        case "\0":
                            return /[0-9]/.test(get_full_char(str, i + 1)) ? "\\x00" : "\\0";
                    }
                    return s;
                });
                function quote_single() {
                    return "'" + str.replace(/\x27/g, "\\'") + "'";
                }
                function quote_double() {
                    return '"' + str.replace(/\x22/g, '\\"') + '"';
                }
                function quote_template() {
                    return "`" + str.replace(/`/g, "\\`") + "`";
                }
                str = to_utf8(str);
                if (quote === "`")
                    return quote_template();
                switch (options.quote_style) {
                    case 1:
                        return quote_single();
                    case 2:
                        return quote_double();
                    case 3:
                        return quote == "'" ? quote_single() : quote_double();
                    default:
                        return dq > sq ? quote_single() : quote_double();
                }
            }
            function encode_string(str, quote) {
                var ret = make_string(str, quote);
                if (options.inline_script) {
                    ret = ret.replace(/<\x2f(script)([>\/\t\n\f\r ])/gi, "<\\/$1$2");
                    ret = ret.replace(/\x3c!--/g, "\\x3c!--");
                    ret = ret.replace(/--\x3e/g, "--\\x3e");
                }
                return ret;
            }
            function make_name(name) {
                name = name.toString();
                name = to_utf8(name, true);
                return name;
            }
            function make_indent(back) {
                return " ".repeat(options.indent_start + indentation - back * options.indent_level);
            }
            /* -----[ beautification/minification ]----- */
            var has_parens = false;
            var might_need_space = false;
            var might_need_semicolon = false;
            var might_add_newline = 0;
            var need_newline_indented = false;
            var need_space = false;
            var newline_insert = -1;
            var last = "";
            var mapping_token, mapping_name, mappings = options.source_map && [];
            var do_add_mapping = mappings ? function () {
                mappings.forEach(function (mapping) {
                    try {
                        let { name, token } = mapping;
                        if (name !== false) {
                            if (token.type == "name" || token.type === "privatename") {
                                name = token.value;
                            }
                            else if (name instanceof AST_Symbol) {
                                name = token.type === "string" ? token.value : name.name;
                            }
                        }
                        options.source_map.add(mapping.token.file, mapping.line, mapping.col, mapping.token.line, mapping.token.col, is_basic_identifier_string(name) ? name : undefined);
                    }
                    catch (ex) {
                        // Ignore bad mapping
                    }
                });
                mappings = [];
            } : noop;
            var ensure_line_len = options.max_line_len ? function () {
                if (current_col > options.max_line_len) {
                    if (might_add_newline) {
                        OUTPUT.insertAt("\n", might_add_newline);
                        const len_after_newline = OUTPUT.length() - might_add_newline - 1;
                        if (mappings) {
                            var delta = len_after_newline - current_col;
                            mappings.forEach(function (mapping) {
                                mapping.line++;
                                mapping.col += delta;
                            });
                        }
                        current_line++;
                        current_pos++;
                        current_col = len_after_newline;
                    }
                }
                if (might_add_newline) {
                    might_add_newline = 0;
                    do_add_mapping();
                }
            } : noop;
            var requireSemicolonChars = makePredicate("( [ + * / - , . `");
            function print(str) {
                str = String(str);
                var ch = get_full_char(str, 0);
                if (need_newline_indented && ch) {
                    need_newline_indented = false;
                    if (ch !== "\n") {
                        print("\n");
                        indent();
                    }
                }
                if (need_space && ch) {
                    need_space = false;
                    if (!/[\s;})]/.test(ch)) {
                        space();
                    }
                }
                newline_insert = -1;
                var prev = last.charAt(last.length - 1);
                if (might_need_semicolon) {
                    might_need_semicolon = false;
                    if (prev === ":" && ch === "}" || (!ch || !";}".includes(ch)) && prev !== ";") {
                        if (options.semicolons || requireSemicolonChars.has(ch)) {
                            OUTPUT.append(";");
                            current_col++;
                            current_pos++;
                        }
                        else {
                            ensure_line_len();
                            if (current_col > 0) {
                                OUTPUT.append("\n");
                                current_pos++;
                                current_line++;
                                current_col = 0;
                            }
                            if (/^\s+$/.test(str)) {
                                // reset the semicolon flag, since we didn't print one
                                // now and might still have to later
                                might_need_semicolon = true;
                            }
                        }
                        if (!options.beautify)
                            might_need_space = false;
                    }
                }
                if (might_need_space) {
                    if ((is_identifier_char(prev)
                        && (is_identifier_char(ch) || ch == "\\"))
                        || (ch == "/" && ch == prev)
                        || ((ch == "+" || ch == "-") && ch == last)) {
                        OUTPUT.append(" ");
                        current_col++;
                        current_pos++;
                    }
                    might_need_space = false;
                }
                if (mapping_token) {
                    mappings.push({
                        token: mapping_token,
                        name: mapping_name,
                        line: current_line,
                        col: current_col
                    });
                    mapping_token = false;
                    if (!might_add_newline)
                        do_add_mapping();
                }
                OUTPUT.append(str);
                has_parens = str[str.length - 1] == "(";
                current_pos += str.length;
                var a = str.split(/\r?\n/), n = a.length - 1;
                current_line += n;
                current_col += a[0].length;
                if (n > 0) {
                    ensure_line_len();
                    current_col = a[n].length;
                }
                last = str;
            }
            var star = function () {
                print("*");
            };
            var space = options.beautify ? function () {
                print(" ");
            } : function () {
                might_need_space = true;
            };
            var indent = options.beautify ? function (half) {
                if (options.beautify) {
                    print(make_indent(half ? 0.5 : 0));
                }
            } : noop;
            var with_indent = options.beautify ? function (col, cont) {
                if (col === true)
                    col = next_indent();
                var save_indentation = indentation;
                indentation = col;
                var ret = cont();
                indentation = save_indentation;
                return ret;
            } : function (col, cont) { return cont(); };
            var newline = options.beautify ? function () {
                if (newline_insert < 0)
                    return print("\n");
                if (OUTPUT.charAt(newline_insert) != "\n") {
                    OUTPUT.insertAt("\n", newline_insert);
                    current_pos++;
                    current_line++;
                }
                newline_insert++;
            } : options.max_line_len ? function () {
                ensure_line_len();
                might_add_newline = OUTPUT.length();
            } : noop;
            var semicolon = options.beautify ? function () {
                print(";");
            } : function () {
                might_need_semicolon = true;
            };
            function force_semicolon() {
                might_need_semicolon = false;
                print(";");
            }
            function next_indent() {
                return indentation + options.indent_level;
            }
            function with_block(cont) {
                var ret;
                print("{");
                newline();
                with_indent(next_indent(), function () {
                    ret = cont();
                });
                indent();
                print("}");
                return ret;
            }
            function with_parens(cont) {
                print("(");
                //XXX: still nice to have that for argument lists
                //var ret = with_indent(current_col, cont);
                var ret = cont();
                print(")");
                return ret;
            }
            function with_square(cont) {
                print("[");
                //var ret = with_indent(current_col, cont);
                var ret = cont();
                print("]");
                return ret;
            }
            function comma() {
                print(",");
                space();
            }
            function colon() {
                print(":");
                space();
            }
            var add_mapping = mappings ? function (token, name) {
                mapping_token = token;
                mapping_name = name;
            } : noop;
            function get() {
                if (might_add_newline) {
                    ensure_line_len();
                }
                return OUTPUT.toString();
            }
            function filter_comment(comment) {
                if (!options.preserve_annotations) {
                    comment = comment.replace(r_annotation, " ");
                }
                if (/^\s*$/.test(comment)) {
                    return "";
                }
                return comment.replace(/(<\s*\/\s*)(script)/i, "<\\/$2");
            }
            function prepend_comments(node) {
                var self = this;
                var start = node.start;
                if (!start)
                    return;
                var printed_comments = self.printed_comments;
                // There cannot be a newline between return/yield and its value.
                const keyword_with_value = node instanceof AST_Exit && node.value
                    || (node instanceof AST_Await || node instanceof AST_Yield)
                        && node.expression;
                if (start.comments_before
                    && printed_comments.has(start.comments_before)) {
                    if (keyword_with_value) {
                        start.comments_before = [];
                    }
                    else {
                        return;
                    }
                }
                var comments = start.comments_before;
                if (!comments) {
                    comments = start.comments_before = [];
                }
                printed_comments.add(comments);
                if (keyword_with_value) {
                    var tw = new TreeWalker(function (node) {
                        var parent = tw.parent();
                        if (parent instanceof AST_Exit
                            || parent instanceof AST_Await
                            || parent instanceof AST_Yield
                            || parent instanceof AST_Binary && parent.left === node
                            || parent.TYPE == "Call" && parent.expression === node
                            || parent instanceof AST_Conditional && parent.condition === node
                            || parent instanceof AST_Dot && parent.expression === node
                            || parent instanceof AST_Sequence && parent.expressions[0] === node
                            || parent instanceof AST_Sub && parent.expression === node
                            || parent instanceof AST_UnaryPostfix) {
                            if (!node.start)
                                return;
                            var text = node.start.comments_before;
                            if (text && !printed_comments.has(text)) {
                                printed_comments.add(text);
                                comments = comments.concat(text);
                            }
                        }
                        else {
                            return true;
                        }
                    });
                    tw.push(node);
                    keyword_with_value.walk(tw);
                }
                if (current_pos == 0) {
                    if (comments.length > 0 && options.shebang && comments[0].type === "comment5"
                        && !printed_comments.has(comments[0])) {
                        print("#!" + comments.shift().value + "\n");
                        indent();
                    }
                    var preamble = options.preamble;
                    if (preamble) {
                        print(preamble.replace(/\r\n?|[\n\u2028\u2029]|\s*$/g, "\n"));
                    }
                }
                comments = comments.filter(comment_filter, node).filter(c => !printed_comments.has(c));
                if (comments.length == 0)
                    return;
                var last_nlb = OUTPUT.hasNLB();
                comments.forEach(function (c, i) {
                    printed_comments.add(c);
                    if (!last_nlb) {
                        if (c.nlb) {
                            print("\n");
                            indent();
                            last_nlb = true;
                        }
                        else if (i > 0) {
                            space();
                        }
                    }
                    if (/comment[134]/.test(c.type)) {
                        var value = filter_comment(c.value);
                        if (value) {
                            print("//" + value + "\n");
                            indent();
                        }
                        last_nlb = true;
                    }
                    else if (c.type == "comment2") {
                        var value = filter_comment(c.value);
                        if (value) {
                            print("/*" + value + "*/");
                        }
                        last_nlb = false;
                    }
                });
                if (!last_nlb) {
                    if (start.nlb) {
                        print("\n");
                        indent();
                    }
                    else {
                        space();
                    }
                }
            }
            function append_comments(node, tail) {
                var self = this;
                var token = node.end;
                if (!token)
                    return;
                var printed_comments = self.printed_comments;
                var comments = token[tail ? "comments_before" : "comments_after"];
                if (!comments || printed_comments.has(comments))
                    return;
                if (!(node instanceof AST_Statement || comments.every((c) => !/comment[134]/.test(c.type))))
                    return;
                printed_comments.add(comments);
                var insert = OUTPUT.length();
                comments.filter(comment_filter, node).forEach(function (c, i) {
                    if (printed_comments.has(c))
                        return;
                    printed_comments.add(c);
                    need_space = false;
                    if (need_newline_indented) {
                        print("\n");
                        indent();
                        need_newline_indented = false;
                    }
                    else if (c.nlb && (i > 0 || !OUTPUT.hasNLB())) {
                        print("\n");
                        indent();
                    }
                    else if (i > 0 || !tail) {
                        space();
                    }
                    if (/comment[134]/.test(c.type)) {
                        const value = filter_comment(c.value);
                        if (value) {
                            print("//" + value);
                        }
                        need_newline_indented = true;
                    }
                    else if (c.type == "comment2") {
                        const value = filter_comment(c.value);
                        if (value) {
                            print("/*" + value + "*/");
                        }
                        need_space = true;
                    }
                });
                if (OUTPUT.length() > insert)
                    newline_insert = insert;
            }
            /**
             * When output.option("_destroy_ast") is enabled, destroy the function.
             * Call this after printing it.
             */
            const gc_scope = options["_destroy_ast"]
                ? function gc_scope(scope) {
                    scope.body.length = 0;
                    scope.argnames.length = 0;
                }
                : noop;
            var stack = [];
            return {
                get: get,
                toString: get,
                indent: indent,
                in_directive: false,
                use_asm: null,
                active_scope: null,
                indentation: function () { return indentation; },
                current_width: function () { return current_col - indentation; },
                should_break: function () { return options.width && this.current_width() >= options.width; },
                has_parens: function () { return has_parens; },
                newline: newline,
                print: print,
                star: star,
                space: space,
                comma: comma,
                colon: colon,
                last: function () { return last; },
                semicolon: semicolon,
                force_semicolon: force_semicolon,
                to_utf8: to_utf8,
                print_name: function (name) { print(make_name(name)); },
                print_string: function (str, quote, escape_directive) {
                    var encoded = encode_string(str, quote);
                    if (escape_directive === true && !encoded.includes("\\")) {
                        // Insert semicolons to break directive prologue
                        if (!OUTPUT.expectDirective()) {
                            force_semicolon();
                        }
                        force_semicolon();
                    }
                    print(encoded);
                },
                print_template_string_chars: function (str) {
                    var encoded = encode_string(str, "`").replace(/\${/g, "\\${");
                    return print(encoded.substr(1, encoded.length - 2));
                },
                encode_string: encode_string,
                next_indent: next_indent,
                with_indent: with_indent,
                with_block: with_block,
                with_parens: with_parens,
                with_square: with_square,
                add_mapping: add_mapping,
                option: function (opt) { return options[opt]; },
                gc_scope,
                printed_comments: printed_comments,
                prepend_comments: readonly ? noop : prepend_comments,
                append_comments: readonly || comment_filter === return_false ? noop : append_comments,
                line: function () { return current_line; },
                col: function () { return current_col; },
                pos: function () { return current_pos; },
                push_node: function (node) { stack.push(node); },
                pop_node: function () { return stack.pop(); },
                parent: function (n) {
                    return stack[stack.length - 2 - (n || 0)];
                }
            };
        }
        /* -----[ code generators ]----- */
        (function () {
            /* -----[ utils ]----- */
            function DEFPRINT(nodetype, generator) {
                nodetype.DEFMETHOD("_codegen", generator);
            }
            AST_Node.DEFMETHOD("print", function (output, force_parens) {
                var self = this, generator = self._codegen;
                if (self instanceof AST_Scope) {
                    output.active_scope = self;
                }
                else if (!output.use_asm && self instanceof AST_Directive && self.value == "use asm") {
                    output.use_asm = output.active_scope;
                }
                function doit() {
                    output.prepend_comments(self);
                    self.add_source_map(output);
                    generator(self, output);
                    output.append_comments(self);
                }
                output.push_node(self);
                if (force_parens || self.needs_parens(output)) {
                    output.with_parens(doit);
                }
                else {
                    doit();
                }
                output.pop_node();
                if (self === output.use_asm) {
                    output.use_asm = null;
                }
            });
            AST_Node.DEFMETHOD("_print", AST_Node.prototype.print);
            AST_Node.DEFMETHOD("print_to_string", function (options) {
                var output = OutputStream(options);
                this.print(output);
                return output.get();
            });
            /* -----[ PARENTHESES ]----- */
            function PARENS(nodetype, func) {
                if (Array.isArray(nodetype)) {
                    nodetype.forEach(function (nodetype) {
                        PARENS(nodetype, func);
                    });
                }
                else {
                    nodetype.DEFMETHOD("needs_parens", func);
                }
            }
            PARENS(AST_Node, return_false);
            // a function expression needs parens around it when it's provably
            // the first token to appear in a statement.
            PARENS(AST_Function, function (output) {
                if (!output.has_parens() && first_in_statement(output)) {
                    return true;
                }
                if (output.option("webkit")) {
                    var p = output.parent();
                    if (p instanceof AST_PropAccess && p.expression === this) {
                        return true;
                    }
                }
                if (output.option("wrap_iife")) {
                    var p = output.parent();
                    if (p instanceof AST_Call && p.expression === this) {
                        return true;
                    }
                }
                if (output.option("wrap_func_args")) {
                    var p = output.parent();
                    if (p instanceof AST_Call && p.args.includes(this)) {
                        return true;
                    }
                }
                return false;
            });
            PARENS(AST_Arrow, function (output) {
                var p = output.parent();
                if (output.option("wrap_func_args")
                    && p instanceof AST_Call
                    && p.args.includes(this)) {
                    return true;
                }
                return p instanceof AST_PropAccess && p.expression === this
                    || p instanceof AST_Conditional && p.condition === this;
            });
            // same goes for an object literal (as in AST_Function), because
            // otherwise {...} would be interpreted as a block of code.
            PARENS(AST_Object, function (output) {
                return !output.has_parens() && first_in_statement(output);
            });
            PARENS(AST_ClassExpression, first_in_statement);
            PARENS(AST_Unary, function (output) {
                var p = output.parent();
                return p instanceof AST_PropAccess && p.expression === this
                    || p instanceof AST_Call && p.expression === this
                    || p instanceof AST_Binary
                        && p.operator === "**"
                        && this instanceof AST_UnaryPrefix
                        && p.left === this
                        && this.operator !== "++"
                        && this.operator !== "--";
            });
            PARENS(AST_Await, function (output) {
                var p = output.parent();
                return p instanceof AST_PropAccess && p.expression === this
                    || p instanceof AST_Call && p.expression === this
                    || p instanceof AST_Binary && p.operator === "**" && p.left === this
                    || output.option("safari10") && p instanceof AST_UnaryPrefix;
            });
            PARENS(AST_Sequence, function (output) {
                var p = output.parent();
                return p instanceof AST_Call // (foo, bar)() or foo(1, (2, 3), 4)
                    || p instanceof AST_Unary // !(foo, bar, baz)
                    || p instanceof AST_Binary // 1 + (2, 3) + 4 ==> 8
                    || p instanceof AST_VarDef // var a = (1, 2), b = a + a; ==> b == 4
                    || p instanceof AST_PropAccess // (1, {foo:2}).foo or (1, {foo:2})["foo"] ==> 2
                    || p instanceof AST_Array // [ 1, (2, 3), 4 ] ==> [ 1, 3, 4 ]
                    || p instanceof AST_ObjectProperty // { foo: (1, 2) }.foo ==> 2
                    || p instanceof AST_Conditional /* (false, true) ? (a = 10, b = 20) : (c = 30)
                                                                   * ==> 20 (side effect, set a := 10 and b := 20) */
                    || p instanceof AST_Arrow // x => (x, x)
                    || p instanceof AST_DefaultAssign // x => (x = (0, function(){}))
                    || p instanceof AST_Expansion // [...(a, b)]
                    || p instanceof AST_ForOf && this === p.object // for (e of (foo, bar)) {}
                    || p instanceof AST_Yield // yield (foo, bar)
                    || p instanceof AST_Export // export default (foo, bar)
                ;
            });
            PARENS(AST_Binary, function (output) {
                var p = output.parent();
                // (foo && bar)()
                if (p instanceof AST_Call && p.expression === this)
                    return true;
                // typeof (foo && bar)
                if (p instanceof AST_Unary)
                    return true;
                // (foo && bar)["prop"], (foo && bar).prop
                if (p instanceof AST_PropAccess && p.expression === this)
                    return true;
                // this deals with precedence: 3 * (2 + 1)
                if (p instanceof AST_Binary) {
                    const parent_op = p.operator;
                    const op = this.operator;
                    // It is forbidden for ?? to be used with || or && without parens.
                    if (op === "??" && (parent_op === "||" || parent_op === "&&")) {
                        return true;
                    }
                    if (parent_op === "??" && (op === "||" || op === "&&")) {
                        return true;
                    }
                    const pp = PRECEDENCE[parent_op];
                    const sp = PRECEDENCE[op];
                    if (pp > sp
                        || (pp == sp
                            && (this === p.right || parent_op == "**"))) {
                        return true;
                    }
                }
                if (p instanceof AST_PrivateIn) {
                    const op = this.operator;
                    const pp = PRECEDENCE["in"];
                    const sp = PRECEDENCE[op];
                    if (pp > sp || (pp == sp && this === p.value)) {
                        return true;
                    }
                }
            });
            PARENS(AST_PrivateIn, function (output) {
                var p = output.parent();
                // (#x in this)()
                if (p instanceof AST_Call && p.expression === this) {
                    return true;
                }
                // typeof (#x in this)
                if (p instanceof AST_Unary) {
                    return true;
                }
                // (#x in this)["prop"], (#x in this).prop
                if (p instanceof AST_PropAccess && p.expression === this) {
                    return true;
                }
                // same precedence as regular in operator
                if (p instanceof AST_Binary) {
                    const parent_op = p.operator;
                    const pp = PRECEDENCE[parent_op];
                    const sp = PRECEDENCE["in"];
                    if (pp > sp
                        || (pp == sp
                            && (this === p.right || parent_op == "**"))) {
                        return true;
                    }
                }
                // rules are the same as binary in, but the class differs
                if (p instanceof AST_PrivateIn && this === p.value) {
                    return true;
                }
            });
            PARENS(AST_Yield, function (output) {
                var p = output.parent();
                // (yield 1) + (yield 2)
                // a = yield 3
                if (p instanceof AST_Binary && p.operator !== "=")
                    return true;
                // (yield 1)()
                // new (yield 1)()
                if (p instanceof AST_Call && p.expression === this)
                    return true;
                // (yield 1) ? yield 2 : yield 3
                if (p instanceof AST_Conditional && p.condition === this)
                    return true;
                // -(yield 4)
                if (p instanceof AST_Unary)
                    return true;
                // (yield x).foo
                // (yield x)['foo']
                if (p instanceof AST_PropAccess && p.expression === this)
                    return true;
            });
            PARENS(AST_Chain, function (output) {
                var p = output.parent();
                if (!(p instanceof AST_Call || p instanceof AST_PropAccess))
                    return false;
                return p.expression === this;
            });
            PARENS(AST_PropAccess, function (output) {
                var p = output.parent();
                if (p instanceof AST_New && p.expression === this) {
                    // i.e. new (foo.bar().baz)
                    //
                    // if there's one call into this subtree, then we need
                    // parens around it too, otherwise the call will be
                    // interpreted as passing the arguments to the upper New
                    // expression.
                    return walk(this, node => {
                        if (node instanceof AST_Scope)
                            return true;
                        if (node instanceof AST_Call) {
                            return walk_abort; // makes walk() return true.
                        }
                    });
                }
            });
            PARENS(AST_Call, function (output) {
                var p = output.parent(), p1;
                if (p instanceof AST_New && p.expression === this
                    || p instanceof AST_Export && p.is_default && this.expression instanceof AST_Function)
                    return true;
                // workaround for Safari bug.
                // https://bugs.webkit.org/show_bug.cgi?id=123506
                return this.expression instanceof AST_Function
                    && p instanceof AST_PropAccess
                    && p.expression === this
                    && (p1 = output.parent(1)) instanceof AST_Assign
                    && p1.left === p;
            });
            PARENS(AST_New, function (output) {
                var p = output.parent();
                if (this.args.length === 0
                    && (p instanceof AST_PropAccess // (new Date).getTime(), (new Date)["getTime"]()
                        || p instanceof AST_Call && p.expression === this
                        || p instanceof AST_PrefixedTemplateString && p.prefix === this)) // (new foo)(bar)
                    return true;
            });
            PARENS(AST_Number, function (output) {
                var p = output.parent();
                if (p instanceof AST_PropAccess && p.expression === this) {
                    var value = this.getValue();
                    if (value < 0 || /^0/.test(make_num(value))) {
                        return true;
                    }
                }
            });
            PARENS(AST_BigInt, function (output) {
                var p = output.parent();
                if (p instanceof AST_PropAccess && p.expression === this) {
                    var value = this.getValue();
                    if (value.startsWith("-")) {
                        return true;
                    }
                }
            });
            PARENS([AST_Assign, AST_Conditional], function (output) {
                var p = output.parent();
                // !(a = false) → true
                if (p instanceof AST_Unary)
                    return true;
                // 1 + (a = 2) + 3 → 6, side effect setting a = 2
                if (p instanceof AST_Binary && !(p instanceof AST_Assign))
                    return true;
                // (a = func)() —or— new (a = Object)()
                if (p instanceof AST_Call && p.expression === this)
                    return true;
                // (a = foo) ? bar : baz
                if (p instanceof AST_Conditional && p.condition === this)
                    return true;
                // (a = foo)["prop"] —or— (a = foo).prop
                if (p instanceof AST_PropAccess && p.expression === this)
                    return true;
                // ({a, b} = {a: 1, b: 2}), a destructuring assignment
                if (this instanceof AST_Assign && this.left instanceof AST_Destructuring && this.left.is_array === false)
                    return true;
            });
            /* -----[ PRINTERS ]----- */
            DEFPRINT(AST_Directive, function (self, output) {
                output.print_string(self.value, self.quote);
                output.semicolon();
            });
            DEFPRINT(AST_Expansion, function (self, output) {
                output.print("...");
                self.expression.print(output);
            });
            DEFPRINT(AST_Destructuring, function (self, output) {
                output.print(self.is_array ? "[" : "{");
                var len = self.names.length;
                self.names.forEach(function (name, i) {
                    if (i > 0)
                        output.comma();
                    name.print(output);
                    // If the final element is a hole, we need to make sure it
                    // doesn't look like a trailing comma, by inserting an actual
                    // trailing comma.
                    if (i == len - 1 && name instanceof AST_Hole)
                        output.comma();
                });
                output.print(self.is_array ? "]" : "}");
            });
            DEFPRINT(AST_Debugger, function (self, output) {
                output.print("debugger");
                output.semicolon();
            });
            /* -----[ statements ]----- */
            function display_body(body, is_toplevel, output, allow_directives) {
                var last = body.length - 1;
                output.in_directive = allow_directives;
                body.forEach(function (stmt, i) {
                    if (output.in_directive === true && !(stmt instanceof AST_Directive ||
                        stmt instanceof AST_EmptyStatement ||
                        (stmt instanceof AST_SimpleStatement && stmt.body instanceof AST_String))) {
                        output.in_directive = false;
                    }
                    if (!(stmt instanceof AST_EmptyStatement)) {
                        output.indent();
                        stmt.print(output);
                        if (!(i == last && is_toplevel)) {
                            output.newline();
                            if (is_toplevel)
                                output.newline();
                        }
                    }
                    if (output.in_directive === true &&
                        stmt instanceof AST_SimpleStatement &&
                        stmt.body instanceof AST_String) {
                        output.in_directive = false;
                    }
                });
                output.in_directive = false;
            }
            AST_StatementWithBody.DEFMETHOD("_do_print_body", function (output) {
                print_maybe_braced_body(this.body, output);
            });
            DEFPRINT(AST_Statement, function (self, output) {
                self.body.print(output);
                output.semicolon();
            });
            DEFPRINT(AST_Toplevel, function (self, output) {
                display_body(self.body, true, output, true);
                output.print("");
            });
            DEFPRINT(AST_LabeledStatement, function (self, output) {
                self.label.print(output);
                output.colon();
                self.body.print(output);
            });
            DEFPRINT(AST_SimpleStatement, function (self, output) {
                self.body.print(output);
                output.semicolon();
            });
            function print_braced_empty(self, output) {
                output.print("{");
                output.with_indent(output.next_indent(), function () {
                    output.append_comments(self, true);
                });
                output.add_mapping(self.end);
                output.print("}");
            }
            function print_braced(self, output, allow_directives) {
                if (self.body.length > 0) {
                    output.with_block(function () {
                        display_body(self.body, false, output, allow_directives);
                        output.add_mapping(self.end);
                    });
                }
                else
                    print_braced_empty(self, output);
            }
            DEFPRINT(AST_BlockStatement, function (self, output) {
                print_braced(self, output);
            });
            DEFPRINT(AST_EmptyStatement, function (self, output) {
                output.semicolon();
            });
            DEFPRINT(AST_Do, function (self, output) {
                output.print("do");
                output.space();
                make_block(self.body, output);
                output.space();
                output.print("while");
                output.space();
                output.with_parens(function () {
                    self.condition.print(output);
                });
                output.semicolon();
            });
            DEFPRINT(AST_While, function (self, output) {
                output.print("while");
                output.space();
                output.with_parens(function () {
                    self.condition.print(output);
                });
                output.space();
                self._do_print_body(output);
            });
            DEFPRINT(AST_For, function (self, output) {
                output.print("for");
                output.space();
                output.with_parens(function () {
                    if (self.init) {
                        if (self.init instanceof AST_Definitions) {
                            self.init.print(output);
                        }
                        else {
                            parenthesize_for_noin(self.init, output, true);
                        }
                        output.print(";");
                        output.space();
                    }
                    else {
                        output.print(";");
                    }
                    if (self.condition) {
                        self.condition.print(output);
                        output.print(";");
                        output.space();
                    }
                    else {
                        output.print(";");
                    }
                    if (self.step) {
                        self.step.print(output);
                    }
                });
                output.space();
                self._do_print_body(output);
            });
            DEFPRINT(AST_ForIn, function (self, output) {
                output.print("for");
                if (self.await) {
                    output.space();
                    output.print("await");
                }
                output.space();
                output.with_parens(function () {
                    self.init.print(output);
                    output.space();
                    output.print(self instanceof AST_ForOf ? "of" : "in");
                    output.space();
                    self.object.print(output);
                });
                output.space();
                self._do_print_body(output);
            });
            DEFPRINT(AST_With, function (self, output) {
                output.print("with");
                output.space();
                output.with_parens(function () {
                    self.expression.print(output);
                });
                output.space();
                self._do_print_body(output);
            });
            /* -----[ functions ]----- */
            AST_Lambda.DEFMETHOD("_do_print", function (output, nokeyword) {
                var self = this;
                if (!nokeyword) {
                    if (self.async) {
                        output.print("async");
                        output.space();
                    }
                    output.print("function");
                    if (self.is_generator) {
                        output.star();
                    }
                    if (self.name) {
                        output.space();
                    }
                }
                if (self.name instanceof AST_Symbol) {
                    self.name.print(output);
                }
                else if (nokeyword && self.name instanceof AST_Node) {
                    output.with_square(function () {
                        self.name.print(output); // Computed method name
                    });
                }
                output.with_parens(function () {
                    self.argnames.forEach(function (arg, i) {
                        if (i)
                            output.comma();
                        arg.print(output);
                    });
                });
                output.space();
                print_braced(self, output, true);
            });
            DEFPRINT(AST_Lambda, function (self, output) {
                self._do_print(output);
                output.gc_scope(self);
            });
            DEFPRINT(AST_PrefixedTemplateString, function (self, output) {
                var tag = self.prefix;
                var parenthesize_tag = tag instanceof AST_Lambda
                    || tag instanceof AST_Binary
                    || tag instanceof AST_Conditional
                    || tag instanceof AST_Sequence
                    || tag instanceof AST_Unary
                    || tag instanceof AST_Dot && tag.expression instanceof AST_Object;
                if (parenthesize_tag)
                    output.print("(");
                self.prefix.print(output);
                if (parenthesize_tag)
                    output.print(")");
                self.template_string.print(output);
            });
            DEFPRINT(AST_TemplateString, function (self, output) {
                var is_tagged = output.parent() instanceof AST_PrefixedTemplateString;
                output.print("`");
                for (var i = 0; i < self.segments.length; i++) {
                    if (!(self.segments[i] instanceof AST_TemplateSegment)) {
                        output.print("${");
                        self.segments[i].print(output);
                        output.print("}");
                    }
                    else if (is_tagged) {
                        output.print(self.segments[i].raw);
                    }
                    else {
                        output.print_template_string_chars(self.segments[i].value);
                    }
                }
                output.print("`");
            });
            DEFPRINT(AST_TemplateSegment, function (self, output) {
                output.print_template_string_chars(self.value);
            });
            AST_Arrow.DEFMETHOD("_do_print", function (output) {
                var self = this;
                var parent = output.parent();
                var needs_parens = (parent instanceof AST_Binary && !(parent instanceof AST_Assign)) ||
                    parent instanceof AST_Unary ||
                    (parent instanceof AST_Call && self === parent.expression);
                if (needs_parens) {
                    output.print("(");
                }
                if (self.async) {
                    output.print("async");
                    output.space();
                }
                if (self.argnames.length === 1 && self.argnames[0] instanceof AST_Symbol) {
                    self.argnames[0].print(output);
                }
                else {
                    output.with_parens(function () {
                        self.argnames.forEach(function (arg, i) {
                            if (i)
                                output.comma();
                            arg.print(output);
                        });
                    });
                }
                output.space();
                output.print("=>");
                output.space();
                const first_statement = self.body[0];
                if (self.body.length === 1
                    && first_statement instanceof AST_Return) {
                    const returned = first_statement.value;
                    if (!returned) {
                        output.print("{}");
                    }
                    else if (left_is_object(returned)) {
                        output.print("(");
                        returned.print(output);
                        output.print(")");
                    }
                    else {
                        returned.print(output);
                    }
                }
                else {
                    print_braced(self, output);
                }
                if (needs_parens) {
                    output.print(")");
                }
                output.gc_scope(self);
            });
            /* -----[ exits ]----- */
            AST_Exit.DEFMETHOD("_do_print", function (output, kind) {
                output.print(kind);
                if (this.value) {
                    output.space();
                    const comments = this.value.start.comments_before;
                    if (comments && comments.length && !output.printed_comments.has(comments)) {
                        output.print("(");
                        this.value.print(output);
                        output.print(")");
                    }
                    else {
                        this.value.print(output);
                    }
                }
                output.semicolon();
            });
            DEFPRINT(AST_Return, function (self, output) {
                self._do_print(output, "return");
            });
            DEFPRINT(AST_Throw, function (self, output) {
                self._do_print(output, "throw");
            });
            /* -----[ yield ]----- */
            DEFPRINT(AST_Yield, function (self, output) {
                var star = self.is_star ? "*" : "";
                output.print("yield" + star);
                if (self.expression) {
                    output.space();
                    self.expression.print(output);
                }
            });
            DEFPRINT(AST_Await, function (self, output) {
                output.print("await");
                output.space();
                var e = self.expression;
                var parens = !(e instanceof AST_Call
                    || e instanceof AST_SymbolRef
                    || e instanceof AST_PropAccess
                    || e instanceof AST_Unary
                    || e instanceof AST_Constant
                    || e instanceof AST_Await
                    || e instanceof AST_Object);
                if (parens)
                    output.print("(");
                self.expression.print(output);
                if (parens)
                    output.print(")");
            });
            /* -----[ loop control ]----- */
            AST_LoopControl.DEFMETHOD("_do_print", function (output, kind) {
                output.print(kind);
                if (this.label) {
                    output.space();
                    this.label.print(output);
                }
                output.semicolon();
            });
            DEFPRINT(AST_Break, function (self, output) {
                self._do_print(output, "break");
            });
            DEFPRINT(AST_Continue, function (self, output) {
                self._do_print(output, "continue");
            });
            /* -----[ if ]----- */
            function make_then(self, output) {
                var b = self.body;
                if (output.option("braces")
                    || output.option("ie8") && b instanceof AST_Do)
                    return make_block(b, output);
                // The squeezer replaces "block"-s that contain only a single
                // statement with the statement itself; technically, the AST
                // is correct, but this can create problems when we output an
                // IF having an ELSE clause where the THEN clause ends in an
                // IF *without* an ELSE block (then the outer ELSE would refer
                // to the inner IF).  This function checks for this case and
                // adds the block braces if needed.
                if (!b)
                    return output.force_semicolon();
                while (true) {
                    if (b instanceof AST_If) {
                        if (!b.alternative) {
                            make_block(self.body, output);
                            return;
                        }
                        b = b.alternative;
                    }
                    else if (b instanceof AST_StatementWithBody) {
                        b = b.body;
                    }
                    else
                        break;
                }
                print_maybe_braced_body(self.body, output);
            }
            DEFPRINT(AST_If, function (self, output) {
                output.print("if");
                output.space();
                output.with_parens(function () {
                    self.condition.print(output);
                });
                output.space();
                if (self.alternative) {
                    make_then(self, output);
                    output.space();
                    output.print("else");
                    output.space();
                    if (self.alternative instanceof AST_If)
                        self.alternative.print(output);
                    else
                        print_maybe_braced_body(self.alternative, output);
                }
                else {
                    self._do_print_body(output);
                }
            });
            /* -----[ switch ]----- */
            DEFPRINT(AST_Switch, function (self, output) {
                output.print("switch");
                output.space();
                output.with_parens(function () {
                    self.expression.print(output);
                });
                output.space();
                var last = self.body.length - 1;
                if (last < 0)
                    print_braced_empty(self, output);
                else
                    output.with_block(function () {
                        self.body.forEach(function (branch, i) {
                            output.indent(true);
                            branch.print(output);
                            if (i < last && branch.body.length > 0)
                                output.newline();
                        });
                    });
            });
            AST_SwitchBranch.DEFMETHOD("_do_print_body", function (output) {
                output.newline();
                this.body.forEach(function (stmt) {
                    output.indent();
                    stmt.print(output);
                    output.newline();
                });
            });
            DEFPRINT(AST_Default, function (self, output) {
                output.print("default:");
                self._do_print_body(output);
            });
            DEFPRINT(AST_Case, function (self, output) {
                output.print("case");
                output.space();
                self.expression.print(output);
                output.print(":");
                self._do_print_body(output);
            });
            /* -----[ exceptions ]----- */
            DEFPRINT(AST_Try, function (self, output) {
                output.print("try");
                output.space();
                self.body.print(output);
                if (self.bcatch) {
                    output.space();
                    self.bcatch.print(output);
                }
                if (self.bfinally) {
                    output.space();
                    self.bfinally.print(output);
                }
            });
            DEFPRINT(AST_TryBlock, function (self, output) {
                print_braced(self, output);
            });
            DEFPRINT(AST_Catch, function (self, output) {
                output.print("catch");
                if (self.argname) {
                    output.space();
                    output.with_parens(function () {
                        self.argname.print(output);
                    });
                }
                output.space();
                print_braced(self, output);
            });
            DEFPRINT(AST_Finally, function (self, output) {
                output.print("finally");
                output.space();
                print_braced(self, output);
            });
            /* -----[ var/const ]----- */
            AST_Definitions.DEFMETHOD("_do_print", function (output, kind) {
                output.print(kind);
                output.space();
                this.definitions.forEach(function (def, i) {
                    if (i)
                        output.comma();
                    def.print(output);
                });
                var p = output.parent();
                var in_for = p instanceof AST_For || p instanceof AST_ForIn;
                var output_semicolon = !in_for || p && p.init !== this;
                if (output_semicolon)
                    output.semicolon();
            });
            DEFPRINT(AST_Let, function (self, output) {
                self._do_print(output, "let");
            });
            DEFPRINT(AST_Var, function (self, output) {
                self._do_print(output, "var");
            });
            DEFPRINT(AST_Const, function (self, output) {
                self._do_print(output, "const");
            });
            DEFPRINT(AST_Import, function (self, output) {
                output.print("import");
                output.space();
                if (self.imported_name) {
                    self.imported_name.print(output);
                }
                if (self.imported_name && self.imported_names) {
                    output.print(",");
                    output.space();
                }
                if (self.imported_names) {
                    if (self.imported_names.length === 1 &&
                        self.imported_names[0].foreign_name.name === "*" &&
                        !self.imported_names[0].foreign_name.quote) {
                        self.imported_names[0].print(output);
                    }
                    else {
                        output.print("{");
                        self.imported_names.forEach(function (name_import, i) {
                            output.space();
                            name_import.print(output);
                            if (i < self.imported_names.length - 1) {
                                output.print(",");
                            }
                        });
                        output.space();
                        output.print("}");
                    }
                }
                if (self.imported_name || self.imported_names) {
                    output.space();
                    output.print("from");
                    output.space();
                }
                self.module_name.print(output);
                if (self.assert_clause) {
                    output.print("assert");
                    self.assert_clause.print(output);
                }
                output.semicolon();
            });
            DEFPRINT(AST_ImportMeta, function (self, output) {
                output.print("import.meta");
            });
            DEFPRINT(AST_NameMapping, function (self, output) {
                var is_import = output.parent() instanceof AST_Import;
                var definition = self.name.definition();
                var foreign_name = self.foreign_name;
                var names_are_different = (definition && definition.mangled_name || self.name.name) !==
                    foreign_name.name;
                if (!names_are_different &&
                    foreign_name.name === "*" &&
                    foreign_name.quote != self.name.quote) {
                    // export * as "*"
                    names_are_different = true;
                }
                var foreign_name_is_name = foreign_name.quote == null;
                if (names_are_different) {
                    if (is_import) {
                        if (foreign_name_is_name) {
                            output.print(foreign_name.name);
                        }
                        else {
                            output.print_string(foreign_name.name, foreign_name.quote);
                        }
                    }
                    else {
                        if (self.name.quote == null) {
                            self.name.print(output);
                        }
                        else {
                            output.print_string(self.name.name, self.name.quote);
                        }
                    }
                    output.space();
                    output.print("as");
                    output.space();
                    if (is_import) {
                        self.name.print(output);
                    }
                    else {
                        if (foreign_name_is_name) {
                            output.print(foreign_name.name);
                        }
                        else {
                            output.print_string(foreign_name.name, foreign_name.quote);
                        }
                    }
                }
                else {
                    if (self.name.quote == null) {
                        self.name.print(output);
                    }
                    else {
                        output.print_string(self.name.name, self.name.quote);
                    }
                }
            });
            DEFPRINT(AST_Export, function (self, output) {
                output.print("export");
                output.space();
                if (self.is_default) {
                    output.print("default");
                    output.space();
                }
                if (self.exported_names) {
                    if (self.exported_names.length === 1 &&
                        self.exported_names[0].name.name === "*" &&
                        !self.exported_names[0].name.quote) {
                        self.exported_names[0].print(output);
                    }
                    else {
                        output.print("{");
                        self.exported_names.forEach(function (name_export, i) {
                            output.space();
                            name_export.print(output);
                            if (i < self.exported_names.length - 1) {
                                output.print(",");
                            }
                        });
                        output.space();
                        output.print("}");
                    }
                }
                else if (self.exported_value) {
                    self.exported_value.print(output);
                }
                else if (self.exported_definition) {
                    self.exported_definition.print(output);
                    if (self.exported_definition instanceof AST_Definitions)
                        return;
                }
                if (self.module_name) {
                    output.space();
                    output.print("from");
                    output.space();
                    self.module_name.print(output);
                }
                if (self.assert_clause) {
                    output.print("assert");
                    self.assert_clause.print(output);
                }
                if (self.exported_value
                    && !(self.exported_value instanceof AST_Defun ||
                        self.exported_value instanceof AST_Function ||
                        self.exported_value instanceof AST_Class)
                    || self.module_name
                    || self.exported_names) {
                    output.semicolon();
                }
            });
            function parenthesize_for_noin(node, output, noin) {
                var parens = false;
                // need to take some precautions here:
                //    https://github.com/mishoo/UglifyJS2/issues/60
                if (noin) {
                    parens = walk(node, node => {
                        // Don't go into scopes -- except arrow functions:
                        // https://github.com/terser/terser/issues/1019#issuecomment-877642607
                        if (node instanceof AST_Scope && !(node instanceof AST_Arrow)) {
                            return true;
                        }
                        if (node instanceof AST_Binary && node.operator == "in"
                            || node instanceof AST_PrivateIn) {
                            return walk_abort; // makes walk() return true
                        }
                    });
                }
                node.print(output, parens);
            }
            DEFPRINT(AST_VarDef, function (self, output) {
                self.name.print(output);
                if (self.value) {
                    output.space();
                    output.print("=");
                    output.space();
                    var p = output.parent(1);
                    var noin = p instanceof AST_For || p instanceof AST_ForIn;
                    parenthesize_for_noin(self.value, output, noin);
                }
            });
            /* -----[ other expressions ]----- */
            DEFPRINT(AST_Call, function (self, output) {
                self.expression.print(output);
                if (self instanceof AST_New && self.args.length === 0)
                    return;
                if (self.expression instanceof AST_Call || self.expression instanceof AST_Lambda) {
                    output.add_mapping(self.start);
                }
                if (self.optional)
                    output.print("?.");
                output.with_parens(function () {
                    self.args.forEach(function (expr, i) {
                        if (i)
                            output.comma();
                        expr.print(output);
                    });
                });
            });
            DEFPRINT(AST_New, function (self, output) {
                output.print("new");
                output.space();
                AST_Call.prototype._codegen(self, output);
            });
            AST_Sequence.DEFMETHOD("_do_print", function (output) {
                this.expressions.forEach(function (node, index) {
                    if (index > 0) {
                        output.comma();
                        if (output.should_break()) {
                            output.newline();
                            output.indent();
                        }
                    }
                    node.print(output);
                });
            });
            DEFPRINT(AST_Sequence, function (self, output) {
                self._do_print(output);
                // var p = output.parent();
                // if (p instanceof AST_Statement) {
                //     output.with_indent(output.next_indent(), function(){
                //         self._do_print(output);
                //     });
                // } else {
                //     self._do_print(output);
                // }
            });
            DEFPRINT(AST_Dot, function (self, output) {
                var expr = self.expression;
                expr.print(output);
                var prop = self.property;
                var print_computed = ALL_RESERVED_WORDS.has(prop)
                    ? output.option("ie8")
                    : !is_identifier_string(prop, output.option("ecma") >= 2015 && !output.option("safari10"));
                if (self.optional)
                    output.print("?.");
                if (print_computed) {
                    output.print("[");
                    output.add_mapping(self.end);
                    output.print_string(prop);
                    output.print("]");
                }
                else {
                    if (expr instanceof AST_Number && expr.getValue() >= 0) {
                        if (!/[xa-f.)]/i.test(output.last())) {
                            output.print(".");
                        }
                    }
                    if (!self.optional)
                        output.print(".");
                    // the name after dot would be mapped about here.
                    output.add_mapping(self.end);
                    output.print_name(prop);
                }
            });
            DEFPRINT(AST_DotHash, function (self, output) {
                var expr = self.expression;
                expr.print(output);
                var prop = self.property;
                if (self.optional)
                    output.print("?");
                output.print(".#");
                output.add_mapping(self.end);
                output.print_name(prop);
            });
            DEFPRINT(AST_Sub, function (self, output) {
                self.expression.print(output);
                if (self.optional)
                    output.print("?.");
                output.print("[");
                self.property.print(output);
                output.print("]");
            });
            DEFPRINT(AST_Chain, function (self, output) {
                self.expression.print(output);
            });
            DEFPRINT(AST_UnaryPrefix, function (self, output) {
                var op = self.operator;
                if (op === "--" && output.last().endsWith("!")) {
                    // avoid printing "<!--"
                    output.print(" ");
                }
                output.print(op);
                if (/^[a-z]/i.test(op)
                    || (/[+-]$/.test(op)
                        && self.expression instanceof AST_UnaryPrefix
                        && /^[+-]/.test(self.expression.operator))) {
                    output.space();
                }
                self.expression.print(output);
            });
            DEFPRINT(AST_UnaryPostfix, function (self, output) {
                self.expression.print(output);
                output.print(self.operator);
            });
            DEFPRINT(AST_Binary, function (self, output) {
                var op = self.operator;
                self.left.print(output);
                if (op[0] == ">" /* ">>" ">>>" ">" ">=" */
                    && output.last().endsWith("--")) {
                    // space is mandatory to avoid outputting -->
                    output.print(" ");
                }
                else {
                    // the space is optional depending on "beautify"
                    output.space();
                }
                output.print(op);
                output.space();
                self.right.print(output);
            });
            DEFPRINT(AST_Conditional, function (self, output) {
                self.condition.print(output);
                output.space();
                output.print("?");
                output.space();
                self.consequent.print(output);
                output.space();
                output.colon();
                self.alternative.print(output);
            });
            /* -----[ literals ]----- */
            DEFPRINT(AST_Array, function (self, output) {
                output.with_square(function () {
                    var a = self.elements, len = a.length;
                    if (len > 0)
                        output.space();
                    a.forEach(function (exp, i) {
                        if (i)
                            output.comma();
                        exp.print(output);
                        // If the final element is a hole, we need to make sure it
                        // doesn't look like a trailing comma, by inserting an actual
                        // trailing comma.
                        if (i === len - 1 && exp instanceof AST_Hole)
                            output.comma();
                    });
                    if (len > 0)
                        output.space();
                });
            });
            DEFPRINT(AST_Object, function (self, output) {
                if (self.properties.length > 0)
                    output.with_block(function () {
                        self.properties.forEach(function (prop, i) {
                            if (i) {
                                output.print(",");
                                output.newline();
                            }
                            output.indent();
                            prop.print(output);
                        });
                        output.newline();
                    });
                else
                    print_braced_empty(self, output);
            });
            DEFPRINT(AST_Class, function (self, output) {
                output.print("class");
                output.space();
                if (self.name) {
                    self.name.print(output);
                    output.space();
                }
                if (self.extends) {
                    var parens = (!(self.extends instanceof AST_SymbolRef)
                        && !(self.extends instanceof AST_PropAccess)
                        && !(self.extends instanceof AST_ClassExpression)
                        && !(self.extends instanceof AST_Function));
                    output.print("extends");
                    if (parens) {
                        output.print("(");
                    }
                    else {
                        output.space();
                    }
                    self.extends.print(output);
                    if (parens) {
                        output.print(")");
                    }
                    else {
                        output.space();
                    }
                }
                if (self.properties.length > 0)
                    output.with_block(function () {
                        self.properties.forEach(function (prop, i) {
                            if (i) {
                                output.newline();
                            }
                            output.indent();
                            prop.print(output);
                        });
                        output.newline();
                    });
                else
                    output.print("{}");
            });
            DEFPRINT(AST_NewTarget, function (self, output) {
                output.print("new.target");
            });
            /** Prints a prop name. Returns whether it can be used as a shorthand. */
            function print_property_name(key, quote, output) {
                if (output.option("quote_keys")) {
                    output.print_string(key);
                    return false;
                }
                if ("" + +key == key && key >= 0) {
                    if (output.option("keep_numbers")) {
                        output.print(key);
                        return false;
                    }
                    output.print(make_num(key));
                    return false;
                }
                var print_string = ALL_RESERVED_WORDS.has(key)
                    ? output.option("ie8")
                    : (output.option("ecma") < 2015 || output.option("safari10")
                        ? !is_basic_identifier_string(key)
                        : !is_identifier_string(key, true));
                if (print_string || (quote && output.option("keep_quoted_props"))) {
                    output.print_string(key, quote);
                    return false;
                }
                output.print_name(key);
                return true;
            }
            DEFPRINT(AST_ObjectKeyVal, function (self, output) {
                function get_name(self) {
                    var def = self.definition();
                    return def ? def.mangled_name || def.name : self.name;
                }
                const try_shorthand = output.option("shorthand") && !(self.key instanceof AST_Node);
                if (try_shorthand
                    && self.value instanceof AST_Symbol
                    && get_name(self.value) === self.key
                    && !ALL_RESERVED_WORDS.has(self.key)) {
                    const was_shorthand = print_property_name(self.key, self.quote, output);
                    if (!was_shorthand) {
                        output.colon();
                        self.value.print(output);
                    }
                }
                else if (try_shorthand
                    && self.value instanceof AST_DefaultAssign
                    && self.value.left instanceof AST_Symbol
                    && get_name(self.value.left) === self.key) {
                    const was_shorthand = print_property_name(self.key, self.quote, output);
                    if (!was_shorthand) {
                        output.colon();
                        self.value.left.print(output);
                    }
                    output.space();
                    output.print("=");
                    output.space();
                    self.value.right.print(output);
                }
                else {
                    if (!(self.key instanceof AST_Node)) {
                        print_property_name(self.key, self.quote, output);
                    }
                    else {
                        output.with_square(function () {
                            self.key.print(output);
                        });
                    }
                    output.colon();
                    self.value.print(output);
                }
            });
            DEFPRINT(AST_ClassPrivateProperty, (self, output) => {
                if (self.static) {
                    output.print("static");
                    output.space();
                }
                output.print("#");
                print_property_name(self.key.name, self.quote, output);
                if (self.value) {
                    output.print("=");
                    self.value.print(output);
                }
                output.semicolon();
            });
            DEFPRINT(AST_ClassProperty, (self, output) => {
                if (self.static) {
                    output.print("static");
                    output.space();
                }
                if (self.key instanceof AST_SymbolClassProperty) {
                    print_property_name(self.key.name, self.quote, output);
                }
                else {
                    output.print("[");
                    self.key.print(output);
                    output.print("]");
                }
                if (self.value) {
                    output.print("=");
                    self.value.print(output);
                }
                output.semicolon();
            });
            AST_ObjectProperty.DEFMETHOD("_print_getter_setter", function (type, is_private, output) {
                var self = this;
                if (self.static) {
                    output.print("static");
                    output.space();
                }
                if (type) {
                    output.print(type);
                    output.space();
                }
                if (self.key instanceof AST_SymbolMethod) {
                    if (is_private)
                        output.print("#");
                    print_property_name(self.key.name, self.quote, output);
                    self.key.add_source_map(output);
                }
                else {
                    output.with_square(function () {
                        self.key.print(output);
                    });
                }
                self.value._do_print(output, true);
            });
            DEFPRINT(AST_ObjectSetter, function (self, output) {
                self._print_getter_setter("set", false, output);
            });
            DEFPRINT(AST_ObjectGetter, function (self, output) {
                self._print_getter_setter("get", false, output);
            });
            DEFPRINT(AST_PrivateSetter, function (self, output) {
                self._print_getter_setter("set", true, output);
            });
            DEFPRINT(AST_PrivateGetter, function (self, output) {
                self._print_getter_setter("get", true, output);
            });
            DEFPRINT(AST_PrivateMethod, function (self, output) {
                var type;
                if (self.is_generator && self.async) {
                    type = "async*";
                }
                else if (self.is_generator) {
                    type = "*";
                }
                else if (self.async) {
                    type = "async";
                }
                self._print_getter_setter(type, true, output);
            });
            DEFPRINT(AST_PrivateIn, function (self, output) {
                self.key.print(output);
                output.space();
                output.print("in");
                output.space();
                self.value.print(output);
            });
            DEFPRINT(AST_SymbolPrivateProperty, function (self, output) {
                output.print("#" + self.name);
            });
            DEFPRINT(AST_ConciseMethod, function (self, output) {
                var type;
                if (self.is_generator && self.async) {
                    type = "async*";
                }
                else if (self.is_generator) {
                    type = "*";
                }
                else if (self.async) {
                    type = "async";
                }
                self._print_getter_setter(type, false, output);
            });
            DEFPRINT(AST_ClassStaticBlock, function (self, output) {
                output.print("static");
                output.space();
                print_braced(self, output);
            });
            AST_Symbol.DEFMETHOD("_do_print", function (output) {
                var def = this.definition();
                output.print_name(def ? def.mangled_name || def.name : this.name);
            });
            DEFPRINT(AST_Symbol, function (self, output) {
                self._do_print(output);
            });
            DEFPRINT(AST_Hole, noop);
            DEFPRINT(AST_This, function (self, output) {
                output.print("this");
            });
            DEFPRINT(AST_Super, function (self, output) {
                output.print("super");
            });
            DEFPRINT(AST_Constant, function (self, output) {
                output.print(self.getValue());
            });
            DEFPRINT(AST_String, function (self, output) {
                output.print_string(self.getValue(), self.quote, output.in_directive);
            });
            DEFPRINT(AST_Number, function (self, output) {
                if ((output.option("keep_numbers") || output.use_asm) && self.raw) {
                    output.print(self.raw);
                }
                else {
                    output.print(make_num(self.getValue()));
                }
            });
            DEFPRINT(AST_BigInt, function (self, output) {
                output.print(self.getValue() + "n");
            });
            const r_slash_script = /(<\s*\/\s*script)/i;
            const r_starts_with_script = /^\s*script/i;
            const slash_script_replace = (_, $1) => $1.replace("/", "\\/");
            DEFPRINT(AST_RegExp, function (self, output) {
                let { source, flags } = self.getValue();
                source = regexp_source_fix(source);
                flags = flags ? sort_regexp_flags(flags) : "";
                // Avoid outputting end of script tag
                source = source.replace(r_slash_script, slash_script_replace);
                if (r_starts_with_script.test(source) && output.last().endsWith("<")) {
                    output.print(" ");
                }
                output.print(output.to_utf8(`/${source}/${flags}`, false, true));
                const parent = output.parent();
                if (parent instanceof AST_Binary
                    && /^\w/.test(parent.operator)
                    && parent.left === self) {
                    output.print(" ");
                }
            });
            /** if, for, while, may or may not have braces surrounding its body */
            function print_maybe_braced_body(stat, output) {
                if (output.option("braces")) {
                    make_block(stat, output);
                }
                else {
                    if (!stat || stat instanceof AST_EmptyStatement)
                        output.force_semicolon();
                    else if (stat instanceof AST_Let || stat instanceof AST_Const || stat instanceof AST_Class)
                        make_block(stat, output);
                    else
                        stat.print(output);
                }
            }
            function best_of(a) {
                var best = a[0], len = best.length;
                for (var i = 1; i < a.length; ++i) {
                    if (a[i].length < len) {
                        best = a[i];
                        len = best.length;
                    }
                }
                return best;
            }
            function make_num(num) {
                var str = num.toString(10).replace(/^0\./, ".").replace("e+", "e");
                var candidates = [str];
                if (Math.floor(num) === num) {
                    if (num < 0) {
                        candidates.push("-0x" + (-num).toString(16).toLowerCase());
                    }
                    else {
                        candidates.push("0x" + num.toString(16).toLowerCase());
                    }
                }
                var match, len, digits;
                if (match = /^\.0+/.exec(str)) {
                    len = match[0].length;
                    digits = str.slice(len);
                    candidates.push(digits + "e-" + (digits.length + len - 1));
                }
                else if (match = /0+$/.exec(str)) {
                    len = match[0].length;
                    candidates.push(str.slice(0, -len) + "e" + len);
                }
                else if (match = /^(\d)\.(\d+)e(-?\d+)$/.exec(str)) {
                    candidates.push(match[1] + match[2] + "e" + (match[3] - match[2].length));
                }
                return best_of(candidates);
            }
            function make_block(stmt, output) {
                if (!stmt || stmt instanceof AST_EmptyStatement)
                    output.print("{}");
                else if (stmt instanceof AST_BlockStatement)
                    stmt.print(output);
                else
                    output.with_block(function () {
                        output.indent();
                        stmt.print(output);
                        output.newline();
                    });
            }
            /* -----[ source map generators ]----- */
            function DEFMAP(nodetype, generator) {
                nodetype.forEach(function (nodetype) {
                    nodetype.DEFMETHOD("add_source_map", generator);
                });
            }
            DEFMAP([
                // We could easily add info for ALL nodes, but it seems to me that
                // would be quite wasteful, hence this noop in the base class.
                AST_Node,
                // since the label symbol will mark it
                AST_LabeledStatement,
                AST_Toplevel,
            ], noop);
            // XXX: I'm not exactly sure if we need it for all of these nodes,
            // or if we should add even more.
            DEFMAP([
                AST_Array,
                AST_BlockStatement,
                AST_Catch,
                AST_Class,
                AST_Constant,
                AST_Debugger,
                AST_Definitions,
                AST_Directive,
                AST_Finally,
                AST_Jump,
                AST_Lambda,
                AST_New,
                AST_Object,
                AST_StatementWithBody,
                AST_Symbol,
                AST_Switch,
                AST_SwitchBranch,
                AST_TemplateString,
                AST_TemplateSegment,
                AST_Try,
            ], function (output) {
                output.add_mapping(this.start);
            });
            DEFMAP([
                AST_ObjectGetter,
                AST_ObjectSetter,
                AST_PrivateGetter,
                AST_PrivateSetter,
                AST_ConciseMethod,
                AST_PrivateMethod,
            ], function (output) {
                output.add_mapping(this.start, false /*name handled below*/);
            });
            DEFMAP([
                AST_SymbolMethod,
                AST_SymbolPrivateProperty
            ], function (output) {
                const tok_type = this.end && this.end.type;
                if (tok_type === "name" || tok_type === "privatename") {
                    output.add_mapping(this.end, this.name);
                }
                else {
                    output.add_mapping(this.end);
                }
            });
            DEFMAP([AST_ObjectProperty], function (output) {
                output.add_mapping(this.start, this.key);
            });
        })();
        const shallow_cmp = (node1, node2) => {
            return (node1 === null && node2 === null
                || node1.TYPE === node2.TYPE && node1.shallow_cmp(node2));
        };
        const equivalent_to = (tree1, tree2) => {
            if (!shallow_cmp(tree1, tree2))
                return false;
            const walk_1_state = [tree1];
            const walk_2_state = [tree2];
            const walk_1_push = walk_1_state.push.bind(walk_1_state);
            const walk_2_push = walk_2_state.push.bind(walk_2_state);
            while (walk_1_state.length && walk_2_state.length) {
                const node_1 = walk_1_state.pop();
                const node_2 = walk_2_state.pop();
                if (!shallow_cmp(node_1, node_2))
                    return false;
                node_1._children_backwards(walk_1_push);
                node_2._children_backwards(walk_2_push);
                if (walk_1_state.length !== walk_2_state.length) {
                    // Different number of children
                    return false;
                }
            }
            return walk_1_state.length == 0 && walk_2_state.length == 0;
        };
        const pass_through = () => true;
        AST_Node.prototype.shallow_cmp = function () {
            throw new Error("did not find a shallow_cmp function for " + this.constructor.name);
        };
        AST_Debugger.prototype.shallow_cmp = pass_through;
        AST_Directive.prototype.shallow_cmp = function (other) {
            return this.value === other.value;
        };
        AST_SimpleStatement.prototype.shallow_cmp = pass_through;
        AST_Block.prototype.shallow_cmp = pass_through;
        AST_EmptyStatement.prototype.shallow_cmp = pass_through;
        AST_LabeledStatement.prototype.shallow_cmp = function (other) {
            return this.label.name === other.label.name;
        };
        AST_Do.prototype.shallow_cmp = pass_through;
        AST_While.prototype.shallow_cmp = pass_through;
        AST_For.prototype.shallow_cmp = function (other) {
            return (this.init == null ? other.init == null : this.init === other.init) && (this.condition == null ? other.condition == null : this.condition === other.condition) && (this.step == null ? other.step == null : this.step === other.step);
        };
        AST_ForIn.prototype.shallow_cmp = pass_through;
        AST_ForOf.prototype.shallow_cmp = pass_through;
        AST_With.prototype.shallow_cmp = pass_through;
        AST_Toplevel.prototype.shallow_cmp = pass_through;
        AST_Expansion.prototype.shallow_cmp = pass_through;
        AST_Lambda.prototype.shallow_cmp = function (other) {
            return this.is_generator === other.is_generator && this.async === other.async;
        };
        AST_Destructuring.prototype.shallow_cmp = function (other) {
            return this.is_array === other.is_array;
        };
        AST_PrefixedTemplateString.prototype.shallow_cmp = pass_through;
        AST_TemplateString.prototype.shallow_cmp = pass_through;
        AST_TemplateSegment.prototype.shallow_cmp = function (other) {
            return this.value === other.value;
        };
        AST_Jump.prototype.shallow_cmp = pass_through;
        AST_LoopControl.prototype.shallow_cmp = pass_through;
        AST_Await.prototype.shallow_cmp = pass_through;
        AST_Yield.prototype.shallow_cmp = function (other) {
            return this.is_star === other.is_star;
        };
        AST_If.prototype.shallow_cmp = function (other) {
            return this.alternative == null ? other.alternative == null : this.alternative === other.alternative;
        };
        AST_Switch.prototype.shallow_cmp = pass_through;
        AST_SwitchBranch.prototype.shallow_cmp = pass_through;
        AST_Try.prototype.shallow_cmp = function (other) {
            return (this.body === other.body) && (this.bcatch == null ? other.bcatch == null : this.bcatch === other.bcatch) && (this.bfinally == null ? other.bfinally == null : this.bfinally === other.bfinally);
        };
        AST_Catch.prototype.shallow_cmp = function (other) {
            return this.argname == null ? other.argname == null : this.argname === other.argname;
        };
        AST_Finally.prototype.shallow_cmp = pass_through;
        AST_Definitions.prototype.shallow_cmp = pass_through;
        AST_VarDef.prototype.shallow_cmp = function (other) {
            return this.value == null ? other.value == null : this.value === other.value;
        };
        AST_NameMapping.prototype.shallow_cmp = pass_through;
        AST_Import.prototype.shallow_cmp = function (other) {
            return (this.imported_name == null ? other.imported_name == null : this.imported_name === other.imported_name) && (this.imported_names == null ? other.imported_names == null : this.imported_names === other.imported_names);
        };
        AST_ImportMeta.prototype.shallow_cmp = pass_through;
        AST_Export.prototype.shallow_cmp = function (other) {
            return (this.exported_definition == null ? other.exported_definition == null : this.exported_definition === other.exported_definition) && (this.exported_value == null ? other.exported_value == null : this.exported_value === other.exported_value) && (this.exported_names == null ? other.exported_names == null : this.exported_names === other.exported_names) && this.module_name === other.module_name && this.is_default === other.is_default;
        };
        AST_Call.prototype.shallow_cmp = pass_through;
        AST_Sequence.prototype.shallow_cmp = pass_through;
        AST_PropAccess.prototype.shallow_cmp = pass_through;
        AST_Chain.prototype.shallow_cmp = pass_through;
        AST_Dot.prototype.shallow_cmp = function (other) {
            return this.property === other.property;
        };
        AST_DotHash.prototype.shallow_cmp = function (other) {
            return this.property === other.property;
        };
        AST_Unary.prototype.shallow_cmp = function (other) {
            return this.operator === other.operator;
        };
        AST_Binary.prototype.shallow_cmp = function (other) {
            return this.operator === other.operator;
        };
        AST_Conditional.prototype.shallow_cmp = pass_through;
        AST_Array.prototype.shallow_cmp = pass_through;
        AST_Object.prototype.shallow_cmp = pass_through;
        AST_ObjectProperty.prototype.shallow_cmp = pass_through;
        AST_ObjectKeyVal.prototype.shallow_cmp = function (other) {
            return this.key === other.key;
        };
        AST_ObjectSetter.prototype.shallow_cmp = function (other) {
            return this.static === other.static;
        };
        AST_ObjectGetter.prototype.shallow_cmp = function (other) {
            return this.static === other.static;
        };
        AST_ConciseMethod.prototype.shallow_cmp = function (other) {
            return this.static === other.static && this.is_generator === other.is_generator && this.async === other.async;
        };
        AST_Class.prototype.shallow_cmp = function (other) {
            return (this.name == null ? other.name == null : this.name === other.name) && (this.extends == null ? other.extends == null : this.extends === other.extends);
        };
        AST_ClassProperty.prototype.shallow_cmp = function (other) {
            return this.static === other.static;
        };
        AST_Symbol.prototype.shallow_cmp = function (other) {
            return this.name === other.name;
        };
        AST_NewTarget.prototype.shallow_cmp = pass_through;
        AST_This.prototype.shallow_cmp = pass_through;
        AST_Super.prototype.shallow_cmp = pass_through;
        AST_String.prototype.shallow_cmp = function (other) {
            return this.value === other.value;
        };
        AST_Number.prototype.shallow_cmp = function (other) {
            return this.value === other.value;
        };
        AST_BigInt.prototype.shallow_cmp = function (other) {
            return this.value === other.value;
        };
        AST_RegExp.prototype.shallow_cmp = function (other) {
            return (this.value.flags === other.value.flags
                && this.value.source === other.value.source);
        };
        AST_Atom.prototype.shallow_cmp = pass_through;
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        const MASK_EXPORT_DONT_MANGLE = 1 << 0;
        const MASK_EXPORT_WANT_MANGLE = 1 << 1;
        let function_defs = null;
        let unmangleable_names = null;
        /**
         * When defined, there is a function declaration somewhere that's inside of a block.
         * See https://tc39.es/ecma262/multipage/additional-ecmascript-features-for-web-browsers.html#sec-block-level-function-declarations-web-legacy-compatibility-semantics
        */
        let scopes_with_block_defuns = null;
        class SymbolDef {
            constructor(scope, orig, init) {
                this.name = orig.name;
                this.orig = [orig];
                this.init = init;
                this.eliminated = 0;
                this.assignments = 0;
                this.scope = scope;
                this.replaced = 0;
                this.global = false;
                this.export = 0;
                this.mangled_name = null;
                this.undeclared = false;
                this.id = SymbolDef.next_id++;
                this.chained = false;
                this.direct_access = false;
                this.escaped = 0;
                this.recursive_refs = 0;
                this.references = [];
                this.should_replace = undefined;
                this.single_use = false;
                this.fixed = false;
                Object.seal(this);
            }
            fixed_value() {
                if (!this.fixed || this.fixed instanceof AST_Node)
                    return this.fixed;
                return this.fixed();
            }
            unmangleable(options) {
                if (!options)
                    options = {};
                if (function_defs &&
                    function_defs.has(this.id) &&
                    keep_name(options.keep_fnames, this.orig[0].name))
                    return true;
                return this.global && !options.toplevel
                    || (this.export & MASK_EXPORT_DONT_MANGLE)
                    || this.undeclared
                    || !options.eval && this.scope.pinned()
                    || (this.orig[0] instanceof AST_SymbolLambda
                        || this.orig[0] instanceof AST_SymbolDefun) && keep_name(options.keep_fnames, this.orig[0].name)
                    || this.orig[0] instanceof AST_SymbolMethod
                    || (this.orig[0] instanceof AST_SymbolClass
                        || this.orig[0] instanceof AST_SymbolDefClass) && keep_name(options.keep_classnames, this.orig[0].name);
            }
            mangle(options) {
                const cache = options.cache && options.cache.props;
                if (this.global && cache && cache.has(this.name)) {
                    this.mangled_name = cache.get(this.name);
                }
                else if (!this.mangled_name && !this.unmangleable(options)) {
                    var s = this.scope;
                    var sym = this.orig[0];
                    if (options.ie8 && sym instanceof AST_SymbolLambda)
                        s = s.parent_scope;
                    const redefinition = redefined_catch_def(this);
                    this.mangled_name = redefinition
                        ? redefinition.mangled_name || redefinition.name
                        : s.next_mangled(options, this);
                    if (this.global && cache) {
                        cache.set(this.name, this.mangled_name);
                    }
                }
            }
        }
        SymbolDef.next_id = 1;
        function redefined_catch_def(def) {
            if (def.orig[0] instanceof AST_SymbolCatch
                && def.scope.is_block_scope()) {
                return def.scope.get_defun_scope().variables.get(def.name);
            }
        }
        AST_Scope.DEFMETHOD("figure_out_scope", function (options, { parent_scope = null, toplevel = this } = {}) {
            options = defaults(options, {
                cache: null,
                ie8: false,
                safari10: false,
                module: false,
            });
            if (!(toplevel instanceof AST_Toplevel)) {
                throw new Error("Invalid toplevel scope");
            }
            // pass 1: setup scope chaining and handle definitions
            var scope = this.parent_scope = parent_scope;
            var labels = new Map();
            var defun = null;
            var in_destructuring = null;
            var for_scopes = [];
            var tw = new TreeWalker((node, descend) => {
                if (node.is_block_scope()) {
                    const save_scope = scope;
                    node.block_scope = scope = new AST_Scope(node);
                    scope._block_scope = true;
                    scope.init_scope_vars(save_scope);
                    scope.uses_with = save_scope.uses_with;
                    scope.uses_eval = save_scope.uses_eval;
                    if (options.safari10) {
                        if (node instanceof AST_For || node instanceof AST_ForIn || node instanceof AST_ForOf) {
                            for_scopes.push(scope);
                        }
                    }
                    if (node instanceof AST_Switch) {
                        // XXX: HACK! Ensure the switch expression gets the correct scope (the parent scope) and the body gets the contained scope
                        // AST_Switch has a scope within the body, but it itself "is a block scope"
                        // This means the switched expression has to belong to the outer scope
                        // while the body inside belongs to the switch itself.
                        // This is pretty nasty and warrants an AST change
                        const the_block_scope = scope;
                        scope = save_scope;
                        node.expression.walk(tw);
                        scope = the_block_scope;
                        for (let i = 0; i < node.body.length; i++) {
                            node.body[i].walk(tw);
                        }
                    }
                    else {
                        descend();
                    }
                    scope = save_scope;
                    return true;
                }
                if (node instanceof AST_Destructuring) {
                    const save_destructuring = in_destructuring;
                    in_destructuring = node;
                    descend();
                    in_destructuring = save_destructuring;
                    return true;
                }
                if (node instanceof AST_Scope) {
                    node.init_scope_vars(scope);
                    var save_scope = scope;
                    var save_defun = defun;
                    var save_labels = labels;
                    defun = scope = node;
                    labels = new Map();
                    descend();
                    scope = save_scope;
                    defun = save_defun;
                    labels = save_labels;
                    return true; // don't descend again in TreeWalker
                }
                if (node instanceof AST_LabeledStatement) {
                    var l = node.label;
                    if (labels.has(l.name)) {
                        throw new Error(string_template("Label {name} defined twice", l));
                    }
                    labels.set(l.name, l);
                    descend();
                    labels.delete(l.name);
                    return true; // no descend again
                }
                if (node instanceof AST_With) {
                    for (var s = scope; s; s = s.parent_scope)
                        s.uses_with = true;
                    return;
                }
                if (node instanceof AST_Symbol) {
                    node.scope = scope;
                }
                if (node instanceof AST_Label) {
                    node.thedef = node;
                    node.references = [];
                }
                if (node instanceof AST_SymbolLambda) {
                    defun.def_function(node, node.name == "arguments" ? undefined : defun);
                }
                else if (node instanceof AST_SymbolDefun) {
                    // Careful here, the scope where this should be defined is
                    // the parent scope.  The reason is that we enter a new
                    // scope when we encounter the AST_Defun node (which is
                    // instanceof AST_Scope) but we get to the symbol a bit
                    // later.
                    const closest_scope = defun.parent_scope;
                    // In strict mode, function definitions are block-scoped
                    node.scope = tw.directives["use strict"]
                        ? closest_scope
                        : closest_scope.get_defun_scope();
                    mark_export(node.scope.def_function(node, defun), 1);
                }
                else if (node instanceof AST_SymbolClass) {
                    mark_export(defun.def_variable(node, defun), 1);
                }
                else if (node instanceof AST_SymbolImport) {
                    scope.def_variable(node);
                }
                else if (node instanceof AST_SymbolDefClass) {
                    // This deals with the name of the class being available
                    // inside the class.
                    mark_export((node.scope = defun.parent_scope).def_function(node, defun), 1);
                }
                else if (node instanceof AST_SymbolVar
                    || node instanceof AST_SymbolLet
                    || node instanceof AST_SymbolConst
                    || node instanceof AST_SymbolCatch) {
                    var def;
                    if (node instanceof AST_SymbolBlockDeclaration) {
                        def = scope.def_variable(node, null);
                    }
                    else {
                        def = defun.def_variable(node, node.TYPE == "SymbolVar" ? null : undefined);
                    }
                    if (!def.orig.every((sym) => {
                        if (sym === node)
                            return true;
                        if (node instanceof AST_SymbolBlockDeclaration) {
                            return sym instanceof AST_SymbolLambda;
                        }
                        return !(sym instanceof AST_SymbolLet || sym instanceof AST_SymbolConst);
                    })) {
                        js_error(`"${node.name}" is redeclared`, node.start.file, node.start.line, node.start.col, node.start.pos);
                    }
                    if (!(node instanceof AST_SymbolFunarg))
                        mark_export(def, 2);
                    if (defun !== scope) {
                        node.mark_enclosed();
                        var def = scope.find_variable(node);
                        if (node.thedef !== def) {
                            node.thedef = def;
                            node.reference();
                        }
                    }
                }
                else if (node instanceof AST_LabelRef) {
                    var sym = labels.get(node.name);
                    if (!sym)
                        throw new Error(string_template("Undefined label {name} [{line},{col}]", {
                            name: node.name,
                            line: node.start.line,
                            col: node.start.col
                        }));
                    node.thedef = sym;
                }
                if (!(scope instanceof AST_Toplevel) && (node instanceof AST_Export || node instanceof AST_Import)) {
                    js_error(`"${node.TYPE}" statement may only appear at the top level`, node.start.file, node.start.line, node.start.col, node.start.pos);
                }
            });
            if (options.module) {
                tw.directives["use strict"] = true;
            }
            this.walk(tw);
            function mark_export(def, level) {
                if (in_destructuring) {
                    var i = 0;
                    do {
                        level++;
                    } while (tw.parent(i++) !== in_destructuring);
                }
                var node = tw.parent(level);
                if (def.export = node instanceof AST_Export ? MASK_EXPORT_DONT_MANGLE : 0) {
                    var exported = node.exported_definition;
                    if ((exported instanceof AST_Defun || exported instanceof AST_DefClass) && node.is_default) {
                        def.export = MASK_EXPORT_WANT_MANGLE;
                    }
                }
            }
            // pass 2: find back references and eval
            const is_toplevel = this instanceof AST_Toplevel;
            if (is_toplevel) {
                this.globals = new Map();
            }
            var tw = new TreeWalker(node => {
                if (node instanceof AST_LoopControl && node.label) {
                    node.label.thedef.references.push(node);
                    return true;
                }
                if (node instanceof AST_SymbolRef) {
                    var name = node.name;
                    if (name == "eval" && tw.parent() instanceof AST_Call) {
                        for (var s = node.scope; s && !s.uses_eval; s = s.parent_scope) {
                            s.uses_eval = true;
                        }
                    }
                    var sym;
                    if (tw.parent() instanceof AST_NameMapping && tw.parent(1).module_name
                        || !(sym = node.scope.find_variable(name))) {
                        sym = toplevel.def_global(node);
                        if (node instanceof AST_SymbolExport)
                            sym.export = MASK_EXPORT_DONT_MANGLE;
                    }
                    else if (sym.scope instanceof AST_Lambda && name == "arguments") {
                        sym.scope.get_defun_scope().uses_arguments = true;
                    }
                    node.thedef = sym;
                    node.reference();
                    if (node.scope.is_block_scope()
                        && !(sym.orig[0] instanceof AST_SymbolBlockDeclaration)) {
                        node.scope = node.scope.get_defun_scope();
                    }
                    return true;
                }
                // ensure mangling works if catch reuses a scope variable
                var def;
                if (node instanceof AST_SymbolCatch && (def = redefined_catch_def(node.definition()))) {
                    var s = node.scope;
                    while (s) {
                        push_uniq(s.enclosed, def);
                        if (s === def.scope)
                            break;
                        s = s.parent_scope;
                    }
                }
            });
            this.walk(tw);
            // pass 3: work around IE8 and Safari catch scope bugs
            if (options.ie8 || options.safari10) {
                walk(this, node => {
                    if (node instanceof AST_SymbolCatch) {
                        var name = node.name;
                        var refs = node.thedef.references;
                        var scope = node.scope.get_defun_scope();
                        var def = scope.find_variable(name)
                            || toplevel.globals.get(name)
                            || scope.def_variable(node);
                        refs.forEach(function (ref) {
                            ref.thedef = def;
                            ref.reference();
                        });
                        node.thedef = def;
                        node.reference();
                        return true;
                    }
                });
            }
            // pass 4: add symbol definitions to loop scopes
            // Safari/Webkit bug workaround - loop init let variable shadowing argument.
            // https://github.com/mishoo/UglifyJS2/issues/1753
            // https://bugs.webkit.org/show_bug.cgi?id=171041
            if (options.safari10) {
                for (const scope of for_scopes) {
                    scope.parent_scope.variables.forEach(function (def) {
                        push_uniq(scope.enclosed, def);
                    });
                }
            }
        });
        AST_Toplevel.DEFMETHOD("def_global", function (node) {
            var globals = this.globals, name = node.name;
            if (globals.has(name)) {
                return globals.get(name);
            }
            else {
                var g = new SymbolDef(this, node);
                g.undeclared = true;
                g.global = true;
                globals.set(name, g);
                return g;
            }
        });
        AST_Scope.DEFMETHOD("init_scope_vars", function (parent_scope) {
            this.variables = new Map(); // map name to AST_SymbolVar (variables defined in this scope; includes functions)
            this.uses_with = false; // will be set to true if this or some nested scope uses the `with` statement
            this.uses_eval = false; // will be set to true if this or nested scope uses the global `eval`
            this.parent_scope = parent_scope; // the parent scope
            this.enclosed = []; // a list of variables from this or outer scope(s) that are referenced from this or inner scopes
            this.cname = -1; // the current index for mangling functions/variables
        });
        AST_Scope.DEFMETHOD("conflicting_def", function (name) {
            return (this.enclosed.find(def => def.name === name)
                || this.variables.has(name)
                || (this.parent_scope && this.parent_scope.conflicting_def(name)));
        });
        AST_Scope.DEFMETHOD("conflicting_def_shallow", function (name) {
            return (this.enclosed.find(def => def.name === name)
                || this.variables.has(name));
        });
        AST_Scope.DEFMETHOD("add_child_scope", function (scope) {
            // `scope` is going to be moved into `this` right now.
            // Update the required scopes' information
            if (scope.parent_scope === this)
                return;
            scope.parent_scope = this;
            // Propagate to this.uses_arguments from arrow functions
            if ((scope instanceof AST_Arrow) && !this.uses_arguments) {
                this.uses_arguments = walk(scope, node => {
                    if (node instanceof AST_SymbolRef
                        && node.scope instanceof AST_Lambda
                        && node.name === "arguments") {
                        return walk_abort;
                    }
                    if (node instanceof AST_Lambda && !(node instanceof AST_Arrow)) {
                        return true;
                    }
                });
            }
            this.uses_with = this.uses_with || scope.uses_with;
            this.uses_eval = this.uses_eval || scope.uses_eval;
            const scope_ancestry = (() => {
                const ancestry = [];
                let cur = this;
                do {
                    ancestry.push(cur);
                } while ((cur = cur.parent_scope));
                ancestry.reverse();
                return ancestry;
            })();
            const new_scope_enclosed_set = new Set(scope.enclosed);
            const to_enclose = [];
            for (const scope_topdown of scope_ancestry) {
                to_enclose.forEach(e => push_uniq(scope_topdown.enclosed, e));
                for (const def of scope_topdown.variables.values()) {
                    if (new_scope_enclosed_set.has(def)) {
                        push_uniq(to_enclose, def);
                        push_uniq(scope_topdown.enclosed, def);
                    }
                }
            }
        });
        function find_scopes_visible_from(scopes) {
            const found_scopes = new Set();
            for (const scope of new Set(scopes)) {
                (function bubble_up(scope) {
                    if (scope == null || found_scopes.has(scope))
                        return;
                    found_scopes.add(scope);
                    bubble_up(scope.parent_scope);
                })(scope);
            }
            return [...found_scopes];
        }
        // Creates a symbol during compression
        AST_Scope.DEFMETHOD("create_symbol", function (SymClass, { source, tentative_name, scope, conflict_scopes = [scope], init = null } = {}) {
            let symbol_name;
            conflict_scopes = find_scopes_visible_from(conflict_scopes);
            if (tentative_name) {
                // Implement hygiene (no new names are conflicting with existing names)
                tentative_name =
                    symbol_name =
                        tentative_name.replace(/(?:^[^a-z_$]|[^a-z0-9_$])/ig, "_");
                let i = 0;
                while (conflict_scopes.find(s => s.conflicting_def_shallow(symbol_name))) {
                    symbol_name = tentative_name + "$" + i++;
                }
            }
            if (!symbol_name) {
                throw new Error("No symbol name could be generated in create_symbol()");
            }
            const symbol = make_node(SymClass, source, {
                name: symbol_name,
                scope
            });
            this.def_variable(symbol, init || null);
            symbol.mark_enclosed();
            return symbol;
        });
        AST_Node.DEFMETHOD("is_block_scope", return_false);
        AST_Class.DEFMETHOD("is_block_scope", return_false);
        AST_Lambda.DEFMETHOD("is_block_scope", return_false);
        AST_Toplevel.DEFMETHOD("is_block_scope", return_false);
        AST_SwitchBranch.DEFMETHOD("is_block_scope", return_false);
        AST_Block.DEFMETHOD("is_block_scope", return_true);
        AST_Scope.DEFMETHOD("is_block_scope", function () {
            return this._block_scope || false;
        });
        AST_IterationStatement.DEFMETHOD("is_block_scope", return_true);
        AST_Lambda.DEFMETHOD("init_scope_vars", function () {
            AST_Scope.prototype.init_scope_vars.apply(this, arguments);
            this.uses_arguments = false;
            this.def_variable(new AST_SymbolFunarg({
                name: "arguments",
                start: this.start,
                end: this.end
            }));
        });
        AST_Arrow.DEFMETHOD("init_scope_vars", function () {
            AST_Scope.prototype.init_scope_vars.apply(this, arguments);
            this.uses_arguments = false;
        });
        AST_Symbol.DEFMETHOD("mark_enclosed", function () {
            var def = this.definition();
            var s = this.scope;
            while (s) {
                push_uniq(s.enclosed, def);
                if (s === def.scope)
                    break;
                s = s.parent_scope;
            }
        });
        AST_Symbol.DEFMETHOD("reference", function () {
            this.definition().references.push(this);
            this.mark_enclosed();
        });
        AST_Scope.DEFMETHOD("find_variable", function (name) {
            if (name instanceof AST_Symbol)
                name = name.name;
            return this.variables.get(name)
                || (this.parent_scope && this.parent_scope.find_variable(name));
        });
        AST_Scope.DEFMETHOD("def_function", function (symbol, init) {
            var def = this.def_variable(symbol, init);
            if (!def.init || def.init instanceof AST_Defun)
                def.init = init;
            return def;
        });
        AST_Scope.DEFMETHOD("def_variable", function (symbol, init) {
            var def = this.variables.get(symbol.name);
            if (def) {
                def.orig.push(symbol);
                if (def.init && (def.scope !== symbol.scope || def.init instanceof AST_Function)) {
                    def.init = init;
                }
            }
            else {
                def = new SymbolDef(this, symbol, init);
                this.variables.set(symbol.name, def);
                def.global = !this.parent_scope;
            }
            return symbol.thedef = def;
        });
        function next_mangled(scope, options) {
            let defun_scope;
            if (scopes_with_block_defuns
                && (defun_scope = scope.get_defun_scope())
                && scopes_with_block_defuns.has(defun_scope)) {
                scope = defun_scope;
            }
            var ext = scope.enclosed;
            var nth_identifier = options.nth_identifier;
            out: while (true) {
                var m = nth_identifier.get(++scope.cname);
                if (ALL_RESERVED_WORDS.has(m))
                    continue; // skip over "do"
                // https://github.com/mishoo/UglifyJS2/issues/242 -- do not
                // shadow a name reserved from mangling.
                if (options.reserved.has(m))
                    continue;
                // Functions with short names might collide with base54 output
                // and therefore cause collisions when keep_fnames is true.
                if (unmangleable_names && unmangleable_names.has(m))
                    continue out;
                // we must ensure that the mangled name does not shadow a name
                // from some parent scope that is referenced in this or in
                // inner scopes.
                for (let i = ext.length; --i >= 0;) {
                    const def = ext[i];
                    const name = def.mangled_name || (def.unmangleable(options) && def.name);
                    if (m == name)
                        continue out;
                }
                return m;
            }
        }
        AST_Scope.DEFMETHOD("next_mangled", function (options) {
            return next_mangled(this, options);
        });
        AST_Toplevel.DEFMETHOD("next_mangled", function (options) {
            let name;
            const mangled_names = this.mangled_names;
            do {
                name = next_mangled(this, options);
            } while (mangled_names.has(name));
            return name;
        });
        AST_Function.DEFMETHOD("next_mangled", function (options, def) {
            // #179, #326
            // in Safari strict mode, something like (function x(x){...}) is a syntax error;
            // a function expression's argument cannot shadow the function expression's name
            var tricky_def = def.orig[0] instanceof AST_SymbolFunarg && this.name && this.name.definition();
            // the function's mangled_name is null when keep_fnames is true
            var tricky_name = tricky_def ? tricky_def.mangled_name || tricky_def.name : null;
            while (true) {
                var name = next_mangled(this, options);
                if (!tricky_name || tricky_name != name)
                    return name;
            }
        });
        AST_Symbol.DEFMETHOD("unmangleable", function (options) {
            var def = this.definition();
            return !def || def.unmangleable(options);
        });
        // labels are always mangleable
        AST_Label.DEFMETHOD("unmangleable", return_false);
        AST_Symbol.DEFMETHOD("unreferenced", function () {
            return !this.definition().references.length && !this.scope.pinned();
        });
        AST_Symbol.DEFMETHOD("definition", function () {
            return this.thedef;
        });
        AST_Symbol.DEFMETHOD("global", function () {
            return this.thedef.global;
        });
        /**
         * Format the mangler options (if any) into their appropriate types
         */
        function format_mangler_options(options) {
            options = defaults(options, {
                eval: false,
                nth_identifier: base54,
                ie8: false,
                keep_classnames: false,
                keep_fnames: false,
                module: false,
                reserved: [],
                toplevel: false,
            });
            if (options.module)
                options.toplevel = true;
            if (!Array.isArray(options.reserved)
                && !(options.reserved instanceof Set)) {
                options.reserved = [];
            }
            options.reserved = new Set(options.reserved);
            // Never mangle arguments
            options.reserved.add("arguments");
            return options;
        }
        AST_Toplevel.DEFMETHOD("mangle_names", function (options) {
            options = format_mangler_options(options);
            var nth_identifier = options.nth_identifier;
            // We only need to mangle declaration nodes.  Special logic wired
            // into the code generator will display the mangled name if it's
            // present (and for AST_SymbolRef-s it'll use the mangled name of
            // the AST_SymbolDeclaration that it points to).
            var lname = -1;
            var to_mangle = [];
            if (options.keep_fnames) {
                function_defs = new Set();
            }
            const mangled_names = this.mangled_names = new Set();
            unmangleable_names = new Set();
            if (options.cache) {
                this.globals.forEach(collect);
                if (options.cache.props) {
                    options.cache.props.forEach(function (mangled_name) {
                        mangled_names.add(mangled_name);
                    });
                }
            }
            var tw = new TreeWalker(function (node, descend) {
                if (node instanceof AST_LabeledStatement) {
                    // lname is incremented when we get to the AST_Label
                    var save_nesting = lname;
                    descend();
                    lname = save_nesting;
                    return true; // don't descend again in TreeWalker
                }
                if (node instanceof AST_Defun
                    && !(tw.parent() instanceof AST_Scope)) {
                    scopes_with_block_defuns = scopes_with_block_defuns || new Set();
                    scopes_with_block_defuns.add(node.parent_scope.get_defun_scope());
                }
                if (node instanceof AST_Scope) {
                    node.variables.forEach(collect);
                    return;
                }
                if (node.is_block_scope()) {
                    node.block_scope.variables.forEach(collect);
                    return;
                }
                if (function_defs
                    && node instanceof AST_VarDef
                    && node.value instanceof AST_Lambda
                    && !node.value.name
                    && keep_name(options.keep_fnames, node.name.name)) {
                    function_defs.add(node.name.definition().id);
                    return;
                }
                if (node instanceof AST_Label) {
                    let name;
                    do {
                        name = nth_identifier.get(++lname);
                    } while (ALL_RESERVED_WORDS.has(name));
                    node.mangled_name = name;
                    return true;
                }
                if (!(options.ie8 || options.safari10) && node instanceof AST_SymbolCatch) {
                    to_mangle.push(node.definition());
                    return;
                }
            });
            this.walk(tw);
            if (options.keep_fnames || options.keep_classnames) {
                // Collect a set of short names which are unmangleable,
                // for use in avoiding collisions in next_mangled.
                to_mangle.forEach(def => {
                    if (def.name.length < 6 && def.unmangleable(options)) {
                        unmangleable_names.add(def.name);
                    }
                });
            }
            to_mangle.forEach(def => { def.mangle(options); });
            function_defs = null;
            unmangleable_names = null;
            scopes_with_block_defuns = null;
            function collect(symbol) {
                if (symbol.export & MASK_EXPORT_DONT_MANGLE) {
                    unmangleable_names.add(symbol.name);
                }
                else if (!options.reserved.has(symbol.name)) {
                    to_mangle.push(symbol);
                }
            }
        });
        AST_Toplevel.DEFMETHOD("find_colliding_names", function (options) {
            const cache = options.cache && options.cache.props;
            const avoid = new Set();
            options.reserved.forEach(to_avoid);
            this.globals.forEach(add_def);
            this.walk(new TreeWalker(function (node) {
                if (node instanceof AST_Scope)
                    node.variables.forEach(add_def);
                if (node instanceof AST_SymbolCatch)
                    add_def(node.definition());
            }));
            return avoid;
            function to_avoid(name) {
                avoid.add(name);
            }
            function add_def(def) {
                var name = def.name;
                if (def.global && cache && cache.has(name))
                    name = cache.get(name);
                else if (!def.unmangleable(options))
                    return;
                to_avoid(name);
            }
        });
        AST_Toplevel.DEFMETHOD("expand_names", function (options) {
            options = format_mangler_options(options);
            var nth_identifier = options.nth_identifier;
            if (nth_identifier.reset && nth_identifier.sort) {
                nth_identifier.reset();
                nth_identifier.sort();
            }
            var avoid = this.find_colliding_names(options);
            var cname = 0;
            this.globals.forEach(rename);
            this.walk(new TreeWalker(function (node) {
                if (node instanceof AST_Scope)
                    node.variables.forEach(rename);
                if (node instanceof AST_SymbolCatch)
                    rename(node.definition());
            }));
            function next_name() {
                var name;
                do {
                    name = nth_identifier.get(cname++);
                } while (avoid.has(name) || ALL_RESERVED_WORDS.has(name));
                return name;
            }
            function rename(def) {
                if (def.global && options.cache)
                    return;
                if (def.unmangleable(options))
                    return;
                if (options.reserved.has(def.name))
                    return;
                const redefinition = redefined_catch_def(def);
                const name = def.name = redefinition ? redefinition.name : next_name();
                def.orig.forEach(function (sym) {
                    sym.name = name;
                });
                def.references.forEach(function (sym) {
                    sym.name = name;
                });
            }
        });
        AST_Node.DEFMETHOD("tail_node", return_this);
        AST_Sequence.DEFMETHOD("tail_node", function () {
            return this.expressions[this.expressions.length - 1];
        });
        AST_Toplevel.DEFMETHOD("compute_char_frequency", function (options) {
            options = format_mangler_options(options);
            var nth_identifier = options.nth_identifier;
            if (!nth_identifier.reset || !nth_identifier.consider || !nth_identifier.sort) {
                // If the identifier mangler is invariant, skip computing character frequency.
                return;
            }
            nth_identifier.reset();
            try {
                AST_Node.prototype.print = function (stream, force_parens) {
                    this._print(stream, force_parens);
                    if (this instanceof AST_Symbol && !this.unmangleable(options)) {
                        nth_identifier.consider(this.name, -1);
                    }
                    else if (options.properties) {
                        if (this instanceof AST_DotHash) {
                            nth_identifier.consider("#" + this.property, -1);
                        }
                        else if (this instanceof AST_Dot) {
                            nth_identifier.consider(this.property, -1);
                        }
                        else if (this instanceof AST_Sub) {
                            skip_string(this.property);
                        }
                    }
                };
                nth_identifier.consider(this.print_to_string(), 1);
            }
            finally {
                AST_Node.prototype.print = AST_Node.prototype._print;
            }
            nth_identifier.sort();
            function skip_string(node) {
                if (node instanceof AST_String) {
                    nth_identifier.consider(node.value, -1);
                }
                else if (node instanceof AST_Conditional) {
                    skip_string(node.consequent);
                    skip_string(node.alternative);
                }
                else if (node instanceof AST_Sequence) {
                    skip_string(node.tail_node());
                }
            }
        });
        const base54 = (() => {
            const leading = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ$_".split("");
            const digits = "0123456789".split("");
            let chars;
            let frequency;
            function reset() {
                frequency = new Map();
                leading.forEach(function (ch) {
                    frequency.set(ch, 0);
                });
                digits.forEach(function (ch) {
                    frequency.set(ch, 0);
                });
            }
            function consider(str, delta) {
                for (var i = str.length; --i >= 0;) {
                    frequency.set(str[i], frequency.get(str[i]) + delta);
                }
            }
            function compare(a, b) {
                return frequency.get(b) - frequency.get(a);
            }
            function sort() {
                chars = mergeSort(leading, compare).concat(mergeSort(digits, compare));
            }
            // Ensure this is in a usable initial state.
            reset();
            sort();
            function base54(num) {
                var ret = "", base = 54;
                num++;
                do {
                    num--;
                    ret += chars[num % base];
                    num = Math.floor(num / base);
                    base = 64;
                } while (num > 0);
                return ret;
            }
            return {
                get: base54,
                consider,
                reset,
                sort
            };
        })();
        let mangle_options = undefined;
        AST_Node.prototype.size = function (compressor, stack) {
            mangle_options = compressor && compressor._mangle_options;
            let size = 0;
            walk_parent(this, (node, info) => {
                size += node._size(info);
                // Braceless arrow functions have fake "return" statements
                if (node instanceof AST_Arrow && node.is_braceless()) {
                    size += node.body[0].value._size(info);
                    return true;
                }
            }, stack || (compressor && compressor.stack));
            // just to save a bit of memory
            mangle_options = undefined;
            return size;
        };
        AST_Node.prototype._size = () => 0;
        AST_Debugger.prototype._size = () => 8;
        AST_Directive.prototype._size = function () {
            // TODO string encoding stuff
            return 2 + this.value.length;
        };
        /** Count commas/semicolons necessary to show a list of expressions/statements */
        const list_overhead = (array) => array.length && array.length - 1;
        AST_Block.prototype._size = function () {
            return 2 + list_overhead(this.body);
        };
        AST_Toplevel.prototype._size = function () {
            return list_overhead(this.body);
        };
        AST_EmptyStatement.prototype._size = () => 1;
        AST_LabeledStatement.prototype._size = () => 2; // x:
        AST_Do.prototype._size = () => 9;
        AST_While.prototype._size = () => 7;
        AST_For.prototype._size = () => 8;
        AST_ForIn.prototype._size = () => 8;
        // AST_ForOf inherits ^
        AST_With.prototype._size = () => 6;
        AST_Expansion.prototype._size = () => 3;
        const lambda_modifiers = func => (func.is_generator ? 1 : 0) + (func.async ? 6 : 0);
        AST_Accessor.prototype._size = function () {
            return lambda_modifiers(this) + 4 + list_overhead(this.argnames) + list_overhead(this.body);
        };
        AST_Function.prototype._size = function (info) {
            const first = !!first_in_statement(info);
            return (first * 2) + lambda_modifiers(this) + 12 + list_overhead(this.argnames) + list_overhead(this.body);
        };
        AST_Defun.prototype._size = function () {
            return lambda_modifiers(this) + 13 + list_overhead(this.argnames) + list_overhead(this.body);
        };
        AST_Arrow.prototype._size = function () {
            let args_and_arrow = 2 + list_overhead(this.argnames);
            if (!(this.argnames.length === 1
                && this.argnames[0] instanceof AST_Symbol)) {
                args_and_arrow += 2; // parens around the args
            }
            const body_overhead = this.is_braceless() ? 0 : list_overhead(this.body) + 2;
            return lambda_modifiers(this) + args_and_arrow + body_overhead;
        };
        AST_Destructuring.prototype._size = () => 2;
        AST_TemplateString.prototype._size = function () {
            return 2 + (Math.floor(this.segments.length / 2) * 3); /* "${}" */
        };
        AST_TemplateSegment.prototype._size = function () {
            return this.value.length;
        };
        AST_Return.prototype._size = function () {
            return this.value ? 7 : 6;
        };
        AST_Throw.prototype._size = () => 6;
        AST_Break.prototype._size = function () {
            return this.label ? 6 : 5;
        };
        AST_Continue.prototype._size = function () {
            return this.label ? 9 : 8;
        };
        AST_If.prototype._size = () => 4;
        AST_Switch.prototype._size = function () {
            return 8 + list_overhead(this.body);
        };
        AST_Case.prototype._size = function () {
            return 5 + list_overhead(this.body);
        };
        AST_Default.prototype._size = function () {
            return 8 + list_overhead(this.body);
        };
        AST_Try.prototype._size = () => 3;
        AST_Catch.prototype._size = function () {
            let size = 7 + list_overhead(this.body);
            if (this.argname) {
                size += 2;
            }
            return size;
        };
        AST_Finally.prototype._size = function () {
            return 7 + list_overhead(this.body);
        };
        AST_Var.prototype._size = function () {
            return 4 + list_overhead(this.definitions);
        };
        AST_Let.prototype._size = function () {
            return 4 + list_overhead(this.definitions);
        };
        AST_Const.prototype._size = function () {
            return 6 + list_overhead(this.definitions);
        };
        AST_VarDef.prototype._size = function () {
            return this.value ? 1 : 0;
        };
        AST_NameMapping.prototype._size = function () {
            // foreign name isn't mangled
            return this.name ? 4 : 0;
        };
        AST_Import.prototype._size = function () {
            // import
            let size = 6;
            if (this.imported_name)
                size += 1;
            // from
            if (this.imported_name || this.imported_names)
                size += 5;
            // braces, and the commas
            if (this.imported_names) {
                size += 2 + list_overhead(this.imported_names);
            }
            return size;
        };
        AST_ImportMeta.prototype._size = () => 11;
        AST_Export.prototype._size = function () {
            let size = 7 + (this.is_default ? 8 : 0);
            if (this.exported_value) {
                size += this.exported_value._size();
            }
            if (this.exported_names) {
                // Braces and commas
                size += 2 + list_overhead(this.exported_names);
            }
            if (this.module_name) {
                // "from "
                size += 5;
            }
            return size;
        };
        AST_Call.prototype._size = function () {
            if (this.optional) {
                return 4 + list_overhead(this.args);
            }
            return 2 + list_overhead(this.args);
        };
        AST_New.prototype._size = function () {
            return 6 + list_overhead(this.args);
        };
        AST_Sequence.prototype._size = function () {
            return list_overhead(this.expressions);
        };
        AST_Dot.prototype._size = function () {
            if (this.optional) {
                return this.property.length + 2;
            }
            return this.property.length + 1;
        };
        AST_DotHash.prototype._size = function () {
            if (this.optional) {
                return this.property.length + 3;
            }
            return this.property.length + 2;
        };
        AST_Sub.prototype._size = function () {
            return this.optional ? 4 : 2;
        };
        AST_Unary.prototype._size = function () {
            if (this.operator === "typeof")
                return 7;
            if (this.operator === "void")
                return 5;
            return this.operator.length;
        };
        AST_Binary.prototype._size = function (info) {
            if (this.operator === "in")
                return 4;
            let size = this.operator.length;
            if ((this.operator === "+" || this.operator === "-")
                && this.right instanceof AST_Unary && this.right.operator === this.operator) {
                // 1+ +a > needs space between the +
                size += 1;
            }
            if (this.needs_parens(info)) {
                size += 2;
            }
            return size;
        };
        AST_Conditional.prototype._size = () => 3;
        AST_Array.prototype._size = function () {
            return 2 + list_overhead(this.elements);
        };
        AST_Object.prototype._size = function (info) {
            let base = 2;
            if (first_in_statement(info)) {
                base += 2; // parens
            }
            return base + list_overhead(this.properties);
        };
        /*#__INLINE__*/
        const key_size = key => typeof key === "string" ? key.length : 0;
        AST_ObjectKeyVal.prototype._size = function () {
            return key_size(this.key) + 1;
        };
        /*#__INLINE__*/
        const static_size = is_static => is_static ? 7 : 0;
        AST_ObjectGetter.prototype._size = function () {
            return 5 + static_size(this.static) + key_size(this.key);
        };
        AST_ObjectSetter.prototype._size = function () {
            return 5 + static_size(this.static) + key_size(this.key);
        };
        AST_ConciseMethod.prototype._size = function () {
            return static_size(this.static) + key_size(this.key) + lambda_modifiers(this);
        };
        AST_PrivateMethod.prototype._size = function () {
            return AST_ConciseMethod.prototype._size.call(this) + 1;
        };
        AST_PrivateGetter.prototype._size = AST_PrivateSetter.prototype._size = function () {
            return AST_ConciseMethod.prototype._size.call(this) + 4;
        };
        AST_PrivateIn.prototype._size = function () {
            return 5; // "#", and " in "
        };
        AST_Class.prototype._size = function () {
            return ((this.name ? 8 : 7)
                + (this.extends ? 8 : 0));
        };
        AST_ClassStaticBlock.prototype._size = function () {
            // "static{}" + semicolons
            return 8 + list_overhead(this.body);
        };
        AST_ClassProperty.prototype._size = function () {
            return (static_size(this.static)
                + (typeof this.key === "string" ? this.key.length + 2 : 0)
                + (this.value ? 1 : 0));
        };
        AST_ClassPrivateProperty.prototype._size = function () {
            return AST_ClassProperty.prototype._size.call(this) + 1;
        };
        AST_Symbol.prototype._size = function () {
            if (!(mangle_options && this.thedef && !this.thedef.unmangleable(mangle_options))) {
                return this.name.length;
            }
            else {
                return 1;
            }
        };
        // TODO take propmangle into account
        AST_SymbolClassProperty.prototype._size = function () {
            return this.name.length;
        };
        AST_SymbolRef.prototype._size = AST_SymbolDeclaration.prototype._size = function () {
            if (this.name === "arguments")
                return 9;
            return AST_Symbol.prototype._size.call(this);
        };
        AST_NewTarget.prototype._size = () => 10;
        AST_SymbolImportForeign.prototype._size = function () {
            return this.name.length;
        };
        AST_SymbolExportForeign.prototype._size = function () {
            return this.name.length;
        };
        AST_This.prototype._size = () => 4;
        AST_Super.prototype._size = () => 5;
        AST_String.prototype._size = function () {
            return this.value.length + 2;
        };
        AST_Number.prototype._size = function () {
            const { value } = this;
            if (value === 0)
                return 1;
            if (value > 0 && Math.floor(value) === value) {
                return Math.floor(Math.log10(value) + 1);
            }
            return value.toString().length;
        };
        AST_BigInt.prototype._size = function () {
            return this.value.length;
        };
        AST_RegExp.prototype._size = function () {
            return this.value.toString().length;
        };
        AST_Null.prototype._size = () => 4;
        AST_NaN.prototype._size = () => 3;
        AST_Undefined.prototype._size = () => 6; // "void 0"
        AST_Hole.prototype._size = () => 0; // comma is taken into account by list_overhead()
        AST_Infinity.prototype._size = () => 8;
        AST_True.prototype._size = () => 4;
        AST_False.prototype._size = () => 5;
        AST_Await.prototype._size = () => 6;
        AST_Yield.prototype._size = () => 6;
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        // bitfield flags to be stored in node.flags.
        // These are set and unset during compression, and store information in the node without requiring multiple fields.
        const UNUSED = 0b00000001;
        const TRUTHY = 0b00000010;
        const FALSY = 0b00000100;
        const UNDEFINED = 0b00001000;
        const INLINED = 0b00010000;
        // Nodes to which values are ever written. Used when keep_assign is part of the unused option string.
        const WRITE_ONLY = 0b00100000;
        // information specific to a single compression pass
        const SQUEEZED = 0b0000000100000000;
        const OPTIMIZED = 0b0000001000000000;
        const TOP = 0b0000010000000000;
        const CLEAR_BETWEEN_PASSES = SQUEEZED | OPTIMIZED | TOP;
        const has_flag = (node, flag) => node.flags & flag;
        const set_flag = (node, flag) => { node.flags |= flag; };
        const clear_flag = (node, flag) => { node.flags &= ~flag; };
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        function merge_sequence(array, node) {
            if (node instanceof AST_Sequence) {
                array.push(...node.expressions);
            }
            else {
                array.push(node);
            }
            return array;
        }
        function make_sequence(orig, expressions) {
            if (expressions.length == 1)
                return expressions[0];
            if (expressions.length == 0)
                throw new Error("trying to create a sequence with length zero!");
            return make_node(AST_Sequence, orig, {
                expressions: expressions.reduce(merge_sequence, [])
            });
        }
        function make_node_from_constant(val, orig) {
            switch (typeof val) {
                case "string":
                    return make_node(AST_String, orig, {
                        value: val
                    });
                case "number":
                    if (isNaN(val))
                        return make_node(AST_NaN, orig);
                    if (isFinite(val)) {
                        return 1 / val < 0 ? make_node(AST_UnaryPrefix, orig, {
                            operator: "-",
                            expression: make_node(AST_Number, orig, { value: -val })
                        }) : make_node(AST_Number, orig, { value: val });
                    }
                    return val < 0 ? make_node(AST_UnaryPrefix, orig, {
                        operator: "-",
                        expression: make_node(AST_Infinity, orig)
                    }) : make_node(AST_Infinity, orig);
                case "bigint":
                    return make_node(AST_BigInt, orig, { value: val.toString() });
                case "boolean":
                    return make_node(val ? AST_True : AST_False, orig);
                case "undefined":
                    return make_node(AST_Undefined, orig);
                default:
                    if (val === null) {
                        return make_node(AST_Null, orig, { value: null });
                    }
                    if (val instanceof RegExp) {
                        return make_node(AST_RegExp, orig, {
                            value: {
                                source: regexp_source_fix(val.source),
                                flags: val.flags
                            }
                        });
                    }
                    throw new Error(string_template("Can't handle constant of type: {type}", {
                        type: typeof val
                    }));
            }
        }
        function best_of_expression(ast1, ast2) {
            return ast1.size() > ast2.size() ? ast2 : ast1;
        }
        function best_of_statement(ast1, ast2) {
            return best_of_expression(make_node(AST_SimpleStatement, ast1, {
                body: ast1
            }), make_node(AST_SimpleStatement, ast2, {
                body: ast2
            })).body;
        }
        /** Find which node is smaller, and return that */
        function best_of(compressor, ast1, ast2) {
            if (first_in_statement(compressor)) {
                return best_of_statement(ast1, ast2);
            }
            else {
                return best_of_expression(ast1, ast2);
            }
        }
        /** Simplify an object property's key, if possible */
        function get_simple_key(key) {
            if (key instanceof AST_Constant) {
                return key.getValue();
            }
            if (key instanceof AST_UnaryPrefix
                && key.operator == "void"
                && key.expression instanceof AST_Constant) {
                return;
            }
            return key;
        }
        function read_property(obj, key) {
            key = get_simple_key(key);
            if (key instanceof AST_Node)
                return;
            var value;
            if (obj instanceof AST_Array) {
                var elements = obj.elements;
                if (key == "length")
                    return make_node_from_constant(elements.length, obj);
                if (typeof key == "number" && key in elements)
                    value = elements[key];
            }
            else if (obj instanceof AST_Object) {
                key = "" + key;
                var props = obj.properties;
                for (var i = props.length; --i >= 0;) {
                    var prop = props[i];
                    if (!(prop instanceof AST_ObjectKeyVal))
                        return;
                    if (!value && props[i].key === key)
                        value = props[i].value;
                }
            }
            return value instanceof AST_SymbolRef && value.fixed_value() || value;
        }
        function has_break_or_continue(loop, parent) {
            var found = false;
            var tw = new TreeWalker(function (node) {
                if (found || node instanceof AST_Scope)
                    return true;
                if (node instanceof AST_LoopControl && tw.loopcontrol_target(node) === loop) {
                    return found = true;
                }
            });
            if (parent instanceof AST_LabeledStatement)
                tw.push(parent);
            tw.push(loop);
            loop.body.walk(tw);
            return found;
        }
        // we shouldn't compress (1,func)(something) to
        // func(something) because that changes the meaning of
        // the func (becomes lexical instead of global).
        function maintain_this_binding(parent, orig, val) {
            if (parent instanceof AST_UnaryPrefix && parent.operator == "delete"
                || parent instanceof AST_Call && parent.expression === orig
                    && (val instanceof AST_Chain
                        || val instanceof AST_PropAccess
                        || val instanceof AST_SymbolRef && val.name == "eval")) {
                const zero = make_node(AST_Number, orig, { value: 0 });
                return make_sequence(orig, [zero, val]);
            }
            else {
                return val;
            }
        }
        function is_func_expr(node) {
            return node instanceof AST_Arrow || node instanceof AST_Function;
        }
        /**
         * Used to determine whether the node can benefit from negation.
         * Not the case with arrow functions (you need an extra set of parens). */
        function is_iife_call(node) {
            if (node.TYPE != "Call")
                return false;
            return node.expression instanceof AST_Function || is_iife_call(node.expression);
        }
        function is_empty(thing) {
            if (thing === null)
                return true;
            if (thing instanceof AST_EmptyStatement)
                return true;
            if (thing instanceof AST_BlockStatement)
                return thing.body.length == 0;
            return false;
        }
        const identifier_atom = makePredicate("Infinity NaN undefined");
        function is_identifier_atom(node) {
            return node instanceof AST_Infinity
                || node instanceof AST_NaN
                || node instanceof AST_Undefined;
        }
        /** Check if this is a SymbolRef node which has one def of a certain AST type */
        function is_ref_of(ref, type) {
            if (!(ref instanceof AST_SymbolRef))
                return false;
            var orig = ref.definition().orig;
            for (var i = orig.length; --i >= 0;) {
                if (orig[i] instanceof type)
                    return true;
            }
        }
        /**Can we turn { block contents... } into just the block contents ?
         * Not if one of these is inside.
         **/
        function can_be_evicted_from_block(node) {
            return !(node instanceof AST_DefClass ||
                node instanceof AST_Defun ||
                node instanceof AST_Let ||
                node instanceof AST_Const ||
                node instanceof AST_Export ||
                node instanceof AST_Import);
        }
        function as_statement_array(thing) {
            if (thing === null)
                return [];
            if (thing instanceof AST_BlockStatement)
                return thing.body;
            if (thing instanceof AST_EmptyStatement)
                return [];
            if (thing instanceof AST_Statement)
                return [thing];
            throw new Error("Can't convert thing to statement array");
        }
        function is_reachable(scope_node, defs) {
            const find_ref = node => {
                if (node instanceof AST_SymbolRef && defs.includes(node.definition())) {
                    return walk_abort;
                }
            };
            return walk_parent(scope_node, (node, info) => {
                if (node instanceof AST_Scope && node !== scope_node) {
                    var parent = info.parent();
                    if (parent instanceof AST_Call
                        && parent.expression === node
                        // Async/Generators aren't guaranteed to sync evaluate all of
                        // their body steps, so it's possible they close over the variable.
                        && !(node.async || node.is_generator)) {
                        return;
                    }
                    if (walk(node, find_ref))
                        return walk_abort;
                    return true;
                }
            });
        }
        /** Check if a ref refers to the name of a function/class it's defined within */
        function is_recursive_ref(compressor, def) {
            var node;
            for (var i = 0; node = compressor.parent(i); i++) {
                if (node instanceof AST_Lambda || node instanceof AST_Class) {
                    var name = node.name;
                    if (name && name.definition() === def) {
                        return true;
                    }
                }
            }
            return false;
        }
        // TODO this only works with AST_Defun, shouldn't it work for other ways of defining functions?
        function retain_top_func(fn, compressor) {
            return compressor.top_retain
                && fn instanceof AST_Defun
                && has_flag(fn, TOP)
                && fn.name
                && compressor.top_retain(fn.name.definition());
        }
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        // Lists of native methods, useful for `unsafe` option which assumes they exist.
        // Note: Lots of methods and functions are missing here, in case they aren't pure
        // or not available in all JS environments.
        function make_nested_lookup(obj) {
            const out = new Map();
            for (var key of Object.keys(obj)) {
                out.set(key, makePredicate(obj[key]));
            }
            const does_have = (global_name, fname) => {
                const inner_map = out.get(global_name);
                return inner_map != null && inner_map.has(fname);
            };
            return does_have;
        }
        // Objects which are safe to access without throwing or causing a side effect.
        // Usually we'd check the `unsafe` option first but these are way too common for that
        const pure_prop_access_globals = new Set([
            "Number",
            "String",
            "Array",
            "Object",
            "Function",
            "Promise",
        ]);
        const object_methods = [
            "constructor",
            "toString",
            "valueOf",
        ];
        const is_pure_native_method = make_nested_lookup({
            Array: [
                "at",
                "flat",
                "includes",
                "indexOf",
                "join",
                "lastIndexOf",
                "slice",
                ...object_methods,
            ],
            Boolean: object_methods,
            Function: object_methods,
            Number: [
                "toExponential",
                "toFixed",
                "toPrecision",
                ...object_methods,
            ],
            Object: object_methods,
            RegExp: [
                "test",
                ...object_methods,
            ],
            String: [
                "at",
                "charAt",
                "charCodeAt",
                "charPointAt",
                "concat",
                "endsWith",
                "fromCharCode",
                "fromCodePoint",
                "includes",
                "indexOf",
                "italics",
                "lastIndexOf",
                "localeCompare",
                "match",
                "matchAll",
                "normalize",
                "padStart",
                "padEnd",
                "repeat",
                "replace",
                "replaceAll",
                "search",
                "slice",
                "split",
                "startsWith",
                "substr",
                "substring",
                "repeat",
                "toLocaleLowerCase",
                "toLocaleUpperCase",
                "toLowerCase",
                "toUpperCase",
                "trim",
                "trimEnd",
                "trimStart",
                ...object_methods,
            ],
        });
        const is_pure_native_fn = make_nested_lookup({
            Array: [
                "isArray",
            ],
            Math: [
                "abs",
                "acos",
                "asin",
                "atan",
                "ceil",
                "cos",
                "exp",
                "floor",
                "log",
                "round",
                "sin",
                "sqrt",
                "tan",
                "atan2",
                "pow",
                "max",
                "min",
            ],
            Number: [
                "isFinite",
                "isNaN",
            ],
            Object: [
                "create",
                "getOwnPropertyDescriptor",
                "getOwnPropertyNames",
                "getPrototypeOf",
                "isExtensible",
                "isFrozen",
                "isSealed",
                "hasOwn",
                "keys",
            ],
            String: [
                "fromCharCode",
            ],
        });
        // Known numeric values which come with JS environments
        const is_pure_native_value = make_nested_lookup({
            Math: [
                "E",
                "LN10",
                "LN2",
                "LOG2E",
                "LOG10E",
                "PI",
                "SQRT1_2",
                "SQRT2",
            ],
            Number: [
                "MAX_VALUE",
                "MIN_VALUE",
                "NaN",
                "NEGATIVE_INFINITY",
                "POSITIVE_INFINITY",
            ],
        });
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        // Functions and methods to infer certain facts about expressions
        // It's not always possible to be 100% sure about something just by static analysis,
        // so `true` means yes, and `false` means maybe
        const is_undeclared_ref = (node) => node instanceof AST_SymbolRef && node.definition().undeclared;
        const bitwise_binop = makePredicate("<<< >> << & | ^ ~");
        const lazy_op = makePredicate("&& || ??");
        const unary_side_effects = makePredicate("delete ++ --");
        // methods to determine whether an expression has a boolean result type
        (function (def_is_boolean) {
            const unary_bool = makePredicate("! delete");
            const binary_bool = makePredicate("in instanceof == != === !== < <= >= >");
            def_is_boolean(AST_Node, return_false);
            def_is_boolean(AST_UnaryPrefix, function () {
                return unary_bool.has(this.operator);
            });
            def_is_boolean(AST_Binary, function () {
                return binary_bool.has(this.operator)
                    || lazy_op.has(this.operator)
                        && this.left.is_boolean()
                        && this.right.is_boolean();
            });
            def_is_boolean(AST_Conditional, function () {
                return this.consequent.is_boolean() && this.alternative.is_boolean();
            });
            def_is_boolean(AST_Assign, function () {
                return this.operator == "=" && this.right.is_boolean();
            });
            def_is_boolean(AST_Sequence, function () {
                return this.tail_node().is_boolean();
            });
            def_is_boolean(AST_True, return_true);
            def_is_boolean(AST_False, return_true);
        })(function (node, func) {
            node.DEFMETHOD("is_boolean", func);
        });
        // methods to determine if an expression has a numeric result type
        (function (def_is_number) {
            def_is_number(AST_Node, return_false);
            def_is_number(AST_Number, return_true);
            const unary = makePredicate("+ - ~ ++ --");
            def_is_number(AST_Unary, function () {
                return unary.has(this.operator) && !(this.expression instanceof AST_BigInt);
            });
            const numeric_ops = makePredicate("- * / % & | ^ << >> >>>");
            def_is_number(AST_Binary, function (compressor) {
                return numeric_ops.has(this.operator) || this.operator == "+"
                    && this.left.is_number(compressor)
                    && this.right.is_number(compressor);
            });
            def_is_number(AST_Assign, function (compressor) {
                return numeric_ops.has(this.operator.slice(0, -1))
                    || this.operator == "=" && this.right.is_number(compressor);
            });
            def_is_number(AST_Sequence, function (compressor) {
                return this.tail_node().is_number(compressor);
            });
            def_is_number(AST_Conditional, function (compressor) {
                return this.consequent.is_number(compressor) && this.alternative.is_number(compressor);
            });
        })(function (node, func) {
            node.DEFMETHOD("is_number", func);
        });
        // methods to determine if an expression is a 32 bit integer (IE results from bitwise ops, or is an integer constant fitting in that size
        (function (def_is_32_bit_integer) {
            def_is_32_bit_integer(AST_Node, return_false);
            def_is_32_bit_integer(AST_Number, function () {
                return this.value === (this.value | 0);
            });
            def_is_32_bit_integer(AST_UnaryPrefix, function () {
                return this.operator == "~" ? this.expression.is_number()
                    : this.operator === "+" ? this.expression.is_32_bit_integer()
                        : false;
            });
            def_is_32_bit_integer(AST_Binary, function () {
                return bitwise_binop.has(this.operator);
            });
        }(function (node, func) {
            node.DEFMETHOD("is_32_bit_integer", func);
        }));
        // methods to determine if an expression has a string result type
        (function (def_is_string) {
            def_is_string(AST_Node, return_false);
            def_is_string(AST_String, return_true);
            def_is_string(AST_TemplateString, return_true);
            def_is_string(AST_UnaryPrefix, function () {
                return this.operator == "typeof";
            });
            def_is_string(AST_Binary, function (compressor) {
                return this.operator == "+" &&
                    (this.left.is_string(compressor) || this.right.is_string(compressor));
            });
            def_is_string(AST_Assign, function (compressor) {
                return (this.operator == "=" || this.operator == "+=") && this.right.is_string(compressor);
            });
            def_is_string(AST_Sequence, function (compressor) {
                return this.tail_node().is_string(compressor);
            });
            def_is_string(AST_Conditional, function (compressor) {
                return this.consequent.is_string(compressor) && this.alternative.is_string(compressor);
            });
        })(function (node, func) {
            node.DEFMETHOD("is_string", func);
        });
        function is_undefined(node, compressor) {
            return (has_flag(node, UNDEFINED)
                || node instanceof AST_Undefined
                || node instanceof AST_UnaryPrefix
                    && node.operator == "void"
                    && !node.expression.has_side_effects(compressor));
        }
        // Is the node explicitly null or undefined.
        function is_null_or_undefined(node, compressor) {
            let fixed;
            return (node instanceof AST_Null
                || is_undefined(node, compressor)
                || (node instanceof AST_SymbolRef
                    && (fixed = node.definition().fixed) instanceof AST_Node
                    && is_nullish(fixed, compressor)));
        }
        // Find out if this expression is optionally chained from a base-point that we
        // can statically analyze as null or undefined.
        function is_nullish_shortcircuited(node, compressor) {
            if (node instanceof AST_PropAccess || node instanceof AST_Call) {
                return ((node.optional && is_null_or_undefined(node.expression, compressor))
                    || is_nullish_shortcircuited(node.expression, compressor));
            }
            if (node instanceof AST_Chain)
                return is_nullish_shortcircuited(node.expression, compressor);
            return false;
        }
        // Find out if something is == null, or can short circuit into nullish.
        // Used to optimize ?. and ??
        function is_nullish(node, compressor) {
            if (is_null_or_undefined(node, compressor))
                return true;
            return is_nullish_shortcircuited(node, compressor);
        }
        // Determine if expression might cause side effects
        // If there's a possibility that a node may change something when it's executed, this returns true
        (function (def_has_side_effects) {
            def_has_side_effects(AST_Node, return_true);
            def_has_side_effects(AST_EmptyStatement, return_false);
            def_has_side_effects(AST_Constant, return_false);
            def_has_side_effects(AST_This, return_false);
            function any(list, compressor) {
                for (var i = list.length; --i >= 0;)
                    if (list[i].has_side_effects(compressor))
                        return true;
                return false;
            }
            def_has_side_effects(AST_Block, function (compressor) {
                return any(this.body, compressor);
            });
            def_has_side_effects(AST_Call, function (compressor) {
                if (!this.is_callee_pure(compressor)
                    && (!this.expression.is_call_pure(compressor)
                        || this.expression.has_side_effects(compressor))) {
                    return true;
                }
                return any(this.args, compressor);
            });
            def_has_side_effects(AST_Switch, function (compressor) {
                return this.expression.has_side_effects(compressor)
                    || any(this.body, compressor);
            });
            def_has_side_effects(AST_Case, function (compressor) {
                return this.expression.has_side_effects(compressor)
                    || any(this.body, compressor);
            });
            def_has_side_effects(AST_Try, function (compressor) {
                return this.body.has_side_effects(compressor)
                    || this.bcatch && this.bcatch.has_side_effects(compressor)
                    || this.bfinally && this.bfinally.has_side_effects(compressor);
            });
            def_has_side_effects(AST_If, function (compressor) {
                return this.condition.has_side_effects(compressor)
                    || this.body && this.body.has_side_effects(compressor)
                    || this.alternative && this.alternative.has_side_effects(compressor);
            });
            def_has_side_effects(AST_ImportMeta, return_false);
            def_has_side_effects(AST_LabeledStatement, function (compressor) {
                return this.body.has_side_effects(compressor);
            });
            def_has_side_effects(AST_SimpleStatement, function (compressor) {
                return this.body.has_side_effects(compressor);
            });
            def_has_side_effects(AST_Lambda, return_false);
            def_has_side_effects(AST_Class, function (compressor) {
                if (this.extends && this.extends.has_side_effects(compressor)) {
                    return true;
                }
                return any(this.properties, compressor);
            });
            def_has_side_effects(AST_ClassStaticBlock, function (compressor) {
                return any(this.body, compressor);
            });
            def_has_side_effects(AST_Binary, function (compressor) {
                return this.left.has_side_effects(compressor)
                    || this.right.has_side_effects(compressor);
            });
            def_has_side_effects(AST_Assign, return_true);
            def_has_side_effects(AST_Conditional, function (compressor) {
                return this.condition.has_side_effects(compressor)
                    || this.consequent.has_side_effects(compressor)
                    || this.alternative.has_side_effects(compressor);
            });
            def_has_side_effects(AST_Unary, function (compressor) {
                return unary_side_effects.has(this.operator)
                    || this.expression.has_side_effects(compressor);
            });
            def_has_side_effects(AST_SymbolRef, function (compressor) {
                return !this.is_declared(compressor) && !pure_prop_access_globals.has(this.name);
            });
            def_has_side_effects(AST_SymbolClassProperty, return_false);
            def_has_side_effects(AST_SymbolDeclaration, return_false);
            def_has_side_effects(AST_Object, function (compressor) {
                return any(this.properties, compressor);
            });
            def_has_side_effects(AST_ObjectProperty, function (compressor) {
                return (this.computed_key() && this.key.has_side_effects(compressor)
                    || this.value && this.value.has_side_effects(compressor));
            });
            def_has_side_effects(AST_ClassProperty, function (compressor) {
                return (this.computed_key() && this.key.has_side_effects(compressor)
                    || this.static && this.value && this.value.has_side_effects(compressor));
            });
            def_has_side_effects(AST_ConciseMethod, function (compressor) {
                return this.computed_key() && this.key.has_side_effects(compressor);
            });
            def_has_side_effects(AST_ObjectGetter, function (compressor) {
                return this.computed_key() && this.key.has_side_effects(compressor);
            });
            def_has_side_effects(AST_ObjectSetter, function (compressor) {
                return this.computed_key() && this.key.has_side_effects(compressor);
            });
            def_has_side_effects(AST_Array, function (compressor) {
                return any(this.elements, compressor);
            });
            def_has_side_effects(AST_Dot, function (compressor) {
                if (is_nullish(this, compressor)) {
                    return this.expression.has_side_effects(compressor);
                }
                if (!this.optional && this.expression.may_throw_on_access(compressor)) {
                    return true;
                }
                return this.expression.has_side_effects(compressor);
            });
            def_has_side_effects(AST_Sub, function (compressor) {
                if (is_nullish(this, compressor)) {
                    return this.expression.has_side_effects(compressor);
                }
                if (!this.optional && this.expression.may_throw_on_access(compressor)) {
                    return true;
                }
                var property = this.property.has_side_effects(compressor);
                if (property && this.optional)
                    return true; // "?." is a condition
                return property || this.expression.has_side_effects(compressor);
            });
            def_has_side_effects(AST_Chain, function (compressor) {
                return this.expression.has_side_effects(compressor);
            });
            def_has_side_effects(AST_Sequence, function (compressor) {
                return any(this.expressions, compressor);
            });
            def_has_side_effects(AST_Definitions, function (compressor) {
                return any(this.definitions, compressor);
            });
            def_has_side_effects(AST_VarDef, function () {
                return this.value;
            });
            def_has_side_effects(AST_TemplateSegment, return_false);
            def_has_side_effects(AST_TemplateString, function (compressor) {
                return any(this.segments, compressor);
            });
        })(function (node, func) {
            node.DEFMETHOD("has_side_effects", func);
        });
        // determine if expression may throw
        (function (def_may_throw) {
            def_may_throw(AST_Node, return_true);
            def_may_throw(AST_Constant, return_false);
            def_may_throw(AST_EmptyStatement, return_false);
            def_may_throw(AST_Lambda, return_false);
            def_may_throw(AST_SymbolDeclaration, return_false);
            def_may_throw(AST_This, return_false);
            def_may_throw(AST_ImportMeta, return_false);
            function any(list, compressor) {
                for (var i = list.length; --i >= 0;)
                    if (list[i].may_throw(compressor))
                        return true;
                return false;
            }
            def_may_throw(AST_Class, function (compressor) {
                if (this.extends && this.extends.may_throw(compressor))
                    return true;
                return any(this.properties, compressor);
            });
            def_may_throw(AST_ClassStaticBlock, function (compressor) {
                return any(this.body, compressor);
            });
            def_may_throw(AST_Array, function (compressor) {
                return any(this.elements, compressor);
            });
            def_may_throw(AST_Assign, function (compressor) {
                if (this.right.may_throw(compressor))
                    return true;
                if (!compressor.has_directive("use strict")
                    && this.operator == "="
                    && this.left instanceof AST_SymbolRef) {
                    return false;
                }
                return this.left.may_throw(compressor);
            });
            def_may_throw(AST_Binary, function (compressor) {
                return this.left.may_throw(compressor)
                    || this.right.may_throw(compressor);
            });
            def_may_throw(AST_Block, function (compressor) {
                return any(this.body, compressor);
            });
            def_may_throw(AST_Call, function (compressor) {
                if (is_nullish(this, compressor))
                    return false;
                if (any(this.args, compressor))
                    return true;
                if (this.is_callee_pure(compressor))
                    return false;
                if (this.expression.may_throw(compressor))
                    return true;
                return !(this.expression instanceof AST_Lambda)
                    || any(this.expression.body, compressor);
            });
            def_may_throw(AST_Case, function (compressor) {
                return this.expression.may_throw(compressor)
                    || any(this.body, compressor);
            });
            def_may_throw(AST_Conditional, function (compressor) {
                return this.condition.may_throw(compressor)
                    || this.consequent.may_throw(compressor)
                    || this.alternative.may_throw(compressor);
            });
            def_may_throw(AST_Definitions, function (compressor) {
                return any(this.definitions, compressor);
            });
            def_may_throw(AST_If, function (compressor) {
                return this.condition.may_throw(compressor)
                    || this.body && this.body.may_throw(compressor)
                    || this.alternative && this.alternative.may_throw(compressor);
            });
            def_may_throw(AST_LabeledStatement, function (compressor) {
                return this.body.may_throw(compressor);
            });
            def_may_throw(AST_Object, function (compressor) {
                return any(this.properties, compressor);
            });
            def_may_throw(AST_ObjectProperty, function (compressor) {
                // TODO key may throw too
                return this.value ? this.value.may_throw(compressor) : false;
            });
            def_may_throw(AST_ClassProperty, function (compressor) {
                return (this.computed_key() && this.key.may_throw(compressor)
                    || this.static && this.value && this.value.may_throw(compressor));
            });
            def_may_throw(AST_ConciseMethod, function (compressor) {
                return this.computed_key() && this.key.may_throw(compressor);
            });
            def_may_throw(AST_ObjectGetter, function (compressor) {
                return this.computed_key() && this.key.may_throw(compressor);
            });
            def_may_throw(AST_ObjectSetter, function (compressor) {
                return this.computed_key() && this.key.may_throw(compressor);
            });
            def_may_throw(AST_Return, function (compressor) {
                return this.value && this.value.may_throw(compressor);
            });
            def_may_throw(AST_Sequence, function (compressor) {
                return any(this.expressions, compressor);
            });
            def_may_throw(AST_SimpleStatement, function (compressor) {
                return this.body.may_throw(compressor);
            });
            def_may_throw(AST_Dot, function (compressor) {
                if (is_nullish(this, compressor))
                    return false;
                return !this.optional && this.expression.may_throw_on_access(compressor)
                    || this.expression.may_throw(compressor);
            });
            def_may_throw(AST_Sub, function (compressor) {
                if (is_nullish(this, compressor))
                    return false;
                return !this.optional && this.expression.may_throw_on_access(compressor)
                    || this.expression.may_throw(compressor)
                    || this.property.may_throw(compressor);
            });
            def_may_throw(AST_Chain, function (compressor) {
                return this.expression.may_throw(compressor);
            });
            def_may_throw(AST_Switch, function (compressor) {
                return this.expression.may_throw(compressor)
                    || any(this.body, compressor);
            });
            def_may_throw(AST_SymbolRef, function (compressor) {
                return !this.is_declared(compressor) && !pure_prop_access_globals.has(this.name);
            });
            def_may_throw(AST_SymbolClassProperty, return_false);
            def_may_throw(AST_Try, function (compressor) {
                return this.bcatch ? this.bcatch.may_throw(compressor) : this.body.may_throw(compressor)
                    || this.bfinally && this.bfinally.may_throw(compressor);
            });
            def_may_throw(AST_Unary, function (compressor) {
                if (this.operator == "typeof" && this.expression instanceof AST_SymbolRef)
                    return false;
                return this.expression.may_throw(compressor);
            });
            def_may_throw(AST_VarDef, function (compressor) {
                if (!this.value)
                    return false;
                return this.value.may_throw(compressor);
            });
        })(function (node, func) {
            node.DEFMETHOD("may_throw", func);
        });
        // determine if expression is constant
        (function (def_is_constant_expression) {
            function all_refs_local(scope) {
                let result = true;
                walk(this, node => {
                    if (node instanceof AST_SymbolRef) {
                        if (has_flag(this, INLINED)) {
                            result = false;
                            return walk_abort;
                        }
                        var def = node.definition();
                        if (member(def, this.enclosed)
                            && !this.variables.has(def.name)) {
                            if (scope) {
                                var scope_def = scope.find_variable(node);
                                if (def.undeclared ? !scope_def : scope_def === def) {
                                    result = "f";
                                    return true;
                                }
                            }
                            result = false;
                            return walk_abort;
                        }
                        return true;
                    }
                    if (node instanceof AST_This && this instanceof AST_Arrow) {
                        result = false;
                        return walk_abort;
                    }
                });
                return result;
            }
            def_is_constant_expression(AST_Node, return_false);
            def_is_constant_expression(AST_Constant, return_true);
            def_is_constant_expression(AST_Class, function (scope) {
                if (this.extends && !this.extends.is_constant_expression(scope)) {
                    return false;
                }
                for (const prop of this.properties) {
                    if (prop.computed_key() && !prop.key.is_constant_expression(scope)) {
                        return false;
                    }
                    if (prop.static && prop.value && !prop.value.is_constant_expression(scope)) {
                        return false;
                    }
                    if (prop instanceof AST_ClassStaticBlock) {
                        return false;
                    }
                }
                return all_refs_local.call(this, scope);
            });
            def_is_constant_expression(AST_Lambda, all_refs_local);
            def_is_constant_expression(AST_Unary, function () {
                return this.expression.is_constant_expression();
            });
            def_is_constant_expression(AST_Binary, function () {
                return this.left.is_constant_expression()
                    && this.right.is_constant_expression();
            });
            def_is_constant_expression(AST_Array, function () {
                return this.elements.every((l) => l.is_constant_expression());
            });
            def_is_constant_expression(AST_Object, function () {
                return this.properties.every((l) => l.is_constant_expression());
            });
            def_is_constant_expression(AST_ObjectProperty, function () {
                return !!(!(this.key instanceof AST_Node) && this.value && this.value.is_constant_expression());
            });
        })(function (node, func) {
            node.DEFMETHOD("is_constant_expression", func);
        });
        // may_throw_on_access()
        // returns true if this node may be null, undefined or contain `AST_Accessor`
        (function (def_may_throw_on_access) {
            AST_Node.DEFMETHOD("may_throw_on_access", function (compressor) {
                return !compressor.option("pure_getters")
                    || this._dot_throw(compressor);
            });
            function is_strict(compressor) {
                return /strict/.test(compressor.option("pure_getters"));
            }
            def_may_throw_on_access(AST_Node, is_strict);
            def_may_throw_on_access(AST_Null, return_true);
            def_may_throw_on_access(AST_Undefined, return_true);
            def_may_throw_on_access(AST_Constant, return_false);
            def_may_throw_on_access(AST_Array, return_false);
            def_may_throw_on_access(AST_Object, function (compressor) {
                if (!is_strict(compressor))
                    return false;
                for (var i = this.properties.length; --i >= 0;)
                    if (this.properties[i]._dot_throw(compressor))
                        return true;
                return false;
            });
            // Do not be as strict with classes as we are with objects.
            // Hopefully the community is not going to abuse static getters and setters.
            // https://github.com/terser/terser/issues/724#issuecomment-643655656
            def_may_throw_on_access(AST_Class, return_false);
            def_may_throw_on_access(AST_ObjectProperty, return_false);
            def_may_throw_on_access(AST_ObjectGetter, return_true);
            def_may_throw_on_access(AST_Expansion, function (compressor) {
                return this.expression._dot_throw(compressor);
            });
            def_may_throw_on_access(AST_Function, return_false);
            def_may_throw_on_access(AST_Arrow, return_false);
            def_may_throw_on_access(AST_UnaryPostfix, return_false);
            def_may_throw_on_access(AST_UnaryPrefix, function () {
                return this.operator == "void";
            });
            def_may_throw_on_access(AST_Binary, function (compressor) {
                return (this.operator == "&&" || this.operator == "||" || this.operator == "??")
                    && (this.left._dot_throw(compressor) || this.right._dot_throw(compressor));
            });
            def_may_throw_on_access(AST_Assign, function (compressor) {
                if (this.logical)
                    return true;
                return this.operator == "="
                    && this.right._dot_throw(compressor);
            });
            def_may_throw_on_access(AST_Conditional, function (compressor) {
                return this.consequent._dot_throw(compressor)
                    || this.alternative._dot_throw(compressor);
            });
            def_may_throw_on_access(AST_Dot, function (compressor) {
                if (!is_strict(compressor))
                    return false;
                if (this.property == "prototype") {
                    return !(this.expression instanceof AST_Function
                        || this.expression instanceof AST_Class);
                }
                return true;
            });
            def_may_throw_on_access(AST_Chain, function (compressor) {
                return this.expression._dot_throw(compressor);
            });
            def_may_throw_on_access(AST_Sequence, function (compressor) {
                return this.tail_node()._dot_throw(compressor);
            });
            def_may_throw_on_access(AST_SymbolRef, function (compressor) {
                if (this.name === "arguments" && this.scope instanceof AST_Lambda)
                    return false;
                if (has_flag(this, UNDEFINED))
                    return true;
                if (!is_strict(compressor))
                    return false;
                if (is_undeclared_ref(this) && this.is_declared(compressor))
                    return false;
                if (this.is_immutable())
                    return false;
                var fixed = this.fixed_value();
                return !fixed || fixed._dot_throw(compressor);
            });
        })(function (node, func) {
            node.DEFMETHOD("_dot_throw", func);
        });
        function is_lhs(node, parent) {
            if (parent instanceof AST_Unary && unary_side_effects.has(parent.operator))
                return parent.expression;
            if (parent instanceof AST_Assign && parent.left === node)
                return node;
            if (parent instanceof AST_ForIn && parent.init === node)
                return node;
        }
        // method to negate an expression
        (function (def_negate) {
            function basic_negation(exp) {
                return make_node(AST_UnaryPrefix, exp, {
                    operator: "!",
                    expression: exp
                });
            }
            function best(orig, alt, first_in_statement) {
                var negated = basic_negation(orig);
                if (first_in_statement) {
                    var stat = make_node(AST_SimpleStatement, alt, {
                        body: alt
                    });
                    return best_of_expression(negated, stat) === stat ? alt : negated;
                }
                return best_of_expression(negated, alt);
            }
            def_negate(AST_Node, function () {
                return basic_negation(this);
            });
            def_negate(AST_Statement, function () {
                throw new Error("Cannot negate a statement");
            });
            def_negate(AST_Function, function () {
                return basic_negation(this);
            });
            def_negate(AST_Class, function () {
                return basic_negation(this);
            });
            def_negate(AST_Arrow, function () {
                return basic_negation(this);
            });
            def_negate(AST_UnaryPrefix, function () {
                if (this.operator == "!")
                    return this.expression;
                return basic_negation(this);
            });
            def_negate(AST_Sequence, function (compressor) {
                var expressions = this.expressions.slice();
                expressions.push(expressions.pop().negate(compressor));
                return make_sequence(this, expressions);
            });
            def_negate(AST_Conditional, function (compressor, first_in_statement) {
                var self = this.clone();
                self.consequent = self.consequent.negate(compressor);
                self.alternative = self.alternative.negate(compressor);
                return best(this, self, first_in_statement);
            });
            def_negate(AST_Binary, function (compressor, first_in_statement) {
                var self = this.clone(), op = this.operator;
                if (compressor.option("unsafe_comps")) {
                    switch (op) {
                        case "<=":
                            self.operator = ">";
                            return self;
                        case "<":
                            self.operator = ">=";
                            return self;
                        case ">=":
                            self.operator = "<";
                            return self;
                        case ">":
                            self.operator = "<=";
                            return self;
                    }
                }
                switch (op) {
                    case "==":
                        self.operator = "!=";
                        return self;
                    case "!=":
                        self.operator = "==";
                        return self;
                    case "===":
                        self.operator = "!==";
                        return self;
                    case "!==":
                        self.operator = "===";
                        return self;
                    case "&&":
                        self.operator = "||";
                        self.left = self.left.negate(compressor, first_in_statement);
                        self.right = self.right.negate(compressor);
                        return best(this, self, first_in_statement);
                    case "||":
                        self.operator = "&&";
                        self.left = self.left.negate(compressor, first_in_statement);
                        self.right = self.right.negate(compressor);
                        return best(this, self, first_in_statement);
                }
                return basic_negation(this);
            });
        })(function (node, func) {
            node.DEFMETHOD("negate", function (compressor, first_in_statement) {
                return func.call(this, compressor, first_in_statement);
            });
        });
        (function (def_bitwise_negate) {
            function basic_negation(exp) {
                return make_node(AST_UnaryPrefix, exp, {
                    operator: "~",
                    expression: exp
                });
            }
            def_bitwise_negate(AST_Node, function () {
                return basic_negation(this);
            });
            def_bitwise_negate(AST_Number, function () {
                const neg = ~this.value;
                if (neg.toString().length > this.value.toString().length) {
                    return basic_negation(this);
                }
                return make_node(AST_Number, this, { value: neg });
            });
            def_bitwise_negate(AST_UnaryPrefix, function (in_32_bit_context) {
                if (this.operator == "~" && (in_32_bit_context || this.expression.is_32_bit_integer())) {
                    return this.expression;
                }
                else {
                    return basic_negation(this);
                }
            });
        })(function (node, func) {
            node.DEFMETHOD("bitwise_negate", func);
        });
        // Is the callee of this function pure?
        var global_pure_fns = makePredicate("Boolean decodeURI decodeURIComponent Date encodeURI encodeURIComponent Error escape EvalError isFinite isNaN Number Object parseFloat parseInt RangeError ReferenceError String SyntaxError TypeError unescape URIError");
        AST_Call.DEFMETHOD("is_callee_pure", function (compressor) {
            if (compressor.option("unsafe")) {
                var expr = this.expression;
                var first_arg = (this.args && this.args[0] && this.args[0].evaluate(compressor));
                if (expr.expression && expr.expression.name === "hasOwnProperty" &&
                    (first_arg == null || first_arg.thedef && first_arg.thedef.undeclared)) {
                    return false;
                }
                if (is_undeclared_ref(expr) && global_pure_fns.has(expr.name))
                    return true;
                if (expr instanceof AST_Dot
                    && is_undeclared_ref(expr.expression)
                    && is_pure_native_fn(expr.expression.name, expr.property)) {
                    return true;
                }
            }
            if ((this instanceof AST_New) && compressor.option("pure_new")) {
                return true;
            }
            if (compressor.option("side_effects") && has_annotation(this, _PURE)) {
                return true;
            }
            return !compressor.pure_funcs(this);
        });
        // If I call this, is it a pure function?
        AST_Node.DEFMETHOD("is_call_pure", return_false);
        AST_Dot.DEFMETHOD("is_call_pure", function (compressor) {
            if (!compressor.option("unsafe"))
                return;
            const expr = this.expression;
            let native_obj;
            if (expr instanceof AST_Array) {
                native_obj = "Array";
            }
            else if (expr.is_boolean()) {
                native_obj = "Boolean";
            }
            else if (expr.is_number(compressor)) {
                native_obj = "Number";
            }
            else if (expr instanceof AST_RegExp) {
                native_obj = "RegExp";
            }
            else if (expr.is_string(compressor)) {
                native_obj = "String";
            }
            else if (!this.may_throw_on_access(compressor)) {
                native_obj = "Object";
            }
            return native_obj != null && is_pure_native_method(native_obj, this.property);
        });
        // tell me if a statement aborts
        const aborts = (thing) => thing && thing.aborts();
        (function (def_aborts) {
            def_aborts(AST_Statement, return_null);
            def_aborts(AST_Jump, return_this);
            function block_aborts() {
                for (var i = 0; i < this.body.length; i++) {
                    if (aborts(this.body[i])) {
                        return this.body[i];
                    }
                }
                return null;
            }
            def_aborts(AST_Import, return_null);
            def_aborts(AST_BlockStatement, block_aborts);
            def_aborts(AST_SwitchBranch, block_aborts);
            def_aborts(AST_DefClass, function () {
                for (const prop of this.properties) {
                    if (prop instanceof AST_ClassStaticBlock) {
                        if (prop.aborts())
                            return prop;
                    }
                }
                return null;
            });
            def_aborts(AST_ClassStaticBlock, block_aborts);
            def_aborts(AST_If, function () {
                return this.alternative && aborts(this.body) && aborts(this.alternative) && this;
            });
        })(function (node, func) {
            node.DEFMETHOD("aborts", func);
        });
        AST_Node.DEFMETHOD("contains_this", function () {
            return walk(this, node => {
                if (node instanceof AST_This)
                    return walk_abort;
                if (node !== this
                    && node instanceof AST_Scope
                    && !(node instanceof AST_Arrow)) {
                    return true;
                }
            });
        });
        function is_modified(compressor, tw, node, value, level, immutable) {
            var parent = tw.parent(level);
            var lhs = is_lhs(node, parent);
            if (lhs)
                return lhs;
            if (!immutable
                && parent instanceof AST_Call
                && parent.expression === node
                && !(value instanceof AST_Arrow)
                && !(value instanceof AST_Class)
                && !parent.is_callee_pure(compressor)
                && (!(value instanceof AST_Function)
                    || !(parent instanceof AST_New) && value.contains_this())) {
                return true;
            }
            if (parent instanceof AST_Array) {
                return is_modified(compressor, tw, parent, parent, level + 1);
            }
            if (parent instanceof AST_ObjectKeyVal && node === parent.value) {
                var obj = tw.parent(level + 1);
                return is_modified(compressor, tw, obj, obj, level + 2);
            }
            if (parent instanceof AST_PropAccess && parent.expression === node) {
                var prop = read_property(value, parent.property);
                return !immutable && is_modified(compressor, tw, parent, prop, level + 1);
            }
        }
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        // methods to evaluate a constant expression
        function def_eval(node, func) {
            node.DEFMETHOD("_eval", func);
        }
        // Used to propagate a nullish short-circuit signal upwards through the chain.
        const nullish = Symbol("This AST_Chain is nullish");
        // If the node has been successfully reduced to a constant,
        // then its value is returned; otherwise the element itself
        // is returned.
        // They can be distinguished as constant value is never a
        // descendant of AST_Node.
        AST_Node.DEFMETHOD("evaluate", function (compressor) {
            if (!compressor.option("evaluate"))
                return this;
            var val = this._eval(compressor, 1);
            if (!val || val instanceof RegExp)
                return val;
            if (typeof val == "function" || typeof val == "object" || val == nullish)
                return this;
            // Evaluated strings can be larger than the original expression
            if (typeof val === "string") {
                const unevaluated_size = this.size(compressor);
                if (val.length + 2 > unevaluated_size)
                    return this;
            }
            return val;
        });
        var unaryPrefix = makePredicate("! ~ - + void");
        AST_Node.DEFMETHOD("is_constant", function () {
            // Accomodate when compress option evaluate=false
            // as well as the common constant expressions !0 and -1
            if (this instanceof AST_Constant) {
                return !(this instanceof AST_RegExp);
            }
            else {
                return this instanceof AST_UnaryPrefix
                    && this.expression instanceof AST_Constant
                    && unaryPrefix.has(this.operator);
            }
        });
        def_eval(AST_Statement, function () {
            throw new Error(string_template("Cannot evaluate a statement [{file}:{line},{col}]", this.start));
        });
        def_eval(AST_Lambda, return_this);
        def_eval(AST_Class, return_this);
        def_eval(AST_Node, return_this);
        def_eval(AST_Constant, function () {
            return this.getValue();
        });
        const supports_bigint = typeof BigInt === "function";
        def_eval(AST_BigInt, function () {
            if (supports_bigint) {
                return BigInt(this.value);
            }
            else {
                return this;
            }
        });
        def_eval(AST_RegExp, function (compressor) {
            let evaluated = compressor.evaluated_regexps.get(this.value);
            if (evaluated === undefined && regexp_is_safe(this.value.source)) {
                try {
                    const { source, flags } = this.value;
                    evaluated = new RegExp(source, flags);
                }
                catch (e) {
                    evaluated = null;
                }
                compressor.evaluated_regexps.set(this.value, evaluated);
            }
            return evaluated || this;
        });
        def_eval(AST_TemplateString, function () {
            if (this.segments.length !== 1)
                return this;
            return this.segments[0].value;
        });
        def_eval(AST_Function, function (compressor) {
            if (compressor.option("unsafe")) {
                var fn = function () { };
                fn.node = this;
                fn.toString = () => this.print_to_string();
                return fn;
            }
            return this;
        });
        def_eval(AST_Array, function (compressor, depth) {
            if (compressor.option("unsafe")) {
                var elements = [];
                for (var i = 0, len = this.elements.length; i < len; i++) {
                    var element = this.elements[i];
                    var value = element._eval(compressor, depth);
                    if (element === value)
                        return this;
                    elements.push(value);
                }
                return elements;
            }
            return this;
        });
        def_eval(AST_Object, function (compressor, depth) {
            if (compressor.option("unsafe")) {
                var val = {};
                for (var i = 0, len = this.properties.length; i < len; i++) {
                    var prop = this.properties[i];
                    if (prop instanceof AST_Expansion)
                        return this;
                    var key = prop.key;
                    if (key instanceof AST_Symbol) {
                        key = key.name;
                    }
                    else if (key instanceof AST_Node) {
                        key = key._eval(compressor, depth);
                        if (key === prop.key)
                            return this;
                    }
                    if (typeof Object.prototype[key] === "function") {
                        return this;
                    }
                    if (prop.value instanceof AST_Function)
                        continue;
                    val[key] = prop.value._eval(compressor, depth);
                    if (val[key] === prop.value)
                        return this;
                }
                return val;
            }
            return this;
        });
        var non_converting_unary = makePredicate("! typeof void");
        def_eval(AST_UnaryPrefix, function (compressor, depth) {
            var e = this.expression;
            // Function would be evaluated to an array and so typeof would
            // incorrectly return 'object'. Hence making is a special case.
            if (compressor.option("typeofs")
                && this.operator == "typeof"
                && (e instanceof AST_Lambda
                    || e instanceof AST_SymbolRef
                        && e.fixed_value() instanceof AST_Lambda)) {
                return typeof function () { };
            }
            if (!non_converting_unary.has(this.operator))
                depth++;
            e = e._eval(compressor, depth);
            if (e === this.expression)
                return this;
            switch (this.operator) {
                case "!": return !e;
                case "typeof":
                    // typeof <RegExp> returns "object" or "function" on different platforms
                    // so cannot evaluate reliably
                    if (e instanceof RegExp)
                        return this;
                    return typeof e;
                case "void": return void e;
                case "~": return ~e;
                case "-": return -e;
                case "+": return +e;
            }
            return this;
        });
        var non_converting_binary = makePredicate("&& || ?? === !==");
        const identity_comparison = makePredicate("== != === !==");
        const has_identity = value => typeof value === "object"
            || typeof value === "function"
            || typeof value === "symbol";
        def_eval(AST_Binary, function (compressor, depth) {
            if (!non_converting_binary.has(this.operator))
                depth++;
            var left = this.left._eval(compressor, depth);
            if (left === this.left)
                return this;
            var right = this.right._eval(compressor, depth);
            if (right === this.right)
                return this;
            if (left != null
                && right != null
                && identity_comparison.has(this.operator)
                && has_identity(left)
                && has_identity(right)
                && typeof left === typeof right) {
                // Do not compare by reference
                return this;
            }
            // Do not mix BigInt and Number; Don't use `>>>` on BigInt or `/ 0n`
            if ((typeof left === "bigint") !== (typeof right === "bigint")
                || typeof left === "bigint"
                    && (this.operator === ">>>"
                        || this.operator === "/" && Number(right) === 0)) {
                return this;
            }
            var result;
            switch (this.operator) {
                case "&&":
                    result = left && right;
                    break;
                case "||":
                    result = left || right;
                    break;
                case "??":
                    result = left != null ? left : right;
                    break;
                case "|":
                    result = left | right;
                    break;
                case "&":
                    result = left & right;
                    break;
                case "^":
                    result = left ^ right;
                    break;
                case "+":
                    result = left + right;
                    break;
                case "*":
                    result = left * right;
                    break;
                case "**":
                    result = left ** right;
                    break;
                case "/":
                    result = left / right;
                    break;
                case "%":
                    result = left % right;
                    break;
                case "-":
                    result = left - right;
                    break;
                case "<<":
                    result = left << right;
                    break;
                case ">>":
                    result = left >> right;
                    break;
                case ">>>":
                    result = left >>> right;
                    break;
                case "==":
                    result = left == right;
                    break;
                case "===":
                    result = left === right;
                    break;
                case "!=":
                    result = left != right;
                    break;
                case "!==":
                    result = left !== right;
                    break;
                case "<":
                    result = left < right;
                    break;
                case "<=":
                    result = left <= right;
                    break;
                case ">":
                    result = left > right;
                    break;
                case ">=":
                    result = left >= right;
                    break;
                default:
                    return this;
            }
            if (typeof result === "number" && isNaN(result) && compressor.find_parent(AST_With)) {
                // leave original expression as is
                return this;
            }
            return result;
        });
        def_eval(AST_Conditional, function (compressor, depth) {
            var condition = this.condition._eval(compressor, depth);
            if (condition === this.condition)
                return this;
            var node = condition ? this.consequent : this.alternative;
            var value = node._eval(compressor, depth);
            return value === node ? this : value;
        });
        // Set of AST_SymbolRef which are currently being evaluated.
        // Avoids infinite recursion of ._eval()
        const reentrant_ref_eval = new Set();
        def_eval(AST_SymbolRef, function (compressor, depth) {
            if (reentrant_ref_eval.has(this))
                return this;
            var fixed = this.fixed_value();
            if (!fixed)
                return this;
            reentrant_ref_eval.add(this);
            const value = fixed._eval(compressor, depth);
            reentrant_ref_eval.delete(this);
            if (value === fixed)
                return this;
            if (value && typeof value == "object") {
                var escaped = this.definition().escaped;
                if (escaped && depth > escaped)
                    return this;
            }
            return value;
        });
        const global_objs = { Array, Math, Number, Object, String };
        const regexp_flags = new Set([
            "dotAll",
            "global",
            "ignoreCase",
            "multiline",
            "sticky",
            "unicode",
        ]);
        def_eval(AST_PropAccess, function (compressor, depth) {
            let obj = this.expression._eval(compressor, depth + 1);
            if (obj === nullish || (this.optional && obj == null))
                return nullish;
            // `.length` of strings and arrays is always safe
            if (this.property === "length") {
                if (typeof obj === "string") {
                    return obj.length;
                }
                const is_spreadless_array = obj instanceof AST_Array
                    && obj.elements.every(el => !(el instanceof AST_Expansion));
                if (is_spreadless_array
                    && obj.elements.every(el => !el.has_side_effects(compressor))) {
                    return obj.elements.length;
                }
            }
            if (compressor.option("unsafe")) {
                var key = this.property;
                if (key instanceof AST_Node) {
                    key = key._eval(compressor, depth);
                    if (key === this.property)
                        return this;
                }
                var exp = this.expression;
                if (is_undeclared_ref(exp)) {
                    var aa;
                    var first_arg = exp.name === "hasOwnProperty"
                        && key === "call"
                        && (aa = compressor.parent() && compressor.parent().args)
                        && (aa && aa[0]
                            && aa[0].evaluate(compressor));
                    first_arg = first_arg instanceof AST_Dot ? first_arg.expression : first_arg;
                    if (first_arg == null || first_arg.thedef && first_arg.thedef.undeclared) {
                        return this.clone();
                    }
                    if (!is_pure_native_value(exp.name, key))
                        return this;
                    obj = global_objs[exp.name];
                }
                else {
                    if (obj instanceof RegExp) {
                        if (key == "source") {
                            return regexp_source_fix(obj.source);
                        }
                        else if (key == "flags" || regexp_flags.has(key)) {
                            return obj[key];
                        }
                    }
                    if (!obj || obj === exp || !HOP(obj, key))
                        return this;
                    if (typeof obj == "function")
                        switch (key) {
                            case "name":
                                return obj.node.name ? obj.node.name.name : "";
                            case "length":
                                return obj.node.length_property();
                            default:
                                return this;
                        }
                }
                return obj[key];
            }
            return this;
        });
        def_eval(AST_Chain, function (compressor, depth) {
            const evaluated = this.expression._eval(compressor, depth);
            return evaluated === nullish
                ? undefined
                : evaluated === this.expression
                    ? this
                    : evaluated;
        });
        def_eval(AST_Call, function (compressor, depth) {
            var exp = this.expression;
            const callee = exp._eval(compressor, depth);
            if (callee === nullish || (this.optional && callee == null))
                return nullish;
            if (compressor.option("unsafe") && exp instanceof AST_PropAccess) {
                var key = exp.property;
                if (key instanceof AST_Node) {
                    key = key._eval(compressor, depth);
                    if (key === exp.property)
                        return this;
                }
                var val;
                var e = exp.expression;
                if (is_undeclared_ref(e)) {
                    var first_arg = e.name === "hasOwnProperty" &&
                        key === "call" &&
                        (this.args[0] && this.args[0].evaluate(compressor));
                    first_arg = first_arg instanceof AST_Dot ? first_arg.expression : first_arg;
                    if ((first_arg == null || first_arg.thedef && first_arg.thedef.undeclared)) {
                        return this.clone();
                    }
                    if (!is_pure_native_fn(e.name, key))
                        return this;
                    val = global_objs[e.name];
                }
                else {
                    val = e._eval(compressor, depth + 1);
                    if (val === e || !val)
                        return this;
                    if (!is_pure_native_method(val.constructor.name, key))
                        return this;
                }
                var args = [];
                for (var i = 0, len = this.args.length; i < len; i++) {
                    var arg = this.args[i];
                    var value = arg._eval(compressor, depth);
                    if (arg === value)
                        return this;
                    if (arg instanceof AST_Lambda)
                        return this;
                    args.push(value);
                }
                try {
                    return val[key].apply(val, args);
                }
                catch (ex) {
                    // We don't really care
                }
            }
            return this;
        });
        // Also a subclass of AST_Call
        def_eval(AST_New, return_this);
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        // AST_Node#drop_side_effect_free() gets called when we don't care about the value,
        // only about side effects. We'll be defining this method for each node type in this module
        //
        // Examples:
        // foo++ -> foo++
        // 1 + func() -> func()
        // 10 -> (nothing)
        // knownPureFunc(foo++) -> foo++
        function def_drop_side_effect_free(node, func) {
            node.DEFMETHOD("drop_side_effect_free", func);
        }
        // Drop side-effect-free elements from an array of expressions.
        // Returns an array of expressions with side-effects or null
        // if all elements were dropped. Note: original array may be
        // returned if nothing changed.
        function trim(nodes, compressor, first_in_statement) {
            var len = nodes.length;
            if (!len)
                return null;
            var ret = [], changed = false;
            for (var i = 0; i < len; i++) {
                var node = nodes[i].drop_side_effect_free(compressor, first_in_statement);
                changed |= node !== nodes[i];
                if (node) {
                    ret.push(node);
                    first_in_statement = false;
                }
            }
            return changed ? ret.length ? ret : null : nodes;
        }
        def_drop_side_effect_free(AST_Node, return_this);
        def_drop_side_effect_free(AST_Constant, return_null);
        def_drop_side_effect_free(AST_This, return_null);
        def_drop_side_effect_free(AST_Call, function (compressor, first_in_statement) {
            if (is_nullish_shortcircuited(this, compressor)) {
                return this.expression.drop_side_effect_free(compressor, first_in_statement);
            }
            if (!this.is_callee_pure(compressor)) {
                if (this.expression.is_call_pure(compressor)) {
                    var exprs = this.args.slice();
                    exprs.unshift(this.expression.expression);
                    exprs = trim(exprs, compressor, first_in_statement);
                    return exprs && make_sequence(this, exprs);
                }
                if (is_func_expr(this.expression)
                    && (!this.expression.name || !this.expression.name.definition().references.length)) {
                    var node = this.clone();
                    node.expression.process_expression(false, compressor);
                    return node;
                }
                return this;
            }
            var args = trim(this.args, compressor, first_in_statement);
            return args && make_sequence(this, args);
        });
        def_drop_side_effect_free(AST_Accessor, return_null);
        def_drop_side_effect_free(AST_Function, return_null);
        def_drop_side_effect_free(AST_Arrow, return_null);
        def_drop_side_effect_free(AST_Class, function (compressor) {
            const with_effects = [];
            if (this.is_self_referential() && this.has_side_effects(compressor)) {
                return this;
            }
            const trimmed_extends = this.extends && this.extends.drop_side_effect_free(compressor);
            if (trimmed_extends)
                with_effects.push(trimmed_extends);
            for (const prop of this.properties) {
                if (prop instanceof AST_ClassStaticBlock) {
                    if (prop.has_side_effects(compressor)) {
                        return this; // Be cautious about these
                    }
                }
                else {
                    const trimmed_prop = prop.drop_side_effect_free(compressor);
                    if (trimmed_prop)
                        with_effects.push(trimmed_prop);
                }
            }
            if (!with_effects.length)
                return null;
            const exprs = make_sequence(this, with_effects);
            if (this instanceof AST_DefClass) {
                // We want a statement
                return make_node(AST_SimpleStatement, this, { body: exprs });
            }
            else {
                return exprs;
            }
        });
        def_drop_side_effect_free(AST_ClassProperty, function (compressor) {
            const key = this.computed_key() && this.key.drop_side_effect_free(compressor);
            const value = this.static && this.value
                && this.value.drop_side_effect_free(compressor);
            if (key && value)
                return make_sequence(this, [key, value]);
            return key || value || null;
        });
        def_drop_side_effect_free(AST_Binary, function (compressor, first_in_statement) {
            var right = this.right.drop_side_effect_free(compressor);
            if (!right)
                return this.left.drop_side_effect_free(compressor, first_in_statement);
            if (lazy_op.has(this.operator)) {
                if (right === this.right)
                    return this;
                var node = this.clone();
                node.right = right;
                return node;
            }
            else {
                var left = this.left.drop_side_effect_free(compressor, first_in_statement);
                if (!left)
                    return this.right.drop_side_effect_free(compressor, first_in_statement);
                return make_sequence(this, [left, right]);
            }
        });
        def_drop_side_effect_free(AST_Assign, function (compressor) {
            if (this.logical)
                return this;
            var left = this.left;
            if (left.has_side_effects(compressor)
                || compressor.has_directive("use strict")
                    && left instanceof AST_PropAccess
                    && left.expression.is_constant()) {
                return this;
            }
            set_flag(this, WRITE_ONLY);
            while (left instanceof AST_PropAccess) {
                left = left.expression;
            }
            if (left.is_constant_expression(compressor.find_parent(AST_Scope))) {
                return this.right.drop_side_effect_free(compressor);
            }
            return this;
        });
        def_drop_side_effect_free(AST_Conditional, function (compressor) {
            var consequent = this.consequent.drop_side_effect_free(compressor);
            var alternative = this.alternative.drop_side_effect_free(compressor);
            if (consequent === this.consequent && alternative === this.alternative)
                return this;
            if (!consequent)
                return alternative ? make_node(AST_Binary, this, {
                    operator: "||",
                    left: this.condition,
                    right: alternative
                }) : this.condition.drop_side_effect_free(compressor);
            if (!alternative)
                return make_node(AST_Binary, this, {
                    operator: "&&",
                    left: this.condition,
                    right: consequent
                });
            var node = this.clone();
            node.consequent = consequent;
            node.alternative = alternative;
            return node;
        });
        def_drop_side_effect_free(AST_Unary, function (compressor, first_in_statement) {
            if (unary_side_effects.has(this.operator)) {
                if (!this.expression.has_side_effects(compressor)) {
                    set_flag(this, WRITE_ONLY);
                }
                else {
                    clear_flag(this, WRITE_ONLY);
                }
                return this;
            }
            if (this.operator == "typeof" && this.expression instanceof AST_SymbolRef)
                return null;
            var expression = this.expression.drop_side_effect_free(compressor, first_in_statement);
            if (first_in_statement && expression && is_iife_call(expression)) {
                if (expression === this.expression && this.operator == "!")
                    return this;
                return expression.negate(compressor, first_in_statement);
            }
            return expression;
        });
        def_drop_side_effect_free(AST_SymbolRef, function (compressor) {
            const safe_access = this.is_declared(compressor)
                || pure_prop_access_globals.has(this.name);
            return safe_access ? null : this;
        });
        def_drop_side_effect_free(AST_Object, function (compressor, first_in_statement) {
            var values = trim(this.properties, compressor, first_in_statement);
            return values && make_sequence(this, values);
        });
        def_drop_side_effect_free(AST_ObjectProperty, function (compressor, first_in_statement) {
            const computed_key = this instanceof AST_ObjectKeyVal && this.key instanceof AST_Node;
            const key = computed_key && this.key.drop_side_effect_free(compressor, first_in_statement);
            const value = this.value && this.value.drop_side_effect_free(compressor, first_in_statement);
            if (key && value) {
                return make_sequence(this, [key, value]);
            }
            return key || value;
        });
        def_drop_side_effect_free(AST_ConciseMethod, function () {
            return this.computed_key() ? this.key : null;
        });
        def_drop_side_effect_free(AST_ObjectGetter, function () {
            return this.computed_key() ? this.key : null;
        });
        def_drop_side_effect_free(AST_ObjectSetter, function () {
            return this.computed_key() ? this.key : null;
        });
        def_drop_side_effect_free(AST_Array, function (compressor, first_in_statement) {
            var values = trim(this.elements, compressor, first_in_statement);
            return values && make_sequence(this, values);
        });
        def_drop_side_effect_free(AST_Dot, function (compressor, first_in_statement) {
            if (is_nullish_shortcircuited(this, compressor)) {
                return this.expression.drop_side_effect_free(compressor, first_in_statement);
            }
            if (!this.optional && this.expression.may_throw_on_access(compressor)) {
                return this;
            }
            return this.expression.drop_side_effect_free(compressor, first_in_statement);
        });
        def_drop_side_effect_free(AST_Sub, function (compressor, first_in_statement) {
            if (is_nullish_shortcircuited(this, compressor)) {
                return this.expression.drop_side_effect_free(compressor, first_in_statement);
            }
            if (!this.optional && this.expression.may_throw_on_access(compressor)) {
                return this;
            }
            var property = this.property.drop_side_effect_free(compressor);
            if (property && this.optional)
                return this;
            var expression = this.expression.drop_side_effect_free(compressor, first_in_statement);
            if (expression && property)
                return make_sequence(this, [expression, property]);
            return expression || property;
        });
        def_drop_side_effect_free(AST_Chain, function (compressor, first_in_statement) {
            return this.expression.drop_side_effect_free(compressor, first_in_statement);
        });
        def_drop_side_effect_free(AST_Sequence, function (compressor) {
            var last = this.tail_node();
            var expr = last.drop_side_effect_free(compressor);
            if (expr === last)
                return this;
            var expressions = this.expressions.slice(0, -1);
            if (expr)
                expressions.push(expr);
            if (!expressions.length) {
                return make_node(AST_Number, this, { value: 0 });
            }
            return make_sequence(this, expressions);
        });
        def_drop_side_effect_free(AST_Expansion, function (compressor, first_in_statement) {
            return this.expression.drop_side_effect_free(compressor, first_in_statement);
        });
        def_drop_side_effect_free(AST_TemplateSegment, return_null);
        def_drop_side_effect_free(AST_TemplateString, function (compressor) {
            var values = trim(this.segments, compressor, first_in_statement);
            return values && make_sequence(this, values);
        });
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        const r_keep_assign = /keep_assign/;
        /** Drop unused variables from this scope */
        AST_Scope.DEFMETHOD("drop_unused", function (compressor) {
            if (!compressor.option("unused"))
                return;
            if (compressor.has_directive("use asm"))
                return;
            if (!this.variables)
                return; // not really a scope (eg: AST_Class)
            var self = this;
            if (self.pinned())
                return;
            var drop_funcs = !(self instanceof AST_Toplevel) || compressor.toplevel.funcs;
            var drop_vars = !(self instanceof AST_Toplevel) || compressor.toplevel.vars;
            const assign_as_unused = r_keep_assign.test(compressor.option("unused")) ? return_false : function (node) {
                if (node instanceof AST_Assign
                    && !node.logical
                    && (has_flag(node, WRITE_ONLY) || node.operator == "=")) {
                    return node.left;
                }
                if (node instanceof AST_Unary && has_flag(node, WRITE_ONLY)) {
                    return node.expression;
                }
            };
            var in_use_ids = new Map();
            var fixed_ids = new Map();
            if (self instanceof AST_Toplevel && compressor.top_retain) {
                self.variables.forEach(function (def) {
                    if (compressor.top_retain(def)) {
                        in_use_ids.set(def.id, def);
                    }
                });
            }
            var var_defs_by_id = new Map();
            var initializations = new Map();
            var self_referential_classes = new Set();
            // pass 1: find out which symbols are directly used in
            // this scope (not in nested scopes).
            var scope = this;
            var tw = new TreeWalker(function (node, descend) {
                if (node instanceof AST_Lambda && node.uses_arguments && !tw.has_directive("use strict")) {
                    node.argnames.forEach(function (argname) {
                        if (!(argname instanceof AST_SymbolDeclaration))
                            return;
                        var def = argname.definition();
                        in_use_ids.set(def.id, def);
                    });
                }
                if (node === self)
                    return;
                if (node instanceof AST_Class && node.has_side_effects(compressor)) {
                    if (node.is_self_referential())
                        self_referential_classes.add(node);
                    node.visit_nondeferred_class_parts(tw);
                }
                if (node instanceof AST_Defun || node instanceof AST_DefClass) {
                    var node_def = node.name.definition();
                    const in_export = tw.parent() instanceof AST_Export;
                    if (in_export || !drop_funcs && scope === self) {
                        if (node_def.global) {
                            in_use_ids.set(node_def.id, node_def);
                        }
                    }
                    map_add(initializations, node_def.id, node);
                    return true; // don't go in nested scopes
                }
                // In the root scope, we drop things. In inner scopes, we just check for uses.
                const in_root_scope = scope === self;
                if (node instanceof AST_SymbolFunarg && in_root_scope) {
                    map_add(var_defs_by_id, node.definition().id, node);
                }
                if (node instanceof AST_Definitions && in_root_scope) {
                    const in_export = tw.parent() instanceof AST_Export;
                    node.definitions.forEach(function (def) {
                        if (def.name instanceof AST_SymbolVar) {
                            map_add(var_defs_by_id, def.name.definition().id, def);
                        }
                        if (in_export || !drop_vars) {
                            walk(def.name, node => {
                                if (node instanceof AST_SymbolDeclaration) {
                                    const def = node.definition();
                                    if (def.global) {
                                        in_use_ids.set(def.id, def);
                                    }
                                }
                            });
                        }
                        if (def.name instanceof AST_Destructuring) {
                            def.walk(tw);
                        }
                        if (def.name instanceof AST_SymbolDeclaration && def.value) {
                            var node_def = def.name.definition();
                            map_add(initializations, node_def.id, def.value);
                            if (!node_def.chained && def.name.fixed_value() === def.value) {
                                fixed_ids.set(node_def.id, def);
                            }
                            if (def.value.has_side_effects(compressor)) {
                                def.value.walk(tw);
                            }
                        }
                    });
                    return true;
                }
                return scan_ref_scoped(node, descend);
            });
            self.walk(tw);
            // pass 2: for every used symbol we need to walk its
            // initialization code to figure out if it uses other
            // symbols (that may not be in_use).
            tw = new TreeWalker(scan_ref_scoped);
            in_use_ids.forEach(function (def) {
                var init = initializations.get(def.id);
                if (init)
                    init.forEach(function (init) {
                        init.walk(tw);
                    });
            });
            self_referential_classes.forEach(function (cls) {
                cls.walk(tw);
            });
            // pass 3: we should drop declarations not in_use
            var tt = new TreeTransformer(function before(node, descend, in_list) {
                var parent = tt.parent();
                if (drop_vars) {
                    const sym = assign_as_unused(node);
                    if (sym instanceof AST_SymbolRef) {
                        var def = sym.definition();
                        var in_use = in_use_ids.has(def.id);
                        if (node instanceof AST_Assign) {
                            if (!in_use || fixed_ids.has(def.id) && fixed_ids.get(def.id) !== node) {
                                return maintain_this_binding(parent, node, node.right.transform(tt));
                            }
                        }
                        else if (!in_use) {
                            return in_list ? MAP.skip : make_node(AST_Number, node, { value: 0 });
                        }
                    }
                }
                if (scope !== self)
                    return;
                var def;
                if (node.name
                    && (node instanceof AST_ClassExpression
                        && !keep_name(compressor.option("keep_classnames"), (def = node.name.definition()).name)
                        || node instanceof AST_Function
                            && !keep_name(compressor.option("keep_fnames"), (def = node.name.definition()).name))) {
                    // any declarations with same name will overshadow
                    // name of this anonymous function and can therefore
                    // never be used anywhere
                    if (!in_use_ids.has(def.id) || def.orig.length > 1)
                        node.name = null;
                }
                if (node instanceof AST_Lambda && !(node instanceof AST_Accessor)) {
                    var trim = !compressor.option("keep_fargs");
                    for (var a = node.argnames, i = a.length; --i >= 0;) {
                        var sym = a[i];
                        if (sym instanceof AST_Expansion) {
                            sym = sym.expression;
                        }
                        if (sym instanceof AST_DefaultAssign) {
                            sym = sym.left;
                        }
                        // Do not drop destructuring arguments.
                        // They constitute a type assertion of sorts
                        if (!(sym instanceof AST_Destructuring)
                            && !in_use_ids.has(sym.definition().id)) {
                            set_flag(sym, UNUSED);
                            if (trim) {
                                a.pop();
                            }
                        }
                        else {
                            trim = false;
                        }
                    }
                }
                if (node instanceof AST_DefClass && node !== self) {
                    const def = node.name.definition();
                    descend(node, this);
                    const keep_class = def.global && !drop_funcs || in_use_ids.has(def.id);
                    if (!keep_class) {
                        const kept = node.drop_side_effect_free(compressor);
                        if (kept == null) {
                            def.eliminated++;
                            return in_list ? MAP.skip : make_node(AST_EmptyStatement, node);
                        }
                        return kept;
                    }
                    return node;
                }
                if (node instanceof AST_Defun && node !== self) {
                    const def = node.name.definition();
                    const keep = def.global && !drop_funcs || in_use_ids.has(def.id);
                    if (!keep) {
                        def.eliminated++;
                        return in_list ? MAP.skip : make_node(AST_EmptyStatement, node);
                    }
                }
                if (node instanceof AST_Definitions && !(parent instanceof AST_ForIn && parent.init === node)) {
                    var drop_block = !(parent instanceof AST_Toplevel) && !(node instanceof AST_Var);
                    // place uninitialized names at the start
                    var body = [], head = [], tail = [];
                    // for unused names whose initialization has
                    // side effects, we can cascade the init. code
                    // into the next one, or next statement.
                    var side_effects = [];
                    node.definitions.forEach(function (def) {
                        if (def.value)
                            def.value = def.value.transform(tt);
                        var is_destructure = def.name instanceof AST_Destructuring;
                        var sym = is_destructure
                            ? new SymbolDef(null, { name: "<destructure>" }) /* fake SymbolDef */
                            : def.name.definition();
                        if (drop_block && sym.global)
                            return tail.push(def);
                        if (!(drop_vars || drop_block)
                            || is_destructure
                                && (def.name.names.length
                                    || def.name.is_array
                                    || compressor.option("pure_getters") != true)
                            || in_use_ids.has(sym.id)) {
                            if (def.value && fixed_ids.has(sym.id) && fixed_ids.get(sym.id) !== def) {
                                def.value = def.value.drop_side_effect_free(compressor);
                            }
                            if (def.name instanceof AST_SymbolVar) {
                                var var_defs = var_defs_by_id.get(sym.id);
                                if (var_defs.length > 1 && (!def.value || sym.orig.indexOf(def.name) > sym.eliminated)) {
                                    if (def.value) {
                                        var ref = make_node(AST_SymbolRef, def.name, def.name);
                                        sym.references.push(ref);
                                        var assign = make_node(AST_Assign, def, {
                                            operator: "=",
                                            logical: false,
                                            left: ref,
                                            right: def.value
                                        });
                                        if (fixed_ids.get(sym.id) === def) {
                                            fixed_ids.set(sym.id, assign);
                                        }
                                        side_effects.push(assign.transform(tt));
                                    }
                                    remove(var_defs, def);
                                    sym.eliminated++;
                                    return;
                                }
                            }
                            if (def.value) {
                                if (side_effects.length > 0) {
                                    if (tail.length > 0) {
                                        side_effects.push(def.value);
                                        def.value = make_sequence(def.value, side_effects);
                                    }
                                    else {
                                        body.push(make_node(AST_SimpleStatement, node, {
                                            body: make_sequence(node, side_effects)
                                        }));
                                    }
                                    side_effects = [];
                                }
                                tail.push(def);
                            }
                            else {
                                head.push(def);
                            }
                        }
                        else if (sym.orig[0] instanceof AST_SymbolCatch) {
                            var value = def.value && def.value.drop_side_effect_free(compressor);
                            if (value)
                                side_effects.push(value);
                            def.value = null;
                            head.push(def);
                        }
                        else {
                            var value = def.value && def.value.drop_side_effect_free(compressor);
                            if (value) {
                                side_effects.push(value);
                            }
                            sym.eliminated++;
                        }
                    });
                    if (head.length > 0 || tail.length > 0) {
                        node.definitions = head.concat(tail);
                        body.push(node);
                    }
                    if (side_effects.length > 0) {
                        body.push(make_node(AST_SimpleStatement, node, {
                            body: make_sequence(node, side_effects)
                        }));
                    }
                    switch (body.length) {
                        case 0:
                            return in_list ? MAP.skip : make_node(AST_EmptyStatement, node);
                        case 1:
                            return body[0];
                        default:
                            return in_list ? MAP.splice(body) : make_node(AST_BlockStatement, node, { body });
                    }
                }
                // certain combination of unused name + side effect leads to:
                //    https://github.com/mishoo/UglifyJS2/issues/44
                //    https://github.com/mishoo/UglifyJS2/issues/1830
                //    https://github.com/mishoo/UglifyJS2/issues/1838
                // that's an invalid AST.
                // We fix it at this stage by moving the `var` outside the `for`.
                if (node instanceof AST_For) {
                    descend(node, this);
                    var block;
                    if (node.init instanceof AST_BlockStatement) {
                        block = node.init;
                        node.init = block.body.pop();
                        block.body.push(node);
                    }
                    if (node.init instanceof AST_SimpleStatement) {
                        node.init = node.init.body;
                    }
                    else if (is_empty(node.init)) {
                        node.init = null;
                    }
                    return !block ? node : in_list ? MAP.splice(block.body) : block;
                }
                if (node instanceof AST_LabeledStatement
                    && node.body instanceof AST_For) {
                    descend(node, this);
                    if (node.body instanceof AST_BlockStatement) {
                        var block = node.body;
                        node.body = block.body.pop();
                        block.body.push(node);
                        return in_list ? MAP.splice(block.body) : block;
                    }
                    return node;
                }
                if (node instanceof AST_BlockStatement) {
                    descend(node, this);
                    if (in_list && node.body.every(can_be_evicted_from_block)) {
                        return MAP.splice(node.body);
                    }
                    return node;
                }
                if (node instanceof AST_Scope && !(node instanceof AST_ClassStaticBlock)) {
                    const save_scope = scope;
                    scope = node;
                    descend(node, this);
                    scope = save_scope;
                    return node;
                }
            });
            self.transform(tt);
            function scan_ref_scoped(node, descend) {
                var node_def;
                const sym = assign_as_unused(node);
                if (sym instanceof AST_SymbolRef
                    && !is_ref_of(node.left, AST_SymbolBlockDeclaration)
                    && self.variables.get(sym.name) === (node_def = sym.definition())) {
                    if (node instanceof AST_Assign) {
                        node.right.walk(tw);
                        if (!node_def.chained && node.left.fixed_value() === node.right) {
                            fixed_ids.set(node_def.id, node);
                        }
                    }
                    return true;
                }
                if (node instanceof AST_SymbolRef) {
                    node_def = node.definition();
                    if (!in_use_ids.has(node_def.id)) {
                        in_use_ids.set(node_def.id, node_def);
                        if (node_def.orig[0] instanceof AST_SymbolCatch) {
                            const redef = node_def.scope.is_block_scope()
                                && node_def.scope.get_defun_scope().variables.get(node_def.name);
                            if (redef)
                                in_use_ids.set(redef.id, redef);
                        }
                    }
                    return true;
                }
                if (node instanceof AST_Class) {
                    descend();
                    return true;
                }
                if (node instanceof AST_Scope && !(node instanceof AST_ClassStaticBlock)) {
                    var save_scope = scope;
                    scope = node;
                    descend();
                    scope = save_scope;
                    return true;
                }
            }
        });
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        /**
         * Define the method AST_Node#reduce_vars, which goes through the AST in
         * execution order to perform basic flow analysis
         */
        function def_reduce_vars(node, func) {
            node.DEFMETHOD("reduce_vars", func);
        }
        def_reduce_vars(AST_Node, noop);
        /** Clear definition properties */
        function reset_def(compressor, def) {
            def.assignments = 0;
            def.chained = false;
            def.direct_access = false;
            def.escaped = 0;
            def.recursive_refs = 0;
            def.references = [];
            def.single_use = undefined;
            if (def.scope.pinned()
                || (def.orig[0] instanceof AST_SymbolFunarg && def.scope.uses_arguments)) {
                def.fixed = false;
            }
            else if (def.orig[0] instanceof AST_SymbolConst || !compressor.exposed(def)) {
                def.fixed = def.init;
            }
            else {
                def.fixed = false;
            }
        }
        function reset_variables(tw, compressor, node) {
            node.variables.forEach(function (def) {
                reset_def(compressor, def);
                if (def.fixed === null) {
                    tw.defs_to_safe_ids.set(def.id, tw.safe_ids);
                    mark(tw, def, true);
                }
                else if (def.fixed) {
                    tw.loop_ids.set(def.id, tw.in_loop);
                    mark(tw, def, true);
                }
            });
        }
        function reset_block_variables(compressor, node) {
            if (node.block_scope)
                node.block_scope.variables.forEach((def) => {
                    reset_def(compressor, def);
                });
        }
        function push(tw) {
            tw.safe_ids = Object.create(tw.safe_ids);
        }
        function pop(tw) {
            tw.safe_ids = Object.getPrototypeOf(tw.safe_ids);
        }
        function mark(tw, def, safe) {
            tw.safe_ids[def.id] = safe;
        }
        function safe_to_read(tw, def) {
            if (def.single_use == "m")
                return false;
            if (tw.safe_ids[def.id]) {
                if (def.fixed == null) {
                    var orig = def.orig[0];
                    if (orig instanceof AST_SymbolFunarg || orig.name == "arguments")
                        return false;
                    def.fixed = make_node(AST_Undefined, orig);
                }
                return true;
            }
            return def.fixed instanceof AST_Defun;
        }
        function safe_to_assign(tw, def, scope, value) {
            if (def.fixed === undefined)
                return true;
            let def_safe_ids;
            if (def.fixed === null
                && (def_safe_ids = tw.defs_to_safe_ids.get(def.id))) {
                def_safe_ids[def.id] = false;
                tw.defs_to_safe_ids.delete(def.id);
                return true;
            }
            if (!HOP(tw.safe_ids, def.id))
                return false;
            if (!safe_to_read(tw, def))
                return false;
            if (def.fixed === false)
                return false;
            if (def.fixed != null && (!value || def.references.length > def.assignments))
                return false;
            if (def.fixed instanceof AST_Defun) {
                return value instanceof AST_Node && def.fixed.parent_scope === scope;
            }
            return def.orig.every((sym) => {
                return !(sym instanceof AST_SymbolConst
                    || sym instanceof AST_SymbolDefun
                    || sym instanceof AST_SymbolLambda);
            });
        }
        function ref_once(tw, compressor, def) {
            return compressor.option("unused")
                && !def.scope.pinned()
                && def.references.length - def.recursive_refs == 1
                && tw.loop_ids.get(def.id) === tw.in_loop;
        }
        function is_immutable(value) {
            if (!value)
                return false;
            return value.is_constant()
                || value instanceof AST_Lambda
                || value instanceof AST_This;
        }
        // A definition "escapes" when its value can leave the point of use.
        // Example: `a = b || c`
        // In this example, "b" and "c" are escaping, because they're going into "a"
        //
        // def.escaped is != 0 when it escapes.
        //
        // When greater than 1, it means that N chained properties will be read off
        // of that def before an escape occurs. This is useful for evaluating
        // property accesses, where you need to know when to stop.
        function mark_escaped(tw, d, scope, node, value, level = 0, depth = 1) {
            var parent = tw.parent(level);
            if (value) {
                if (value.is_constant())
                    return;
                if (value instanceof AST_ClassExpression)
                    return;
            }
            if (parent instanceof AST_Assign && (parent.operator === "=" || parent.logical) && node === parent.right
                || parent instanceof AST_Call && (node !== parent.expression || parent instanceof AST_New)
                || parent instanceof AST_Exit && node === parent.value && node.scope !== d.scope
                || parent instanceof AST_VarDef && node === parent.value
                || parent instanceof AST_Yield && node === parent.value && node.scope !== d.scope) {
                if (depth > 1 && !(value && value.is_constant_expression(scope)))
                    depth = 1;
                if (!d.escaped || d.escaped > depth)
                    d.escaped = depth;
                return;
            }
            else if (parent instanceof AST_Array
                || parent instanceof AST_Await
                || parent instanceof AST_Binary && lazy_op.has(parent.operator)
                || parent instanceof AST_Conditional && node !== parent.condition
                || parent instanceof AST_Expansion
                || parent instanceof AST_Sequence && node === parent.tail_node()) {
                mark_escaped(tw, d, scope, parent, parent, level + 1, depth);
            }
            else if (parent instanceof AST_ObjectKeyVal && node === parent.value) {
                var obj = tw.parent(level + 1);
                mark_escaped(tw, d, scope, obj, obj, level + 2, depth);
            }
            else if (parent instanceof AST_PropAccess && node === parent.expression) {
                value = read_property(value, parent.property);
                mark_escaped(tw, d, scope, parent, value, level + 1, depth + 1);
                if (value)
                    return;
            }
            if (level > 0)
                return;
            if (parent instanceof AST_Sequence && node !== parent.tail_node())
                return;
            if (parent instanceof AST_SimpleStatement)
                return;
            d.direct_access = true;
        }
        const suppress = node => walk(node, node => {
            if (!(node instanceof AST_Symbol))
                return;
            var d = node.definition();
            if (!d)
                return;
            if (node instanceof AST_SymbolRef)
                d.references.push(node);
            d.fixed = false;
        });
        def_reduce_vars(AST_Accessor, function (tw, descend, compressor) {
            push(tw);
            reset_variables(tw, compressor, this);
            descend();
            pop(tw);
            return true;
        });
        def_reduce_vars(AST_Assign, function (tw, descend, compressor) {
            var node = this;
            if (node.left instanceof AST_Destructuring) {
                suppress(node.left);
                return;
            }
            const finish_walk = () => {
                if (node.logical) {
                    node.left.walk(tw);
                    push(tw);
                    node.right.walk(tw);
                    pop(tw);
                    return true;
                }
            };
            var sym = node.left;
            if (!(sym instanceof AST_SymbolRef))
                return finish_walk();
            var def = sym.definition();
            var safe = safe_to_assign(tw, def, sym.scope, node.right);
            def.assignments++;
            if (!safe)
                return finish_walk();
            var fixed = def.fixed;
            if (!fixed && node.operator != "=" && !node.logical)
                return finish_walk();
            var eq = node.operator == "=";
            var value = eq ? node.right : node;
            if (is_modified(compressor, tw, node, value, 0))
                return finish_walk();
            def.references.push(sym);
            if (!node.logical) {
                if (!eq)
                    def.chained = true;
                def.fixed = eq ? function () {
                    return node.right;
                } : function () {
                    return make_node(AST_Binary, node, {
                        operator: node.operator.slice(0, -1),
                        left: fixed instanceof AST_Node ? fixed : fixed(),
                        right: node.right
                    });
                };
            }
            if (node.logical) {
                mark(tw, def, false);
                push(tw);
                node.right.walk(tw);
                pop(tw);
                return true;
            }
            mark(tw, def, false);
            node.right.walk(tw);
            mark(tw, def, true);
            mark_escaped(tw, def, sym.scope, node, value, 0, 1);
            return true;
        });
        def_reduce_vars(AST_Binary, function (tw) {
            if (!lazy_op.has(this.operator))
                return;
            this.left.walk(tw);
            push(tw);
            this.right.walk(tw);
            pop(tw);
            return true;
        });
        def_reduce_vars(AST_Block, function (tw, descend, compressor) {
            reset_block_variables(compressor, this);
        });
        def_reduce_vars(AST_Case, function (tw) {
            push(tw);
            this.expression.walk(tw);
            pop(tw);
            push(tw);
            walk_body(this, tw);
            pop(tw);
            return true;
        });
        def_reduce_vars(AST_Class, function (tw, descend) {
            clear_flag(this, INLINED);
            push(tw);
            descend();
            pop(tw);
            return true;
        });
        def_reduce_vars(AST_ClassStaticBlock, function (tw, descend, compressor) {
            reset_block_variables(compressor, this);
        });
        def_reduce_vars(AST_Conditional, function (tw) {
            this.condition.walk(tw);
            push(tw);
            this.consequent.walk(tw);
            pop(tw);
            push(tw);
            this.alternative.walk(tw);
            pop(tw);
            return true;
        });
        def_reduce_vars(AST_Chain, function (tw, descend) {
            // Chains' conditions apply left-to-right, cumulatively.
            // If we walk normally we don't go in that order because we would pop before pushing again
            // Solution: AST_PropAccess and AST_Call push when they are optional, and never pop.
            // Then we pop everything when they are done being walked.
            const safe_ids = tw.safe_ids;
            descend();
            // Unroll back to start
            tw.safe_ids = safe_ids;
            return true;
        });
        def_reduce_vars(AST_Call, function (tw) {
            this.expression.walk(tw);
            if (this.optional) {
                // Never pop -- it's popped at AST_Chain above
                push(tw);
            }
            for (const arg of this.args)
                arg.walk(tw);
            return true;
        });
        def_reduce_vars(AST_PropAccess, function (tw) {
            if (!this.optional)
                return;
            this.expression.walk(tw);
            // Never pop -- it's popped at AST_Chain above
            push(tw);
            if (this.property instanceof AST_Node)
                this.property.walk(tw);
            return true;
        });
        def_reduce_vars(AST_Default, function (tw, descend) {
            push(tw);
            descend();
            pop(tw);
            return true;
        });
        function mark_lambda(tw, descend, compressor) {
            clear_flag(this, INLINED);
            push(tw);
            reset_variables(tw, compressor, this);
            var iife;
            if (!this.name
                && !this.uses_arguments
                && !this.pinned()
                && (iife = tw.parent()) instanceof AST_Call
                && iife.expression === this
                && !iife.args.some(arg => arg instanceof AST_Expansion)
                && this.argnames.every(arg_name => arg_name instanceof AST_Symbol)) {
                // Virtually turn IIFE parameters into variable definitions:
                //   (function(a,b) {...})(c,d) => (function() {var a=c,b=d; ...})()
                // So existing transformation rules can work on them.
                this.argnames.forEach((arg, i) => {
                    if (!arg.definition)
                        return;
                    var d = arg.definition();
                    // Avoid setting fixed when there's more than one origin for a variable value
                    if (d.orig.length > 1)
                        return;
                    if (d.fixed === undefined && (!this.uses_arguments || tw.has_directive("use strict"))) {
                        d.fixed = function () {
                            return iife.args[i] || make_node(AST_Undefined, iife);
                        };
                        tw.loop_ids.set(d.id, tw.in_loop);
                        mark(tw, d, true);
                    }
                    else {
                        d.fixed = false;
                    }
                });
            }
            descend();
            pop(tw);
            handle_defined_after_hoist(this);
            return true;
        }
        /**
         * It's possible for a hoisted function to use something that's not defined yet. Example:
         *
         * hoisted();
         * var defined_after = true;
         * function hoisted() {
         *   // use defined_after
         * }
         *
         * This function is called on the parent to handle this issue.
         */
        function handle_defined_after_hoist(parent) {
            const defuns = [];
            walk(parent, node => {
                if (node === parent)
                    return;
                if (node instanceof AST_Defun)
                    defuns.push(node);
                if (node instanceof AST_Scope
                    || node instanceof AST_SimpleStatement)
                    return true;
            });
            const symbols_of_interest = new Set();
            const defuns_of_interest = new Set();
            const potential_conflicts = [];
            for (const defun of defuns) {
                const fname_def = defun.name.definition();
                const found_self_ref_in_other_defuns = defuns.some(d => d !== defun && d.enclosed.indexOf(fname_def) !== -1);
                for (const def of defun.enclosed) {
                    if (def.fixed === false
                        || def === fname_def
                        || def.scope.get_defun_scope() !== parent) {
                        continue;
                    }
                    // defun is hoisted, so always safe
                    if (def.assignments === 0
                        && def.orig.length === 1
                        && def.orig[0] instanceof AST_SymbolDefun) {
                        continue;
                    }
                    if (found_self_ref_in_other_defuns) {
                        def.fixed = false;
                        continue;
                    }
                    // for the slower checks below this loop
                    potential_conflicts.push({ defun, def, fname_def });
                    symbols_of_interest.add(def.id);
                    symbols_of_interest.add(fname_def.id);
                    defuns_of_interest.add(defun);
                }
            }
            // linearize all symbols, and locate defs that are read after the defun
            if (potential_conflicts.length) {
                // All "symbols of interest", that is, defuns or defs, that we found.
                // These are placed in order so we can check which is after which.
                const found_symbols = [];
                // Indices of `found_symbols` which are writes
                const found_symbol_writes = new Set();
                // Defun ranges are recorded because we don't care if a function uses the def internally
                const defun_ranges = new Map();
                let tw;
                parent.walk((tw = new TreeWalker((node, descend) => {
                    if (node instanceof AST_Defun && defuns_of_interest.has(node)) {
                        const start = found_symbols.length;
                        descend();
                        const end = found_symbols.length;
                        defun_ranges.set(node, { start, end });
                        return true;
                    }
                    // if we found a defun on the list, mark IN_DEFUN=id and descend
                    if (node instanceof AST_Symbol && node.thedef) {
                        const id = node.definition().id;
                        if (symbols_of_interest.has(id)) {
                            if (node instanceof AST_SymbolDeclaration || is_lhs(node, tw)) {
                                found_symbol_writes.add(found_symbols.length);
                            }
                            found_symbols.push(id);
                        }
                    }
                })));
                for (const { def, defun, fname_def } of potential_conflicts) {
                    const defun_range = defun_ranges.get(defun);
                    // find the index in `found_symbols`, with some special rules:
                    const find = (sym_id, starting_at = 0, must_be_write = false) => {
                        let index = starting_at;
                        for (;;) {
                            index = found_symbols.indexOf(sym_id, index);
                            if (index === -1) {
                                break;
                            }
                            else if (index >= defun_range.start && index < defun_range.end) {
                                index = defun_range.end;
                                continue;
                            }
                            else if (must_be_write && !found_symbol_writes.has(index)) {
                                index++;
                                continue;
                            }
                            else {
                                break;
                            }
                        }
                        return index;
                    };
                    const read_defun_at = find(fname_def.id);
                    const wrote_def_at = find(def.id, read_defun_at + 1, true);
                    const wrote_def_after_reading_defun = read_defun_at != -1 && wrote_def_at != -1 && wrote_def_at > read_defun_at;
                    if (wrote_def_after_reading_defun) {
                        def.fixed = false;
                    }
                }
            }
        }
        def_reduce_vars(AST_Lambda, mark_lambda);
        def_reduce_vars(AST_Do, function (tw, descend, compressor) {
            reset_block_variables(compressor, this);
            const saved_loop = tw.in_loop;
            tw.in_loop = this;
            push(tw);
            this.body.walk(tw);
            if (has_break_or_continue(this)) {
                pop(tw);
                push(tw);
            }
            this.condition.walk(tw);
            pop(tw);
            tw.in_loop = saved_loop;
            return true;
        });
        def_reduce_vars(AST_For, function (tw, descend, compressor) {
            reset_block_variables(compressor, this);
            if (this.init)
                this.init.walk(tw);
            const saved_loop = tw.in_loop;
            tw.in_loop = this;
            push(tw);
            if (this.condition)
                this.condition.walk(tw);
            this.body.walk(tw);
            if (this.step) {
                if (has_break_or_continue(this)) {
                    pop(tw);
                    push(tw);
                }
                this.step.walk(tw);
            }
            pop(tw);
            tw.in_loop = saved_loop;
            return true;
        });
        def_reduce_vars(AST_ForIn, function (tw, descend, compressor) {
            reset_block_variables(compressor, this);
            suppress(this.init);
            this.object.walk(tw);
            const saved_loop = tw.in_loop;
            tw.in_loop = this;
            push(tw);
            this.body.walk(tw);
            pop(tw);
            tw.in_loop = saved_loop;
            return true;
        });
        def_reduce_vars(AST_If, function (tw) {
            this.condition.walk(tw);
            push(tw);
            this.body.walk(tw);
            pop(tw);
            if (this.alternative) {
                push(tw);
                this.alternative.walk(tw);
                pop(tw);
            }
            return true;
        });
        def_reduce_vars(AST_LabeledStatement, function (tw) {
            push(tw);
            this.body.walk(tw);
            pop(tw);
            return true;
        });
        def_reduce_vars(AST_SymbolCatch, function () {
            this.definition().fixed = false;
        });
        def_reduce_vars(AST_SymbolRef, function (tw, descend, compressor) {
            var d = this.definition();
            d.references.push(this);
            if (d.references.length == 1
                && !d.fixed
                && d.orig[0] instanceof AST_SymbolDefun) {
                tw.loop_ids.set(d.id, tw.in_loop);
            }
            var fixed_value;
            if (d.fixed === undefined || !safe_to_read(tw, d)) {
                d.fixed = false;
            }
            else if (d.fixed) {
                fixed_value = this.fixed_value();
                if (fixed_value instanceof AST_Lambda
                    && is_recursive_ref(tw, d)) {
                    d.recursive_refs++;
                }
                else if (fixed_value
                    && !compressor.exposed(d)
                    && ref_once(tw, compressor, d)) {
                    d.single_use =
                        fixed_value instanceof AST_Lambda && !fixed_value.pinned()
                            || fixed_value instanceof AST_Class
                            || d.scope === this.scope && fixed_value.is_constant_expression();
                }
                else {
                    d.single_use = false;
                }
                if (is_modified(compressor, tw, this, fixed_value, 0, is_immutable(fixed_value))) {
                    if (d.single_use) {
                        d.single_use = "m";
                    }
                    else {
                        d.fixed = false;
                    }
                }
            }
            mark_escaped(tw, d, this.scope, this, fixed_value, 0, 1);
        });
        def_reduce_vars(AST_Toplevel, function (tw, descend, compressor) {
            this.globals.forEach(function (def) {
                reset_def(compressor, def);
            });
            reset_variables(tw, compressor, this);
            descend();
            handle_defined_after_hoist(this);
            return true;
        });
        def_reduce_vars(AST_Try, function (tw, descend, compressor) {
            reset_block_variables(compressor, this);
            push(tw);
            this.body.walk(tw);
            pop(tw);
            if (this.bcatch) {
                push(tw);
                this.bcatch.walk(tw);
                pop(tw);
            }
            if (this.bfinally)
                this.bfinally.walk(tw);
            return true;
        });
        def_reduce_vars(AST_Unary, function (tw) {
            var node = this;
            if (node.operator !== "++" && node.operator !== "--")
                return;
            var exp = node.expression;
            if (!(exp instanceof AST_SymbolRef))
                return;
            var def = exp.definition();
            var safe = safe_to_assign(tw, def, exp.scope, true);
            def.assignments++;
            if (!safe)
                return;
            var fixed = def.fixed;
            if (!fixed)
                return;
            def.references.push(exp);
            def.chained = true;
            def.fixed = function () {
                return make_node(AST_Binary, node, {
                    operator: node.operator.slice(0, -1),
                    left: make_node(AST_UnaryPrefix, node, {
                        operator: "+",
                        expression: fixed instanceof AST_Node ? fixed : fixed()
                    }),
                    right: make_node(AST_Number, node, {
                        value: 1
                    })
                });
            };
            mark(tw, def, true);
            return true;
        });
        def_reduce_vars(AST_VarDef, function (tw, descend) {
            var node = this;
            if (node.name instanceof AST_Destructuring) {
                suppress(node.name);
                return;
            }
            var d = node.name.definition();
            if (node.value) {
                if (safe_to_assign(tw, d, node.name.scope, node.value)) {
                    d.fixed = function () {
                        return node.value;
                    };
                    tw.loop_ids.set(d.id, tw.in_loop);
                    mark(tw, d, false);
                    descend();
                    mark(tw, d, true);
                    return true;
                }
                else {
                    d.fixed = false;
                }
            }
        });
        def_reduce_vars(AST_While, function (tw, descend, compressor) {
            reset_block_variables(compressor, this);
            const saved_loop = tw.in_loop;
            tw.in_loop = this;
            push(tw);
            descend();
            pop(tw);
            tw.in_loop = saved_loop;
            return true;
        });
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        function loop_body(x) {
            if (x instanceof AST_IterationStatement) {
                return x.body instanceof AST_BlockStatement ? x.body : x;
            }
            return x;
        }
        function is_lhs_read_only(lhs) {
            if (lhs instanceof AST_This)
                return true;
            if (lhs instanceof AST_SymbolRef)
                return lhs.definition().orig[0] instanceof AST_SymbolLambda;
            if (lhs instanceof AST_PropAccess) {
                lhs = lhs.expression;
                if (lhs instanceof AST_SymbolRef) {
                    if (lhs.is_immutable())
                        return false;
                    lhs = lhs.fixed_value();
                }
                if (!lhs)
                    return true;
                if (lhs instanceof AST_RegExp)
                    return false;
                if (lhs instanceof AST_Constant)
                    return true;
                return is_lhs_read_only(lhs);
            }
            return false;
        }
        /** var a = 1 --> var a*/
        function remove_initializers(var_statement) {
            var decls = [];
            var_statement.definitions.forEach(function (def) {
                if (def.name instanceof AST_SymbolDeclaration) {
                    def.value = null;
                    decls.push(def);
                }
                else {
                    def.declarations_as_names().forEach(name => {
                        decls.push(make_node(AST_VarDef, def, {
                            name,
                            value: null
                        }));
                    });
                }
            });
            return decls.length ? make_node(AST_Var, var_statement, { definitions: decls }) : null;
        }
        /** Called on code which we know is unreachable, to keep elements that affect outside of it. */
        function trim_unreachable_code(compressor, stat, target) {
            walk(stat, node => {
                if (node instanceof AST_Var) {
                    const no_initializers = remove_initializers(node);
                    if (no_initializers)
                        target.push(no_initializers);
                    return true;
                }
                if (node instanceof AST_Defun
                    && (node === stat || !compressor.has_directive("use strict"))) {
                    target.push(node === stat ? node : make_node(AST_Var, node, {
                        definitions: [
                            make_node(AST_VarDef, node, {
                                name: make_node(AST_SymbolVar, node.name, node.name),
                                value: null
                            })
                        ]
                    }));
                    return true;
                }
                if (node instanceof AST_Export || node instanceof AST_Import) {
                    target.push(node);
                    return true;
                }
                if (node instanceof AST_Scope) {
                    return true;
                }
            });
        }
        /** Tighten a bunch of statements together, and perform statement-level optimization. */
        function tighten_body(statements, compressor) {
            const nearest_scope = compressor.find_scope();
            const defun_scope = nearest_scope.get_defun_scope();
            const { in_loop, in_try } = find_loop_scope_try();
            var CHANGED, max_iter = 10;
            do {
                CHANGED = false;
                eliminate_spurious_blocks(statements);
                if (compressor.option("dead_code")) {
                    eliminate_dead_code(statements, compressor);
                }
                if (compressor.option("if_return")) {
                    handle_if_return(statements, compressor);
                }
                if (compressor.sequences_limit > 0) {
                    sequencesize(statements, compressor);
                    sequencesize_2(statements, compressor);
                }
                if (compressor.option("join_vars")) {
                    join_consecutive_vars(statements);
                }
                if (compressor.option("collapse_vars")) {
                    collapse(statements, compressor);
                }
            } while (CHANGED && max_iter-- > 0);
            function find_loop_scope_try() {
                var node = compressor.self(), level = 0, in_loop = false, in_try = false;
                do {
                    if (node instanceof AST_IterationStatement) {
                        in_loop = true;
                    }
                    else if (node instanceof AST_Scope) {
                        break;
                    }
                    else if (node instanceof AST_TryBlock) {
                        in_try = true;
                    }
                } while (node = compressor.parent(level++));
                return { in_loop, in_try };
            }
            // Search from right to left for assignment-like expressions:
            // - `var a = x;`
            // - `a = x;`
            // - `++a`
            // For each candidate, scan from left to right for first usage, then try
            // to fold assignment into the site for compression.
            // Will not attempt to collapse assignments into or past code blocks
            // which are not sequentially executed, e.g. loops and conditionals.
            function collapse(statements, compressor) {
                if (nearest_scope.pinned() || defun_scope.pinned())
                    return statements;
                var args;
                var candidates = [];
                var stat_index = statements.length;
                var scanner = new TreeTransformer(function (node) {
                    if (abort)
                        return node;
                    // Skip nodes before `candidate` as quickly as possible
                    if (!hit) {
                        if (node !== hit_stack[hit_index])
                            return node;
                        hit_index++;
                        if (hit_index < hit_stack.length)
                            return handle_custom_scan_order(node);
                        hit = true;
                        stop_after = find_stop(node, 0);
                        if (stop_after === node)
                            abort = true;
                        return node;
                    }
                    // Stop immediately if these node types are encountered
                    var parent = scanner.parent();
                    if (node instanceof AST_Assign
                        && (node.logical || node.operator != "=" && lhs.equivalent_to(node.left))
                        || node instanceof AST_Await
                        || node instanceof AST_Call && lhs instanceof AST_PropAccess && lhs.equivalent_to(node.expression)
                        ||
                            (node instanceof AST_Call || node instanceof AST_PropAccess)
                                && node.optional
                        || node instanceof AST_Debugger
                        || node instanceof AST_Destructuring
                        || node instanceof AST_Expansion
                            && node.expression instanceof AST_Symbol
                            && (node.expression instanceof AST_This
                                || node.expression.definition().references.length > 1)
                        || node instanceof AST_IterationStatement && !(node instanceof AST_For)
                        || node instanceof AST_LoopControl
                        || node instanceof AST_Try
                        || node instanceof AST_With
                        || node instanceof AST_Yield
                        || node instanceof AST_Export
                        || node instanceof AST_Class
                        || parent instanceof AST_For && node !== parent.init
                        || !replace_all
                            && (node instanceof AST_SymbolRef
                                && !node.is_declared(compressor)
                                && !pure_prop_access_globals.has(node))
                        || node instanceof AST_SymbolRef
                            && parent instanceof AST_Call
                            && has_annotation(parent, _NOINLINE)
                        || node instanceof AST_ObjectProperty && node.key instanceof AST_Node) {
                        abort = true;
                        return node;
                    }
                    // Stop only if candidate is found within conditional branches
                    if (!stop_if_hit && (!lhs_local || !replace_all)
                        && (parent instanceof AST_Binary && lazy_op.has(parent.operator) && parent.left !== node
                            || parent instanceof AST_Conditional && parent.condition !== node
                            || parent instanceof AST_If && parent.condition !== node)) {
                        stop_if_hit = parent;
                    }
                    // Replace variable with assignment when found
                    if (can_replace
                        && !(node instanceof AST_SymbolDeclaration)
                        && lhs.equivalent_to(node)
                        && !shadows(scanner.find_scope() || nearest_scope, lvalues)) {
                        if (stop_if_hit) {
                            abort = true;
                            return node;
                        }
                        if (is_lhs(node, parent)) {
                            if (value_def)
                                replaced++;
                            return node;
                        }
                        else {
                            replaced++;
                            if (value_def && candidate instanceof AST_VarDef)
                                return node;
                        }
                        CHANGED = abort = true;
                        if (candidate instanceof AST_UnaryPostfix) {
                            return make_node(AST_UnaryPrefix, candidate, candidate);
                        }
                        if (candidate instanceof AST_VarDef) {
                            var def = candidate.name.definition();
                            var value = candidate.value;
                            if (def.references.length - def.replaced == 1 && !compressor.exposed(def)) {
                                def.replaced++;
                                if (funarg && is_identifier_atom(value)) {
                                    return value.transform(compressor);
                                }
                                else {
                                    return maintain_this_binding(parent, node, value);
                                }
                            }
                            return make_node(AST_Assign, candidate, {
                                operator: "=",
                                logical: false,
                                left: make_node(AST_SymbolRef, candidate.name, candidate.name),
                                right: value
                            });
                        }
                        clear_flag(candidate, WRITE_ONLY);
                        return candidate;
                    }
                    // These node types have child nodes that execute sequentially,
                    // but are otherwise not safe to scan into or beyond them.
                    var sym;
                    if (node instanceof AST_Call
                        || node instanceof AST_Exit
                            && (side_effects || lhs instanceof AST_PropAccess || may_modify(lhs))
                        || node instanceof AST_PropAccess
                            && (side_effects || node.expression.may_throw_on_access(compressor))
                        || node instanceof AST_SymbolRef
                            && ((lvalues.has(node.name) && lvalues.get(node.name).modified) || side_effects && may_modify(node))
                        || node instanceof AST_VarDef && node.value
                            && (lvalues.has(node.name.name) || side_effects && may_modify(node.name))
                        || (sym = is_lhs(node.left, node))
                            && (sym instanceof AST_PropAccess || lvalues.has(sym.name))
                        || may_throw
                            && (in_try ? node.has_side_effects(compressor) : side_effects_external(node))) {
                        stop_after = node;
                        if (node instanceof AST_Scope)
                            abort = true;
                    }
                    return handle_custom_scan_order(node);
                }, function (node) {
                    if (abort)
                        return;
                    if (stop_after === node)
                        abort = true;
                    if (stop_if_hit === node)
                        stop_if_hit = null;
                });
                var multi_replacer = new TreeTransformer(function (node) {
                    if (abort)
                        return node;
                    // Skip nodes before `candidate` as quickly as possible
                    if (!hit) {
                        if (node !== hit_stack[hit_index])
                            return node;
                        hit_index++;
                        if (hit_index < hit_stack.length)
                            return;
                        hit = true;
                        return node;
                    }
                    // Replace variable when found
                    if (node instanceof AST_SymbolRef
                        && node.name == def.name) {
                        if (!--replaced)
                            abort = true;
                        if (is_lhs(node, multi_replacer.parent()))
                            return node;
                        def.replaced++;
                        value_def.replaced--;
                        return candidate.value;
                    }
                    // Skip (non-executed) functions and (leading) default case in switch statements
                    if (node instanceof AST_Default || node instanceof AST_Scope)
                        return node;
                });
                while (--stat_index >= 0) {
                    // Treat parameters as collapsible in IIFE, i.e.
                    //   function(a, b){ ... }(x());
                    // would be translated into equivalent assignments:
                    //   var a = x(), b = undefined;
                    if (stat_index == 0 && compressor.option("unused"))
                        extract_args();
                    // Find collapsible assignments
                    var hit_stack = [];
                    extract_candidates(statements[stat_index]);
                    while (candidates.length > 0) {
                        hit_stack = candidates.pop();
                        var hit_index = 0;
                        var candidate = hit_stack[hit_stack.length - 1];
                        var value_def = null;
                        var stop_after = null;
                        var stop_if_hit = null;
                        var lhs = get_lhs(candidate);
                        if (!lhs || is_lhs_read_only(lhs) || lhs.has_side_effects(compressor))
                            continue;
                        // Locate symbols which may execute code outside of scanning range
                        var lvalues = get_lvalues(candidate);
                        var lhs_local = is_lhs_local(lhs);
                        if (lhs instanceof AST_SymbolRef) {
                            lvalues.set(lhs.name, { def: lhs.definition(), modified: false });
                        }
                        var side_effects = value_has_side_effects(candidate);
                        var replace_all = replace_all_symbols();
                        var may_throw = candidate.may_throw(compressor);
                        var funarg = candidate.name instanceof AST_SymbolFunarg;
                        var hit = funarg;
                        var abort = false, replaced = 0, can_replace = !args || !hit;
                        if (!can_replace) {
                            for (let j = compressor.self().argnames.lastIndexOf(candidate.name) + 1; !abort && j < args.length; j++) {
                                args[j].transform(scanner);
                            }
                            can_replace = true;
                        }
                        for (var i = stat_index; !abort && i < statements.length; i++) {
                            statements[i].transform(scanner);
                        }
                        if (value_def) {
                            var def = candidate.name.definition();
                            if (abort && def.references.length - def.replaced > replaced)
                                replaced = false;
                            else {
                                abort = false;
                                hit_index = 0;
                                hit = funarg;
                                for (var i = stat_index; !abort && i < statements.length; i++) {
                                    statements[i].transform(multi_replacer);
                                }
                                value_def.single_use = false;
                            }
                        }
                        if (replaced && !remove_candidate(candidate))
                            statements.splice(stat_index, 1);
                    }
                }
                function handle_custom_scan_order(node) {
                    // Skip (non-executed) functions
                    if (node instanceof AST_Scope)
                        return node;
                    // Scan case expressions first in a switch statement
                    if (node instanceof AST_Switch) {
                        node.expression = node.expression.transform(scanner);
                        for (var i = 0, len = node.body.length; !abort && i < len; i++) {
                            var branch = node.body[i];
                            if (branch instanceof AST_Case) {
                                if (!hit) {
                                    if (branch !== hit_stack[hit_index])
                                        continue;
                                    hit_index++;
                                }
                                branch.expression = branch.expression.transform(scanner);
                                if (!replace_all)
                                    break;
                            }
                        }
                        abort = true;
                        return node;
                    }
                }
                function redefined_within_scope(def, scope) {
                    if (def.global)
                        return false;
                    let cur_scope = def.scope;
                    while (cur_scope && cur_scope !== scope) {
                        if (cur_scope.variables.has(def.name)) {
                            return true;
                        }
                        cur_scope = cur_scope.parent_scope;
                    }
                    return false;
                }
                function has_overlapping_symbol(fn, arg, fn_strict) {
                    var found = false, scan_this = !(fn instanceof AST_Arrow);
                    arg.walk(new TreeWalker(function (node, descend) {
                        if (found)
                            return true;
                        if (node instanceof AST_SymbolRef && (fn.variables.has(node.name) || redefined_within_scope(node.definition(), fn))) {
                            var s = node.definition().scope;
                            if (s !== defun_scope)
                                while (s = s.parent_scope) {
                                    if (s === defun_scope)
                                        return true;
                                }
                            return found = true;
                        }
                        if ((fn_strict || scan_this) && node instanceof AST_This) {
                            return found = true;
                        }
                        if (node instanceof AST_Scope && !(node instanceof AST_Arrow)) {
                            var prev = scan_this;
                            scan_this = false;
                            descend();
                            scan_this = prev;
                            return true;
                        }
                    }));
                    return found;
                }
                function arg_is_injectable(arg) {
                    if (arg instanceof AST_Expansion)
                        return false;
                    const contains_await = walk(arg, (node) => {
                        if (node instanceof AST_Await)
                            return walk_abort;
                    });
                    if (contains_await)
                        return false;
                    return true;
                }
                function extract_args() {
                    var iife, fn = compressor.self();
                    if (is_func_expr(fn)
                        && !fn.name
                        && !fn.uses_arguments
                        && !fn.pinned()
                        && (iife = compressor.parent()) instanceof AST_Call
                        && iife.expression === fn
                        && iife.args.every(arg_is_injectable)) {
                        var fn_strict = compressor.has_directive("use strict");
                        if (fn_strict && !member(fn_strict, fn.body))
                            fn_strict = false;
                        var len = fn.argnames.length;
                        args = iife.args.slice(len);
                        var names = new Set();
                        for (var i = len; --i >= 0;) {
                            var sym = fn.argnames[i];
                            var arg = iife.args[i];
                            // The following two line fix is a duplicate of the fix at
                            // https://github.com/terser/terser/commit/011d3eb08cefe6922c7d1bdfa113fc4aeaca1b75
                            // This might mean that these two pieces of code (one here in collapse_vars and another in reduce_vars
                            // Might be doing the exact same thing.
                            const def = sym.definition && sym.definition();
                            const is_reassigned = def && def.orig.length > 1;
                            if (is_reassigned)
                                continue;
                            args.unshift(make_node(AST_VarDef, sym, {
                                name: sym,
                                value: arg
                            }));
                            if (names.has(sym.name))
                                continue;
                            names.add(sym.name);
                            if (sym instanceof AST_Expansion) {
                                var elements = iife.args.slice(i);
                                if (elements.every((arg) => !has_overlapping_symbol(fn, arg, fn_strict))) {
                                    candidates.unshift([make_node(AST_VarDef, sym, {
                                            name: sym.expression,
                                            value: make_node(AST_Array, iife, {
                                                elements: elements
                                            })
                                        })]);
                                }
                            }
                            else {
                                if (!arg) {
                                    arg = make_node(AST_Undefined, sym).transform(compressor);
                                }
                                else if (arg instanceof AST_Lambda && arg.pinned()
                                    || has_overlapping_symbol(fn, arg, fn_strict)) {
                                    arg = null;
                                }
                                if (arg)
                                    candidates.unshift([make_node(AST_VarDef, sym, {
                                            name: sym,
                                            value: arg
                                        })]);
                            }
                        }
                    }
                }
                function extract_candidates(expr) {
                    hit_stack.push(expr);
                    if (expr instanceof AST_Assign) {
                        if (!expr.left.has_side_effects(compressor)
                            && !(expr.right instanceof AST_Chain)) {
                            candidates.push(hit_stack.slice());
                        }
                        extract_candidates(expr.right);
                    }
                    else if (expr instanceof AST_Binary) {
                        extract_candidates(expr.left);
                        extract_candidates(expr.right);
                    }
                    else if (expr instanceof AST_Call && !has_annotation(expr, _NOINLINE)) {
                        extract_candidates(expr.expression);
                        expr.args.forEach(extract_candidates);
                    }
                    else if (expr instanceof AST_Case) {
                        extract_candidates(expr.expression);
                    }
                    else if (expr instanceof AST_Conditional) {
                        extract_candidates(expr.condition);
                        extract_candidates(expr.consequent);
                        extract_candidates(expr.alternative);
                    }
                    else if (expr instanceof AST_Definitions) {
                        var len = expr.definitions.length;
                        // limit number of trailing variable definitions for consideration
                        var i = len - 200;
                        if (i < 0)
                            i = 0;
                        for (; i < len; i++) {
                            extract_candidates(expr.definitions[i]);
                        }
                    }
                    else if (expr instanceof AST_DWLoop) {
                        extract_candidates(expr.condition);
                        if (!(expr.body instanceof AST_Block)) {
                            extract_candidates(expr.body);
                        }
                    }
                    else if (expr instanceof AST_Exit) {
                        if (expr.value)
                            extract_candidates(expr.value);
                    }
                    else if (expr instanceof AST_For) {
                        if (expr.init)
                            extract_candidates(expr.init);
                        if (expr.condition)
                            extract_candidates(expr.condition);
                        if (expr.step)
                            extract_candidates(expr.step);
                        if (!(expr.body instanceof AST_Block)) {
                            extract_candidates(expr.body);
                        }
                    }
                    else if (expr instanceof AST_ForIn) {
                        extract_candidates(expr.object);
                        if (!(expr.body instanceof AST_Block)) {
                            extract_candidates(expr.body);
                        }
                    }
                    else if (expr instanceof AST_If) {
                        extract_candidates(expr.condition);
                        if (!(expr.body instanceof AST_Block)) {
                            extract_candidates(expr.body);
                        }
                        if (expr.alternative && !(expr.alternative instanceof AST_Block)) {
                            extract_candidates(expr.alternative);
                        }
                    }
                    else if (expr instanceof AST_Sequence) {
                        expr.expressions.forEach(extract_candidates);
                    }
                    else if (expr instanceof AST_SimpleStatement) {
                        extract_candidates(expr.body);
                    }
                    else if (expr instanceof AST_Switch) {
                        extract_candidates(expr.expression);
                        expr.body.forEach(extract_candidates);
                    }
                    else if (expr instanceof AST_Unary) {
                        if (expr.operator == "++" || expr.operator == "--") {
                            candidates.push(hit_stack.slice());
                        }
                    }
                    else if (expr instanceof AST_VarDef) {
                        if (expr.value && !(expr.value instanceof AST_Chain)) {
                            candidates.push(hit_stack.slice());
                            extract_candidates(expr.value);
                        }
                    }
                    hit_stack.pop();
                }
                function find_stop(node, level, write_only) {
                    var parent = scanner.parent(level);
                    if (parent instanceof AST_Assign) {
                        if (write_only
                            && !parent.logical
                            && !(parent.left instanceof AST_PropAccess
                                || lvalues.has(parent.left.name))) {
                            return find_stop(parent, level + 1, write_only);
                        }
                        return node;
                    }
                    if (parent instanceof AST_Binary) {
                        if (write_only && (!lazy_op.has(parent.operator) || parent.left === node)) {
                            return find_stop(parent, level + 1, write_only);
                        }
                        return node;
                    }
                    if (parent instanceof AST_Call)
                        return node;
                    if (parent instanceof AST_Case)
                        return node;
                    if (parent instanceof AST_Conditional) {
                        if (write_only && parent.condition === node) {
                            return find_stop(parent, level + 1, write_only);
                        }
                        return node;
                    }
                    if (parent instanceof AST_Definitions) {
                        return find_stop(parent, level + 1, true);
                    }
                    if (parent instanceof AST_Exit) {
                        return write_only ? find_stop(parent, level + 1, write_only) : node;
                    }
                    if (parent instanceof AST_If) {
                        if (write_only && parent.condition === node) {
                            return find_stop(parent, level + 1, write_only);
                        }
                        return node;
                    }
                    if (parent instanceof AST_IterationStatement)
                        return node;
                    if (parent instanceof AST_Sequence) {
                        return find_stop(parent, level + 1, parent.tail_node() !== node);
                    }
                    if (parent instanceof AST_SimpleStatement) {
                        return find_stop(parent, level + 1, true);
                    }
                    if (parent instanceof AST_Switch)
                        return node;
                    if (parent instanceof AST_VarDef)
                        return node;
                    return null;
                }
                function mangleable_var(var_def) {
                    var value = var_def.value;
                    if (!(value instanceof AST_SymbolRef))
                        return;
                    if (value.name == "arguments")
                        return;
                    var def = value.definition();
                    if (def.undeclared)
                        return;
                    return value_def = def;
                }
                function get_lhs(expr) {
                    if (expr instanceof AST_Assign && expr.logical) {
                        return false;
                    }
                    else if (expr instanceof AST_VarDef && expr.name instanceof AST_SymbolDeclaration) {
                        var def = expr.name.definition();
                        if (!member(expr.name, def.orig))
                            return;
                        var referenced = def.references.length - def.replaced;
                        if (!referenced)
                            return;
                        var declared = def.orig.length - def.eliminated;
                        if (declared > 1 && !(expr.name instanceof AST_SymbolFunarg)
                            || (referenced > 1 ? mangleable_var(expr) : !compressor.exposed(def))) {
                            return make_node(AST_SymbolRef, expr.name, expr.name);
                        }
                    }
                    else {
                        const lhs = expr instanceof AST_Assign
                            ? expr.left
                            : expr.expression;
                        return !is_ref_of(lhs, AST_SymbolConst)
                            && !is_ref_of(lhs, AST_SymbolLet) && lhs;
                    }
                }
                function get_rvalue(expr) {
                    if (expr instanceof AST_Assign) {
                        return expr.right;
                    }
                    else {
                        return expr.value;
                    }
                }
                function get_lvalues(expr) {
                    var lvalues = new Map();
                    if (expr instanceof AST_Unary)
                        return lvalues;
                    var tw = new TreeWalker(function (node) {
                        var sym = node;
                        while (sym instanceof AST_PropAccess)
                            sym = sym.expression;
                        if (sym instanceof AST_SymbolRef) {
                            const prev = lvalues.get(sym.name);
                            if (!prev || !prev.modified) {
                                lvalues.set(sym.name, {
                                    def: sym.definition(),
                                    modified: is_modified(compressor, tw, node, node, 0)
                                });
                            }
                        }
                    });
                    get_rvalue(expr).walk(tw);
                    return lvalues;
                }
                function remove_candidate(expr) {
                    if (expr.name instanceof AST_SymbolFunarg) {
                        var iife = compressor.parent(), argnames = compressor.self().argnames;
                        var index = argnames.indexOf(expr.name);
                        if (index < 0) {
                            iife.args.length = Math.min(iife.args.length, argnames.length - 1);
                        }
                        else {
                            var args = iife.args;
                            if (args[index])
                                args[index] = make_node(AST_Number, args[index], {
                                    value: 0
                                });
                        }
                        return true;
                    }
                    var found = false;
                    return statements[stat_index].transform(new TreeTransformer(function (node, descend, in_list) {
                        if (found)
                            return node;
                        if (node === expr || node.body === expr) {
                            found = true;
                            if (node instanceof AST_VarDef) {
                                node.value = node.name instanceof AST_SymbolConst
                                    ? make_node(AST_Undefined, node.value) // `const` always needs value.
                                    : null;
                                return node;
                            }
                            return in_list ? MAP.skip : null;
                        }
                    }, function (node) {
                        if (node instanceof AST_Sequence)
                            switch (node.expressions.length) {
                                case 0: return null;
                                case 1: return node.expressions[0];
                            }
                    }));
                }
                function is_lhs_local(lhs) {
                    while (lhs instanceof AST_PropAccess)
                        lhs = lhs.expression;
                    return lhs instanceof AST_SymbolRef
                        && lhs.definition().scope.get_defun_scope() === defun_scope
                        && !(in_loop
                            && (lvalues.has(lhs.name)
                                || candidate instanceof AST_Unary
                                || (candidate instanceof AST_Assign
                                    && !candidate.logical
                                    && candidate.operator != "=")));
                }
                function value_has_side_effects(expr) {
                    if (expr instanceof AST_Unary)
                        return unary_side_effects.has(expr.operator);
                    return get_rvalue(expr).has_side_effects(compressor);
                }
                function replace_all_symbols() {
                    if (side_effects)
                        return false;
                    if (value_def)
                        return true;
                    if (lhs instanceof AST_SymbolRef) {
                        var def = lhs.definition();
                        if (def.references.length - def.replaced == (candidate instanceof AST_VarDef ? 1 : 2)) {
                            return true;
                        }
                    }
                    return false;
                }
                function may_modify(sym) {
                    if (!sym.definition)
                        return true; // AST_Destructuring
                    var def = sym.definition();
                    if (def.orig.length == 1 && def.orig[0] instanceof AST_SymbolDefun)
                        return false;
                    if (def.scope.get_defun_scope() !== defun_scope)
                        return true;
                    return def.references.some((ref) => ref.scope.get_defun_scope() !== defun_scope);
                }
                function side_effects_external(node, lhs) {
                    if (node instanceof AST_Assign)
                        return side_effects_external(node.left, true);
                    if (node instanceof AST_Unary)
                        return side_effects_external(node.expression, true);
                    if (node instanceof AST_VarDef)
                        return node.value && side_effects_external(node.value);
                    if (lhs) {
                        if (node instanceof AST_Dot)
                            return side_effects_external(node.expression, true);
                        if (node instanceof AST_Sub)
                            return side_effects_external(node.expression, true);
                        if (node instanceof AST_SymbolRef)
                            return node.definition().scope.get_defun_scope() !== defun_scope;
                    }
                    return false;
                }
                /**
                 * Will any of the pulled-in lvalues shadow a variable in newScope or parents?
                 * similar to scope_encloses_variables_in_this_scope */
                function shadows(my_scope, lvalues) {
                    for (const { def } of lvalues.values()) {
                        const looked_up = my_scope.find_variable(def.name);
                        if (looked_up) {
                            if (looked_up === def)
                                continue;
                            return true;
                        }
                    }
                    return false;
                }
            }
            function eliminate_spurious_blocks(statements) {
                var seen_dirs = [];
                for (var i = 0; i < statements.length;) {
                    var stat = statements[i];
                    if (stat instanceof AST_BlockStatement && stat.body.every(can_be_evicted_from_block)) {
                        CHANGED = true;
                        eliminate_spurious_blocks(stat.body);
                        statements.splice(i, 1, ...stat.body);
                        i += stat.body.length;
                    }
                    else if (stat instanceof AST_EmptyStatement) {
                        CHANGED = true;
                        statements.splice(i, 1);
                    }
                    else if (stat instanceof AST_Directive) {
                        if (seen_dirs.indexOf(stat.value) < 0) {
                            i++;
                            seen_dirs.push(stat.value);
                        }
                        else {
                            CHANGED = true;
                            statements.splice(i, 1);
                        }
                    }
                    else
                        i++;
                }
            }
            function handle_if_return(statements, compressor) {
                var self = compressor.self();
                var multiple_if_returns = has_multiple_if_returns(statements);
                var in_lambda = self instanceof AST_Lambda;
                // Prevent extremely deep nesting
                // https://github.com/terser/terser/issues/1432
                // https://github.com/webpack/webpack/issues/17548
                const iteration_start = Math.min(statements.length, 500);
                for (var i = iteration_start; --i >= 0;) {
                    var stat = statements[i];
                    var j = next_index(i);
                    var next = statements[j];
                    if (in_lambda && !next && stat instanceof AST_Return) {
                        if (!stat.value) {
                            CHANGED = true;
                            statements.splice(i, 1);
                            continue;
                        }
                        if (stat.value instanceof AST_UnaryPrefix && stat.value.operator == "void") {
                            CHANGED = true;
                            statements[i] = make_node(AST_SimpleStatement, stat, {
                                body: stat.value.expression
                            });
                            continue;
                        }
                    }
                    if (stat instanceof AST_If) {
                        let ab, new_else;
                        ab = aborts(stat.body);
                        if (can_merge_flow(ab)
                            && (new_else = as_statement_array_with_return(stat.body, ab))) {
                            if (ab.label) {
                                remove(ab.label.thedef.references, ab);
                            }
                            CHANGED = true;
                            stat = stat.clone();
                            stat.condition = stat.condition.negate(compressor);
                            stat.body = make_node(AST_BlockStatement, stat, {
                                body: as_statement_array(stat.alternative).concat(extract_functions())
                            });
                            stat.alternative = make_node(AST_BlockStatement, stat, {
                                body: new_else
                            });
                            statements[i] = stat.transform(compressor);
                            continue;
                        }
                        ab = aborts(stat.alternative);
                        if (can_merge_flow(ab)
                            && (new_else = as_statement_array_with_return(stat.alternative, ab))) {
                            if (ab.label) {
                                remove(ab.label.thedef.references, ab);
                            }
                            CHANGED = true;
                            stat = stat.clone();
                            stat.body = make_node(AST_BlockStatement, stat.body, {
                                body: as_statement_array(stat.body).concat(extract_functions())
                            });
                            stat.alternative = make_node(AST_BlockStatement, stat.alternative, {
                                body: new_else
                            });
                            statements[i] = stat.transform(compressor);
                            continue;
                        }
                    }
                    if (stat instanceof AST_If && stat.body instanceof AST_Return) {
                        var value = stat.body.value;
                        //---
                        // pretty silly case, but:
                        // if (foo()) return; return; ==> foo(); return;
                        if (!value && !stat.alternative
                            && (in_lambda && !next || next instanceof AST_Return && !next.value)) {
                            CHANGED = true;
                            statements[i] = make_node(AST_SimpleStatement, stat.condition, {
                                body: stat.condition
                            });
                            continue;
                        }
                        //---
                        // if (foo()) return x; return y; ==> return foo() ? x : y;
                        if (value && !stat.alternative && next instanceof AST_Return && next.value) {
                            CHANGED = true;
                            stat = stat.clone();
                            stat.alternative = next;
                            statements[i] = stat.transform(compressor);
                            statements.splice(j, 1);
                            continue;
                        }
                        //---
                        // if (foo()) return x; [ return ; ] ==> return foo() ? x : undefined;
                        if (value && !stat.alternative
                            && (!next && in_lambda && multiple_if_returns
                                || next instanceof AST_Return)) {
                            CHANGED = true;
                            stat = stat.clone();
                            stat.alternative = next || make_node(AST_Return, stat, {
                                value: null
                            });
                            statements[i] = stat.transform(compressor);
                            if (next)
                                statements.splice(j, 1);
                            continue;
                        }
                        //---
                        // if (a) return b; if (c) return d; e; ==> return a ? b : c ? d : void e;
                        //
                        // if sequences is not enabled, this can lead to an endless loop (issue #866).
                        // however, with sequences on this helps producing slightly better output for
                        // the example code.
                        var prev = statements[prev_index(i)];
                        if (compressor.option("sequences") && in_lambda && !stat.alternative
                            && prev instanceof AST_If && prev.body instanceof AST_Return
                            && next_index(j) == statements.length && next instanceof AST_SimpleStatement) {
                            CHANGED = true;
                            stat = stat.clone();
                            stat.alternative = make_node(AST_BlockStatement, next, {
                                body: [
                                    next,
                                    make_node(AST_Return, next, {
                                        value: null
                                    })
                                ]
                            });
                            statements[i] = stat.transform(compressor);
                            statements.splice(j, 1);
                            continue;
                        }
                    }
                }
                function has_multiple_if_returns(statements) {
                    var n = 0;
                    for (var i = statements.length; --i >= 0;) {
                        var stat = statements[i];
                        if (stat instanceof AST_If && stat.body instanceof AST_Return) {
                            if (++n > 1)
                                return true;
                        }
                    }
                    return false;
                }
                function is_return_void(value) {
                    return !value || value instanceof AST_UnaryPrefix && value.operator == "void";
                }
                function can_merge_flow(ab) {
                    if (!ab)
                        return false;
                    for (var j = i + 1, len = statements.length; j < len; j++) {
                        var stat = statements[j];
                        if (stat instanceof AST_Const || stat instanceof AST_Let)
                            return false;
                    }
                    var lct = ab instanceof AST_LoopControl ? compressor.loopcontrol_target(ab) : null;
                    return ab instanceof AST_Return && in_lambda && is_return_void(ab.value)
                        || ab instanceof AST_Continue && self === loop_body(lct)
                        || ab instanceof AST_Break && lct instanceof AST_BlockStatement && self === lct;
                }
                function extract_functions() {
                    var tail = statements.slice(i + 1);
                    statements.length = i + 1;
                    return tail.filter(function (stat) {
                        if (stat instanceof AST_Defun) {
                            statements.push(stat);
                            return false;
                        }
                        return true;
                    });
                }
                function as_statement_array_with_return(node, ab) {
                    var body = as_statement_array(node);
                    if (ab !== body[body.length - 1]) {
                        return undefined;
                    }
                    body = body.slice(0, -1);
                    if (ab.value) {
                        body.push(make_node(AST_SimpleStatement, ab.value, {
                            body: ab.value.expression
                        }));
                    }
                    return body;
                }
                function next_index(i) {
                    for (var j = i + 1, len = statements.length; j < len; j++) {
                        var stat = statements[j];
                        if (!(stat instanceof AST_Var && declarations_only(stat))) {
                            break;
                        }
                    }
                    return j;
                }
                function prev_index(i) {
                    for (var j = i; --j >= 0;) {
                        var stat = statements[j];
                        if (!(stat instanceof AST_Var && declarations_only(stat))) {
                            break;
                        }
                    }
                    return j;
                }
            }
            function eliminate_dead_code(statements, compressor) {
                var has_quit;
                var self = compressor.self();
                for (var i = 0, n = 0, len = statements.length; i < len; i++) {
                    var stat = statements[i];
                    if (stat instanceof AST_LoopControl) {
                        var lct = compressor.loopcontrol_target(stat);
                        if (stat instanceof AST_Break
                            && !(lct instanceof AST_IterationStatement)
                            && loop_body(lct) === self
                            || stat instanceof AST_Continue
                                && loop_body(lct) === self) {
                            if (stat.label) {
                                remove(stat.label.thedef.references, stat);
                            }
                        }
                        else {
                            statements[n++] = stat;
                        }
                    }
                    else {
                        statements[n++] = stat;
                    }
                    if (aborts(stat)) {
                        has_quit = statements.slice(i + 1);
                        break;
                    }
                }
                statements.length = n;
                CHANGED = n != len;
                if (has_quit)
                    has_quit.forEach(function (stat) {
                        trim_unreachable_code(compressor, stat, statements);
                    });
            }
            function declarations_only(node) {
                return node.definitions.every((var_def) => !var_def.value);
            }
            function sequencesize(statements, compressor) {
                if (statements.length < 2)
                    return;
                var seq = [], n = 0;
                function push_seq() {
                    if (!seq.length)
                        return;
                    var body = make_sequence(seq[0], seq);
                    statements[n++] = make_node(AST_SimpleStatement, body, { body: body });
                    seq = [];
                }
                for (var i = 0, len = statements.length; i < len; i++) {
                    var stat = statements[i];
                    if (stat instanceof AST_SimpleStatement) {
                        if (seq.length >= compressor.sequences_limit)
                            push_seq();
                        var body = stat.body;
                        if (seq.length > 0)
                            body = body.drop_side_effect_free(compressor);
                        if (body)
                            merge_sequence(seq, body);
                    }
                    else if (stat instanceof AST_Definitions && declarations_only(stat)
                        || stat instanceof AST_Defun) {
                        statements[n++] = stat;
                    }
                    else {
                        push_seq();
                        statements[n++] = stat;
                    }
                }
                push_seq();
                statements.length = n;
                if (n != len)
                    CHANGED = true;
            }
            function to_simple_statement(block, decls) {
                if (!(block instanceof AST_BlockStatement))
                    return block;
                var stat = null;
                for (var i = 0, len = block.body.length; i < len; i++) {
                    var line = block.body[i];
                    if (line instanceof AST_Var && declarations_only(line)) {
                        decls.push(line);
                    }
                    else if (stat || line instanceof AST_Const || line instanceof AST_Let) {
                        return false;
                    }
                    else {
                        stat = line;
                    }
                }
                return stat;
            }
            function sequencesize_2(statements, compressor) {
                function cons_seq(right) {
                    n--;
                    CHANGED = true;
                    var left = prev.body;
                    return make_sequence(left, [left, right]).transform(compressor);
                }
                var n = 0, prev;
                for (var i = 0; i < statements.length; i++) {
                    var stat = statements[i];
                    if (prev) {
                        if (stat instanceof AST_Exit) {
                            stat.value = cons_seq(stat.value || make_node(AST_Undefined, stat).transform(compressor));
                        }
                        else if (stat instanceof AST_For) {
                            if (!(stat.init instanceof AST_Definitions)) {
                                const abort = walk(prev.body, node => {
                                    if (node instanceof AST_Scope)
                                        return true;
                                    if (node instanceof AST_Binary
                                        && node.operator === "in") {
                                        return walk_abort;
                                    }
                                });
                                if (!abort) {
                                    if (stat.init)
                                        stat.init = cons_seq(stat.init);
                                    else {
                                        stat.init = prev.body;
                                        n--;
                                        CHANGED = true;
                                    }
                                }
                            }
                        }
                        else if (stat instanceof AST_ForIn) {
                            if (!(stat.init instanceof AST_Const) && !(stat.init instanceof AST_Let)) {
                                stat.object = cons_seq(stat.object);
                            }
                        }
                        else if (stat instanceof AST_If) {
                            stat.condition = cons_seq(stat.condition);
                        }
                        else if (stat instanceof AST_Switch) {
                            stat.expression = cons_seq(stat.expression);
                        }
                        else if (stat instanceof AST_With) {
                            stat.expression = cons_seq(stat.expression);
                        }
                    }
                    if (compressor.option("conditionals") && stat instanceof AST_If) {
                        var decls = [];
                        var body = to_simple_statement(stat.body, decls);
                        var alt = to_simple_statement(stat.alternative, decls);
                        if (body !== false && alt !== false && decls.length > 0) {
                            var len = decls.length;
                            decls.push(make_node(AST_If, stat, {
                                condition: stat.condition,
                                body: body || make_node(AST_EmptyStatement, stat.body),
                                alternative: alt
                            }));
                            decls.unshift(n, 1);
                            [].splice.apply(statements, decls);
                            i += len;
                            n += len + 1;
                            prev = null;
                            CHANGED = true;
                            continue;
                        }
                    }
                    statements[n++] = stat;
                    prev = stat instanceof AST_SimpleStatement ? stat : null;
                }
                statements.length = n;
            }
            function join_object_assignments(defn, body) {
                if (!(defn instanceof AST_Definitions))
                    return;
                var def = defn.definitions[defn.definitions.length - 1];
                if (!(def.value instanceof AST_Object))
                    return;
                var exprs;
                if (body instanceof AST_Assign && !body.logical) {
                    exprs = [body];
                }
                else if (body instanceof AST_Sequence) {
                    exprs = body.expressions.slice();
                }
                if (!exprs)
                    return;
                var trimmed = false;
                do {
                    var node = exprs[0];
                    if (!(node instanceof AST_Assign))
                        break;
                    if (node.operator != "=")
                        break;
                    if (!(node.left instanceof AST_PropAccess))
                        break;
                    var sym = node.left.expression;
                    if (!(sym instanceof AST_SymbolRef))
                        break;
                    if (def.name.name != sym.name)
                        break;
                    if (!node.right.is_constant_expression(nearest_scope))
                        break;
                    var prop = node.left.property;
                    if (prop instanceof AST_Node) {
                        prop = prop.evaluate(compressor);
                    }
                    if (prop instanceof AST_Node)
                        break;
                    prop = "" + prop;
                    var diff = compressor.option("ecma") < 2015
                        && compressor.has_directive("use strict") ? function (node) {
                        return node.key != prop && (node.key && node.key.name != prop);
                    } : function (node) {
                        return node.key && node.key.name != prop;
                    };
                    if (!def.value.properties.every(diff))
                        break;
                    var p = def.value.properties.filter(function (p) { return p.key === prop; })[0];
                    if (!p) {
                        def.value.properties.push(make_node(AST_ObjectKeyVal, node, {
                            key: prop,
                            value: node.right
                        }));
                    }
                    else {
                        p.value = new AST_Sequence({
                            start: p.start,
                            expressions: [p.value.clone(), node.right.clone()],
                            end: p.end
                        });
                    }
                    exprs.shift();
                    trimmed = true;
                } while (exprs.length);
                return trimmed && exprs;
            }
            function join_consecutive_vars(statements) {
                var defs;
                for (var i = 0, j = -1, len = statements.length; i < len; i++) {
                    var stat = statements[i];
                    var prev = statements[j];
                    if (stat instanceof AST_Definitions) {
                        if (prev && prev.TYPE == stat.TYPE) {
                            prev.definitions = prev.definitions.concat(stat.definitions);
                            CHANGED = true;
                        }
                        else if (defs && defs.TYPE == stat.TYPE && declarations_only(stat)) {
                            defs.definitions = defs.definitions.concat(stat.definitions);
                            CHANGED = true;
                        }
                        else {
                            statements[++j] = stat;
                            defs = stat;
                        }
                    }
                    else if (stat instanceof AST_Exit) {
                        stat.value = extract_object_assignments(stat.value);
                    }
                    else if (stat instanceof AST_For) {
                        var exprs = join_object_assignments(prev, stat.init);
                        if (exprs) {
                            CHANGED = true;
                            stat.init = exprs.length ? make_sequence(stat.init, exprs) : null;
                            statements[++j] = stat;
                        }
                        else if (prev instanceof AST_Var
                            && (!stat.init || stat.init.TYPE == prev.TYPE)) {
                            if (stat.init) {
                                prev.definitions = prev.definitions.concat(stat.init.definitions);
                            }
                            stat.init = prev;
                            statements[j] = stat;
                            CHANGED = true;
                        }
                        else if (defs instanceof AST_Var
                            && stat.init instanceof AST_Var
                            && declarations_only(stat.init)) {
                            defs.definitions = defs.definitions.concat(stat.init.definitions);
                            stat.init = null;
                            statements[++j] = stat;
                            CHANGED = true;
                        }
                        else {
                            statements[++j] = stat;
                        }
                    }
                    else if (stat instanceof AST_ForIn) {
                        stat.object = extract_object_assignments(stat.object);
                    }
                    else if (stat instanceof AST_If) {
                        stat.condition = extract_object_assignments(stat.condition);
                    }
                    else if (stat instanceof AST_SimpleStatement) {
                        var exprs = join_object_assignments(prev, stat.body);
                        if (exprs) {
                            CHANGED = true;
                            if (!exprs.length)
                                continue;
                            stat.body = make_sequence(stat.body, exprs);
                        }
                        statements[++j] = stat;
                    }
                    else if (stat instanceof AST_Switch) {
                        stat.expression = extract_object_assignments(stat.expression);
                    }
                    else if (stat instanceof AST_With) {
                        stat.expression = extract_object_assignments(stat.expression);
                    }
                    else {
                        statements[++j] = stat;
                    }
                }
                statements.length = j + 1;
                function extract_object_assignments(value) {
                    statements[++j] = stat;
                    var exprs = join_object_assignments(prev, value);
                    if (exprs) {
                        CHANGED = true;
                        if (exprs.length) {
                            return make_sequence(value, exprs);
                        }
                        else if (value instanceof AST_Sequence) {
                            return value.tail_node().left;
                        }
                        else {
                            return value.left;
                        }
                    }
                    return value;
                }
            }
        }
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        /**
         * Module that contains the inlining logic.
         *
         * @module
         *
         * The stars of the show are `inline_into_symbolref` and `inline_into_call`.
         */
        function within_array_or_object_literal(compressor) {
            var node, level = 0;
            while (node = compressor.parent(level++)) {
                if (node instanceof AST_Statement)
                    return false;
                if (node instanceof AST_Array
                    || node instanceof AST_ObjectKeyVal
                    || node instanceof AST_Object) {
                    return true;
                }
            }
            return false;
        }
        function scope_encloses_variables_in_this_scope(scope, pulled_scope) {
            for (const enclosed of pulled_scope.enclosed) {
                if (pulled_scope.variables.has(enclosed.name)) {
                    continue;
                }
                const looked_up = scope.find_variable(enclosed.name);
                if (looked_up) {
                    if (looked_up === enclosed)
                        continue;
                    return true;
                }
            }
            return false;
        }
        /**
         * An extra check function for `top_retain` option, compare the length of const identifier
         * and init value length and return true if init value is longer than identifier. for example:
         * ```
         * // top_retain: ["example"]
         * const example = 100
         * ```
         * it will return false because length of "100" is short than identifier "example".
         */
        function is_const_symbol_short_than_init_value(def, fixed_value) {
            if (def.orig.length === 1 && fixed_value) {
                const init_value_length = fixed_value.size();
                const identifer_length = def.name.length;
                return init_value_length > identifer_length;
            }
            return true;
        }
        function inline_into_symbolref(self, compressor) {
            if (compressor.in_computed_key())
                return self;
            const parent = compressor.parent();
            const def = self.definition();
            const nearest_scope = compressor.find_scope();
            let fixed = self.fixed_value();
            if (compressor.top_retain &&
                def.global &&
                compressor.top_retain(def) &&
                // when identifier is in top_retain option dose not mean we can always inline it.
                // if identifier name is longer then init value, we can replace it.
                is_const_symbol_short_than_init_value(def, fixed)) {
                // keep it
                def.fixed = false;
                def.single_use = false;
                return self;
            }
            let single_use = def.single_use
                && !(parent instanceof AST_Call
                    && (parent.is_callee_pure(compressor))
                    || has_annotation(parent, _NOINLINE))
                && !(parent instanceof AST_Export
                    && fixed instanceof AST_Lambda
                    && fixed.name);
            if (single_use && fixed instanceof AST_Node) {
                single_use =
                    !fixed.has_side_effects(compressor)
                        && !fixed.may_throw(compressor);
            }
            if (fixed instanceof AST_Class && def.scope !== self.scope) {
                return self;
            }
            if (single_use && (fixed instanceof AST_Lambda || fixed instanceof AST_Class)) {
                if (retain_top_func(fixed, compressor)) {
                    single_use = false;
                }
                else if (def.scope !== self.scope
                    && (def.escaped == 1
                        || has_flag(fixed, INLINED)
                        || within_array_or_object_literal(compressor)
                        || !compressor.option("reduce_funcs"))) {
                    single_use = false;
                }
                else if (is_recursive_ref(compressor, def)) {
                    single_use = false;
                }
                else if (def.scope !== self.scope || def.orig[0] instanceof AST_SymbolFunarg) {
                    single_use = fixed.is_constant_expression(self.scope);
                    if (single_use == "f") {
                        var scope = self.scope;
                        do {
                            if (scope instanceof AST_Defun || is_func_expr(scope)) {
                                set_flag(scope, INLINED);
                            }
                        } while (scope = scope.parent_scope);
                    }
                }
            }
            if (single_use && (fixed instanceof AST_Lambda || fixed instanceof AST_Class)) {
                single_use =
                    def.scope === self.scope
                        && !scope_encloses_variables_in_this_scope(nearest_scope, fixed)
                        || parent instanceof AST_Call
                            && parent.expression === self
                            && !scope_encloses_variables_in_this_scope(nearest_scope, fixed)
                            && !(fixed.name && fixed.name.definition().recursive_refs > 0);
            }
            if (single_use && fixed) {
                if (fixed instanceof AST_DefClass) {
                    set_flag(fixed, SQUEEZED);
                    fixed = make_node(AST_ClassExpression, fixed, fixed);
                }
                if (fixed instanceof AST_Defun) {
                    set_flag(fixed, SQUEEZED);
                    fixed = make_node(AST_Function, fixed, fixed);
                }
                if (def.recursive_refs > 0 && fixed.name instanceof AST_SymbolDefun) {
                    const defun_def = fixed.name.definition();
                    let lambda_def = fixed.variables.get(fixed.name.name);
                    let name = lambda_def && lambda_def.orig[0];
                    if (!(name instanceof AST_SymbolLambda)) {
                        name = make_node(AST_SymbolLambda, fixed.name, fixed.name);
                        name.scope = fixed;
                        fixed.name = name;
                        lambda_def = fixed.def_function(name);
                    }
                    walk(fixed, node => {
                        if (node instanceof AST_SymbolRef && node.definition() === defun_def) {
                            node.thedef = lambda_def;
                            lambda_def.references.push(node);
                        }
                    });
                }
                if ((fixed instanceof AST_Lambda || fixed instanceof AST_Class)
                    && fixed.parent_scope !== nearest_scope) {
                    fixed = fixed.clone(true, compressor.get_toplevel());
                    nearest_scope.add_child_scope(fixed);
                }
                return fixed.optimize(compressor);
            }
            // multiple uses
            if (fixed) {
                let replace;
                if (fixed instanceof AST_This) {
                    if (!(def.orig[0] instanceof AST_SymbolFunarg)
                        && def.references.every((ref) => def.scope === ref.scope)) {
                        replace = fixed;
                    }
                }
                else {
                    var ev = fixed.evaluate(compressor);
                    if (ev !== fixed
                        && (compressor.option("unsafe_regexp") || !(ev instanceof RegExp))) {
                        replace = make_node_from_constant(ev, fixed);
                    }
                }
                if (replace) {
                    const name_length = self.size(compressor);
                    const replace_size = replace.size(compressor);
                    let overhead = 0;
                    if (compressor.option("unused") && !compressor.exposed(def)) {
                        overhead =
                            (name_length + 2 + fixed.size(compressor)) /
                                (def.references.length - def.assignments);
                    }
                    if (replace_size <= name_length + overhead) {
                        return replace;
                    }
                }
            }
            return self;
        }
        function inline_into_call(self, compressor) {
            if (compressor.in_computed_key())
                return self;
            var exp = self.expression;
            var fn = exp;
            var simple_args = self.args.every((arg) => !(arg instanceof AST_Expansion));
            if (compressor.option("reduce_vars")
                && fn instanceof AST_SymbolRef
                && !has_annotation(self, _NOINLINE)) {
                const fixed = fn.fixed_value();
                if (retain_top_func(fixed, compressor)
                    || !compressor.toplevel.funcs && exp.definition().global) {
                    return self;
                }
                fn = fixed;
            }
            var is_func = fn instanceof AST_Lambda;
            var stat = is_func && fn.body[0];
            var is_regular_func = is_func && !fn.is_generator && !fn.async;
            var can_inline = is_regular_func && compressor.option("inline") && !self.is_callee_pure(compressor);
            if (can_inline && stat instanceof AST_Return) {
                let returned = stat.value;
                if (!returned || returned.is_constant_expression()) {
                    if (returned) {
                        returned = returned.clone(true);
                    }
                    else {
                        returned = make_node(AST_Undefined, self);
                    }
                    const args = self.args.concat(returned);
                    return make_sequence(self, args).optimize(compressor);
                }
                // optimize identity function
                if (fn.argnames.length === 1
                    && (fn.argnames[0] instanceof AST_SymbolFunarg)
                    && self.args.length < 2
                    && !(self.args[0] instanceof AST_Expansion)
                    && returned instanceof AST_SymbolRef
                    && returned.name === fn.argnames[0].name) {
                    const replacement = (self.args[0] || make_node(AST_Undefined)).optimize(compressor);
                    let parent;
                    if (replacement instanceof AST_PropAccess
                        && (parent = compressor.parent()) instanceof AST_Call
                        && parent.expression === self) {
                        // identity function was being used to remove `this`, like in
                        //
                        // id(bag.no_this)(...)
                        //
                        // Replace with a larger but more effish (0, bag.no_this) wrapper.
                        return make_sequence(self, [
                            make_node(AST_Number, self, { value: 0 }),
                            replacement
                        ]);
                    }
                    // replace call with first argument or undefined if none passed
                    return replacement;
                }
            }
            if (can_inline) {
                var scope, in_loop, level = -1;
                let def;
                let returned_value;
                let nearest_scope;
                if (simple_args
                    && !fn.uses_arguments
                    && !(compressor.parent() instanceof AST_Class)
                    && !(fn.name && fn instanceof AST_Function)
                    && (returned_value = can_flatten_body(stat))
                    && (exp === fn
                        || has_annotation(self, _INLINE)
                        || compressor.option("unused")
                            && (def = exp.definition()).references.length == 1
                            && !is_recursive_ref(compressor, def)
                            && fn.is_constant_expression(exp.scope))
                    && !has_annotation(self, _PURE | _NOINLINE)
                    && !fn.contains_this()
                    && can_inject_symbols()
                    && (nearest_scope = compressor.find_scope())
                    && !scope_encloses_variables_in_this_scope(nearest_scope, fn)
                    && !(function in_default_assign() {
                        // Due to the fact function parameters have their own scope
                        // which can't use `var something` in the function body within,
                        // we simply don't inline into DefaultAssign.
                        let i = 0;
                        let p;
                        while ((p = compressor.parent(i++))) {
                            if (p instanceof AST_DefaultAssign)
                                return true;
                            if (p instanceof AST_Block)
                                break;
                        }
                        return false;
                    })()
                    && !(scope instanceof AST_Class)) {
                    set_flag(fn, SQUEEZED);
                    nearest_scope.add_child_scope(fn);
                    return make_sequence(self, flatten_fn(returned_value)).optimize(compressor);
                }
            }
            if (can_inline && has_annotation(self, _INLINE)) {
                set_flag(fn, SQUEEZED);
                fn = make_node(fn.CTOR === AST_Defun ? AST_Function : fn.CTOR, fn, fn);
                fn = fn.clone(true);
                fn.figure_out_scope({}, {
                    parent_scope: compressor.find_scope(),
                    toplevel: compressor.get_toplevel()
                });
                return make_node(AST_Call, self, {
                    expression: fn,
                    args: self.args,
                }).optimize(compressor);
            }
            const can_drop_this_call = is_regular_func && compressor.option("side_effects") && fn.body.every(is_empty);
            if (can_drop_this_call) {
                var args = self.args.concat(make_node(AST_Undefined, self));
                return make_sequence(self, args).optimize(compressor);
            }
            if (compressor.option("negate_iife")
                && compressor.parent() instanceof AST_SimpleStatement
                && is_iife_call(self)) {
                return self.negate(compressor, true);
            }
            var ev = self.evaluate(compressor);
            if (ev !== self) {
                ev = make_node_from_constant(ev, self).optimize(compressor);
                return best_of(compressor, ev, self);
            }
            return self;
            function return_value(stat) {
                if (!stat)
                    return make_node(AST_Undefined, self);
                if (stat instanceof AST_Return) {
                    if (!stat.value)
                        return make_node(AST_Undefined, self);
                    return stat.value.clone(true);
                }
                if (stat instanceof AST_SimpleStatement) {
                    return make_node(AST_UnaryPrefix, stat, {
                        operator: "void",
                        expression: stat.body.clone(true)
                    });
                }
            }
            function can_flatten_body(stat) {
                var body = fn.body;
                var len = body.length;
                if (compressor.option("inline") < 3) {
                    return len == 1 && return_value(stat);
                }
                stat = null;
                for (var i = 0; i < len; i++) {
                    var line = body[i];
                    if (line instanceof AST_Var) {
                        if (stat && !line.definitions.every((var_def) => !var_def.value)) {
                            return false;
                        }
                    }
                    else if (stat) {
                        return false;
                    }
                    else if (!(line instanceof AST_EmptyStatement)) {
                        stat = line;
                    }
                }
                return return_value(stat);
            }
            function can_inject_args(block_scoped, safe_to_inject) {
                for (var i = 0, len = fn.argnames.length; i < len; i++) {
                    var arg = fn.argnames[i];
                    if (arg instanceof AST_DefaultAssign) {
                        if (has_flag(arg.left, UNUSED))
                            continue;
                        return false;
                    }
                    if (arg instanceof AST_Destructuring)
                        return false;
                    if (arg instanceof AST_Expansion) {
                        if (has_flag(arg.expression, UNUSED))
                            continue;
                        return false;
                    }
                    if (has_flag(arg, UNUSED))
                        continue;
                    if (!safe_to_inject
                        || block_scoped.has(arg.name)
                        || identifier_atom.has(arg.name)
                        || scope.conflicting_def(arg.name)) {
                        return false;
                    }
                    if (in_loop)
                        in_loop.push(arg.definition());
                }
                return true;
            }
            function can_inject_vars(block_scoped, safe_to_inject) {
                var len = fn.body.length;
                for (var i = 0; i < len; i++) {
                    var stat = fn.body[i];
                    if (!(stat instanceof AST_Var))
                        continue;
                    if (!safe_to_inject)
                        return false;
                    for (var j = stat.definitions.length; --j >= 0;) {
                        var name = stat.definitions[j].name;
                        if (name instanceof AST_Destructuring
                            || block_scoped.has(name.name)
                            || identifier_atom.has(name.name)
                            || scope.conflicting_def(name.name)) {
                            return false;
                        }
                        if (in_loop)
                            in_loop.push(name.definition());
                    }
                }
                return true;
            }
            function can_inject_symbols() {
                var block_scoped = new Set();
                do {
                    scope = compressor.parent(++level);
                    if (scope.is_block_scope() && scope.block_scope) {
                        // TODO this is sometimes undefined during compression.
                        // But it should always have a value!
                        scope.block_scope.variables.forEach(function (variable) {
                            block_scoped.add(variable.name);
                        });
                    }
                    if (scope instanceof AST_Catch) {
                        // TODO can we delete? AST_Catch is a block scope.
                        if (scope.argname) {
                            block_scoped.add(scope.argname.name);
                        }
                    }
                    else if (scope instanceof AST_IterationStatement) {
                        in_loop = [];
                    }
                    else if (scope instanceof AST_SymbolRef) {
                        if (scope.fixed_value() instanceof AST_Scope)
                            return false;
                    }
                } while (!(scope instanceof AST_Scope));
                var safe_to_inject = !(scope instanceof AST_Toplevel) || compressor.toplevel.vars;
                var inline = compressor.option("inline");
                if (!can_inject_vars(block_scoped, inline >= 3 && safe_to_inject))
                    return false;
                if (!can_inject_args(block_scoped, inline >= 2 && safe_to_inject))
                    return false;
                return !in_loop || in_loop.length == 0 || !is_reachable(fn, in_loop);
            }
            function append_var(decls, expressions, name, value) {
                var def = name.definition();
                // Name already exists, only when a function argument had the same name
                const already_appended = scope.variables.has(name.name);
                if (!already_appended) {
                    scope.variables.set(name.name, def);
                    scope.enclosed.push(def);
                    decls.push(make_node(AST_VarDef, name, {
                        name: name,
                        value: null
                    }));
                }
                var sym = make_node(AST_SymbolRef, name, name);
                def.references.push(sym);
                if (value)
                    expressions.push(make_node(AST_Assign, self, {
                        operator: "=",
                        logical: false,
                        left: sym,
                        right: value.clone()
                    }));
            }
            function flatten_args(decls, expressions) {
                var len = fn.argnames.length;
                for (var i = self.args.length; --i >= len;) {
                    expressions.push(self.args[i]);
                }
                for (i = len; --i >= 0;) {
                    var name = fn.argnames[i];
                    var value = self.args[i];
                    if (has_flag(name, UNUSED) || !name.name || scope.conflicting_def(name.name)) {
                        if (value)
                            expressions.push(value);
                    }
                    else {
                        var symbol = make_node(AST_SymbolVar, name, name);
                        name.definition().orig.push(symbol);
                        if (!value && in_loop)
                            value = make_node(AST_Undefined, self);
                        append_var(decls, expressions, symbol, value);
                    }
                }
                decls.reverse();
                expressions.reverse();
            }
            function flatten_vars(decls, expressions) {
                var pos = expressions.length;
                for (var i = 0, lines = fn.body.length; i < lines; i++) {
                    var stat = fn.body[i];
                    if (!(stat instanceof AST_Var))
                        continue;
                    for (var j = 0, defs = stat.definitions.length; j < defs; j++) {
                        var var_def = stat.definitions[j];
                        var name = var_def.name;
                        append_var(decls, expressions, name, var_def.value);
                        if (in_loop && fn.argnames.every((argname) => argname.name != name.name)) {
                            var def = fn.variables.get(name.name);
                            var sym = make_node(AST_SymbolRef, name, name);
                            def.references.push(sym);
                            expressions.splice(pos++, 0, make_node(AST_Assign, var_def, {
                                operator: "=",
                                logical: false,
                                left: sym,
                                right: make_node(AST_Undefined, name)
                            }));
                        }
                    }
                }
            }
            function flatten_fn(returned_value) {
                var decls = [];
                var expressions = [];
                flatten_args(decls, expressions);
                flatten_vars(decls, expressions);
                expressions.push(returned_value);
                if (decls.length) {
                    const i = scope.body.indexOf(compressor.parent(level - 1)) + 1;
                    scope.body.splice(i, 0, make_node(AST_Var, fn, {
                        definitions: decls
                    }));
                }
                return expressions.map(exp => exp.clone(true));
            }
        }
        (function (def_find_defs) {
            function to_node(value, orig) {
                if (value instanceof AST_Node) {
                    if (!(value instanceof AST_Constant)) {
                        // Value may be a function, an array including functions and even a complex assign / block expression,
                        // so it should never be shared in different places.
                        // Otherwise wrong information may be used in the compression phase
                        value = value.clone(true);
                    }
                    return make_node(value.CTOR, orig, value);
                }
                if (Array.isArray(value))
                    return make_node(AST_Array, orig, {
                        elements: value.map(function (value) {
                            return to_node(value, orig);
                        })
                    });
                if (value && typeof value == "object") {
                    var props = [];
                    for (var key in value)
                        if (HOP(value, key)) {
                            props.push(make_node(AST_ObjectKeyVal, orig, {
                                key: key,
                                value: to_node(value[key], orig)
                            }));
                        }
                    return make_node(AST_Object, orig, {
                        properties: props
                    });
                }
                return make_node_from_constant(value, orig);
            }
            AST_Toplevel.DEFMETHOD("resolve_defines", function (compressor) {
                if (!compressor.option("global_defs"))
                    return this;
                this.figure_out_scope({ ie8: compressor.option("ie8") });
                return this.transform(new TreeTransformer(function (node) {
                    var def = node._find_defs(compressor, "");
                    if (!def)
                        return;
                    var level = 0, child = node, parent;
                    while (parent = this.parent(level++)) {
                        if (!(parent instanceof AST_PropAccess))
                            break;
                        if (parent.expression !== child)
                            break;
                        child = parent;
                    }
                    if (is_lhs(child, parent)) {
                        return;
                    }
                    return def;
                }));
            });
            def_find_defs(AST_Node, noop);
            def_find_defs(AST_Chain, function (compressor, suffix) {
                return this.expression._find_defs(compressor, suffix);
            });
            def_find_defs(AST_Dot, function (compressor, suffix) {
                return this.expression._find_defs(compressor, "." + this.property + suffix);
            });
            def_find_defs(AST_SymbolDeclaration, function () {
                if (!this.global())
                    return;
            });
            def_find_defs(AST_SymbolRef, function (compressor, suffix) {
                if (!this.global())
                    return;
                var defines = compressor.option("global_defs");
                var name = this.name + suffix;
                if (HOP(defines, name))
                    return to_node(defines[name], this);
            });
            def_find_defs(AST_ImportMeta, function (compressor, suffix) {
                var defines = compressor.option("global_defs");
                var name = "import.meta" + suffix;
                if (HOP(defines, name))
                    return to_node(defines[name], this);
            });
        })(function (node, func) {
            node.DEFMETHOD("_find_defs", func);
        });
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        class Compressor extends TreeWalker {
            constructor(options, { false_by_default = false, mangle_options = false }) {
                super();
                if (options.defaults !== undefined && !options.defaults)
                    false_by_default = true;
                this.options = defaults(options, {
                    arguments: false,
                    arrows: !false_by_default,
                    booleans: !false_by_default,
                    booleans_as_integers: false,
                    collapse_vars: !false_by_default,
                    comparisons: !false_by_default,
                    computed_props: !false_by_default,
                    conditionals: !false_by_default,
                    dead_code: !false_by_default,
                    defaults: true,
                    directives: !false_by_default,
                    drop_console: false,
                    drop_debugger: !false_by_default,
                    ecma: 5,
                    evaluate: !false_by_default,
                    expression: false,
                    global_defs: false,
                    hoist_funs: false,
                    hoist_props: !false_by_default,
                    hoist_vars: false,
                    ie8: false,
                    if_return: !false_by_default,
                    inline: !false_by_default,
                    join_vars: !false_by_default,
                    keep_classnames: false,
                    keep_fargs: true,
                    keep_fnames: false,
                    keep_infinity: false,
                    lhs_constants: !false_by_default,
                    loops: !false_by_default,
                    module: false,
                    negate_iife: !false_by_default,
                    passes: 1,
                    properties: !false_by_default,
                    pure_getters: !false_by_default && "strict",
                    pure_funcs: null,
                    pure_new: false,
                    reduce_funcs: !false_by_default,
                    reduce_vars: !false_by_default,
                    sequences: !false_by_default,
                    side_effects: !false_by_default,
                    switches: !false_by_default,
                    top_retain: null,
                    toplevel: !!(options && options["top_retain"]),
                    typeofs: !false_by_default,
                    unsafe: false,
                    unsafe_arrows: false,
                    unsafe_comps: false,
                    unsafe_Function: false,
                    unsafe_math: false,
                    unsafe_symbols: false,
                    unsafe_methods: false,
                    unsafe_proto: false,
                    unsafe_regexp: false,
                    unsafe_undefined: false,
                    unused: !false_by_default,
                    warnings: false // legacy
                }, true);
                var global_defs = this.options["global_defs"];
                if (typeof global_defs == "object")
                    for (var key in global_defs) {
                        if (key[0] === "@" && HOP(global_defs, key)) {
                            global_defs[key.slice(1)] = parse(global_defs[key], {
                                expression: true
                            });
                        }
                    }
                if (this.options["inline"] === true)
                    this.options["inline"] = 3;
                var pure_funcs = this.options["pure_funcs"];
                if (typeof pure_funcs == "function") {
                    this.pure_funcs = pure_funcs;
                }
                else {
                    this.pure_funcs = pure_funcs ? function (node) {
                        return !pure_funcs.includes(node.expression.print_to_string());
                    } : return_true;
                }
                var top_retain = this.options["top_retain"];
                if (top_retain instanceof RegExp) {
                    this.top_retain = function (def) {
                        return top_retain.test(def.name);
                    };
                }
                else if (typeof top_retain == "function") {
                    this.top_retain = top_retain;
                }
                else if (top_retain) {
                    if (typeof top_retain == "string") {
                        top_retain = top_retain.split(/,/);
                    }
                    this.top_retain = function (def) {
                        return top_retain.includes(def.name);
                    };
                }
                if (this.options["module"]) {
                    this.directives["use strict"] = true;
                    this.options["toplevel"] = true;
                }
                var toplevel = this.options["toplevel"];
                this.toplevel = typeof toplevel == "string" ? {
                    funcs: /funcs/.test(toplevel),
                    vars: /vars/.test(toplevel)
                } : {
                    funcs: toplevel,
                    vars: toplevel
                };
                var sequences = this.options["sequences"];
                this.sequences_limit = sequences == 1 ? 800 : sequences | 0;
                this.evaluated_regexps = new Map();
                this._toplevel = undefined;
                this._mangle_options = mangle_options
                    ? format_mangler_options(mangle_options)
                    : mangle_options;
            }
            mangle_options() {
                var nth_identifier = this._mangle_options && this._mangle_options.nth_identifier || base54;
                var module = this._mangle_options && this._mangle_options.module || this.option("module");
                return { ie8: this.option("ie8"), nth_identifier, module };
            }
            option(key) {
                return this.options[key];
            }
            exposed(def) {
                if (def.export)
                    return true;
                if (def.global)
                    for (var i = 0, len = def.orig.length; i < len; i++)
                        if (!this.toplevel[def.orig[i] instanceof AST_SymbolDefun ? "funcs" : "vars"])
                            return true;
                return false;
            }
            in_boolean_context() {
                if (!this.option("booleans"))
                    return false;
                var self = this.self();
                for (var i = 0, p; p = this.parent(i); i++) {
                    if (p instanceof AST_SimpleStatement
                        || p instanceof AST_Conditional && p.condition === self
                        || p instanceof AST_DWLoop && p.condition === self
                        || p instanceof AST_For && p.condition === self
                        || p instanceof AST_If && p.condition === self
                        || p instanceof AST_UnaryPrefix && p.operator == "!" && p.expression === self) {
                        return true;
                    }
                    if (p instanceof AST_Binary
                        && (p.operator == "&&"
                            || p.operator == "||"
                            || p.operator == "??")
                        || p instanceof AST_Conditional
                        || p.tail_node() === self) {
                        self = p;
                    }
                    else {
                        return false;
                    }
                }
            }
            in_32_bit_context() {
                if (!this.option("evaluate"))
                    return false;
                var self = this.self();
                for (var i = 0, p; p = this.parent(i); i++) {
                    if (p instanceof AST_Binary && bitwise_binop.has(p.operator)) {
                        return true;
                    }
                    if (p instanceof AST_UnaryPrefix) {
                        return p.operator === "~";
                    }
                    if (p instanceof AST_Binary
                        && (p.operator == "&&"
                            || p.operator == "||"
                            || p.operator == "??")
                        || p instanceof AST_Conditional && p.condition !== self
                        || p.tail_node() === self) {
                        self = p;
                    }
                    else {
                        return false;
                    }
                }
            }
            in_computed_key() {
                if (!this.option("evaluate"))
                    return false;
                var self = this.self();
                for (var i = 0, p; p = this.parent(i); i++) {
                    if (p instanceof AST_ObjectProperty && p.key === self) {
                        return true;
                    }
                }
                return false;
            }
            get_toplevel() {
                return this._toplevel;
            }
            compress(toplevel) {
                toplevel = toplevel.resolve_defines(this);
                this._toplevel = toplevel;
                if (this.option("expression")) {
                    this._toplevel.process_expression(true);
                }
                var passes = +this.options.passes || 1;
                var min_count = 1 / 0;
                var stopping = false;
                var mangle = this.mangle_options();
                for (var pass = 0; pass < passes; pass++) {
                    this._toplevel.figure_out_scope(mangle);
                    if (pass === 0 && this.option("drop_console")) {
                        // must be run before reduce_vars and compress pass
                        this._toplevel = this._toplevel.drop_console(this.option("drop_console"));
                    }
                    if (pass > 0 || this.option("reduce_vars")) {
                        this._toplevel.reset_opt_flags(this);
                    }
                    this._toplevel = this._toplevel.transform(this);
                    if (passes > 1) {
                        let count = 0;
                        walk(this._toplevel, () => { count++; });
                        if (count < min_count) {
                            min_count = count;
                            stopping = false;
                        }
                        else if (stopping) {
                            break;
                        }
                        else {
                            stopping = true;
                        }
                    }
                }
                if (this.option("expression")) {
                    this._toplevel.process_expression(false);
                }
                toplevel = this._toplevel;
                this._toplevel = undefined;
                return toplevel;
            }
            before(node, descend) {
                if (has_flag(node, SQUEEZED))
                    return node;
                var was_scope = false;
                if (node instanceof AST_Scope) {
                    node = node.hoist_properties(this);
                    node = node.hoist_declarations(this);
                    was_scope = true;
                }
                // Before https://github.com/mishoo/UglifyJS2/pull/1602 AST_Node.optimize()
                // would call AST_Node.transform() if a different instance of AST_Node is
                // produced after def_optimize().
                // This corrupts TreeWalker.stack, which cause AST look-ups to malfunction.
                // Migrate and defer all children's AST_Node.transform() to below, which
                // will now happen after this parent AST_Node has been properly substituted
                // thus gives a consistent AST snapshot.
                descend(node, this);
                // Existing code relies on how AST_Node.optimize() worked, and omitting the
                // following replacement call would result in degraded efficiency of both
                // output and performance.
                descend(node, this);
                var opt = node.optimize(this);
                if (was_scope && opt instanceof AST_Scope) {
                    opt.drop_unused(this);
                    descend(opt, this);
                }
                if (opt === node)
                    set_flag(opt, SQUEEZED);
                return opt;
            }
            /** Alternative to plain is_lhs() which doesn't work within .optimize() */
            is_lhs() {
                const self = this.stack[this.stack.length - 1];
                const parent = this.stack[this.stack.length - 2];
                return is_lhs(self, parent);
            }
        }
        function def_optimize(node, optimizer) {
            node.DEFMETHOD("optimize", function (compressor) {
                var self = this;
                if (has_flag(self, OPTIMIZED))
                    return self;
                if (compressor.has_directive("use asm"))
                    return self;
                var opt = optimizer(self, compressor);
                set_flag(opt, OPTIMIZED);
                return opt;
            });
        }
        def_optimize(AST_Node, function (self) {
            return self;
        });
        AST_Toplevel.DEFMETHOD("drop_console", function (options) {
            var isArray = Array.isArray(options);
            return this.transform(new TreeTransformer(function (self) {
                if (self.TYPE !== "Call") {
                    return;
                }
                var exp = self.expression;
                if (!(exp instanceof AST_PropAccess)) {
                    return;
                }
                if (isArray && options.indexOf(exp.property) === -1) {
                    return;
                }
                var name = exp.expression;
                while (name.expression) {
                    name = name.expression;
                }
                if (is_undeclared_ref(name) && name.name == "console") {
                    return make_node(AST_Undefined, self);
                }
            }));
        });
        AST_Node.DEFMETHOD("equivalent_to", function (node) {
            return equivalent_to(this, node);
        });
        AST_Scope.DEFMETHOD("process_expression", function (insert, compressor) {
            var self = this;
            var tt = new TreeTransformer(function (node) {
                if (insert && node instanceof AST_SimpleStatement) {
                    return make_node(AST_Return, node, {
                        value: node.body
                    });
                }
                if (!insert && node instanceof AST_Return) {
                    if (compressor) {
                        var value = node.value && node.value.drop_side_effect_free(compressor, true);
                        return value
                            ? make_node(AST_SimpleStatement, node, { body: value })
                            : make_node(AST_EmptyStatement, node);
                    }
                    return make_node(AST_SimpleStatement, node, {
                        body: node.value || make_node(AST_UnaryPrefix, node, {
                            operator: "void",
                            expression: make_node(AST_Number, node, {
                                value: 0
                            })
                        })
                    });
                }
                if (node instanceof AST_Class || node instanceof AST_Lambda && node !== self) {
                    return node;
                }
                if (node instanceof AST_Block) {
                    var index = node.body.length - 1;
                    if (index >= 0) {
                        node.body[index] = node.body[index].transform(tt);
                    }
                }
                else if (node instanceof AST_If) {
                    node.body = node.body.transform(tt);
                    if (node.alternative) {
                        node.alternative = node.alternative.transform(tt);
                    }
                }
                else if (node instanceof AST_With) {
                    node.body = node.body.transform(tt);
                }
                return node;
            });
            self.transform(tt);
        });
        AST_Toplevel.DEFMETHOD("reset_opt_flags", function (compressor) {
            const self = this;
            const reduce_vars = compressor.option("reduce_vars");
            const preparation = new TreeWalker(function (node, descend) {
                clear_flag(node, CLEAR_BETWEEN_PASSES);
                if (reduce_vars) {
                    if (compressor.top_retain
                        && node instanceof AST_Defun // Only functions are retained
                        && preparation.parent() === self) {
                        set_flag(node, TOP);
                    }
                    return node.reduce_vars(preparation, descend, compressor);
                }
            });
            // Stack of look-up tables to keep track of whether a `SymbolDef` has been
            // properly assigned before use:
            // - `push()` & `pop()` when visiting conditional branches
            preparation.safe_ids = Object.create(null);
            preparation.in_loop = null;
            preparation.loop_ids = new Map();
            preparation.defs_to_safe_ids = new Map();
            self.walk(preparation);
        });
        AST_Symbol.DEFMETHOD("fixed_value", function () {
            var fixed = this.thedef.fixed;
            if (!fixed || fixed instanceof AST_Node)
                return fixed;
            return fixed();
        });
        AST_SymbolRef.DEFMETHOD("is_immutable", function () {
            var orig = this.definition().orig;
            return orig.length == 1 && orig[0] instanceof AST_SymbolLambda;
        });
        function find_variable(compressor, name) {
            var scope, i = 0;
            while (scope = compressor.parent(i++)) {
                if (scope instanceof AST_Scope)
                    break;
                if (scope instanceof AST_Catch && scope.argname) {
                    scope = scope.argname.definition().scope;
                    break;
                }
            }
            return scope.find_variable(name);
        }
        var global_names = makePredicate("Array Boolean clearInterval clearTimeout console Date decodeURI decodeURIComponent encodeURI encodeURIComponent Error escape eval EvalError Function isFinite isNaN JSON Math Number parseFloat parseInt RangeError ReferenceError RegExp Object setInterval setTimeout String SyntaxError TypeError unescape URIError");
        AST_SymbolRef.DEFMETHOD("is_declared", function (compressor) {
            return !this.definition().undeclared
                || compressor.option("unsafe") && global_names.has(this.name);
        });
        /* -----[ optimizers ]----- */
        var directives = new Set(["use asm", "use strict"]);
        def_optimize(AST_Directive, function (self, compressor) {
            if (compressor.option("directives")
                && (!directives.has(self.value) || compressor.has_directive(self.value) !== self)) {
                return make_node(AST_EmptyStatement, self);
            }
            return self;
        });
        def_optimize(AST_Debugger, function (self, compressor) {
            if (compressor.option("drop_debugger"))
                return make_node(AST_EmptyStatement, self);
            return self;
        });
        def_optimize(AST_LabeledStatement, function (self, compressor) {
            if (self.body instanceof AST_Break
                && compressor.loopcontrol_target(self.body) === self.body) {
                return make_node(AST_EmptyStatement, self);
            }
            return self.label.references.length == 0 ? self.body : self;
        });
        def_optimize(AST_Block, function (self, compressor) {
            tighten_body(self.body, compressor);
            return self;
        });
        function can_be_extracted_from_if_block(node) {
            return !(node instanceof AST_Const
                || node instanceof AST_Let
                || node instanceof AST_Class);
        }
        def_optimize(AST_BlockStatement, function (self, compressor) {
            tighten_body(self.body, compressor);
            switch (self.body.length) {
                case 1:
                    if (!compressor.has_directive("use strict")
                        && compressor.parent() instanceof AST_If
                        && can_be_extracted_from_if_block(self.body[0])
                        || can_be_evicted_from_block(self.body[0])) {
                        return self.body[0];
                    }
                    break;
                case 0: return make_node(AST_EmptyStatement, self);
            }
            return self;
        });
        function opt_AST_Lambda(self, compressor) {
            tighten_body(self.body, compressor);
            if (compressor.option("side_effects")
                && self.body.length == 1
                && self.body[0] === compressor.has_directive("use strict")) {
                self.body.length = 0;
            }
            return self;
        }
        def_optimize(AST_Lambda, opt_AST_Lambda);
        AST_Scope.DEFMETHOD("hoist_declarations", function (compressor) {
            var self = this;
            if (compressor.has_directive("use asm"))
                return self;
            var hoist_funs = compressor.option("hoist_funs");
            var hoist_vars = compressor.option("hoist_vars");
            if (hoist_funs || hoist_vars) {
                var dirs = [];
                var hoisted = [];
                var vars = new Map(), vars_found = 0, var_decl = 0;
                // let's count var_decl first, we seem to waste a lot of
                // space if we hoist `var` when there's only one.
                walk(self, node => {
                    if (node instanceof AST_Scope && node !== self)
                        return true;
                    if (node instanceof AST_Var) {
                        ++var_decl;
                        return true;
                    }
                });
                hoist_vars = hoist_vars && var_decl > 1;
                var tt = new TreeTransformer(function before(node) {
                    if (node !== self) {
                        if (node instanceof AST_Directive) {
                            dirs.push(node);
                            return make_node(AST_EmptyStatement, node);
                        }
                        if (hoist_funs && node instanceof AST_Defun
                            && !(tt.parent() instanceof AST_Export)
                            && tt.parent() === self) {
                            hoisted.push(node);
                            return make_node(AST_EmptyStatement, node);
                        }
                        if (hoist_vars
                            && node instanceof AST_Var
                            && !node.definitions.some(def => def.name instanceof AST_Destructuring)) {
                            node.definitions.forEach(function (def) {
                                vars.set(def.name.name, def);
                                ++vars_found;
                            });
                            var seq = node.to_assignments(compressor);
                            var p = tt.parent();
                            if (p instanceof AST_ForIn && p.init === node) {
                                if (seq == null) {
                                    var def = node.definitions[0].name;
                                    return make_node(AST_SymbolRef, def, def);
                                }
                                return seq;
                            }
                            if (p instanceof AST_For && p.init === node) {
                                return seq;
                            }
                            if (!seq)
                                return make_node(AST_EmptyStatement, node);
                            return make_node(AST_SimpleStatement, node, {
                                body: seq
                            });
                        }
                        if (node instanceof AST_Scope)
                            return node; // to avoid descending in nested scopes
                    }
                });
                self = self.transform(tt);
                if (vars_found > 0) {
                    // collect only vars which don't show up in self's arguments list
                    var defs = [];
                    const is_lambda = self instanceof AST_Lambda;
                    const args_as_names = is_lambda ? self.args_as_names() : null;
                    vars.forEach((def, name) => {
                        if (is_lambda && args_as_names.some((x) => x.name === def.name.name)) {
                            vars.delete(name);
                        }
                        else {
                            def = def.clone();
                            def.value = null;
                            defs.push(def);
                            vars.set(name, def);
                        }
                    });
                    if (defs.length > 0) {
                        // try to merge in assignments
                        for (var i = 0; i < self.body.length;) {
                            if (self.body[i] instanceof AST_SimpleStatement) {
                                var expr = self.body[i].body, sym, assign;
                                if (expr instanceof AST_Assign
                                    && expr.operator == "="
                                    && (sym = expr.left) instanceof AST_Symbol
                                    && vars.has(sym.name)) {
                                    var def = vars.get(sym.name);
                                    if (def.value)
                                        break;
                                    def.value = expr.right;
                                    remove(defs, def);
                                    defs.push(def);
                                    self.body.splice(i, 1);
                                    continue;
                                }
                                if (expr instanceof AST_Sequence
                                    && (assign = expr.expressions[0]) instanceof AST_Assign
                                    && assign.operator == "="
                                    && (sym = assign.left) instanceof AST_Symbol
                                    && vars.has(sym.name)) {
                                    var def = vars.get(sym.name);
                                    if (def.value)
                                        break;
                                    def.value = assign.right;
                                    remove(defs, def);
                                    defs.push(def);
                                    self.body[i].body = make_sequence(expr, expr.expressions.slice(1));
                                    continue;
                                }
                            }
                            if (self.body[i] instanceof AST_EmptyStatement) {
                                self.body.splice(i, 1);
                                continue;
                            }
                            if (self.body[i] instanceof AST_BlockStatement) {
                                self.body.splice(i, 1, ...self.body[i].body);
                                continue;
                            }
                            break;
                        }
                        defs = make_node(AST_Var, self, {
                            definitions: defs
                        });
                        hoisted.push(defs);
                    }
                }
                self.body = dirs.concat(hoisted, self.body);
            }
            return self;
        });
        AST_Scope.DEFMETHOD("hoist_properties", function (compressor) {
            var self = this;
            if (!compressor.option("hoist_props") || compressor.has_directive("use asm"))
                return self;
            var top_retain = self instanceof AST_Toplevel && compressor.top_retain || return_false;
            var defs_by_id = new Map();
            var hoister = new TreeTransformer(function (node, descend) {
                if (node instanceof AST_VarDef) {
                    const sym = node.name;
                    let def;
                    let value;
                    if (sym.scope === self
                        && (def = sym.definition()).escaped != 1
                        && !def.assignments
                        && !def.direct_access
                        && !def.single_use
                        && !compressor.exposed(def)
                        && !top_retain(def)
                        && (value = sym.fixed_value()) === node.value
                        && value instanceof AST_Object
                        && !value.properties.some(prop => prop instanceof AST_Expansion || prop.computed_key())) {
                        descend(node, this);
                        const defs = new Map();
                        const assignments = [];
                        value.properties.forEach(({ key, value }) => {
                            const scope = hoister.find_scope();
                            const symbol = self.create_symbol(sym.CTOR, {
                                source: sym,
                                scope,
                                conflict_scopes: new Set([
                                    scope,
                                    ...sym.definition().references.map(ref => ref.scope)
                                ]),
                                tentative_name: sym.name + "_" + key
                            });
                            defs.set(String(key), symbol.definition());
                            assignments.push(make_node(AST_VarDef, node, {
                                name: symbol,
                                value
                            }));
                        });
                        defs_by_id.set(def.id, defs);
                        return MAP.splice(assignments);
                    }
                }
                else if (node instanceof AST_PropAccess
                    && node.expression instanceof AST_SymbolRef) {
                    const defs = defs_by_id.get(node.expression.definition().id);
                    if (defs) {
                        const def = defs.get(String(get_simple_key(node.property)));
                        const sym = make_node(AST_SymbolRef, node, {
                            name: def.name,
                            scope: node.expression.scope,
                            thedef: def
                        });
                        sym.reference({});
                        return sym;
                    }
                }
            });
            return self.transform(hoister);
        });
        def_optimize(AST_SimpleStatement, function (self, compressor) {
            if (compressor.option("side_effects")) {
                var body = self.body;
                var node = body.drop_side_effect_free(compressor, true);
                if (!node) {
                    return make_node(AST_EmptyStatement, self);
                }
                if (node !== body) {
                    return make_node(AST_SimpleStatement, self, { body: node });
                }
            }
            return self;
        });
        def_optimize(AST_While, function (self, compressor) {
            return compressor.option("loops") ? make_node(AST_For, self, self).optimize(compressor) : self;
        });
        def_optimize(AST_Do, function (self, compressor) {
            if (!compressor.option("loops"))
                return self;
            var cond = self.condition.tail_node().evaluate(compressor);
            if (!(cond instanceof AST_Node)) {
                if (cond)
                    return make_node(AST_For, self, {
                        body: make_node(AST_BlockStatement, self.body, {
                            body: [
                                self.body,
                                make_node(AST_SimpleStatement, self.condition, {
                                    body: self.condition
                                })
                            ]
                        })
                    }).optimize(compressor);
                if (!has_break_or_continue(self, compressor.parent())) {
                    return make_node(AST_BlockStatement, self.body, {
                        body: [
                            self.body,
                            make_node(AST_SimpleStatement, self.condition, {
                                body: self.condition
                            })
                        ]
                    }).optimize(compressor);
                }
            }
            return self;
        });
        function if_break_in_loop(self, compressor) {
            var first = self.body instanceof AST_BlockStatement ? self.body.body[0] : self.body;
            if (compressor.option("dead_code") && is_break(first)) {
                var body = [];
                if (self.init instanceof AST_Statement) {
                    body.push(self.init);
                }
                else if (self.init) {
                    body.push(make_node(AST_SimpleStatement, self.init, {
                        body: self.init
                    }));
                }
                if (self.condition) {
                    body.push(make_node(AST_SimpleStatement, self.condition, {
                        body: self.condition
                    }));
                }
                trim_unreachable_code(compressor, self.body, body);
                return make_node(AST_BlockStatement, self, {
                    body: body
                });
            }
            if (first instanceof AST_If) {
                if (is_break(first.body)) {
                    if (self.condition) {
                        self.condition = make_node(AST_Binary, self.condition, {
                            left: self.condition,
                            operator: "&&",
                            right: first.condition.negate(compressor),
                        });
                    }
                    else {
                        self.condition = first.condition.negate(compressor);
                    }
                    drop_it(first.alternative);
                }
                else if (is_break(first.alternative)) {
                    if (self.condition) {
                        self.condition = make_node(AST_Binary, self.condition, {
                            left: self.condition,
                            operator: "&&",
                            right: first.condition,
                        });
                    }
                    else {
                        self.condition = first.condition;
                    }
                    drop_it(first.body);
                }
            }
            return self;
            function is_break(node) {
                return node instanceof AST_Break
                    && compressor.loopcontrol_target(node) === compressor.self();
            }
            function drop_it(rest) {
                rest = as_statement_array(rest);
                if (self.body instanceof AST_BlockStatement) {
                    self.body = self.body.clone();
                    self.body.body = rest.concat(self.body.body.slice(1));
                    self.body = self.body.transform(compressor);
                }
                else {
                    self.body = make_node(AST_BlockStatement, self.body, {
                        body: rest
                    }).transform(compressor);
                }
                self = if_break_in_loop(self, compressor);
            }
        }
        def_optimize(AST_For, function (self, compressor) {
            if (!compressor.option("loops"))
                return self;
            if (compressor.option("side_effects") && self.init) {
                self.init = self.init.drop_side_effect_free(compressor);
            }
            if (self.condition) {
                var cond = self.condition.evaluate(compressor);
                if (!(cond instanceof AST_Node)) {
                    if (cond)
                        self.condition = null;
                    else if (!compressor.option("dead_code")) {
                        var orig = self.condition;
                        self.condition = make_node_from_constant(cond, self.condition);
                        self.condition = best_of_expression(self.condition.transform(compressor), orig);
                    }
                }
                if (compressor.option("dead_code")) {
                    if (cond instanceof AST_Node)
                        cond = self.condition.tail_node().evaluate(compressor);
                    if (!cond) {
                        var body = [];
                        trim_unreachable_code(compressor, self.body, body);
                        if (self.init instanceof AST_Statement) {
                            body.push(self.init);
                        }
                        else if (self.init) {
                            body.push(make_node(AST_SimpleStatement, self.init, {
                                body: self.init
                            }));
                        }
                        body.push(make_node(AST_SimpleStatement, self.condition, {
                            body: self.condition
                        }));
                        return make_node(AST_BlockStatement, self, { body: body }).optimize(compressor);
                    }
                }
            }
            return if_break_in_loop(self, compressor);
        });
        def_optimize(AST_If, function (self, compressor) {
            if (is_empty(self.alternative))
                self.alternative = null;
            if (!compressor.option("conditionals"))
                return self;
            // if condition can be statically determined, drop
            // one of the blocks.  note, statically determined implies
            // “has no side effects”; also it doesn't work for cases like
            // `x && true`, though it probably should.
            var cond = self.condition.evaluate(compressor);
            if (!compressor.option("dead_code") && !(cond instanceof AST_Node)) {
                var orig = self.condition;
                self.condition = make_node_from_constant(cond, orig);
                self.condition = best_of_expression(self.condition.transform(compressor), orig);
            }
            if (compressor.option("dead_code")) {
                if (cond instanceof AST_Node)
                    cond = self.condition.tail_node().evaluate(compressor);
                if (!cond) {
                    var body = [];
                    trim_unreachable_code(compressor, self.body, body);
                    body.push(make_node(AST_SimpleStatement, self.condition, {
                        body: self.condition
                    }));
                    if (self.alternative)
                        body.push(self.alternative);
                    return make_node(AST_BlockStatement, self, { body: body }).optimize(compressor);
                }
                else if (!(cond instanceof AST_Node)) {
                    var body = [];
                    body.push(make_node(AST_SimpleStatement, self.condition, {
                        body: self.condition
                    }));
                    body.push(self.body);
                    if (self.alternative) {
                        trim_unreachable_code(compressor, self.alternative, body);
                    }
                    return make_node(AST_BlockStatement, self, { body: body }).optimize(compressor);
                }
            }
            var negated = self.condition.negate(compressor);
            var self_condition_length = self.condition.size();
            var negated_length = negated.size();
            var negated_is_best = negated_length < self_condition_length;
            if (self.alternative && negated_is_best) {
                negated_is_best = false; // because we already do the switch here.
                // no need to swap values of self_condition_length and negated_length
                // here because they are only used in an equality comparison later on.
                self.condition = negated;
                var tmp = self.body;
                self.body = self.alternative || make_node(AST_EmptyStatement, self);
                self.alternative = tmp;
            }
            if (is_empty(self.body) && is_empty(self.alternative)) {
                return make_node(AST_SimpleStatement, self.condition, {
                    body: self.condition.clone()
                }).optimize(compressor);
            }
            if (self.body instanceof AST_SimpleStatement
                && self.alternative instanceof AST_SimpleStatement) {
                return make_node(AST_SimpleStatement, self, {
                    body: make_node(AST_Conditional, self, {
                        condition: self.condition,
                        consequent: self.body.body,
                        alternative: self.alternative.body
                    })
                }).optimize(compressor);
            }
            if (is_empty(self.alternative) && self.body instanceof AST_SimpleStatement) {
                if (self_condition_length === negated_length && !negated_is_best
                    && self.condition instanceof AST_Binary && self.condition.operator == "||") {
                    // although the code length of self.condition and negated are the same,
                    // negated does not require additional surrounding parentheses.
                    // see https://github.com/mishoo/UglifyJS2/issues/979
                    negated_is_best = true;
                }
                if (negated_is_best)
                    return make_node(AST_SimpleStatement, self, {
                        body: make_node(AST_Binary, self, {
                            operator: "||",
                            left: negated,
                            right: self.body.body
                        })
                    }).optimize(compressor);
                return make_node(AST_SimpleStatement, self, {
                    body: make_node(AST_Binary, self, {
                        operator: "&&",
                        left: self.condition,
                        right: self.body.body
                    })
                }).optimize(compressor);
            }
            if (self.body instanceof AST_EmptyStatement
                && self.alternative instanceof AST_SimpleStatement) {
                return make_node(AST_SimpleStatement, self, {
                    body: make_node(AST_Binary, self, {
                        operator: "||",
                        left: self.condition,
                        right: self.alternative.body
                    })
                }).optimize(compressor);
            }
            if (self.body instanceof AST_Exit
                && self.alternative instanceof AST_Exit
                && self.body.TYPE == self.alternative.TYPE) {
                return make_node(self.body.CTOR, self, {
                    value: make_node(AST_Conditional, self, {
                        condition: self.condition,
                        consequent: self.body.value || make_node(AST_Undefined, self.body),
                        alternative: self.alternative.value || make_node(AST_Undefined, self.alternative)
                    }).transform(compressor)
                }).optimize(compressor);
            }
            if (self.body instanceof AST_If
                && !self.body.alternative
                && !self.alternative) {
                self = make_node(AST_If, self, {
                    condition: make_node(AST_Binary, self.condition, {
                        operator: "&&",
                        left: self.condition,
                        right: self.body.condition
                    }),
                    body: self.body.body,
                    alternative: null
                });
            }
            if (aborts(self.body)) {
                if (self.alternative) {
                    var alt = self.alternative;
                    self.alternative = null;
                    return make_node(AST_BlockStatement, self, {
                        body: [self, alt]
                    }).optimize(compressor);
                }
            }
            if (aborts(self.alternative)) {
                var body = self.body;
                self.body = self.alternative;
                self.condition = negated_is_best ? negated : self.condition.negate(compressor);
                self.alternative = null;
                return make_node(AST_BlockStatement, self, {
                    body: [self, body]
                }).optimize(compressor);
            }
            return self;
        });
        def_optimize(AST_Switch, function (self, compressor) {
            if (!compressor.option("switches"))
                return self;
            var branch;
            var value = self.expression.evaluate(compressor);
            if (!(value instanceof AST_Node)) {
                var orig = self.expression;
                self.expression = make_node_from_constant(value, orig);
                self.expression = best_of_expression(self.expression.transform(compressor), orig);
            }
            if (!compressor.option("dead_code"))
                return self;
            if (value instanceof AST_Node) {
                value = self.expression.tail_node().evaluate(compressor);
            }
            var decl = [];
            var body = [];
            var default_branch;
            var exact_match;
            for (var i = 0, len = self.body.length; i < len && !exact_match; i++) {
                branch = self.body[i];
                if (branch instanceof AST_Default) {
                    if (!default_branch) {
                        default_branch = branch;
                    }
                    else {
                        eliminate_branch(branch, body[body.length - 1]);
                    }
                }
                else if (!(value instanceof AST_Node)) {
                    var exp = branch.expression.evaluate(compressor);
                    if (!(exp instanceof AST_Node) && exp !== value) {
                        eliminate_branch(branch, body[body.length - 1]);
                        continue;
                    }
                    if (exp instanceof AST_Node)
                        exp = branch.expression.tail_node().evaluate(compressor);
                    if (exp === value) {
                        exact_match = branch;
                        if (default_branch) {
                            var default_index = body.indexOf(default_branch);
                            body.splice(default_index, 1);
                            eliminate_branch(default_branch, body[default_index - 1]);
                            default_branch = null;
                        }
                    }
                }
                body.push(branch);
            }
            while (i < len)
                eliminate_branch(self.body[i++], body[body.length - 1]);
            self.body = body;
            let default_or_exact = default_branch || exact_match;
            default_branch = null;
            exact_match = null;
            // group equivalent branches so they will be located next to each other,
            // that way the next micro-optimization will merge them.
            // ** bail micro-optimization if not a simple switch case with breaks
            if (body.every((branch, i) => (branch === default_or_exact || branch.expression instanceof AST_Constant)
                && (branch.body.length === 0 || aborts(branch) || body.length - 1 === i))) {
                for (let i = 0; i < body.length; i++) {
                    const branch = body[i];
                    for (let j = i + 1; j < body.length; j++) {
                        const next = body[j];
                        if (next.body.length === 0)
                            continue;
                        const last_branch = j === (body.length - 1);
                        const equivalentBranch = branches_equivalent(next, branch, false);
                        if (equivalentBranch || (last_branch && branches_equivalent(next, branch, true))) {
                            if (!equivalentBranch && last_branch) {
                                next.body.push(make_node(AST_Break));
                            }
                            // let's find previous siblings with inert fallthrough...
                            let x = j - 1;
                            let fallthroughDepth = 0;
                            while (x > i) {
                                if (is_inert_body(body[x--])) {
                                    fallthroughDepth++;
                                }
                                else {
                                    break;
                                }
                            }
                            const plucked = body.splice(j - fallthroughDepth, 1 + fallthroughDepth);
                            body.splice(i + 1, 0, ...plucked);
                            i += plucked.length;
                        }
                    }
                }
            }
            // merge equivalent branches in a row
            for (let i = 0; i < body.length; i++) {
                let branch = body[i];
                if (branch.body.length === 0)
                    continue;
                if (!aborts(branch))
                    continue;
                for (let j = i + 1; j < body.length; i++, j++) {
                    let next = body[j];
                    if (next.body.length === 0)
                        continue;
                    if (branches_equivalent(next, branch, false)
                        || (j === body.length - 1 && branches_equivalent(next, branch, true))) {
                        branch.body = [];
                        branch = next;
                        continue;
                    }
                    break;
                }
            }
            // Prune any empty branches at the end of the switch statement.
            {
                let i = body.length - 1;
                for (; i >= 0; i--) {
                    let bbody = body[i].body;
                    if (is_break(bbody[bbody.length - 1], compressor))
                        bbody.pop();
                    if (!is_inert_body(body[i]))
                        break;
                }
                // i now points to the index of a branch that contains a body. By incrementing, it's
                // pointing to the first branch that's empty.
                i++;
                if (!default_or_exact || body.indexOf(default_or_exact) >= i) {
                    // The default behavior is to do nothing. We can take advantage of that to
                    // remove all case expressions that are side-effect free that also do
                    // nothing, since they'll default to doing nothing. But we can't remove any
                    // case expressions before one that would side-effect, since they may cause
                    // the side-effect to be skipped.
                    for (let j = body.length - 1; j >= i; j--) {
                        let branch = body[j];
                        if (branch === default_or_exact) {
                            default_or_exact = null;
                            body.pop();
                        }
                        else if (!branch.expression.has_side_effects(compressor)) {
                            body.pop();
                        }
                        else {
                            break;
                        }
                    }
                }
            }
            // Prune side-effect free branches that fall into default.
            DEFAULT: if (default_or_exact) {
                let default_index = body.indexOf(default_or_exact);
                let default_body_index = default_index;
                for (; default_body_index < body.length - 1; default_body_index++) {
                    if (!is_inert_body(body[default_body_index]))
                        break;
                }
                if (default_body_index < body.length - 1) {
                    break DEFAULT;
                }
                let side_effect_index = body.length - 1;
                for (; side_effect_index >= 0; side_effect_index--) {
                    let branch = body[side_effect_index];
                    if (branch === default_or_exact)
                        continue;
                    if (branch.expression.has_side_effects(compressor))
                        break;
                }
                // If the default behavior comes after any side-effect case expressions,
                // then we can fold all side-effect free cases into the default branch.
                // If the side-effect case is after the default, then any side-effect
                // free cases could prevent the side-effect from occurring.
                if (default_body_index > side_effect_index) {
                    let prev_body_index = default_index - 1;
                    for (; prev_body_index >= 0; prev_body_index--) {
                        if (!is_inert_body(body[prev_body_index]))
                            break;
                    }
                    let before = Math.max(side_effect_index, prev_body_index) + 1;
                    let after = default_index;
                    if (side_effect_index > default_index) {
                        // If the default falls into the same body as a side-effect
                        // case, then we need preserve that case and only prune the
                        // cases after it.
                        after = side_effect_index;
                        body[side_effect_index].body = body[default_body_index].body;
                    }
                    else {
                        // The default will be the last branch.
                        default_or_exact.body = body[default_body_index].body;
                    }
                    // Prune everything after the default (or last side-effect case)
                    // until the next case with a body.
                    body.splice(after + 1, default_body_index - after);
                    // Prune everything before the default that falls into it.
                    body.splice(before, default_index - before);
                }
            }
            // See if we can remove the switch entirely if all cases (the default) fall into the same case body.
            DEFAULT: if (default_or_exact) {
                let i = body.findIndex(branch => !is_inert_body(branch));
                let caseBody;
                // `i` is equal to one of the following:
                // - `-1`, there is no body in the switch statement.
                // - `body.length - 1`, all cases fall into the same body.
                // - anything else, there are multiple bodies in the switch.
                if (i === body.length - 1) {
                    // All cases fall into the case body.
                    let branch = body[i];
                    if (has_nested_break(self))
                        break DEFAULT;
                    // This is the last case body, and we've already pruned any breaks, so it's
                    // safe to hoist.
                    caseBody = make_node(AST_BlockStatement, branch, {
                        body: branch.body
                    });
                    branch.body = [];
                }
                else if (i !== -1) {
                    // If there are multiple bodies, then we cannot optimize anything.
                    break DEFAULT;
                }
                let sideEffect = body.find(branch => {
                    return (branch !== default_or_exact
                        && branch.expression.has_side_effects(compressor));
                });
                // If no cases cause a side-effect, we can eliminate the switch entirely.
                if (!sideEffect) {
                    return make_node(AST_BlockStatement, self, {
                        body: decl.concat(statement(self.expression), default_or_exact.expression ? statement(default_or_exact.expression) : [], caseBody || [])
                    }).optimize(compressor);
                }
                // If we're this far, either there was no body or all cases fell into the same body.
                // If there was no body, then we don't need a default branch (because the default is
                // do nothing). If there was a body, we'll extract it to after the switch, so the
                // switch's new default is to do nothing and we can still prune it.
                const default_index = body.indexOf(default_or_exact);
                body.splice(default_index, 1);
                default_or_exact = null;
                if (caseBody) {
                    // Recurse into switch statement one more time so that we can append the case body
                    // outside of the switch. This recursion will only happen once since we've pruned
                    // the default case.
                    return make_node(AST_BlockStatement, self, {
                        body: decl.concat(self, caseBody)
                    }).optimize(compressor);
                }
                // If we fall here, there is a default branch somewhere, there are no case bodies,
                // and there's a side-effect somewhere. Just let the below paths take care of it.
            }
            if (body.length > 0) {
                body[0].body = decl.concat(body[0].body);
            }
            if (body.length == 0) {
                return make_node(AST_BlockStatement, self, {
                    body: decl.concat(statement(self.expression))
                }).optimize(compressor);
            }
            if (body.length == 1 && !has_nested_break(self)) {
                // This is the last case body, and we've already pruned any breaks, so it's
                // safe to hoist.
                let branch = body[0];
                return make_node(AST_If, self, {
                    condition: make_node(AST_Binary, self, {
                        operator: "===",
                        left: self.expression,
                        right: branch.expression,
                    }),
                    body: make_node(AST_BlockStatement, branch, {
                        body: branch.body
                    }),
                    alternative: null
                }).optimize(compressor);
            }
            if (body.length === 2 && default_or_exact && !has_nested_break(self)) {
                let branch = body[0] === default_or_exact ? body[1] : body[0];
                let exact_exp = default_or_exact.expression && statement(default_or_exact.expression);
                if (aborts(body[0])) {
                    // Only the first branch body could have a break (at the last statement)
                    let first = body[0];
                    if (is_break(first.body[first.body.length - 1], compressor)) {
                        first.body.pop();
                    }
                    return make_node(AST_If, self, {
                        condition: make_node(AST_Binary, self, {
                            operator: "===",
                            left: self.expression,
                            right: branch.expression,
                        }),
                        body: make_node(AST_BlockStatement, branch, {
                            body: branch.body
                        }),
                        alternative: make_node(AST_BlockStatement, default_or_exact, {
                            body: [].concat(exact_exp || [], default_or_exact.body)
                        })
                    }).optimize(compressor);
                }
                let operator = "===";
                let consequent = make_node(AST_BlockStatement, branch, {
                    body: branch.body,
                });
                let always = make_node(AST_BlockStatement, default_or_exact, {
                    body: [].concat(exact_exp || [], default_or_exact.body)
                });
                if (body[0] === default_or_exact) {
                    operator = "!==";
                    let tmp = always;
                    always = consequent;
                    consequent = tmp;
                }
                return make_node(AST_BlockStatement, self, {
                    body: [
                        make_node(AST_If, self, {
                            condition: make_node(AST_Binary, self, {
                                operator: operator,
                                left: self.expression,
                                right: branch.expression,
                            }),
                            body: consequent,
                            alternative: null
                        })
                    ].concat(always)
                }).optimize(compressor);
            }
            return self;
            function eliminate_branch(branch, prev) {
                if (prev && !aborts(prev)) {
                    prev.body = prev.body.concat(branch.body);
                }
                else {
                    trim_unreachable_code(compressor, branch, decl);
                }
            }
            function branches_equivalent(branch, prev, insertBreak) {
                let bbody = branch.body;
                let pbody = prev.body;
                if (insertBreak) {
                    bbody = bbody.concat(make_node(AST_Break));
                }
                if (bbody.length !== pbody.length)
                    return false;
                let bblock = make_node(AST_BlockStatement, branch, { body: bbody });
                let pblock = make_node(AST_BlockStatement, prev, { body: pbody });
                return bblock.equivalent_to(pblock);
            }
            function statement(expression) {
                return make_node(AST_SimpleStatement, expression, {
                    body: expression
                });
            }
            function has_nested_break(root) {
                let has_break = false;
                let tw = new TreeWalker(node => {
                    if (has_break)
                        return true;
                    if (node instanceof AST_Lambda)
                        return true;
                    if (node instanceof AST_SimpleStatement)
                        return true;
                    if (!is_break(node, tw))
                        return;
                    let parent = tw.parent();
                    if (parent instanceof AST_SwitchBranch
                        && parent.body[parent.body.length - 1] === node) {
                        return;
                    }
                    has_break = true;
                });
                root.walk(tw);
                return has_break;
            }
            function is_break(node, stack) {
                return node instanceof AST_Break
                    && stack.loopcontrol_target(node) === self;
            }
            function is_inert_body(branch) {
                return !aborts(branch) && !make_node(AST_BlockStatement, branch, {
                    body: branch.body
                }).has_side_effects(compressor);
            }
        });
        def_optimize(AST_Try, function (self, compressor) {
            if (self.bcatch && self.bfinally && self.bfinally.body.every(is_empty))
                self.bfinally = null;
            if (compressor.option("dead_code") && self.body.body.every(is_empty)) {
                var body = [];
                if (self.bcatch) {
                    trim_unreachable_code(compressor, self.bcatch, body);
                }
                if (self.bfinally)
                    body.push(...self.bfinally.body);
                return make_node(AST_BlockStatement, self, {
                    body: body
                }).optimize(compressor);
            }
            return self;
        });
        AST_Definitions.DEFMETHOD("to_assignments", function (compressor) {
            var reduce_vars = compressor.option("reduce_vars");
            var assignments = [];
            for (const def of this.definitions) {
                if (def.value) {
                    var name = make_node(AST_SymbolRef, def.name, def.name);
                    assignments.push(make_node(AST_Assign, def, {
                        operator: "=",
                        logical: false,
                        left: name,
                        right: def.value
                    }));
                    if (reduce_vars)
                        name.definition().fixed = false;
                }
                const thedef = def.name.definition();
                thedef.eliminated++;
                thedef.replaced--;
            }
            if (assignments.length == 0)
                return null;
            return make_sequence(this, assignments);
        });
        def_optimize(AST_Definitions, function (self) {
            if (self.definitions.length == 0) {
                return make_node(AST_EmptyStatement, self);
            }
            return self;
        });
        def_optimize(AST_VarDef, function (self, compressor) {
            if (self.name instanceof AST_SymbolLet
                && self.value != null
                && is_undefined(self.value, compressor)) {
                self.value = null;
            }
            return self;
        });
        def_optimize(AST_Import, function (self) {
            return self;
        });
        def_optimize(AST_Call, function (self, compressor) {
            var exp = self.expression;
            var fn = exp;
            inline_array_like_spread(self.args);
            var simple_args = self.args.every((arg) => !(arg instanceof AST_Expansion));
            if (compressor.option("reduce_vars") && fn instanceof AST_SymbolRef) {
                fn = fn.fixed_value();
            }
            var is_func = fn instanceof AST_Lambda;
            if (is_func && fn.pinned())
                return self;
            if (compressor.option("unused")
                && simple_args
                && is_func
                && !fn.uses_arguments) {
                var pos = 0, last = 0;
                for (var i = 0, len = self.args.length; i < len; i++) {
                    if (fn.argnames[i] instanceof AST_Expansion) {
                        if (has_flag(fn.argnames[i].expression, UNUSED))
                            while (i < len) {
                                var node = self.args[i++].drop_side_effect_free(compressor);
                                if (node) {
                                    self.args[pos++] = node;
                                }
                            }
                        else
                            while (i < len) {
                                self.args[pos++] = self.args[i++];
                            }
                        last = pos;
                        break;
                    }
                    var trim = i >= fn.argnames.length;
                    if (trim || has_flag(fn.argnames[i], UNUSED)) {
                        var node = self.args[i].drop_side_effect_free(compressor);
                        if (node) {
                            self.args[pos++] = node;
                        }
                        else if (!trim) {
                            self.args[pos++] = make_node(AST_Number, self.args[i], {
                                value: 0
                            });
                            continue;
                        }
                    }
                    else {
                        self.args[pos++] = self.args[i];
                    }
                    last = pos;
                }
                self.args.length = last;
            }
            if (compressor.option("unsafe") && !exp.contains_optional()) {
                if (exp instanceof AST_Dot && exp.start.value === "Array" && exp.property === "from" && self.args.length === 1) {
                    const [argument] = self.args;
                    if (argument instanceof AST_Array) {
                        return make_node(AST_Array, argument, {
                            elements: argument.elements
                        }).optimize(compressor);
                    }
                }
                if (is_undeclared_ref(exp))
                    switch (exp.name) {
                        case "Array":
                            if (self.args.length != 1) {
                                return make_node(AST_Array, self, {
                                    elements: self.args
                                }).optimize(compressor);
                            }
                            else if (self.args[0] instanceof AST_Number && self.args[0].value <= 11) {
                                const elements = [];
                                for (let i = 0; i < self.args[0].value; i++)
                                    elements.push(new AST_Hole);
                                return new AST_Array({ elements });
                            }
                            break;
                        case "Object":
                            if (self.args.length == 0) {
                                return make_node(AST_Object, self, {
                                    properties: []
                                });
                            }
                            break;
                        case "String":
                            if (self.args.length == 0)
                                return make_node(AST_String, self, {
                                    value: ""
                                });
                            if (self.args.length <= 1)
                                return make_node(AST_Binary, self, {
                                    left: self.args[0],
                                    operator: "+",
                                    right: make_node(AST_String, self, { value: "" })
                                }).optimize(compressor);
                            break;
                        case "Number":
                            if (self.args.length == 0)
                                return make_node(AST_Number, self, {
                                    value: 0
                                });
                            if (self.args.length == 1 && compressor.option("unsafe_math")) {
                                return make_node(AST_UnaryPrefix, self, {
                                    expression: self.args[0],
                                    operator: "+"
                                }).optimize(compressor);
                            }
                            break;
                        case "Symbol":
                            if (self.args.length == 1 && self.args[0] instanceof AST_String && compressor.option("unsafe_symbols"))
                                self.args.length = 0;
                            break;
                        case "Boolean":
                            if (self.args.length == 0)
                                return make_node(AST_False, self);
                            if (self.args.length == 1)
                                return make_node(AST_UnaryPrefix, self, {
                                    expression: make_node(AST_UnaryPrefix, self, {
                                        expression: self.args[0],
                                        operator: "!"
                                    }),
                                    operator: "!"
                                }).optimize(compressor);
                            break;
                        case "RegExp":
                            var params = [];
                            if (self.args.length >= 1
                                && self.args.length <= 2
                                && self.args.every((arg) => {
                                    var value = arg.evaluate(compressor);
                                    params.push(value);
                                    return arg !== value;
                                })
                                && regexp_is_safe(params[0])) {
                                let [source, flags] = params;
                                source = regexp_source_fix(new RegExp(source).source);
                                const rx = make_node(AST_RegExp, self, {
                                    value: { source, flags }
                                });
                                if (rx._eval(compressor) !== rx) {
                                    return rx;
                                }
                            }
                            break;
                    }
                else if (exp instanceof AST_Dot)
                    switch (exp.property) {
                        case "toString":
                            if (self.args.length == 0 && !exp.expression.may_throw_on_access(compressor)) {
                                return make_node(AST_Binary, self, {
                                    left: make_node(AST_String, self, { value: "" }),
                                    operator: "+",
                                    right: exp.expression
                                }).optimize(compressor);
                            }
                            break;
                        case "join":
                            if (exp.expression instanceof AST_Array)
                                EXIT: {
                                    var separator;
                                    if (self.args.length > 0) {
                                        separator = self.args[0].evaluate(compressor);
                                        if (separator === self.args[0])
                                            break EXIT; // not a constant
                                    }
                                    var elements = [];
                                    var consts = [];
                                    for (var i = 0, len = exp.expression.elements.length; i < len; i++) {
                                        var el = exp.expression.elements[i];
                                        if (el instanceof AST_Expansion)
                                            break EXIT;
                                        var value = el.evaluate(compressor);
                                        if (value !== el) {
                                            consts.push(value);
                                        }
                                        else {
                                            if (consts.length > 0) {
                                                elements.push(make_node(AST_String, self, {
                                                    value: consts.join(separator)
                                                }));
                                                consts.length = 0;
                                            }
                                            elements.push(el);
                                        }
                                    }
                                    if (consts.length > 0) {
                                        elements.push(make_node(AST_String, self, {
                                            value: consts.join(separator)
                                        }));
                                    }
                                    if (elements.length == 0)
                                        return make_node(AST_String, self, { value: "" });
                                    if (elements.length == 1) {
                                        if (elements[0].is_string(compressor)) {
                                            return elements[0];
                                        }
                                        return make_node(AST_Binary, elements[0], {
                                            operator: "+",
                                            left: make_node(AST_String, self, { value: "" }),
                                            right: elements[0]
                                        });
                                    }
                                    if (separator == "") {
                                        var first;
                                        if (elements[0].is_string(compressor)
                                            || elements[1].is_string(compressor)) {
                                            first = elements.shift();
                                        }
                                        else {
                                            first = make_node(AST_String, self, { value: "" });
                                        }
                                        return elements.reduce(function (prev, el) {
                                            return make_node(AST_Binary, el, {
                                                operator: "+",
                                                left: prev,
                                                right: el
                                            });
                                        }, first).optimize(compressor);
                                    }
                                    // need this awkward cloning to not affect original element
                                    // best_of will decide which one to get through.
                                    var node = self.clone();
                                    node.expression = node.expression.clone();
                                    node.expression.expression = node.expression.expression.clone();
                                    node.expression.expression.elements = elements;
                                    return best_of(compressor, self, node);
                                }
                            break;
                        case "charAt":
                            if (exp.expression.is_string(compressor)) {
                                var arg = self.args[0];
                                var index = arg ? arg.evaluate(compressor) : 0;
                                if (index !== arg) {
                                    return make_node(AST_Sub, exp, {
                                        expression: exp.expression,
                                        property: make_node_from_constant(index | 0, arg || exp)
                                    }).optimize(compressor);
                                }
                            }
                            break;
                        case "apply":
                            if (self.args.length == 2 && self.args[1] instanceof AST_Array) {
                                var args = self.args[1].elements.slice();
                                args.unshift(self.args[0]);
                                return make_node(AST_Call, self, {
                                    expression: make_node(AST_Dot, exp, {
                                        expression: exp.expression,
                                        optional: false,
                                        property: "call"
                                    }),
                                    args: args
                                }).optimize(compressor);
                            }
                            break;
                        case "call":
                            var func = exp.expression;
                            if (func instanceof AST_SymbolRef) {
                                func = func.fixed_value();
                            }
                            if (func instanceof AST_Lambda && !func.contains_this()) {
                                return (self.args.length ? make_sequence(this, [
                                    self.args[0],
                                    make_node(AST_Call, self, {
                                        expression: exp.expression,
                                        args: self.args.slice(1)
                                    })
                                ]) : make_node(AST_Call, self, {
                                    expression: exp.expression,
                                    args: []
                                })).optimize(compressor);
                            }
                            break;
                    }
            }
            if (compressor.option("unsafe_Function")
                && is_undeclared_ref(exp)
                && exp.name == "Function") {
                // new Function() => function(){}
                if (self.args.length == 0)
                    return make_node(AST_Function, self, {
                        argnames: [],
                        body: []
                    }).optimize(compressor);
                if (self.args.every((x) => x instanceof AST_String)) {
                    // quite a corner-case, but we can handle it:
                    //   https://github.com/mishoo/UglifyJS2/issues/203
                    // if the code argument is a constant, then we can minify it.
                    try {
                        var code = "n(function(" + self.args.slice(0, -1).map(function (arg) {
                            return arg.value;
                        }).join(",") + "){" + self.args[self.args.length - 1].value + "})";
                        var ast = parse(code);
                        var mangle = compressor.mangle_options();
                        ast.figure_out_scope(mangle);
                        var comp = new Compressor(compressor.options, {
                            mangle_options: compressor._mangle_options
                        });
                        ast = ast.transform(comp);
                        ast.figure_out_scope(mangle);
                        ast.compute_char_frequency(mangle);
                        ast.mangle_names(mangle);
                        var fun;
                        walk(ast, node => {
                            if (is_func_expr(node)) {
                                fun = node;
                                return walk_abort;
                            }
                        });
                        var code = OutputStream();
                        AST_BlockStatement.prototype._codegen.call(fun, fun, code);
                        self.args = [
                            make_node(AST_String, self, {
                                value: fun.argnames.map(function (arg) {
                                    return arg.print_to_string();
                                }).join(",")
                            }),
                            make_node(AST_String, self.args[self.args.length - 1], {
                                value: code.get().replace(/^{|}$/g, "")
                            })
                        ];
                        return self;
                    }
                    catch (ex) {
                        if (!(ex instanceof JS_Parse_Error)) {
                            throw ex;
                        }
                        // Otherwise, it crashes at runtime. Or maybe it's nonstandard syntax.
                    }
                }
            }
            return inline_into_call(self, compressor);
        });
        /** Does this node contain optional property access or optional call? */
        AST_Node.DEFMETHOD("contains_optional", function () {
            if (this instanceof AST_PropAccess
                || this instanceof AST_Call
                || this instanceof AST_Chain) {
                if (this.optional) {
                    return true;
                }
                else {
                    return this.expression.contains_optional();
                }
            }
            else {
                return false;
            }
        });
        def_optimize(AST_New, function (self, compressor) {
            if (compressor.option("unsafe") &&
                is_undeclared_ref(self.expression) &&
                ["Object", "RegExp", "Function", "Error", "Array"].includes(self.expression.name))
                return make_node(AST_Call, self, self).transform(compressor);
            return self;
        });
        def_optimize(AST_Sequence, function (self, compressor) {
            if (!compressor.option("side_effects"))
                return self;
            var expressions = [];
            filter_for_side_effects();
            var end = expressions.length - 1;
            trim_right_for_undefined();
            if (end == 0) {
                self = maintain_this_binding(compressor.parent(), compressor.self(), expressions[0]);
                if (!(self instanceof AST_Sequence))
                    self = self.optimize(compressor);
                return self;
            }
            self.expressions = expressions;
            return self;
            function filter_for_side_effects() {
                var first = first_in_statement(compressor);
                var last = self.expressions.length - 1;
                self.expressions.forEach(function (expr, index) {
                    if (index < last)
                        expr = expr.drop_side_effect_free(compressor, first);
                    if (expr) {
                        merge_sequence(expressions, expr);
                        first = false;
                    }
                });
            }
            function trim_right_for_undefined() {
                while (end > 0 && is_undefined(expressions[end], compressor))
                    end--;
                if (end < expressions.length - 1) {
                    expressions[end] = make_node(AST_UnaryPrefix, self, {
                        operator: "void",
                        expression: expressions[end]
                    });
                    expressions.length = end + 1;
                }
            }
        });
        AST_Unary.DEFMETHOD("lift_sequences", function (compressor) {
            if (compressor.option("sequences")) {
                if (this.expression instanceof AST_Sequence) {
                    var x = this.expression.expressions.slice();
                    var e = this.clone();
                    e.expression = x.pop();
                    x.push(e);
                    return make_sequence(this, x).optimize(compressor);
                }
            }
            return this;
        });
        def_optimize(AST_UnaryPostfix, function (self, compressor) {
            return self.lift_sequences(compressor);
        });
        def_optimize(AST_UnaryPrefix, function (self, compressor) {
            var e = self.expression;
            if (self.operator == "delete" &&
                !(e instanceof AST_SymbolRef ||
                    e instanceof AST_PropAccess ||
                    e instanceof AST_Chain ||
                    is_identifier_atom(e))) {
                return make_sequence(self, [e, make_node(AST_True, self)]).optimize(compressor);
            }
            var seq = self.lift_sequences(compressor);
            if (seq !== self) {
                return seq;
            }
            if (compressor.option("side_effects") && self.operator == "void") {
                e = e.drop_side_effect_free(compressor);
                if (e) {
                    self.expression = e;
                    return self;
                }
                else {
                    return make_node(AST_Undefined, self).optimize(compressor);
                }
            }
            if (compressor.in_boolean_context()) {
                switch (self.operator) {
                    case "!":
                        if (e instanceof AST_UnaryPrefix && e.operator == "!") {
                            // !!foo ==> foo, if we're in boolean context
                            return e.expression;
                        }
                        if (e instanceof AST_Binary) {
                            self = best_of(compressor, self, e.negate(compressor, first_in_statement(compressor)));
                        }
                        break;
                    case "typeof":
                        // typeof always returns a non-empty string, thus it's
                        // always true in booleans
                        // And we don't need to check if it's undeclared, because in typeof, that's OK
                        return (e instanceof AST_SymbolRef ? make_node(AST_True, self) : make_sequence(self, [
                            e,
                            make_node(AST_True, self)
                        ])).optimize(compressor);
                }
            }
            if (self.operator == "-" && e instanceof AST_Infinity) {
                e = e.transform(compressor);
            }
            if (e instanceof AST_Binary
                && (self.operator == "+" || self.operator == "-")
                && (e.operator == "*" || e.operator == "/" || e.operator == "%")) {
                return make_node(AST_Binary, self, {
                    operator: e.operator,
                    left: make_node(AST_UnaryPrefix, e.left, {
                        operator: self.operator,
                        expression: e.left
                    }),
                    right: e.right
                });
            }
            if (compressor.option("evaluate")) {
                // ~~x => x (in 32-bit context)
                // ~~{32 bit integer} => {32 bit integer}
                if (self.operator === "~"
                    && self.expression instanceof AST_UnaryPrefix
                    && self.expression.operator === "~"
                    && (compressor.in_32_bit_context() || self.expression.expression.is_32_bit_integer())) {
                    return self.expression.expression;
                }
                // ~(x ^ y) => x ^ ~y
                if (self.operator === "~"
                    && e instanceof AST_Binary
                    && e.operator === "^") {
                    if (e.left instanceof AST_UnaryPrefix && e.left.operator === "~") {
                        // ~(~x ^ y) => x ^ y
                        e.left = e.left.bitwise_negate(true);
                    }
                    else {
                        e.right = e.right.bitwise_negate(true);
                    }
                    return e;
                }
            }
            if (self.operator != "-"
                // avoid infinite recursion of numerals
                || !(e instanceof AST_Number || e instanceof AST_Infinity || e instanceof AST_BigInt)) {
                var ev = self.evaluate(compressor);
                if (ev !== self) {
                    ev = make_node_from_constant(ev, self).optimize(compressor);
                    return best_of(compressor, ev, self);
                }
            }
            return self;
        });
        AST_Binary.DEFMETHOD("lift_sequences", function (compressor) {
            if (compressor.option("sequences")) {
                if (this.left instanceof AST_Sequence) {
                    var x = this.left.expressions.slice();
                    var e = this.clone();
                    e.left = x.pop();
                    x.push(e);
                    return make_sequence(this, x).optimize(compressor);
                }
                if (this.right instanceof AST_Sequence && !this.left.has_side_effects(compressor)) {
                    var assign = this.operator == "=" && this.left instanceof AST_SymbolRef;
                    var x = this.right.expressions;
                    var last = x.length - 1;
                    for (var i = 0; i < last; i++) {
                        if (!assign && x[i].has_side_effects(compressor))
                            break;
                    }
                    if (i == last) {
                        x = x.slice();
                        var e = this.clone();
                        e.right = x.pop();
                        x.push(e);
                        return make_sequence(this, x).optimize(compressor);
                    }
                    else if (i > 0) {
                        var e = this.clone();
                        e.right = make_sequence(this.right, x.slice(i));
                        x = x.slice(0, i);
                        x.push(e);
                        return make_sequence(this, x).optimize(compressor);
                    }
                }
            }
            return this;
        });
        var commutativeOperators = makePredicate("== === != !== * & | ^");
        function is_object(node) {
            return node instanceof AST_Array
                || node instanceof AST_Lambda
                || node instanceof AST_Object
                || node instanceof AST_Class;
        }
        def_optimize(AST_Binary, function (self, compressor) {
            function reversible() {
                return self.left.is_constant()
                    || self.right.is_constant()
                    || !self.left.has_side_effects(compressor)
                        && !self.right.has_side_effects(compressor);
            }
            function reverse(op) {
                if (reversible()) {
                    if (op)
                        self.operator = op;
                    var tmp = self.left;
                    self.left = self.right;
                    self.right = tmp;
                }
            }
            if (compressor.option("lhs_constants") && commutativeOperators.has(self.operator)) {
                if (self.right.is_constant()
                    && !self.left.is_constant()) {
                    // if right is a constant, whatever side effects the
                    // left side might have could not influence the
                    // result.  hence, force switch.
                    if (!(self.left instanceof AST_Binary
                        && PRECEDENCE[self.left.operator] >= PRECEDENCE[self.operator])) {
                        reverse();
                    }
                }
            }
            self = self.lift_sequences(compressor);
            if (compressor.option("comparisons"))
                switch (self.operator) {
                    case "===":
                    case "!==":
                        var is_strict_comparison = true;
                        if ((self.left.is_string(compressor) && self.right.is_string(compressor)) ||
                            (self.left.is_number(compressor) && self.right.is_number(compressor)) ||
                            (self.left.is_boolean() && self.right.is_boolean()) ||
                            self.left.equivalent_to(self.right)) {
                            self.operator = self.operator.substr(0, 2);
                        }
                    // XXX: intentionally falling down to the next case
                    case "==":
                    case "!=":
                        // void 0 == x => null == x
                        if (!is_strict_comparison && is_undefined(self.left, compressor)) {
                            self.left = make_node(AST_Null, self.left);
                            // x == void 0 => x == null
                        }
                        else if (!is_strict_comparison && is_undefined(self.right, compressor)) {
                            self.right = make_node(AST_Null, self.right);
                        }
                        else if (compressor.option("typeofs")
                            // "undefined" == typeof x => undefined === x
                            && self.left instanceof AST_String
                            && self.left.value == "undefined"
                            && self.right instanceof AST_UnaryPrefix
                            && self.right.operator == "typeof") {
                            var expr = self.right.expression;
                            if (expr instanceof AST_SymbolRef ? expr.is_declared(compressor)
                                : !(expr instanceof AST_PropAccess && compressor.option("ie8"))) {
                                self.right = expr;
                                self.left = make_node(AST_Undefined, self.left).optimize(compressor);
                                if (self.operator.length == 2)
                                    self.operator += "=";
                            }
                        }
                        else if (compressor.option("typeofs")
                            // typeof x === "undefined" => x === undefined
                            && self.left instanceof AST_UnaryPrefix
                            && self.left.operator == "typeof"
                            && self.right instanceof AST_String
                            && self.right.value == "undefined") {
                            var expr = self.left.expression;
                            if (expr instanceof AST_SymbolRef ? expr.is_declared(compressor)
                                : !(expr instanceof AST_PropAccess && compressor.option("ie8"))) {
                                self.left = expr;
                                self.right = make_node(AST_Undefined, self.right).optimize(compressor);
                                if (self.operator.length == 2)
                                    self.operator += "=";
                            }
                        }
                        else if (self.left instanceof AST_SymbolRef
                            // obj !== obj => false
                            && self.right instanceof AST_SymbolRef
                            && self.left.definition() === self.right.definition()
                            && is_object(self.left.fixed_value())) {
                            return make_node(self.operator[0] == "=" ? AST_True : AST_False, self);
                        }
                        else if (self.left.is_32_bit_integer() && self.right.is_32_bit_integer()) {
                            const not = node => make_node(AST_UnaryPrefix, node, {
                                operator: "!",
                                expression: node
                            });
                            const booleanify = (node, truthy) => {
                                if (truthy) {
                                    return compressor.in_boolean_context()
                                        ? node
                                        : not(not(node));
                                }
                                else {
                                    return not(node);
                                }
                            };
                            // The only falsy 32-bit integer is 0
                            if (self.left instanceof AST_Number && self.left.value === 0) {
                                return booleanify(self.right, self.operator[0] === "!");
                            }
                            if (self.right instanceof AST_Number && self.right.value === 0) {
                                return booleanify(self.left, self.operator[0] === "!");
                            }
                            // Mask all-bits check
                            // (x & 0xFF) != 0xFF => !(~x & 0xFF)
                            let and_op, x, mask;
                            if ((and_op =
                                self.left instanceof AST_Binary ? self.left
                                    : self.right instanceof AST_Binary ? self.right : null)
                                && (mask = and_op === self.left ? self.right : self.left)
                                && and_op.operator === "&"
                                && mask instanceof AST_Number
                                && mask.is_32_bit_integer()
                                && (x =
                                    and_op.left.equivalent_to(mask) ? and_op.right
                                        : and_op.right.equivalent_to(mask) ? and_op.left : null)) {
                                let optimized = booleanify(make_node(AST_Binary, self, {
                                    operator: "&",
                                    left: mask,
                                    right: make_node(AST_UnaryPrefix, self, {
                                        operator: "~",
                                        expression: x
                                    })
                                }), self.operator[0] === "!");
                                return best_of(compressor, optimized, self);
                            }
                        }
                        break;
                    case "&&":
                    case "||":
                        var lhs = self.left;
                        if (lhs.operator == self.operator) {
                            lhs = lhs.right;
                        }
                        if (lhs instanceof AST_Binary
                            && lhs.operator == (self.operator == "&&" ? "!==" : "===")
                            && self.right instanceof AST_Binary
                            && lhs.operator == self.right.operator
                            && (is_undefined(lhs.left, compressor) && self.right.left instanceof AST_Null
                                || lhs.left instanceof AST_Null && is_undefined(self.right.left, compressor))
                            && !lhs.right.has_side_effects(compressor)
                            && lhs.right.equivalent_to(self.right.right)) {
                            var combined = make_node(AST_Binary, self, {
                                operator: lhs.operator.slice(0, -1),
                                left: make_node(AST_Null, self),
                                right: lhs.right
                            });
                            if (lhs !== self.left) {
                                combined = make_node(AST_Binary, self, {
                                    operator: self.operator,
                                    left: self.left.left,
                                    right: combined
                                });
                            }
                            return combined;
                        }
                        break;
                }
            if (self.operator == "+" && compressor.in_boolean_context()) {
                var ll = self.left.evaluate(compressor);
                var rr = self.right.evaluate(compressor);
                if (ll && typeof ll == "string") {
                    return make_sequence(self, [
                        self.right,
                        make_node(AST_True, self)
                    ]).optimize(compressor);
                }
                if (rr && typeof rr == "string") {
                    return make_sequence(self, [
                        self.left,
                        make_node(AST_True, self)
                    ]).optimize(compressor);
                }
            }
            if (compressor.option("comparisons") && self.is_boolean()) {
                if (!(compressor.parent() instanceof AST_Binary)
                    || compressor.parent() instanceof AST_Assign) {
                    var negated = make_node(AST_UnaryPrefix, self, {
                        operator: "!",
                        expression: self.negate(compressor, first_in_statement(compressor))
                    });
                    self = best_of(compressor, self, negated);
                }
                if (compressor.option("unsafe_comps")) {
                    switch (self.operator) {
                        case "<":
                            reverse(">");
                            break;
                        case "<=":
                            reverse(">=");
                            break;
                    }
                }
            }
            if (self.operator == "+") {
                if (self.right instanceof AST_String
                    && self.right.getValue() == ""
                    && self.left.is_string(compressor)) {
                    return self.left;
                }
                if (self.left instanceof AST_String
                    && self.left.getValue() == ""
                    && self.right.is_string(compressor)) {
                    return self.right;
                }
                if (self.left instanceof AST_Binary
                    && self.left.operator == "+"
                    && self.left.left instanceof AST_String
                    && self.left.left.getValue() == ""
                    && self.right.is_string(compressor)) {
                    self.left = self.left.right;
                    return self;
                }
            }
            if (compressor.option("evaluate")) {
                switch (self.operator) {
                    case "&&":
                        var ll = has_flag(self.left, TRUTHY)
                            ? true
                            : has_flag(self.left, FALSY)
                                ? false
                                : self.left.evaluate(compressor);
                        if (!ll) {
                            return maintain_this_binding(compressor.parent(), compressor.self(), self.left).optimize(compressor);
                        }
                        else if (!(ll instanceof AST_Node)) {
                            return make_sequence(self, [self.left, self.right]).optimize(compressor);
                        }
                        var rr = self.right.evaluate(compressor);
                        if (!rr) {
                            if (compressor.in_boolean_context()) {
                                return make_sequence(self, [
                                    self.left,
                                    make_node(AST_False, self)
                                ]).optimize(compressor);
                            }
                            else {
                                set_flag(self, FALSY);
                            }
                        }
                        else if (!(rr instanceof AST_Node)) {
                            var parent = compressor.parent();
                            if (parent.operator == "&&" && parent.left === compressor.self() || compressor.in_boolean_context()) {
                                return self.left.optimize(compressor);
                            }
                        }
                        // x || false && y ---> x ? y : false
                        if (self.left.operator == "||") {
                            var lr = self.left.right.evaluate(compressor);
                            if (!lr)
                                return make_node(AST_Conditional, self, {
                                    condition: self.left.left,
                                    consequent: self.right,
                                    alternative: self.left.right
                                }).optimize(compressor);
                        }
                        break;
                    case "||":
                        var ll = has_flag(self.left, TRUTHY)
                            ? true
                            : has_flag(self.left, FALSY)
                                ? false
                                : self.left.evaluate(compressor);
                        if (!ll) {
                            return make_sequence(self, [self.left, self.right]).optimize(compressor);
                        }
                        else if (!(ll instanceof AST_Node)) {
                            return maintain_this_binding(compressor.parent(), compressor.self(), self.left).optimize(compressor);
                        }
                        var rr = self.right.evaluate(compressor);
                        if (!rr) {
                            var parent = compressor.parent();
                            if (parent.operator == "||" && parent.left === compressor.self() || compressor.in_boolean_context()) {
                                return self.left.optimize(compressor);
                            }
                        }
                        else if (!(rr instanceof AST_Node)) {
                            if (compressor.in_boolean_context()) {
                                return make_sequence(self, [
                                    self.left,
                                    make_node(AST_True, self)
                                ]).optimize(compressor);
                            }
                            else {
                                set_flag(self, TRUTHY);
                            }
                        }
                        if (self.left.operator == "&&") {
                            var lr = self.left.right.evaluate(compressor);
                            if (lr && !(lr instanceof AST_Node))
                                return make_node(AST_Conditional, self, {
                                    condition: self.left.left,
                                    consequent: self.left.right,
                                    alternative: self.right
                                }).optimize(compressor);
                        }
                        break;
                    case "??":
                        if (is_nullish(self.left, compressor)) {
                            return self.right;
                        }
                        var ll = self.left.evaluate(compressor);
                        if (!(ll instanceof AST_Node)) {
                            // if we know the value for sure we can simply compute right away.
                            return ll == null ? self.right : self.left;
                        }
                        if (compressor.in_boolean_context()) {
                            const rr = self.right.evaluate(compressor);
                            if (!(rr instanceof AST_Node) && !rr) {
                                return self.left;
                            }
                        }
                }
                var associative = true;
                switch (self.operator) {
                    case "+":
                        // (x + "foo") + "bar" => x + "foobar"
                        if (self.right instanceof AST_Constant
                            && self.left instanceof AST_Binary
                            && self.left.operator == "+"
                            && self.left.is_string(compressor)) {
                            var binary = make_node(AST_Binary, self, {
                                operator: "+",
                                left: self.left.right,
                                right: self.right,
                            });
                            var r = binary.optimize(compressor);
                            if (binary !== r) {
                                self = make_node(AST_Binary, self, {
                                    operator: "+",
                                    left: self.left.left,
                                    right: r
                                });
                            }
                        }
                        // (x + "foo") + ("bar" + y) => (x + "foobar") + y
                        if (self.left instanceof AST_Binary
                            && self.left.operator == "+"
                            && self.left.is_string(compressor)
                            && self.right instanceof AST_Binary
                            && self.right.operator == "+"
                            && self.right.is_string(compressor)) {
                            var binary = make_node(AST_Binary, self, {
                                operator: "+",
                                left: self.left.right,
                                right: self.right.left,
                            });
                            var m = binary.optimize(compressor);
                            if (binary !== m) {
                                self = make_node(AST_Binary, self, {
                                    operator: "+",
                                    left: make_node(AST_Binary, self.left, {
                                        operator: "+",
                                        left: self.left.left,
                                        right: m
                                    }),
                                    right: self.right.right
                                });
                            }
                        }
                        // a + -b => a - b
                        if (self.right instanceof AST_UnaryPrefix
                            && self.right.operator == "-"
                            && self.left.is_number(compressor)) {
                            self = make_node(AST_Binary, self, {
                                operator: "-",
                                left: self.left,
                                right: self.right.expression
                            });
                            break;
                        }
                        // -a + b => b - a
                        if (self.left instanceof AST_UnaryPrefix
                            && self.left.operator == "-"
                            && reversible()
                            && self.right.is_number(compressor)) {
                            self = make_node(AST_Binary, self, {
                                operator: "-",
                                left: self.right,
                                right: self.left.expression
                            });
                            break;
                        }
                        // `foo${bar}baz` + 1 => `foo${bar}baz1`
                        if (self.left instanceof AST_TemplateString) {
                            var l = self.left;
                            var r = self.right.evaluate(compressor);
                            if (r != self.right) {
                                l.segments[l.segments.length - 1].value += String(r);
                                return l;
                            }
                        }
                        // 1 + `foo${bar}baz` => `1foo${bar}baz`
                        if (self.right instanceof AST_TemplateString) {
                            var r = self.right;
                            var l = self.left.evaluate(compressor);
                            if (l != self.left) {
                                r.segments[0].value = String(l) + r.segments[0].value;
                                return r;
                            }
                        }
                        // `1${bar}2` + `foo${bar}baz` => `1${bar}2foo${bar}baz`
                        if (self.left instanceof AST_TemplateString
                            && self.right instanceof AST_TemplateString) {
                            var l = self.left;
                            var segments = l.segments;
                            var r = self.right;
                            segments[segments.length - 1].value += r.segments[0].value;
                            for (var i = 1; i < r.segments.length; i++) {
                                segments.push(r.segments[i]);
                            }
                            return l;
                        }
                    case "*":
                        associative = compressor.option("unsafe_math");
                    case "&":
                    case "|":
                    case "^":
                        // a + +b => +b + a
                        if (self.left.is_number(compressor)
                            && self.right.is_number(compressor)
                            && reversible()
                            && !(self.left instanceof AST_Binary
                                && self.left.operator != self.operator
                                && PRECEDENCE[self.left.operator] >= PRECEDENCE[self.operator])) {
                            var reversed = make_node(AST_Binary, self, {
                                operator: self.operator,
                                left: self.right,
                                right: self.left
                            });
                            if (self.right instanceof AST_Constant
                                && !(self.left instanceof AST_Constant)) {
                                self = best_of(compressor, reversed, self);
                            }
                            else {
                                self = best_of(compressor, self, reversed);
                            }
                        }
                        if (associative && self.is_number(compressor)) {
                            // a + (b + c) => (a + b) + c
                            if (self.right instanceof AST_Binary
                                && self.right.operator == self.operator) {
                                self = make_node(AST_Binary, self, {
                                    operator: self.operator,
                                    left: make_node(AST_Binary, self.left, {
                                        operator: self.operator,
                                        left: self.left,
                                        right: self.right.left,
                                        start: self.left.start,
                                        end: self.right.left.end
                                    }),
                                    right: self.right.right
                                });
                            }
                            // (n + 2) + 3 => 5 + n
                            // (2 * n) * 3 => 6 + n
                            if (self.right instanceof AST_Constant
                                && self.left instanceof AST_Binary
                                && self.left.operator == self.operator) {
                                if (self.left.left instanceof AST_Constant) {
                                    self = make_node(AST_Binary, self, {
                                        operator: self.operator,
                                        left: make_node(AST_Binary, self.left, {
                                            operator: self.operator,
                                            left: self.left.left,
                                            right: self.right,
                                            start: self.left.left.start,
                                            end: self.right.end
                                        }),
                                        right: self.left.right
                                    });
                                }
                                else if (self.left.right instanceof AST_Constant) {
                                    self = make_node(AST_Binary, self, {
                                        operator: self.operator,
                                        left: make_node(AST_Binary, self.left, {
                                            operator: self.operator,
                                            left: self.left.right,
                                            right: self.right,
                                            start: self.left.right.start,
                                            end: self.right.end
                                        }),
                                        right: self.left.left
                                    });
                                }
                            }
                            // (a | 1) | (2 | d) => (3 | a) | b
                            if (self.left instanceof AST_Binary
                                && self.left.operator == self.operator
                                && self.left.right instanceof AST_Constant
                                && self.right instanceof AST_Binary
                                && self.right.operator == self.operator
                                && self.right.left instanceof AST_Constant) {
                                self = make_node(AST_Binary, self, {
                                    operator: self.operator,
                                    left: make_node(AST_Binary, self.left, {
                                        operator: self.operator,
                                        left: make_node(AST_Binary, self.left.left, {
                                            operator: self.operator,
                                            left: self.left.right,
                                            right: self.right.left,
                                            start: self.left.right.start,
                                            end: self.right.left.end
                                        }),
                                        right: self.left.left
                                    }),
                                    right: self.right.right
                                });
                            }
                        }
                }
                // bitwise ops
                if (bitwise_binop.has(self.operator)) {
                    // Use De Morgan's laws
                    // z & (X | y)
                    // => z & X (given y & z === 0)
                    // => z & X | {y & z} (given y & z !== 0)
                    let y, z, x_node, y_node, z_node = self.left;
                    if (self.operator === "&"
                        && self.right instanceof AST_Binary
                        && self.right.operator === "|"
                        && typeof (z = self.left.evaluate(compressor)) === "number") {
                        if (typeof (y = self.right.right.evaluate(compressor)) === "number") {
                            // z & (X | y)
                            x_node = self.right.left;
                            y_node = self.right.right;
                        }
                        else if (typeof (y = self.right.left.evaluate(compressor)) === "number") {
                            // z & (y | X)
                            x_node = self.right.right;
                            y_node = self.right.left;
                        }
                        if (x_node && y_node) {
                            if ((y & z) === 0) {
                                self = make_node(AST_Binary, self, {
                                    operator: self.operator,
                                    left: z_node,
                                    right: x_node
                                });
                            }
                            else {
                                const reordered_ops = make_node(AST_Binary, self, {
                                    operator: "|",
                                    left: make_node(AST_Binary, self, {
                                        operator: "&",
                                        left: x_node,
                                        right: z_node
                                    }),
                                    right: make_node_from_constant(y & z, y_node),
                                });
                                self = best_of(compressor, self, reordered_ops);
                            }
                        }
                    }
                    // x ^ x => 0
                    // x | x => 0 | x
                    // x & x => 0 | x
                    const same_operands = self.left.equivalent_to(self.right) && !self.left.has_side_effects(compressor);
                    if (same_operands) {
                        if (self.operator === "^") {
                            return make_node(AST_Number, self, { value: 0 });
                        }
                        if (self.operator === "|" || self.operator === "&") {
                            self.left = make_node(AST_Number, self, { value: 0 });
                            self.operator = "|";
                        }
                    }
                    // Shifts that do nothing
                    // {anything} >> 0 => {anything} | 0
                    // {anything} << 0 => {anything} | 0
                    if ((self.operator === "<<" || self.operator === ">>")
                        && self.right instanceof AST_Number && self.right.value === 0) {
                        self.operator = "|";
                    }
                    // Find useless to-bitwise conversions
                    // {32 bit integer} | 0 => {32 bit integer}
                    // {32 bit integer} ^ 0 => {32 bit integer}
                    const zero_side = self.right instanceof AST_Number && self.right.value === 0 ? self.right
                        : self.left instanceof AST_Number && self.left.value === 0 ? self.left
                            : null;
                    const non_zero_side = zero_side && (zero_side === self.right ? self.left : self.right);
                    if (zero_side
                        && (self.operator === "|" || self.operator === "^")
                        && (non_zero_side.is_32_bit_integer() || compressor.in_32_bit_context())) {
                        return non_zero_side;
                    }
                    // {anything} & 0 => 0
                    if (zero_side
                        && self.operator === "&"
                        && !non_zero_side.has_side_effects(compressor)) {
                        return zero_side;
                    }
                    const is_full_mask = (node) => node instanceof AST_Number && node.value === -1
                        ||
                            node instanceof AST_UnaryPrefix && (node.operator === "-"
                                && node.expression instanceof AST_Number
                                && node.expression.value === 1
                                || node.operator === "~"
                                    && node.expression instanceof AST_Number
                                    && node.expression.value === 0);
                    const full_mask = is_full_mask(self.right) ? self.right
                        : is_full_mask(self.left) ? self.left
                            : null;
                    const non_full_mask_side = full_mask && (full_mask === self.right ? self.left : self.right);
                    switch (self.operator) {
                        case "|":
                            // {anything} | -1 => -1
                            if (full_mask && !non_full_mask_side.has_side_effects(compressor)) {
                                return full_mask;
                            }
                            break;
                        case "&":
                            // {32 bit integer} & -1 => {32 bit integer}
                            if (full_mask
                                && (non_full_mask_side.is_32_bit_integer() || compressor.in_32_bit_context())) {
                                return non_full_mask_side;
                            }
                            break;
                        case "^":
                            // {anything} ^ -1 => ~{anything}
                            if (full_mask) {
                                return non_full_mask_side.bitwise_negate(compressor.in_32_bit_context());
                            }
                            // ~x ^ ~y => x ^ y
                            if (self.left instanceof AST_UnaryPrefix
                                && self.left.operator === "~"
                                && self.right instanceof AST_UnaryPrefix
                                && self.right.operator === "~") {
                                self = make_node(AST_Binary, self, {
                                    operator: "^",
                                    left: self.left.expression,
                                    right: self.right.expression
                                });
                            }
                            break;
                    }
                }
            }
            // x && (y && z)  ==>  x && y && z
            // x || (y || z)  ==>  x || y || z
            // x + ("y" + z)  ==>  x + "y" + z
            // "x" + (y + "z")==>  "x" + y + "z"
            if (self.right instanceof AST_Binary
                && self.right.operator == self.operator
                && (lazy_op.has(self.operator)
                    || (self.operator == "+"
                        && (self.right.left.is_string(compressor)
                            || (self.left.is_string(compressor)
                                && self.right.right.is_string(compressor)))))) {
                self.left = make_node(AST_Binary, self.left, {
                    operator: self.operator,
                    left: self.left.transform(compressor),
                    right: self.right.left.transform(compressor)
                });
                self.right = self.right.right.transform(compressor);
                return self.transform(compressor);
            }
            var ev = self.evaluate(compressor);
            if (ev !== self) {
                ev = make_node_from_constant(ev, self).optimize(compressor);
                return best_of(compressor, ev, self);
            }
            return self;
        });
        def_optimize(AST_SymbolExport, function (self) {
            return self;
        });
        def_optimize(AST_SymbolRef, function (self, compressor) {
            if (!compressor.option("ie8")
                && is_undeclared_ref(self)
                && !compressor.find_parent(AST_With)) {
                switch (self.name) {
                    case "undefined":
                        return make_node(AST_Undefined, self).optimize(compressor);
                    case "NaN":
                        return make_node(AST_NaN, self).optimize(compressor);
                    case "Infinity":
                        return make_node(AST_Infinity, self).optimize(compressor);
                }
            }
            if (compressor.option("reduce_vars") && !compressor.is_lhs()) {
                return inline_into_symbolref(self, compressor);
            }
            else {
                return self;
            }
        });
        function is_atomic(lhs, self) {
            return lhs instanceof AST_SymbolRef || lhs.TYPE === self.TYPE;
        }
        def_optimize(AST_Undefined, function (self, compressor) {
            if (compressor.option("unsafe_undefined")) {
                var undef = find_variable(compressor, "undefined");
                if (undef) {
                    var ref = make_node(AST_SymbolRef, self, {
                        name: "undefined",
                        scope: undef.scope,
                        thedef: undef
                    });
                    set_flag(ref, UNDEFINED);
                    return ref;
                }
            }
            var lhs = compressor.is_lhs();
            if (lhs && is_atomic(lhs, self))
                return self;
            return make_node(AST_UnaryPrefix, self, {
                operator: "void",
                expression: make_node(AST_Number, self, {
                    value: 0
                })
            });
        });
        def_optimize(AST_Infinity, function (self, compressor) {
            var lhs = compressor.is_lhs();
            if (lhs && is_atomic(lhs, self))
                return self;
            if (compressor.option("keep_infinity")
                && !(lhs && !is_atomic(lhs, self))
                && !find_variable(compressor, "Infinity")) {
                return self;
            }
            return make_node(AST_Binary, self, {
                operator: "/",
                left: make_node(AST_Number, self, {
                    value: 1
                }),
                right: make_node(AST_Number, self, {
                    value: 0
                })
            });
        });
        def_optimize(AST_NaN, function (self, compressor) {
            var lhs = compressor.is_lhs();
            if (lhs && !is_atomic(lhs, self)
                || find_variable(compressor, "NaN")) {
                return make_node(AST_Binary, self, {
                    operator: "/",
                    left: make_node(AST_Number, self, {
                        value: 0
                    }),
                    right: make_node(AST_Number, self, {
                        value: 0
                    })
                });
            }
            return self;
        });
        const ASSIGN_OPS = makePredicate("+ - / * % >> << >>> | ^ &");
        const ASSIGN_OPS_COMMUTATIVE = makePredicate("* | ^ &");
        def_optimize(AST_Assign, function (self, compressor) {
            if (self.logical) {
                return self.lift_sequences(compressor);
            }
            var def;
            // x = x ---> x
            if (self.operator === "="
                && self.left instanceof AST_SymbolRef
                && self.left.name !== "arguments"
                && !(def = self.left.definition()).undeclared
                && self.right.equivalent_to(self.left)) {
                return self.right;
            }
            if (compressor.option("dead_code")
                && self.left instanceof AST_SymbolRef
                && (def = self.left.definition()).scope === compressor.find_parent(AST_Lambda)) {
                var level = 0, node, parent = self;
                do {
                    node = parent;
                    parent = compressor.parent(level++);
                    if (parent instanceof AST_Exit) {
                        if (in_try(level, parent))
                            break;
                        if (is_reachable(def.scope, [def]))
                            break;
                        if (self.operator == "=")
                            return self.right;
                        def.fixed = false;
                        return make_node(AST_Binary, self, {
                            operator: self.operator.slice(0, -1),
                            left: self.left,
                            right: self.right
                        }).optimize(compressor);
                    }
                } while (parent instanceof AST_Binary && parent.right === node
                    || parent instanceof AST_Sequence && parent.tail_node() === node);
            }
            self = self.lift_sequences(compressor);
            if (self.operator == "=" && self.left instanceof AST_SymbolRef && self.right instanceof AST_Binary) {
                // x = expr1 OP expr2
                if (self.right.left instanceof AST_SymbolRef
                    && self.right.left.name == self.left.name
                    && ASSIGN_OPS.has(self.right.operator)) {
                    // x = x - 2  --->  x -= 2
                    self.operator = self.right.operator + "=";
                    self.right = self.right.right;
                }
                else if (self.right.right instanceof AST_SymbolRef
                    && self.right.right.name == self.left.name
                    && ASSIGN_OPS_COMMUTATIVE.has(self.right.operator)
                    && !self.right.left.has_side_effects(compressor)) {
                    // x = 2 & x  --->  x &= 2
                    self.operator = self.right.operator + "=";
                    self.right = self.right.left;
                }
            }
            return self;
            function in_try(level, node) {
                function may_assignment_throw() {
                    const right = self.right;
                    self.right = make_node(AST_Null, right);
                    const may_throw = node.may_throw(compressor);
                    self.right = right;
                    return may_throw;
                }
                var stop_at = self.left.definition().scope.get_defun_scope();
                var parent;
                while ((parent = compressor.parent(level++)) !== stop_at) {
                    if (parent instanceof AST_Try) {
                        if (parent.bfinally)
                            return true;
                        if (parent.bcatch && may_assignment_throw())
                            return true;
                    }
                }
            }
        });
        def_optimize(AST_DefaultAssign, function (self, compressor) {
            if (!compressor.option("evaluate")) {
                return self;
            }
            var evaluateRight = self.right.evaluate(compressor);
            // `[x = undefined] = foo` ---> `[x] = foo`
            // `(arg = undefined) => ...` ---> `(arg) => ...` (unless `keep_fargs`)
            // `((arg = undefined) => ...)()` ---> `((arg) => ...)()`
            let lambda, iife;
            if (evaluateRight === undefined) {
                if ((lambda = compressor.parent()) instanceof AST_Lambda
                    ? (compressor.option("keep_fargs") === false
                        || (iife = compressor.parent(1)).TYPE === "Call"
                            && iife.expression === lambda)
                    : true) {
                    self = self.left;
                }
            }
            else if (evaluateRight !== self.right) {
                evaluateRight = make_node_from_constant(evaluateRight, self.right);
                self.right = best_of_expression(evaluateRight, self.right);
            }
            return self;
        });
        function is_nullish_check(check, check_subject, compressor) {
            if (check_subject.may_throw(compressor))
                return false;
            let nullish_side;
            // foo == null
            if (check instanceof AST_Binary
                && check.operator === "=="
                // which side is nullish?
                && ((nullish_side = is_nullish(check.left, compressor) && check.left)
                    || (nullish_side = is_nullish(check.right, compressor) && check.right))
                // is the other side the same as the check_subject
                && (nullish_side === check.left
                    ? check.right
                    : check.left).equivalent_to(check_subject)) {
                return true;
            }
            // foo === null || foo === undefined
            if (check instanceof AST_Binary && check.operator === "||") {
                let null_cmp;
                let undefined_cmp;
                const find_comparison = cmp => {
                    if (!(cmp instanceof AST_Binary
                        && (cmp.operator === "===" || cmp.operator === "=="))) {
                        return false;
                    }
                    let found = 0;
                    let defined_side;
                    if (cmp.left instanceof AST_Null) {
                        found++;
                        null_cmp = cmp;
                        defined_side = cmp.right;
                    }
                    if (cmp.right instanceof AST_Null) {
                        found++;
                        null_cmp = cmp;
                        defined_side = cmp.left;
                    }
                    if (is_undefined(cmp.left, compressor)) {
                        found++;
                        undefined_cmp = cmp;
                        defined_side = cmp.right;
                    }
                    if (is_undefined(cmp.right, compressor)) {
                        found++;
                        undefined_cmp = cmp;
                        defined_side = cmp.left;
                    }
                    if (found !== 1) {
                        return false;
                    }
                    if (!defined_side.equivalent_to(check_subject)) {
                        return false;
                    }
                    return true;
                };
                if (!find_comparison(check.left))
                    return false;
                if (!find_comparison(check.right))
                    return false;
                if (null_cmp && undefined_cmp && null_cmp !== undefined_cmp) {
                    return true;
                }
            }
            return false;
        }
        def_optimize(AST_Conditional, function (self, compressor) {
            if (!compressor.option("conditionals"))
                return self;
            // This looks like lift_sequences(), should probably be under "sequences"
            if (self.condition instanceof AST_Sequence) {
                var expressions = self.condition.expressions.slice();
                self.condition = expressions.pop();
                expressions.push(self);
                return make_sequence(self, expressions);
            }
            var cond = self.condition.evaluate(compressor);
            if (cond !== self.condition) {
                if (cond) {
                    return maintain_this_binding(compressor.parent(), compressor.self(), self.consequent);
                }
                else {
                    return maintain_this_binding(compressor.parent(), compressor.self(), self.alternative);
                }
            }
            var negated = cond.negate(compressor, first_in_statement(compressor));
            if (best_of(compressor, cond, negated) === negated) {
                self = make_node(AST_Conditional, self, {
                    condition: negated,
                    consequent: self.alternative,
                    alternative: self.consequent
                });
            }
            var condition = self.condition;
            var consequent = self.consequent;
            var alternative = self.alternative;
            // x?x:y --> x||y
            if (condition instanceof AST_SymbolRef
                && consequent instanceof AST_SymbolRef
                && condition.definition() === consequent.definition()) {
                return make_node(AST_Binary, self, {
                    operator: "||",
                    left: condition,
                    right: alternative
                });
            }
            // if (foo) exp = something; else exp = something_else;
            //                   |
            //                   v
            // exp = foo ? something : something_else;
            if (consequent instanceof AST_Assign
                && alternative instanceof AST_Assign
                && consequent.operator === alternative.operator
                && consequent.logical === alternative.logical
                && consequent.left.equivalent_to(alternative.left)
                && (!self.condition.has_side_effects(compressor)
                    || consequent.operator == "="
                        && !consequent.left.has_side_effects(compressor))) {
                return make_node(AST_Assign, self, {
                    operator: consequent.operator,
                    left: consequent.left,
                    logical: consequent.logical,
                    right: make_node(AST_Conditional, self, {
                        condition: self.condition,
                        consequent: consequent.right,
                        alternative: alternative.right
                    })
                });
            }
            // x ? y(a) : y(b) --> y(x ? a : b)
            var arg_index;
            if (consequent instanceof AST_Call
                && alternative.TYPE === consequent.TYPE
                && consequent.args.length > 0
                && consequent.args.length == alternative.args.length
                && consequent.expression.equivalent_to(alternative.expression)
                && !self.condition.has_side_effects(compressor)
                && !consequent.expression.has_side_effects(compressor)
                && typeof (arg_index = single_arg_diff()) == "number") {
                var node = consequent.clone();
                node.args[arg_index] = make_node(AST_Conditional, self, {
                    condition: self.condition,
                    consequent: consequent.args[arg_index],
                    alternative: alternative.args[arg_index]
                });
                return node;
            }
            // a ? b : c ? b : d --> (a || c) ? b : d
            if (alternative instanceof AST_Conditional
                && consequent.equivalent_to(alternative.consequent)) {
                return make_node(AST_Conditional, self, {
                    condition: make_node(AST_Binary, self, {
                        operator: "||",
                        left: condition,
                        right: alternative.condition
                    }),
                    consequent: consequent,
                    alternative: alternative.alternative
                }).optimize(compressor);
            }
            // a == null ? b : a -> a ?? b
            if (compressor.option("ecma") >= 2020 &&
                is_nullish_check(condition, alternative, compressor)) {
                return make_node(AST_Binary, self, {
                    operator: "??",
                    left: alternative,
                    right: consequent
                }).optimize(compressor);
            }
            // a ? b : (c, b) --> (a || c), b
            if (alternative instanceof AST_Sequence
                && consequent.equivalent_to(alternative.expressions[alternative.expressions.length - 1])) {
                return make_sequence(self, [
                    make_node(AST_Binary, self, {
                        operator: "||",
                        left: condition,
                        right: make_sequence(self, alternative.expressions.slice(0, -1))
                    }),
                    consequent
                ]).optimize(compressor);
            }
            // a ? b : (c && b) --> (a || c) && b
            if (alternative instanceof AST_Binary
                && alternative.operator == "&&"
                && consequent.equivalent_to(alternative.right)) {
                return make_node(AST_Binary, self, {
                    operator: "&&",
                    left: make_node(AST_Binary, self, {
                        operator: "||",
                        left: condition,
                        right: alternative.left
                    }),
                    right: consequent
                }).optimize(compressor);
            }
            // x?y?z:a:a --> x&&y?z:a
            if (consequent instanceof AST_Conditional
                && consequent.alternative.equivalent_to(alternative)) {
                return make_node(AST_Conditional, self, {
                    condition: make_node(AST_Binary, self, {
                        left: self.condition,
                        operator: "&&",
                        right: consequent.condition
                    }),
                    consequent: consequent.consequent,
                    alternative: alternative
                });
            }
            // x ? y : y --> x, y
            if (consequent.equivalent_to(alternative)) {
                return make_sequence(self, [
                    self.condition,
                    consequent
                ]).optimize(compressor);
            }
            // x ? y || z : z --> x && y || z
            if (consequent instanceof AST_Binary
                && consequent.operator == "||"
                && consequent.right.equivalent_to(alternative)) {
                return make_node(AST_Binary, self, {
                    operator: "||",
                    left: make_node(AST_Binary, self, {
                        operator: "&&",
                        left: self.condition,
                        right: consequent.left
                    }),
                    right: alternative
                }).optimize(compressor);
            }
            const in_bool = compressor.in_boolean_context();
            if (is_true(self.consequent)) {
                if (is_false(self.alternative)) {
                    // c ? true : false ---> !!c
                    return booleanize(self.condition);
                }
                // c ? true : x ---> !!c || x
                return make_node(AST_Binary, self, {
                    operator: "||",
                    left: booleanize(self.condition),
                    right: self.alternative
                });
            }
            if (is_false(self.consequent)) {
                if (is_true(self.alternative)) {
                    // c ? false : true ---> !c
                    return booleanize(self.condition.negate(compressor));
                }
                // c ? false : x ---> !c && x
                return make_node(AST_Binary, self, {
                    operator: "&&",
                    left: booleanize(self.condition.negate(compressor)),
                    right: self.alternative
                });
            }
            if (is_true(self.alternative)) {
                // c ? x : true ---> !c || x
                return make_node(AST_Binary, self, {
                    operator: "||",
                    left: booleanize(self.condition.negate(compressor)),
                    right: self.consequent
                });
            }
            if (is_false(self.alternative)) {
                // c ? x : false ---> !!c && x
                return make_node(AST_Binary, self, {
                    operator: "&&",
                    left: booleanize(self.condition),
                    right: self.consequent
                });
            }
            return self;
            function booleanize(node) {
                if (node.is_boolean())
                    return node;
                // !!expression
                return make_node(AST_UnaryPrefix, node, {
                    operator: "!",
                    expression: node.negate(compressor)
                });
            }
            // AST_True or !0
            function is_true(node) {
                return node instanceof AST_True
                    || in_bool
                        && node instanceof AST_Constant
                        && node.getValue()
                    || (node instanceof AST_UnaryPrefix
                        && node.operator == "!"
                        && node.expression instanceof AST_Constant
                        && !node.expression.getValue());
            }
            // AST_False or !1
            function is_false(node) {
                return node instanceof AST_False
                    || in_bool
                        && node instanceof AST_Constant
                        && !node.getValue()
                    || (node instanceof AST_UnaryPrefix
                        && node.operator == "!"
                        && node.expression instanceof AST_Constant
                        && node.expression.getValue());
            }
            function single_arg_diff() {
                var a = consequent.args;
                var b = alternative.args;
                for (var i = 0, len = a.length; i < len; i++) {
                    if (a[i] instanceof AST_Expansion)
                        return;
                    if (!a[i].equivalent_to(b[i])) {
                        if (b[i] instanceof AST_Expansion)
                            return;
                        for (var j = i + 1; j < len; j++) {
                            if (a[j] instanceof AST_Expansion)
                                return;
                            if (!a[j].equivalent_to(b[j]))
                                return;
                        }
                        return i;
                    }
                }
            }
        });
        def_optimize(AST_Boolean, function (self, compressor) {
            if (compressor.in_boolean_context())
                return make_node(AST_Number, self, {
                    value: +self.value
                });
            var p = compressor.parent();
            if (compressor.option("booleans_as_integers")) {
                if (p instanceof AST_Binary && (p.operator == "===" || p.operator == "!==")) {
                    p.operator = p.operator.replace(/=$/, "");
                }
                return make_node(AST_Number, self, {
                    value: +self.value
                });
            }
            if (compressor.option("booleans")) {
                if (p instanceof AST_Binary && (p.operator == "=="
                    || p.operator == "!=")) {
                    return make_node(AST_Number, self, {
                        value: +self.value
                    });
                }
                return make_node(AST_UnaryPrefix, self, {
                    operator: "!",
                    expression: make_node(AST_Number, self, {
                        value: 1 - self.value
                    })
                });
            }
            return self;
        });
        function safe_to_flatten(value, compressor) {
            if (value instanceof AST_SymbolRef) {
                value = value.fixed_value();
            }
            if (!value)
                return false;
            if (!(value instanceof AST_Lambda || value instanceof AST_Class))
                return true;
            if (!(value instanceof AST_Lambda && value.contains_this()))
                return true;
            return compressor.parent() instanceof AST_New;
        }
        AST_PropAccess.DEFMETHOD("flatten_object", function (key, compressor) {
            if (!compressor.option("properties"))
                return;
            if (key === "__proto__")
                return;
            var arrows = compressor.option("unsafe_arrows") && compressor.option("ecma") >= 2015;
            var expr = this.expression;
            if (expr instanceof AST_Object) {
                var props = expr.properties;
                for (var i = props.length; --i >= 0;) {
                    var prop = props[i];
                    if ("" + (prop instanceof AST_ConciseMethod ? prop.key.name : prop.key) == key) {
                        const all_props_flattenable = props.every((p) => (p instanceof AST_ObjectKeyVal
                            || arrows && p instanceof AST_ConciseMethod && !p.is_generator)
                            && !p.computed_key());
                        if (!all_props_flattenable)
                            return;
                        if (!safe_to_flatten(prop.value, compressor))
                            return;
                        return make_node(AST_Sub, this, {
                            expression: make_node(AST_Array, expr, {
                                elements: props.map(function (prop) {
                                    var v = prop.value;
                                    if (v instanceof AST_Accessor) {
                                        v = make_node(AST_Function, v, v);
                                    }
                                    var k = prop.key;
                                    if (k instanceof AST_Node && !(k instanceof AST_SymbolMethod)) {
                                        return make_sequence(prop, [k, v]);
                                    }
                                    return v;
                                })
                            }),
                            property: make_node(AST_Number, this, {
                                value: i
                            })
                        });
                    }
                }
            }
        });
        def_optimize(AST_Sub, function (self, compressor) {
            var expr = self.expression;
            var prop = self.property;
            if (compressor.option("properties")) {
                var key = prop.evaluate(compressor);
                if (key !== prop) {
                    if (typeof key == "string") {
                        if (key == "undefined") {
                            key = undefined;
                        }
                        else {
                            var value = parseFloat(key);
                            if (value.toString() == key) {
                                key = value;
                            }
                        }
                    }
                    prop = self.property = best_of_expression(prop, make_node_from_constant(key, prop).transform(compressor));
                    var property = "" + key;
                    if (is_basic_identifier_string(property)
                        && property.length <= prop.size() + 1) {
                        return make_node(AST_Dot, self, {
                            expression: expr,
                            optional: self.optional,
                            property: property,
                            quote: prop.quote,
                        }).optimize(compressor);
                    }
                }
            }
            var fn;
            OPT_ARGUMENTS: if (compressor.option("arguments")
                && expr instanceof AST_SymbolRef
                && expr.name == "arguments"
                && expr.definition().orig.length == 1
                && (fn = expr.scope) instanceof AST_Lambda
                && fn.uses_arguments
                && !(fn instanceof AST_Arrow)
                && prop instanceof AST_Number) {
                var index = prop.getValue();
                var params = new Set();
                var argnames = fn.argnames;
                for (var n = 0; n < argnames.length; n++) {
                    if (!(argnames[n] instanceof AST_SymbolFunarg)) {
                        break OPT_ARGUMENTS; // destructuring parameter - bail
                    }
                    var param = argnames[n].name;
                    if (params.has(param)) {
                        break OPT_ARGUMENTS; // duplicate parameter - bail
                    }
                    params.add(param);
                }
                var argname = fn.argnames[index];
                if (argname && compressor.has_directive("use strict")) {
                    var def = argname.definition();
                    if (!compressor.option("reduce_vars") || def.assignments || def.orig.length > 1) {
                        argname = null;
                    }
                }
                else if (!argname && !compressor.option("keep_fargs") && index < fn.argnames.length + 5) {
                    while (index >= fn.argnames.length) {
                        argname = fn.create_symbol(AST_SymbolFunarg, {
                            source: fn,
                            scope: fn,
                            tentative_name: "argument_" + fn.argnames.length,
                        });
                        fn.argnames.push(argname);
                    }
                }
                if (argname) {
                    var sym = make_node(AST_SymbolRef, self, argname);
                    sym.reference({});
                    clear_flag(argname, UNUSED);
                    return sym;
                }
            }
            if (compressor.is_lhs())
                return self;
            if (key !== prop) {
                var sub = self.flatten_object(property, compressor);
                if (sub) {
                    expr = self.expression = sub.expression;
                    prop = self.property = sub.property;
                }
            }
            if (compressor.option("properties") && compressor.option("side_effects")
                && prop instanceof AST_Number && expr instanceof AST_Array) {
                var index = prop.getValue();
                var elements = expr.elements;
                var retValue = elements[index];
                FLATTEN: if (safe_to_flatten(retValue, compressor)) {
                    var flatten = true;
                    var values = [];
                    for (var i = elements.length; --i > index;) {
                        var value = elements[i].drop_side_effect_free(compressor);
                        if (value) {
                            values.unshift(value);
                            if (flatten && value.has_side_effects(compressor))
                                flatten = false;
                        }
                    }
                    if (retValue instanceof AST_Expansion)
                        break FLATTEN;
                    retValue = retValue instanceof AST_Hole ? make_node(AST_Undefined, retValue) : retValue;
                    if (!flatten)
                        values.unshift(retValue);
                    while (--i >= 0) {
                        var value = elements[i];
                        if (value instanceof AST_Expansion)
                            break FLATTEN;
                        value = value.drop_side_effect_free(compressor);
                        if (value)
                            values.unshift(value);
                        else
                            index--;
                    }
                    if (flatten) {
                        values.push(retValue);
                        return make_sequence(self, values).optimize(compressor);
                    }
                    else
                        return make_node(AST_Sub, self, {
                            expression: make_node(AST_Array, expr, {
                                elements: values
                            }),
                            property: make_node(AST_Number, prop, {
                                value: index
                            })
                        });
                }
            }
            var ev = self.evaluate(compressor);
            if (ev !== self) {
                ev = make_node_from_constant(ev, self).optimize(compressor);
                return best_of(compressor, ev, self);
            }
            return self;
        });
        def_optimize(AST_Chain, function (self, compressor) {
            if (is_nullish(self.expression, compressor)) {
                let parent = compressor.parent();
                // It's valid to delete a nullish optional chain, but if we optimized
                // this to `delete undefined` then it would appear to be a syntax error
                // when we try to optimize the delete. Thankfully, `delete 0` is fine.
                if (parent instanceof AST_UnaryPrefix && parent.operator === "delete") {
                    return make_node_from_constant(0, self);
                }
                return make_node(AST_Undefined, self);
            }
            return self;
        });
        def_optimize(AST_Dot, function (self, compressor) {
            const parent = compressor.parent();
            if (compressor.is_lhs())
                return self;
            if (compressor.option("unsafe_proto")
                && self.expression instanceof AST_Dot
                && self.expression.property == "prototype") {
                var exp = self.expression.expression;
                if (is_undeclared_ref(exp))
                    switch (exp.name) {
                        case "Array":
                            self.expression = make_node(AST_Array, self.expression, {
                                elements: []
                            });
                            break;
                        case "Function":
                            self.expression = make_node(AST_Function, self.expression, {
                                argnames: [],
                                body: []
                            });
                            break;
                        case "Number":
                            self.expression = make_node(AST_Number, self.expression, {
                                value: 0
                            });
                            break;
                        case "Object":
                            self.expression = make_node(AST_Object, self.expression, {
                                properties: []
                            });
                            break;
                        case "RegExp":
                            self.expression = make_node(AST_RegExp, self.expression, {
                                value: { source: "t", flags: "" }
                            });
                            break;
                        case "String":
                            self.expression = make_node(AST_String, self.expression, {
                                value: ""
                            });
                            break;
                    }
            }
            if (!(parent instanceof AST_Call) || !has_annotation(parent, _NOINLINE)) {
                const sub = self.flatten_object(self.property, compressor);
                if (sub)
                    return sub.optimize(compressor);
            }
            if (self.expression instanceof AST_PropAccess
                && parent instanceof AST_PropAccess) {
                return self;
            }
            let ev = self.evaluate(compressor);
            if (ev !== self) {
                ev = make_node_from_constant(ev, self).optimize(compressor);
                return best_of(compressor, ev, self);
            }
            return self;
        });
        function literals_in_boolean_context(self, compressor) {
            if (compressor.in_boolean_context()) {
                return best_of(compressor, self, make_sequence(self, [
                    self,
                    make_node(AST_True, self)
                ]).optimize(compressor));
            }
            return self;
        }
        function inline_array_like_spread(elements) {
            for (var i = 0; i < elements.length; i++) {
                var el = elements[i];
                if (el instanceof AST_Expansion) {
                    var expr = el.expression;
                    if (expr instanceof AST_Array
                        && !expr.elements.some(elm => elm instanceof AST_Hole)) {
                        elements.splice(i, 1, ...expr.elements);
                        // Step back one, as the element at i is now new.
                        i--;
                    }
                    // In array-like spread, spreading a non-iterable value is TypeError.
                    // We therefore can’t optimize anything else, unlike with object spread.
                }
            }
        }
        def_optimize(AST_Array, function (self, compressor) {
            var optimized = literals_in_boolean_context(self, compressor);
            if (optimized !== self) {
                return optimized;
            }
            inline_array_like_spread(self.elements);
            return self;
        });
        function inline_object_prop_spread(props, compressor) {
            for (var i = 0; i < props.length; i++) {
                var prop = props[i];
                if (prop instanceof AST_Expansion) {
                    const expr = prop.expression;
                    if (expr instanceof AST_Object
                        && expr.properties.every(prop => prop instanceof AST_ObjectKeyVal)) {
                        props.splice(i, 1, ...expr.properties);
                        // Step back one, as the property at i is now new.
                        i--;
                    }
                    else if (expr instanceof AST_Constant
                        && !(expr instanceof AST_String)) {
                        // Unlike array-like spread, in object spread, spreading a
                        // non-iterable value silently does nothing; it is thus safe
                        // to remove. AST_String is the only iterable AST_Constant.
                        props.splice(i, 1);
                        i--;
                    }
                    else if (is_nullish(expr, compressor)) {
                        // Likewise, null and undefined can be silently removed.
                        props.splice(i, 1);
                        i--;
                    }
                }
            }
        }
        def_optimize(AST_Object, function (self, compressor) {
            var optimized = literals_in_boolean_context(self, compressor);
            if (optimized !== self) {
                return optimized;
            }
            inline_object_prop_spread(self.properties, compressor);
            return self;
        });
        def_optimize(AST_RegExp, literals_in_boolean_context);
        def_optimize(AST_Return, function (self, compressor) {
            if (self.value && is_undefined(self.value, compressor)) {
                self.value = null;
            }
            return self;
        });
        def_optimize(AST_Arrow, opt_AST_Lambda);
        def_optimize(AST_Function, function (self, compressor) {
            self = opt_AST_Lambda(self, compressor);
            if (compressor.option("unsafe_arrows")
                && compressor.option("ecma") >= 2015
                && !self.name
                && !self.is_generator
                && !self.uses_arguments
                && !self.pinned()) {
                const uses_this = walk(self, node => {
                    if (node instanceof AST_This)
                        return walk_abort;
                });
                if (!uses_this)
                    return make_node(AST_Arrow, self, self).optimize(compressor);
            }
            return self;
        });
        def_optimize(AST_Class, function (self) {
            for (let i = 0; i < self.properties.length; i++) {
                const prop = self.properties[i];
                if (prop instanceof AST_ClassStaticBlock && prop.body.length == 0) {
                    self.properties.splice(i, 1);
                    i--;
                }
            }
            return self;
        });
        def_optimize(AST_ClassStaticBlock, function (self, compressor) {
            tighten_body(self.body, compressor);
            return self;
        });
        def_optimize(AST_Yield, function (self, compressor) {
            if (self.expression && !self.is_star && is_undefined(self.expression, compressor)) {
                self.expression = null;
            }
            return self;
        });
        def_optimize(AST_TemplateString, function (self, compressor) {
            if (!compressor.option("evaluate")
                || compressor.parent() instanceof AST_PrefixedTemplateString) {
                return self;
            }
            var segments = [];
            for (var i = 0; i < self.segments.length; i++) {
                var segment = self.segments[i];
                if (segment instanceof AST_Node) {
                    var result = segment.evaluate(compressor);
                    // Evaluate to constant value
                    // Constant value shorter than ${segment}
                    if (result !== segment && (result + "").length <= segment.size() + "${}".length) {
                        // There should always be a previous and next segment if segment is a node
                        segments[segments.length - 1].value = segments[segments.length - 1].value + result + self.segments[++i].value;
                        continue;
                    }
                    // `before ${`innerBefore ${any} innerAfter`} after` => `before innerBefore ${any} innerAfter after`
                    // TODO:
                    // `before ${'test' + foo} after` => `before innerBefore ${any} innerAfter after`
                    // `before ${foo + 'test} after` => `before innerBefore ${any} innerAfter after`
                    if (segment instanceof AST_TemplateString) {
                        var inners = segment.segments;
                        segments[segments.length - 1].value += inners[0].value;
                        for (var j = 1; j < inners.length; j++) {
                            segment = inners[j];
                            segments.push(segment);
                        }
                        continue;
                    }
                }
                segments.push(segment);
            }
            self.segments = segments;
            // `foo` => "foo"
            if (segments.length == 1) {
                return make_node(AST_String, self, segments[0]);
            }
            if (segments.length === 3
                && segments[1] instanceof AST_Node
                && (segments[1].is_string(compressor)
                    || segments[1].is_number(compressor)
                    || is_nullish(segments[1], compressor)
                    || compressor.option("unsafe"))) {
                // `foo${bar}` => "foo" + bar
                if (segments[2].value === "") {
                    return make_node(AST_Binary, self, {
                        operator: "+",
                        left: make_node(AST_String, self, {
                            value: segments[0].value,
                        }),
                        right: segments[1],
                    });
                }
                // `${bar}baz` => bar + "baz"
                if (segments[0].value === "") {
                    return make_node(AST_Binary, self, {
                        operator: "+",
                        left: segments[1],
                        right: make_node(AST_String, self, {
                            value: segments[2].value,
                        }),
                    });
                }
            }
            return self;
        });
        def_optimize(AST_PrefixedTemplateString, function (self) {
            return self;
        });
        // ["p"]:1 ---> p:1
        // [42]:1 ---> 42:1
        function lift_key(self, compressor) {
            if (!compressor.option("computed_props"))
                return self;
            // save a comparison in the typical case
            if (!(self.key instanceof AST_Constant))
                return self;
            // allow certain acceptable props as not all AST_Constants are true constants
            if (self.key instanceof AST_String || self.key instanceof AST_Number) {
                const key = self.key.value.toString();
                if (key === "__proto__")
                    return self;
                if (key == "constructor"
                    && compressor.parent() instanceof AST_Class)
                    return self;
                if (self instanceof AST_ObjectKeyVal) {
                    self.quote = self.key.quote;
                    self.key = key;
                }
                else if (self instanceof AST_ClassProperty) {
                    self.quote = self.key.quote;
                    self.key = make_node(AST_SymbolClassProperty, self.key, {
                        name: key,
                    });
                }
                else {
                    self.quote = self.key.quote;
                    self.key = make_node(AST_SymbolMethod, self.key, {
                        name: key,
                    });
                }
            }
            return self;
        }
        def_optimize(AST_ObjectProperty, lift_key);
        def_optimize(AST_ConciseMethod, function (self, compressor) {
            lift_key(self, compressor);
            // p(){return x;} ---> p:()=>x
            if (compressor.option("arrows")
                && compressor.parent() instanceof AST_Object
                && !self.is_generator
                && !self.value.uses_arguments
                && !self.value.pinned()
                && self.value.body.length == 1
                && self.value.body[0] instanceof AST_Return
                && self.value.body[0].value
                && !self.value.contains_this()) {
                var arrow = make_node(AST_Arrow, self.value, self.value);
                arrow.async = self.async;
                arrow.is_generator = self.is_generator;
                return make_node(AST_ObjectKeyVal, self, {
                    key: self.key instanceof AST_SymbolMethod ? self.key.name : self.key,
                    value: arrow,
                    quote: self.quote,
                });
            }
            return self;
        });
        def_optimize(AST_ObjectKeyVal, function (self, compressor) {
            lift_key(self, compressor);
            // p:function(){} ---> p(){}
            // p:function*(){} ---> *p(){}
            // p:async function(){} ---> async p(){}
            // p:()=>{} ---> p(){}
            // p:async()=>{} ---> async p(){}
            var unsafe_methods = compressor.option("unsafe_methods");
            if (unsafe_methods
                && compressor.option("ecma") >= 2015
                && (!(unsafe_methods instanceof RegExp) || unsafe_methods.test(self.key + ""))) {
                var key = self.key;
                var value = self.value;
                var is_arrow_with_block = value instanceof AST_Arrow
                    && Array.isArray(value.body)
                    && !value.contains_this();
                if ((is_arrow_with_block || value instanceof AST_Function) && !value.name) {
                    return make_node(AST_ConciseMethod, self, {
                        async: value.async,
                        is_generator: value.is_generator,
                        key: key instanceof AST_Node ? key : make_node(AST_SymbolMethod, self, {
                            name: key,
                        }),
                        value: make_node(AST_Accessor, value, value),
                        quote: self.quote,
                    });
                }
            }
            return self;
        });
        def_optimize(AST_Destructuring, function (self, compressor) {
            if (compressor.option("pure_getters") == true
                && compressor.option("unused")
                && !self.is_array
                && Array.isArray(self.names)
                && !is_destructuring_export_decl(compressor)
                && !(self.names[self.names.length - 1] instanceof AST_Expansion)) {
                var keep = [];
                for (var i = 0; i < self.names.length; i++) {
                    var elem = self.names[i];
                    if (!(elem instanceof AST_ObjectKeyVal
                        && typeof elem.key == "string"
                        && elem.value instanceof AST_SymbolDeclaration
                        && !should_retain(compressor, elem.value.definition()))) {
                        keep.push(elem);
                    }
                }
                if (keep.length != self.names.length) {
                    self.names = keep;
                }
            }
            return self;
            function is_destructuring_export_decl(compressor) {
                var ancestors = [/^VarDef$/, /^(Const|Let|Var)$/, /^Export$/];
                for (var a = 0, p = 0, len = ancestors.length; a < len; p++) {
                    var parent = compressor.parent(p);
                    if (!parent)
                        return false;
                    if (a === 0 && parent.TYPE == "Destructuring")
                        continue;
                    if (!ancestors[a].test(parent.TYPE)) {
                        return false;
                    }
                    a++;
                }
                return true;
            }
            function should_retain(compressor, def) {
                if (def.references.length)
                    return true;
                if (!def.global)
                    return false;
                if (compressor.toplevel.vars) {
                    if (compressor.top_retain) {
                        return compressor.top_retain(def);
                    }
                    return false;
                }
                return true;
            }
        });
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        // a small wrapper around source-map and @jridgewell/source-map
        function* SourceMap(options) {
            options = defaults(options, {
                file: null,
                root: null,
                orig: null,
                files: {},
            });
            var orig_map;
            var generator = new sourceMap.SourceMapGenerator({
                file: options.file,
                sourceRoot: options.root
            });
            let sourcesContent = { __proto__: null };
            let files = options.files;
            for (var name in files)
                if (HOP(files, name)) {
                    sourcesContent[name] = files[name];
                }
            if (options.orig) {
                // We support both @jridgewell/source-map (which has a sync
                // SourceMapConsumer) and source-map (which has an async
                // SourceMapConsumer).
                orig_map = yield new sourceMap.SourceMapConsumer(options.orig);
                if (orig_map.sourcesContent) {
                    orig_map.sources.forEach(function (source, i) {
                        var content = orig_map.sourcesContent[i];
                        if (content) {
                            sourcesContent[source] = content;
                        }
                    });
                }
            }
            function add(source, gen_line, gen_col, orig_line, orig_col, name) {
                let generatedPos = { line: gen_line, column: gen_col };
                if (orig_map) {
                    var info = orig_map.originalPositionFor({
                        line: orig_line,
                        column: orig_col
                    });
                    if (info.source === null) {
                        generator.addMapping({
                            generated: generatedPos,
                            original: null,
                            source: null,
                            name: null
                        });
                        return;
                    }
                    source = info.source;
                    orig_line = info.line;
                    orig_col = info.column;
                    name = info.name || name;
                }
                generator.addMapping({
                    generated: generatedPos,
                    original: { line: orig_line, column: orig_col },
                    source: source,
                    name: name
                });
                generator.setSourceContent(source, sourcesContent[source]);
            }
            function clean(map) {
                const allNull = map.sourcesContent && map.sourcesContent.every(c => c == null);
                if (allNull)
                    delete map.sourcesContent;
                if (map.file === undefined)
                    delete map.file;
                if (map.sourceRoot === undefined)
                    delete map.sourceRoot;
                return map;
            }
            function getDecoded() {
                if (!generator.toDecodedMap)
                    return null;
                return clean(generator.toDecodedMap());
            }
            function getEncoded() {
                return clean(generator.toJSON());
            }
            function destroy() {
                // @jridgewell/source-map's SourceMapConsumer does not need to be
                // manually freed.
                if (orig_map && orig_map.destroy)
                    orig_map.destroy();
            }
            return {
                add,
                getDecoded,
                getEncoded,
                destroy,
            };
        }
        var domprops = [
            "$&",
            "$'",
            "$*",
            "$+",
            "$1",
            "$2",
            "$3",
            "$4",
            "$5",
            "$6",
            "$7",
            "$8",
            "$9",
            "$_",
            "$`",
            "$input",
            "-moz-animation",
            "-moz-animation-delay",
            "-moz-animation-direction",
            "-moz-animation-duration",
            "-moz-animation-fill-mode",
            "-moz-animation-iteration-count",
            "-moz-animation-name",
            "-moz-animation-play-state",
            "-moz-animation-timing-function",
            "-moz-appearance",
            "-moz-backface-visibility",
            "-moz-border-end",
            "-moz-border-end-color",
            "-moz-border-end-style",
            "-moz-border-end-width",
            "-moz-border-image",
            "-moz-border-start",
            "-moz-border-start-color",
            "-moz-border-start-style",
            "-moz-border-start-width",
            "-moz-box-align",
            "-moz-box-direction",
            "-moz-box-flex",
            "-moz-box-ordinal-group",
            "-moz-box-orient",
            "-moz-box-pack",
            "-moz-box-sizing",
            "-moz-float-edge",
            "-moz-font-feature-settings",
            "-moz-font-language-override",
            "-moz-force-broken-image-icon",
            "-moz-hyphens",
            "-moz-image-region",
            "-moz-margin-end",
            "-moz-margin-start",
            "-moz-orient",
            "-moz-osx-font-smoothing",
            "-moz-outline-radius",
            "-moz-outline-radius-bottomleft",
            "-moz-outline-radius-bottomright",
            "-moz-outline-radius-topleft",
            "-moz-outline-radius-topright",
            "-moz-padding-end",
            "-moz-padding-start",
            "-moz-perspective",
            "-moz-perspective-origin",
            "-moz-tab-size",
            "-moz-text-size-adjust",
            "-moz-transform",
            "-moz-transform-origin",
            "-moz-transform-style",
            "-moz-transition",
            "-moz-transition-delay",
            "-moz-transition-duration",
            "-moz-transition-property",
            "-moz-transition-timing-function",
            "-moz-user-focus",
            "-moz-user-input",
            "-moz-user-modify",
            "-moz-user-select",
            "-moz-window-dragging",
            "-webkit-align-content",
            "-webkit-align-items",
            "-webkit-align-self",
            "-webkit-animation",
            "-webkit-animation-delay",
            "-webkit-animation-direction",
            "-webkit-animation-duration",
            "-webkit-animation-fill-mode",
            "-webkit-animation-iteration-count",
            "-webkit-animation-name",
            "-webkit-animation-play-state",
            "-webkit-animation-timing-function",
            "-webkit-appearance",
            "-webkit-backface-visibility",
            "-webkit-background-clip",
            "-webkit-background-origin",
            "-webkit-background-size",
            "-webkit-border-bottom-left-radius",
            "-webkit-border-bottom-right-radius",
            "-webkit-border-image",
            "-webkit-border-radius",
            "-webkit-border-top-left-radius",
            "-webkit-border-top-right-radius",
            "-webkit-box-align",
            "-webkit-box-direction",
            "-webkit-box-flex",
            "-webkit-box-ordinal-group",
            "-webkit-box-orient",
            "-webkit-box-pack",
            "-webkit-box-shadow",
            "-webkit-box-sizing",
            "-webkit-filter",
            "-webkit-flex",
            "-webkit-flex-basis",
            "-webkit-flex-direction",
            "-webkit-flex-flow",
            "-webkit-flex-grow",
            "-webkit-flex-shrink",
            "-webkit-flex-wrap",
            "-webkit-justify-content",
            "-webkit-line-clamp",
            "-webkit-mask",
            "-webkit-mask-clip",
            "-webkit-mask-composite",
            "-webkit-mask-image",
            "-webkit-mask-origin",
            "-webkit-mask-position",
            "-webkit-mask-position-x",
            "-webkit-mask-position-y",
            "-webkit-mask-repeat",
            "-webkit-mask-size",
            "-webkit-order",
            "-webkit-perspective",
            "-webkit-perspective-origin",
            "-webkit-text-fill-color",
            "-webkit-text-size-adjust",
            "-webkit-text-stroke",
            "-webkit-text-stroke-color",
            "-webkit-text-stroke-width",
            "-webkit-transform",
            "-webkit-transform-origin",
            "-webkit-transform-style",
            "-webkit-transition",
            "-webkit-transition-delay",
            "-webkit-transition-duration",
            "-webkit-transition-property",
            "-webkit-transition-timing-function",
            "-webkit-user-select",
            "0",
            "1",
            "10",
            "11",
            "12",
            "13",
            "14",
            "15",
            "16",
            "17",
            "18",
            "19",
            "2",
            "20",
            "3",
            "4",
            "5",
            "6",
            "7",
            "8",
            "9",
            "@@iterator",
            "ABORT_ERR",
            "ACTIVE",
            "ACTIVE_ATTRIBUTES",
            "ACTIVE_TEXTURE",
            "ACTIVE_UNIFORMS",
            "ACTIVE_UNIFORM_BLOCKS",
            "ADDITION",
            "ALIASED_LINE_WIDTH_RANGE",
            "ALIASED_POINT_SIZE_RANGE",
            "ALL",
            "ALLOW_KEYBOARD_INPUT",
            "ALLPASS",
            "ALPHA",
            "ALPHA_BITS",
            "ALREADY_SIGNALED",
            "ALT_MASK",
            "ALWAYS",
            "ANY_SAMPLES_PASSED",
            "ANY_SAMPLES_PASSED_CONSERVATIVE",
            "ANY_TYPE",
            "ANY_UNORDERED_NODE_TYPE",
            "ARRAY_BUFFER",
            "ARRAY_BUFFER_BINDING",
            "ATTACHED_SHADERS",
            "ATTRIBUTE_NODE",
            "AT_TARGET",
            "AbortController",
            "AbortSignal",
            "AbsoluteOrientationSensor",
            "AbstractRange",
            "Accelerometer",
            "AddSearchProvider",
            "AggregateError",
            "AnalyserNode",
            "Animation",
            "AnimationEffect",
            "AnimationEvent",
            "AnimationPlaybackEvent",
            "AnimationTimeline",
            "AnonXMLHttpRequest",
            "Any",
            "ApplicationCache",
            "ApplicationCacheErrorEvent",
            "Array",
            "ArrayBuffer",
            "ArrayType",
            "Atomics",
            "Attr",
            "Audio",
            "AudioBuffer",
            "AudioBufferSourceNode",
            "AudioContext",
            "AudioDestinationNode",
            "AudioListener",
            "AudioNode",
            "AudioParam",
            "AudioParamMap",
            "AudioProcessingEvent",
            "AudioScheduledSourceNode",
            "AudioStreamTrack",
            "AudioWorklet",
            "AudioWorkletNode",
            "AuthenticatorAssertionResponse",
            "AuthenticatorAttestationResponse",
            "AuthenticatorResponse",
            "AutocompleteErrorEvent",
            "BACK",
            "BAD_BOUNDARYPOINTS_ERR",
            "BAD_REQUEST",
            "BANDPASS",
            "BLEND",
            "BLEND_COLOR",
            "BLEND_DST_ALPHA",
            "BLEND_DST_RGB",
            "BLEND_EQUATION",
            "BLEND_EQUATION_ALPHA",
            "BLEND_EQUATION_RGB",
            "BLEND_SRC_ALPHA",
            "BLEND_SRC_RGB",
            "BLUE",
            "BLUE_BITS",
            "BLUR",
            "BOOL",
            "BOOLEAN_TYPE",
            "BOOL_VEC2",
            "BOOL_VEC3",
            "BOOL_VEC4",
            "BOTH",
            "BROWSER_DEFAULT_WEBGL",
            "BUBBLING_PHASE",
            "BUFFER_SIZE",
            "BUFFER_USAGE",
            "BYTE",
            "BYTES_PER_ELEMENT",
            "BackgroundFetchManager",
            "BackgroundFetchRecord",
            "BackgroundFetchRegistration",
            "BarProp",
            "BarcodeDetector",
            "BaseAudioContext",
            "BaseHref",
            "BatteryManager",
            "BeforeInstallPromptEvent",
            "BeforeLoadEvent",
            "BeforeUnloadEvent",
            "BigInt",
            "BigInt64Array",
            "BigUint64Array",
            "BiquadFilterNode",
            "Blob",
            "BlobEvent",
            "Bluetooth",
            "BluetoothCharacteristicProperties",
            "BluetoothDevice",
            "BluetoothRemoteGATTCharacteristic",
            "BluetoothRemoteGATTDescriptor",
            "BluetoothRemoteGATTServer",
            "BluetoothRemoteGATTService",
            "BluetoothUUID",
            "Boolean",
            "BroadcastChannel",
            "ByteLengthQueuingStrategy",
            "CAPTURING_PHASE",
            "CCW",
            "CDATASection",
            "CDATA_SECTION_NODE",
            "CHANGE",
            "CHARSET_RULE",
            "CHECKING",
            "CLAMP_TO_EDGE",
            "CLICK",
            "CLOSED",
            "CLOSING",
            "COLOR",
            "COLOR_ATTACHMENT0",
            "COLOR_ATTACHMENT1",
            "COLOR_ATTACHMENT10",
            "COLOR_ATTACHMENT11",
            "COLOR_ATTACHMENT12",
            "COLOR_ATTACHMENT13",
            "COLOR_ATTACHMENT14",
            "COLOR_ATTACHMENT15",
            "COLOR_ATTACHMENT2",
            "COLOR_ATTACHMENT3",
            "COLOR_ATTACHMENT4",
            "COLOR_ATTACHMENT5",
            "COLOR_ATTACHMENT6",
            "COLOR_ATTACHMENT7",
            "COLOR_ATTACHMENT8",
            "COLOR_ATTACHMENT9",
            "COLOR_BUFFER_BIT",
            "COLOR_CLEAR_VALUE",
            "COLOR_WRITEMASK",
            "COMMENT_NODE",
            "COMPARE_REF_TO_TEXTURE",
            "COMPILE_STATUS",
            "COMPLETION_STATUS_KHR",
            "COMPRESSED_RGBA_S3TC_DXT1_EXT",
            "COMPRESSED_RGBA_S3TC_DXT3_EXT",
            "COMPRESSED_RGBA_S3TC_DXT5_EXT",
            "COMPRESSED_RGB_S3TC_DXT1_EXT",
            "COMPRESSED_TEXTURE_FORMATS",
            "COMPUTE",
            "CONDITION_SATISFIED",
            "CONFIGURATION_UNSUPPORTED",
            "CONNECTING",
            "CONSTANT_ALPHA",
            "CONSTANT_COLOR",
            "CONSTRAINT_ERR",
            "CONTEXT_LOST_WEBGL",
            "CONTROL_MASK",
            "COPY_DST",
            "COPY_READ_BUFFER",
            "COPY_READ_BUFFER_BINDING",
            "COPY_SRC",
            "COPY_WRITE_BUFFER",
            "COPY_WRITE_BUFFER_BINDING",
            "COUNTER_STYLE_RULE",
            "CSS",
            "CSS2Properties",
            "CSSAnimation",
            "CSSCharsetRule",
            "CSSConditionRule",
            "CSSCounterStyleRule",
            "CSSFontFaceRule",
            "CSSFontFeatureValuesRule",
            "CSSGroupingRule",
            "CSSImageValue",
            "CSSImportRule",
            "CSSKeyframeRule",
            "CSSKeyframesRule",
            "CSSKeywordValue",
            "CSSMathInvert",
            "CSSMathMax",
            "CSSMathMin",
            "CSSMathNegate",
            "CSSMathProduct",
            "CSSMathSum",
            "CSSMathValue",
            "CSSMatrixComponent",
            "CSSMediaRule",
            "CSSMozDocumentRule",
            "CSSNameSpaceRule",
            "CSSNamespaceRule",
            "CSSNumericArray",
            "CSSNumericValue",
            "CSSPageRule",
            "CSSPerspective",
            "CSSPositionValue",
            "CSSPrimitiveValue",
            "CSSRotate",
            "CSSRule",
            "CSSRuleList",
            "CSSScale",
            "CSSSkew",
            "CSSSkewX",
            "CSSSkewY",
            "CSSStyleDeclaration",
            "CSSStyleRule",
            "CSSStyleSheet",
            "CSSStyleValue",
            "CSSSupportsRule",
            "CSSTransformComponent",
            "CSSTransformValue",
            "CSSTransition",
            "CSSTranslate",
            "CSSUnitValue",
            "CSSUnknownRule",
            "CSSUnparsedValue",
            "CSSValue",
            "CSSValueList",
            "CSSVariableReferenceValue",
            "CSSVariablesDeclaration",
            "CSSVariablesRule",
            "CSSViewportRule",
            "CSS_ATTR",
            "CSS_CM",
            "CSS_COUNTER",
            "CSS_CUSTOM",
            "CSS_DEG",
            "CSS_DIMENSION",
            "CSS_EMS",
            "CSS_EXS",
            "CSS_FILTER_BLUR",
            "CSS_FILTER_BRIGHTNESS",
            "CSS_FILTER_CONTRAST",
            "CSS_FILTER_CUSTOM",
            "CSS_FILTER_DROP_SHADOW",
            "CSS_FILTER_GRAYSCALE",
            "CSS_FILTER_HUE_ROTATE",
            "CSS_FILTER_INVERT",
            "CSS_FILTER_OPACITY",
            "CSS_FILTER_REFERENCE",
            "CSS_FILTER_SATURATE",
            "CSS_FILTER_SEPIA",
            "CSS_GRAD",
            "CSS_HZ",
            "CSS_IDENT",
            "CSS_IN",
            "CSS_INHERIT",
            "CSS_KHZ",
            "CSS_MATRIX",
            "CSS_MATRIX3D",
            "CSS_MM",
            "CSS_MS",
            "CSS_NUMBER",
            "CSS_PC",
            "CSS_PERCENTAGE",
            "CSS_PERSPECTIVE",
            "CSS_PRIMITIVE_VALUE",
            "CSS_PT",
            "CSS_PX",
            "CSS_RAD",
            "CSS_RECT",
            "CSS_RGBCOLOR",
            "CSS_ROTATE",
            "CSS_ROTATE3D",
            "CSS_ROTATEX",
            "CSS_ROTATEY",
            "CSS_ROTATEZ",
            "CSS_S",
            "CSS_SCALE",
            "CSS_SCALE3D",
            "CSS_SCALEX",
            "CSS_SCALEY",
            "CSS_SCALEZ",
            "CSS_SKEW",
            "CSS_SKEWX",
            "CSS_SKEWY",
            "CSS_STRING",
            "CSS_TRANSLATE",
            "CSS_TRANSLATE3D",
            "CSS_TRANSLATEX",
            "CSS_TRANSLATEY",
            "CSS_TRANSLATEZ",
            "CSS_UNKNOWN",
            "CSS_URI",
            "CSS_VALUE_LIST",
            "CSS_VH",
            "CSS_VMAX",
            "CSS_VMIN",
            "CSS_VW",
            "CULL_FACE",
            "CULL_FACE_MODE",
            "CURRENT_PROGRAM",
            "CURRENT_QUERY",
            "CURRENT_VERTEX_ATTRIB",
            "CUSTOM",
            "CW",
            "Cache",
            "CacheStorage",
            "CanvasCaptureMediaStream",
            "CanvasCaptureMediaStreamTrack",
            "CanvasGradient",
            "CanvasPattern",
            "CanvasRenderingContext2D",
            "CaretPosition",
            "ChannelMergerNode",
            "ChannelSplitterNode",
            "CharacterData",
            "ClientRect",
            "ClientRectList",
            "Clipboard",
            "ClipboardEvent",
            "ClipboardItem",
            "CloseEvent",
            "Collator",
            "CommandEvent",
            "Comment",
            "CompileError",
            "CompositionEvent",
            "CompressionStream",
            "Console",
            "ConstantSourceNode",
            "Controllers",
            "ConvolverNode",
            "CountQueuingStrategy",
            "Counter",
            "Credential",
            "CredentialsContainer",
            "Crypto",
            "CryptoKey",
            "CustomElementRegistry",
            "CustomEvent",
            "DATABASE_ERR",
            "DATA_CLONE_ERR",
            "DATA_ERR",
            "DBLCLICK",
            "DECR",
            "DECR_WRAP",
            "DELETE_STATUS",
            "DEPTH",
            "DEPTH24_STENCIL8",
            "DEPTH32F_STENCIL8",
            "DEPTH_ATTACHMENT",
            "DEPTH_BITS",
            "DEPTH_BUFFER_BIT",
            "DEPTH_CLEAR_VALUE",
            "DEPTH_COMPONENT",
            "DEPTH_COMPONENT16",
            "DEPTH_COMPONENT24",
            "DEPTH_COMPONENT32F",
            "DEPTH_FUNC",
            "DEPTH_RANGE",
            "DEPTH_STENCIL",
            "DEPTH_STENCIL_ATTACHMENT",
            "DEPTH_TEST",
            "DEPTH_WRITEMASK",
            "DEVICE_INELIGIBLE",
            "DIRECTION_DOWN",
            "DIRECTION_LEFT",
            "DIRECTION_RIGHT",
            "DIRECTION_UP",
            "DISABLED",
            "DISPATCH_REQUEST_ERR",
            "DITHER",
            "DOCUMENT_FRAGMENT_NODE",
            "DOCUMENT_NODE",
            "DOCUMENT_POSITION_CONTAINED_BY",
            "DOCUMENT_POSITION_CONTAINS",
            "DOCUMENT_POSITION_DISCONNECTED",
            "DOCUMENT_POSITION_FOLLOWING",
            "DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC",
            "DOCUMENT_POSITION_PRECEDING",
            "DOCUMENT_TYPE_NODE",
            "DOMCursor",
            "DOMError",
            "DOMException",
            "DOMImplementation",
            "DOMImplementationLS",
            "DOMMatrix",
            "DOMMatrixReadOnly",
            "DOMParser",
            "DOMPoint",
            "DOMPointReadOnly",
            "DOMQuad",
            "DOMRect",
            "DOMRectList",
            "DOMRectReadOnly",
            "DOMRequest",
            "DOMSTRING_SIZE_ERR",
            "DOMSettableTokenList",
            "DOMStringList",
            "DOMStringMap",
            "DOMTokenList",
            "DOMTransactionEvent",
            "DOM_DELTA_LINE",
            "DOM_DELTA_PAGE",
            "DOM_DELTA_PIXEL",
            "DOM_INPUT_METHOD_DROP",
            "DOM_INPUT_METHOD_HANDWRITING",
            "DOM_INPUT_METHOD_IME",
            "DOM_INPUT_METHOD_KEYBOARD",
            "DOM_INPUT_METHOD_MULTIMODAL",
            "DOM_INPUT_METHOD_OPTION",
            "DOM_INPUT_METHOD_PASTE",
            "DOM_INPUT_METHOD_SCRIPT",
            "DOM_INPUT_METHOD_UNKNOWN",
            "DOM_INPUT_METHOD_VOICE",
            "DOM_KEY_LOCATION_JOYSTICK",
            "DOM_KEY_LOCATION_LEFT",
            "DOM_KEY_LOCATION_MOBILE",
            "DOM_KEY_LOCATION_NUMPAD",
            "DOM_KEY_LOCATION_RIGHT",
            "DOM_KEY_LOCATION_STANDARD",
            "DOM_VK_0",
            "DOM_VK_1",
            "DOM_VK_2",
            "DOM_VK_3",
            "DOM_VK_4",
            "DOM_VK_5",
            "DOM_VK_6",
            "DOM_VK_7",
            "DOM_VK_8",
            "DOM_VK_9",
            "DOM_VK_A",
            "DOM_VK_ACCEPT",
            "DOM_VK_ADD",
            "DOM_VK_ALT",
            "DOM_VK_ALTGR",
            "DOM_VK_AMPERSAND",
            "DOM_VK_ASTERISK",
            "DOM_VK_AT",
            "DOM_VK_ATTN",
            "DOM_VK_B",
            "DOM_VK_BACKSPACE",
            "DOM_VK_BACK_QUOTE",
            "DOM_VK_BACK_SLASH",
            "DOM_VK_BACK_SPACE",
            "DOM_VK_C",
            "DOM_VK_CANCEL",
            "DOM_VK_CAPS_LOCK",
            "DOM_VK_CIRCUMFLEX",
            "DOM_VK_CLEAR",
            "DOM_VK_CLOSE_BRACKET",
            "DOM_VK_CLOSE_CURLY_BRACKET",
            "DOM_VK_CLOSE_PAREN",
            "DOM_VK_COLON",
            "DOM_VK_COMMA",
            "DOM_VK_CONTEXT_MENU",
            "DOM_VK_CONTROL",
            "DOM_VK_CONVERT",
            "DOM_VK_CRSEL",
            "DOM_VK_CTRL",
            "DOM_VK_D",
            "DOM_VK_DECIMAL",
            "DOM_VK_DELETE",
            "DOM_VK_DIVIDE",
            "DOM_VK_DOLLAR",
            "DOM_VK_DOUBLE_QUOTE",
            "DOM_VK_DOWN",
            "DOM_VK_E",
            "DOM_VK_EISU",
            "DOM_VK_END",
            "DOM_VK_ENTER",
            "DOM_VK_EQUALS",
            "DOM_VK_EREOF",
            "DOM_VK_ESCAPE",
            "DOM_VK_EXCLAMATION",
            "DOM_VK_EXECUTE",
            "DOM_VK_EXSEL",
            "DOM_VK_F",
            "DOM_VK_F1",
            "DOM_VK_F10",
            "DOM_VK_F11",
            "DOM_VK_F12",
            "DOM_VK_F13",
            "DOM_VK_F14",
            "DOM_VK_F15",
            "DOM_VK_F16",
            "DOM_VK_F17",
            "DOM_VK_F18",
            "DOM_VK_F19",
            "DOM_VK_F2",
            "DOM_VK_F20",
            "DOM_VK_F21",
            "DOM_VK_F22",
            "DOM_VK_F23",
            "DOM_VK_F24",
            "DOM_VK_F25",
            "DOM_VK_F26",
            "DOM_VK_F27",
            "DOM_VK_F28",
            "DOM_VK_F29",
            "DOM_VK_F3",
            "DOM_VK_F30",
            "DOM_VK_F31",
            "DOM_VK_F32",
            "DOM_VK_F33",
            "DOM_VK_F34",
            "DOM_VK_F35",
            "DOM_VK_F36",
            "DOM_VK_F4",
            "DOM_VK_F5",
            "DOM_VK_F6",
            "DOM_VK_F7",
            "DOM_VK_F8",
            "DOM_VK_F9",
            "DOM_VK_FINAL",
            "DOM_VK_FRONT",
            "DOM_VK_G",
            "DOM_VK_GREATER_THAN",
            "DOM_VK_H",
            "DOM_VK_HANGUL",
            "DOM_VK_HANJA",
            "DOM_VK_HASH",
            "DOM_VK_HELP",
            "DOM_VK_HK_TOGGLE",
            "DOM_VK_HOME",
            "DOM_VK_HYPHEN_MINUS",
            "DOM_VK_I",
            "DOM_VK_INSERT",
            "DOM_VK_J",
            "DOM_VK_JUNJA",
            "DOM_VK_K",
            "DOM_VK_KANA",
            "DOM_VK_KANJI",
            "DOM_VK_L",
            "DOM_VK_LEFT",
            "DOM_VK_LEFT_TAB",
            "DOM_VK_LESS_THAN",
            "DOM_VK_M",
            "DOM_VK_META",
            "DOM_VK_MODECHANGE",
            "DOM_VK_MULTIPLY",
            "DOM_VK_N",
            "DOM_VK_NONCONVERT",
            "DOM_VK_NUMPAD0",
            "DOM_VK_NUMPAD1",
            "DOM_VK_NUMPAD2",
            "DOM_VK_NUMPAD3",
            "DOM_VK_NUMPAD4",
            "DOM_VK_NUMPAD5",
            "DOM_VK_NUMPAD6",
            "DOM_VK_NUMPAD7",
            "DOM_VK_NUMPAD8",
            "DOM_VK_NUMPAD9",
            "DOM_VK_NUM_LOCK",
            "DOM_VK_O",
            "DOM_VK_OEM_1",
            "DOM_VK_OEM_102",
            "DOM_VK_OEM_2",
            "DOM_VK_OEM_3",
            "DOM_VK_OEM_4",
            "DOM_VK_OEM_5",
            "DOM_VK_OEM_6",
            "DOM_VK_OEM_7",
            "DOM_VK_OEM_8",
            "DOM_VK_OEM_COMMA",
            "DOM_VK_OEM_MINUS",
            "DOM_VK_OEM_PERIOD",
            "DOM_VK_OEM_PLUS",
            "DOM_VK_OPEN_BRACKET",
            "DOM_VK_OPEN_CURLY_BRACKET",
            "DOM_VK_OPEN_PAREN",
            "DOM_VK_P",
            "DOM_VK_PA1",
            "DOM_VK_PAGEDOWN",
            "DOM_VK_PAGEUP",
            "DOM_VK_PAGE_DOWN",
            "DOM_VK_PAGE_UP",
            "DOM_VK_PAUSE",
            "DOM_VK_PERCENT",
            "DOM_VK_PERIOD",
            "DOM_VK_PIPE",
            "DOM_VK_PLAY",
            "DOM_VK_PLUS",
            "DOM_VK_PRINT",
            "DOM_VK_PRINTSCREEN",
            "DOM_VK_PROCESSKEY",
            "DOM_VK_PROPERITES",
            "DOM_VK_Q",
            "DOM_VK_QUESTION_MARK",
            "DOM_VK_QUOTE",
            "DOM_VK_R",
            "DOM_VK_REDO",
            "DOM_VK_RETURN",
            "DOM_VK_RIGHT",
            "DOM_VK_S",
            "DOM_VK_SCROLL_LOCK",
            "DOM_VK_SELECT",
            "DOM_VK_SEMICOLON",
            "DOM_VK_SEPARATOR",
            "DOM_VK_SHIFT",
            "DOM_VK_SLASH",
            "DOM_VK_SLEEP",
            "DOM_VK_SPACE",
            "DOM_VK_SUBTRACT",
            "DOM_VK_T",
            "DOM_VK_TAB",
            "DOM_VK_TILDE",
            "DOM_VK_U",
            "DOM_VK_UNDERSCORE",
            "DOM_VK_UNDO",
            "DOM_VK_UNICODE",
            "DOM_VK_UP",
            "DOM_VK_V",
            "DOM_VK_VOLUME_DOWN",
            "DOM_VK_VOLUME_MUTE",
            "DOM_VK_VOLUME_UP",
            "DOM_VK_W",
            "DOM_VK_WIN",
            "DOM_VK_WINDOW",
            "DOM_VK_WIN_ICO_00",
            "DOM_VK_WIN_ICO_CLEAR",
            "DOM_VK_WIN_ICO_HELP",
            "DOM_VK_WIN_OEM_ATTN",
            "DOM_VK_WIN_OEM_AUTO",
            "DOM_VK_WIN_OEM_BACKTAB",
            "DOM_VK_WIN_OEM_CLEAR",
            "DOM_VK_WIN_OEM_COPY",
            "DOM_VK_WIN_OEM_CUSEL",
            "DOM_VK_WIN_OEM_ENLW",
            "DOM_VK_WIN_OEM_FINISH",
            "DOM_VK_WIN_OEM_FJ_JISHO",
            "DOM_VK_WIN_OEM_FJ_LOYA",
            "DOM_VK_WIN_OEM_FJ_MASSHOU",
            "DOM_VK_WIN_OEM_FJ_ROYA",
            "DOM_VK_WIN_OEM_FJ_TOUROKU",
            "DOM_VK_WIN_OEM_JUMP",
            "DOM_VK_WIN_OEM_PA1",
            "DOM_VK_WIN_OEM_PA2",
            "DOM_VK_WIN_OEM_PA3",
            "DOM_VK_WIN_OEM_RESET",
            "DOM_VK_WIN_OEM_WSCTRL",
            "DOM_VK_X",
            "DOM_VK_XF86XK_ADD_FAVORITE",
            "DOM_VK_XF86XK_APPLICATION_LEFT",
            "DOM_VK_XF86XK_APPLICATION_RIGHT",
            "DOM_VK_XF86XK_AUDIO_CYCLE_TRACK",
            "DOM_VK_XF86XK_AUDIO_FORWARD",
            "DOM_VK_XF86XK_AUDIO_LOWER_VOLUME",
            "DOM_VK_XF86XK_AUDIO_MEDIA",
            "DOM_VK_XF86XK_AUDIO_MUTE",
            "DOM_VK_XF86XK_AUDIO_NEXT",
            "DOM_VK_XF86XK_AUDIO_PAUSE",
            "DOM_VK_XF86XK_AUDIO_PLAY",
            "DOM_VK_XF86XK_AUDIO_PREV",
            "DOM_VK_XF86XK_AUDIO_RAISE_VOLUME",
            "DOM_VK_XF86XK_AUDIO_RANDOM_PLAY",
            "DOM_VK_XF86XK_AUDIO_RECORD",
            "DOM_VK_XF86XK_AUDIO_REPEAT",
            "DOM_VK_XF86XK_AUDIO_REWIND",
            "DOM_VK_XF86XK_AUDIO_STOP",
            "DOM_VK_XF86XK_AWAY",
            "DOM_VK_XF86XK_BACK",
            "DOM_VK_XF86XK_BACK_FORWARD",
            "DOM_VK_XF86XK_BATTERY",
            "DOM_VK_XF86XK_BLUE",
            "DOM_VK_XF86XK_BLUETOOTH",
            "DOM_VK_XF86XK_BOOK",
            "DOM_VK_XF86XK_BRIGHTNESS_ADJUST",
            "DOM_VK_XF86XK_CALCULATOR",
            "DOM_VK_XF86XK_CALENDAR",
            "DOM_VK_XF86XK_CD",
            "DOM_VK_XF86XK_CLOSE",
            "DOM_VK_XF86XK_COMMUNITY",
            "DOM_VK_XF86XK_CONTRAST_ADJUST",
            "DOM_VK_XF86XK_COPY",
            "DOM_VK_XF86XK_CUT",
            "DOM_VK_XF86XK_CYCLE_ANGLE",
            "DOM_VK_XF86XK_DISPLAY",
            "DOM_VK_XF86XK_DOCUMENTS",
            "DOM_VK_XF86XK_DOS",
            "DOM_VK_XF86XK_EJECT",
            "DOM_VK_XF86XK_EXCEL",
            "DOM_VK_XF86XK_EXPLORER",
            "DOM_VK_XF86XK_FAVORITES",
            "DOM_VK_XF86XK_FINANCE",
            "DOM_VK_XF86XK_FORWARD",
            "DOM_VK_XF86XK_FRAME_BACK",
            "DOM_VK_XF86XK_FRAME_FORWARD",
            "DOM_VK_XF86XK_GAME",
            "DOM_VK_XF86XK_GO",
            "DOM_VK_XF86XK_GREEN",
            "DOM_VK_XF86XK_HIBERNATE",
            "DOM_VK_XF86XK_HISTORY",
            "DOM_VK_XF86XK_HOME_PAGE",
            "DOM_VK_XF86XK_HOT_LINKS",
            "DOM_VK_XF86XK_I_TOUCH",
            "DOM_VK_XF86XK_KBD_BRIGHTNESS_DOWN",
            "DOM_VK_XF86XK_KBD_BRIGHTNESS_UP",
            "DOM_VK_XF86XK_KBD_LIGHT_ON_OFF",
            "DOM_VK_XF86XK_LAUNCH0",
            "DOM_VK_XF86XK_LAUNCH1",
            "DOM_VK_XF86XK_LAUNCH2",
            "DOM_VK_XF86XK_LAUNCH3",
            "DOM_VK_XF86XK_LAUNCH4",
            "DOM_VK_XF86XK_LAUNCH5",
            "DOM_VK_XF86XK_LAUNCH6",
            "DOM_VK_XF86XK_LAUNCH7",
            "DOM_VK_XF86XK_LAUNCH8",
            "DOM_VK_XF86XK_LAUNCH9",
            "DOM_VK_XF86XK_LAUNCH_A",
            "DOM_VK_XF86XK_LAUNCH_B",
            "DOM_VK_XF86XK_LAUNCH_C",
            "DOM_VK_XF86XK_LAUNCH_D",
            "DOM_VK_XF86XK_LAUNCH_E",
            "DOM_VK_XF86XK_LAUNCH_F",
            "DOM_VK_XF86XK_LIGHT_BULB",
            "DOM_VK_XF86XK_LOG_OFF",
            "DOM_VK_XF86XK_MAIL",
            "DOM_VK_XF86XK_MAIL_FORWARD",
            "DOM_VK_XF86XK_MARKET",
            "DOM_VK_XF86XK_MEETING",
            "DOM_VK_XF86XK_MEMO",
            "DOM_VK_XF86XK_MENU_KB",
            "DOM_VK_XF86XK_MENU_PB",
            "DOM_VK_XF86XK_MESSENGER",
            "DOM_VK_XF86XK_MON_BRIGHTNESS_DOWN",
            "DOM_VK_XF86XK_MON_BRIGHTNESS_UP",
            "DOM_VK_XF86XK_MUSIC",
            "DOM_VK_XF86XK_MY_COMPUTER",
            "DOM_VK_XF86XK_MY_SITES",
            "DOM_VK_XF86XK_NEW",
            "DOM_VK_XF86XK_NEWS",
            "DOM_VK_XF86XK_OFFICE_HOME",
            "DOM_VK_XF86XK_OPEN",
            "DOM_VK_XF86XK_OPEN_URL",
            "DOM_VK_XF86XK_OPTION",
            "DOM_VK_XF86XK_PASTE",
            "DOM_VK_XF86XK_PHONE",
            "DOM_VK_XF86XK_PICTURES",
            "DOM_VK_XF86XK_POWER_DOWN",
            "DOM_VK_XF86XK_POWER_OFF",
            "DOM_VK_XF86XK_RED",
            "DOM_VK_XF86XK_REFRESH",
            "DOM_VK_XF86XK_RELOAD",
            "DOM_VK_XF86XK_REPLY",
            "DOM_VK_XF86XK_ROCKER_DOWN",
            "DOM_VK_XF86XK_ROCKER_ENTER",
            "DOM_VK_XF86XK_ROCKER_UP",
            "DOM_VK_XF86XK_ROTATE_WINDOWS",
            "DOM_VK_XF86XK_ROTATION_KB",
            "DOM_VK_XF86XK_ROTATION_PB",
            "DOM_VK_XF86XK_SAVE",
            "DOM_VK_XF86XK_SCREEN_SAVER",
            "DOM_VK_XF86XK_SCROLL_CLICK",
            "DOM_VK_XF86XK_SCROLL_DOWN",
            "DOM_VK_XF86XK_SCROLL_UP",
            "DOM_VK_XF86XK_SEARCH",
            "DOM_VK_XF86XK_SEND",
            "DOM_VK_XF86XK_SHOP",
            "DOM_VK_XF86XK_SPELL",
            "DOM_VK_XF86XK_SPLIT_SCREEN",
            "DOM_VK_XF86XK_STANDBY",
            "DOM_VK_XF86XK_START",
            "DOM_VK_XF86XK_STOP",
            "DOM_VK_XF86XK_SUBTITLE",
            "DOM_VK_XF86XK_SUPPORT",
            "DOM_VK_XF86XK_SUSPEND",
            "DOM_VK_XF86XK_TASK_PANE",
            "DOM_VK_XF86XK_TERMINAL",
            "DOM_VK_XF86XK_TIME",
            "DOM_VK_XF86XK_TOOLS",
            "DOM_VK_XF86XK_TOP_MENU",
            "DOM_VK_XF86XK_TO_DO_LIST",
            "DOM_VK_XF86XK_TRAVEL",
            "DOM_VK_XF86XK_USER1KB",
            "DOM_VK_XF86XK_USER2KB",
            "DOM_VK_XF86XK_USER_PB",
            "DOM_VK_XF86XK_UWB",
            "DOM_VK_XF86XK_VENDOR_HOME",
            "DOM_VK_XF86XK_VIDEO",
            "DOM_VK_XF86XK_VIEW",
            "DOM_VK_XF86XK_WAKE_UP",
            "DOM_VK_XF86XK_WEB_CAM",
            "DOM_VK_XF86XK_WHEEL_BUTTON",
            "DOM_VK_XF86XK_WLAN",
            "DOM_VK_XF86XK_WORD",
            "DOM_VK_XF86XK_WWW",
            "DOM_VK_XF86XK_XFER",
            "DOM_VK_XF86XK_YELLOW",
            "DOM_VK_XF86XK_ZOOM_IN",
            "DOM_VK_XF86XK_ZOOM_OUT",
            "DOM_VK_Y",
            "DOM_VK_Z",
            "DOM_VK_ZOOM",
            "DONE",
            "DONT_CARE",
            "DOWNLOADING",
            "DRAGDROP",
            "DRAW_BUFFER0",
            "DRAW_BUFFER1",
            "DRAW_BUFFER10",
            "DRAW_BUFFER11",
            "DRAW_BUFFER12",
            "DRAW_BUFFER13",
            "DRAW_BUFFER14",
            "DRAW_BUFFER15",
            "DRAW_BUFFER2",
            "DRAW_BUFFER3",
            "DRAW_BUFFER4",
            "DRAW_BUFFER5",
            "DRAW_BUFFER6",
            "DRAW_BUFFER7",
            "DRAW_BUFFER8",
            "DRAW_BUFFER9",
            "DRAW_FRAMEBUFFER",
            "DRAW_FRAMEBUFFER_BINDING",
            "DST_ALPHA",
            "DST_COLOR",
            "DYNAMIC_COPY",
            "DYNAMIC_DRAW",
            "DYNAMIC_READ",
            "DataChannel",
            "DataTransfer",
            "DataTransferItem",
            "DataTransferItemList",
            "DataView",
            "Date",
            "DateTimeFormat",
            "DecompressionStream",
            "DelayNode",
            "DeprecationReportBody",
            "DesktopNotification",
            "DesktopNotificationCenter",
            "DeviceLightEvent",
            "DeviceMotionEvent",
            "DeviceMotionEventAcceleration",
            "DeviceMotionEventRotationRate",
            "DeviceOrientationEvent",
            "DeviceProximityEvent",
            "DeviceStorage",
            "DeviceStorageChangeEvent",
            "Directory",
            "DisplayNames",
            "Document",
            "DocumentFragment",
            "DocumentTimeline",
            "DocumentType",
            "DragEvent",
            "DynamicsCompressorNode",
            "E",
            "ELEMENT_ARRAY_BUFFER",
            "ELEMENT_ARRAY_BUFFER_BINDING",
            "ELEMENT_NODE",
            "EMPTY",
            "ENCODING_ERR",
            "ENDED",
            "END_TO_END",
            "END_TO_START",
            "ENTITY_NODE",
            "ENTITY_REFERENCE_NODE",
            "EPSILON",
            "EQUAL",
            "EQUALPOWER",
            "ERROR",
            "EXPONENTIAL_DISTANCE",
            "Element",
            "ElementInternals",
            "ElementQuery",
            "EnterPictureInPictureEvent",
            "Entity",
            "EntityReference",
            "Error",
            "ErrorEvent",
            "EvalError",
            "Event",
            "EventException",
            "EventSource",
            "EventTarget",
            "External",
            "FASTEST",
            "FIDOSDK",
            "FILTER_ACCEPT",
            "FILTER_INTERRUPT",
            "FILTER_REJECT",
            "FILTER_SKIP",
            "FINISHED_STATE",
            "FIRST_ORDERED_NODE_TYPE",
            "FLOAT",
            "FLOAT_32_UNSIGNED_INT_24_8_REV",
            "FLOAT_MAT2",
            "FLOAT_MAT2x3",
            "FLOAT_MAT2x4",
            "FLOAT_MAT3",
            "FLOAT_MAT3x2",
            "FLOAT_MAT3x4",
            "FLOAT_MAT4",
            "FLOAT_MAT4x2",
            "FLOAT_MAT4x3",
            "FLOAT_VEC2",
            "FLOAT_VEC3",
            "FLOAT_VEC4",
            "FOCUS",
            "FONT_FACE_RULE",
            "FONT_FEATURE_VALUES_RULE",
            "FRAGMENT",
            "FRAGMENT_SHADER",
            "FRAGMENT_SHADER_DERIVATIVE_HINT",
            "FRAGMENT_SHADER_DERIVATIVE_HINT_OES",
            "FRAMEBUFFER",
            "FRAMEBUFFER_ATTACHMENT_ALPHA_SIZE",
            "FRAMEBUFFER_ATTACHMENT_BLUE_SIZE",
            "FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING",
            "FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE",
            "FRAMEBUFFER_ATTACHMENT_DEPTH_SIZE",
            "FRAMEBUFFER_ATTACHMENT_GREEN_SIZE",
            "FRAMEBUFFER_ATTACHMENT_OBJECT_NAME",
            "FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE",
            "FRAMEBUFFER_ATTACHMENT_RED_SIZE",
            "FRAMEBUFFER_ATTACHMENT_STENCIL_SIZE",
            "FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE",
            "FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER",
            "FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL",
            "FRAMEBUFFER_BINDING",
            "FRAMEBUFFER_COMPLETE",
            "FRAMEBUFFER_DEFAULT",
            "FRAMEBUFFER_INCOMPLETE_ATTACHMENT",
            "FRAMEBUFFER_INCOMPLETE_DIMENSIONS",
            "FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT",
            "FRAMEBUFFER_INCOMPLETE_MULTISAMPLE",
            "FRAMEBUFFER_UNSUPPORTED",
            "FRONT",
            "FRONT_AND_BACK",
            "FRONT_FACE",
            "FUNC_ADD",
            "FUNC_REVERSE_SUBTRACT",
            "FUNC_SUBTRACT",
            "FeaturePolicy",
            "FeaturePolicyViolationReportBody",
            "FederatedCredential",
            "Feed",
            "FeedEntry",
            "File",
            "FileError",
            "FileList",
            "FileReader",
            "FileSystem",
            "FileSystemDirectoryEntry",
            "FileSystemDirectoryReader",
            "FileSystemEntry",
            "FileSystemFileEntry",
            "FinalizationRegistry",
            "FindInPage",
            "Float32Array",
            "Float64Array",
            "FocusEvent",
            "FontFace",
            "FontFaceSet",
            "FontFaceSetLoadEvent",
            "FormData",
            "FormDataEvent",
            "FragmentDirective",
            "Function",
            "GENERATE_MIPMAP_HINT",
            "GEQUAL",
            "GREATER",
            "GREEN",
            "GREEN_BITS",
            "GainNode",
            "Gamepad",
            "GamepadAxisMoveEvent",
            "GamepadButton",
            "GamepadButtonEvent",
            "GamepadEvent",
            "GamepadHapticActuator",
            "GamepadPose",
            "Geolocation",
            "GeolocationCoordinates",
            "GeolocationPosition",
            "GeolocationPositionError",
            "GestureEvent",
            "Global",
            "Gyroscope",
            "HALF_FLOAT",
            "HAVE_CURRENT_DATA",
            "HAVE_ENOUGH_DATA",
            "HAVE_FUTURE_DATA",
            "HAVE_METADATA",
            "HAVE_NOTHING",
            "HEADERS_RECEIVED",
            "HIDDEN",
            "HIERARCHY_REQUEST_ERR",
            "HIGHPASS",
            "HIGHSHELF",
            "HIGH_FLOAT",
            "HIGH_INT",
            "HORIZONTAL",
            "HORIZONTAL_AXIS",
            "HRTF",
            "HTMLAllCollection",
            "HTMLAnchorElement",
            "HTMLAppletElement",
            "HTMLAreaElement",
            "HTMLAudioElement",
            "HTMLBRElement",
            "HTMLBaseElement",
            "HTMLBaseFontElement",
            "HTMLBlockquoteElement",
            "HTMLBodyElement",
            "HTMLButtonElement",
            "HTMLCanvasElement",
            "HTMLCollection",
            "HTMLCommandElement",
            "HTMLContentElement",
            "HTMLDListElement",
            "HTMLDataElement",
            "HTMLDataListElement",
            "HTMLDetailsElement",
            "HTMLDialogElement",
            "HTMLDirectoryElement",
            "HTMLDivElement",
            "HTMLDocument",
            "HTMLElement",
            "HTMLEmbedElement",
            "HTMLFieldSetElement",
            "HTMLFontElement",
            "HTMLFormControlsCollection",
            "HTMLFormElement",
            "HTMLFrameElement",
            "HTMLFrameSetElement",
            "HTMLHRElement",
            "HTMLHeadElement",
            "HTMLHeadingElement",
            "HTMLHtmlElement",
            "HTMLIFrameElement",
            "HTMLImageElement",
            "HTMLInputElement",
            "HTMLIsIndexElement",
            "HTMLKeygenElement",
            "HTMLLIElement",
            "HTMLLabelElement",
            "HTMLLegendElement",
            "HTMLLinkElement",
            "HTMLMapElement",
            "HTMLMarqueeElement",
            "HTMLMediaElement",
            "HTMLMenuElement",
            "HTMLMenuItemElement",
            "HTMLMetaElement",
            "HTMLMeterElement",
            "HTMLModElement",
            "HTMLOListElement",
            "HTMLObjectElement",
            "HTMLOptGroupElement",
            "HTMLOptionElement",
            "HTMLOptionsCollection",
            "HTMLOutputElement",
            "HTMLParagraphElement",
            "HTMLParamElement",
            "HTMLPictureElement",
            "HTMLPreElement",
            "HTMLProgressElement",
            "HTMLPropertiesCollection",
            "HTMLQuoteElement",
            "HTMLScriptElement",
            "HTMLSelectElement",
            "HTMLShadowElement",
            "HTMLSlotElement",
            "HTMLSourceElement",
            "HTMLSpanElement",
            "HTMLStyleElement",
            "HTMLTableCaptionElement",
            "HTMLTableCellElement",
            "HTMLTableColElement",
            "HTMLTableElement",
            "HTMLTableRowElement",
            "HTMLTableSectionElement",
            "HTMLTemplateElement",
            "HTMLTextAreaElement",
            "HTMLTimeElement",
            "HTMLTitleElement",
            "HTMLTrackElement",
            "HTMLUListElement",
            "HTMLUnknownElement",
            "HTMLVideoElement",
            "HashChangeEvent",
            "Headers",
            "History",
            "Hz",
            "ICE_CHECKING",
            "ICE_CLOSED",
            "ICE_COMPLETED",
            "ICE_CONNECTED",
            "ICE_FAILED",
            "ICE_GATHERING",
            "ICE_WAITING",
            "IDBCursor",
            "IDBCursorWithValue",
            "IDBDatabase",
            "IDBDatabaseException",
            "IDBFactory",
            "IDBFileHandle",
            "IDBFileRequest",
            "IDBIndex",
            "IDBKeyRange",
            "IDBMutableFile",
            "IDBObjectStore",
            "IDBOpenDBRequest",
            "IDBRequest",
            "IDBTransaction",
            "IDBVersionChangeEvent",
            "IDLE",
            "IIRFilterNode",
            "IMPLEMENTATION_COLOR_READ_FORMAT",
            "IMPLEMENTATION_COLOR_READ_TYPE",
            "IMPORT_RULE",
            "INCR",
            "INCR_WRAP",
            "INDEX",
            "INDEX_SIZE_ERR",
            "INDIRECT",
            "INT",
            "INTERLEAVED_ATTRIBS",
            "INT_2_10_10_10_REV",
            "INT_SAMPLER_2D",
            "INT_SAMPLER_2D_ARRAY",
            "INT_SAMPLER_3D",
            "INT_SAMPLER_CUBE",
            "INT_VEC2",
            "INT_VEC3",
            "INT_VEC4",
            "INUSE_ATTRIBUTE_ERR",
            "INVALID_ACCESS_ERR",
            "INVALID_CHARACTER_ERR",
            "INVALID_ENUM",
            "INVALID_EXPRESSION_ERR",
            "INVALID_FRAMEBUFFER_OPERATION",
            "INVALID_INDEX",
            "INVALID_MODIFICATION_ERR",
            "INVALID_NODE_TYPE_ERR",
            "INVALID_OPERATION",
            "INVALID_STATE_ERR",
            "INVALID_VALUE",
            "INVERSE_DISTANCE",
            "INVERT",
            "IceCandidate",
            "IdleDeadline",
            "Image",
            "ImageBitmap",
            "ImageBitmapRenderingContext",
            "ImageCapture",
            "ImageData",
            "Infinity",
            "InputDeviceCapabilities",
            "InputDeviceInfo",
            "InputEvent",
            "InputMethodContext",
            "InstallTrigger",
            "InstallTriggerImpl",
            "Instance",
            "Int16Array",
            "Int32Array",
            "Int8Array",
            "Intent",
            "InternalError",
            "IntersectionObserver",
            "IntersectionObserverEntry",
            "Intl",
            "IsSearchProviderInstalled",
            "Iterator",
            "JSON",
            "KEEP",
            "KEYDOWN",
            "KEYFRAMES_RULE",
            "KEYFRAME_RULE",
            "KEYPRESS",
            "KEYUP",
            "KeyEvent",
            "Keyboard",
            "KeyboardEvent",
            "KeyboardLayoutMap",
            "KeyframeEffect",
            "LENGTHADJUST_SPACING",
            "LENGTHADJUST_SPACINGANDGLYPHS",
            "LENGTHADJUST_UNKNOWN",
            "LEQUAL",
            "LESS",
            "LINEAR",
            "LINEAR_DISTANCE",
            "LINEAR_MIPMAP_LINEAR",
            "LINEAR_MIPMAP_NEAREST",
            "LINES",
            "LINE_LOOP",
            "LINE_STRIP",
            "LINE_WIDTH",
            "LINK_STATUS",
            "LIVE",
            "LN10",
            "LN2",
            "LOADED",
            "LOADING",
            "LOG10E",
            "LOG2E",
            "LOWPASS",
            "LOWSHELF",
            "LOW_FLOAT",
            "LOW_INT",
            "LSException",
            "LSParserFilter",
            "LUMINANCE",
            "LUMINANCE_ALPHA",
            "LargestContentfulPaint",
            "LayoutShift",
            "LayoutShiftAttribution",
            "LinearAccelerationSensor",
            "LinkError",
            "ListFormat",
            "LocalMediaStream",
            "Locale",
            "Location",
            "Lock",
            "LockManager",
            "MAP_READ",
            "MAP_WRITE",
            "MAX",
            "MAX_3D_TEXTURE_SIZE",
            "MAX_ARRAY_TEXTURE_LAYERS",
            "MAX_CLIENT_WAIT_TIMEOUT_WEBGL",
            "MAX_COLOR_ATTACHMENTS",
            "MAX_COMBINED_FRAGMENT_UNIFORM_COMPONENTS",
            "MAX_COMBINED_TEXTURE_IMAGE_UNITS",
            "MAX_COMBINED_UNIFORM_BLOCKS",
            "MAX_COMBINED_VERTEX_UNIFORM_COMPONENTS",
            "MAX_CUBE_MAP_TEXTURE_SIZE",
            "MAX_DRAW_BUFFERS",
            "MAX_ELEMENTS_INDICES",
            "MAX_ELEMENTS_VERTICES",
            "MAX_ELEMENT_INDEX",
            "MAX_FRAGMENT_INPUT_COMPONENTS",
            "MAX_FRAGMENT_UNIFORM_BLOCKS",
            "MAX_FRAGMENT_UNIFORM_COMPONENTS",
            "MAX_FRAGMENT_UNIFORM_VECTORS",
            "MAX_PROGRAM_TEXEL_OFFSET",
            "MAX_RENDERBUFFER_SIZE",
            "MAX_SAFE_INTEGER",
            "MAX_SAMPLES",
            "MAX_SERVER_WAIT_TIMEOUT",
            "MAX_TEXTURE_IMAGE_UNITS",
            "MAX_TEXTURE_LOD_BIAS",
            "MAX_TEXTURE_MAX_ANISOTROPY_EXT",
            "MAX_TEXTURE_SIZE",
            "MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS",
            "MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS",
            "MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS",
            "MAX_UNIFORM_BLOCK_SIZE",
            "MAX_UNIFORM_BUFFER_BINDINGS",
            "MAX_VALUE",
            "MAX_VARYING_COMPONENTS",
            "MAX_VARYING_VECTORS",
            "MAX_VERTEX_ATTRIBS",
            "MAX_VERTEX_OUTPUT_COMPONENTS",
            "MAX_VERTEX_TEXTURE_IMAGE_UNITS",
            "MAX_VERTEX_UNIFORM_BLOCKS",
            "MAX_VERTEX_UNIFORM_COMPONENTS",
            "MAX_VERTEX_UNIFORM_VECTORS",
            "MAX_VIEWPORT_DIMS",
            "MEDIA_ERR_ABORTED",
            "MEDIA_ERR_DECODE",
            "MEDIA_ERR_ENCRYPTED",
            "MEDIA_ERR_NETWORK",
            "MEDIA_ERR_SRC_NOT_SUPPORTED",
            "MEDIA_KEYERR_CLIENT",
            "MEDIA_KEYERR_DOMAIN",
            "MEDIA_KEYERR_HARDWARECHANGE",
            "MEDIA_KEYERR_OUTPUT",
            "MEDIA_KEYERR_SERVICE",
            "MEDIA_KEYERR_UNKNOWN",
            "MEDIA_RULE",
            "MEDIUM_FLOAT",
            "MEDIUM_INT",
            "META_MASK",
            "MIDIAccess",
            "MIDIConnectionEvent",
            "MIDIInput",
            "MIDIInputMap",
            "MIDIMessageEvent",
            "MIDIOutput",
            "MIDIOutputMap",
            "MIDIPort",
            "MIN",
            "MIN_PROGRAM_TEXEL_OFFSET",
            "MIN_SAFE_INTEGER",
            "MIN_VALUE",
            "MIRRORED_REPEAT",
            "MODE_ASYNCHRONOUS",
            "MODE_SYNCHRONOUS",
            "MODIFICATION",
            "MOUSEDOWN",
            "MOUSEDRAG",
            "MOUSEMOVE",
            "MOUSEOUT",
            "MOUSEOVER",
            "MOUSEUP",
            "MOZ_KEYFRAMES_RULE",
            "MOZ_KEYFRAME_RULE",
            "MOZ_SOURCE_CURSOR",
            "MOZ_SOURCE_ERASER",
            "MOZ_SOURCE_KEYBOARD",
            "MOZ_SOURCE_MOUSE",
            "MOZ_SOURCE_PEN",
            "MOZ_SOURCE_TOUCH",
            "MOZ_SOURCE_UNKNOWN",
            "MSGESTURE_FLAG_BEGIN",
            "MSGESTURE_FLAG_CANCEL",
            "MSGESTURE_FLAG_END",
            "MSGESTURE_FLAG_INERTIA",
            "MSGESTURE_FLAG_NONE",
            "MSPOINTER_TYPE_MOUSE",
            "MSPOINTER_TYPE_PEN",
            "MSPOINTER_TYPE_TOUCH",
            "MS_ASYNC_CALLBACK_STATUS_ASSIGN_DELEGATE",
            "MS_ASYNC_CALLBACK_STATUS_CANCEL",
            "MS_ASYNC_CALLBACK_STATUS_CHOOSEANY",
            "MS_ASYNC_CALLBACK_STATUS_ERROR",
            "MS_ASYNC_CALLBACK_STATUS_JOIN",
            "MS_ASYNC_OP_STATUS_CANCELED",
            "MS_ASYNC_OP_STATUS_ERROR",
            "MS_ASYNC_OP_STATUS_SUCCESS",
            "MS_MANIPULATION_STATE_ACTIVE",
            "MS_MANIPULATION_STATE_CANCELLED",
            "MS_MANIPULATION_STATE_COMMITTED",
            "MS_MANIPULATION_STATE_DRAGGING",
            "MS_MANIPULATION_STATE_INERTIA",
            "MS_MANIPULATION_STATE_PRESELECT",
            "MS_MANIPULATION_STATE_SELECTING",
            "MS_MANIPULATION_STATE_STOPPED",
            "MS_MEDIA_ERR_ENCRYPTED",
            "MS_MEDIA_KEYERR_CLIENT",
            "MS_MEDIA_KEYERR_DOMAIN",
            "MS_MEDIA_KEYERR_HARDWARECHANGE",
            "MS_MEDIA_KEYERR_OUTPUT",
            "MS_MEDIA_KEYERR_SERVICE",
            "MS_MEDIA_KEYERR_UNKNOWN",
            "Map",
            "Math",
            "MathMLElement",
            "MediaCapabilities",
            "MediaCapabilitiesInfo",
            "MediaController",
            "MediaDeviceInfo",
            "MediaDevices",
            "MediaElementAudioSourceNode",
            "MediaEncryptedEvent",
            "MediaError",
            "MediaKeyError",
            "MediaKeyEvent",
            "MediaKeyMessageEvent",
            "MediaKeyNeededEvent",
            "MediaKeySession",
            "MediaKeyStatusMap",
            "MediaKeySystemAccess",
            "MediaKeys",
            "MediaList",
            "MediaMetadata",
            "MediaQueryList",
            "MediaQueryListEvent",
            "MediaRecorder",
            "MediaRecorderErrorEvent",
            "MediaSession",
            "MediaSettingsRange",
            "MediaSource",
            "MediaStream",
            "MediaStreamAudioDestinationNode",
            "MediaStreamAudioSourceNode",
            "MediaStreamEvent",
            "MediaStreamTrack",
            "MediaStreamTrackAudioSourceNode",
            "MediaStreamTrackEvent",
            "Memory",
            "MessageChannel",
            "MessageEvent",
            "MessagePort",
            "Methods",
            "MimeType",
            "MimeTypeArray",
            "Module",
            "MouseEvent",
            "MouseScrollEvent",
            "MozAnimation",
            "MozAnimationDelay",
            "MozAnimationDirection",
            "MozAnimationDuration",
            "MozAnimationFillMode",
            "MozAnimationIterationCount",
            "MozAnimationName",
            "MozAnimationPlayState",
            "MozAnimationTimingFunction",
            "MozAppearance",
            "MozBackfaceVisibility",
            "MozBinding",
            "MozBorderBottomColors",
            "MozBorderEnd",
            "MozBorderEndColor",
            "MozBorderEndStyle",
            "MozBorderEndWidth",
            "MozBorderImage",
            "MozBorderLeftColors",
            "MozBorderRightColors",
            "MozBorderStart",
            "MozBorderStartColor",
            "MozBorderStartStyle",
            "MozBorderStartWidth",
            "MozBorderTopColors",
            "MozBoxAlign",
            "MozBoxDirection",
            "MozBoxFlex",
            "MozBoxOrdinalGroup",
            "MozBoxOrient",
            "MozBoxPack",
            "MozBoxSizing",
            "MozCSSKeyframeRule",
            "MozCSSKeyframesRule",
            "MozColumnCount",
            "MozColumnFill",
            "MozColumnGap",
            "MozColumnRule",
            "MozColumnRuleColor",
            "MozColumnRuleStyle",
            "MozColumnRuleWidth",
            "MozColumnWidth",
            "MozColumns",
            "MozContactChangeEvent",
            "MozFloatEdge",
            "MozFontFeatureSettings",
            "MozFontLanguageOverride",
            "MozForceBrokenImageIcon",
            "MozHyphens",
            "MozImageRegion",
            "MozMarginEnd",
            "MozMarginStart",
            "MozMmsEvent",
            "MozMmsMessage",
            "MozMobileMessageThread",
            "MozOSXFontSmoothing",
            "MozOrient",
            "MozOsxFontSmoothing",
            "MozOutlineRadius",
            "MozOutlineRadiusBottomleft",
            "MozOutlineRadiusBottomright",
            "MozOutlineRadiusTopleft",
            "MozOutlineRadiusTopright",
            "MozPaddingEnd",
            "MozPaddingStart",
            "MozPerspective",
            "MozPerspectiveOrigin",
            "MozPowerManager",
            "MozSettingsEvent",
            "MozSmsEvent",
            "MozSmsMessage",
            "MozStackSizing",
            "MozTabSize",
            "MozTextAlignLast",
            "MozTextDecorationColor",
            "MozTextDecorationLine",
            "MozTextDecorationStyle",
            "MozTextSizeAdjust",
            "MozTransform",
            "MozTransformOrigin",
            "MozTransformStyle",
            "MozTransition",
            "MozTransitionDelay",
            "MozTransitionDuration",
            "MozTransitionProperty",
            "MozTransitionTimingFunction",
            "MozUserFocus",
            "MozUserInput",
            "MozUserModify",
            "MozUserSelect",
            "MozWindowDragging",
            "MozWindowShadow",
            "MutationEvent",
            "MutationObserver",
            "MutationRecord",
            "NAMESPACE_ERR",
            "NAMESPACE_RULE",
            "NEAREST",
            "NEAREST_MIPMAP_LINEAR",
            "NEAREST_MIPMAP_NEAREST",
            "NEGATIVE_INFINITY",
            "NETWORK_EMPTY",
            "NETWORK_ERR",
            "NETWORK_IDLE",
            "NETWORK_LOADED",
            "NETWORK_LOADING",
            "NETWORK_NO_SOURCE",
            "NEVER",
            "NEW",
            "NEXT",
            "NEXT_NO_DUPLICATE",
            "NICEST",
            "NODE_AFTER",
            "NODE_BEFORE",
            "NODE_BEFORE_AND_AFTER",
            "NODE_INSIDE",
            "NONE",
            "NON_TRANSIENT_ERR",
            "NOTATION_NODE",
            "NOTCH",
            "NOTEQUAL",
            "NOT_ALLOWED_ERR",
            "NOT_FOUND_ERR",
            "NOT_READABLE_ERR",
            "NOT_SUPPORTED_ERR",
            "NO_DATA_ALLOWED_ERR",
            "NO_ERR",
            "NO_ERROR",
            "NO_MODIFICATION_ALLOWED_ERR",
            "NUMBER_TYPE",
            "NUM_COMPRESSED_TEXTURE_FORMATS",
            "NaN",
            "NamedNodeMap",
            "NavigationPreloadManager",
            "Navigator",
            "NearbyLinks",
            "NetworkInformation",
            "Node",
            "NodeFilter",
            "NodeIterator",
            "NodeList",
            "Notation",
            "Notification",
            "NotifyPaintEvent",
            "Number",
            "NumberFormat",
            "OBJECT_TYPE",
            "OBSOLETE",
            "OK",
            "ONE",
            "ONE_MINUS_CONSTANT_ALPHA",
            "ONE_MINUS_CONSTANT_COLOR",
            "ONE_MINUS_DST_ALPHA",
            "ONE_MINUS_DST_COLOR",
            "ONE_MINUS_SRC_ALPHA",
            "ONE_MINUS_SRC_COLOR",
            "OPEN",
            "OPENED",
            "OPENING",
            "ORDERED_NODE_ITERATOR_TYPE",
            "ORDERED_NODE_SNAPSHOT_TYPE",
            "OTHER_ERROR",
            "OUT_OF_MEMORY",
            "Object",
            "OfflineAudioCompletionEvent",
            "OfflineAudioContext",
            "OfflineResourceList",
            "OffscreenCanvas",
            "OffscreenCanvasRenderingContext2D",
            "Option",
            "OrientationSensor",
            "OscillatorNode",
            "OverconstrainedError",
            "OverflowEvent",
            "PACK_ALIGNMENT",
            "PACK_ROW_LENGTH",
            "PACK_SKIP_PIXELS",
            "PACK_SKIP_ROWS",
            "PAGE_RULE",
            "PARSE_ERR",
            "PATHSEG_ARC_ABS",
            "PATHSEG_ARC_REL",
            "PATHSEG_CLOSEPATH",
            "PATHSEG_CURVETO_CUBIC_ABS",
            "PATHSEG_CURVETO_CUBIC_REL",
            "PATHSEG_CURVETO_CUBIC_SMOOTH_ABS",
            "PATHSEG_CURVETO_CUBIC_SMOOTH_REL",
            "PATHSEG_CURVETO_QUADRATIC_ABS",
            "PATHSEG_CURVETO_QUADRATIC_REL",
            "PATHSEG_CURVETO_QUADRATIC_SMOOTH_ABS",
            "PATHSEG_CURVETO_QUADRATIC_SMOOTH_REL",
            "PATHSEG_LINETO_ABS",
            "PATHSEG_LINETO_HORIZONTAL_ABS",
            "PATHSEG_LINETO_HORIZONTAL_REL",
            "PATHSEG_LINETO_REL",
            "PATHSEG_LINETO_VERTICAL_ABS",
            "PATHSEG_LINETO_VERTICAL_REL",
            "PATHSEG_MOVETO_ABS",
            "PATHSEG_MOVETO_REL",
            "PATHSEG_UNKNOWN",
            "PATH_EXISTS_ERR",
            "PEAKING",
            "PERMISSION_DENIED",
            "PERSISTENT",
            "PI",
            "PIXEL_PACK_BUFFER",
            "PIXEL_PACK_BUFFER_BINDING",
            "PIXEL_UNPACK_BUFFER",
            "PIXEL_UNPACK_BUFFER_BINDING",
            "PLAYING_STATE",
            "POINTS",
            "POLYGON_OFFSET_FACTOR",
            "POLYGON_OFFSET_FILL",
            "POLYGON_OFFSET_UNITS",
            "POSITION_UNAVAILABLE",
            "POSITIVE_INFINITY",
            "PREV",
            "PREV_NO_DUPLICATE",
            "PROCESSING_INSTRUCTION_NODE",
            "PageChangeEvent",
            "PageTransitionEvent",
            "PaintRequest",
            "PaintRequestList",
            "PannerNode",
            "PasswordCredential",
            "Path2D",
            "PaymentAddress",
            "PaymentInstruments",
            "PaymentManager",
            "PaymentMethodChangeEvent",
            "PaymentRequest",
            "PaymentRequestUpdateEvent",
            "PaymentResponse",
            "Performance",
            "PerformanceElementTiming",
            "PerformanceEntry",
            "PerformanceEventTiming",
            "PerformanceLongTaskTiming",
            "PerformanceMark",
            "PerformanceMeasure",
            "PerformanceNavigation",
            "PerformanceNavigationTiming",
            "PerformanceObserver",
            "PerformanceObserverEntryList",
            "PerformancePaintTiming",
            "PerformanceResourceTiming",
            "PerformanceServerTiming",
            "PerformanceTiming",
            "PeriodicSyncManager",
            "PeriodicWave",
            "PermissionStatus",
            "Permissions",
            "PhotoCapabilities",
            "PictureInPictureWindow",
            "Plugin",
            "PluginArray",
            "PluralRules",
            "PointerEvent",
            "PopStateEvent",
            "PopupBlockedEvent",
            "Presentation",
            "PresentationAvailability",
            "PresentationConnection",
            "PresentationConnectionAvailableEvent",
            "PresentationConnectionCloseEvent",
            "PresentationConnectionList",
            "PresentationReceiver",
            "PresentationRequest",
            "ProcessingInstruction",
            "ProgressEvent",
            "Promise",
            "PromiseRejectionEvent",
            "PropertyNodeList",
            "Proxy",
            "PublicKeyCredential",
            "PushManager",
            "PushSubscription",
            "PushSubscriptionOptions",
            "Q",
            "QUERY_RESOLVE",
            "QUERY_RESULT",
            "QUERY_RESULT_AVAILABLE",
            "QUOTA_ERR",
            "QUOTA_EXCEEDED_ERR",
            "QueryInterface",
            "R11F_G11F_B10F",
            "R16F",
            "R16I",
            "R16UI",
            "R32F",
            "R32I",
            "R32UI",
            "R8",
            "R8I",
            "R8UI",
            "R8_SNORM",
            "RASTERIZER_DISCARD",
            "READ",
            "READ_BUFFER",
            "READ_FRAMEBUFFER",
            "READ_FRAMEBUFFER_BINDING",
            "READ_ONLY",
            "READ_ONLY_ERR",
            "READ_WRITE",
            "RED",
            "RED_BITS",
            "RED_INTEGER",
            "REMOVAL",
            "RENDERBUFFER",
            "RENDERBUFFER_ALPHA_SIZE",
            "RENDERBUFFER_BINDING",
            "RENDERBUFFER_BLUE_SIZE",
            "RENDERBUFFER_DEPTH_SIZE",
            "RENDERBUFFER_GREEN_SIZE",
            "RENDERBUFFER_HEIGHT",
            "RENDERBUFFER_INTERNAL_FORMAT",
            "RENDERBUFFER_RED_SIZE",
            "RENDERBUFFER_SAMPLES",
            "RENDERBUFFER_STENCIL_SIZE",
            "RENDERBUFFER_WIDTH",
            "RENDERER",
            "RENDERING_INTENT_ABSOLUTE_COLORIMETRIC",
            "RENDERING_INTENT_AUTO",
            "RENDERING_INTENT_PERCEPTUAL",
            "RENDERING_INTENT_RELATIVE_COLORIMETRIC",
            "RENDERING_INTENT_SATURATION",
            "RENDERING_INTENT_UNKNOWN",
            "RENDER_ATTACHMENT",
            "REPEAT",
            "REPLACE",
            "RG",
            "RG16F",
            "RG16I",
            "RG16UI",
            "RG32F",
            "RG32I",
            "RG32UI",
            "RG8",
            "RG8I",
            "RG8UI",
            "RG8_SNORM",
            "RGB",
            "RGB10_A2",
            "RGB10_A2UI",
            "RGB16F",
            "RGB16I",
            "RGB16UI",
            "RGB32F",
            "RGB32I",
            "RGB32UI",
            "RGB565",
            "RGB5_A1",
            "RGB8",
            "RGB8I",
            "RGB8UI",
            "RGB8_SNORM",
            "RGB9_E5",
            "RGBA",
            "RGBA16F",
            "RGBA16I",
            "RGBA16UI",
            "RGBA32F",
            "RGBA32I",
            "RGBA32UI",
            "RGBA4",
            "RGBA8",
            "RGBA8I",
            "RGBA8UI",
            "RGBA8_SNORM",
            "RGBA_INTEGER",
            "RGBColor",
            "RGB_INTEGER",
            "RG_INTEGER",
            "ROTATION_CLOCKWISE",
            "ROTATION_COUNTERCLOCKWISE",
            "RTCCertificate",
            "RTCDTMFSender",
            "RTCDTMFToneChangeEvent",
            "RTCDataChannel",
            "RTCDataChannelEvent",
            "RTCDtlsTransport",
            "RTCError",
            "RTCErrorEvent",
            "RTCIceCandidate",
            "RTCIceTransport",
            "RTCPeerConnection",
            "RTCPeerConnectionIceErrorEvent",
            "RTCPeerConnectionIceEvent",
            "RTCRtpReceiver",
            "RTCRtpSender",
            "RTCRtpTransceiver",
            "RTCSctpTransport",
            "RTCSessionDescription",
            "RTCStatsReport",
            "RTCTrackEvent",
            "RadioNodeList",
            "Range",
            "RangeError",
            "RangeException",
            "ReadableStream",
            "ReadableStreamDefaultReader",
            "RecordErrorEvent",
            "Rect",
            "ReferenceError",
            "Reflect",
            "RegExp",
            "RelativeOrientationSensor",
            "RelativeTimeFormat",
            "RemotePlayback",
            "Report",
            "ReportBody",
            "ReportingObserver",
            "Request",
            "ResizeObserver",
            "ResizeObserverEntry",
            "ResizeObserverSize",
            "Response",
            "RuntimeError",
            "SAMPLER_2D",
            "SAMPLER_2D_ARRAY",
            "SAMPLER_2D_ARRAY_SHADOW",
            "SAMPLER_2D_SHADOW",
            "SAMPLER_3D",
            "SAMPLER_BINDING",
            "SAMPLER_CUBE",
            "SAMPLER_CUBE_SHADOW",
            "SAMPLES",
            "SAMPLE_ALPHA_TO_COVERAGE",
            "SAMPLE_BUFFERS",
            "SAMPLE_COVERAGE",
            "SAMPLE_COVERAGE_INVERT",
            "SAMPLE_COVERAGE_VALUE",
            "SAWTOOTH",
            "SCHEDULED_STATE",
            "SCISSOR_BOX",
            "SCISSOR_TEST",
            "SCROLL_PAGE_DOWN",
            "SCROLL_PAGE_UP",
            "SDP_ANSWER",
            "SDP_OFFER",
            "SDP_PRANSWER",
            "SECURITY_ERR",
            "SELECT",
            "SEPARATE_ATTRIBS",
            "SERIALIZE_ERR",
            "SEVERITY_ERROR",
            "SEVERITY_FATAL_ERROR",
            "SEVERITY_WARNING",
            "SHADER_COMPILER",
            "SHADER_TYPE",
            "SHADING_LANGUAGE_VERSION",
            "SHIFT_MASK",
            "SHORT",
            "SHOWING",
            "SHOW_ALL",
            "SHOW_ATTRIBUTE",
            "SHOW_CDATA_SECTION",
            "SHOW_COMMENT",
            "SHOW_DOCUMENT",
            "SHOW_DOCUMENT_FRAGMENT",
            "SHOW_DOCUMENT_TYPE",
            "SHOW_ELEMENT",
            "SHOW_ENTITY",
            "SHOW_ENTITY_REFERENCE",
            "SHOW_NOTATION",
            "SHOW_PROCESSING_INSTRUCTION",
            "SHOW_TEXT",
            "SIGNALED",
            "SIGNED_NORMALIZED",
            "SINE",
            "SOUNDFIELD",
            "SQLException",
            "SQRT1_2",
            "SQRT2",
            "SQUARE",
            "SRC_ALPHA",
            "SRC_ALPHA_SATURATE",
            "SRC_COLOR",
            "SRGB",
            "SRGB8",
            "SRGB8_ALPHA8",
            "START_TO_END",
            "START_TO_START",
            "STATIC_COPY",
            "STATIC_DRAW",
            "STATIC_READ",
            "STENCIL",
            "STENCIL_ATTACHMENT",
            "STENCIL_BACK_FAIL",
            "STENCIL_BACK_FUNC",
            "STENCIL_BACK_PASS_DEPTH_FAIL",
            "STENCIL_BACK_PASS_DEPTH_PASS",
            "STENCIL_BACK_REF",
            "STENCIL_BACK_VALUE_MASK",
            "STENCIL_BACK_WRITEMASK",
            "STENCIL_BITS",
            "STENCIL_BUFFER_BIT",
            "STENCIL_CLEAR_VALUE",
            "STENCIL_FAIL",
            "STENCIL_FUNC",
            "STENCIL_INDEX",
            "STENCIL_INDEX8",
            "STENCIL_PASS_DEPTH_FAIL",
            "STENCIL_PASS_DEPTH_PASS",
            "STENCIL_REF",
            "STENCIL_TEST",
            "STENCIL_VALUE_MASK",
            "STENCIL_WRITEMASK",
            "STORAGE",
            "STORAGE_BINDING",
            "STREAM_COPY",
            "STREAM_DRAW",
            "STREAM_READ",
            "STRING_TYPE",
            "STYLE_RULE",
            "SUBPIXEL_BITS",
            "SUPPORTS_RULE",
            "SVGAElement",
            "SVGAltGlyphDefElement",
            "SVGAltGlyphElement",
            "SVGAltGlyphItemElement",
            "SVGAngle",
            "SVGAnimateColorElement",
            "SVGAnimateElement",
            "SVGAnimateMotionElement",
            "SVGAnimateTransformElement",
            "SVGAnimatedAngle",
            "SVGAnimatedBoolean",
            "SVGAnimatedEnumeration",
            "SVGAnimatedInteger",
            "SVGAnimatedLength",
            "SVGAnimatedLengthList",
            "SVGAnimatedNumber",
            "SVGAnimatedNumberList",
            "SVGAnimatedPreserveAspectRatio",
            "SVGAnimatedRect",
            "SVGAnimatedString",
            "SVGAnimatedTransformList",
            "SVGAnimationElement",
            "SVGCircleElement",
            "SVGClipPathElement",
            "SVGColor",
            "SVGComponentTransferFunctionElement",
            "SVGCursorElement",
            "SVGDefsElement",
            "SVGDescElement",
            "SVGDiscardElement",
            "SVGDocument",
            "SVGElement",
            "SVGElementInstance",
            "SVGElementInstanceList",
            "SVGEllipseElement",
            "SVGException",
            "SVGFEBlendElement",
            "SVGFEColorMatrixElement",
            "SVGFEComponentTransferElement",
            "SVGFECompositeElement",
            "SVGFEConvolveMatrixElement",
            "SVGFEDiffuseLightingElement",
            "SVGFEDisplacementMapElement",
            "SVGFEDistantLightElement",
            "SVGFEDropShadowElement",
            "SVGFEFloodElement",
            "SVGFEFuncAElement",
            "SVGFEFuncBElement",
            "SVGFEFuncGElement",
            "SVGFEFuncRElement",
            "SVGFEGaussianBlurElement",
            "SVGFEImageElement",
            "SVGFEMergeElement",
            "SVGFEMergeNodeElement",
            "SVGFEMorphologyElement",
            "SVGFEOffsetElement",
            "SVGFEPointLightElement",
            "SVGFESpecularLightingElement",
            "SVGFESpotLightElement",
            "SVGFETileElement",
            "SVGFETurbulenceElement",
            "SVGFilterElement",
            "SVGFontElement",
            "SVGFontFaceElement",
            "SVGFontFaceFormatElement",
            "SVGFontFaceNameElement",
            "SVGFontFaceSrcElement",
            "SVGFontFaceUriElement",
            "SVGForeignObjectElement",
            "SVGGElement",
            "SVGGeometryElement",
            "SVGGlyphElement",
            "SVGGlyphRefElement",
            "SVGGradientElement",
            "SVGGraphicsElement",
            "SVGHKernElement",
            "SVGImageElement",
            "SVGLength",
            "SVGLengthList",
            "SVGLineElement",
            "SVGLinearGradientElement",
            "SVGMPathElement",
            "SVGMarkerElement",
            "SVGMaskElement",
            "SVGMatrix",
            "SVGMetadataElement",
            "SVGMissingGlyphElement",
            "SVGNumber",
            "SVGNumberList",
            "SVGPaint",
            "SVGPathElement",
            "SVGPathSeg",
            "SVGPathSegArcAbs",
            "SVGPathSegArcRel",
            "SVGPathSegClosePath",
            "SVGPathSegCurvetoCubicAbs",
            "SVGPathSegCurvetoCubicRel",
            "SVGPathSegCurvetoCubicSmoothAbs",
            "SVGPathSegCurvetoCubicSmoothRel",
            "SVGPathSegCurvetoQuadraticAbs",
            "SVGPathSegCurvetoQuadraticRel",
            "SVGPathSegCurvetoQuadraticSmoothAbs",
            "SVGPathSegCurvetoQuadraticSmoothRel",
            "SVGPathSegLinetoAbs",
            "SVGPathSegLinetoHorizontalAbs",
            "SVGPathSegLinetoHorizontalRel",
            "SVGPathSegLinetoRel",
            "SVGPathSegLinetoVerticalAbs",
            "SVGPathSegLinetoVerticalRel",
            "SVGPathSegList",
            "SVGPathSegMovetoAbs",
            "SVGPathSegMovetoRel",
            "SVGPatternElement",
            "SVGPoint",
            "SVGPointList",
            "SVGPolygonElement",
            "SVGPolylineElement",
            "SVGPreserveAspectRatio",
            "SVGRadialGradientElement",
            "SVGRect",
            "SVGRectElement",
            "SVGRenderingIntent",
            "SVGSVGElement",
            "SVGScriptElement",
            "SVGSetElement",
            "SVGStopElement",
            "SVGStringList",
            "SVGStyleElement",
            "SVGSwitchElement",
            "SVGSymbolElement",
            "SVGTRefElement",
            "SVGTSpanElement",
            "SVGTextContentElement",
            "SVGTextElement",
            "SVGTextPathElement",
            "SVGTextPositioningElement",
            "SVGTitleElement",
            "SVGTransform",
            "SVGTransformList",
            "SVGUnitTypes",
            "SVGUseElement",
            "SVGVKernElement",
            "SVGViewElement",
            "SVGViewSpec",
            "SVGZoomAndPan",
            "SVGZoomEvent",
            "SVG_ANGLETYPE_DEG",
            "SVG_ANGLETYPE_GRAD",
            "SVG_ANGLETYPE_RAD",
            "SVG_ANGLETYPE_UNKNOWN",
            "SVG_ANGLETYPE_UNSPECIFIED",
            "SVG_CHANNEL_A",
            "SVG_CHANNEL_B",
            "SVG_CHANNEL_G",
            "SVG_CHANNEL_R",
            "SVG_CHANNEL_UNKNOWN",
            "SVG_COLORTYPE_CURRENTCOLOR",
            "SVG_COLORTYPE_RGBCOLOR",
            "SVG_COLORTYPE_RGBCOLOR_ICCCOLOR",
            "SVG_COLORTYPE_UNKNOWN",
            "SVG_EDGEMODE_DUPLICATE",
            "SVG_EDGEMODE_NONE",
            "SVG_EDGEMODE_UNKNOWN",
            "SVG_EDGEMODE_WRAP",
            "SVG_FEBLEND_MODE_COLOR",
            "SVG_FEBLEND_MODE_COLOR_BURN",
            "SVG_FEBLEND_MODE_COLOR_DODGE",
            "SVG_FEBLEND_MODE_DARKEN",
            "SVG_FEBLEND_MODE_DIFFERENCE",
            "SVG_FEBLEND_MODE_EXCLUSION",
            "SVG_FEBLEND_MODE_HARD_LIGHT",
            "SVG_FEBLEND_MODE_HUE",
            "SVG_FEBLEND_MODE_LIGHTEN",
            "SVG_FEBLEND_MODE_LUMINOSITY",
            "SVG_FEBLEND_MODE_MULTIPLY",
            "SVG_FEBLEND_MODE_NORMAL",
            "SVG_FEBLEND_MODE_OVERLAY",
            "SVG_FEBLEND_MODE_SATURATION",
            "SVG_FEBLEND_MODE_SCREEN",
            "SVG_FEBLEND_MODE_SOFT_LIGHT",
            "SVG_FEBLEND_MODE_UNKNOWN",
            "SVG_FECOLORMATRIX_TYPE_HUEROTATE",
            "SVG_FECOLORMATRIX_TYPE_LUMINANCETOALPHA",
            "SVG_FECOLORMATRIX_TYPE_MATRIX",
            "SVG_FECOLORMATRIX_TYPE_SATURATE",
            "SVG_FECOLORMATRIX_TYPE_UNKNOWN",
            "SVG_FECOMPONENTTRANSFER_TYPE_DISCRETE",
            "SVG_FECOMPONENTTRANSFER_TYPE_GAMMA",
            "SVG_FECOMPONENTTRANSFER_TYPE_IDENTITY",
            "SVG_FECOMPONENTTRANSFER_TYPE_LINEAR",
            "SVG_FECOMPONENTTRANSFER_TYPE_TABLE",
            "SVG_FECOMPONENTTRANSFER_TYPE_UNKNOWN",
            "SVG_FECOMPOSITE_OPERATOR_ARITHMETIC",
            "SVG_FECOMPOSITE_OPERATOR_ATOP",
            "SVG_FECOMPOSITE_OPERATOR_IN",
            "SVG_FECOMPOSITE_OPERATOR_OUT",
            "SVG_FECOMPOSITE_OPERATOR_OVER",
            "SVG_FECOMPOSITE_OPERATOR_UNKNOWN",
            "SVG_FECOMPOSITE_OPERATOR_XOR",
            "SVG_INVALID_VALUE_ERR",
            "SVG_LENGTHTYPE_CM",
            "SVG_LENGTHTYPE_EMS",
            "SVG_LENGTHTYPE_EXS",
            "SVG_LENGTHTYPE_IN",
            "SVG_LENGTHTYPE_MM",
            "SVG_LENGTHTYPE_NUMBER",
            "SVG_LENGTHTYPE_PC",
            "SVG_LENGTHTYPE_PERCENTAGE",
            "SVG_LENGTHTYPE_PT",
            "SVG_LENGTHTYPE_PX",
            "SVG_LENGTHTYPE_UNKNOWN",
            "SVG_MARKERUNITS_STROKEWIDTH",
            "SVG_MARKERUNITS_UNKNOWN",
            "SVG_MARKERUNITS_USERSPACEONUSE",
            "SVG_MARKER_ORIENT_ANGLE",
            "SVG_MARKER_ORIENT_AUTO",
            "SVG_MARKER_ORIENT_UNKNOWN",
            "SVG_MASKTYPE_ALPHA",
            "SVG_MASKTYPE_LUMINANCE",
            "SVG_MATRIX_NOT_INVERTABLE",
            "SVG_MEETORSLICE_MEET",
            "SVG_MEETORSLICE_SLICE",
            "SVG_MEETORSLICE_UNKNOWN",
            "SVG_MORPHOLOGY_OPERATOR_DILATE",
            "SVG_MORPHOLOGY_OPERATOR_ERODE",
            "SVG_MORPHOLOGY_OPERATOR_UNKNOWN",
            "SVG_PAINTTYPE_CURRENTCOLOR",
            "SVG_PAINTTYPE_NONE",
            "SVG_PAINTTYPE_RGBCOLOR",
            "SVG_PAINTTYPE_RGBCOLOR_ICCCOLOR",
            "SVG_PAINTTYPE_UNKNOWN",
            "SVG_PAINTTYPE_URI",
            "SVG_PAINTTYPE_URI_CURRENTCOLOR",
            "SVG_PAINTTYPE_URI_NONE",
            "SVG_PAINTTYPE_URI_RGBCOLOR",
            "SVG_PAINTTYPE_URI_RGBCOLOR_ICCCOLOR",
            "SVG_PRESERVEASPECTRATIO_NONE",
            "SVG_PRESERVEASPECTRATIO_UNKNOWN",
            "SVG_PRESERVEASPECTRATIO_XMAXYMAX",
            "SVG_PRESERVEASPECTRATIO_XMAXYMID",
            "SVG_PRESERVEASPECTRATIO_XMAXYMIN",
            "SVG_PRESERVEASPECTRATIO_XMIDYMAX",
            "SVG_PRESERVEASPECTRATIO_XMIDYMID",
            "SVG_PRESERVEASPECTRATIO_XMIDYMIN",
            "SVG_PRESERVEASPECTRATIO_XMINYMAX",
            "SVG_PRESERVEASPECTRATIO_XMINYMID",
            "SVG_PRESERVEASPECTRATIO_XMINYMIN",
            "SVG_SPREADMETHOD_PAD",
            "SVG_SPREADMETHOD_REFLECT",
            "SVG_SPREADMETHOD_REPEAT",
            "SVG_SPREADMETHOD_UNKNOWN",
            "SVG_STITCHTYPE_NOSTITCH",
            "SVG_STITCHTYPE_STITCH",
            "SVG_STITCHTYPE_UNKNOWN",
            "SVG_TRANSFORM_MATRIX",
            "SVG_TRANSFORM_ROTATE",
            "SVG_TRANSFORM_SCALE",
            "SVG_TRANSFORM_SKEWX",
            "SVG_TRANSFORM_SKEWY",
            "SVG_TRANSFORM_TRANSLATE",
            "SVG_TRANSFORM_UNKNOWN",
            "SVG_TURBULENCE_TYPE_FRACTALNOISE",
            "SVG_TURBULENCE_TYPE_TURBULENCE",
            "SVG_TURBULENCE_TYPE_UNKNOWN",
            "SVG_UNIT_TYPE_OBJECTBOUNDINGBOX",
            "SVG_UNIT_TYPE_UNKNOWN",
            "SVG_UNIT_TYPE_USERSPACEONUSE",
            "SVG_WRONG_TYPE_ERR",
            "SVG_ZOOMANDPAN_DISABLE",
            "SVG_ZOOMANDPAN_MAGNIFY",
            "SVG_ZOOMANDPAN_UNKNOWN",
            "SYNC_CONDITION",
            "SYNC_FENCE",
            "SYNC_FLAGS",
            "SYNC_FLUSH_COMMANDS_BIT",
            "SYNC_GPU_COMMANDS_COMPLETE",
            "SYNC_STATUS",
            "SYNTAX_ERR",
            "SavedPages",
            "Screen",
            "ScreenOrientation",
            "Script",
            "ScriptProcessorNode",
            "ScrollAreaEvent",
            "SecurityPolicyViolationEvent",
            "Selection",
            "Sensor",
            "SensorErrorEvent",
            "ServiceWorker",
            "ServiceWorkerContainer",
            "ServiceWorkerRegistration",
            "SessionDescription",
            "Set",
            "ShadowRoot",
            "SharedArrayBuffer",
            "SharedWorker",
            "SimpleGestureEvent",
            "SourceBuffer",
            "SourceBufferList",
            "SpeechSynthesis",
            "SpeechSynthesisErrorEvent",
            "SpeechSynthesisEvent",
            "SpeechSynthesisUtterance",
            "SpeechSynthesisVoice",
            "StaticRange",
            "StereoPannerNode",
            "StopIteration",
            "Storage",
            "StorageEvent",
            "StorageManager",
            "String",
            "StructType",
            "StylePropertyMap",
            "StylePropertyMapReadOnly",
            "StyleSheet",
            "StyleSheetList",
            "SubmitEvent",
            "SubtleCrypto",
            "Symbol",
            "SyncManager",
            "SyntaxError",
            "TEMPORARY",
            "TEXTPATH_METHODTYPE_ALIGN",
            "TEXTPATH_METHODTYPE_STRETCH",
            "TEXTPATH_METHODTYPE_UNKNOWN",
            "TEXTPATH_SPACINGTYPE_AUTO",
            "TEXTPATH_SPACINGTYPE_EXACT",
            "TEXTPATH_SPACINGTYPE_UNKNOWN",
            "TEXTURE",
            "TEXTURE0",
            "TEXTURE1",
            "TEXTURE10",
            "TEXTURE11",
            "TEXTURE12",
            "TEXTURE13",
            "TEXTURE14",
            "TEXTURE15",
            "TEXTURE16",
            "TEXTURE17",
            "TEXTURE18",
            "TEXTURE19",
            "TEXTURE2",
            "TEXTURE20",
            "TEXTURE21",
            "TEXTURE22",
            "TEXTURE23",
            "TEXTURE24",
            "TEXTURE25",
            "TEXTURE26",
            "TEXTURE27",
            "TEXTURE28",
            "TEXTURE29",
            "TEXTURE3",
            "TEXTURE30",
            "TEXTURE31",
            "TEXTURE4",
            "TEXTURE5",
            "TEXTURE6",
            "TEXTURE7",
            "TEXTURE8",
            "TEXTURE9",
            "TEXTURE_2D",
            "TEXTURE_2D_ARRAY",
            "TEXTURE_3D",
            "TEXTURE_BASE_LEVEL",
            "TEXTURE_BINDING",
            "TEXTURE_BINDING_2D",
            "TEXTURE_BINDING_2D_ARRAY",
            "TEXTURE_BINDING_3D",
            "TEXTURE_BINDING_CUBE_MAP",
            "TEXTURE_COMPARE_FUNC",
            "TEXTURE_COMPARE_MODE",
            "TEXTURE_CUBE_MAP",
            "TEXTURE_CUBE_MAP_NEGATIVE_X",
            "TEXTURE_CUBE_MAP_NEGATIVE_Y",
            "TEXTURE_CUBE_MAP_NEGATIVE_Z",
            "TEXTURE_CUBE_MAP_POSITIVE_X",
            "TEXTURE_CUBE_MAP_POSITIVE_Y",
            "TEXTURE_CUBE_MAP_POSITIVE_Z",
            "TEXTURE_IMMUTABLE_FORMAT",
            "TEXTURE_IMMUTABLE_LEVELS",
            "TEXTURE_MAG_FILTER",
            "TEXTURE_MAX_ANISOTROPY_EXT",
            "TEXTURE_MAX_LEVEL",
            "TEXTURE_MAX_LOD",
            "TEXTURE_MIN_FILTER",
            "TEXTURE_MIN_LOD",
            "TEXTURE_WRAP_R",
            "TEXTURE_WRAP_S",
            "TEXTURE_WRAP_T",
            "TEXT_NODE",
            "TIMEOUT",
            "TIMEOUT_ERR",
            "TIMEOUT_EXPIRED",
            "TIMEOUT_IGNORED",
            "TOO_LARGE_ERR",
            "TRANSACTION_INACTIVE_ERR",
            "TRANSFORM_FEEDBACK",
            "TRANSFORM_FEEDBACK_ACTIVE",
            "TRANSFORM_FEEDBACK_BINDING",
            "TRANSFORM_FEEDBACK_BUFFER",
            "TRANSFORM_FEEDBACK_BUFFER_BINDING",
            "TRANSFORM_FEEDBACK_BUFFER_MODE",
            "TRANSFORM_FEEDBACK_BUFFER_SIZE",
            "TRANSFORM_FEEDBACK_BUFFER_START",
            "TRANSFORM_FEEDBACK_PAUSED",
            "TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN",
            "TRANSFORM_FEEDBACK_VARYINGS",
            "TRIANGLE",
            "TRIANGLES",
            "TRIANGLE_FAN",
            "TRIANGLE_STRIP",
            "TYPE_BACK_FORWARD",
            "TYPE_ERR",
            "TYPE_MISMATCH_ERR",
            "TYPE_NAVIGATE",
            "TYPE_RELOAD",
            "TYPE_RESERVED",
            "Table",
            "TaskAttributionTiming",
            "Text",
            "TextDecoder",
            "TextDecoderStream",
            "TextEncoder",
            "TextEncoderStream",
            "TextEvent",
            "TextMetrics",
            "TextTrack",
            "TextTrackCue",
            "TextTrackCueList",
            "TextTrackList",
            "TimeEvent",
            "TimeRanges",
            "Touch",
            "TouchEvent",
            "TouchList",
            "TrackEvent",
            "TransformStream",
            "TransitionEvent",
            "TreeWalker",
            "TrustedHTML",
            "TrustedScript",
            "TrustedScriptURL",
            "TrustedTypePolicy",
            "TrustedTypePolicyFactory",
            "TypeError",
            "TypedObject",
            "U2F",
            "UIEvent",
            "UNCACHED",
            "UNIFORM",
            "UNIFORM_ARRAY_STRIDE",
            "UNIFORM_BLOCK_ACTIVE_UNIFORMS",
            "UNIFORM_BLOCK_ACTIVE_UNIFORM_INDICES",
            "UNIFORM_BLOCK_BINDING",
            "UNIFORM_BLOCK_DATA_SIZE",
            "UNIFORM_BLOCK_INDEX",
            "UNIFORM_BLOCK_REFERENCED_BY_FRAGMENT_SHADER",
            "UNIFORM_BLOCK_REFERENCED_BY_VERTEX_SHADER",
            "UNIFORM_BUFFER",
            "UNIFORM_BUFFER_BINDING",
            "UNIFORM_BUFFER_OFFSET_ALIGNMENT",
            "UNIFORM_BUFFER_SIZE",
            "UNIFORM_BUFFER_START",
            "UNIFORM_IS_ROW_MAJOR",
            "UNIFORM_MATRIX_STRIDE",
            "UNIFORM_OFFSET",
            "UNIFORM_SIZE",
            "UNIFORM_TYPE",
            "UNKNOWN_ERR",
            "UNKNOWN_RULE",
            "UNMASKED_RENDERER_WEBGL",
            "UNMASKED_VENDOR_WEBGL",
            "UNORDERED_NODE_ITERATOR_TYPE",
            "UNORDERED_NODE_SNAPSHOT_TYPE",
            "UNPACK_ALIGNMENT",
            "UNPACK_COLORSPACE_CONVERSION_WEBGL",
            "UNPACK_FLIP_Y_WEBGL",
            "UNPACK_IMAGE_HEIGHT",
            "UNPACK_PREMULTIPLY_ALPHA_WEBGL",
            "UNPACK_ROW_LENGTH",
            "UNPACK_SKIP_IMAGES",
            "UNPACK_SKIP_PIXELS",
            "UNPACK_SKIP_ROWS",
            "UNSCHEDULED_STATE",
            "UNSENT",
            "UNSIGNALED",
            "UNSIGNED_BYTE",
            "UNSIGNED_INT",
            "UNSIGNED_INT_10F_11F_11F_REV",
            "UNSIGNED_INT_24_8",
            "UNSIGNED_INT_2_10_10_10_REV",
            "UNSIGNED_INT_5_9_9_9_REV",
            "UNSIGNED_INT_SAMPLER_2D",
            "UNSIGNED_INT_SAMPLER_2D_ARRAY",
            "UNSIGNED_INT_SAMPLER_3D",
            "UNSIGNED_INT_SAMPLER_CUBE",
            "UNSIGNED_INT_VEC2",
            "UNSIGNED_INT_VEC3",
            "UNSIGNED_INT_VEC4",
            "UNSIGNED_NORMALIZED",
            "UNSIGNED_SHORT",
            "UNSIGNED_SHORT_4_4_4_4",
            "UNSIGNED_SHORT_5_5_5_1",
            "UNSIGNED_SHORT_5_6_5",
            "UNSPECIFIED_EVENT_TYPE_ERR",
            "UPDATEREADY",
            "URIError",
            "URL",
            "URLSearchParams",
            "URLUnencoded",
            "URL_MISMATCH_ERR",
            "USB",
            "USBAlternateInterface",
            "USBConfiguration",
            "USBConnectionEvent",
            "USBDevice",
            "USBEndpoint",
            "USBInTransferResult",
            "USBInterface",
            "USBIsochronousInTransferPacket",
            "USBIsochronousInTransferResult",
            "USBIsochronousOutTransferPacket",
            "USBIsochronousOutTransferResult",
            "USBOutTransferResult",
            "UTC",
            "Uint16Array",
            "Uint32Array",
            "Uint8Array",
            "Uint8ClampedArray",
            "UserActivation",
            "UserMessageHandler",
            "UserMessageHandlersNamespace",
            "UserProximityEvent",
            "VALIDATE_STATUS",
            "VALIDATION_ERR",
            "VARIABLES_RULE",
            "VENDOR",
            "VERSION",
            "VERSION_CHANGE",
            "VERSION_ERR",
            "VERTEX",
            "VERTEX_ARRAY_BINDING",
            "VERTEX_ATTRIB_ARRAY_BUFFER_BINDING",
            "VERTEX_ATTRIB_ARRAY_DIVISOR",
            "VERTEX_ATTRIB_ARRAY_DIVISOR_ANGLE",
            "VERTEX_ATTRIB_ARRAY_ENABLED",
            "VERTEX_ATTRIB_ARRAY_INTEGER",
            "VERTEX_ATTRIB_ARRAY_NORMALIZED",
            "VERTEX_ATTRIB_ARRAY_POINTER",
            "VERTEX_ATTRIB_ARRAY_SIZE",
            "VERTEX_ATTRIB_ARRAY_STRIDE",
            "VERTEX_ATTRIB_ARRAY_TYPE",
            "VERTEX_SHADER",
            "VERTICAL",
            "VERTICAL_AXIS",
            "VER_ERR",
            "VIEWPORT",
            "VIEWPORT_RULE",
            "VRDisplay",
            "VRDisplayCapabilities",
            "VRDisplayEvent",
            "VREyeParameters",
            "VRFieldOfView",
            "VRFrameData",
            "VRPose",
            "VRStageParameters",
            "VTTCue",
            "VTTRegion",
            "ValidityState",
            "VideoPlaybackQuality",
            "VideoStreamTrack",
            "VisualViewport",
            "WAIT_FAILED",
            "WEBKIT_FILTER_RULE",
            "WEBKIT_KEYFRAMES_RULE",
            "WEBKIT_KEYFRAME_RULE",
            "WEBKIT_REGION_RULE",
            "WRITE",
            "WRONG_DOCUMENT_ERR",
            "WakeLock",
            "WakeLockSentinel",
            "WasmAnyRef",
            "WaveShaperNode",
            "WeakMap",
            "WeakRef",
            "WeakSet",
            "WebAssembly",
            "WebGL2RenderingContext",
            "WebGLActiveInfo",
            "WebGLBuffer",
            "WebGLContextEvent",
            "WebGLFramebuffer",
            "WebGLProgram",
            "WebGLQuery",
            "WebGLRenderbuffer",
            "WebGLRenderingContext",
            "WebGLSampler",
            "WebGLShader",
            "WebGLShaderPrecisionFormat",
            "WebGLSync",
            "WebGLTexture",
            "WebGLTransformFeedback",
            "WebGLUniformLocation",
            "WebGLVertexArray",
            "WebGLVertexArrayObject",
            "WebKitAnimationEvent",
            "WebKitBlobBuilder",
            "WebKitCSSFilterRule",
            "WebKitCSSFilterValue",
            "WebKitCSSKeyframeRule",
            "WebKitCSSKeyframesRule",
            "WebKitCSSMatrix",
            "WebKitCSSRegionRule",
            "WebKitCSSTransformValue",
            "WebKitDataCue",
            "WebKitGamepad",
            "WebKitMediaKeyError",
            "WebKitMediaKeyMessageEvent",
            "WebKitMediaKeySession",
            "WebKitMediaKeys",
            "WebKitMediaSource",
            "WebKitMutationObserver",
            "WebKitNamespace",
            "WebKitPlaybackTargetAvailabilityEvent",
            "WebKitPoint",
            "WebKitShadowRoot",
            "WebKitSourceBuffer",
            "WebKitSourceBufferList",
            "WebKitTransitionEvent",
            "WebSocket",
            "WebkitAlignContent",
            "WebkitAlignItems",
            "WebkitAlignSelf",
            "WebkitAnimation",
            "WebkitAnimationDelay",
            "WebkitAnimationDirection",
            "WebkitAnimationDuration",
            "WebkitAnimationFillMode",
            "WebkitAnimationIterationCount",
            "WebkitAnimationName",
            "WebkitAnimationPlayState",
            "WebkitAnimationTimingFunction",
            "WebkitAppearance",
            "WebkitBackfaceVisibility",
            "WebkitBackgroundClip",
            "WebkitBackgroundOrigin",
            "WebkitBackgroundSize",
            "WebkitBorderBottomLeftRadius",
            "WebkitBorderBottomRightRadius",
            "WebkitBorderImage",
            "WebkitBorderRadius",
            "WebkitBorderTopLeftRadius",
            "WebkitBorderTopRightRadius",
            "WebkitBoxAlign",
            "WebkitBoxDirection",
            "WebkitBoxFlex",
            "WebkitBoxOrdinalGroup",
            "WebkitBoxOrient",
            "WebkitBoxPack",
            "WebkitBoxShadow",
            "WebkitBoxSizing",
            "WebkitFilter",
            "WebkitFlex",
            "WebkitFlexBasis",
            "WebkitFlexDirection",
            "WebkitFlexFlow",
            "WebkitFlexGrow",
            "WebkitFlexShrink",
            "WebkitFlexWrap",
            "WebkitJustifyContent",
            "WebkitLineClamp",
            "WebkitMask",
            "WebkitMaskClip",
            "WebkitMaskComposite",
            "WebkitMaskImage",
            "WebkitMaskOrigin",
            "WebkitMaskPosition",
            "WebkitMaskPositionX",
            "WebkitMaskPositionY",
            "WebkitMaskRepeat",
            "WebkitMaskSize",
            "WebkitOrder",
            "WebkitPerspective",
            "WebkitPerspectiveOrigin",
            "WebkitTextFillColor",
            "WebkitTextSizeAdjust",
            "WebkitTextStroke",
            "WebkitTextStrokeColor",
            "WebkitTextStrokeWidth",
            "WebkitTransform",
            "WebkitTransformOrigin",
            "WebkitTransformStyle",
            "WebkitTransition",
            "WebkitTransitionDelay",
            "WebkitTransitionDuration",
            "WebkitTransitionProperty",
            "WebkitTransitionTimingFunction",
            "WebkitUserSelect",
            "WheelEvent",
            "Window",
            "Worker",
            "Worklet",
            "WritableStream",
            "WritableStreamDefaultWriter",
            "XMLDocument",
            "XMLHttpRequest",
            "XMLHttpRequestEventTarget",
            "XMLHttpRequestException",
            "XMLHttpRequestProgressEvent",
            "XMLHttpRequestUpload",
            "XMLSerializer",
            "XMLStylesheetProcessingInstruction",
            "XPathEvaluator",
            "XPathException",
            "XPathExpression",
            "XPathNSResolver",
            "XPathResult",
            "XRBoundedReferenceSpace",
            "XRDOMOverlayState",
            "XRFrame",
            "XRHitTestResult",
            "XRHitTestSource",
            "XRInputSource",
            "XRInputSourceArray",
            "XRInputSourceEvent",
            "XRInputSourcesChangeEvent",
            "XRLayer",
            "XRPose",
            "XRRay",
            "XRReferenceSpace",
            "XRReferenceSpaceEvent",
            "XRRenderState",
            "XRRigidTransform",
            "XRSession",
            "XRSessionEvent",
            "XRSpace",
            "XRSystem",
            "XRTransientInputHitTestResult",
            "XRTransientInputHitTestSource",
            "XRView",
            "XRViewerPose",
            "XRViewport",
            "XRWebGLLayer",
            "XSLTProcessor",
            "ZERO",
            "_XD0M_",
            "_YD0M_",
            "__brand",
            "__defineGetter__",
            "__defineSetter__",
            "__lookupGetter__",
            "__lookupSetter__",
            "__opera",
            "__proto__",
            "_browserjsran",
            "a",
            "aLink",
            "abbr",
            "abort",
            "aborted",
            "abs",
            "absolute",
            "acceleration",
            "accelerationIncludingGravity",
            "accelerator",
            "accept",
            "acceptCharset",
            "acceptNode",
            "access",
            "accessKey",
            "accessKeyLabel",
            "accuracy",
            "acos",
            "acosh",
            "action",
            "actionURL",
            "actions",
            "activated",
            "active",
            "activeCues",
            "activeElement",
            "activeSourceBuffers",
            "activeSourceCount",
            "activeTexture",
            "activeVRDisplays",
            "actualBoundingBoxAscent",
            "actualBoundingBoxDescent",
            "actualBoundingBoxLeft",
            "actualBoundingBoxRight",
            "add",
            "addAll",
            "addBehavior",
            "addCandidate",
            "addColorStop",
            "addCue",
            "addElement",
            "addEventListener",
            "addFilter",
            "addFromString",
            "addFromUri",
            "addIceCandidate",
            "addImport",
            "addListener",
            "addModule",
            "addNamed",
            "addPageRule",
            "addPath",
            "addPointer",
            "addRange",
            "addRegion",
            "addRule",
            "addSearchEngine",
            "addSourceBuffer",
            "addStream",
            "addTextTrack",
            "addTrack",
            "addTransceiver",
            "addWakeLockListener",
            "added",
            "addedNodes",
            "additionalName",
            "additiveSymbols",
            "addons",
            "address",
            "addressLine",
            "addressModeU",
            "addressModeV",
            "addressModeW",
            "adoptNode",
            "adoptedStyleSheets",
            "adr",
            "advance",
            "after",
            "album",
            "alert",
            "algorithm",
            "align",
            "align-content",
            "align-items",
            "align-self",
            "alignContent",
            "alignItems",
            "alignSelf",
            "alignmentBaseline",
            "alinkColor",
            "all",
            "allSettled",
            "allow",
            "allowFullscreen",
            "allowPaymentRequest",
            "allowedDirections",
            "allowedFeatures",
            "allowedToPlay",
            "allowsFeature",
            "alpha",
            "alphaMode",
            "alphaToCoverageEnabled",
            "alt",
            "altGraphKey",
            "altHtml",
            "altKey",
            "altLeft",
            "alternate",
            "alternateSetting",
            "alternates",
            "altitude",
            "altitudeAccuracy",
            "amplitude",
            "ancestorOrigins",
            "anchor",
            "anchorNode",
            "anchorOffset",
            "anchors",
            "and",
            "angle",
            "angularAcceleration",
            "angularVelocity",
            "animVal",
            "animate",
            "animatedInstanceRoot",
            "animatedNormalizedPathSegList",
            "animatedPathSegList",
            "animatedPoints",
            "animation",
            "animation-delay",
            "animation-direction",
            "animation-duration",
            "animation-fill-mode",
            "animation-iteration-count",
            "animation-name",
            "animation-play-state",
            "animation-timing-function",
            "animationDelay",
            "animationDirection",
            "animationDuration",
            "animationFillMode",
            "animationIterationCount",
            "animationName",
            "animationPlayState",
            "animationStartTime",
            "animationTimingFunction",
            "animationsPaused",
            "anniversary",
            "antialias",
            "anticipatedRemoval",
            "any",
            "app",
            "appCodeName",
            "appMinorVersion",
            "appName",
            "appNotifications",
            "appVersion",
            "appearance",
            "append",
            "appendBuffer",
            "appendChild",
            "appendData",
            "appendItem",
            "appendMedium",
            "appendNamed",
            "appendRule",
            "appendStream",
            "appendWindowEnd",
            "appendWindowStart",
            "applets",
            "applicationCache",
            "applicationServerKey",
            "apply",
            "applyConstraints",
            "applyElement",
            "arc",
            "arcTo",
            "architecture",
            "archive",
            "areas",
            "arguments",
            "ariaAtomic",
            "ariaAutoComplete",
            "ariaBusy",
            "ariaChecked",
            "ariaColCount",
            "ariaColIndex",
            "ariaColSpan",
            "ariaCurrent",
            "ariaDescription",
            "ariaDisabled",
            "ariaExpanded",
            "ariaHasPopup",
            "ariaHidden",
            "ariaKeyShortcuts",
            "ariaLabel",
            "ariaLevel",
            "ariaLive",
            "ariaModal",
            "ariaMultiLine",
            "ariaMultiSelectable",
            "ariaOrientation",
            "ariaPlaceholder",
            "ariaPosInSet",
            "ariaPressed",
            "ariaReadOnly",
            "ariaRelevant",
            "ariaRequired",
            "ariaRoleDescription",
            "ariaRowCount",
            "ariaRowIndex",
            "ariaRowSpan",
            "ariaSelected",
            "ariaSetSize",
            "ariaSort",
            "ariaValueMax",
            "ariaValueMin",
            "ariaValueNow",
            "ariaValueText",
            "arrayBuffer",
            "arrayLayerCount",
            "arrayStride",
            "artist",
            "artwork",
            "as",
            "asIntN",
            "asUintN",
            "asin",
            "asinh",
            "aspect",
            "assert",
            "assign",
            "assignedElements",
            "assignedNodes",
            "assignedSlot",
            "async",
            "asyncIterator",
            "atEnd",
            "atan",
            "atan2",
            "atanh",
            "atob",
            "attachEvent",
            "attachInternals",
            "attachShader",
            "attachShadow",
            "attachments",
            "attack",
            "attestationObject",
            "attrChange",
            "attrName",
            "attributeFilter",
            "attributeName",
            "attributeNamespace",
            "attributeOldValue",
            "attributeStyleMap",
            "attributes",
            "attribution",
            "audioBitsPerSecond",
            "audioTracks",
            "audioWorklet",
            "authenticatedSignedWrites",
            "authenticatorData",
            "autoIncrement",
            "autobuffer",
            "autocapitalize",
            "autocomplete",
            "autocorrect",
            "autofocus",
            "automationRate",
            "autoplay",
            "availHeight",
            "availLeft",
            "availTop",
            "availWidth",
            "availability",
            "available",
            "aversion",
            "ax",
            "axes",
            "axis",
            "ay",
            "azimuth",
            "b",
            "back",
            "backface-visibility",
            "backfaceVisibility",
            "background",
            "background-attachment",
            "background-blend-mode",
            "background-clip",
            "background-color",
            "background-image",
            "background-origin",
            "background-position",
            "background-position-x",
            "background-position-y",
            "background-repeat",
            "background-size",
            "backgroundAttachment",
            "backgroundBlendMode",
            "backgroundClip",
            "backgroundColor",
            "backgroundFetch",
            "backgroundImage",
            "backgroundOrigin",
            "backgroundPosition",
            "backgroundPositionX",
            "backgroundPositionY",
            "backgroundRepeat",
            "backgroundSize",
            "badInput",
            "badge",
            "balance",
            "baseArrayLayer",
            "baseFrequencyX",
            "baseFrequencyY",
            "baseLatency",
            "baseLayer",
            "baseMipLevel",
            "baseNode",
            "baseOffset",
            "baseURI",
            "baseVal",
            "baselineShift",
            "battery",
            "bday",
            "before",
            "beginComputePass",
            "beginElement",
            "beginElementAt",
            "beginOcclusionQuery",
            "beginPath",
            "beginQuery",
            "beginRenderPass",
            "beginTransformFeedback",
            "beginningOfPassWriteIndex",
            "behavior",
            "behaviorCookie",
            "behaviorPart",
            "behaviorUrns",
            "beta",
            "bezierCurveTo",
            "bgColor",
            "bgProperties",
            "bias",
            "big",
            "bigint64",
            "biguint64",
            "binaryType",
            "bind",
            "bindAttribLocation",
            "bindBuffer",
            "bindBufferBase",
            "bindBufferRange",
            "bindFramebuffer",
            "bindGroupLayouts",
            "bindRenderbuffer",
            "bindSampler",
            "bindTexture",
            "bindTransformFeedback",
            "bindVertexArray",
            "binding",
            "bitness",
            "blend",
            "blendColor",
            "blendEquation",
            "blendEquationSeparate",
            "blendFunc",
            "blendFuncSeparate",
            "blink",
            "blitFramebuffer",
            "blob",
            "block-size",
            "blockDirection",
            "blockSize",
            "blockedURI",
            "blue",
            "bluetooth",
            "blur",
            "body",
            "bodyUsed",
            "bold",
            "bookmarks",
            "booleanValue",
            "border",
            "border-block",
            "border-block-color",
            "border-block-end",
            "border-block-end-color",
            "border-block-end-style",
            "border-block-end-width",
            "border-block-start",
            "border-block-start-color",
            "border-block-start-style",
            "border-block-start-width",
            "border-block-style",
            "border-block-width",
            "border-bottom",
            "border-bottom-color",
            "border-bottom-left-radius",
            "border-bottom-right-radius",
            "border-bottom-style",
            "border-bottom-width",
            "border-collapse",
            "border-color",
            "border-end-end-radius",
            "border-end-start-radius",
            "border-image",
            "border-image-outset",
            "border-image-repeat",
            "border-image-slice",
            "border-image-source",
            "border-image-width",
            "border-inline",
            "border-inline-color",
            "border-inline-end",
            "border-inline-end-color",
            "border-inline-end-style",
            "border-inline-end-width",
            "border-inline-start",
            "border-inline-start-color",
            "border-inline-start-style",
            "border-inline-start-width",
            "border-inline-style",
            "border-inline-width",
            "border-left",
            "border-left-color",
            "border-left-style",
            "border-left-width",
            "border-radius",
            "border-right",
            "border-right-color",
            "border-right-style",
            "border-right-width",
            "border-spacing",
            "border-start-end-radius",
            "border-start-start-radius",
            "border-style",
            "border-top",
            "border-top-color",
            "border-top-left-radius",
            "border-top-right-radius",
            "border-top-style",
            "border-top-width",
            "border-width",
            "borderBlock",
            "borderBlockColor",
            "borderBlockEnd",
            "borderBlockEndColor",
            "borderBlockEndStyle",
            "borderBlockEndWidth",
            "borderBlockStart",
            "borderBlockStartColor",
            "borderBlockStartStyle",
            "borderBlockStartWidth",
            "borderBlockStyle",
            "borderBlockWidth",
            "borderBottom",
            "borderBottomColor",
            "borderBottomLeftRadius",
            "borderBottomRightRadius",
            "borderBottomStyle",
            "borderBottomWidth",
            "borderBoxSize",
            "borderCollapse",
            "borderColor",
            "borderColorDark",
            "borderColorLight",
            "borderEndEndRadius",
            "borderEndStartRadius",
            "borderImage",
            "borderImageOutset",
            "borderImageRepeat",
            "borderImageSlice",
            "borderImageSource",
            "borderImageWidth",
            "borderInline",
            "borderInlineColor",
            "borderInlineEnd",
            "borderInlineEndColor",
            "borderInlineEndStyle",
            "borderInlineEndWidth",
            "borderInlineStart",
            "borderInlineStartColor",
            "borderInlineStartStyle",
            "borderInlineStartWidth",
            "borderInlineStyle",
            "borderInlineWidth",
            "borderLeft",
            "borderLeftColor",
            "borderLeftStyle",
            "borderLeftWidth",
            "borderRadius",
            "borderRight",
            "borderRightColor",
            "borderRightStyle",
            "borderRightWidth",
            "borderSpacing",
            "borderStartEndRadius",
            "borderStartStartRadius",
            "borderStyle",
            "borderTop",
            "borderTopColor",
            "borderTopLeftRadius",
            "borderTopRightRadius",
            "borderTopStyle",
            "borderTopWidth",
            "borderWidth",
            "bottom",
            "bottomMargin",
            "bound",
            "boundElements",
            "boundingClientRect",
            "boundingHeight",
            "boundingLeft",
            "boundingTop",
            "boundingWidth",
            "bounds",
            "boundsGeometry",
            "box-decoration-break",
            "box-shadow",
            "box-sizing",
            "boxDecorationBreak",
            "boxShadow",
            "boxSizing",
            "brand",
            "brands",
            "break-after",
            "break-before",
            "break-inside",
            "breakAfter",
            "breakBefore",
            "breakInside",
            "broadcast",
            "browserLanguage",
            "btoa",
            "bubbles",
            "buffer",
            "bufferData",
            "bufferDepth",
            "bufferSize",
            "bufferSubData",
            "buffered",
            "bufferedAmount",
            "bufferedAmountLowThreshold",
            "buffers",
            "buildID",
            "buildNumber",
            "button",
            "buttonID",
            "buttons",
            "byteLength",
            "byteOffset",
            "bytesPerRow",
            "bytesWritten",
            "c",
            "cache",
            "caches",
            "call",
            "caller",
            "canBeFormatted",
            "canBeMounted",
            "canBeShared",
            "canHaveChildren",
            "canHaveHTML",
            "canInsertDTMF",
            "canMakePayment",
            "canPlayType",
            "canPresent",
            "canTrickleIceCandidates",
            "cancel",
            "cancelAndHoldAtTime",
            "cancelAnimationFrame",
            "cancelBubble",
            "cancelIdleCallback",
            "cancelScheduledValues",
            "cancelVideoFrameCallback",
            "cancelWatchAvailability",
            "cancelable",
            "candidate",
            "canonicalUUID",
            "canvas",
            "capabilities",
            "caption",
            "caption-side",
            "captionSide",
            "capture",
            "captureEvents",
            "captureStackTrace",
            "captureStream",
            "caret-color",
            "caretBidiLevel",
            "caretColor",
            "caretPositionFromPoint",
            "caretRangeFromPoint",
            "cast",
            "catch",
            "category",
            "cbrt",
            "cd",
            "ceil",
            "cellIndex",
            "cellPadding",
            "cellSpacing",
            "cells",
            "ch",
            "chOff",
            "chain",
            "challenge",
            "changeType",
            "changedTouches",
            "channel",
            "channelCount",
            "channelCountMode",
            "channelInterpretation",
            "char",
            "charAt",
            "charCode",
            "charCodeAt",
            "charIndex",
            "charLength",
            "characterData",
            "characterDataOldValue",
            "characterSet",
            "characteristic",
            "charging",
            "chargingTime",
            "charset",
            "check",
            "checkEnclosure",
            "checkFramebufferStatus",
            "checkIntersection",
            "checkValidity",
            "checked",
            "childElementCount",
            "childList",
            "childNodes",
            "children",
            "chrome",
            "ciphertext",
            "cite",
            "city",
            "claimInterface",
            "claimed",
            "classList",
            "className",
            "classid",
            "clear",
            "clearAppBadge",
            "clearAttributes",
            "clearBuffer",
            "clearBufferfi",
            "clearBufferfv",
            "clearBufferiv",
            "clearBufferuiv",
            "clearColor",
            "clearData",
            "clearDepth",
            "clearHalt",
            "clearImmediate",
            "clearInterval",
            "clearLiveSeekableRange",
            "clearMarks",
            "clearMaxGCPauseAccumulator",
            "clearMeasures",
            "clearParameters",
            "clearRect",
            "clearResourceTimings",
            "clearShadow",
            "clearStencil",
            "clearTimeout",
            "clearValue",
            "clearWatch",
            "click",
            "clickCount",
            "clientDataJSON",
            "clientHeight",
            "clientInformation",
            "clientLeft",
            "clientRect",
            "clientRects",
            "clientTop",
            "clientWaitSync",
            "clientWidth",
            "clientX",
            "clientY",
            "clip",
            "clip-path",
            "clip-rule",
            "clipBottom",
            "clipLeft",
            "clipPath",
            "clipPathUnits",
            "clipRight",
            "clipRule",
            "clipTop",
            "clipboard",
            "clipboardData",
            "clone",
            "cloneContents",
            "cloneNode",
            "cloneRange",
            "close",
            "closePath",
            "closed",
            "closest",
            "clz",
            "clz32",
            "cm",
            "cmp",
            "code",
            "codeBase",
            "codePointAt",
            "codeType",
            "colSpan",
            "collapse",
            "collapseToEnd",
            "collapseToStart",
            "collapsed",
            "collect",
            "colno",
            "color",
            "color-adjust",
            "color-interpolation",
            "color-interpolation-filters",
            "colorAdjust",
            "colorAttachments",
            "colorDepth",
            "colorFormats",
            "colorInterpolation",
            "colorInterpolationFilters",
            "colorMask",
            "colorSpace",
            "colorType",
            "cols",
            "column-count",
            "column-fill",
            "column-gap",
            "column-rule",
            "column-rule-color",
            "column-rule-style",
            "column-rule-width",
            "column-span",
            "column-width",
            "columnCount",
            "columnFill",
            "columnGap",
            "columnNumber",
            "columnRule",
            "columnRuleColor",
            "columnRuleStyle",
            "columnRuleWidth",
            "columnSpan",
            "columnWidth",
            "columns",
            "command",
            "commit",
            "commitPreferences",
            "commitStyles",
            "commonAncestorContainer",
            "compact",
            "compare",
            "compareBoundaryPoints",
            "compareDocumentPosition",
            "compareEndPoints",
            "compareExchange",
            "compareNode",
            "comparePoint",
            "compatMode",
            "compatible",
            "compile",
            "compileShader",
            "compileStreaming",
            "complete",
            "component",
            "componentFromPoint",
            "composed",
            "composedPath",
            "composite",
            "compositionEndOffset",
            "compositionStartOffset",
            "compressedTexImage2D",
            "compressedTexImage3D",
            "compressedTexSubImage2D",
            "compressedTexSubImage3D",
            "compute",
            "computedStyleMap",
            "concat",
            "conditionText",
            "coneInnerAngle",
            "coneOuterAngle",
            "coneOuterGain",
            "configurable",
            "configuration",
            "configurationName",
            "configurationValue",
            "configurations",
            "configure",
            "confirm",
            "confirmComposition",
            "confirmSiteSpecificTrackingException",
            "confirmWebWideTrackingException",
            "connect",
            "connectEnd",
            "connectShark",
            "connectStart",
            "connected",
            "connection",
            "connectionList",
            "connectionSpeed",
            "connectionState",
            "connections",
            "console",
            "consolidate",
            "constants",
            "constraint",
            "constrictionActive",
            "construct",
            "constructor",
            "contactID",
            "contain",
            "containerId",
            "containerName",
            "containerSrc",
            "containerType",
            "contains",
            "containsNode",
            "content",
            "contentBoxSize",
            "contentDocument",
            "contentEditable",
            "contentHint",
            "contentOverflow",
            "contentRect",
            "contentScriptType",
            "contentStyleType",
            "contentType",
            "contentWindow",
            "context",
            "contextMenu",
            "contextmenu",
            "continue",
            "continuePrimaryKey",
            "continuous",
            "control",
            "controlTransferIn",
            "controlTransferOut",
            "controller",
            "controls",
            "controlsList",
            "convertPointFromNode",
            "convertQuadFromNode",
            "convertRectFromNode",
            "convertToBlob",
            "convertToSpecifiedUnits",
            "cookie",
            "cookieEnabled",
            "coords",
            "copyBufferSubData",
            "copyBufferToBuffer",
            "copyBufferToTexture",
            "copyExternalImageToTexture",
            "copyFromChannel",
            "copyTexImage2D",
            "copyTexSubImage2D",
            "copyTexSubImage3D",
            "copyTextureToBuffer",
            "copyTextureToTexture",
            "copyToChannel",
            "copyWithin",
            "correspondingElement",
            "correspondingUseElement",
            "corruptedVideoFrames",
            "cos",
            "cosh",
            "count",
            "countReset",
            "counter-increment",
            "counter-reset",
            "counter-set",
            "counterIncrement",
            "counterReset",
            "counterSet",
            "country",
            "cpuClass",
            "cpuSleepAllowed",
            "create",
            "createAnalyser",
            "createAnswer",
            "createAttribute",
            "createAttributeNS",
            "createBindGroup",
            "createBindGroupLayout",
            "createBiquadFilter",
            "createBuffer",
            "createBufferSource",
            "createCDATASection",
            "createCSSStyleSheet",
            "createCaption",
            "createChannelMerger",
            "createChannelSplitter",
            "createCommandEncoder",
            "createComment",
            "createComputePipeline",
            "createComputePipelineAsync",
            "createConstantSource",
            "createContextualFragment",
            "createControlRange",
            "createConvolver",
            "createDTMFSender",
            "createDataChannel",
            "createDelay",
            "createDelayNode",
            "createDocument",
            "createDocumentFragment",
            "createDocumentType",
            "createDynamicsCompressor",
            "createElement",
            "createElementNS",
            "createEntityReference",
            "createEvent",
            "createEventObject",
            "createExpression",
            "createFramebuffer",
            "createFunction",
            "createGain",
            "createGainNode",
            "createHTML",
            "createHTMLDocument",
            "createIIRFilter",
            "createImageBitmap",
            "createImageData",
            "createIndex",
            "createJavaScriptNode",
            "createLinearGradient",
            "createMediaElementSource",
            "createMediaKeys",
            "createMediaStreamDestination",
            "createMediaStreamSource",
            "createMediaStreamTrackSource",
            "createMutableFile",
            "createNSResolver",
            "createNodeIterator",
            "createNotification",
            "createObjectStore",
            "createObjectURL",
            "createOffer",
            "createOscillator",
            "createPanner",
            "createPattern",
            "createPeriodicWave",
            "createPipelineLayout",
            "createPolicy",
            "createPopup",
            "createProcessingInstruction",
            "createProgram",
            "createQuery",
            "createQuerySet",
            "createRadialGradient",
            "createRange",
            "createRangeCollection",
            "createReader",
            "createRenderBundleEncoder",
            "createRenderPipeline",
            "createRenderPipelineAsync",
            "createRenderbuffer",
            "createSVGAngle",
            "createSVGLength",
            "createSVGMatrix",
            "createSVGNumber",
            "createSVGPathSegArcAbs",
            "createSVGPathSegArcRel",
            "createSVGPathSegClosePath",
            "createSVGPathSegCurvetoCubicAbs",
            "createSVGPathSegCurvetoCubicRel",
            "createSVGPathSegCurvetoCubicSmoothAbs",
            "createSVGPathSegCurvetoCubicSmoothRel",
            "createSVGPathSegCurvetoQuadraticAbs",
            "createSVGPathSegCurvetoQuadraticRel",
            "createSVGPathSegCurvetoQuadraticSmoothAbs",
            "createSVGPathSegCurvetoQuadraticSmoothRel",
            "createSVGPathSegLinetoAbs",
            "createSVGPathSegLinetoHorizontalAbs",
            "createSVGPathSegLinetoHorizontalRel",
            "createSVGPathSegLinetoRel",
            "createSVGPathSegLinetoVerticalAbs",
            "createSVGPathSegLinetoVerticalRel",
            "createSVGPathSegMovetoAbs",
            "createSVGPathSegMovetoRel",
            "createSVGPoint",
            "createSVGRect",
            "createSVGTransform",
            "createSVGTransformFromMatrix",
            "createSampler",
            "createScript",
            "createScriptProcessor",
            "createScriptURL",
            "createSession",
            "createShader",
            "createShaderModule",
            "createShadowRoot",
            "createStereoPanner",
            "createStyleSheet",
            "createTBody",
            "createTFoot",
            "createTHead",
            "createTextNode",
            "createTextRange",
            "createTexture",
            "createTouch",
            "createTouchList",
            "createTransformFeedback",
            "createTreeWalker",
            "createVertexArray",
            "createView",
            "createWaveShaper",
            "creationTime",
            "credentials",
            "crossOrigin",
            "crossOriginIsolated",
            "crypto",
            "csi",
            "csp",
            "cssFloat",
            "cssRules",
            "cssText",
            "cssValueType",
            "ctrlKey",
            "ctrlLeft",
            "cues",
            "cullFace",
            "cullMode",
            "currentDirection",
            "currentLocalDescription",
            "currentNode",
            "currentPage",
            "currentRect",
            "currentRemoteDescription",
            "currentScale",
            "currentScript",
            "currentSrc",
            "currentState",
            "currentStyle",
            "currentTarget",
            "currentTime",
            "currentTranslate",
            "currentView",
            "cursor",
            "curve",
            "customElements",
            "customError",
            "cx",
            "cy",
            "d",
            "data",
            "dataFld",
            "dataFormatAs",
            "dataLoss",
            "dataLossMessage",
            "dataPageSize",
            "dataSrc",
            "dataTransfer",
            "database",
            "databases",
            "dataset",
            "dateTime",
            "db",
            "debug",
            "debuggerEnabled",
            "declare",
            "decode",
            "decodeAudioData",
            "decodeURI",
            "decodeURIComponent",
            "decodedBodySize",
            "decoding",
            "decodingInfo",
            "decrypt",
            "default",
            "defaultCharset",
            "defaultChecked",
            "defaultMuted",
            "defaultPlaybackRate",
            "defaultPolicy",
            "defaultPrevented",
            "defaultQueue",
            "defaultRequest",
            "defaultSelected",
            "defaultStatus",
            "defaultURL",
            "defaultValue",
            "defaultView",
            "defaultstatus",
            "defer",
            "define",
            "defineMagicFunction",
            "defineMagicVariable",
            "defineProperties",
            "defineProperty",
            "deg",
            "delay",
            "delayTime",
            "delegatesFocus",
            "delete",
            "deleteBuffer",
            "deleteCaption",
            "deleteCell",
            "deleteContents",
            "deleteData",
            "deleteDatabase",
            "deleteFramebuffer",
            "deleteFromDocument",
            "deleteIndex",
            "deleteMedium",
            "deleteObjectStore",
            "deleteProgram",
            "deleteProperty",
            "deleteQuery",
            "deleteRenderbuffer",
            "deleteRow",
            "deleteRule",
            "deleteSampler",
            "deleteShader",
            "deleteSync",
            "deleteTFoot",
            "deleteTHead",
            "deleteTexture",
            "deleteTransformFeedback",
            "deleteVertexArray",
            "deliverChangeRecords",
            "delivery",
            "deliveryInfo",
            "deliveryStatus",
            "deliveryTimestamp",
            "delta",
            "deltaMode",
            "deltaX",
            "deltaY",
            "deltaZ",
            "dependentLocality",
            "depthBias",
            "depthBiasClamp",
            "depthBiasSlopeScale",
            "depthClearValue",
            "depthCompare",
            "depthFailOp",
            "depthFar",
            "depthFunc",
            "depthLoadOp",
            "depthMask",
            "depthNear",
            "depthOrArrayLayers",
            "depthRange",
            "depthReadOnly",
            "depthStencil",
            "depthStencilAttachment",
            "depthStencilFormat",
            "depthStoreOp",
            "depthWriteEnabled",
            "deref",
            "deriveBits",
            "deriveKey",
            "description",
            "deselectAll",
            "designMode",
            "desiredSize",
            "destination",
            "destinationURL",
            "destroy",
            "detach",
            "detachEvent",
            "detachShader",
            "detail",
            "details",
            "detect",
            "detune",
            "device",
            "deviceClass",
            "deviceId",
            "deviceMemory",
            "devicePixelContentBoxSize",
            "devicePixelRatio",
            "deviceProtocol",
            "deviceSubclass",
            "deviceVersionMajor",
            "deviceVersionMinor",
            "deviceVersionSubminor",
            "deviceXDPI",
            "deviceYDPI",
            "didTimeout",
            "diffuseConstant",
            "digest",
            "dimension",
            "dimensions",
            "dir",
            "dirName",
            "direction",
            "dirxml",
            "disable",
            "disablePictureInPicture",
            "disableRemotePlayback",
            "disableVertexAttribArray",
            "disabled",
            "dischargingTime",
            "disconnect",
            "disconnectShark",
            "dispatchEvent",
            "dispatchWorkgroups",
            "dispatchWorkgroupsIndirect",
            "display",
            "displayId",
            "displayName",
            "disposition",
            "distanceModel",
            "div",
            "divisor",
            "djsapi",
            "djsproxy",
            "doImport",
            "doNotTrack",
            "doScroll",
            "doctype",
            "document",
            "documentElement",
            "documentMode",
            "documentURI",
            "dolphin",
            "dolphinGameCenter",
            "dolphininfo",
            "dolphinmeta",
            "domComplete",
            "domContentLoadedEventEnd",
            "domContentLoadedEventStart",
            "domInteractive",
            "domLoading",
            "domOverlayState",
            "domain",
            "domainLookupEnd",
            "domainLookupStart",
            "dominant-baseline",
            "dominantBaseline",
            "done",
            "dopplerFactor",
            "dotAll",
            "downDegrees",
            "downlink",
            "download",
            "downloadTotal",
            "downloaded",
            "dpcm",
            "dpi",
            "dppx",
            "dragDrop",
            "draggable",
            "draw",
            "drawArrays",
            "drawArraysInstanced",
            "drawArraysInstancedANGLE",
            "drawBuffers",
            "drawCustomFocusRing",
            "drawElements",
            "drawElementsInstanced",
            "drawElementsInstancedANGLE",
            "drawFocusIfNeeded",
            "drawImage",
            "drawImageFromRect",
            "drawIndexed",
            "drawIndexedIndirect",
            "drawIndirect",
            "drawRangeElements",
            "drawSystemFocusRing",
            "drawingBufferHeight",
            "drawingBufferWidth",
            "dropEffect",
            "droppedVideoFrames",
            "dropzone",
            "dstFactor",
            "dtmf",
            "dump",
            "dumpProfile",
            "duplicate",
            "durability",
            "duration",
            "dvname",
            "dvnum",
            "dx",
            "dy",
            "dynsrc",
            "e",
            "edgeMode",
            "effect",
            "effectAllowed",
            "effectiveDirective",
            "effectiveType",
            "elapsedTime",
            "element",
            "elementFromPoint",
            "elementTiming",
            "elements",
            "elementsFromPoint",
            "elevation",
            "ellipse",
            "em",
            "email",
            "embeds",
            "emma",
            "empty",
            "empty-cells",
            "emptyCells",
            "emptyHTML",
            "emptyScript",
            "emulatedPosition",
            "enable",
            "enableBackground",
            "enableDelegations",
            "enableStyleSheetsForSet",
            "enableVertexAttribArray",
            "enabled",
            "enabledPlugin",
            "encode",
            "encodeInto",
            "encodeURI",
            "encodeURIComponent",
            "encodedBodySize",
            "encoding",
            "encodingInfo",
            "encrypt",
            "enctype",
            "end",
            "endContainer",
            "endElement",
            "endElementAt",
            "endOcclusionQuery",
            "endOfPassWriteIndex",
            "endOfStream",
            "endOffset",
            "endQuery",
            "endTime",
            "endTransformFeedback",
            "ended",
            "endpoint",
            "endpointNumber",
            "endpoints",
            "endsWith",
            "enterKeyHint",
            "entities",
            "entries",
            "entryPoint",
            "entryType",
            "enumerable",
            "enumerate",
            "enumerateDevices",
            "enumerateEditable",
            "environmentBlendMode",
            "equals",
            "error",
            "errorCode",
            "errorDetail",
            "errorText",
            "escape",
            "estimate",
            "eval",
            "evaluate",
            "event",
            "eventPhase",
            "every",
            "ex",
            "exception",
            "exchange",
            "exec",
            "execCommand",
            "execCommandShowHelp",
            "execScript",
            "executeBundles",
            "exitFullscreen",
            "exitPictureInPicture",
            "exitPointerLock",
            "exitPresent",
            "exp",
            "expand",
            "expandEntityReferences",
            "expando",
            "expansion",
            "expiration",
            "expirationTime",
            "expires",
            "expiryDate",
            "explicitOriginalTarget",
            "expm1",
            "exponent",
            "exponentialRampToValueAtTime",
            "exportKey",
            "exports",
            "extend",
            "extensions",
            "extentNode",
            "extentOffset",
            "external",
            "externalResourcesRequired",
            "externalTexture",
            "extractContents",
            "extractable",
            "eye",
            "f",
            "face",
            "factoryReset",
            "failOp",
            "failureReason",
            "fallback",
            "family",
            "familyName",
            "farthestViewportElement",
            "fastSeek",
            "fatal",
            "featureId",
            "featurePolicy",
            "featureSettings",
            "features",
            "fenceSync",
            "fetch",
            "fetchStart",
            "fftSize",
            "fgColor",
            "fieldOfView",
            "file",
            "fileCreatedDate",
            "fileHandle",
            "fileModifiedDate",
            "fileName",
            "fileSize",
            "fileUpdatedDate",
            "filename",
            "files",
            "filesystem",
            "fill",
            "fill-opacity",
            "fill-rule",
            "fillLightMode",
            "fillOpacity",
            "fillRect",
            "fillRule",
            "fillStyle",
            "fillText",
            "filter",
            "filterResX",
            "filterResY",
            "filterUnits",
            "filters",
            "finally",
            "find",
            "findIndex",
            "findRule",
            "findText",
            "finish",
            "finished",
            "fireEvent",
            "firesTouchEvents",
            "firstChild",
            "firstElementChild",
            "firstPage",
            "fixed",
            "flags",
            "flat",
            "flatMap",
            "flex",
            "flex-basis",
            "flex-direction",
            "flex-flow",
            "flex-grow",
            "flex-shrink",
            "flex-wrap",
            "flexBasis",
            "flexDirection",
            "flexFlow",
            "flexGrow",
            "flexShrink",
            "flexWrap",
            "flipX",
            "flipY",
            "float",
            "float32",
            "float64",
            "flood-color",
            "flood-opacity",
            "floodColor",
            "floodOpacity",
            "floor",
            "flush",
            "focus",
            "focusNode",
            "focusOffset",
            "font",
            "font-family",
            "font-feature-settings",
            "font-kerning",
            "font-language-override",
            "font-optical-sizing",
            "font-size",
            "font-size-adjust",
            "font-stretch",
            "font-style",
            "font-synthesis",
            "font-variant",
            "font-variant-alternates",
            "font-variant-caps",
            "font-variant-east-asian",
            "font-variant-ligatures",
            "font-variant-numeric",
            "font-variant-position",
            "font-variation-settings",
            "font-weight",
            "fontFamily",
            "fontFeatureSettings",
            "fontKerning",
            "fontLanguageOverride",
            "fontOpticalSizing",
            "fontSize",
            "fontSizeAdjust",
            "fontSmoothingEnabled",
            "fontStretch",
            "fontStyle",
            "fontSynthesis",
            "fontVariant",
            "fontVariantAlternates",
            "fontVariantCaps",
            "fontVariantEastAsian",
            "fontVariantLigatures",
            "fontVariantNumeric",
            "fontVariantPosition",
            "fontVariationSettings",
            "fontWeight",
            "fontcolor",
            "fontfaces",
            "fonts",
            "fontsize",
            "for",
            "forEach",
            "force",
            "forceFallbackAdapter",
            "forceRedraw",
            "form",
            "formAction",
            "formData",
            "formEnctype",
            "formMethod",
            "formNoValidate",
            "formTarget",
            "format",
            "formatToParts",
            "forms",
            "forward",
            "forwardX",
            "forwardY",
            "forwardZ",
            "foundation",
            "fr",
            "fragment",
            "fragmentDirective",
            "frame",
            "frameBorder",
            "frameElement",
            "frameSpacing",
            "framebuffer",
            "framebufferHeight",
            "framebufferRenderbuffer",
            "framebufferTexture2D",
            "framebufferTextureLayer",
            "framebufferWidth",
            "frames",
            "freeSpace",
            "freeze",
            "frequency",
            "frequencyBinCount",
            "from",
            "fromCharCode",
            "fromCodePoint",
            "fromElement",
            "fromEntries",
            "fromFloat32Array",
            "fromFloat64Array",
            "fromMatrix",
            "fromPoint",
            "fromQuad",
            "fromRect",
            "frontFace",
            "fround",
            "fullPath",
            "fullScreen",
            "fullVersionList",
            "fullscreen",
            "fullscreenElement",
            "fullscreenEnabled",
            "fx",
            "fy",
            "g",
            "gain",
            "gamepad",
            "gamma",
            "gap",
            "gatheringState",
            "gatt",
            "genderIdentity",
            "generateCertificate",
            "generateKey",
            "generateMipmap",
            "generateRequest",
            "geolocation",
            "gestureObject",
            "get",
            "getActiveAttrib",
            "getActiveUniform",
            "getActiveUniformBlockName",
            "getActiveUniformBlockParameter",
            "getActiveUniforms",
            "getAdjacentText",
            "getAll",
            "getAllKeys",
            "getAllResponseHeaders",
            "getAllowlistForFeature",
            "getAnimations",
            "getAsFile",
            "getAsString",
            "getAttachedShaders",
            "getAttribLocation",
            "getAttribute",
            "getAttributeNS",
            "getAttributeNames",
            "getAttributeNode",
            "getAttributeNodeNS",
            "getAttributeType",
            "getAudioTracks",
            "getAvailability",
            "getBBox",
            "getBattery",
            "getBigInt64",
            "getBigUint64",
            "getBindGroupLayout",
            "getBlob",
            "getBookmark",
            "getBoundingClientRect",
            "getBounds",
            "getBoxQuads",
            "getBufferParameter",
            "getBufferSubData",
            "getByteFrequencyData",
            "getByteTimeDomainData",
            "getCSSCanvasContext",
            "getCTM",
            "getCandidateWindowClientRect",
            "getCanonicalLocales",
            "getCapabilities",
            "getChannelData",
            "getCharNumAtPosition",
            "getCharacteristic",
            "getCharacteristics",
            "getClientExtensionResults",
            "getClientRect",
            "getClientRects",
            "getCoalescedEvents",
            "getCompilationInfo",
            "getCompositionAlternatives",
            "getComputedStyle",
            "getComputedTextLength",
            "getComputedTiming",
            "getConfiguration",
            "getConstraints",
            "getContext",
            "getContextAttributes",
            "getContributingSources",
            "getCounterValue",
            "getCueAsHTML",
            "getCueById",
            "getCurrentPosition",
            "getCurrentTexture",
            "getCurrentTime",
            "getData",
            "getDatabaseNames",
            "getDate",
            "getDay",
            "getDefaultComputedStyle",
            "getDescriptor",
            "getDescriptors",
            "getDestinationInsertionPoints",
            "getDevices",
            "getDirectory",
            "getDisplayMedia",
            "getDistributedNodes",
            "getEditable",
            "getElementById",
            "getElementsByClassName",
            "getElementsByName",
            "getElementsByTagName",
            "getElementsByTagNameNS",
            "getEnclosureList",
            "getEndPositionOfChar",
            "getEntries",
            "getEntriesByName",
            "getEntriesByType",
            "getError",
            "getExtension",
            "getExtentOfChar",
            "getEyeParameters",
            "getFeature",
            "getFile",
            "getFiles",
            "getFilesAndDirectories",
            "getFingerprints",
            "getFloat32",
            "getFloat64",
            "getFloatFrequencyData",
            "getFloatTimeDomainData",
            "getFloatValue",
            "getFragDataLocation",
            "getFrameData",
            "getFramebufferAttachmentParameter",
            "getFrequencyResponse",
            "getFullYear",
            "getGamepads",
            "getHighEntropyValues",
            "getHitTestResults",
            "getHitTestResultsForTransientInput",
            "getHours",
            "getIdentityAssertion",
            "getIds",
            "getImageData",
            "getIndexedParameter",
            "getInstalledRelatedApps",
            "getInt16",
            "getInt32",
            "getInt8",
            "getInternalformatParameter",
            "getIntersectionList",
            "getItem",
            "getItems",
            "getKey",
            "getKeyframes",
            "getLayers",
            "getLayoutMap",
            "getLineDash",
            "getLocalCandidates",
            "getLocalParameters",
            "getLocalStreams",
            "getMappedRange",
            "getMarks",
            "getMatchedCSSRules",
            "getMaxGCPauseSinceClear",
            "getMeasures",
            "getMetadata",
            "getMilliseconds",
            "getMinutes",
            "getModifierState",
            "getMonth",
            "getNamedItem",
            "getNamedItemNS",
            "getNativeFramebufferScaleFactor",
            "getNotifications",
            "getNotifier",
            "getNumberOfChars",
            "getOffsetReferenceSpace",
            "getOutputTimestamp",
            "getOverrideHistoryNavigationMode",
            "getOverrideStyle",
            "getOwnPropertyDescriptor",
            "getOwnPropertyDescriptors",
            "getOwnPropertyNames",
            "getOwnPropertySymbols",
            "getParameter",
            "getParameters",
            "getParent",
            "getPathSegAtLength",
            "getPhotoCapabilities",
            "getPhotoSettings",
            "getPointAtLength",
            "getPose",
            "getPredictedEvents",
            "getPreference",
            "getPreferenceDefault",
            "getPreferredCanvasFormat",
            "getPresentationAttribute",
            "getPreventDefault",
            "getPrimaryService",
            "getPrimaryServices",
            "getProgramInfoLog",
            "getProgramParameter",
            "getPropertyCSSValue",
            "getPropertyPriority",
            "getPropertyShorthand",
            "getPropertyType",
            "getPropertyValue",
            "getPrototypeOf",
            "getQuery",
            "getQueryParameter",
            "getRGBColorValue",
            "getRandomValues",
            "getRangeAt",
            "getReader",
            "getReceivers",
            "getRectValue",
            "getRegistration",
            "getRegistrations",
            "getRemoteCandidates",
            "getRemoteCertificates",
            "getRemoteParameters",
            "getRemoteStreams",
            "getRenderbufferParameter",
            "getResponseHeader",
            "getRoot",
            "getRootNode",
            "getRotationOfChar",
            "getSVGDocument",
            "getSamplerParameter",
            "getScreenCTM",
            "getSeconds",
            "getSelectedCandidatePair",
            "getSelection",
            "getSenders",
            "getService",
            "getSettings",
            "getShaderInfoLog",
            "getShaderParameter",
            "getShaderPrecisionFormat",
            "getShaderSource",
            "getSimpleDuration",
            "getSiteIcons",
            "getSources",
            "getSpeculativeParserUrls",
            "getStartPositionOfChar",
            "getStartTime",
            "getState",
            "getStats",
            "getStatusForPolicy",
            "getStorageUpdates",
            "getStreamById",
            "getStringValue",
            "getSubStringLength",
            "getSubscription",
            "getSupportedConstraints",
            "getSupportedExtensions",
            "getSupportedFormats",
            "getSyncParameter",
            "getSynchronizationSources",
            "getTags",
            "getTargetRanges",
            "getTexParameter",
            "getTime",
            "getTimezoneOffset",
            "getTiming",
            "getTotalLength",
            "getTrackById",
            "getTracks",
            "getTransceivers",
            "getTransform",
            "getTransformFeedbackVarying",
            "getTransformToElement",
            "getTransports",
            "getType",
            "getTypeMapping",
            "getUTCDate",
            "getUTCDay",
            "getUTCFullYear",
            "getUTCHours",
            "getUTCMilliseconds",
            "getUTCMinutes",
            "getUTCMonth",
            "getUTCSeconds",
            "getUint16",
            "getUint32",
            "getUint8",
            "getUniform",
            "getUniformBlockIndex",
            "getUniformIndices",
            "getUniformLocation",
            "getUserMedia",
            "getVRDisplays",
            "getValues",
            "getVarDate",
            "getVariableValue",
            "getVertexAttrib",
            "getVertexAttribOffset",
            "getVideoPlaybackQuality",
            "getVideoTracks",
            "getViewerPose",
            "getViewport",
            "getVoices",
            "getWakeLockState",
            "getWriter",
            "getYear",
            "givenName",
            "global",
            "globalAlpha",
            "globalCompositeOperation",
            "globalThis",
            "glyphOrientationHorizontal",
            "glyphOrientationVertical",
            "glyphRef",
            "go",
            "gpu",
            "grabFrame",
            "grad",
            "gradientTransform",
            "gradientUnits",
            "grammars",
            "green",
            "grid",
            "grid-area",
            "grid-auto-columns",
            "grid-auto-flow",
            "grid-auto-rows",
            "grid-column",
            "grid-column-end",
            "grid-column-gap",
            "grid-column-start",
            "grid-gap",
            "grid-row",
            "grid-row-end",
            "grid-row-gap",
            "grid-row-start",
            "grid-template",
            "grid-template-areas",
            "grid-template-columns",
            "grid-template-rows",
            "gridArea",
            "gridAutoColumns",
            "gridAutoFlow",
            "gridAutoRows",
            "gridColumn",
            "gridColumnEnd",
            "gridColumnGap",
            "gridColumnStart",
            "gridGap",
            "gridRow",
            "gridRowEnd",
            "gridRowGap",
            "gridRowStart",
            "gridTemplate",
            "gridTemplateAreas",
            "gridTemplateColumns",
            "gridTemplateRows",
            "gripSpace",
            "group",
            "groups",
            "groupCollapsed",
            "groupEnd",
            "groupId",
            "hadRecentInput",
            "hand",
            "handedness",
            "hapticActuators",
            "hardwareConcurrency",
            "has",
            "hasAttribute",
            "hasAttributeNS",
            "hasAttributes",
            "hasBeenActive",
            "hasChildNodes",
            "hasComposition",
            "hasDynamicOffset",
            "hasEnrolledInstrument",
            "hasExtension",
            "hasExternalDisplay",
            "hasFeature",
            "hasFocus",
            "hasInstance",
            "hasLayout",
            "hasOrientation",
            "hasOwnProperty",
            "hasPointerCapture",
            "hasPosition",
            "hasReading",
            "hasStorageAccess",
            "hash",
            "head",
            "headers",
            "heading",
            "height",
            "hidden",
            "hide",
            "hideFocus",
            "high",
            "highWaterMark",
            "hint",
            "hints",
            "history",
            "honorificPrefix",
            "honorificSuffix",
            "horizontalOverflow",
            "host",
            "hostCandidate",
            "hostname",
            "href",
            "hrefTranslate",
            "hreflang",
            "hspace",
            "html5TagCheckInerface",
            "htmlFor",
            "htmlText",
            "httpEquiv",
            "httpRequestStatusCode",
            "hwTimestamp",
            "hyphens",
            "hypot",
            "iccId",
            "iceConnectionState",
            "iceGatheringState",
            "iceTransport",
            "icon",
            "iconURL",
            "id",
            "identifier",
            "identity",
            "idpLoginUrl",
            "ignoreBOM",
            "ignoreCase",
            "ignoreDepthValues",
            "image-orientation",
            "image-rendering",
            "imageHeight",
            "imageOrientation",
            "imageRendering",
            "imageSizes",
            "imageSmoothingEnabled",
            "imageSmoothingQuality",
            "imageSrcset",
            "imageWidth",
            "images",
            "ime-mode",
            "imeMode",
            "implementation",
            "importExternalTexture",
            "importKey",
            "importNode",
            "importStylesheet",
            "imports",
            "impp",
            "imul",
            "in",
            "in1",
            "in2",
            "inBandMetadataTrackDispatchType",
            "inRange",
            "includes",
            "incremental",
            "indeterminate",
            "index",
            "indexNames",
            "indexOf",
            "indexedDB",
            "indicate",
            "indices",
            "inert",
            "inertiaDestinationX",
            "inertiaDestinationY",
            "info",
            "init",
            "initAnimationEvent",
            "initBeforeLoadEvent",
            "initClipboardEvent",
            "initCloseEvent",
            "initCommandEvent",
            "initCompositionEvent",
            "initCustomEvent",
            "initData",
            "initDataType",
            "initDeviceMotionEvent",
            "initDeviceOrientationEvent",
            "initDragEvent",
            "initErrorEvent",
            "initEvent",
            "initFocusEvent",
            "initGestureEvent",
            "initHashChangeEvent",
            "initKeyEvent",
            "initKeyboardEvent",
            "initMSManipulationEvent",
            "initMessageEvent",
            "initMouseEvent",
            "initMouseScrollEvent",
            "initMouseWheelEvent",
            "initMutationEvent",
            "initNSMouseEvent",
            "initOverflowEvent",
            "initPageEvent",
            "initPageTransitionEvent",
            "initPointerEvent",
            "initPopStateEvent",
            "initProgressEvent",
            "initScrollAreaEvent",
            "initSimpleGestureEvent",
            "initStorageEvent",
            "initTextEvent",
            "initTimeEvent",
            "initTouchEvent",
            "initTransitionEvent",
            "initUIEvent",
            "initWebKitAnimationEvent",
            "initWebKitTransitionEvent",
            "initWebKitWheelEvent",
            "initWheelEvent",
            "initialTime",
            "initialize",
            "initiatorType",
            "inline-size",
            "inlineSize",
            "inlineVerticalFieldOfView",
            "inner",
            "innerHTML",
            "innerHeight",
            "innerText",
            "innerWidth",
            "input",
            "inputBuffer",
            "inputEncoding",
            "inputMethod",
            "inputMode",
            "inputSource",
            "inputSources",
            "inputType",
            "inputs",
            "insertAdjacentElement",
            "insertAdjacentHTML",
            "insertAdjacentText",
            "insertBefore",
            "insertCell",
            "insertDTMF",
            "insertData",
            "insertDebugMarker",
            "insertItemBefore",
            "insertNode",
            "insertRow",
            "insertRule",
            "inset",
            "inset-block",
            "inset-block-end",
            "inset-block-start",
            "inset-inline",
            "inset-inline-end",
            "inset-inline-start",
            "insetBlock",
            "insetBlockEnd",
            "insetBlockStart",
            "insetInline",
            "insetInlineEnd",
            "insetInlineStart",
            "installing",
            "instanceRoot",
            "instantiate",
            "instantiateStreaming",
            "instruments",
            "int16",
            "int32",
            "int8",
            "integrity",
            "interactionMode",
            "intercept",
            "interfaceClass",
            "interfaceName",
            "interfaceNumber",
            "interfaceProtocol",
            "interfaceSubclass",
            "interfaces",
            "interimResults",
            "internalSubset",
            "interpretation",
            "intersectionRatio",
            "intersectionRect",
            "intersectsNode",
            "interval",
            "invalidIteratorState",
            "invalidateFramebuffer",
            "invalidateSubFramebuffer",
            "inverse",
            "invertSelf",
            "is",
            "is2D",
            "isActive",
            "isAlternate",
            "isArray",
            "isBingCurrentSearchDefault",
            "isBuffer",
            "isCandidateWindowVisible",
            "isChar",
            "isCollapsed",
            "isComposing",
            "isConcatSpreadable",
            "isConnected",
            "isContentEditable",
            "isContentHandlerRegistered",
            "isContextLost",
            "isDefaultNamespace",
            "isDirectory",
            "isDisabled",
            "isEnabled",
            "isEqual",
            "isEqualNode",
            "isExtensible",
            "isExternalCTAP2SecurityKeySupported",
            "isFallbackAdapter",
            "isFile",
            "isFinite",
            "isFramebuffer",
            "isFrozen",
            "isGenerator",
            "isHTML",
            "isHistoryNavigation",
            "isId",
            "isIdentity",
            "isInjected",
            "isInteger",
            "isIntersecting",
            "isLockFree",
            "isMap",
            "isMultiLine",
            "isNaN",
            "isOpen",
            "isPointInFill",
            "isPointInPath",
            "isPointInRange",
            "isPointInStroke",
            "isPrefAlternate",
            "isPresenting",
            "isPrimary",
            "isProgram",
            "isPropertyImplicit",
            "isProtocolHandlerRegistered",
            "isPrototypeOf",
            "isQuery",
            "isRenderbuffer",
            "isSafeInteger",
            "isSameNode",
            "isSampler",
            "isScript",
            "isScriptURL",
            "isSealed",
            "isSecureContext",
            "isSessionSupported",
            "isShader",
            "isSupported",
            "isSync",
            "isTextEdit",
            "isTexture",
            "isTransformFeedback",
            "isTrusted",
            "isTypeSupported",
            "isUserVerifyingPlatformAuthenticatorAvailable",
            "isVertexArray",
            "isView",
            "isVisible",
            "isochronousTransferIn",
            "isochronousTransferOut",
            "isolation",
            "italics",
            "item",
            "itemId",
            "itemProp",
            "itemRef",
            "itemScope",
            "itemType",
            "itemValue",
            "items",
            "iterateNext",
            "iterationComposite",
            "iterator",
            "javaEnabled",
            "jobTitle",
            "join",
            "json",
            "justify-content",
            "justify-items",
            "justify-self",
            "justifyContent",
            "justifyItems",
            "justifySelf",
            "k1",
            "k2",
            "k3",
            "k4",
            "kHz",
            "keepalive",
            "kernelMatrix",
            "kernelUnitLengthX",
            "kernelUnitLengthY",
            "kerning",
            "key",
            "keyCode",
            "keyFor",
            "keyIdentifier",
            "keyLightEnabled",
            "keyLocation",
            "keyPath",
            "keyStatuses",
            "keySystem",
            "keyText",
            "keyUsage",
            "keyboard",
            "keys",
            "keytype",
            "kind",
            "knee",
            "label",
            "labels",
            "lang",
            "language",
            "languages",
            "largeArcFlag",
            "lastChild",
            "lastElementChild",
            "lastEventId",
            "lastIndex",
            "lastIndexOf",
            "lastInputTime",
            "lastMatch",
            "lastMessageSubject",
            "lastMessageType",
            "lastModified",
            "lastModifiedDate",
            "lastPage",
            "lastParen",
            "lastState",
            "lastStyleSheetSet",
            "latitude",
            "layerX",
            "layerY",
            "layout",
            "layoutFlow",
            "layoutGrid",
            "layoutGridChar",
            "layoutGridLine",
            "layoutGridMode",
            "layoutGridType",
            "lbound",
            "left",
            "leftContext",
            "leftDegrees",
            "leftMargin",
            "leftProjectionMatrix",
            "leftViewMatrix",
            "length",
            "lengthAdjust",
            "lengthComputable",
            "letter-spacing",
            "letterSpacing",
            "level",
            "lighting-color",
            "lightingColor",
            "limitingConeAngle",
            "limits",
            "line",
            "line-break",
            "line-height",
            "lineAlign",
            "lineBreak",
            "lineCap",
            "lineDashOffset",
            "lineHeight",
            "lineJoin",
            "lineNum",
            "lineNumber",
            "linePos",
            "lineTo",
            "lineWidth",
            "linearAcceleration",
            "linearRampToValueAtTime",
            "linearVelocity",
            "lineno",
            "lines",
            "link",
            "linkColor",
            "linkProgram",
            "links",
            "list",
            "list-style",
            "list-style-image",
            "list-style-position",
            "list-style-type",
            "listStyle",
            "listStyleImage",
            "listStylePosition",
            "listStyleType",
            "listener",
            "load",
            "loadEventEnd",
            "loadEventStart",
            "loadOp",
            "loadTime",
            "loadTimes",
            "loaded",
            "loading",
            "localDescription",
            "localName",
            "localService",
            "localStorage",
            "locale",
            "localeCompare",
            "location",
            "locationbar",
            "lock",
            "locked",
            "lockedFile",
            "locks",
            "lodMaxClamp",
            "lodMinClamp",
            "log",
            "log10",
            "log1p",
            "log2",
            "logicalXDPI",
            "logicalYDPI",
            "longDesc",
            "longitude",
            "lookupNamespaceURI",
            "lookupPrefix",
            "loop",
            "loopEnd",
            "loopStart",
            "looping",
            "lost",
            "low",
            "lower",
            "lowerBound",
            "lowerOpen",
            "lowsrc",
            "m11",
            "m12",
            "m13",
            "m14",
            "m21",
            "m22",
            "m23",
            "m24",
            "m31",
            "m32",
            "m33",
            "m34",
            "m41",
            "m42",
            "m43",
            "m44",
            "magFilter",
            "makeXRCompatible",
            "manifest",
            "manufacturer",
            "manufacturerName",
            "map",
            "mapAsync",
            "mapState",
            "mappedAtCreation",
            "mapping",
            "margin",
            "margin-block",
            "margin-block-end",
            "margin-block-start",
            "margin-bottom",
            "margin-inline",
            "margin-inline-end",
            "margin-inline-start",
            "margin-left",
            "margin-right",
            "margin-top",
            "marginBlock",
            "marginBlockEnd",
            "marginBlockStart",
            "marginBottom",
            "marginHeight",
            "marginInline",
            "marginInlineEnd",
            "marginInlineStart",
            "marginLeft",
            "marginRight",
            "marginTop",
            "marginWidth",
            "mark",
            "marker",
            "marker-end",
            "marker-mid",
            "marker-offset",
            "marker-start",
            "markerEnd",
            "markerHeight",
            "markerMid",
            "markerOffset",
            "markerStart",
            "markerUnits",
            "markerWidth",
            "marks",
            "mask",
            "mask-clip",
            "mask-composite",
            "mask-image",
            "mask-mode",
            "mask-origin",
            "mask-position",
            "mask-position-x",
            "mask-position-y",
            "mask-repeat",
            "mask-size",
            "mask-type",
            "maskClip",
            "maskComposite",
            "maskContentUnits",
            "maskImage",
            "maskMode",
            "maskOrigin",
            "maskPosition",
            "maskPositionX",
            "maskPositionY",
            "maskRepeat",
            "maskSize",
            "maskType",
            "maskUnits",
            "match",
            "matchAll",
            "matchMedia",
            "matchMedium",
            "matches",
            "matrix",
            "matrixTransform",
            "max",
            "max-block-size",
            "max-height",
            "max-inline-size",
            "max-width",
            "maxActions",
            "maxAlternatives",
            "maxAnisotropy",
            "maxBindGroups",
            "maxBindGroupsPlusVertexBuffers",
            "maxBindingsPerBindGroup",
            "maxBlockSize",
            "maxBufferSize",
            "maxChannelCount",
            "maxChannels",
            "maxColorAttachmentBytesPerSample",
            "maxColorAttachments",
            "maxComputeInvocationsPerWorkgroup",
            "maxComputeWorkgroupSizeX",
            "maxComputeWorkgroupSizeY",
            "maxComputeWorkgroupSizeZ",
            "maxComputeWorkgroupStorageSize",
            "maxComputeWorkgroupsPerDimension",
            "maxConnectionsPerServer",
            "maxDecibels",
            "maxDistance",
            "maxDrawCount",
            "maxDynamicStorageBuffersPerPipelineLayout",
            "maxDynamicUniformBuffersPerPipelineLayout",
            "maxHeight",
            "maxInlineSize",
            "maxInterStageShaderComponents",
            "maxInterStageShaderVariables",
            "maxLayers",
            "maxLength",
            "maxMessageSize",
            "maxPacketLifeTime",
            "maxRetransmits",
            "maxSampledTexturesPerShaderStage",
            "maxSamplersPerShaderStage",
            "maxStorageBufferBindingSize",
            "maxStorageBuffersPerShaderStage",
            "maxStorageTexturesPerShaderStage",
            "maxTextureArrayLayers",
            "maxTextureDimension1D",
            "maxTextureDimension2D",
            "maxTextureDimension3D",
            "maxTouchPoints",
            "maxUniformBufferBindingSize",
            "maxUniformBuffersPerShaderStage",
            "maxValue",
            "maxVertexAttributes",
            "maxVertexBufferArrayStride",
            "maxVertexBuffers",
            "maxWidth",
            "measure",
            "measureText",
            "media",
            "mediaCapabilities",
            "mediaDevices",
            "mediaElement",
            "mediaGroup",
            "mediaKeys",
            "mediaSession",
            "mediaStream",
            "mediaText",
            "meetOrSlice",
            "memory",
            "menubar",
            "mergeAttributes",
            "message",
            "messageClass",
            "messageHandlers",
            "messageType",
            "messages",
            "metaKey",
            "metadata",
            "method",
            "methodDetails",
            "methodName",
            "mid",
            "mimeType",
            "mimeTypes",
            "min",
            "min-block-size",
            "min-height",
            "min-inline-size",
            "min-width",
            "minBindingSize",
            "minBlockSize",
            "minDecibels",
            "minFilter",
            "minHeight",
            "minInlineSize",
            "minLength",
            "minStorageBufferOffsetAlignment",
            "minUniformBufferOffsetAlignment",
            "minValue",
            "minWidth",
            "mipLevel",
            "mipLevelCount",
            "mipmapFilter",
            "miterLimit",
            "mix-blend-mode",
            "mixBlendMode",
            "mm",
            "mobile",
            "mode",
            "model",
            "modify",
            "module",
            "mount",
            "move",
            "moveBy",
            "moveEnd",
            "moveFirst",
            "moveFocusDown",
            "moveFocusLeft",
            "moveFocusRight",
            "moveFocusUp",
            "moveNext",
            "moveRow",
            "moveStart",
            "moveTo",
            "moveToBookmark",
            "moveToElementText",
            "moveToPoint",
            "movementX",
            "movementY",
            "mozAdd",
            "mozAnimationStartTime",
            "mozAnon",
            "mozApps",
            "mozAudioCaptured",
            "mozAudioChannelType",
            "mozAutoplayEnabled",
            "mozCancelAnimationFrame",
            "mozCancelFullScreen",
            "mozCancelRequestAnimationFrame",
            "mozCaptureStream",
            "mozCaptureStreamUntilEnded",
            "mozClearDataAt",
            "mozContact",
            "mozContacts",
            "mozCreateFileHandle",
            "mozCurrentTransform",
            "mozCurrentTransformInverse",
            "mozCursor",
            "mozDash",
            "mozDashOffset",
            "mozDecodedFrames",
            "mozExitPointerLock",
            "mozFillRule",
            "mozFragmentEnd",
            "mozFrameDelay",
            "mozFullScreen",
            "mozFullScreenElement",
            "mozFullScreenEnabled",
            "mozGetAll",
            "mozGetAllKeys",
            "mozGetAsFile",
            "mozGetDataAt",
            "mozGetMetadata",
            "mozGetUserMedia",
            "mozHasAudio",
            "mozHasItem",
            "mozHidden",
            "mozImageSmoothingEnabled",
            "mozIndexedDB",
            "mozInnerScreenX",
            "mozInnerScreenY",
            "mozInputSource",
            "mozIsTextField",
            "mozItem",
            "mozItemCount",
            "mozItems",
            "mozLength",
            "mozLockOrientation",
            "mozMatchesSelector",
            "mozMovementX",
            "mozMovementY",
            "mozOpaque",
            "mozOrientation",
            "mozPaintCount",
            "mozPaintedFrames",
            "mozParsedFrames",
            "mozPay",
            "mozPointerLockElement",
            "mozPresentedFrames",
            "mozPreservesPitch",
            "mozPressure",
            "mozPrintCallback",
            "mozRTCIceCandidate",
            "mozRTCPeerConnection",
            "mozRTCSessionDescription",
            "mozRemove",
            "mozRequestAnimationFrame",
            "mozRequestFullScreen",
            "mozRequestPointerLock",
            "mozSetDataAt",
            "mozSetImageElement",
            "mozSourceNode",
            "mozSrcObject",
            "mozSystem",
            "mozTCPSocket",
            "mozTextStyle",
            "mozTypesAt",
            "mozUnlockOrientation",
            "mozUserCancelled",
            "mozVisibilityState",
            "ms",
            "msAnimation",
            "msAnimationDelay",
            "msAnimationDirection",
            "msAnimationDuration",
            "msAnimationFillMode",
            "msAnimationIterationCount",
            "msAnimationName",
            "msAnimationPlayState",
            "msAnimationStartTime",
            "msAnimationTimingFunction",
            "msBackfaceVisibility",
            "msBlockProgression",
            "msCSSOMElementFloatMetrics",
            "msCaching",
            "msCachingEnabled",
            "msCancelRequestAnimationFrame",
            "msCapsLockWarningOff",
            "msClearImmediate",
            "msClose",
            "msContentZoomChaining",
            "msContentZoomFactor",
            "msContentZoomLimit",
            "msContentZoomLimitMax",
            "msContentZoomLimitMin",
            "msContentZoomSnap",
            "msContentZoomSnapPoints",
            "msContentZoomSnapType",
            "msContentZooming",
            "msConvertURL",
            "msCrypto",
            "msDoNotTrack",
            "msElementsFromPoint",
            "msElementsFromRect",
            "msExitFullscreen",
            "msExtendedCode",
            "msFillRule",
            "msFirstPaint",
            "msFlex",
            "msFlexAlign",
            "msFlexDirection",
            "msFlexFlow",
            "msFlexItemAlign",
            "msFlexLinePack",
            "msFlexNegative",
            "msFlexOrder",
            "msFlexPack",
            "msFlexPositive",
            "msFlexPreferredSize",
            "msFlexWrap",
            "msFlowFrom",
            "msFlowInto",
            "msFontFeatureSettings",
            "msFullscreenElement",
            "msFullscreenEnabled",
            "msGetInputContext",
            "msGetRegionContent",
            "msGetUntransformedBounds",
            "msGraphicsTrustStatus",
            "msGridColumn",
            "msGridColumnAlign",
            "msGridColumnSpan",
            "msGridColumns",
            "msGridRow",
            "msGridRowAlign",
            "msGridRowSpan",
            "msGridRows",
            "msHidden",
            "msHighContrastAdjust",
            "msHyphenateLimitChars",
            "msHyphenateLimitLines",
            "msHyphenateLimitZone",
            "msHyphens",
            "msImageSmoothingEnabled",
            "msImeAlign",
            "msIndexedDB",
            "msInterpolationMode",
            "msIsStaticHTML",
            "msKeySystem",
            "msKeys",
            "msLaunchUri",
            "msLockOrientation",
            "msManipulationViewsEnabled",
            "msMatchMedia",
            "msMatchesSelector",
            "msMaxTouchPoints",
            "msOrientation",
            "msOverflowStyle",
            "msPerspective",
            "msPerspectiveOrigin",
            "msPlayToDisabled",
            "msPlayToPreferredSourceUri",
            "msPlayToPrimary",
            "msPointerEnabled",
            "msRegionOverflow",
            "msReleasePointerCapture",
            "msRequestAnimationFrame",
            "msRequestFullscreen",
            "msSaveBlob",
            "msSaveOrOpenBlob",
            "msScrollChaining",
            "msScrollLimit",
            "msScrollLimitXMax",
            "msScrollLimitXMin",
            "msScrollLimitYMax",
            "msScrollLimitYMin",
            "msScrollRails",
            "msScrollSnapPointsX",
            "msScrollSnapPointsY",
            "msScrollSnapType",
            "msScrollSnapX",
            "msScrollSnapY",
            "msScrollTranslation",
            "msSetImmediate",
            "msSetMediaKeys",
            "msSetPointerCapture",
            "msTextCombineHorizontal",
            "msTextSizeAdjust",
            "msToBlob",
            "msTouchAction",
            "msTouchSelect",
            "msTraceAsyncCallbackCompleted",
            "msTraceAsyncCallbackStarting",
            "msTraceAsyncOperationCompleted",
            "msTraceAsyncOperationStarting",
            "msTransform",
            "msTransformOrigin",
            "msTransformStyle",
            "msTransition",
            "msTransitionDelay",
            "msTransitionDuration",
            "msTransitionProperty",
            "msTransitionTimingFunction",
            "msUnlockOrientation",
            "msUpdateAsyncCallbackRelation",
            "msUserSelect",
            "msVisibilityState",
            "msWrapFlow",
            "msWrapMargin",
            "msWrapThrough",
            "msWriteProfilerMark",
            "msZoom",
            "msZoomTo",
            "mt",
            "mul",
            "multiEntry",
            "multiSelectionObj",
            "multiline",
            "multiple",
            "multiply",
            "multiplySelf",
            "multisample",
            "multisampled",
            "mutableFile",
            "muted",
            "n",
            "name",
            "nameProp",
            "namedItem",
            "namedRecordset",
            "names",
            "namespaceURI",
            "namespaces",
            "naturalHeight",
            "naturalWidth",
            "navigate",
            "navigation",
            "navigationMode",
            "navigationPreload",
            "navigationStart",
            "navigator",
            "near",
            "nearestViewportElement",
            "negative",
            "negotiated",
            "netscape",
            "networkState",
            "newScale",
            "newTranslate",
            "newURL",
            "newValue",
            "newValueSpecifiedUnits",
            "newVersion",
            "newhome",
            "next",
            "nextElementSibling",
            "nextHopProtocol",
            "nextNode",
            "nextPage",
            "nextSibling",
            "nickname",
            "noHref",
            "noModule",
            "noResize",
            "noShade",
            "noValidate",
            "noWrap",
            "node",
            "nodeName",
            "nodeType",
            "nodeValue",
            "nonce",
            "normalize",
            "normalizedPathSegList",
            "notationName",
            "notations",
            "note",
            "noteGrainOn",
            "noteOff",
            "noteOn",
            "notify",
            "now",
            "numOctaves",
            "number",
            "numberOfChannels",
            "numberOfInputs",
            "numberOfItems",
            "numberOfOutputs",
            "numberValue",
            "oMatchesSelector",
            "object",
            "object-fit",
            "object-position",
            "objectFit",
            "objectPosition",
            "objectStore",
            "objectStoreNames",
            "objectType",
            "observe",
            "occlusionQuerySet",
            "of",
            "offscreenBuffering",
            "offset",
            "offset-anchor",
            "offset-distance",
            "offset-path",
            "offset-rotate",
            "offsetAnchor",
            "offsetDistance",
            "offsetHeight",
            "offsetLeft",
            "offsetNode",
            "offsetParent",
            "offsetPath",
            "offsetRotate",
            "offsetTop",
            "offsetWidth",
            "offsetX",
            "offsetY",
            "ok",
            "oldURL",
            "oldValue",
            "oldVersion",
            "olderShadowRoot",
            "onLine",
            "onSubmittedWorkDone",
            "onabort",
            "onabsolutedeviceorientation",
            "onactivate",
            "onactive",
            "onaddsourcebuffer",
            "onaddstream",
            "onaddtrack",
            "onafterprint",
            "onafterscriptexecute",
            "onafterupdate",
            "onanimationcancel",
            "onanimationend",
            "onanimationiteration",
            "onanimationstart",
            "onappinstalled",
            "onaudioend",
            "onaudioprocess",
            "onaudiostart",
            "onautocomplete",
            "onautocompleteerror",
            "onauxclick",
            "onbeforeactivate",
            "onbeforecopy",
            "onbeforecut",
            "onbeforedeactivate",
            "onbeforeeditfocus",
            "onbeforeinstallprompt",
            "onbeforepaste",
            "onbeforeprint",
            "onbeforescriptexecute",
            "onbeforeunload",
            "onbeforeupdate",
            "onbeforexrselect",
            "onbegin",
            "onblocked",
            "onblur",
            "onbounce",
            "onboundary",
            "onbufferedamountlow",
            "oncached",
            "oncancel",
            "oncandidatewindowhide",
            "oncandidatewindowshow",
            "oncandidatewindowupdate",
            "oncanplay",
            "oncanplaythrough",
            "once",
            "oncellchange",
            "onchange",
            "oncharacteristicvaluechanged",
            "onchargingchange",
            "onchargingtimechange",
            "onchecking",
            "onclick",
            "onclose",
            "onclosing",
            "oncompassneedscalibration",
            "oncomplete",
            "onconnect",
            "onconnecting",
            "onconnectionavailable",
            "onconnectionstatechange",
            "oncontextmenu",
            "oncontrollerchange",
            "oncontrolselect",
            "oncopy",
            "oncuechange",
            "oncut",
            "ondataavailable",
            "ondatachannel",
            "ondatasetchanged",
            "ondatasetcomplete",
            "ondblclick",
            "ondeactivate",
            "ondevicechange",
            "ondevicelight",
            "ondevicemotion",
            "ondeviceorientation",
            "ondeviceorientationabsolute",
            "ondeviceproximity",
            "ondischargingtimechange",
            "ondisconnect",
            "ondisplay",
            "ondownloading",
            "ondrag",
            "ondragend",
            "ondragenter",
            "ondragexit",
            "ondragleave",
            "ondragover",
            "ondragstart",
            "ondrop",
            "ondurationchange",
            "onemptied",
            "onencrypted",
            "onend",
            "onended",
            "onenter",
            "onenterpictureinpicture",
            "onerror",
            "onerrorupdate",
            "onexit",
            "onfilterchange",
            "onfinish",
            "onfocus",
            "onfocusin",
            "onfocusout",
            "onformdata",
            "onfreeze",
            "onfullscreenchange",
            "onfullscreenerror",
            "ongatheringstatechange",
            "ongattserverdisconnected",
            "ongesturechange",
            "ongestureend",
            "ongesturestart",
            "ongotpointercapture",
            "onhashchange",
            "onhelp",
            "onicecandidate",
            "onicecandidateerror",
            "oniceconnectionstatechange",
            "onicegatheringstatechange",
            "oninactive",
            "oninput",
            "oninputsourceschange",
            "oninvalid",
            "onkeydown",
            "onkeypress",
            "onkeystatuseschange",
            "onkeyup",
            "onlanguagechange",
            "onlayoutcomplete",
            "onleavepictureinpicture",
            "onlevelchange",
            "onload",
            "onloadeddata",
            "onloadedmetadata",
            "onloadend",
            "onloading",
            "onloadingdone",
            "onloadingerror",
            "onloadstart",
            "onlosecapture",
            "onlostpointercapture",
            "only",
            "onmark",
            "onmessage",
            "onmessageerror",
            "onmidimessage",
            "onmousedown",
            "onmouseenter",
            "onmouseleave",
            "onmousemove",
            "onmouseout",
            "onmouseover",
            "onmouseup",
            "onmousewheel",
            "onmove",
            "onmoveend",
            "onmovestart",
            "onmozfullscreenchange",
            "onmozfullscreenerror",
            "onmozorientationchange",
            "onmozpointerlockchange",
            "onmozpointerlockerror",
            "onmscontentzoom",
            "onmsfullscreenchange",
            "onmsfullscreenerror",
            "onmsgesturechange",
            "onmsgesturedoubletap",
            "onmsgestureend",
            "onmsgesturehold",
            "onmsgesturestart",
            "onmsgesturetap",
            "onmsgotpointercapture",
            "onmsinertiastart",
            "onmslostpointercapture",
            "onmsmanipulationstatechanged",
            "onmsneedkey",
            "onmsorientationchange",
            "onmspointercancel",
            "onmspointerdown",
            "onmspointerenter",
            "onmspointerhover",
            "onmspointerleave",
            "onmspointermove",
            "onmspointerout",
            "onmspointerover",
            "onmspointerup",
            "onmssitemodejumplistitemremoved",
            "onmsthumbnailclick",
            "onmute",
            "onnegotiationneeded",
            "onnomatch",
            "onnoupdate",
            "onobsolete",
            "onoffline",
            "ononline",
            "onopen",
            "onorientationchange",
            "onpagechange",
            "onpagehide",
            "onpageshow",
            "onpaste",
            "onpause",
            "onpayerdetailchange",
            "onpaymentmethodchange",
            "onplay",
            "onplaying",
            "onpluginstreamstart",
            "onpointercancel",
            "onpointerdown",
            "onpointerenter",
            "onpointerleave",
            "onpointerlockchange",
            "onpointerlockerror",
            "onpointermove",
            "onpointerout",
            "onpointerover",
            "onpointerrawupdate",
            "onpointerup",
            "onpopstate",
            "onprocessorerror",
            "onprogress",
            "onpropertychange",
            "onratechange",
            "onreading",
            "onreadystatechange",
            "onrejectionhandled",
            "onrelease",
            "onremove",
            "onremovesourcebuffer",
            "onremovestream",
            "onremovetrack",
            "onrepeat",
            "onreset",
            "onresize",
            "onresizeend",
            "onresizestart",
            "onresourcetimingbufferfull",
            "onresult",
            "onresume",
            "onrowenter",
            "onrowexit",
            "onrowsdelete",
            "onrowsinserted",
            "onscroll",
            "onsearch",
            "onsecuritypolicyviolation",
            "onseeked",
            "onseeking",
            "onselect",
            "onselectedcandidatepairchange",
            "onselectend",
            "onselectionchange",
            "onselectstart",
            "onshippingaddresschange",
            "onshippingoptionchange",
            "onshow",
            "onsignalingstatechange",
            "onsoundend",
            "onsoundstart",
            "onsourceclose",
            "onsourceclosed",
            "onsourceended",
            "onsourceopen",
            "onspeechend",
            "onspeechstart",
            "onsqueeze",
            "onsqueezeend",
            "onsqueezestart",
            "onstalled",
            "onstart",
            "onstatechange",
            "onstop",
            "onstorage",
            "onstoragecommit",
            "onsubmit",
            "onsuccess",
            "onsuspend",
            "onterminate",
            "ontextinput",
            "ontimeout",
            "ontimeupdate",
            "ontoggle",
            "ontonechange",
            "ontouchcancel",
            "ontouchend",
            "ontouchmove",
            "ontouchstart",
            "ontrack",
            "ontransitioncancel",
            "ontransitionend",
            "ontransitionrun",
            "ontransitionstart",
            "onuncapturederror",
            "onunhandledrejection",
            "onunload",
            "onunmute",
            "onupdate",
            "onupdateend",
            "onupdatefound",
            "onupdateready",
            "onupdatestart",
            "onupgradeneeded",
            "onuserproximity",
            "onversionchange",
            "onvisibilitychange",
            "onvoiceschanged",
            "onvolumechange",
            "onvrdisplayactivate",
            "onvrdisplayconnect",
            "onvrdisplaydeactivate",
            "onvrdisplaydisconnect",
            "onvrdisplaypresentchange",
            "onwaiting",
            "onwaitingforkey",
            "onwarning",
            "onwebkitanimationend",
            "onwebkitanimationiteration",
            "onwebkitanimationstart",
            "onwebkitcurrentplaybacktargetiswirelesschanged",
            "onwebkitfullscreenchange",
            "onwebkitfullscreenerror",
            "onwebkitkeyadded",
            "onwebkitkeyerror",
            "onwebkitkeymessage",
            "onwebkitneedkey",
            "onwebkitorientationchange",
            "onwebkitplaybacktargetavailabilitychanged",
            "onwebkitpointerlockchange",
            "onwebkitpointerlockerror",
            "onwebkitresourcetimingbufferfull",
            "onwebkittransitionend",
            "onwheel",
            "onzoom",
            "opacity",
            "open",
            "openCursor",
            "openDatabase",
            "openKeyCursor",
            "opened",
            "opener",
            "opera",
            "operation",
            "operationType",
            "operator",
            "opr",
            "optimum",
            "options",
            "or",
            "order",
            "orderX",
            "orderY",
            "ordered",
            "org",
            "organization",
            "orient",
            "orientAngle",
            "orientType",
            "orientation",
            "orientationX",
            "orientationY",
            "orientationZ",
            "origin",
            "originalPolicy",
            "originalTarget",
            "orphans",
            "oscpu",
            "outerHTML",
            "outerHeight",
            "outerText",
            "outerWidth",
            "outline",
            "outline-color",
            "outline-offset",
            "outline-style",
            "outline-width",
            "outlineColor",
            "outlineOffset",
            "outlineStyle",
            "outlineWidth",
            "outputBuffer",
            "outputChannelCount",
            "outputLatency",
            "outputs",
            "overflow",
            "overflow-anchor",
            "overflow-block",
            "overflow-inline",
            "overflow-wrap",
            "overflow-x",
            "overflow-y",
            "overflowAnchor",
            "overflowBlock",
            "overflowInline",
            "overflowWrap",
            "overflowX",
            "overflowY",
            "overrideMimeType",
            "oversample",
            "overscroll-behavior",
            "overscroll-behavior-block",
            "overscroll-behavior-inline",
            "overscroll-behavior-x",
            "overscroll-behavior-y",
            "overscrollBehavior",
            "overscrollBehaviorBlock",
            "overscrollBehaviorInline",
            "overscrollBehaviorX",
            "overscrollBehaviorY",
            "ownKeys",
            "ownerDocument",
            "ownerElement",
            "ownerNode",
            "ownerRule",
            "ownerSVGElement",
            "owningElement",
            "p1",
            "p2",
            "p3",
            "p4",
            "packetSize",
            "packets",
            "pad",
            "padEnd",
            "padStart",
            "padding",
            "padding-block",
            "padding-block-end",
            "padding-block-start",
            "padding-bottom",
            "padding-inline",
            "padding-inline-end",
            "padding-inline-start",
            "padding-left",
            "padding-right",
            "padding-top",
            "paddingBlock",
            "paddingBlockEnd",
            "paddingBlockStart",
            "paddingBottom",
            "paddingInline",
            "paddingInlineEnd",
            "paddingInlineStart",
            "paddingLeft",
            "paddingRight",
            "paddingTop",
            "page",
            "page-break-after",
            "page-break-before",
            "page-break-inside",
            "pageBreakAfter",
            "pageBreakBefore",
            "pageBreakInside",
            "pageCount",
            "pageLeft",
            "pageTop",
            "pageX",
            "pageXOffset",
            "pageY",
            "pageYOffset",
            "pages",
            "paint-order",
            "paintOrder",
            "paintRequests",
            "paintType",
            "paintWorklet",
            "palette",
            "pan",
            "panningModel",
            "parameterData",
            "parameters",
            "parent",
            "parentElement",
            "parentNode",
            "parentRule",
            "parentStyleSheet",
            "parentTextEdit",
            "parentWindow",
            "parse",
            "parseAll",
            "parseFloat",
            "parseFromString",
            "parseInt",
            "part",
            "participants",
            "passOp",
            "passive",
            "password",
            "pasteHTML",
            "path",
            "pathLength",
            "pathSegList",
            "pathSegType",
            "pathSegTypeAsLetter",
            "pathname",
            "pattern",
            "patternContentUnits",
            "patternMismatch",
            "patternTransform",
            "patternUnits",
            "pause",
            "pauseAnimations",
            "pauseOnExit",
            "pauseProfilers",
            "pauseTransformFeedback",
            "paused",
            "payerEmail",
            "payerName",
            "payerPhone",
            "paymentManager",
            "pc",
            "peerIdentity",
            "pending",
            "pendingLocalDescription",
            "pendingRemoteDescription",
            "percent",
            "performance",
            "periodicSync",
            "permission",
            "permissionState",
            "permissions",
            "persist",
            "persisted",
            "personalbar",
            "perspective",
            "perspective-origin",
            "perspectiveOrigin",
            "phone",
            "phoneticFamilyName",
            "phoneticGivenName",
            "photo",
            "pictureInPictureElement",
            "pictureInPictureEnabled",
            "pictureInPictureWindow",
            "ping",
            "pipeThrough",
            "pipeTo",
            "pitch",
            "pixelBottom",
            "pixelDepth",
            "pixelHeight",
            "pixelLeft",
            "pixelRight",
            "pixelStorei",
            "pixelTop",
            "pixelUnitToMillimeterX",
            "pixelUnitToMillimeterY",
            "pixelWidth",
            "place-content",
            "place-items",
            "place-self",
            "placeContent",
            "placeItems",
            "placeSelf",
            "placeholder",
            "platform",
            "platformVersion",
            "platforms",
            "play",
            "playEffect",
            "playState",
            "playbackRate",
            "playbackState",
            "playbackTime",
            "played",
            "playoutDelayHint",
            "playsInline",
            "plugins",
            "pluginspage",
            "pname",
            "pointer-events",
            "pointerBeforeReferenceNode",
            "pointerEnabled",
            "pointerEvents",
            "pointerId",
            "pointerLockElement",
            "pointerType",
            "points",
            "pointsAtX",
            "pointsAtY",
            "pointsAtZ",
            "polygonOffset",
            "pop",
            "popDebugGroup",
            "popErrorScope",
            "populateMatrix",
            "popupWindowFeatures",
            "popupWindowName",
            "popupWindowURI",
            "port",
            "port1",
            "port2",
            "ports",
            "posBottom",
            "posHeight",
            "posLeft",
            "posRight",
            "posTop",
            "posWidth",
            "pose",
            "position",
            "positionAlign",
            "positionX",
            "positionY",
            "positionZ",
            "postError",
            "postMessage",
            "postalCode",
            "poster",
            "pow",
            "powerEfficient",
            "powerOff",
            "powerPreference",
            "preMultiplySelf",
            "precision",
            "preferredStyleSheetSet",
            "preferredStylesheetSet",
            "prefix",
            "preload",
            "premultipliedAlpha",
            "prepend",
            "presentation",
            "preserveAlpha",
            "preserveAspectRatio",
            "preserveAspectRatioString",
            "pressed",
            "pressure",
            "prevValue",
            "preventDefault",
            "preventExtensions",
            "preventSilentAccess",
            "previousElementSibling",
            "previousNode",
            "previousPage",
            "previousRect",
            "previousScale",
            "previousSibling",
            "previousTranslate",
            "primaryKey",
            "primitive",
            "primitiveType",
            "primitiveUnits",
            "principals",
            "print",
            "priority",
            "privateKey",
            "probablySupportsContext",
            "process",
            "processIceMessage",
            "processingEnd",
            "processingStart",
            "processorOptions",
            "product",
            "productId",
            "productName",
            "productSub",
            "profile",
            "profileEnd",
            "profiles",
            "projectionMatrix",
            "promise",
            "prompt",
            "properties",
            "propertyIsEnumerable",
            "propertyName",
            "protocol",
            "protocolLong",
            "prototype",
            "provider",
            "pseudoClass",
            "pseudoElement",
            "pt",
            "publicId",
            "publicKey",
            "published",
            "pulse",
            "push",
            "pushDebugGroup",
            "pushErrorScope",
            "pushManager",
            "pushNotification",
            "pushState",
            "put",
            "putImageData",
            "px",
            "quadraticCurveTo",
            "qualifier",
            "quaternion",
            "query",
            "queryCommandEnabled",
            "queryCommandIndeterm",
            "queryCommandState",
            "queryCommandSupported",
            "queryCommandText",
            "queryCommandValue",
            "querySelector",
            "querySelectorAll",
            "querySet",
            "queue",
            "queueMicrotask",
            "quote",
            "quotes",
            "r",
            "r1",
            "r2",
            "race",
            "rad",
            "radiogroup",
            "radiusX",
            "radiusY",
            "random",
            "range",
            "rangeCount",
            "rangeMax",
            "rangeMin",
            "rangeOffset",
            "rangeOverflow",
            "rangeParent",
            "rangeUnderflow",
            "rate",
            "ratio",
            "raw",
            "rawId",
            "read",
            "readAsArrayBuffer",
            "readAsBinaryString",
            "readAsBlob",
            "readAsDataURL",
            "readAsText",
            "readBuffer",
            "readEntries",
            "readOnly",
            "readPixels",
            "readReportRequested",
            "readText",
            "readValue",
            "readable",
            "ready",
            "readyState",
            "reason",
            "reboot",
            "receivedAlert",
            "receiver",
            "receivers",
            "recipient",
            "reconnect",
            "recordNumber",
            "recordsAvailable",
            "recordset",
            "rect",
            "red",
            "redEyeReduction",
            "redirect",
            "redirectCount",
            "redirectEnd",
            "redirectStart",
            "redirected",
            "reduce",
            "reduceRight",
            "reduction",
            "refDistance",
            "refX",
            "refY",
            "referenceNode",
            "referenceSpace",
            "referrer",
            "referrerPolicy",
            "refresh",
            "region",
            "regionAnchorX",
            "regionAnchorY",
            "regionId",
            "regions",
            "register",
            "registerContentHandler",
            "registerElement",
            "registerProperty",
            "registerProtocolHandler",
            "reject",
            "rel",
            "relList",
            "relatedAddress",
            "relatedNode",
            "relatedPort",
            "relatedTarget",
            "release",
            "releaseCapture",
            "releaseEvents",
            "releaseInterface",
            "releaseLock",
            "releasePointerCapture",
            "releaseShaderCompiler",
            "reliable",
            "reliableWrite",
            "reload",
            "rem",
            "remainingSpace",
            "remote",
            "remoteDescription",
            "remove",
            "removeAllRanges",
            "removeAttribute",
            "removeAttributeNS",
            "removeAttributeNode",
            "removeBehavior",
            "removeChild",
            "removeCue",
            "removeEventListener",
            "removeFilter",
            "removeImport",
            "removeItem",
            "removeListener",
            "removeNamedItem",
            "removeNamedItemNS",
            "removeNode",
            "removeParameter",
            "removeProperty",
            "removeRange",
            "removeRegion",
            "removeRule",
            "removeSiteSpecificTrackingException",
            "removeSourceBuffer",
            "removeStream",
            "removeTrack",
            "removeVariable",
            "removeWakeLockListener",
            "removeWebWideTrackingException",
            "removed",
            "removedNodes",
            "renderHeight",
            "renderState",
            "renderTime",
            "renderWidth",
            "renderbufferStorage",
            "renderbufferStorageMultisample",
            "renderedBuffer",
            "renderingMode",
            "renotify",
            "repeat",
            "replace",
            "replaceAdjacentText",
            "replaceAll",
            "replaceChild",
            "replaceChildren",
            "replaceData",
            "replaceId",
            "replaceItem",
            "replaceNode",
            "replaceState",
            "replaceSync",
            "replaceTrack",
            "replaceWholeText",
            "replaceWith",
            "reportValidity",
            "request",
            "requestAdapter",
            "requestAdapterInfo",
            "requestAnimationFrame",
            "requestAutocomplete",
            "requestData",
            "requestDevice",
            "requestFrame",
            "requestFullscreen",
            "requestHitTestSource",
            "requestHitTestSourceForTransientInput",
            "requestId",
            "requestIdleCallback",
            "requestMIDIAccess",
            "requestMediaKeySystemAccess",
            "requestPermission",
            "requestPictureInPicture",
            "requestPointerLock",
            "requestPresent",
            "requestReferenceSpace",
            "requestSession",
            "requestStart",
            "requestStorageAccess",
            "requestSubmit",
            "requestVideoFrameCallback",
            "requestingWindow",
            "requireInteraction",
            "required",
            "requiredExtensions",
            "requiredFeatures",
            "requiredLimits",
            "reset",
            "resetPose",
            "resetTransform",
            "resize",
            "resizeBy",
            "resizeTo",
            "resolve",
            "resolveQuerySet",
            "resolveTarget",
            "resource",
            "response",
            "responseBody",
            "responseEnd",
            "responseReady",
            "responseStart",
            "responseText",
            "responseType",
            "responseURL",
            "responseXML",
            "restartIce",
            "restore",
            "result",
            "resultIndex",
            "resultType",
            "results",
            "resume",
            "resumeProfilers",
            "resumeTransformFeedback",
            "retry",
            "returnValue",
            "rev",
            "reverse",
            "reversed",
            "revocable",
            "revokeObjectURL",
            "rgbColor",
            "right",
            "rightContext",
            "rightDegrees",
            "rightMargin",
            "rightProjectionMatrix",
            "rightViewMatrix",
            "role",
            "rolloffFactor",
            "root",
            "rootBounds",
            "rootElement",
            "rootMargin",
            "rotate",
            "rotateAxisAngle",
            "rotateAxisAngleSelf",
            "rotateFromVector",
            "rotateFromVectorSelf",
            "rotateSelf",
            "rotation",
            "rotationAngle",
            "rotationRate",
            "round",
            "roundRect",
            "row-gap",
            "rowGap",
            "rowIndex",
            "rowSpan",
            "rows",
            "rowsPerImage",
            "rtcpTransport",
            "rtt",
            "ruby-align",
            "ruby-position",
            "rubyAlign",
            "rubyOverhang",
            "rubyPosition",
            "rules",
            "runtime",
            "runtimeStyle",
            "rx",
            "ry",
            "s",
            "safari",
            "sample",
            "sampleCount",
            "sampleCoverage",
            "sampleRate",
            "sampleType",
            "sampler",
            "samplerParameterf",
            "samplerParameteri",
            "sandbox",
            "save",
            "saveData",
            "scale",
            "scale3d",
            "scale3dSelf",
            "scaleNonUniform",
            "scaleNonUniformSelf",
            "scaleSelf",
            "scheme",
            "scissor",
            "scope",
            "scopeName",
            "scoped",
            "screen",
            "screenBrightness",
            "screenEnabled",
            "screenLeft",
            "screenPixelToMillimeterX",
            "screenPixelToMillimeterY",
            "screenTop",
            "screenX",
            "screenY",
            "scriptURL",
            "scripts",
            "scroll",
            "scroll-behavior",
            "scroll-margin",
            "scroll-margin-block",
            "scroll-margin-block-end",
            "scroll-margin-block-start",
            "scroll-margin-bottom",
            "scroll-margin-inline",
            "scroll-margin-inline-end",
            "scroll-margin-inline-start",
            "scroll-margin-left",
            "scroll-margin-right",
            "scroll-margin-top",
            "scroll-padding",
            "scroll-padding-block",
            "scroll-padding-block-end",
            "scroll-padding-block-start",
            "scroll-padding-bottom",
            "scroll-padding-inline",
            "scroll-padding-inline-end",
            "scroll-padding-inline-start",
            "scroll-padding-left",
            "scroll-padding-right",
            "scroll-padding-top",
            "scroll-snap-align",
            "scroll-snap-type",
            "scrollAmount",
            "scrollBehavior",
            "scrollBy",
            "scrollByLines",
            "scrollByPages",
            "scrollDelay",
            "scrollHeight",
            "scrollIntoView",
            "scrollIntoViewIfNeeded",
            "scrollLeft",
            "scrollLeftMax",
            "scrollMargin",
            "scrollMarginBlock",
            "scrollMarginBlockEnd",
            "scrollMarginBlockStart",
            "scrollMarginBottom",
            "scrollMarginInline",
            "scrollMarginInlineEnd",
            "scrollMarginInlineStart",
            "scrollMarginLeft",
            "scrollMarginRight",
            "scrollMarginTop",
            "scrollMaxX",
            "scrollMaxY",
            "scrollPadding",
            "scrollPaddingBlock",
            "scrollPaddingBlockEnd",
            "scrollPaddingBlockStart",
            "scrollPaddingBottom",
            "scrollPaddingInline",
            "scrollPaddingInlineEnd",
            "scrollPaddingInlineStart",
            "scrollPaddingLeft",
            "scrollPaddingRight",
            "scrollPaddingTop",
            "scrollRestoration",
            "scrollSnapAlign",
            "scrollSnapType",
            "scrollTo",
            "scrollTop",
            "scrollTopMax",
            "scrollWidth",
            "scrollX",
            "scrollY",
            "scrollbar-color",
            "scrollbar-width",
            "scrollbar3dLightColor",
            "scrollbarArrowColor",
            "scrollbarBaseColor",
            "scrollbarColor",
            "scrollbarDarkShadowColor",
            "scrollbarFaceColor",
            "scrollbarHighlightColor",
            "scrollbarShadowColor",
            "scrollbarTrackColor",
            "scrollbarWidth",
            "scrollbars",
            "scrolling",
            "scrollingElement",
            "sctp",
            "sctpCauseCode",
            "sdp",
            "sdpLineNumber",
            "sdpMLineIndex",
            "sdpMid",
            "seal",
            "search",
            "searchBox",
            "searchBoxJavaBridge_",
            "searchParams",
            "sectionRowIndex",
            "secureConnectionStart",
            "security",
            "seed",
            "seekToNextFrame",
            "seekable",
            "seeking",
            "select",
            "selectAllChildren",
            "selectAlternateInterface",
            "selectConfiguration",
            "selectNode",
            "selectNodeContents",
            "selectNodes",
            "selectSingleNode",
            "selectSubString",
            "selected",
            "selectedIndex",
            "selectedOptions",
            "selectedStyleSheetSet",
            "selectedStylesheetSet",
            "selection",
            "selectionDirection",
            "selectionEnd",
            "selectionStart",
            "selector",
            "selectorText",
            "self",
            "send",
            "sendAsBinary",
            "sendBeacon",
            "sender",
            "sentAlert",
            "sentTimestamp",
            "separator",
            "serialNumber",
            "serializeToString",
            "serverTiming",
            "service",
            "serviceWorker",
            "session",
            "sessionId",
            "sessionStorage",
            "set",
            "setActionHandler",
            "setActive",
            "setAlpha",
            "setAppBadge",
            "setAttribute",
            "setAttributeNS",
            "setAttributeNode",
            "setAttributeNodeNS",
            "setBaseAndExtent",
            "setBigInt64",
            "setBigUint64",
            "setBindGroup",
            "setBingCurrentSearchDefault",
            "setBlendConstant",
            "setCapture",
            "setCodecPreferences",
            "setColor",
            "setCompositeOperation",
            "setConfiguration",
            "setCurrentTime",
            "setCustomValidity",
            "setData",
            "setDate",
            "setDragImage",
            "setEnd",
            "setEndAfter",
            "setEndBefore",
            "setEndPoint",
            "setFillColor",
            "setFilterRes",
            "setFloat32",
            "setFloat64",
            "setFloatValue",
            "setFormValue",
            "setFullYear",
            "setHeaderValue",
            "setHours",
            "setIdentityProvider",
            "setImmediate",
            "setIndexBuffer",
            "setInt16",
            "setInt32",
            "setInt8",
            "setInterval",
            "setItem",
            "setKeyframes",
            "setLineCap",
            "setLineDash",
            "setLineJoin",
            "setLineWidth",
            "setLiveSeekableRange",
            "setLocalDescription",
            "setMatrix",
            "setMatrixValue",
            "setMediaKeys",
            "setMilliseconds",
            "setMinutes",
            "setMiterLimit",
            "setMonth",
            "setNamedItem",
            "setNamedItemNS",
            "setNonUserCodeExceptions",
            "setOrientToAngle",
            "setOrientToAuto",
            "setOrientation",
            "setOverrideHistoryNavigationMode",
            "setPaint",
            "setParameter",
            "setParameters",
            "setPeriodicWave",
            "setPipeline",
            "setPointerCapture",
            "setPosition",
            "setPositionState",
            "setPreference",
            "setProperty",
            "setPrototypeOf",
            "setRGBColor",
            "setRGBColorICCColor",
            "setRadius",
            "setRangeText",
            "setRemoteDescription",
            "setRequestHeader",
            "setResizable",
            "setResourceTimingBufferSize",
            "setRotate",
            "setScale",
            "setScissorRect",
            "setSeconds",
            "setSelectionRange",
            "setServerCertificate",
            "setShadow",
            "setSinkId",
            "setSkewX",
            "setSkewY",
            "setStart",
            "setStartAfter",
            "setStartBefore",
            "setStdDeviation",
            "setStencilReference",
            "setStreams",
            "setStringValue",
            "setStrokeColor",
            "setSuggestResult",
            "setTargetAtTime",
            "setTargetValueAtTime",
            "setTime",
            "setTimeout",
            "setTransform",
            "setTranslate",
            "setUTCDate",
            "setUTCFullYear",
            "setUTCHours",
            "setUTCMilliseconds",
            "setUTCMinutes",
            "setUTCMonth",
            "setUTCSeconds",
            "setUint16",
            "setUint32",
            "setUint8",
            "setUri",
            "setValidity",
            "setValueAtTime",
            "setValueCurveAtTime",
            "setVariable",
            "setVelocity",
            "setVersion",
            "setVertexBuffer",
            "setViewport",
            "setYear",
            "settingName",
            "settingValue",
            "sex",
            "shaderLocation",
            "shaderSource",
            "shadowBlur",
            "shadowColor",
            "shadowOffsetX",
            "shadowOffsetY",
            "shadowRoot",
            "shape",
            "shape-image-threshold",
            "shape-margin",
            "shape-outside",
            "shape-rendering",
            "shapeImageThreshold",
            "shapeMargin",
            "shapeOutside",
            "shapeRendering",
            "sheet",
            "shift",
            "shiftKey",
            "shiftLeft",
            "shippingAddress",
            "shippingOption",
            "shippingType",
            "show",
            "showHelp",
            "showModal",
            "showModalDialog",
            "showModelessDialog",
            "showNotification",
            "sidebar",
            "sign",
            "signal",
            "signalingState",
            "signature",
            "silent",
            "sin",
            "singleNodeValue",
            "sinh",
            "sinkId",
            "sittingToStandingTransform",
            "size",
            "sizeToContent",
            "sizeX",
            "sizeZ",
            "sizes",
            "skewX",
            "skewXSelf",
            "skewY",
            "skewYSelf",
            "slice",
            "slope",
            "slot",
            "small",
            "smil",
            "smooth",
            "smoothingTimeConstant",
            "snapToLines",
            "snapshotItem",
            "snapshotLength",
            "some",
            "sort",
            "sortingCode",
            "source",
            "sourceBuffer",
            "sourceBuffers",
            "sourceCapabilities",
            "sourceFile",
            "sourceIndex",
            "sourceMap",
            "sources",
            "spacing",
            "span",
            "speak",
            "speakAs",
            "speaking",
            "species",
            "specified",
            "specularConstant",
            "specularExponent",
            "speechSynthesis",
            "speed",
            "speedOfSound",
            "spellcheck",
            "splice",
            "split",
            "splitText",
            "spreadMethod",
            "sqrt",
            "src",
            "srcElement",
            "srcFactor",
            "srcFilter",
            "srcObject",
            "srcUrn",
            "srcdoc",
            "srclang",
            "srcset",
            "stack",
            "stackTraceLimit",
            "stacktrace",
            "stageParameters",
            "standalone",
            "standby",
            "start",
            "startContainer",
            "startIce",
            "startMessages",
            "startNotifications",
            "startOffset",
            "startProfiling",
            "startRendering",
            "startShark",
            "startTime",
            "startsWith",
            "state",
            "status",
            "statusCode",
            "statusMessage",
            "statusText",
            "statusbar",
            "stdDeviationX",
            "stdDeviationY",
            "stencilBack",
            "stencilClearValue",
            "stencilFront",
            "stencilFunc",
            "stencilFuncSeparate",
            "stencilLoadOp",
            "stencilMask",
            "stencilMaskSeparate",
            "stencilOp",
            "stencilOpSeparate",
            "stencilReadMask",
            "stencilReadOnly",
            "stencilStoreOp",
            "stencilWriteMask",
            "step",
            "stepDown",
            "stepMismatch",
            "stepMode",
            "stepUp",
            "sticky",
            "stitchTiles",
            "stop",
            "stop-color",
            "stop-opacity",
            "stopColor",
            "stopImmediatePropagation",
            "stopNotifications",
            "stopOpacity",
            "stopProfiling",
            "stopPropagation",
            "stopShark",
            "stopped",
            "storage",
            "storageArea",
            "storageName",
            "storageStatus",
            "storageTexture",
            "store",
            "storeOp",
            "storeSiteSpecificTrackingException",
            "storeWebWideTrackingException",
            "stpVersion",
            "stream",
            "streams",
            "stretch",
            "strike",
            "string",
            "stringValue",
            "stringify",
            "stripIndexFormat",
            "stroke",
            "stroke-dasharray",
            "stroke-dashoffset",
            "stroke-linecap",
            "stroke-linejoin",
            "stroke-miterlimit",
            "stroke-opacity",
            "stroke-width",
            "strokeDasharray",
            "strokeDashoffset",
            "strokeLinecap",
            "strokeLinejoin",
            "strokeMiterlimit",
            "strokeOpacity",
            "strokeRect",
            "strokeStyle",
            "strokeText",
            "strokeWidth",
            "style",
            "styleFloat",
            "styleMap",
            "styleMedia",
            "styleSheet",
            "styleSheetSets",
            "styleSheets",
            "sub",
            "subarray",
            "subject",
            "submit",
            "submitFrame",
            "submitter",
            "subscribe",
            "substr",
            "substring",
            "substringData",
            "subtle",
            "subtree",
            "suffix",
            "suffixes",
            "summary",
            "sup",
            "supported",
            "supportedContentEncodings",
            "supportedEntryTypes",
            "supports",
            "supportsSession",
            "surfaceScale",
            "surroundContents",
            "suspend",
            "suspendRedraw",
            "swapCache",
            "swapNode",
            "sweepFlag",
            "symbols",
            "sync",
            "sysexEnabled",
            "system",
            "systemCode",
            "systemId",
            "systemLanguage",
            "systemXDPI",
            "systemYDPI",
            "tBodies",
            "tFoot",
            "tHead",
            "tabIndex",
            "table",
            "table-layout",
            "tableLayout",
            "tableValues",
            "tag",
            "tagName",
            "tagUrn",
            "tags",
            "taintEnabled",
            "takePhoto",
            "takeRecords",
            "tan",
            "tangentialPressure",
            "tanh",
            "target",
            "targetElement",
            "targetRayMode",
            "targetRaySpace",
            "targetTouches",
            "targetX",
            "targetY",
            "targets",
            "tcpType",
            "tee",
            "tel",
            "terminate",
            "test",
            "texImage2D",
            "texImage3D",
            "texParameterf",
            "texParameteri",
            "texStorage2D",
            "texStorage3D",
            "texSubImage2D",
            "texSubImage3D",
            "text",
            "text-align",
            "text-align-last",
            "text-anchor",
            "text-combine-upright",
            "text-decoration",
            "text-decoration-color",
            "text-decoration-line",
            "text-decoration-skip-ink",
            "text-decoration-style",
            "text-decoration-thickness",
            "text-emphasis",
            "text-emphasis-color",
            "text-emphasis-position",
            "text-emphasis-style",
            "text-indent",
            "text-justify",
            "text-orientation",
            "text-overflow",
            "text-rendering",
            "text-shadow",
            "text-transform",
            "text-underline-offset",
            "text-underline-position",
            "textAlign",
            "textAlignLast",
            "textAnchor",
            "textAutospace",
            "textBaseline",
            "textCombineUpright",
            "textContent",
            "textDecoration",
            "textDecorationBlink",
            "textDecorationColor",
            "textDecorationLine",
            "textDecorationLineThrough",
            "textDecorationNone",
            "textDecorationOverline",
            "textDecorationSkipInk",
            "textDecorationStyle",
            "textDecorationThickness",
            "textDecorationUnderline",
            "textEmphasis",
            "textEmphasisColor",
            "textEmphasisPosition",
            "textEmphasisStyle",
            "textIndent",
            "textJustify",
            "textJustifyTrim",
            "textKashida",
            "textKashidaSpace",
            "textLength",
            "textOrientation",
            "textOverflow",
            "textRendering",
            "textShadow",
            "textTracks",
            "textTransform",
            "textUnderlineOffset",
            "textUnderlinePosition",
            "texture",
            "then",
            "threadId",
            "threshold",
            "thresholds",
            "tiltX",
            "tiltY",
            "time",
            "timeEnd",
            "timeLog",
            "timeOrigin",
            "timeRemaining",
            "timeStamp",
            "timecode",
            "timeline",
            "timelineTime",
            "timeout",
            "timestamp",
            "timestampOffset",
            "timestampWrites",
            "timing",
            "title",
            "to",
            "toArray",
            "toBlob",
            "toDataURL",
            "toDateString",
            "toElement",
            "toExponential",
            "toFixed",
            "toFloat32Array",
            "toFloat64Array",
            "toGMTString",
            "toISOString",
            "toJSON",
            "toLocaleDateString",
            "toLocaleFormat",
            "toLocaleLowerCase",
            "toLocaleString",
            "toLocaleTimeString",
            "toLocaleUpperCase",
            "toLowerCase",
            "toMatrix",
            "toMethod",
            "toPrecision",
            "toPrimitive",
            "toSdp",
            "toSource",
            "toStaticHTML",
            "toString",
            "toStringTag",
            "toSum",
            "toTimeString",
            "toUTCString",
            "toUpperCase",
            "toggle",
            "toggleAttribute",
            "toggleLongPressEnabled",
            "tone",
            "toneBuffer",
            "tooLong",
            "tooShort",
            "toolbar",
            "top",
            "topMargin",
            "topology",
            "total",
            "totalFrameDelay",
            "totalVideoFrames",
            "touch-action",
            "touchAction",
            "touched",
            "touches",
            "trace",
            "track",
            "trackVisibility",
            "transaction",
            "transactions",
            "transceiver",
            "transferControlToOffscreen",
            "transferFromImageBitmap",
            "transferImageBitmap",
            "transferIn",
            "transferOut",
            "transferSize",
            "transferToImageBitmap",
            "transform",
            "transform-box",
            "transform-origin",
            "transform-style",
            "transformBox",
            "transformFeedbackVaryings",
            "transformOrigin",
            "transformPoint",
            "transformString",
            "transformStyle",
            "transformToDocument",
            "transformToFragment",
            "transition",
            "transition-delay",
            "transition-duration",
            "transition-property",
            "transition-timing-function",
            "transitionDelay",
            "transitionDuration",
            "transitionProperty",
            "transitionTimingFunction",
            "translate",
            "translateSelf",
            "translationX",
            "translationY",
            "transport",
            "trim",
            "trimEnd",
            "trimLeft",
            "trimRight",
            "trimStart",
            "trueSpeed",
            "trunc",
            "truncate",
            "trustedTypes",
            "turn",
            "twist",
            "type",
            "typeDetail",
            "typeMismatch",
            "typeMustMatch",
            "types",
            "u2f",
            "ubound",
            "uint16",
            "uint32",
            "uint8",
            "uint8Clamped",
            "unclippedDepth",
            "unconfigure",
            "undefined",
            "unescape",
            "uneval",
            "unicode",
            "unicode-bidi",
            "unicodeBidi",
            "unicodeRange",
            "uniform1f",
            "uniform1fv",
            "uniform1i",
            "uniform1iv",
            "uniform1ui",
            "uniform1uiv",
            "uniform2f",
            "uniform2fv",
            "uniform2i",
            "uniform2iv",
            "uniform2ui",
            "uniform2uiv",
            "uniform3f",
            "uniform3fv",
            "uniform3i",
            "uniform3iv",
            "uniform3ui",
            "uniform3uiv",
            "uniform4f",
            "uniform4fv",
            "uniform4i",
            "uniform4iv",
            "uniform4ui",
            "uniform4uiv",
            "uniformBlockBinding",
            "uniformMatrix2fv",
            "uniformMatrix2x3fv",
            "uniformMatrix2x4fv",
            "uniformMatrix3fv",
            "uniformMatrix3x2fv",
            "uniformMatrix3x4fv",
            "uniformMatrix4fv",
            "uniformMatrix4x2fv",
            "uniformMatrix4x3fv",
            "unique",
            "uniqueID",
            "uniqueNumber",
            "unit",
            "unitType",
            "units",
            "unloadEventEnd",
            "unloadEventStart",
            "unlock",
            "unmap",
            "unmount",
            "unobserve",
            "unpause",
            "unpauseAnimations",
            "unreadCount",
            "unregister",
            "unregisterContentHandler",
            "unregisterProtocolHandler",
            "unscopables",
            "unselectable",
            "unshift",
            "unsubscribe",
            "unsuspendRedraw",
            "unsuspendRedrawAll",
            "unwatch",
            "unwrapKey",
            "upDegrees",
            "upX",
            "upY",
            "upZ",
            "update",
            "updateCommands",
            "updateIce",
            "updateInterval",
            "updatePlaybackRate",
            "updateRenderState",
            "updateSettings",
            "updateTiming",
            "updateViaCache",
            "updateWith",
            "updated",
            "updating",
            "upgrade",
            "upload",
            "uploadTotal",
            "uploaded",
            "upper",
            "upperBound",
            "upperOpen",
            "uri",
            "url",
            "urn",
            "urns",
            "usage",
            "usages",
            "usb",
            "usbVersionMajor",
            "usbVersionMinor",
            "usbVersionSubminor",
            "useCurrentView",
            "useMap",
            "useProgram",
            "usedSpace",
            "user-select",
            "userActivation",
            "userAgent",
            "userAgentData",
            "userChoice",
            "userHandle",
            "userHint",
            "userLanguage",
            "userSelect",
            "userVisibleOnly",
            "username",
            "usernameFragment",
            "utterance",
            "uuid",
            "v8BreakIterator",
            "vAlign",
            "vLink",
            "valid",
            "validate",
            "validateProgram",
            "validationMessage",
            "validity",
            "value",
            "valueAsDate",
            "valueAsNumber",
            "valueAsString",
            "valueInSpecifiedUnits",
            "valueMissing",
            "valueOf",
            "valueText",
            "valueType",
            "values",
            "variable",
            "variant",
            "variationSettings",
            "vector-effect",
            "vectorEffect",
            "velocityAngular",
            "velocityExpansion",
            "velocityX",
            "velocityY",
            "vendor",
            "vendorId",
            "vendorSub",
            "verify",
            "version",
            "vertex",
            "vertexAttrib1f",
            "vertexAttrib1fv",
            "vertexAttrib2f",
            "vertexAttrib2fv",
            "vertexAttrib3f",
            "vertexAttrib3fv",
            "vertexAttrib4f",
            "vertexAttrib4fv",
            "vertexAttribDivisor",
            "vertexAttribDivisorANGLE",
            "vertexAttribI4i",
            "vertexAttribI4iv",
            "vertexAttribI4ui",
            "vertexAttribI4uiv",
            "vertexAttribIPointer",
            "vertexAttribPointer",
            "vertical",
            "vertical-align",
            "verticalAlign",
            "verticalOverflow",
            "vh",
            "vibrate",
            "vibrationActuator",
            "videoBitsPerSecond",
            "videoHeight",
            "videoTracks",
            "videoWidth",
            "view",
            "viewBox",
            "viewBoxString",
            "viewDimension",
            "viewFormats",
            "viewTarget",
            "viewTargetString",
            "viewport",
            "viewportAnchorX",
            "viewportAnchorY",
            "viewportElement",
            "views",
            "violatedDirective",
            "visibility",
            "visibilityState",
            "visible",
            "visualViewport",
            "vlinkColor",
            "vmax",
            "vmin",
            "voice",
            "voiceURI",
            "volume",
            "vrml",
            "vspace",
            "vw",
            "w",
            "wait",
            "waitSync",
            "waiting",
            "wake",
            "wakeLock",
            "wand",
            "warn",
            "wasClean",
            "wasDiscarded",
            "watch",
            "watchAvailability",
            "watchPosition",
            "webdriver",
            "webkitAddKey",
            "webkitAlignContent",
            "webkitAlignItems",
            "webkitAlignSelf",
            "webkitAnimation",
            "webkitAnimationDelay",
            "webkitAnimationDirection",
            "webkitAnimationDuration",
            "webkitAnimationFillMode",
            "webkitAnimationIterationCount",
            "webkitAnimationName",
            "webkitAnimationPlayState",
            "webkitAnimationTimingFunction",
            "webkitAppearance",
            "webkitAudioContext",
            "webkitAudioDecodedByteCount",
            "webkitAudioPannerNode",
            "webkitBackfaceVisibility",
            "webkitBackground",
            "webkitBackgroundAttachment",
            "webkitBackgroundClip",
            "webkitBackgroundColor",
            "webkitBackgroundImage",
            "webkitBackgroundOrigin",
            "webkitBackgroundPosition",
            "webkitBackgroundPositionX",
            "webkitBackgroundPositionY",
            "webkitBackgroundRepeat",
            "webkitBackgroundSize",
            "webkitBackingStorePixelRatio",
            "webkitBorderBottomLeftRadius",
            "webkitBorderBottomRightRadius",
            "webkitBorderImage",
            "webkitBorderImageOutset",
            "webkitBorderImageRepeat",
            "webkitBorderImageSlice",
            "webkitBorderImageSource",
            "webkitBorderImageWidth",
            "webkitBorderRadius",
            "webkitBorderTopLeftRadius",
            "webkitBorderTopRightRadius",
            "webkitBoxAlign",
            "webkitBoxDirection",
            "webkitBoxFlex",
            "webkitBoxOrdinalGroup",
            "webkitBoxOrient",
            "webkitBoxPack",
            "webkitBoxShadow",
            "webkitBoxSizing",
            "webkitCancelAnimationFrame",
            "webkitCancelFullScreen",
            "webkitCancelKeyRequest",
            "webkitCancelRequestAnimationFrame",
            "webkitClearResourceTimings",
            "webkitClosedCaptionsVisible",
            "webkitConvertPointFromNodeToPage",
            "webkitConvertPointFromPageToNode",
            "webkitCreateShadowRoot",
            "webkitCurrentFullScreenElement",
            "webkitCurrentPlaybackTargetIsWireless",
            "webkitDecodedFrameCount",
            "webkitDirectionInvertedFromDevice",
            "webkitDisplayingFullscreen",
            "webkitDroppedFrameCount",
            "webkitEnterFullScreen",
            "webkitEnterFullscreen",
            "webkitEntries",
            "webkitExitFullScreen",
            "webkitExitFullscreen",
            "webkitExitPointerLock",
            "webkitFilter",
            "webkitFlex",
            "webkitFlexBasis",
            "webkitFlexDirection",
            "webkitFlexFlow",
            "webkitFlexGrow",
            "webkitFlexShrink",
            "webkitFlexWrap",
            "webkitFullScreenKeyboardInputAllowed",
            "webkitFullscreenElement",
            "webkitFullscreenEnabled",
            "webkitGenerateKeyRequest",
            "webkitGetAsEntry",
            "webkitGetDatabaseNames",
            "webkitGetEntries",
            "webkitGetEntriesByName",
            "webkitGetEntriesByType",
            "webkitGetFlowByName",
            "webkitGetGamepads",
            "webkitGetImageDataHD",
            "webkitGetNamedFlows",
            "webkitGetRegionFlowRanges",
            "webkitGetUserMedia",
            "webkitHasClosedCaptions",
            "webkitHidden",
            "webkitIDBCursor",
            "webkitIDBDatabase",
            "webkitIDBDatabaseError",
            "webkitIDBDatabaseException",
            "webkitIDBFactory",
            "webkitIDBIndex",
            "webkitIDBKeyRange",
            "webkitIDBObjectStore",
            "webkitIDBRequest",
            "webkitIDBTransaction",
            "webkitImageSmoothingEnabled",
            "webkitIndexedDB",
            "webkitInitMessageEvent",
            "webkitIsFullScreen",
            "webkitJustifyContent",
            "webkitKeys",
            "webkitLineClamp",
            "webkitLineDashOffset",
            "webkitLockOrientation",
            "webkitMask",
            "webkitMaskClip",
            "webkitMaskComposite",
            "webkitMaskImage",
            "webkitMaskOrigin",
            "webkitMaskPosition",
            "webkitMaskPositionX",
            "webkitMaskPositionY",
            "webkitMaskRepeat",
            "webkitMaskSize",
            "webkitMatchesSelector",
            "webkitMediaStream",
            "webkitNotifications",
            "webkitOfflineAudioContext",
            "webkitOrder",
            "webkitOrientation",
            "webkitPeerConnection00",
            "webkitPersistentStorage",
            "webkitPerspective",
            "webkitPerspectiveOrigin",
            "webkitPointerLockElement",
            "webkitPostMessage",
            "webkitPreservesPitch",
            "webkitPutImageDataHD",
            "webkitRTCPeerConnection",
            "webkitRegionOverset",
            "webkitRelativePath",
            "webkitRequestAnimationFrame",
            "webkitRequestFileSystem",
            "webkitRequestFullScreen",
            "webkitRequestFullscreen",
            "webkitRequestPointerLock",
            "webkitResolveLocalFileSystemURL",
            "webkitSetMediaKeys",
            "webkitSetResourceTimingBufferSize",
            "webkitShadowRoot",
            "webkitShowPlaybackTargetPicker",
            "webkitSlice",
            "webkitSpeechGrammar",
            "webkitSpeechGrammarList",
            "webkitSpeechRecognition",
            "webkitSpeechRecognitionError",
            "webkitSpeechRecognitionEvent",
            "webkitStorageInfo",
            "webkitSupportsFullscreen",
            "webkitTemporaryStorage",
            "webkitTextFillColor",
            "webkitTextSizeAdjust",
            "webkitTextStroke",
            "webkitTextStrokeColor",
            "webkitTextStrokeWidth",
            "webkitTransform",
            "webkitTransformOrigin",
            "webkitTransformStyle",
            "webkitTransition",
            "webkitTransitionDelay",
            "webkitTransitionDuration",
            "webkitTransitionProperty",
            "webkitTransitionTimingFunction",
            "webkitURL",
            "webkitUnlockOrientation",
            "webkitUserSelect",
            "webkitVideoDecodedByteCount",
            "webkitVisibilityState",
            "webkitWirelessVideoPlaybackDisabled",
            "webkitdirectory",
            "webkitdropzone",
            "webstore",
            "weight",
            "wgslLanguageFeatures",
            "whatToShow",
            "wheelDelta",
            "wheelDeltaX",
            "wheelDeltaY",
            "whenDefined",
            "which",
            "white-space",
            "whiteSpace",
            "wholeText",
            "widows",
            "width",
            "will-change",
            "willChange",
            "willValidate",
            "window",
            "withCredentials",
            "word-break",
            "word-spacing",
            "word-wrap",
            "wordBreak",
            "wordSpacing",
            "wordWrap",
            "workerStart",
            "wow64",
            "wrap",
            "wrapKey",
            "writable",
            "writableAuxiliaries",
            "write",
            "writeBuffer",
            "writeMask",
            "writeText",
            "writeTexture",
            "writeTimestamp",
            "writeValue",
            "writeWithoutResponse",
            "writeln",
            "writing-mode",
            "writingMode",
            "x",
            "x1",
            "x2",
            "xChannelSelector",
            "xmlEncoding",
            "xmlStandalone",
            "xmlVersion",
            "xmlbase",
            "xmllang",
            "xmlspace",
            "xor",
            "xr",
            "y",
            "y1",
            "y2",
            "yChannelSelector",
            "yandex",
            "z",
            "z-index",
            "zIndex",
            "zoom",
            "zoomAndPan",
            "zoomRectScreen",
        ];
        /***********************************************************************
        
          A JavaScript tokenizer / parser / beautifier / compressor.
          https://github.com/mishoo/UglifyJS2
        
          -------------------------------- (C) ---------------------------------
        
                                   Author: Mihai Bazon
                                 <mihai.bazon@gmail.com>
                               http://mihai.bazon.net/blog
        
          Distributed under the BSD license:
        
            Copyright 2012 (c) Mihai Bazon <mihai.bazon@gmail.com>
        
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions
            are met:
        
                * Redistributions of source code must retain the above
                  copyright notice, this list of conditions and the following
                  disclaimer.
        
                * Redistributions in binary form must reproduce the above
                  copyright notice, this list of conditions and the following
                  disclaimer in the documentation and/or other materials
                  provided with the distribution.
        
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
            EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
            PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
            LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
            OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
            PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
            PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
            THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
            TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
            THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
            SUCH DAMAGE.
        
         ***********************************************************************/
        function find_builtins(reserved) {
            domprops.forEach(add);
            // Compatibility fix for some standard defined globals not defined on every js environment
            var new_globals = ["Symbol", "Map", "Promise", "Proxy", "Reflect", "Set", "WeakMap", "WeakSet"];
            var objects = {};
            var global_ref = typeof global === "object" ? global : self;
            new_globals.forEach(function (new_global) {
                objects[new_global] = global_ref[new_global] || function () { };
            });
            [
                "null",
                "true",
                "false",
                "NaN",
                "Infinity",
                "-Infinity",
                "undefined",
            ].forEach(add);
            [Object, Array, Function, Number,
                String, Boolean, Error, Math,
                Date, RegExp, objects.Symbol, ArrayBuffer,
                DataView, decodeURI, decodeURIComponent,
                encodeURI, encodeURIComponent, eval, EvalError,
                Float32Array, Float64Array, Int8Array, Int16Array,
                Int32Array, isFinite, isNaN, JSON, objects.Map, parseFloat,
                parseInt, objects.Promise, objects.Proxy, RangeError, ReferenceError,
                objects.Reflect, objects.Set, SyntaxError, TypeError, Uint8Array,
                Uint8ClampedArray, Uint16Array, Uint32Array, URIError,
                objects.WeakMap, objects.WeakSet
            ].forEach(function (ctor) {
                Object.getOwnPropertyNames(ctor).map(add);
                if (ctor.prototype) {
                    Object.getOwnPropertyNames(ctor.prototype).map(add);
                }
            });
            function add(name) {
                reserved.add(name);
            }
        }
        function reserve_quoted_keys(ast, reserved) {
            function add(name) {
                push_uniq(reserved, name);
            }
            ast.walk(new TreeWalker(function (node) {
                if (node instanceof AST_ObjectKeyVal && node.quote) {
                    add(node.key);
                }
                else if (node instanceof AST_ObjectProperty && node.quote) {
                    add(node.key.name);
                }
                else if (node instanceof AST_Sub) {
                    addStrings(node.property, add);
                }
            }));
        }
        function addStrings(node, add) {
            node.walk(new TreeWalker(function (node) {
                if (node instanceof AST_Sequence) {
                    addStrings(node.tail_node(), add);
                }
                else if (node instanceof AST_String) {
                    add(node.value);
                }
                else if (node instanceof AST_Conditional) {
                    addStrings(node.consequent, add);
                    addStrings(node.alternative, add);
                }
                return true;
            }));
        }
        function mangle_private_properties(ast, options) {
            var cprivate = -1;
            var private_cache = new Map();
            var nth_identifier = options.nth_identifier || base54;
            ast = ast.transform(new TreeTransformer(function (node) {
                if (node instanceof AST_ClassPrivateProperty
                    || node instanceof AST_PrivateMethod
                    || node instanceof AST_PrivateGetter
                    || node instanceof AST_PrivateSetter
                    || node instanceof AST_PrivateIn) {
                    node.key.name = mangle_private(node.key.name);
                }
                else if (node instanceof AST_DotHash) {
                    node.property = mangle_private(node.property);
                }
            }));
            return ast;
            function mangle_private(name) {
                let mangled = private_cache.get(name);
                if (!mangled) {
                    mangled = nth_identifier.get(++cprivate);
                    private_cache.set(name, mangled);
                }
                return mangled;
            }
        }
        function find_annotated_props(ast) {
            var annotated_props = new Set();
            walk(ast, node => {
                if (node instanceof AST_ClassPrivateProperty
                    || node instanceof AST_PrivateMethod
                    || node instanceof AST_PrivateGetter
                    || node instanceof AST_PrivateSetter
                    || node instanceof AST_DotHash)
                    ;
                else if (node instanceof AST_ObjectKeyVal) {
                    if (typeof node.key == "string" && has_annotation(node, _MANGLEPROP)) {
                        annotated_props.add(node.key);
                    }
                }
                else if (node instanceof AST_ObjectProperty) {
                    // setter or getter, since KeyVal is handled above
                    if (has_annotation(node, _MANGLEPROP)) {
                        annotated_props.add(node.key.name);
                    }
                }
                else if (node instanceof AST_Dot) {
                    if (has_annotation(node, _MANGLEPROP)) {
                        annotated_props.add(node.property);
                    }
                }
                else if (node instanceof AST_Sub) {
                    if (node.property instanceof AST_String && has_annotation(node, _MANGLEPROP)) {
                        annotated_props.add(node.property.value);
                    }
                }
            });
            return annotated_props;
        }
        function mangle_properties(ast, options, annotated_props = find_annotated_props(ast)) {
            options = defaults(options, {
                builtins: false,
                cache: null,
                debug: false,
                keep_quoted: false,
                nth_identifier: base54,
                only_cache: false,
                regex: null,
                reserved: null,
                undeclared: false,
                only_annotated: false,
            }, true);
            var nth_identifier = options.nth_identifier;
            var reserved_option = options.reserved;
            if (!Array.isArray(reserved_option))
                reserved_option = [reserved_option];
            var reserved = new Set(reserved_option);
            if (!options.builtins)
                find_builtins(reserved);
            var cname = -1;
            var cache;
            if (options.cache) {
                cache = options.cache.props;
            }
            else {
                cache = new Map();
            }
            var only_annotated = options.only_annotated;
            var regex = options.regex && new RegExp(options.regex);
            // note debug is either false (disabled), or a string of the debug suffix to use (enabled).
            // note debug may be enabled as an empty string, which is falsey. Also treat passing 'true'
            // the same as passing an empty string.
            var debug = options.debug !== false;
            var debug_name_suffix;
            if (debug) {
                debug_name_suffix = (options.debug === true ? "" : options.debug);
            }
            var names_to_mangle = new Set();
            var unmangleable = new Set();
            // Track each already-mangled name to prevent nth_identifier from generating
            // the same name.
            cache.forEach((mangled_name) => unmangleable.add(mangled_name));
            var keep_quoted = !!options.keep_quoted;
            // step 1: find candidates to mangle
            ast.walk(new TreeWalker(function (node) {
                if (node instanceof AST_ClassPrivateProperty
                    || node instanceof AST_PrivateMethod
                    || node instanceof AST_PrivateGetter
                    || node instanceof AST_PrivateSetter
                    || node instanceof AST_DotHash)
                    ;
                else if (node instanceof AST_ObjectKeyVal) {
                    if (typeof node.key == "string" && (!keep_quoted || !node.quote)) {
                        add(node.key);
                    }
                }
                else if (node instanceof AST_ObjectProperty) {
                    // setter or getter, since KeyVal is handled above
                    if (!keep_quoted || !node.quote) {
                        add(node.key.name);
                    }
                }
                else if (node instanceof AST_Dot) {
                    var declared = !!options.undeclared;
                    if (!declared) {
                        var root = node;
                        while (root.expression) {
                            root = root.expression;
                        }
                        declared = !(root.thedef && root.thedef.undeclared);
                    }
                    if (declared &&
                        (!keep_quoted || !node.quote)) {
                        add(node.property);
                    }
                }
                else if (node instanceof AST_Sub) {
                    if (!keep_quoted) {
                        addStrings(node.property, add);
                    }
                }
                else if (node instanceof AST_Call
                    && node.expression.print_to_string() == "Object.defineProperty") {
                    addStrings(node.args[1], add);
                }
                else if (node instanceof AST_Binary && node.operator === "in") {
                    addStrings(node.left, add);
                }
                else if (node instanceof AST_String && has_annotation(node, _KEY)) {
                    add(node.value);
                }
            }));
            // step 2: transform the tree, renaming properties
            return ast.transform(new TreeTransformer(function (node) {
                if (node instanceof AST_ClassPrivateProperty
                    || node instanceof AST_PrivateMethod
                    || node instanceof AST_PrivateGetter
                    || node instanceof AST_PrivateSetter
                    || node instanceof AST_DotHash)
                    ;
                else if (node instanceof AST_ObjectKeyVal) {
                    if (typeof node.key == "string" && (!keep_quoted || !node.quote)) {
                        node.key = mangle(node.key);
                    }
                }
                else if (node instanceof AST_ObjectProperty) {
                    // setter, getter, method or class field
                    if (!keep_quoted || !node.quote) {
                        node.key.name = mangle(node.key.name);
                    }
                }
                else if (node instanceof AST_Dot) {
                    if (!keep_quoted || !node.quote) {
                        node.property = mangle(node.property);
                    }
                }
                else if (!keep_quoted && node instanceof AST_Sub) {
                    node.property = mangleStrings(node.property);
                }
                else if (node instanceof AST_Call
                    && node.expression.print_to_string() == "Object.defineProperty") {
                    node.args[1] = mangleStrings(node.args[1]);
                }
                else if (node instanceof AST_Binary && node.operator === "in") {
                    node.left = mangleStrings(node.left);
                }
                else if (node instanceof AST_String && has_annotation(node, _KEY)) {
                    // Clear _KEY annotation to prevent double mangling
                    clear_annotation(node, _KEY);
                    node.value = mangle(node.value);
                }
            }));
            // only function declarations after this line
            function can_mangle(name) {
                if (unmangleable.has(name))
                    return false;
                if (reserved.has(name))
                    return false;
                if (options.only_cache) {
                    return cache.has(name);
                }
                if (/^-?[0-9]+(\.[0-9]+)?(e[+-][0-9]+)?$/.test(name))
                    return false;
                return true;
            }
            function should_mangle(name) {
                if (only_annotated && !annotated_props.has(name))
                    return false;
                if (regex && !regex.test(name)) {
                    return annotated_props.has(name);
                }
                if (reserved.has(name))
                    return false;
                return cache.has(name)
                    || names_to_mangle.has(name);
            }
            function add(name) {
                if (can_mangle(name)) {
                    names_to_mangle.add(name);
                }
                if (!should_mangle(name)) {
                    unmangleable.add(name);
                }
            }
            function mangle(name) {
                if (!should_mangle(name)) {
                    return name;
                }
                var mangled = cache.get(name);
                if (!mangled) {
                    if (debug) {
                        // debug mode: use a prefix and suffix to preserve readability, e.g. o.foo -> o._$foo$NNN_.
                        var debug_mangled = "_$" + name + "$" + debug_name_suffix + "_";
                        if (can_mangle(debug_mangled)) {
                            mangled = debug_mangled;
                        }
                    }
                    // either debug mode is off, or it is on and we could not use the mangled name
                    if (!mangled) {
                        do {
                            mangled = nth_identifier.get(++cname);
                        } while (!can_mangle(mangled));
                    }
                    cache.set(name, mangled);
                }
                return mangled;
            }
            function mangleStrings(node) {
                return node.transform(new TreeTransformer(function (node) {
                    if (node instanceof AST_Sequence) {
                        var last = node.expressions.length - 1;
                        node.expressions[last] = mangleStrings(node.expressions[last]);
                    }
                    else if (node instanceof AST_String) {
                        // Clear _KEY annotation to prevent double mangling
                        clear_annotation(node, _KEY);
                        node.value = mangle(node.value);
                    }
                    else if (node instanceof AST_Conditional) {
                        node.consequent = mangleStrings(node.consequent);
                        node.alternative = mangleStrings(node.alternative);
                    }
                    return node;
                }));
            }
        }
        // to/from base64 functions
        // Prefer built-in Buffer, if available, then use hack
        // https://developer.mozilla.org/en-US/docs/Glossary/Base64#The_Unicode_Problem
        var to_ascii = typeof Buffer !== "undefined"
            ? (b64) => Buffer.from(b64, "base64").toString()
            : (b64) => decodeURIComponent(escape(atob(b64)));
        var to_base64 = typeof Buffer !== "undefined"
            ? (str) => Buffer.from(str).toString("base64")
            : (str) => btoa(unescape(encodeURIComponent(str)));
        function read_source_map(code) {
            var match = /(?:^|[^.])\/\/# sourceMappingURL=data:application\/json(;[\w=-]*)?;base64,([+/0-9A-Za-z]*=*)\s*$/.exec(code);
            if (!match) {
                console.warn("inline source map not found");
                return null;
            }
            return to_ascii(match[2]);
        }
        function set_shorthand(name, options, keys) {
            if (options[name]) {
                keys.forEach(function (key) {
                    if (options[key]) {
                        if (typeof options[key] != "object")
                            options[key] = {};
                        if (!(name in options[key]))
                            options[key][name] = options[name];
                    }
                });
            }
        }
        function init_cache(cache) {
            if (!cache)
                return;
            if (!("props" in cache)) {
                cache.props = new Map();
            }
            else if (!(cache.props instanceof Map)) {
                cache.props = map_from_object(cache.props);
            }
        }
        function cache_to_json(cache) {
            return {
                props: map_to_object(cache.props)
            };
        }
        function log_input(files, options, fs, debug_folder) {
            if (!(fs && fs.writeFileSync && fs.mkdirSync)) {
                return;
            }
            try {
                fs.mkdirSync(debug_folder);
            }
            catch (e) {
                if (e.code !== "EEXIST")
                    throw e;
            }
            const log_path = `${debug_folder}/terser-debug-${(Math.random() * 9999999) | 0}.log`;
            options = options || {};
            const options_str = JSON.stringify(options, (_key, thing) => {
                if (typeof thing === "function")
                    return "[Function " + thing.toString() + "]";
                if (thing instanceof RegExp)
                    return "[RegExp " + thing.toString() + "]";
                return thing;
            }, 4);
            const files_str = (file) => {
                if (typeof file === "object" && options.parse && options.parse.spidermonkey) {
                    return JSON.stringify(file, null, 2);
                }
                else if (typeof file === "object") {
                    return Object.keys(file)
                        .map((key) => key + ": " + files_str(file[key]))
                        .join("\n\n");
                }
                else if (typeof file === "string") {
                    return "```\n" + file + "\n```";
                }
                else {
                    return file; // What do?
                }
            };
            fs.writeFileSync(log_path, "Options: \n" + options_str + "\n\nInput files:\n\n" + files_str(files) + "\n");
        }
        function* minify_sync_or_async(files, options, _fs_module) {
            if (_fs_module
                && typeof process === "object"
                && process.env
                && typeof process.env.TERSER_DEBUG_DIR === "string") {
                log_input(files, options, _fs_module, process.env.TERSER_DEBUG_DIR);
            }
            options = defaults(options, {
                compress: {},
                ecma: undefined,
                enclose: false,
                ie8: false,
                keep_classnames: undefined,
                keep_fnames: false,
                mangle: {},
                module: false,
                nameCache: null,
                output: null,
                format: null,
                parse: {},
                rename: undefined,
                safari10: false,
                sourceMap: false,
                spidermonkey: false,
                timings: false,
                toplevel: false,
                warnings: false,
                wrap: false,
            }, true);
            var timings = options.timings && {
                start: Date.now()
            };
            if (options.keep_classnames === undefined) {
                options.keep_classnames = options.keep_fnames;
            }
            if (options.rename === undefined) {
                options.rename = options.compress && options.mangle;
            }
            if (options.output && options.format) {
                throw new Error("Please only specify either output or format option, preferrably format.");
            }
            options.format = options.format || options.output || {};
            set_shorthand("ecma", options, ["parse", "compress", "format"]);
            set_shorthand("ie8", options, ["compress", "mangle", "format"]);
            set_shorthand("keep_classnames", options, ["compress", "mangle"]);
            set_shorthand("keep_fnames", options, ["compress", "mangle"]);
            set_shorthand("module", options, ["parse", "compress", "mangle"]);
            set_shorthand("safari10", options, ["mangle", "format"]);
            set_shorthand("toplevel", options, ["compress", "mangle"]);
            set_shorthand("warnings", options, ["compress"]); // legacy
            var quoted_props;
            if (options.mangle) {
                options.mangle = defaults(options.mangle, {
                    cache: options.nameCache && (options.nameCache.vars || {}),
                    eval: false,
                    ie8: false,
                    keep_classnames: false,
                    keep_fnames: false,
                    module: false,
                    nth_identifier: base54,
                    properties: false,
                    reserved: [],
                    safari10: false,
                    toplevel: false,
                }, true);
                if (options.mangle.properties) {
                    if (typeof options.mangle.properties != "object") {
                        options.mangle.properties = {};
                    }
                    if (options.mangle.properties.keep_quoted) {
                        quoted_props = options.mangle.properties.reserved;
                        if (!Array.isArray(quoted_props))
                            quoted_props = [];
                        options.mangle.properties.reserved = quoted_props;
                    }
                    if (options.nameCache && !("cache" in options.mangle.properties)) {
                        options.mangle.properties.cache = options.nameCache.props || {};
                    }
                }
                init_cache(options.mangle.cache);
                init_cache(options.mangle.properties.cache);
            }
            if (options.sourceMap) {
                options.sourceMap = defaults(options.sourceMap, {
                    asObject: false,
                    content: null,
                    filename: null,
                    includeSources: false,
                    root: null,
                    url: null,
                }, true);
            }
            // -- Parse phase --
            if (timings)
                timings.parse = Date.now();
            var toplevel;
            if (files instanceof AST_Toplevel) {
                toplevel = files;
            }
            else {
                if (typeof files == "string" || (options.parse.spidermonkey && !Array.isArray(files))) {
                    files = [files];
                }
                options.parse = options.parse || {};
                options.parse.toplevel = null;
                if (options.parse.spidermonkey) {
                    options.parse.toplevel = AST_Node.from_mozilla_ast(Object.keys(files).reduce(function (toplevel, name) {
                        if (!toplevel)
                            return files[name];
                        toplevel.body = toplevel.body.concat(files[name].body);
                        return toplevel;
                    }, null));
                }
                else {
                    delete options.parse.spidermonkey;
                    for (var name in files)
                        if (HOP(files, name)) {
                            options.parse.filename = name;
                            options.parse.toplevel = parse(files[name], options.parse);
                            if (options.sourceMap && options.sourceMap.content == "inline") {
                                if (Object.keys(files).length > 1)
                                    throw new Error("inline source map only works with singular input");
                                options.sourceMap.content = read_source_map(files[name]);
                            }
                        }
                }
                if (options.parse.toplevel === null) {
                    throw new Error("no source file given");
                }
                toplevel = options.parse.toplevel;
            }
            if (quoted_props && options.mangle.properties.keep_quoted !== "strict") {
                reserve_quoted_keys(toplevel, quoted_props);
            }
            var annotated_props;
            if (options.mangle && options.mangle.properties) {
                annotated_props = find_annotated_props(toplevel);
            }
            if (options.wrap) {
                toplevel = toplevel.wrap_commonjs(options.wrap);
            }
            if (options.enclose) {
                toplevel = toplevel.wrap_enclose(options.enclose);
            }
            if (timings)
                timings.rename = Date.now();
            // -- Compress phase --
            if (timings)
                timings.compress = Date.now();
            if (options.compress) {
                toplevel = new Compressor(options.compress, {
                    mangle_options: options.mangle
                }).compress(toplevel);
            }
            // -- Mangle phase --
            if (timings)
                timings.scope = Date.now();
            if (options.mangle)
                toplevel.figure_out_scope(options.mangle);
            if (timings)
                timings.mangle = Date.now();
            if (options.mangle) {
                toplevel.compute_char_frequency(options.mangle);
                toplevel.mangle_names(options.mangle);
                toplevel = mangle_private_properties(toplevel, options.mangle);
            }
            if (timings)
                timings.properties = Date.now();
            if (options.mangle && options.mangle.properties) {
                toplevel = mangle_properties(toplevel, options.mangle.properties, annotated_props);
            }
            // Format phase
            if (timings)
                timings.format = Date.now();
            var result = {};
            if (options.format.ast) {
                result.ast = toplevel;
            }
            if (options.format.spidermonkey) {
                result.ast = toplevel.to_mozilla_ast();
            }
            let format_options;
            if (!HOP(options.format, "code") || options.format.code) {
                // Make a shallow copy so that we can modify without mutating the user's input.
                format_options = { ...options.format };
                if (!format_options.ast) {
                    // Destroy stuff to save RAM. (unless the deprecated `ast` option is on)
                    format_options._destroy_ast = true;
                    walk(toplevel, node => {
                        if (node instanceof AST_Scope) {
                            node.variables = undefined;
                            node.enclosed = undefined;
                            node.parent_scope = undefined;
                        }
                        if (node.block_scope) {
                            node.block_scope.variables = undefined;
                            node.block_scope.enclosed = undefined;
                            node.parent_scope = undefined;
                        }
                    });
                }
                if (options.sourceMap) {
                    if (options.sourceMap.includeSources && files instanceof AST_Toplevel) {
                        throw new Error("original source content unavailable");
                    }
                    format_options.source_map = yield* SourceMap({
                        file: options.sourceMap.filename,
                        orig: options.sourceMap.content,
                        root: options.sourceMap.root,
                        files: options.sourceMap.includeSources ? files : null,
                    });
                }
                delete format_options.ast;
                delete format_options.code;
                delete format_options.spidermonkey;
                var stream = OutputStream(format_options);
                toplevel.print(stream);
                result.code = stream.get();
                if (options.sourceMap) {
                    Object.defineProperty(result, "map", {
                        configurable: true,
                        enumerable: true,
                        get() {
                            const map = format_options.source_map.getEncoded();
                            return (result.map = options.sourceMap.asObject ? map : JSON.stringify(map));
                        },
                        set(value) {
                            Object.defineProperty(result, "map", {
                                value,
                                writable: true,
                            });
                        }
                    });
                    result.decoded_map = format_options.source_map.getDecoded();
                    if (options.sourceMap.url == "inline") {
                        var sourceMap = typeof result.map === "object" ? JSON.stringify(result.map) : result.map;
                        result.code += "\n//# sourceMappingURL=data:application/json;charset=utf-8;base64," + to_base64(sourceMap);
                    }
                    else if (options.sourceMap.url) {
                        result.code += "\n//# sourceMappingURL=" + options.sourceMap.url;
                    }
                }
            }
            if (options.nameCache && options.mangle) {
                if (options.mangle.cache)
                    options.nameCache.vars = cache_to_json(options.mangle.cache);
                if (options.mangle.properties && options.mangle.properties.cache) {
                    options.nameCache.props = cache_to_json(options.mangle.properties.cache);
                }
            }
            if (format_options && format_options.source_map) {
                format_options.source_map.destroy();
            }
            if (timings) {
                timings.end = Date.now();
                result.timings = {
                    parse: 1e-3 * (timings.rename - timings.parse),
                    rename: 1e-3 * (timings.compress - timings.rename),
                    compress: 1e-3 * (timings.scope - timings.compress),
                    scope: 1e-3 * (timings.mangle - timings.scope),
                    mangle: 1e-3 * (timings.properties - timings.mangle),
                    properties: 1e-3 * (timings.format - timings.properties),
                    format: 1e-3 * (timings.end - timings.format),
                    total: 1e-3 * (timings.end - timings.start)
                };
            }
            return result;
        }
        async function minify(files, options, _fs_module) {
            const gen = minify_sync_or_async(files, options, _fs_module);
            let yielded;
            let val;
            do {
                val = gen.next(await yielded);
                yielded = val.value;
            } while (!val.done);
            return val.value;
        }
        function minify_sync(files, options, _fs_module) {
            const gen = minify_sync_or_async(files, options, _fs_module);
            let yielded;
            let val;
            do {
                if (yielded && typeof yielded.then === "function") {
                    throw new Error("minify_sync cannot be used with the legacy source-map module");
                }
                val = gen.next(yielded);
                yielded = val.value;
            } while (!val.done);
            return val.value;
        }
        async function run_cli({ program, packageJson, fs, path }) {
            const skip_keys = new Set(["cname", "parent_scope", "scope", "uses_eval", "uses_with"]);
            var files = {};
            var options = {
                compress: false,
                mangle: false
            };
            const default_options = await _default_options();
            program.version(packageJson.name + " " + packageJson.version);
            program.parseArgv = program.parse;
            program.parse = undefined;
            if (process.argv.includes("ast"))
                program.helpInformation = describe_ast;
            else if (process.argv.includes("options"))
                program.helpInformation = function () {
                    var text = [];
                    for (var option in default_options) {
                        text.push("--" + (option === "sourceMap" ? "source-map" : option) + " options:");
                        text.push(format_object(default_options[option]));
                        text.push("");
                    }
                    return text.join("\n");
                };
            program.option("-p, --parse <options>", "Specify parser options.", parse_js());
            program.option("-c, --compress [options]", "Enable compressor/specify compressor options.", parse_js());
            program.option("-m, --mangle [options]", "Mangle names/specify mangler options.", parse_js());
            program.option("--mangle-props [options]", "Mangle properties/specify mangler options.", parse_js());
            program.option("-f, --format [options]", "Format options.", parse_js());
            program.option("-b, --beautify [options]", "Alias for --format.", parse_js());
            program.option("-o, --output <file>", "Output file (default STDOUT).");
            program.option("--comments [filter]", "Preserve copyright comments in the output.");
            program.option("--config-file <file>", "Read minify() options from JSON file.");
            program.option("-d, --define <expr>[=value]", "Global definitions.", parse_js("define"));
            program.option("--ecma <version>", "Specify ECMAScript release: 5, 2015, 2016 or 2017...");
            program.option("-e, --enclose [arg[,...][:value[,...]]]", "Embed output in a big function with configurable arguments and values.");
            program.option("--ie8", "Support non-standard Internet Explorer 8.");
            program.option("--keep-classnames", "Do not mangle/drop class names.");
            program.option("--keep-fnames", "Do not mangle/drop function names. Useful for code relying on Function.prototype.name.");
            program.option("--module", "Input is an ES6 module");
            program.option("--name-cache <file>", "File to hold mangled name mappings.");
            program.option("--rename", "Force symbol expansion.");
            program.option("--no-rename", "Disable symbol expansion.");
            program.option("--safari10", "Support non-standard Safari 10.");
            program.option("--source-map [options]", "Enable source map/specify source map options.", parse_js());
            program.option("--timings", "Display operations run time on STDERR.");
            program.option("--toplevel", "Compress and/or mangle variables in toplevel scope.");
            program.option("--wrap <name>", "Embed everything as a function with “exports” corresponding to “name” globally.");
            program.arguments("[files...]").parseArgv(process.argv);
            if (program.configFile) {
                options = JSON.parse(read_file(program.configFile));
            }
            if (!program.output && program.sourceMap && program.sourceMap.url != "inline") {
                fatal("ERROR: cannot write source map to STDOUT");
            }
            [
                "compress",
                "enclose",
                "ie8",
                "mangle",
                "module",
                "safari10",
                "sourceMap",
                "toplevel",
                "wrap"
            ].forEach(function (name) {
                if (name in program) {
                    options[name] = program[name];
                }
            });
            if ("ecma" in program) {
                if (program.ecma != (program.ecma | 0))
                    fatal("ERROR: ecma must be an integer");
                const ecma = program.ecma | 0;
                if (ecma > 5 && ecma < 2015)
                    options.ecma = ecma + 2009;
                else
                    options.ecma = ecma;
            }
            if (program.format || program.beautify) {
                const chosenOption = program.format || program.beautify;
                options.format = typeof chosenOption === "object" ? chosenOption : {};
            }
            if (program.comments) {
                if (typeof options.format != "object")
                    options.format = {};
                options.format.comments = typeof program.comments == "string" ? (program.comments == "false" ? false : program.comments) : "some";
            }
            if (program.define) {
                if (typeof options.compress != "object")
                    options.compress = {};
                if (typeof options.compress.global_defs != "object")
                    options.compress.global_defs = {};
                for (var expr in program.define) {
                    options.compress.global_defs[expr] = program.define[expr];
                }
            }
            if (program.keepClassnames) {
                options.keep_classnames = true;
            }
            if (program.keepFnames) {
                options.keep_fnames = true;
            }
            if (program.mangleProps) {
                if (program.mangleProps.domprops) {
                    delete program.mangleProps.domprops;
                }
                else {
                    if (typeof program.mangleProps != "object")
                        program.mangleProps = {};
                    if (!Array.isArray(program.mangleProps.reserved))
                        program.mangleProps.reserved = [];
                }
                if (typeof options.mangle != "object")
                    options.mangle = {};
                options.mangle.properties = program.mangleProps;
            }
            if (program.nameCache) {
                options.nameCache = JSON.parse(read_file(program.nameCache, "{}"));
            }
            if (program.output == "ast") {
                options.format = {
                    ast: true,
                    code: false
                };
            }
            if (program.parse) {
                if (!program.parse.acorn && !program.parse.spidermonkey) {
                    options.parse = program.parse;
                }
                else if (program.sourceMap && program.sourceMap.content == "inline") {
                    fatal("ERROR: inline source map only works with built-in parser");
                }
            }
            if (~program.rawArgs.indexOf("--rename")) {
                options.rename = true;
            }
            else if (!program.rename) {
                options.rename = false;
            }
            let convert_path = name => name;
            if (typeof program.sourceMap == "object" && "base" in program.sourceMap) {
                convert_path = function () {
                    var base = program.sourceMap.base;
                    delete options.sourceMap.base;
                    return function (name) {
                        return path.relative(base, name);
                    };
                }();
            }
            let filesList;
            if (options.files && options.files.length) {
                filesList = options.files;
                delete options.files;
            }
            else if (program.args.length) {
                filesList = program.args;
            }
            if (filesList) {
                simple_glob(filesList).forEach(function (name) {
                    files[convert_path(name)] = read_file(name);
                });
            }
            else {
                await new Promise((resolve) => {
                    var chunks = [];
                    process.stdin.setEncoding("utf8");
                    process.stdin.on("data", function (chunk) {
                        chunks.push(chunk);
                    }).on("end", function () {
                        files = [chunks.join("")];
                        resolve();
                    });
                    process.stdin.resume();
                });
            }
            await run_cli();
            function convert_ast(fn) {
                return AST_Node.from_mozilla_ast(Object.keys(files).reduce(fn, null));
            }
            async function run_cli() {
                var content = program.sourceMap && program.sourceMap.content;
                if (content && content !== "inline") {
                    options.sourceMap.content = read_file(content, content);
                }
                if (program.timings)
                    options.timings = true;
                try {
                    if (program.parse) {
                        if (program.parse.acorn) {
                            files = convert_ast(function (toplevel, name) {
                                return require(52) /* acorn */.parse(files[name], {
                                    ecmaVersion: 2018,
                                    locations: true,
                                    program: toplevel,
                                    sourceFile: name,
                                    sourceType: options.module || program.parse.module ? "module" : "script"
                                });
                            });
                        }
                        else if (program.parse.spidermonkey) {
                            files = convert_ast(function (toplevel, name) {
                                var obj = JSON.parse(files[name]);
                                if (!toplevel)
                                    return obj;
                                toplevel.body = toplevel.body.concat(obj.body);
                                return toplevel;
                            });
                        }
                    }
                }
                catch (ex) {
                    fatal(ex);
                }
                let result;
                try {
                    result = await minify(files, options, fs);
                }
                catch (ex) {
                    if (ex.name == "SyntaxError") {
                        print_error("Parse error at " + ex.filename + ":" + ex.line + "," + ex.col);
                        var col = ex.col;
                        var lines = files[ex.filename].split(/\r?\n/);
                        var line = lines[ex.line - 1];
                        if (!line && !col) {
                            line = lines[ex.line - 2];
                            col = line.length;
                        }
                        if (line) {
                            var limit = 70;
                            if (col > limit) {
                                line = line.slice(col - limit);
                                col = limit;
                            }
                            print_error(line.slice(0, 80));
                            print_error(line.slice(0, col).replace(/\S/g, " ") + "^");
                        }
                    }
                    if (ex.defs) {
                        print_error("Supported options:");
                        print_error(format_object(ex.defs));
                    }
                    fatal(ex);
                    return;
                }
                if (program.output == "ast") {
                    if (!options.compress && !options.mangle) {
                        result.ast.figure_out_scope({});
                    }
                    console.log(JSON.stringify(result.ast, function (key, value) {
                        if (value)
                            switch (key) {
                                case "thedef":
                                    return symdef(value);
                                case "enclosed":
                                    return value.length ? value.map(symdef) : undefined;
                                case "variables":
                                case "globals":
                                    return value.size ? collect_from_map(value, symdef) : undefined;
                            }
                        if (skip_keys.has(key))
                            return;
                        if (value instanceof AST_Token)
                            return;
                        if (value instanceof Map)
                            return;
                        if (value instanceof AST_Node) {
                            var result = {
                                _class: "AST_" + value.TYPE
                            };
                            if (value.block_scope) {
                                result.variables = value.block_scope.variables;
                                result.enclosed = value.block_scope.enclosed;
                            }
                            value.CTOR.PROPS.forEach(function (prop) {
                                if (prop !== "block_scope") {
                                    result[prop] = value[prop];
                                }
                            });
                            return result;
                        }
                        return value;
                    }, 2));
                }
                else if (program.output == "spidermonkey") {
                    try {
                        const minified = await minify(result.code, {
                            compress: false,
                            mangle: false,
                            format: {
                                ast: true,
                                code: false
                            }
                        }, fs);
                        console.log(JSON.stringify(minified.ast.to_mozilla_ast(), null, 2));
                    }
                    catch (ex) {
                        fatal(ex);
                        return;
                    }
                }
                else if (program.output) {
                    fs.writeFileSync(program.output, result.code);
                    if (options.sourceMap && options.sourceMap.url !== "inline" && result.map) {
                        fs.writeFileSync(program.output + ".map", result.map);
                    }
                }
                else {
                    console.log(result.code);
                }
                if (program.nameCache) {
                    fs.writeFileSync(program.nameCache, JSON.stringify(options.nameCache));
                }
                if (result.timings)
                    for (var phase in result.timings) {
                        print_error("- " + phase + ": " + result.timings[phase].toFixed(3) + "s");
                    }
            }
            function fatal(message) {
                if (message instanceof Error)
                    message = message.stack.replace(/^\S*?Error:/, "ERROR:");
                print_error(message);
                process.exit(1);
            }
            // A file glob function that only supports "*" and "?" wildcards in the basename.
            // Example: "foo/bar/*baz??.*.js"
            // Argument `glob` may be a string or an array of strings.
            // Returns an array of strings. Garbage in, garbage out.
            function simple_glob(glob) {
                if (Array.isArray(glob)) {
                    return [].concat.apply([], glob.map(simple_glob));
                }
                if (glob && glob.match(/[*?]/)) {
                    var dir = path.dirname(glob);
                    try {
                        var entries = fs.readdirSync(dir);
                    }
                    catch (ex) { }
                    if (entries) {
                        var pattern = "^" + path.basename(glob)
                            .replace(/[.+^$[\]\\(){}]/g, "\\$&")
                            .replace(/\*/g, "[^/\\\\]*")
                            .replace(/\?/g, "[^/\\\\]") + "$";
                        var mod = process.platform === "win32" ? "i" : "";
                        var rx = new RegExp(pattern, mod);
                        var results = entries.filter(function (name) {
                            return rx.test(name);
                        }).map(function (name) {
                            return path.join(dir, name);
                        });
                        if (results.length)
                            return results;
                    }
                }
                return [glob];
            }
            function read_file(path, default_value) {
                try {
                    return fs.readFileSync(path, "utf8");
                }
                catch (ex) {
                    if ((ex.code == "ENOENT" || ex.code == "ENAMETOOLONG") && default_value != null)
                        return default_value;
                    fatal(ex);
                }
            }
            function parse_js(flag) {
                return function (value, options) {
                    options = options || {};
                    try {
                        walk(parse(value, { expression: true }), node => {
                            if (node instanceof AST_Assign) {
                                var name = node.left.print_to_string();
                                var value = node.right;
                                if (flag) {
                                    options[name] = value;
                                }
                                else if (value instanceof AST_Array) {
                                    options[name] = value.elements.map(to_string);
                                }
                                else if (value instanceof AST_RegExp) {
                                    value = value.value;
                                    options[name] = new RegExp(value.source, value.flags);
                                }
                                else {
                                    options[name] = to_string(value);
                                }
                                return true;
                            }
                            if (node instanceof AST_Symbol || node instanceof AST_PropAccess) {
                                var name = node.print_to_string();
                                options[name] = true;
                                return true;
                            }
                            if (!(node instanceof AST_Sequence))
                                throw node;
                            function to_string(value) {
                                return value instanceof AST_Constant ? value.getValue() : value.print_to_string({
                                    quote_keys: true
                                });
                            }
                        });
                    }
                    catch (ex) {
                        if (flag) {
                            fatal("Error parsing arguments for '" + flag + "': " + value);
                        }
                        else {
                            options[value] = null;
                        }
                    }
                    return options;
                };
            }
            function symdef(def) {
                var ret = (1e6 + def.id) + " " + def.name;
                if (def.mangled_name)
                    ret += " " + def.mangled_name;
                return ret;
            }
            function collect_from_map(map, callback) {
                var result = [];
                map.forEach(function (def) {
                    result.push(callback(def));
                });
                return result;
            }
            function format_object(obj) {
                var lines = [];
                var padding = "";
                Object.keys(obj).map(function (name) {
                    if (padding.length < name.length)
                        padding = Array(name.length + 1).join(" ");
                    return [name, JSON.stringify(obj[name])];
                }).forEach(function (tokens) {
                    lines.push("  " + tokens[0] + padding.slice(tokens[0].length - 2) + tokens[1]);
                });
                return lines.join("\n");
            }
            function print_error(msg) {
                process.stderr.write(msg);
                process.stderr.write("\n");
            }
            function describe_ast() {
                var out = OutputStream({ beautify: true });
                function doitem(ctor) {
                    out.print("AST_" + ctor.TYPE);
                    const props = ctor.SELF_PROPS.filter(prop => !/^\$/.test(prop));
                    if (props.length > 0) {
                        out.space();
                        out.with_parens(function () {
                            props.forEach(function (prop, i) {
                                if (i)
                                    out.space();
                                out.print(prop);
                            });
                        });
                    }
                    if (ctor.documentation) {
                        out.space();
                        out.print_string(ctor.documentation);
                    }
                    if (ctor.SUBCLASSES.length > 0) {
                        out.space();
                        out.with_block(function () {
                            ctor.SUBCLASSES.forEach(function (ctor) {
                                out.indent();
                                doitem(ctor);
                                out.newline();
                            });
                        });
                    }
                }
                doitem(AST_Node);
                return out + "\n";
            }
        }
        async function _default_options() {
            const defs = {};
            Object.keys(infer_options({ 0: 0 })).forEach((component) => {
                const options = infer_options({
                    [component]: { 0: 0 }
                });
                if (options)
                    defs[component] = options;
            });
            return defs;
        }
        async function infer_options(options) {
            try {
                await minify("", options);
            }
            catch (error) {
                return error.defs;
            }
        }
        exports._default_options = _default_options;
        exports._run_cli = run_cli;
        exports.minify = minify;
        exports.minify_sync = minify_sync;
    }));
},
/* @jridgewell/source-map/dist/source-map.cjs */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    Object.defineProperty(exports, '__esModule', { value: true });
    var traceMapping = require(47) /* @jridgewell/trace-mapping */;
    var genMapping = require(50) /* @jridgewell/gen-mapping */;
    class SourceMapConsumer {
        constructor(map, mapUrl) {
            const trace = (this._map = new traceMapping.AnyMap(map, mapUrl));
            this.file = trace.file;
            this.names = trace.names;
            this.sourceRoot = trace.sourceRoot;
            this.sources = trace.resolvedSources;
            this.sourcesContent = trace.sourcesContent;
            this.version = trace.version;
        }
        static fromSourceMap(map, mapUrl) {
            // This is more performant if we receive
            // a @jridgewell/source-map SourceMapGenerator
            if (map.toDecodedMap) {
                return new SourceMapConsumer(map.toDecodedMap(), mapUrl);
            }
            // This is a fallback for `source-map` and `source-map-js`
            return new SourceMapConsumer(map.toJSON(), mapUrl);
        }
        get mappings() {
            return traceMapping.encodedMappings(this._map);
        }
        originalPositionFor(needle) {
            return traceMapping.originalPositionFor(this._map, needle);
        }
        generatedPositionFor(originalPosition) {
            return traceMapping.generatedPositionFor(this._map, originalPosition);
        }
        allGeneratedPositionsFor(originalPosition) {
            return traceMapping.allGeneratedPositionsFor(this._map, originalPosition);
        }
        hasContentsOfAllSources() {
            if (!this.sourcesContent || this.sourcesContent.length !== this.sources.length) {
                return false;
            }
            for (const content of this.sourcesContent) {
                if (content == null) {
                    return false;
                }
            }
            return true;
        }
        sourceContentFor(source, nullOnMissing) {
            const sourceContent = traceMapping.sourceContentFor(this._map, source);
            if (sourceContent != null) {
                return sourceContent;
            }
            if (nullOnMissing) {
                return null;
            }
            throw new Error(`"${source}" is not in the SourceMap.`);
        }
        eachMapping(callback, context /*, order?: number*/) {
            // order is ignored as @jridgewell/trace-map doesn't implement it
            traceMapping.eachMapping(this._map, context ? callback.bind(context) : callback);
        }
        destroy() {
            // noop.
        }
    }
    class SourceMapGenerator {
        constructor(opts) {
            // TODO :: should this be duck-typed ?
            this._map = opts instanceof genMapping.GenMapping ? opts : new genMapping.GenMapping(opts);
        }
        static fromSourceMap(consumer) {
            return new SourceMapGenerator(genMapping.fromMap(consumer));
        }
        addMapping(mapping) {
            genMapping.maybeAddMapping(this._map, mapping);
        }
        setSourceContent(source, content) {
            genMapping.setSourceContent(this._map, source, content);
        }
        toJSON() {
            return genMapping.toEncodedMap(this._map);
        }
        toString() {
            return JSON.stringify(this.toJSON());
        }
        toDecodedMap() {
            return genMapping.toDecodedMap(this._map);
        }
    }
    exports.SourceMapConsumer = SourceMapConsumer;
    exports.SourceMapGenerator = SourceMapGenerator;
    
},
/* @jridgewell/trace-mapping/dist/trace-mapping.umd.js */ function _(require, module, exports, __esModule, __esExport) {
    (function (global, factory) {
        typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require(48) /* @jridgewell/sourcemap-codec */, require(49) /* @jridgewell/resolve-uri */) :
            typeof define === 'function' && define.amd ? define(['exports', '@jridgewell/sourcemap-codec', '@jridgewell/resolve-uri'], factory) :
                (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.traceMapping = {}, global.sourcemapCodec, global.resolveURI));
    })(this, (function (exports, sourcemapCodec, resolveUri) {
        'use strict';
        function resolve(input, base) {
            // The base is always treated as a directory, if it's not empty.
            // https://github.com/mozilla/source-map/blob/8cb3ee57/lib/util.js#L327
            // https://github.com/chromium/chromium/blob/da4adbb3/third_party/blink/renderer/devtools/front_end/sdk/SourceMap.js#L400-L401
            if (base && !base.endsWith('/'))
                base += '/';
            return resolveUri(input, base);
        }
        /**
         * Removes everything after the last "/", but leaves the slash.
         */
        function stripFilename(path) {
            if (!path)
                return '';
            const index = path.lastIndexOf('/');
            return path.slice(0, index + 1);
        }
        const COLUMN = 0;
        const SOURCES_INDEX = 1;
        const SOURCE_LINE = 2;
        const SOURCE_COLUMN = 3;
        const NAMES_INDEX = 4;
        const REV_GENERATED_LINE = 1;
        const REV_GENERATED_COLUMN = 2;
        function maybeSort(mappings, owned) {
            const unsortedIndex = nextUnsortedSegmentLine(mappings, 0);
            if (unsortedIndex === mappings.length)
                return mappings;
            // If we own the array (meaning we parsed it from JSON), then we're free to directly mutate it. If
            // not, we do not want to modify the consumer's input array.
            if (!owned)
                mappings = mappings.slice();
            for (let i = unsortedIndex; i < mappings.length; i = nextUnsortedSegmentLine(mappings, i + 1)) {
                mappings[i] = sortSegments(mappings[i], owned);
            }
            return mappings;
        }
        function nextUnsortedSegmentLine(mappings, start) {
            for (let i = start; i < mappings.length; i++) {
                if (!isSorted(mappings[i]))
                    return i;
            }
            return mappings.length;
        }
        function isSorted(line) {
            for (let j = 1; j < line.length; j++) {
                if (line[j][COLUMN] < line[j - 1][COLUMN]) {
                    return false;
                }
            }
            return true;
        }
        function sortSegments(line, owned) {
            if (!owned)
                line = line.slice();
            return line.sort(sortComparator);
        }
        function sortComparator(a, b) {
            return a[COLUMN] - b[COLUMN];
        }
        let found = false;
        /**
         * A binary search implementation that returns the index if a match is found.
         * If no match is found, then the left-index (the index associated with the item that comes just
         * before the desired index) is returned. To maintain proper sort order, a splice would happen at
         * the next index:
         *
         * ```js
         * const array = [1, 3];
         * const needle = 2;
         * const index = binarySearch(array, needle, (item, needle) => item - needle);
         *
         * assert.equal(index, 0);
         * array.splice(index + 1, 0, needle);
         * assert.deepEqual(array, [1, 2, 3]);
         * ```
         */
        function binarySearch(haystack, needle, low, high) {
            while (low <= high) {
                const mid = low + ((high - low) >> 1);
                const cmp = haystack[mid][COLUMN] - needle;
                if (cmp === 0) {
                    found = true;
                    return mid;
                }
                if (cmp < 0) {
                    low = mid + 1;
                }
                else {
                    high = mid - 1;
                }
            }
            found = false;
            return low - 1;
        }
        function upperBound(haystack, needle, index) {
            for (let i = index + 1; i < haystack.length; index = i++) {
                if (haystack[i][COLUMN] !== needle)
                    break;
            }
            return index;
        }
        function lowerBound(haystack, needle, index) {
            for (let i = index - 1; i >= 0; index = i--) {
                if (haystack[i][COLUMN] !== needle)
                    break;
            }
            return index;
        }
        function memoizedState() {
            return {
                lastKey: -1,
                lastNeedle: -1,
                lastIndex: -1,
            };
        }
        /**
         * This overly complicated beast is just to record the last tested line/column and the resulting
         * index, allowing us to skip a few tests if mappings are monotonically increasing.
         */
        function memoizedBinarySearch(haystack, needle, state, key) {
            const { lastKey, lastNeedle, lastIndex } = state;
            let low = 0;
            let high = haystack.length - 1;
            if (key === lastKey) {
                if (needle === lastNeedle) {
                    found = lastIndex !== -1 && haystack[lastIndex][COLUMN] === needle;
                    return lastIndex;
                }
                if (needle >= lastNeedle) {
                    // lastIndex may be -1 if the previous needle was not found.
                    low = lastIndex === -1 ? 0 : lastIndex;
                }
                else {
                    high = lastIndex;
                }
            }
            state.lastKey = key;
            state.lastNeedle = needle;
            return (state.lastIndex = binarySearch(haystack, needle, low, high));
        }
        // Rebuilds the original source files, with mappings that are ordered by source line/column instead
        // of generated line/column.
        function buildBySources(decoded, memos) {
            const sources = memos.map(buildNullArray);
            for (let i = 0; i < decoded.length; i++) {
                const line = decoded[i];
                for (let j = 0; j < line.length; j++) {
                    const seg = line[j];
                    if (seg.length === 1)
                        continue;
                    const sourceIndex = seg[SOURCES_INDEX];
                    const sourceLine = seg[SOURCE_LINE];
                    const sourceColumn = seg[SOURCE_COLUMN];
                    const originalSource = sources[sourceIndex];
                    const originalLine = (originalSource[sourceLine] || (originalSource[sourceLine] = []));
                    const memo = memos[sourceIndex];
                    // The binary search either found a match, or it found the left-index just before where the
                    // segment should go. Either way, we want to insert after that. And there may be multiple
                    // generated segments associated with an original location, so there may need to move several
                    // indexes before we find where we need to insert.
                    let index = upperBound(originalLine, sourceColumn, memoizedBinarySearch(originalLine, sourceColumn, memo, sourceLine));
                    memo.lastIndex = ++index;
                    insert(originalLine, index, [sourceColumn, i, seg[COLUMN]]);
                }
            }
            return sources;
        }
        function insert(array, index, value) {
            for (let i = array.length; i > index; i--) {
                array[i] = array[i - 1];
            }
            array[index] = value;
        }
        // Null arrays allow us to use ordered index keys without actually allocating contiguous memory like
        // a real array. We use a null-prototype object to avoid prototype pollution and deoptimizations.
        // Numeric properties on objects are magically sorted in ascending order by the engine regardless of
        // the insertion order. So, by setting any numeric keys, even out of order, we'll get ascending
        // order when iterating with for-in.
        function buildNullArray() {
            return { __proto__: null };
        }
        const AnyMap = function (map, mapUrl) {
            const parsed = parse(map);
            if (!('sections' in parsed)) {
                return new TraceMap(parsed, mapUrl);
            }
            const mappings = [];
            const sources = [];
            const sourcesContent = [];
            const names = [];
            const ignoreList = [];
            recurse(parsed, mapUrl, mappings, sources, sourcesContent, names, ignoreList, 0, 0, Infinity, Infinity);
            const joined = {
                version: 3,
                file: parsed.file,
                names,
                sources,
                sourcesContent,
                mappings,
                ignoreList,
            };
            return presortedDecodedMap(joined);
        };
        function parse(map) {
            return typeof map === 'string' ? JSON.parse(map) : map;
        }
        function recurse(input, mapUrl, mappings, sources, sourcesContent, names, ignoreList, lineOffset, columnOffset, stopLine, stopColumn) {
            const { sections } = input;
            for (let i = 0; i < sections.length; i++) {
                const { map, offset } = sections[i];
                let sl = stopLine;
                let sc = stopColumn;
                if (i + 1 < sections.length) {
                    const nextOffset = sections[i + 1].offset;
                    sl = Math.min(stopLine, lineOffset + nextOffset.line);
                    if (sl === stopLine) {
                        sc = Math.min(stopColumn, columnOffset + nextOffset.column);
                    }
                    else if (sl < stopLine) {
                        sc = columnOffset + nextOffset.column;
                    }
                }
                addSection(map, mapUrl, mappings, sources, sourcesContent, names, ignoreList, lineOffset + offset.line, columnOffset + offset.column, sl, sc);
            }
        }
        function addSection(input, mapUrl, mappings, sources, sourcesContent, names, ignoreList, lineOffset, columnOffset, stopLine, stopColumn) {
            const parsed = parse(input);
            if ('sections' in parsed)
                return recurse(...arguments);
            const map = new TraceMap(parsed, mapUrl);
            const sourcesOffset = sources.length;
            const namesOffset = names.length;
            const decoded = decodedMappings(map);
            const { resolvedSources, sourcesContent: contents, ignoreList: ignores } = map;
            append(sources, resolvedSources);
            append(names, map.names);
            if (contents)
                append(sourcesContent, contents);
            else
                for (let i = 0; i < resolvedSources.length; i++)
                    sourcesContent.push(null);
            if (ignores)
                for (let i = 0; i < ignores.length; i++)
                    ignoreList.push(ignores[i] + sourcesOffset);
            for (let i = 0; i < decoded.length; i++) {
                const lineI = lineOffset + i;
                // We can only add so many lines before we step into the range that the next section's map
                // controls. When we get to the last line, then we'll start checking the segments to see if
                // they've crossed into the column range. But it may not have any columns that overstep, so we
                // still need to check that we don't overstep lines, too.
                if (lineI > stopLine)
                    return;
                // The out line may already exist in mappings (if we're continuing the line started by a
                // previous section). Or, we may have jumped ahead several lines to start this section.
                const out = getLine(mappings, lineI);
                // On the 0th loop, the section's column offset shifts us forward. On all other lines (since the
                // map can be multiple lines), it doesn't.
                const cOffset = i === 0 ? columnOffset : 0;
                const line = decoded[i];
                for (let j = 0; j < line.length; j++) {
                    const seg = line[j];
                    const column = cOffset + seg[COLUMN];
                    // If this segment steps into the column range that the next section's map controls, we need
                    // to stop early.
                    if (lineI === stopLine && column >= stopColumn)
                        return;
                    if (seg.length === 1) {
                        out.push([column]);
                        continue;
                    }
                    const sourcesIndex = sourcesOffset + seg[SOURCES_INDEX];
                    const sourceLine = seg[SOURCE_LINE];
                    const sourceColumn = seg[SOURCE_COLUMN];
                    out.push(seg.length === 4
                        ? [column, sourcesIndex, sourceLine, sourceColumn]
                        : [column, sourcesIndex, sourceLine, sourceColumn, namesOffset + seg[NAMES_INDEX]]);
                }
            }
        }
        function append(arr, other) {
            for (let i = 0; i < other.length; i++)
                arr.push(other[i]);
        }
        function getLine(arr, index) {
            for (let i = arr.length; i <= index; i++)
                arr[i] = [];
            return arr[index];
        }
        const LINE_GTR_ZERO = '`line` must be greater than 0 (lines start at line 1)';
        const COL_GTR_EQ_ZERO = '`column` must be greater than or equal to 0 (columns start at column 0)';
        const LEAST_UPPER_BOUND = -1;
        const GREATEST_LOWER_BOUND = 1;
        class TraceMap {
            constructor(map, mapUrl) {
                const isString = typeof map === 'string';
                if (!isString && map._decodedMemo)
                    return map;
                const parsed = (isString ? JSON.parse(map) : map);
                const { version, file, names, sourceRoot, sources, sourcesContent } = parsed;
                this.version = version;
                this.file = file;
                this.names = names || [];
                this.sourceRoot = sourceRoot;
                this.sources = sources;
                this.sourcesContent = sourcesContent;
                this.ignoreList = parsed.ignoreList || parsed.x_google_ignoreList || undefined;
                const from = resolve(sourceRoot || '', stripFilename(mapUrl));
                this.resolvedSources = sources.map((s) => resolve(s || '', from));
                const { mappings } = parsed;
                if (typeof mappings === 'string') {
                    this._encoded = mappings;
                    this._decoded = undefined;
                }
                else {
                    this._encoded = undefined;
                    this._decoded = maybeSort(mappings, isString);
                }
                this._decodedMemo = memoizedState();
                this._bySources = undefined;
                this._bySourceMemos = undefined;
            }
        }
        /**
         * Typescript doesn't allow friend access to private fields, so this just casts the map into a type
         * with public access modifiers.
         */
        function cast(map) {
            return map;
        }
        /**
         * Returns the encoded (VLQ string) form of the SourceMap's mappings field.
         */
        function encodedMappings(map) {
            var _a;
            var _b;
            return ((_a = (_b = cast(map))._encoded) !== null && _a !== void 0 ? _a : (_b._encoded = sourcemapCodec.encode(cast(map)._decoded)));
        }
        /**
         * Returns the decoded (array of lines of segments) form of the SourceMap's mappings field.
         */
        function decodedMappings(map) {
            var _a;
            return ((_a = cast(map))._decoded || (_a._decoded = sourcemapCodec.decode(cast(map)._encoded)));
        }
        /**
         * A low-level API to find the segment associated with a generated line/column (think, from a
         * stack trace). Line and column here are 0-based, unlike `originalPositionFor`.
         */
        function traceSegment(map, line, column) {
            const decoded = decodedMappings(map);
            // It's common for parent source maps to have pointers to lines that have no
            // mapping (like a "//# sourceMappingURL=") at the end of the child file.
            if (line >= decoded.length)
                return null;
            const segments = decoded[line];
            const index = traceSegmentInternal(segments, cast(map)._decodedMemo, line, column, GREATEST_LOWER_BOUND);
            return index === -1 ? null : segments[index];
        }
        /**
         * A higher-level API to find the source/line/column associated with a generated line/column
         * (think, from a stack trace). Line is 1-based, but column is 0-based, due to legacy behavior in
         * `source-map` library.
         */
        function originalPositionFor(map, needle) {
            let { line, column, bias } = needle;
            line--;
            if (line < 0)
                throw new Error(LINE_GTR_ZERO);
            if (column < 0)
                throw new Error(COL_GTR_EQ_ZERO);
            const decoded = decodedMappings(map);
            // It's common for parent source maps to have pointers to lines that have no
            // mapping (like a "//# sourceMappingURL=") at the end of the child file.
            if (line >= decoded.length)
                return OMapping(null, null, null, null);
            const segments = decoded[line];
            const index = traceSegmentInternal(segments, cast(map)._decodedMemo, line, column, bias || GREATEST_LOWER_BOUND);
            if (index === -1)
                return OMapping(null, null, null, null);
            const segment = segments[index];
            if (segment.length === 1)
                return OMapping(null, null, null, null);
            const { names, resolvedSources } = map;
            return OMapping(resolvedSources[segment[SOURCES_INDEX]], segment[SOURCE_LINE] + 1, segment[SOURCE_COLUMN], segment.length === 5 ? names[segment[NAMES_INDEX]] : null);
        }
        /**
         * Finds the generated line/column position of the provided source/line/column source position.
         */
        function generatedPositionFor(map, needle) {
            const { source, line, column, bias } = needle;
            return generatedPosition(map, source, line, column, bias || GREATEST_LOWER_BOUND, false);
        }
        /**
         * Finds all generated line/column positions of the provided source/line/column source position.
         */
        function allGeneratedPositionsFor(map, needle) {
            const { source, line, column, bias } = needle;
            // SourceMapConsumer uses LEAST_UPPER_BOUND for some reason, so we follow suit.
            return generatedPosition(map, source, line, column, bias || LEAST_UPPER_BOUND, true);
        }
        /**
         * Iterates each mapping in generated position order.
         */
        function eachMapping(map, cb) {
            const decoded = decodedMappings(map);
            const { names, resolvedSources } = map;
            for (let i = 0; i < decoded.length; i++) {
                const line = decoded[i];
                for (let j = 0; j < line.length; j++) {
                    const seg = line[j];
                    const generatedLine = i + 1;
                    const generatedColumn = seg[0];
                    let source = null;
                    let originalLine = null;
                    let originalColumn = null;
                    let name = null;
                    if (seg.length !== 1) {
                        source = resolvedSources[seg[1]];
                        originalLine = seg[2] + 1;
                        originalColumn = seg[3];
                    }
                    if (seg.length === 5)
                        name = names[seg[4]];
                    cb({
                        generatedLine,
                        generatedColumn,
                        source,
                        originalLine,
                        originalColumn,
                        name,
                    });
                }
            }
        }
        function sourceIndex(map, source) {
            const { sources, resolvedSources } = map;
            let index = sources.indexOf(source);
            if (index === -1)
                index = resolvedSources.indexOf(source);
            return index;
        }
        /**
         * Retrieves the source content for a particular source, if its found. Returns null if not.
         */
        function sourceContentFor(map, source) {
            const { sourcesContent } = map;
            if (sourcesContent == null)
                return null;
            const index = sourceIndex(map, source);
            return index === -1 ? null : sourcesContent[index];
        }
        /**
         * Determines if the source is marked to ignore by the source map.
         */
        function isIgnored(map, source) {
            const { ignoreList } = map;
            if (ignoreList == null)
                return false;
            const index = sourceIndex(map, source);
            return index === -1 ? false : ignoreList.includes(index);
        }
        /**
         * A helper that skips sorting of the input map's mappings array, which can be expensive for larger
         * maps.
         */
        function presortedDecodedMap(map, mapUrl) {
            const tracer = new TraceMap(clone(map, []), mapUrl);
            cast(tracer)._decoded = map.mappings;
            return tracer;
        }
        /**
         * Returns a sourcemap object (with decoded mappings) suitable for passing to a library that expects
         * a sourcemap, or to JSON.stringify.
         */
        function decodedMap(map) {
            return clone(map, decodedMappings(map));
        }
        /**
         * Returns a sourcemap object (with encoded mappings) suitable for passing to a library that expects
         * a sourcemap, or to JSON.stringify.
         */
        function encodedMap(map) {
            return clone(map, encodedMappings(map));
        }
        function clone(map, mappings) {
            return {
                version: map.version,
                file: map.file,
                names: map.names,
                sourceRoot: map.sourceRoot,
                sources: map.sources,
                sourcesContent: map.sourcesContent,
                mappings,
                ignoreList: map.ignoreList || map.x_google_ignoreList,
            };
        }
        function OMapping(source, line, column, name) {
            return { source, line, column, name };
        }
        function GMapping(line, column) {
            return { line, column };
        }
        function traceSegmentInternal(segments, memo, line, column, bias) {
            let index = memoizedBinarySearch(segments, column, memo, line);
            if (found) {
                index = (bias === LEAST_UPPER_BOUND ? upperBound : lowerBound)(segments, column, index);
            }
            else if (bias === LEAST_UPPER_BOUND)
                index++;
            if (index === -1 || index === segments.length)
                return -1;
            return index;
        }
        function sliceGeneratedPositions(segments, memo, line, column, bias) {
            let min = traceSegmentInternal(segments, memo, line, column, GREATEST_LOWER_BOUND);
            // We ignored the bias when tracing the segment so that we're guarnateed to find the first (in
            // insertion order) segment that matched. Even if we did respect the bias when tracing, we would
            // still need to call `lowerBound()` to find the first segment, which is slower than just looking
            // for the GREATEST_LOWER_BOUND to begin with. The only difference that matters for us is when the
            // binary search didn't match, in which case GREATEST_LOWER_BOUND just needs to increment to
            // match LEAST_UPPER_BOUND.
            if (!found && bias === LEAST_UPPER_BOUND)
                min++;
            if (min === -1 || min === segments.length)
                return [];
            // We may have found the segment that started at an earlier column. If this is the case, then we
            // need to slice all generated segments that match _that_ column, because all such segments span
            // to our desired column.
            const matchedColumn = found ? column : segments[min][COLUMN];
            // The binary search is not guaranteed to find the lower bound when a match wasn't found.
            if (!found)
                min = lowerBound(segments, matchedColumn, min);
            const max = upperBound(segments, matchedColumn, min);
            const result = [];
            for (; min <= max; min++) {
                const segment = segments[min];
                result.push(GMapping(segment[REV_GENERATED_LINE] + 1, segment[REV_GENERATED_COLUMN]));
            }
            return result;
        }
        function generatedPosition(map, source, line, column, bias, all) {
            var _a;
            line--;
            if (line < 0)
                throw new Error(LINE_GTR_ZERO);
            if (column < 0)
                throw new Error(COL_GTR_EQ_ZERO);
            const { sources, resolvedSources } = map;
            let sourceIndex = sources.indexOf(source);
            if (sourceIndex === -1)
                sourceIndex = resolvedSources.indexOf(source);
            if (sourceIndex === -1)
                return all ? [] : GMapping(null, null);
            const generated = ((_a = cast(map))._bySources || (_a._bySources = buildBySources(decodedMappings(map), (cast(map)._bySourceMemos = sources.map(memoizedState)))));
            const segments = generated[sourceIndex][line];
            if (segments == null)
                return all ? [] : GMapping(null, null);
            const memo = cast(map)._bySourceMemos[sourceIndex];
            if (all)
                return sliceGeneratedPositions(segments, memo, line, column, bias);
            const index = traceSegmentInternal(segments, memo, line, column, bias);
            if (index === -1)
                return GMapping(null, null);
            const segment = segments[index];
            return GMapping(segment[REV_GENERATED_LINE] + 1, segment[REV_GENERATED_COLUMN]);
        }
        exports.AnyMap = AnyMap;
        exports.GREATEST_LOWER_BOUND = GREATEST_LOWER_BOUND;
        exports.LEAST_UPPER_BOUND = LEAST_UPPER_BOUND;
        exports.TraceMap = TraceMap;
        exports.allGeneratedPositionsFor = allGeneratedPositionsFor;
        exports.decodedMap = decodedMap;
        exports.decodedMappings = decodedMappings;
        exports.eachMapping = eachMapping;
        exports.encodedMap = encodedMap;
        exports.encodedMappings = encodedMappings;
        exports.generatedPositionFor = generatedPositionFor;
        exports.isIgnored = isIgnored;
        exports.originalPositionFor = originalPositionFor;
        exports.presortedDecodedMap = presortedDecodedMap;
        exports.sourceContentFor = sourceContentFor;
        exports.traceSegment = traceSegment;
    }));
    
},
/* @jridgewell/sourcemap-codec/dist/sourcemap-codec.umd.js */ function _(require, module, exports, __esModule, __esExport) {
    (function (global, factory) {
        typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
            typeof define === 'function' && define.amd ? define(['exports'], factory) :
                (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.sourcemapCodec = {}));
    })(this, (function (exports) {
        'use strict';
        const comma = ','.charCodeAt(0);
        const semicolon = ';'.charCodeAt(0);
        const chars = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
        const intToChar = new Uint8Array(64); // 64 possible chars.
        const charToInt = new Uint8Array(128); // z is 122 in ASCII
        for (let i = 0; i < chars.length; i++) {
            const c = chars.charCodeAt(i);
            intToChar[i] = c;
            charToInt[c] = i;
        }
        // Provide a fallback for older environments.
        const td = typeof TextDecoder !== 'undefined'
            ? /* #__PURE__ */ new TextDecoder()
            : typeof Buffer !== 'undefined'
                ? {
                    decode(buf) {
                        const out = Buffer.from(buf.buffer, buf.byteOffset, buf.byteLength);
                        return out.toString();
                    },
                }
                : {
                    decode(buf) {
                        let out = '';
                        for (let i = 0; i < buf.length; i++) {
                            out += String.fromCharCode(buf[i]);
                        }
                        return out;
                    },
                };
        function decode(mappings) {
            const state = new Int32Array(5);
            const decoded = [];
            let index = 0;
            do {
                const semi = indexOf(mappings, index);
                const line = [];
                let sorted = true;
                let lastCol = 0;
                state[0] = 0;
                for (let i = index; i < semi; i++) {
                    let seg;
                    i = decodeInteger(mappings, i, state, 0); // genColumn
                    const col = state[0];
                    if (col < lastCol)
                        sorted = false;
                    lastCol = col;
                    if (hasMoreVlq(mappings, i, semi)) {
                        i = decodeInteger(mappings, i, state, 1); // sourcesIndex
                        i = decodeInteger(mappings, i, state, 2); // sourceLine
                        i = decodeInteger(mappings, i, state, 3); // sourceColumn
                        if (hasMoreVlq(mappings, i, semi)) {
                            i = decodeInteger(mappings, i, state, 4); // namesIndex
                            seg = [col, state[1], state[2], state[3], state[4]];
                        }
                        else {
                            seg = [col, state[1], state[2], state[3]];
                        }
                    }
                    else {
                        seg = [col];
                    }
                    line.push(seg);
                }
                if (!sorted)
                    sort(line);
                decoded.push(line);
                index = semi + 1;
            } while (index <= mappings.length);
            return decoded;
        }
        function indexOf(mappings, index) {
            const idx = mappings.indexOf(';', index);
            return idx === -1 ? mappings.length : idx;
        }
        function decodeInteger(mappings, pos, state, j) {
            let value = 0;
            let shift = 0;
            let integer = 0;
            do {
                const c = mappings.charCodeAt(pos++);
                integer = charToInt[c];
                value |= (integer & 31) << shift;
                shift += 5;
            } while (integer & 32);
            const shouldNegate = value & 1;
            value >>>= 1;
            if (shouldNegate) {
                value = -0x80000000 | -value;
            }
            state[j] += value;
            return pos;
        }
        function hasMoreVlq(mappings, i, length) {
            if (i >= length)
                return false;
            return mappings.charCodeAt(i) !== comma;
        }
        function sort(line) {
            line.sort(sortComparator);
        }
        function sortComparator(a, b) {
            return a[0] - b[0];
        }
        function encode(decoded) {
            const state = new Int32Array(5);
            const bufLength = 1024 * 16;
            const subLength = bufLength - 36;
            const buf = new Uint8Array(bufLength);
            const sub = buf.subarray(0, subLength);
            let pos = 0;
            let out = '';
            for (let i = 0; i < decoded.length; i++) {
                const line = decoded[i];
                if (i > 0) {
                    if (pos === bufLength) {
                        out += td.decode(buf);
                        pos = 0;
                    }
                    buf[pos++] = semicolon;
                }
                if (line.length === 0)
                    continue;
                state[0] = 0;
                for (let j = 0; j < line.length; j++) {
                    const segment = line[j];
                    // We can push up to 5 ints, each int can take at most 7 chars, and we
                    // may push a comma.
                    if (pos > subLength) {
                        out += td.decode(sub);
                        buf.copyWithin(0, subLength, pos);
                        pos -= subLength;
                    }
                    if (j > 0)
                        buf[pos++] = comma;
                    pos = encodeInteger(buf, pos, state, segment, 0); // genColumn
                    if (segment.length === 1)
                        continue;
                    pos = encodeInteger(buf, pos, state, segment, 1); // sourcesIndex
                    pos = encodeInteger(buf, pos, state, segment, 2); // sourceLine
                    pos = encodeInteger(buf, pos, state, segment, 3); // sourceColumn
                    if (segment.length === 4)
                        continue;
                    pos = encodeInteger(buf, pos, state, segment, 4); // namesIndex
                }
            }
            return out + td.decode(buf.subarray(0, pos));
        }
        function encodeInteger(buf, pos, state, segment, j) {
            const next = segment[j];
            let num = next - state[j];
            state[j] = next;
            num = num < 0 ? (-num << 1) | 1 : num << 1;
            do {
                let clamped = num & 0b011111;
                num >>>= 5;
                if (num > 0)
                    clamped |= 0b100000;
                buf[pos++] = intToChar[clamped];
            } while (num > 0);
            return pos;
        }
        exports.decode = decode;
        exports.encode = encode;
        Object.defineProperty(exports, '__esModule', { value: true });
    }));
    
},
/* @jridgewell/resolve-uri/dist/resolve-uri.umd.js */ function _(require, module, exports, __esModule, __esExport) {
    (function (global, factory) {
        typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
            typeof define === 'function' && define.amd ? define(factory) :
                (global = typeof globalThis !== 'undefined' ? globalThis : global || self, global.resolveURI = factory());
    })(this, (function () {
        'use strict';
        // Matches the scheme of a URL, eg "http://"
        const schemeRegex = /^[\w+.-]+:\/\//;
        /**
         * Matches the parts of a URL:
         * 1. Scheme, including ":", guaranteed.
         * 2. User/password, including "@", optional.
         * 3. Host, guaranteed.
         * 4. Port, including ":", optional.
         * 5. Path, including "/", optional.
         * 6. Query, including "?", optional.
         * 7. Hash, including "#", optional.
         */
        const urlRegex = /^([\w+.-]+:)\/\/([^@/#?]*@)?([^:/#?]*)(:\d+)?(\/[^#?]*)?(\?[^#]*)?(#.*)?/;
        /**
         * File URLs are weird. They dont' need the regular `//` in the scheme, they may or may not start
         * with a leading `/`, they can have a domain (but only if they don't start with a Windows drive).
         *
         * 1. Host, optional.
         * 2. Path, which may include "/", guaranteed.
         * 3. Query, including "?", optional.
         * 4. Hash, including "#", optional.
         */
        const fileRegex = /^file:(?:\/\/((?![a-z]:)[^/#?]*)?)?(\/?[^#?]*)(\?[^#]*)?(#.*)?/i;
        function isAbsoluteUrl(input) {
            return schemeRegex.test(input);
        }
        function isSchemeRelativeUrl(input) {
            return input.startsWith('//');
        }
        function isAbsolutePath(input) {
            return input.startsWith('/');
        }
        function isFileUrl(input) {
            return input.startsWith('file:');
        }
        function isRelative(input) {
            return /^[.?#]/.test(input);
        }
        function parseAbsoluteUrl(input) {
            const match = urlRegex.exec(input);
            return makeUrl(match[1], match[2] || '', match[3], match[4] || '', match[5] || '/', match[6] || '', match[7] || '');
        }
        function parseFileUrl(input) {
            const match = fileRegex.exec(input);
            const path = match[2];
            return makeUrl('file:', '', match[1] || '', '', isAbsolutePath(path) ? path : '/' + path, match[3] || '', match[4] || '');
        }
        function makeUrl(scheme, user, host, port, path, query, hash) {
            return {
                scheme,
                user,
                host,
                port,
                path,
                query,
                hash,
                type: 7 /* Absolute */,
            };
        }
        function parseUrl(input) {
            if (isSchemeRelativeUrl(input)) {
                const url = parseAbsoluteUrl('http:' + input);
                url.scheme = '';
                url.type = 6 /* SchemeRelative */;
                return url;
            }
            if (isAbsolutePath(input)) {
                const url = parseAbsoluteUrl('http://foo.com' + input);
                url.scheme = '';
                url.host = '';
                url.type = 5 /* AbsolutePath */;
                return url;
            }
            if (isFileUrl(input))
                return parseFileUrl(input);
            if (isAbsoluteUrl(input))
                return parseAbsoluteUrl(input);
            const url = parseAbsoluteUrl('http://foo.com/' + input);
            url.scheme = '';
            url.host = '';
            url.type = input
                ? input.startsWith('?')
                    ? 3 /* Query */
                    : input.startsWith('#')
                        ? 2 /* Hash */
                        : 4 /* RelativePath */
                : 1 /* Empty */;
            return url;
        }
        function stripPathFilename(path) {
            // If a path ends with a parent directory "..", then it's a relative path with excess parent
            // paths. It's not a file, so we can't strip it.
            if (path.endsWith('/..'))
                return path;
            const index = path.lastIndexOf('/');
            return path.slice(0, index + 1);
        }
        function mergePaths(url, base) {
            normalizePath(base, base.type);
            // If the path is just a "/", then it was an empty path to begin with (remember, we're a relative
            // path).
            if (url.path === '/') {
                url.path = base.path;
            }
            else {
                // Resolution happens relative to the base path's directory, not the file.
                url.path = stripPathFilename(base.path) + url.path;
            }
        }
        /**
         * The path can have empty directories "//", unneeded parents "foo/..", or current directory
         * "foo/.". We need to normalize to a standard representation.
         */
        function normalizePath(url, type) {
            const rel = type <= 4 /* RelativePath */;
            const pieces = url.path.split('/');
            // We need to preserve the first piece always, so that we output a leading slash. The item at
            // pieces[0] is an empty string.
            let pointer = 1;
            // Positive is the number of real directories we've output, used for popping a parent directory.
            // Eg, "foo/bar/.." will have a positive 2, and we can decrement to be left with just "foo".
            let positive = 0;
            // We need to keep a trailing slash if we encounter an empty directory (eg, splitting "foo/" will
            // generate `["foo", ""]` pieces). And, if we pop a parent directory. But once we encounter a
            // real directory, we won't need to append, unless the other conditions happen again.
            let addTrailingSlash = false;
            for (let i = 1; i < pieces.length; i++) {
                const piece = pieces[i];
                // An empty directory, could be a trailing slash, or just a double "//" in the path.
                if (!piece) {
                    addTrailingSlash = true;
                    continue;
                }
                // If we encounter a real directory, then we don't need to append anymore.
                addTrailingSlash = false;
                // A current directory, which we can always drop.
                if (piece === '.')
                    continue;
                // A parent directory, we need to see if there are any real directories we can pop. Else, we
                // have an excess of parents, and we'll need to keep the "..".
                if (piece === '..') {
                    if (positive) {
                        addTrailingSlash = true;
                        positive--;
                        pointer--;
                    }
                    else if (rel) {
                        // If we're in a relativePath, then we need to keep the excess parents. Else, in an absolute
                        // URL, protocol relative URL, or an absolute path, we don't need to keep excess.
                        pieces[pointer++] = piece;
                    }
                    continue;
                }
                // We've encountered a real directory. Move it to the next insertion pointer, which accounts for
                // any popped or dropped directories.
                pieces[pointer++] = piece;
                positive++;
            }
            let path = '';
            for (let i = 1; i < pointer; i++) {
                path += '/' + pieces[i];
            }
            if (!path || (addTrailingSlash && !path.endsWith('/..'))) {
                path += '/';
            }
            url.path = path;
        }
        /**
         * Attempts to resolve `input` URL/path relative to `base`.
         */
        function resolve(input, base) {
            if (!input && !base)
                return '';
            const url = parseUrl(input);
            let inputType = url.type;
            if (base && inputType !== 7 /* Absolute */) {
                const baseUrl = parseUrl(base);
                const baseType = baseUrl.type;
                switch (inputType) {
                    case 1 /* Empty */:
                        url.hash = baseUrl.hash;
                    // fall through
                    case 2 /* Hash */:
                        url.query = baseUrl.query;
                    // fall through
                    case 3 /* Query */:
                    case 4 /* RelativePath */:
                        mergePaths(url, baseUrl);
                    // fall through
                    case 5 /* AbsolutePath */:
                        // The host, user, and port are joined, you can't copy one without the others.
                        url.user = baseUrl.user;
                        url.host = baseUrl.host;
                        url.port = baseUrl.port;
                    // fall through
                    case 6 /* SchemeRelative */:
                        // The input doesn't have a schema at least, so we need to copy at least that over.
                        url.scheme = baseUrl.scheme;
                }
                if (baseType > inputType)
                    inputType = baseType;
            }
            normalizePath(url, inputType);
            const queryHash = url.query + url.hash;
            switch (inputType) {
                // This is impossible, because of the empty checks at the start of the function.
                // case UrlType.Empty:
                case 2 /* Hash */:
                case 3 /* Query */:
                    return queryHash;
                case 4 /* RelativePath */: {
                    // The first char is always a "/", and we need it to be relative.
                    const path = url.path.slice(1);
                    if (!path)
                        return queryHash || '.';
                    if (isRelative(base || input) && !isRelative(path)) {
                        // If base started with a leading ".", or there is no base and input started with a ".",
                        // then we need to ensure that the relative path starts with a ".". We don't know if
                        // relative starts with a "..", though, so check before prepending.
                        return './' + path + queryHash;
                    }
                    return path + queryHash;
                }
                case 5 /* AbsolutePath */:
                    return url.path + queryHash;
                default:
                    return url.scheme + '//' + url.user + url.host + url.port + url.path + queryHash;
            }
        }
        return resolve;
    }));
    
},
/* @jridgewell/gen-mapping/dist/gen-mapping.umd.js */ function _(require, module, exports, __esModule, __esExport) {
    (function (global, factory) {
        typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require(51) /* @jridgewell/set-array */, require(48) /* @jridgewell/sourcemap-codec */, require(47) /* @jridgewell/trace-mapping */) :
            typeof define === 'function' && define.amd ? define(['exports', '@jridgewell/set-array', '@jridgewell/sourcemap-codec', '@jridgewell/trace-mapping'], factory) :
                (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.genMapping = {}, global.setArray, global.sourcemapCodec, global.traceMapping));
    })(this, (function (exports, setArray, sourcemapCodec, traceMapping) {
        'use strict';
        const COLUMN = 0;
        const SOURCES_INDEX = 1;
        const SOURCE_LINE = 2;
        const SOURCE_COLUMN = 3;
        const NAMES_INDEX = 4;
        const NO_NAME = -1;
        /**
         * Provides the state to generate a sourcemap.
         */
        class GenMapping {
            constructor({ file, sourceRoot } = {}) {
                this._names = new setArray.SetArray();
                this._sources = new setArray.SetArray();
                this._sourcesContent = [];
                this._mappings = [];
                this.file = file;
                this.sourceRoot = sourceRoot;
                this._ignoreList = new setArray.SetArray();
            }
        }
        /**
         * Typescript doesn't allow friend access to private fields, so this just casts the map into a type
         * with public access modifiers.
         */
        function cast(map) {
            return map;
        }
        function addSegment(map, genLine, genColumn, source, sourceLine, sourceColumn, name, content) {
            return addSegmentInternal(false, map, genLine, genColumn, source, sourceLine, sourceColumn, name, content);
        }
        function addMapping(map, mapping) {
            return addMappingInternal(false, map, mapping);
        }
        /**
         * Same as `addSegment`, but will only add the segment if it generates useful information in the
         * resulting map. This only works correctly if segments are added **in order**, meaning you should
         * not add a segment with a lower generated line/column than one that came before.
         */
        const maybeAddSegment = (map, genLine, genColumn, source, sourceLine, sourceColumn, name, content) => {
            return addSegmentInternal(true, map, genLine, genColumn, source, sourceLine, sourceColumn, name, content);
        };
        /**
         * Same as `addMapping`, but will only add the mapping if it generates useful information in the
         * resulting map. This only works correctly if mappings are added **in order**, meaning you should
         * not add a mapping with a lower generated line/column than one that came before.
         */
        const maybeAddMapping = (map, mapping) => {
            return addMappingInternal(true, map, mapping);
        };
        /**
         * Adds/removes the content of the source file to the source map.
         */
        function setSourceContent(map, source, content) {
            const { _sources: sources, _sourcesContent: sourcesContent } = cast(map);
            const index = setArray.put(sources, source);
            sourcesContent[index] = content;
        }
        function setIgnore(map, source, ignore = true) {
            const { _sources: sources, _sourcesContent: sourcesContent, _ignoreList: ignoreList } = cast(map);
            const index = setArray.put(sources, source);
            if (index === sourcesContent.length)
                sourcesContent[index] = null;
            if (ignore)
                setArray.put(ignoreList, index);
            else
                setArray.remove(ignoreList, index);
        }
        /**
         * Returns a sourcemap object (with decoded mappings) suitable for passing to a library that expects
         * a sourcemap, or to JSON.stringify.
         */
        function toDecodedMap(map) {
            const { _mappings: mappings, _sources: sources, _sourcesContent: sourcesContent, _names: names, _ignoreList: ignoreList, } = cast(map);
            removeEmptyFinalLines(mappings);
            return {
                version: 3,
                file: map.file || undefined,
                names: names.array,
                sourceRoot: map.sourceRoot || undefined,
                sources: sources.array,
                sourcesContent,
                mappings,
                ignoreList: ignoreList.array,
            };
        }
        /**
         * Returns a sourcemap object (with encoded mappings) suitable for passing to a library that expects
         * a sourcemap, or to JSON.stringify.
         */
        function toEncodedMap(map) {
            const decoded = toDecodedMap(map);
            return Object.assign(Object.assign({}, decoded), { mappings: sourcemapCodec.encode(decoded.mappings) });
        }
        /**
         * Constructs a new GenMapping, using the already present mappings of the input.
         */
        function fromMap(input) {
            const map = new traceMapping.TraceMap(input);
            const gen = new GenMapping({ file: map.file, sourceRoot: map.sourceRoot });
            putAll(cast(gen)._names, map.names);
            putAll(cast(gen)._sources, map.sources);
            cast(gen)._sourcesContent = map.sourcesContent || map.sources.map(() => null);
            cast(gen)._mappings = traceMapping.decodedMappings(map);
            if (map.ignoreList)
                putAll(cast(gen)._ignoreList, map.ignoreList);
            return gen;
        }
        /**
         * Returns an array of high-level mapping objects for every recorded segment, which could then be
         * passed to the `source-map` library.
         */
        function allMappings(map) {
            const out = [];
            const { _mappings: mappings, _sources: sources, _names: names } = cast(map);
            for (let i = 0; i < mappings.length; i++) {
                const line = mappings[i];
                for (let j = 0; j < line.length; j++) {
                    const seg = line[j];
                    const generated = { line: i + 1, column: seg[COLUMN] };
                    let source = undefined;
                    let original = undefined;
                    let name = undefined;
                    if (seg.length !== 1) {
                        source = sources.array[seg[SOURCES_INDEX]];
                        original = { line: seg[SOURCE_LINE] + 1, column: seg[SOURCE_COLUMN] };
                        if (seg.length === 5)
                            name = names.array[seg[NAMES_INDEX]];
                    }
                    out.push({ generated, source, original, name });
                }
            }
            return out;
        }
        // This split declaration is only so that terser can elminiate the static initialization block.
        function addSegmentInternal(skipable, map, genLine, genColumn, source, sourceLine, sourceColumn, name, content) {
            const { _mappings: mappings, _sources: sources, _sourcesContent: sourcesContent, _names: names, } = cast(map);
            const line = getLine(mappings, genLine);
            const index = getColumnIndex(line, genColumn);
            if (!source) {
                if (skipable && skipSourceless(line, index))
                    return;
                return insert(line, index, [genColumn]);
            }
            const sourcesIndex = setArray.put(sources, source);
            const namesIndex = name ? setArray.put(names, name) : NO_NAME;
            if (sourcesIndex === sourcesContent.length)
                sourcesContent[sourcesIndex] = content !== null && content !== void 0 ? content : null;
            if (skipable && skipSource(line, index, sourcesIndex, sourceLine, sourceColumn, namesIndex)) {
                return;
            }
            return insert(line, index, name
                ? [genColumn, sourcesIndex, sourceLine, sourceColumn, namesIndex]
                : [genColumn, sourcesIndex, sourceLine, sourceColumn]);
        }
        function getLine(mappings, index) {
            for (let i = mappings.length; i <= index; i++) {
                mappings[i] = [];
            }
            return mappings[index];
        }
        function getColumnIndex(line, genColumn) {
            let index = line.length;
            for (let i = index - 1; i >= 0; index = i--) {
                const current = line[i];
                if (genColumn >= current[COLUMN])
                    break;
            }
            return index;
        }
        function insert(array, index, value) {
            for (let i = array.length; i > index; i--) {
                array[i] = array[i - 1];
            }
            array[index] = value;
        }
        function removeEmptyFinalLines(mappings) {
            const { length } = mappings;
            let len = length;
            for (let i = len - 1; i >= 0; len = i, i--) {
                if (mappings[i].length > 0)
                    break;
            }
            if (len < length)
                mappings.length = len;
        }
        function putAll(setarr, array) {
            for (let i = 0; i < array.length; i++)
                setArray.put(setarr, array[i]);
        }
        function skipSourceless(line, index) {
            // The start of a line is already sourceless, so adding a sourceless segment to the beginning
            // doesn't generate any useful information.
            if (index === 0)
                return true;
            const prev = line[index - 1];
            // If the previous segment is also sourceless, then adding another sourceless segment doesn't
            // genrate any new information. Else, this segment will end the source/named segment and point to
            // a sourceless position, which is useful.
            return prev.length === 1;
        }
        function skipSource(line, index, sourcesIndex, sourceLine, sourceColumn, namesIndex) {
            // A source/named segment at the start of a line gives position at that genColumn
            if (index === 0)
                return false;
            const prev = line[index - 1];
            // If the previous segment is sourceless, then we're transitioning to a source.
            if (prev.length === 1)
                return false;
            // If the previous segment maps to the exact same source position, then this segment doesn't
            // provide any new position information.
            return (sourcesIndex === prev[SOURCES_INDEX] &&
                sourceLine === prev[SOURCE_LINE] &&
                sourceColumn === prev[SOURCE_COLUMN] &&
                namesIndex === (prev.length === 5 ? prev[NAMES_INDEX] : NO_NAME));
        }
        function addMappingInternal(skipable, map, mapping) {
            const { generated, source, original, name, content } = mapping;
            if (!source) {
                return addSegmentInternal(skipable, map, generated.line - 1, generated.column, null, null, null, null, null);
            }
            return addSegmentInternal(skipable, map, generated.line - 1, generated.column, source, original.line - 1, original.column, name, content);
        }
        exports.GenMapping = GenMapping;
        exports.addMapping = addMapping;
        exports.addSegment = addSegment;
        exports.allMappings = allMappings;
        exports.fromMap = fromMap;
        exports.maybeAddMapping = maybeAddMapping;
        exports.maybeAddSegment = maybeAddSegment;
        exports.setIgnore = setIgnore;
        exports.setSourceContent = setSourceContent;
        exports.toDecodedMap = toDecodedMap;
        exports.toEncodedMap = toEncodedMap;
        Object.defineProperty(exports, '__esModule', { value: true });
    }));
    
},
/* @jridgewell/set-array/dist/set-array.umd.js */ function _(require, module, exports, __esModule, __esExport) {
    (function (global, factory) {
        typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
            typeof define === 'function' && define.amd ? define(['exports'], factory) :
                (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.setArray = {}));
    })(this, (function (exports) {
        'use strict';
        /**
         * SetArray acts like a `Set` (allowing only one occurrence of a string `key`), but provides the
         * index of the `key` in the backing array.
         *
         * This is designed to allow synchronizing a second array with the contents of the backing array,
         * like how in a sourcemap `sourcesContent[i]` is the source content associated with `source[i]`,
         * and there are never duplicates.
         */
        class SetArray {
            constructor() {
                this._indexes = { __proto__: null };
                this.array = [];
            }
        }
        /**
         * Typescript doesn't allow friend access to private fields, so this just casts the set into a type
         * with public access modifiers.
         */
        function cast(set) {
            return set;
        }
        /**
         * Gets the index associated with `key` in the backing array, if it is already present.
         */
        function get(setarr, key) {
            return cast(setarr)._indexes[key];
        }
        /**
         * Puts `key` into the backing array, if it is not already present. Returns
         * the index of the `key` in the backing array.
         */
        function put(setarr, key) {
            // The key may or may not be present. If it is present, it's a number.
            const index = get(setarr, key);
            if (index !== undefined)
                return index;
            const { array, _indexes: indexes } = cast(setarr);
            const length = array.push(key);
            return (indexes[key] = length - 1);
        }
        /**
         * Pops the last added item out of the SetArray.
         */
        function pop(setarr) {
            const { array, _indexes: indexes } = cast(setarr);
            if (array.length === 0)
                return;
            const last = array.pop();
            indexes[last] = undefined;
        }
        /**
         * Removes the key, if it exists in the set.
         */
        function remove(setarr, key) {
            const index = get(setarr, key);
            if (index === undefined)
                return;
            const { array, _indexes: indexes } = cast(setarr);
            for (let i = index + 1; i < array.length; i++) {
                const k = array[i];
                array[i - 1] = k;
                indexes[k]--;
            }
            indexes[key] = undefined;
            array.pop();
        }
        exports.SetArray = SetArray;
        exports.get = get;
        exports.pop = pop;
        exports.put = put;
        exports.remove = remove;
        Object.defineProperty(exports, '__esModule', { value: true });
    }));
    
},
/* acorn/dist/acorn.js */ function _(require, module, exports, __esModule, __esExport) {
    (function (global, factory) {
        typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
            typeof define === 'function' && define.amd ? define(['exports'], factory) :
                (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.acorn = {}));
    })(this, (function (exports) {
        'use strict';
        // This file was generated. Do not modify manually!
        var astralIdentifierCodes = [509, 0, 227, 0, 150, 4, 294, 9, 1368, 2, 2, 1, 6, 3, 41, 2, 5, 0, 166, 1, 574, 3, 9, 9, 370, 1, 81, 2, 71, 10, 50, 3, 123, 2, 54, 14, 32, 10, 3, 1, 11, 3, 46, 10, 8, 0, 46, 9, 7, 2, 37, 13, 2, 9, 6, 1, 45, 0, 13, 2, 49, 13, 9, 3, 2, 11, 83, 11, 7, 0, 3, 0, 158, 11, 6, 9, 7, 3, 56, 1, 2, 6, 3, 1, 3, 2, 10, 0, 11, 1, 3, 6, 4, 4, 193, 17, 10, 9, 5, 0, 82, 19, 13, 9, 214, 6, 3, 8, 28, 1, 83, 16, 16, 9, 82, 12, 9, 9, 84, 14, 5, 9, 243, 14, 166, 9, 71, 5, 2, 1, 3, 3, 2, 0, 2, 1, 13, 9, 120, 6, 3, 6, 4, 0, 29, 9, 41, 6, 2, 3, 9, 0, 10, 10, 47, 15, 406, 7, 2, 7, 17, 9, 57, 21, 2, 13, 123, 5, 4, 0, 2, 1, 2, 6, 2, 0, 9, 9, 49, 4, 2, 1, 2, 4, 9, 9, 330, 3, 10, 1, 2, 0, 49, 6, 4, 4, 14, 9, 5351, 0, 7, 14, 13835, 9, 87, 9, 39, 4, 60, 6, 26, 9, 1014, 0, 2, 54, 8, 3, 82, 0, 12, 1, 19628, 1, 4706, 45, 3, 22, 543, 4, 4, 5, 9, 7, 3, 6, 31, 3, 149, 2, 1418, 49, 513, 54, 5, 49, 9, 0, 15, 0, 23, 4, 2, 14, 1361, 6, 2, 16, 3, 6, 2, 1, 2, 4, 101, 0, 161, 6, 10, 9, 357, 0, 62, 13, 499, 13, 983, 6, 110, 6, 6, 9, 4759, 9, 787719, 239];
        // This file was generated. Do not modify manually!
        var astralIdentifierStartCodes = [0, 11, 2, 25, 2, 18, 2, 1, 2, 14, 3, 13, 35, 122, 70, 52, 268, 28, 4, 48, 48, 31, 14, 29, 6, 37, 11, 29, 3, 35, 5, 7, 2, 4, 43, 157, 19, 35, 5, 35, 5, 39, 9, 51, 13, 10, 2, 14, 2, 6, 2, 1, 2, 10, 2, 14, 2, 6, 2, 1, 68, 310, 10, 21, 11, 7, 25, 5, 2, 41, 2, 8, 70, 5, 3, 0, 2, 43, 2, 1, 4, 0, 3, 22, 11, 22, 10, 30, 66, 18, 2, 1, 11, 21, 11, 25, 71, 55, 7, 1, 65, 0, 16, 3, 2, 2, 2, 28, 43, 28, 4, 28, 36, 7, 2, 27, 28, 53, 11, 21, 11, 18, 14, 17, 111, 72, 56, 50, 14, 50, 14, 35, 349, 41, 7, 1, 79, 28, 11, 0, 9, 21, 43, 17, 47, 20, 28, 22, 13, 52, 58, 1, 3, 0, 14, 44, 33, 24, 27, 35, 30, 0, 3, 0, 9, 34, 4, 0, 13, 47, 15, 3, 22, 0, 2, 0, 36, 17, 2, 24, 20, 1, 64, 6, 2, 0, 2, 3, 2, 14, 2, 9, 8, 46, 39, 7, 3, 1, 3, 21, 2, 6, 2, 1, 2, 4, 4, 0, 19, 0, 13, 4, 159, 52, 19, 3, 21, 2, 31, 47, 21, 1, 2, 0, 185, 46, 42, 3, 37, 47, 21, 0, 60, 42, 14, 0, 72, 26, 38, 6, 186, 43, 117, 63, 32, 7, 3, 0, 3, 7, 2, 1, 2, 23, 16, 0, 2, 0, 95, 7, 3, 38, 17, 0, 2, 0, 29, 0, 11, 39, 8, 0, 22, 0, 12, 45, 20, 0, 19, 72, 264, 8, 2, 36, 18, 0, 50, 29, 113, 6, 2, 1, 2, 37, 22, 0, 26, 5, 2, 1, 2, 31, 15, 0, 328, 18, 16, 0, 2, 12, 2, 33, 125, 0, 80, 921, 103, 110, 18, 195, 2637, 96, 16, 1071, 18, 5, 4026, 582, 8634, 568, 8, 30, 18, 78, 18, 29, 19, 47, 17, 3, 32, 20, 6, 18, 689, 63, 129, 74, 6, 0, 67, 12, 65, 1, 2, 0, 29, 6135, 9, 1237, 43, 8, 8936, 3, 2, 6, 2, 1, 2, 290, 16, 0, 30, 2, 3, 0, 15, 3, 9, 395, 2309, 106, 6, 12, 4, 8, 8, 9, 5991, 84, 2, 70, 2, 1, 3, 0, 3, 1, 3, 3, 2, 11, 2, 0, 2, 6, 2, 64, 2, 3, 3, 7, 2, 6, 2, 27, 2, 3, 2, 4, 2, 0, 4, 6, 2, 339, 3, 24, 2, 24, 2, 30, 2, 24, 2, 30, 2, 24, 2, 30, 2, 24, 2, 30, 2, 24, 2, 7, 1845, 30, 7, 5, 262, 61, 147, 44, 11, 6, 17, 0, 322, 29, 19, 43, 485, 27, 757, 6, 2, 3, 2, 1, 2, 14, 2, 196, 60, 67, 8, 0, 1205, 3, 2, 26, 2, 1, 2, 0, 3, 0, 2, 9, 2, 3, 2, 0, 2, 0, 7, 0, 5, 0, 2, 0, 2, 0, 2, 2, 2, 1, 2, 0, 3, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 1, 2, 0, 3, 3, 2, 6, 2, 3, 2, 3, 2, 0, 2, 9, 2, 16, 6, 2, 2, 4, 2, 16, 4421, 42719, 33, 4153, 7, 221, 3, 5761, 15, 7472, 16, 621, 2467, 541, 1507, 4938, 6, 4191];
        // This file was generated. Do not modify manually!
        var nonASCIIidentifierChars = "\u200c\u200d\xb7\u0300-\u036f\u0387\u0483-\u0487\u0591-\u05bd\u05bf\u05c1\u05c2\u05c4\u05c5\u05c7\u0610-\u061a\u064b-\u0669\u0670\u06d6-\u06dc\u06df-\u06e4\u06e7\u06e8\u06ea-\u06ed\u06f0-\u06f9\u0711\u0730-\u074a\u07a6-\u07b0\u07c0-\u07c9\u07eb-\u07f3\u07fd\u0816-\u0819\u081b-\u0823\u0825-\u0827\u0829-\u082d\u0859-\u085b\u0898-\u089f\u08ca-\u08e1\u08e3-\u0903\u093a-\u093c\u093e-\u094f\u0951-\u0957\u0962\u0963\u0966-\u096f\u0981-\u0983\u09bc\u09be-\u09c4\u09c7\u09c8\u09cb-\u09cd\u09d7\u09e2\u09e3\u09e6-\u09ef\u09fe\u0a01-\u0a03\u0a3c\u0a3e-\u0a42\u0a47\u0a48\u0a4b-\u0a4d\u0a51\u0a66-\u0a71\u0a75\u0a81-\u0a83\u0abc\u0abe-\u0ac5\u0ac7-\u0ac9\u0acb-\u0acd\u0ae2\u0ae3\u0ae6-\u0aef\u0afa-\u0aff\u0b01-\u0b03\u0b3c\u0b3e-\u0b44\u0b47\u0b48\u0b4b-\u0b4d\u0b55-\u0b57\u0b62\u0b63\u0b66-\u0b6f\u0b82\u0bbe-\u0bc2\u0bc6-\u0bc8\u0bca-\u0bcd\u0bd7\u0be6-\u0bef\u0c00-\u0c04\u0c3c\u0c3e-\u0c44\u0c46-\u0c48\u0c4a-\u0c4d\u0c55\u0c56\u0c62\u0c63\u0c66-\u0c6f\u0c81-\u0c83\u0cbc\u0cbe-\u0cc4\u0cc6-\u0cc8\u0cca-\u0ccd\u0cd5\u0cd6\u0ce2\u0ce3\u0ce6-\u0cef\u0cf3\u0d00-\u0d03\u0d3b\u0d3c\u0d3e-\u0d44\u0d46-\u0d48\u0d4a-\u0d4d\u0d57\u0d62\u0d63\u0d66-\u0d6f\u0d81-\u0d83\u0dca\u0dcf-\u0dd4\u0dd6\u0dd8-\u0ddf\u0de6-\u0def\u0df2\u0df3\u0e31\u0e34-\u0e3a\u0e47-\u0e4e\u0e50-\u0e59\u0eb1\u0eb4-\u0ebc\u0ec8-\u0ece\u0ed0-\u0ed9\u0f18\u0f19\u0f20-\u0f29\u0f35\u0f37\u0f39\u0f3e\u0f3f\u0f71-\u0f84\u0f86\u0f87\u0f8d-\u0f97\u0f99-\u0fbc\u0fc6\u102b-\u103e\u1040-\u1049\u1056-\u1059\u105e-\u1060\u1062-\u1064\u1067-\u106d\u1071-\u1074\u1082-\u108d\u108f-\u109d\u135d-\u135f\u1369-\u1371\u1712-\u1715\u1732-\u1734\u1752\u1753\u1772\u1773\u17b4-\u17d3\u17dd\u17e0-\u17e9\u180b-\u180d\u180f-\u1819\u18a9\u1920-\u192b\u1930-\u193b\u1946-\u194f\u19d0-\u19da\u1a17-\u1a1b\u1a55-\u1a5e\u1a60-\u1a7c\u1a7f-\u1a89\u1a90-\u1a99\u1ab0-\u1abd\u1abf-\u1ace\u1b00-\u1b04\u1b34-\u1b44\u1b50-\u1b59\u1b6b-\u1b73\u1b80-\u1b82\u1ba1-\u1bad\u1bb0-\u1bb9\u1be6-\u1bf3\u1c24-\u1c37\u1c40-\u1c49\u1c50-\u1c59\u1cd0-\u1cd2\u1cd4-\u1ce8\u1ced\u1cf4\u1cf7-\u1cf9\u1dc0-\u1dff\u200c\u200d\u203f\u2040\u2054\u20d0-\u20dc\u20e1\u20e5-\u20f0\u2cef-\u2cf1\u2d7f\u2de0-\u2dff\u302a-\u302f\u3099\u309a\u30fb\ua620-\ua629\ua66f\ua674-\ua67d\ua69e\ua69f\ua6f0\ua6f1\ua802\ua806\ua80b\ua823-\ua827\ua82c\ua880\ua881\ua8b4-\ua8c5\ua8d0-\ua8d9\ua8e0-\ua8f1\ua8ff-\ua909\ua926-\ua92d\ua947-\ua953\ua980-\ua983\ua9b3-\ua9c0\ua9d0-\ua9d9\ua9e5\ua9f0-\ua9f9\uaa29-\uaa36\uaa43\uaa4c\uaa4d\uaa50-\uaa59\uaa7b-\uaa7d\uaab0\uaab2-\uaab4\uaab7\uaab8\uaabe\uaabf\uaac1\uaaeb-\uaaef\uaaf5\uaaf6\uabe3-\uabea\uabec\uabed\uabf0-\uabf9\ufb1e\ufe00-\ufe0f\ufe20-\ufe2f\ufe33\ufe34\ufe4d-\ufe4f\uff10-\uff19\uff3f\uff65";
        // This file was generated. Do not modify manually!
        var nonASCIIidentifierStartChars = "\xaa\xb5\xba\xc0-\xd6\xd8-\xf6\xf8-\u02c1\u02c6-\u02d1\u02e0-\u02e4\u02ec\u02ee\u0370-\u0374\u0376\u0377\u037a-\u037d\u037f\u0386\u0388-\u038a\u038c\u038e-\u03a1\u03a3-\u03f5\u03f7-\u0481\u048a-\u052f\u0531-\u0556\u0559\u0560-\u0588\u05d0-\u05ea\u05ef-\u05f2\u0620-\u064a\u066e\u066f\u0671-\u06d3\u06d5\u06e5\u06e6\u06ee\u06ef\u06fa-\u06fc\u06ff\u0710\u0712-\u072f\u074d-\u07a5\u07b1\u07ca-\u07ea\u07f4\u07f5\u07fa\u0800-\u0815\u081a\u0824\u0828\u0840-\u0858\u0860-\u086a\u0870-\u0887\u0889-\u088e\u08a0-\u08c9\u0904-\u0939\u093d\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098c\u098f\u0990\u0993-\u09a8\u09aa-\u09b0\u09b2\u09b6-\u09b9\u09bd\u09ce\u09dc\u09dd\u09df-\u09e1\u09f0\u09f1\u09fc\u0a05-\u0a0a\u0a0f\u0a10\u0a13-\u0a28\u0a2a-\u0a30\u0a32\u0a33\u0a35\u0a36\u0a38\u0a39\u0a59-\u0a5c\u0a5e\u0a72-\u0a74\u0a85-\u0a8d\u0a8f-\u0a91\u0a93-\u0aa8\u0aaa-\u0ab0\u0ab2\u0ab3\u0ab5-\u0ab9\u0abd\u0ad0\u0ae0\u0ae1\u0af9\u0b05-\u0b0c\u0b0f\u0b10\u0b13-\u0b28\u0b2a-\u0b30\u0b32\u0b33\u0b35-\u0b39\u0b3d\u0b5c\u0b5d\u0b5f-\u0b61\u0b71\u0b83\u0b85-\u0b8a\u0b8e-\u0b90\u0b92-\u0b95\u0b99\u0b9a\u0b9c\u0b9e\u0b9f\u0ba3\u0ba4\u0ba8-\u0baa\u0bae-\u0bb9\u0bd0\u0c05-\u0c0c\u0c0e-\u0c10\u0c12-\u0c28\u0c2a-\u0c39\u0c3d\u0c58-\u0c5a\u0c5d\u0c60\u0c61\u0c80\u0c85-\u0c8c\u0c8e-\u0c90\u0c92-\u0ca8\u0caa-\u0cb3\u0cb5-\u0cb9\u0cbd\u0cdd\u0cde\u0ce0\u0ce1\u0cf1\u0cf2\u0d04-\u0d0c\u0d0e-\u0d10\u0d12-\u0d3a\u0d3d\u0d4e\u0d54-\u0d56\u0d5f-\u0d61\u0d7a-\u0d7f\u0d85-\u0d96\u0d9a-\u0db1\u0db3-\u0dbb\u0dbd\u0dc0-\u0dc6\u0e01-\u0e30\u0e32\u0e33\u0e40-\u0e46\u0e81\u0e82\u0e84\u0e86-\u0e8a\u0e8c-\u0ea3\u0ea5\u0ea7-\u0eb0\u0eb2\u0eb3\u0ebd\u0ec0-\u0ec4\u0ec6\u0edc-\u0edf\u0f00\u0f40-\u0f47\u0f49-\u0f6c\u0f88-\u0f8c\u1000-\u102a\u103f\u1050-\u1055\u105a-\u105d\u1061\u1065\u1066\u106e-\u1070\u1075-\u1081\u108e\u10a0-\u10c5\u10c7\u10cd\u10d0-\u10fa\u10fc-\u1248\u124a-\u124d\u1250-\u1256\u1258\u125a-\u125d\u1260-\u1288\u128a-\u128d\u1290-\u12b0\u12b2-\u12b5\u12b8-\u12be\u12c0\u12c2-\u12c5\u12c8-\u12d6\u12d8-\u1310\u1312-\u1315\u1318-\u135a\u1380-\u138f\u13a0-\u13f5\u13f8-\u13fd\u1401-\u166c\u166f-\u167f\u1681-\u169a\u16a0-\u16ea\u16ee-\u16f8\u1700-\u1711\u171f-\u1731\u1740-\u1751\u1760-\u176c\u176e-\u1770\u1780-\u17b3\u17d7\u17dc\u1820-\u1878\u1880-\u18a8\u18aa\u18b0-\u18f5\u1900-\u191e\u1950-\u196d\u1970-\u1974\u1980-\u19ab\u19b0-\u19c9\u1a00-\u1a16\u1a20-\u1a54\u1aa7\u1b05-\u1b33\u1b45-\u1b4c\u1b83-\u1ba0\u1bae\u1baf\u1bba-\u1be5\u1c00-\u1c23\u1c4d-\u1c4f\u1c5a-\u1c7d\u1c80-\u1c88\u1c90-\u1cba\u1cbd-\u1cbf\u1ce9-\u1cec\u1cee-\u1cf3\u1cf5\u1cf6\u1cfa\u1d00-\u1dbf\u1e00-\u1f15\u1f18-\u1f1d\u1f20-\u1f45\u1f48-\u1f4d\u1f50-\u1f57\u1f59\u1f5b\u1f5d\u1f5f-\u1f7d\u1f80-\u1fb4\u1fb6-\u1fbc\u1fbe\u1fc2-\u1fc4\u1fc6-\u1fcc\u1fd0-\u1fd3\u1fd6-\u1fdb\u1fe0-\u1fec\u1ff2-\u1ff4\u1ff6-\u1ffc\u2071\u207f\u2090-\u209c\u2102\u2107\u210a-\u2113\u2115\u2118-\u211d\u2124\u2126\u2128\u212a-\u2139\u213c-\u213f\u2145-\u2149\u214e\u2160-\u2188\u2c00-\u2ce4\u2ceb-\u2cee\u2cf2\u2cf3\u2d00-\u2d25\u2d27\u2d2d\u2d30-\u2d67\u2d6f\u2d80-\u2d96\u2da0-\u2da6\u2da8-\u2dae\u2db0-\u2db6\u2db8-\u2dbe\u2dc0-\u2dc6\u2dc8-\u2dce\u2dd0-\u2dd6\u2dd8-\u2dde\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303c\u3041-\u3096\u309b-\u309f\u30a1-\u30fa\u30fc-\u30ff\u3105-\u312f\u3131-\u318e\u31a0-\u31bf\u31f0-\u31ff\u3400-\u4dbf\u4e00-\ua48c\ua4d0-\ua4fd\ua500-\ua60c\ua610-\ua61f\ua62a\ua62b\ua640-\ua66e\ua67f-\ua69d\ua6a0-\ua6ef\ua717-\ua71f\ua722-\ua788\ua78b-\ua7ca\ua7d0\ua7d1\ua7d3\ua7d5-\ua7d9\ua7f2-\ua801\ua803-\ua805\ua807-\ua80a\ua80c-\ua822\ua840-\ua873\ua882-\ua8b3\ua8f2-\ua8f7\ua8fb\ua8fd\ua8fe\ua90a-\ua925\ua930-\ua946\ua960-\ua97c\ua984-\ua9b2\ua9cf\ua9e0-\ua9e4\ua9e6-\ua9ef\ua9fa-\ua9fe\uaa00-\uaa28\uaa40-\uaa42\uaa44-\uaa4b\uaa60-\uaa76\uaa7a\uaa7e-\uaaaf\uaab1\uaab5\uaab6\uaab9-\uaabd\uaac0\uaac2\uaadb-\uaadd\uaae0-\uaaea\uaaf2-\uaaf4\uab01-\uab06\uab09-\uab0e\uab11-\uab16\uab20-\uab26\uab28-\uab2e\uab30-\uab5a\uab5c-\uab69\uab70-\uabe2\uac00-\ud7a3\ud7b0-\ud7c6\ud7cb-\ud7fb\uf900-\ufa6d\ufa70-\ufad9\ufb00-\ufb06\ufb13-\ufb17\ufb1d\ufb1f-\ufb28\ufb2a-\ufb36\ufb38-\ufb3c\ufb3e\ufb40\ufb41\ufb43\ufb44\ufb46-\ufbb1\ufbd3-\ufd3d\ufd50-\ufd8f\ufd92-\ufdc7\ufdf0-\ufdfb\ufe70-\ufe74\ufe76-\ufefc\uff21-\uff3a\uff41-\uff5a\uff66-\uffbe\uffc2-\uffc7\uffca-\uffcf\uffd2-\uffd7\uffda-\uffdc";
        // These are a run-length and offset encoded representation of the
        // >0xffff code points that are a valid part of identifiers. The
        // offset starts at 0x10000, and each pair of numbers represents an
        // offset to the next range, and then a size of the range.
        // Reserved word lists for various dialects of the language
        var reservedWords = {
            3: "abstract boolean byte char class double enum export extends final float goto implements import int interface long native package private protected public short static super synchronized throws transient volatile",
            5: "class enum extends super const export import",
            6: "enum",
            strict: "implements interface let package private protected public static yield",
            strictBind: "eval arguments"
        };
        // And the keywords
        var ecma5AndLessKeywords = "break case catch continue debugger default do else finally for function if return switch throw try var while with null true false instanceof typeof void delete new in this";
        var keywords$1 = {
            5: ecma5AndLessKeywords,
            "5module": ecma5AndLessKeywords + " export import",
            6: ecma5AndLessKeywords + " const class extends export import super"
        };
        var keywordRelationalOperator = /^in(stanceof)?$/;
        // ## Character categories
        var nonASCIIidentifierStart = new RegExp("[" + nonASCIIidentifierStartChars + "]");
        var nonASCIIidentifier = new RegExp("[" + nonASCIIidentifierStartChars + nonASCIIidentifierChars + "]");
        // This has a complexity linear to the value of the code. The
        // assumption is that looking up astral identifier characters is
        // rare.
        function isInAstralSet(code, set) {
            var pos = 0x10000;
            for (var i = 0; i < set.length; i += 2) {
                pos += set[i];
                if (pos > code) {
                    return false;
                }
                pos += set[i + 1];
                if (pos >= code) {
                    return true;
                }
            }
            return false;
        }
        // Test whether a given character code starts an identifier.
        function isIdentifierStart(code, astral) {
            if (code < 65) {
                return code === 36;
            }
            if (code < 91) {
                return true;
            }
            if (code < 97) {
                return code === 95;
            }
            if (code < 123) {
                return true;
            }
            if (code <= 0xffff) {
                return code >= 0xaa && nonASCIIidentifierStart.test(String.fromCharCode(code));
            }
            if (astral === false) {
                return false;
            }
            return isInAstralSet(code, astralIdentifierStartCodes);
        }
        // Test whether a given character is part of an identifier.
        function isIdentifierChar(code, astral) {
            if (code < 48) {
                return code === 36;
            }
            if (code < 58) {
                return true;
            }
            if (code < 65) {
                return false;
            }
            if (code < 91) {
                return true;
            }
            if (code < 97) {
                return code === 95;
            }
            if (code < 123) {
                return true;
            }
            if (code <= 0xffff) {
                return code >= 0xaa && nonASCIIidentifier.test(String.fromCharCode(code));
            }
            if (astral === false) {
                return false;
            }
            return isInAstralSet(code, astralIdentifierStartCodes) || isInAstralSet(code, astralIdentifierCodes);
        }
        // ## Token types
        // The assignment of fine-grained, information-carrying type objects
        // allows the tokenizer to store the information it has about a
        // token in a way that is very cheap for the parser to look up.
        // All token type variables start with an underscore, to make them
        // easy to recognize.
        // The `beforeExpr` property is used to disambiguate between regular
        // expressions and divisions. It is set on all token types that can
        // be followed by an expression (thus, a slash after them would be a
        // regular expression).
        //
        // The `startsExpr` property is used to check if the token ends a
        // `yield` expression. It is set on all token types that either can
        // directly start an expression (like a quotation mark) or can
        // continue an expression (like the body of a string).
        //
        // `isLoop` marks a keyword as starting a loop, which is important
        // to know when parsing a label, in order to allow or disallow
        // continue jumps to that label.
        var TokenType = function TokenType(label, conf) {
            if (conf === void 0)
                conf = {};
            this.label = label;
            this.keyword = conf.keyword;
            this.beforeExpr = !!conf.beforeExpr;
            this.startsExpr = !!conf.startsExpr;
            this.isLoop = !!conf.isLoop;
            this.isAssign = !!conf.isAssign;
            this.prefix = !!conf.prefix;
            this.postfix = !!conf.postfix;
            this.binop = conf.binop || null;
            this.updateContext = null;
        };
        function binop(name, prec) {
            return new TokenType(name, { beforeExpr: true, binop: prec });
        }
        var beforeExpr = { beforeExpr: true }, startsExpr = { startsExpr: true };
        // Map keyword names to token types.
        var keywords = {};
        // Succinct definitions of keyword token types
        function kw(name, options) {
            if (options === void 0)
                options = {};
            options.keyword = name;
            return keywords[name] = new TokenType(name, options);
        }
        var types$1 = {
            num: new TokenType("num", startsExpr),
            regexp: new TokenType("regexp", startsExpr),
            string: new TokenType("string", startsExpr),
            name: new TokenType("name", startsExpr),
            privateId: new TokenType("privateId", startsExpr),
            eof: new TokenType("eof"),
            // Punctuation token types.
            bracketL: new TokenType("[", { beforeExpr: true, startsExpr: true }),
            bracketR: new TokenType("]"),
            braceL: new TokenType("{", { beforeExpr: true, startsExpr: true }),
            braceR: new TokenType("}"),
            parenL: new TokenType("(", { beforeExpr: true, startsExpr: true }),
            parenR: new TokenType(")"),
            comma: new TokenType(",", beforeExpr),
            semi: new TokenType(";", beforeExpr),
            colon: new TokenType(":", beforeExpr),
            dot: new TokenType("."),
            question: new TokenType("?", beforeExpr),
            questionDot: new TokenType("?."),
            arrow: new TokenType("=>", beforeExpr),
            template: new TokenType("template"),
            invalidTemplate: new TokenType("invalidTemplate"),
            ellipsis: new TokenType("...", beforeExpr),
            backQuote: new TokenType("`", startsExpr),
            dollarBraceL: new TokenType("${", { beforeExpr: true, startsExpr: true }),
            // Operators. These carry several kinds of properties to help the
            // parser use them properly (the presence of these properties is
            // what categorizes them as operators).
            //
            // `binop`, when present, specifies that this operator is a binary
            // operator, and will refer to its precedence.
            //
            // `prefix` and `postfix` mark the operator as a prefix or postfix
            // unary operator.
            //
            // `isAssign` marks all of `=`, `+=`, `-=` etcetera, which act as
            // binary operators with a very low precedence, that should result
            // in AssignmentExpression nodes.
            eq: new TokenType("=", { beforeExpr: true, isAssign: true }),
            assign: new TokenType("_=", { beforeExpr: true, isAssign: true }),
            incDec: new TokenType("++/--", { prefix: true, postfix: true, startsExpr: true }),
            prefix: new TokenType("!/~", { beforeExpr: true, prefix: true, startsExpr: true }),
            logicalOR: binop("||", 1),
            logicalAND: binop("&&", 2),
            bitwiseOR: binop("|", 3),
            bitwiseXOR: binop("^", 4),
            bitwiseAND: binop("&", 5),
            equality: binop("==/!=/===/!==", 6),
            relational: binop("</>/<=/>=", 7),
            bitShift: binop("<</>>/>>>", 8),
            plusMin: new TokenType("+/-", { beforeExpr: true, binop: 9, prefix: true, startsExpr: true }),
            modulo: binop("%", 10),
            star: binop("*", 10),
            slash: binop("/", 10),
            starstar: new TokenType("**", { beforeExpr: true }),
            coalesce: binop("??", 1),
            // Keyword token types.
            _break: kw("break"),
            _case: kw("case", beforeExpr),
            _catch: kw("catch"),
            _continue: kw("continue"),
            _debugger: kw("debugger"),
            _default: kw("default", beforeExpr),
            _do: kw("do", { isLoop: true, beforeExpr: true }),
            _else: kw("else", beforeExpr),
            _finally: kw("finally"),
            _for: kw("for", { isLoop: true }),
            _function: kw("function", startsExpr),
            _if: kw("if"),
            _return: kw("return", beforeExpr),
            _switch: kw("switch"),
            _throw: kw("throw", beforeExpr),
            _try: kw("try"),
            _var: kw("var"),
            _const: kw("const"),
            _while: kw("while", { isLoop: true }),
            _with: kw("with"),
            _new: kw("new", { beforeExpr: true, startsExpr: true }),
            _this: kw("this", startsExpr),
            _super: kw("super", startsExpr),
            _class: kw("class", startsExpr),
            _extends: kw("extends", beforeExpr),
            _export: kw("export"),
            _import: kw("import", startsExpr),
            _null: kw("null", startsExpr),
            _true: kw("true", startsExpr),
            _false: kw("false", startsExpr),
            _in: kw("in", { beforeExpr: true, binop: 7 }),
            _instanceof: kw("instanceof", { beforeExpr: true, binop: 7 }),
            _typeof: kw("typeof", { beforeExpr: true, prefix: true, startsExpr: true }),
            _void: kw("void", { beforeExpr: true, prefix: true, startsExpr: true }),
            _delete: kw("delete", { beforeExpr: true, prefix: true, startsExpr: true })
        };
        // Matches a whole line break (where CRLF is considered a single
        // line break). Used to count lines.
        var lineBreak = /\r\n?|\n|\u2028|\u2029/;
        var lineBreakG = new RegExp(lineBreak.source, "g");
        function isNewLine(code) {
            return code === 10 || code === 13 || code === 0x2028 || code === 0x2029;
        }
        function nextLineBreak(code, from, end) {
            if (end === void 0)
                end = code.length;
            for (var i = from; i < end; i++) {
                var next = code.charCodeAt(i);
                if (isNewLine(next)) {
                    return i < end - 1 && next === 13 && code.charCodeAt(i + 1) === 10 ? i + 2 : i + 1;
                }
            }
            return -1;
        }
        var nonASCIIwhitespace = /[\u1680\u2000-\u200a\u202f\u205f\u3000\ufeff]/;
        var skipWhiteSpace = /(?:\s|\/\/.*|\/\*[^]*?\*\/)*/g;
        var ref = Object.prototype;
        var hasOwnProperty = ref.hasOwnProperty;
        var toString = ref.toString;
        var hasOwn = Object.hasOwn || (function (obj, propName) {
            return (hasOwnProperty.call(obj, propName));
        });
        var isArray = Array.isArray || (function (obj) {
            return (toString.call(obj) === "[object Array]");
        });
        var regexpCache = Object.create(null);
        function wordsRegexp(words) {
            return regexpCache[words] || (regexpCache[words] = new RegExp("^(?:" + words.replace(/ /g, "|") + ")$"));
        }
        function codePointToString(code) {
            // UTF-16 Decoding
            if (code <= 0xFFFF) {
                return String.fromCharCode(code);
            }
            code -= 0x10000;
            return String.fromCharCode((code >> 10) + 0xD800, (code & 1023) + 0xDC00);
        }
        var loneSurrogate = /(?:[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])/;
        // These are used when `options.locations` is on, for the
        // `startLoc` and `endLoc` properties.
        var Position = function Position(line, col) {
            this.line = line;
            this.column = col;
        };
        Position.prototype.offset = function offset(n) {
            return new Position(this.line, this.column + n);
        };
        var SourceLocation = function SourceLocation(p, start, end) {
            this.start = start;
            this.end = end;
            if (p.sourceFile !== null) {
                this.source = p.sourceFile;
            }
        };
        // The `getLineInfo` function is mostly useful when the
        // `locations` option is off (for performance reasons) and you
        // want to find the line/column position for a given character
        // offset. `input` should be the code string that the offset refers
        // into.
        function getLineInfo(input, offset) {
            for (var line = 1, cur = 0;;) {
                var nextBreak = nextLineBreak(input, cur, offset);
                if (nextBreak < 0) {
                    return new Position(line, offset - cur);
                }
                ++line;
                cur = nextBreak;
            }
        }
        // A second argument must be given to configure the parser process.
        // These options are recognized (only `ecmaVersion` is required):
        var defaultOptions = {
            // `ecmaVersion` indicates the ECMAScript version to parse. Must be
            // either 3, 5, 6 (or 2015), 7 (2016), 8 (2017), 9 (2018), 10
            // (2019), 11 (2020), 12 (2021), 13 (2022), 14 (2023), or `"latest"`
            // (the latest version the library supports). This influences
            // support for strict mode, the set of reserved words, and support
            // for new syntax features.
            ecmaVersion: null,
            // `sourceType` indicates the mode the code should be parsed in.
            // Can be either `"script"` or `"module"`. This influences global
            // strict mode and parsing of `import` and `export` declarations.
            sourceType: "script",
            // `onInsertedSemicolon` can be a callback that will be called when
            // a semicolon is automatically inserted. It will be passed the
            // position of the inserted semicolon as an offset, and if
            // `locations` is enabled, it is given the location as a `{line,
            // column}` object as second argument.
            onInsertedSemicolon: null,
            // `onTrailingComma` is similar to `onInsertedSemicolon`, but for
            // trailing commas.
            onTrailingComma: null,
            // By default, reserved words are only enforced if ecmaVersion >= 5.
            // Set `allowReserved` to a boolean value to explicitly turn this on
            // an off. When this option has the value "never", reserved words
            // and keywords can also not be used as property names.
            allowReserved: null,
            // When enabled, a return at the top level is not considered an
            // error.
            allowReturnOutsideFunction: false,
            // When enabled, import/export statements are not constrained to
            // appearing at the top of the program, and an import.meta expression
            // in a script isn't considered an error.
            allowImportExportEverywhere: false,
            // By default, await identifiers are allowed to appear at the top-level scope only if ecmaVersion >= 2022.
            // When enabled, await identifiers are allowed to appear at the top-level scope,
            // but they are still not allowed in non-async functions.
            allowAwaitOutsideFunction: null,
            // When enabled, super identifiers are not constrained to
            // appearing in methods and do not raise an error when they appear elsewhere.
            allowSuperOutsideMethod: null,
            // When enabled, hashbang directive in the beginning of file is
            // allowed and treated as a line comment. Enabled by default when
            // `ecmaVersion` >= 2023.
            allowHashBang: false,
            // By default, the parser will verify that private properties are
            // only used in places where they are valid and have been declared.
            // Set this to false to turn such checks off.
            checkPrivateFields: true,
            // When `locations` is on, `loc` properties holding objects with
            // `start` and `end` properties in `{line, column}` form (with
            // line being 1-based and column 0-based) will be attached to the
            // nodes.
            locations: false,
            // A function can be passed as `onToken` option, which will
            // cause Acorn to call that function with object in the same
            // format as tokens returned from `tokenizer().getToken()`. Note
            // that you are not allowed to call the parser from the
            // callback—that will corrupt its internal state.
            onToken: null,
            // A function can be passed as `onComment` option, which will
            // cause Acorn to call that function with `(block, text, start,
            // end)` parameters whenever a comment is skipped. `block` is a
            // boolean indicating whether this is a block (`/* */`) comment,
            // `text` is the content of the comment, and `start` and `end` are
            // character offsets that denote the start and end of the comment.
            // When the `locations` option is on, two more parameters are
            // passed, the full `{line, column}` locations of the start and
            // end of the comments. Note that you are not allowed to call the
            // parser from the callback—that will corrupt its internal state.
            // When this option has an array as value, objects representing the
            // comments are pushed to it.
            onComment: null,
            // Nodes have their start and end characters offsets recorded in
            // `start` and `end` properties (directly on the node, rather than
            // the `loc` object, which holds line/column data. To also add a
            // [semi-standardized][range] `range` property holding a `[start,
            // end]` array with the same numbers, set the `ranges` option to
            // `true`.
            //
            // [range]: https://bugzilla.mozilla.org/show_bug.cgi?id=745678
            ranges: false,
            // It is possible to parse multiple files into a single AST by
            // passing the tree produced by parsing the first file as
            // `program` option in subsequent parses. This will add the
            // toplevel forms of the parsed file to the `Program` (top) node
            // of an existing parse tree.
            program: null,
            // When `locations` is on, you can pass this to record the source
            // file in every node's `loc` object.
            sourceFile: null,
            // This value, if given, is stored in every node, whether
            // `locations` is on or off.
            directSourceFile: null,
            // When enabled, parenthesized expressions are represented by
            // (non-standard) ParenthesizedExpression nodes
            preserveParens: false
        };
        // Interpret and default an options object
        var warnedAboutEcmaVersion = false;
        function getOptions(opts) {
            var options = {};
            for (var opt in defaultOptions) {
                options[opt] = opts && hasOwn(opts, opt) ? opts[opt] : defaultOptions[opt];
            }
            if (options.ecmaVersion === "latest") {
                options.ecmaVersion = 1e8;
            }
            else if (options.ecmaVersion == null) {
                if (!warnedAboutEcmaVersion && typeof console === "object" && console.warn) {
                    warnedAboutEcmaVersion = true;
                    console.warn("Since Acorn 8.0.0, options.ecmaVersion is required.\nDefaulting to 2020, but this will stop working in the future.");
                }
                options.ecmaVersion = 11;
            }
            else if (options.ecmaVersion >= 2015) {
                options.ecmaVersion -= 2009;
            }
            if (options.allowReserved == null) {
                options.allowReserved = options.ecmaVersion < 5;
            }
            if (!opts || opts.allowHashBang == null) {
                options.allowHashBang = options.ecmaVersion >= 14;
            }
            if (isArray(options.onToken)) {
                var tokens = options.onToken;
                options.onToken = function (token) { return tokens.push(token); };
            }
            if (isArray(options.onComment)) {
                options.onComment = pushComment(options, options.onComment);
            }
            return options;
        }
        function pushComment(options, array) {
            return function (block, text, start, end, startLoc, endLoc) {
                var comment = {
                    type: block ? "Block" : "Line",
                    value: text,
                    start: start,
                    end: end
                };
                if (options.locations) {
                    comment.loc = new SourceLocation(this, startLoc, endLoc);
                }
                if (options.ranges) {
                    comment.range = [start, end];
                }
                array.push(comment);
            };
        }
        // Each scope gets a bitset that may contain these flags
        var SCOPE_TOP = 1, SCOPE_FUNCTION = 2, SCOPE_ASYNC = 4, SCOPE_GENERATOR = 8, SCOPE_ARROW = 16, SCOPE_SIMPLE_CATCH = 32, SCOPE_SUPER = 64, SCOPE_DIRECT_SUPER = 128, SCOPE_CLASS_STATIC_BLOCK = 256, SCOPE_VAR = SCOPE_TOP | SCOPE_FUNCTION | SCOPE_CLASS_STATIC_BLOCK;
        function functionFlags(async, generator) {
            return SCOPE_FUNCTION | (async ? SCOPE_ASYNC : 0) | (generator ? SCOPE_GENERATOR : 0);
        }
        // Used in checkLVal* and declareName to determine the type of a binding
        var BIND_NONE = 0, // Not a binding
        BIND_VAR = 1, // Var-style binding
        BIND_LEXICAL = 2, // Let- or const-style binding
        BIND_FUNCTION = 3, // Function declaration
        BIND_SIMPLE_CATCH = 4, // Simple (identifier pattern) catch binding
        BIND_OUTSIDE = 5; // Special case for function names as bound inside the function
        var Parser = function Parser(options, input, startPos) {
            this.options = options = getOptions(options);
            this.sourceFile = options.sourceFile;
            this.keywords = wordsRegexp(keywords$1[options.ecmaVersion >= 6 ? 6 : options.sourceType === "module" ? "5module" : 5]);
            var reserved = "";
            if (options.allowReserved !== true) {
                reserved = reservedWords[options.ecmaVersion >= 6 ? 6 : options.ecmaVersion === 5 ? 5 : 3];
                if (options.sourceType === "module") {
                    reserved += " await";
                }
            }
            this.reservedWords = wordsRegexp(reserved);
            var reservedStrict = (reserved ? reserved + " " : "") + reservedWords.strict;
            this.reservedWordsStrict = wordsRegexp(reservedStrict);
            this.reservedWordsStrictBind = wordsRegexp(reservedStrict + " " + reservedWords.strictBind);
            this.input = String(input);
            // Used to signal to callers of `readWord1` whether the word
            // contained any escape sequences. This is needed because words with
            // escape sequences must not be interpreted as keywords.
            this.containsEsc = false;
            // Set up token state
            // The current position of the tokenizer in the input.
            if (startPos) {
                this.pos = startPos;
                this.lineStart = this.input.lastIndexOf("\n", startPos - 1) + 1;
                this.curLine = this.input.slice(0, this.lineStart).split(lineBreak).length;
            }
            else {
                this.pos = this.lineStart = 0;
                this.curLine = 1;
            }
            // Properties of the current token:
            // Its type
            this.type = types$1.eof;
            // For tokens that include more information than their type, the value
            this.value = null;
            // Its start and end offset
            this.start = this.end = this.pos;
            // And, if locations are used, the {line, column} object
            // corresponding to those offsets
            this.startLoc = this.endLoc = this.curPosition();
            // Position information for the previous token
            this.lastTokEndLoc = this.lastTokStartLoc = null;
            this.lastTokStart = this.lastTokEnd = this.pos;
            // The context stack is used to superficially track syntactic
            // context to predict whether a regular expression is allowed in a
            // given position.
            this.context = this.initialContext();
            this.exprAllowed = true;
            // Figure out if it's a module code.
            this.inModule = options.sourceType === "module";
            this.strict = this.inModule || this.strictDirective(this.pos);
            // Used to signify the start of a potential arrow function
            this.potentialArrowAt = -1;
            this.potentialArrowInForAwait = false;
            // Positions to delayed-check that yield/await does not exist in default parameters.
            this.yieldPos = this.awaitPos = this.awaitIdentPos = 0;
            // Labels in scope.
            this.labels = [];
            // Thus-far undefined exports.
            this.undefinedExports = Object.create(null);
            // If enabled, skip leading hashbang line.
            if (this.pos === 0 && options.allowHashBang && this.input.slice(0, 2) === "#!") {
                this.skipLineComment(2);
            }
            // Scope tracking for duplicate variable names (see scope.js)
            this.scopeStack = [];
            this.enterScope(SCOPE_TOP);
            // For RegExp validation
            this.regexpState = null;
            // The stack of private names.
            // Each element has two properties: 'declared' and 'used'.
            // When it exited from the outermost class definition, all used private names must be declared.
            this.privateNameStack = [];
        };
        var prototypeAccessors = { inFunction: { configurable: true }, inGenerator: { configurable: true }, inAsync: { configurable: true }, canAwait: { configurable: true }, allowSuper: { configurable: true }, allowDirectSuper: { configurable: true }, treatFunctionsAsVar: { configurable: true }, allowNewDotTarget: { configurable: true }, inClassStaticBlock: { configurable: true } };
        Parser.prototype.parse = function parse() {
            var node = this.options.program || this.startNode();
            this.nextToken();
            return this.parseTopLevel(node);
        };
        prototypeAccessors.inFunction.get = function () { return (this.currentVarScope().flags & SCOPE_FUNCTION) > 0; };
        prototypeAccessors.inGenerator.get = function () { return (this.currentVarScope().flags & SCOPE_GENERATOR) > 0 && !this.currentVarScope().inClassFieldInit; };
        prototypeAccessors.inAsync.get = function () { return (this.currentVarScope().flags & SCOPE_ASYNC) > 0 && !this.currentVarScope().inClassFieldInit; };
        prototypeAccessors.canAwait.get = function () {
            for (var i = this.scopeStack.length - 1; i >= 0; i--) {
                var scope = this.scopeStack[i];
                if (scope.inClassFieldInit || scope.flags & SCOPE_CLASS_STATIC_BLOCK) {
                    return false;
                }
                if (scope.flags & SCOPE_FUNCTION) {
                    return (scope.flags & SCOPE_ASYNC) > 0;
                }
            }
            return (this.inModule && this.options.ecmaVersion >= 13) || this.options.allowAwaitOutsideFunction;
        };
        prototypeAccessors.allowSuper.get = function () {
            var ref = this.currentThisScope();
            var flags = ref.flags;
            var inClassFieldInit = ref.inClassFieldInit;
            return (flags & SCOPE_SUPER) > 0 || inClassFieldInit || this.options.allowSuperOutsideMethod;
        };
        prototypeAccessors.allowDirectSuper.get = function () { return (this.currentThisScope().flags & SCOPE_DIRECT_SUPER) > 0; };
        prototypeAccessors.treatFunctionsAsVar.get = function () { return this.treatFunctionsAsVarInScope(this.currentScope()); };
        prototypeAccessors.allowNewDotTarget.get = function () {
            var ref = this.currentThisScope();
            var flags = ref.flags;
            var inClassFieldInit = ref.inClassFieldInit;
            return (flags & (SCOPE_FUNCTION | SCOPE_CLASS_STATIC_BLOCK)) > 0 || inClassFieldInit;
        };
        prototypeAccessors.inClassStaticBlock.get = function () {
            return (this.currentVarScope().flags & SCOPE_CLASS_STATIC_BLOCK) > 0;
        };
        Parser.extend = function extend() {
            var plugins = [], len = arguments.length;
            while (len--)
                plugins[len] = arguments[len];
            var cls = this;
            for (var i = 0; i < plugins.length; i++) {
                cls = plugins[i](cls);
            }
            return cls;
        };
        Parser.parse = function parse(input, options) {
            return new this(options, input).parse();
        };
        Parser.parseExpressionAt = function parseExpressionAt(input, pos, options) {
            var parser = new this(options, input, pos);
            parser.nextToken();
            return parser.parseExpression();
        };
        Parser.tokenizer = function tokenizer(input, options) {
            return new this(options, input);
        };
        Object.defineProperties(Parser.prototype, prototypeAccessors);
        var pp$9 = Parser.prototype;
        // ## Parser utilities
        var literal = /^(?:'((?:\\.|[^'\\])*?)'|"((?:\\.|[^"\\])*?)")/;
        pp$9.strictDirective = function (start) {
            if (this.options.ecmaVersion < 5) {
                return false;
            }
            for (;;) {
                // Try to find string literal.
                skipWhiteSpace.lastIndex = start;
                start += skipWhiteSpace.exec(this.input)[0].length;
                var match = literal.exec(this.input.slice(start));
                if (!match) {
                    return false;
                }
                if ((match[1] || match[2]) === "use strict") {
                    skipWhiteSpace.lastIndex = start + match[0].length;
                    var spaceAfter = skipWhiteSpace.exec(this.input), end = spaceAfter.index + spaceAfter[0].length;
                    var next = this.input.charAt(end);
                    return next === ";" || next === "}" ||
                        (lineBreak.test(spaceAfter[0]) &&
                            !(/[(`.[+\-/*%<>=,?^&]/.test(next) || next === "!" && this.input.charAt(end + 1) === "="));
                }
                start += match[0].length;
                // Skip semicolon, if any.
                skipWhiteSpace.lastIndex = start;
                start += skipWhiteSpace.exec(this.input)[0].length;
                if (this.input[start] === ";") {
                    start++;
                }
            }
        };
        // Predicate that tests whether the next token is of the given
        // type, and if yes, consumes it as a side effect.
        pp$9.eat = function (type) {
            if (this.type === type) {
                this.next();
                return true;
            }
            else {
                return false;
            }
        };
        // Tests whether parsed token is a contextual keyword.
        pp$9.isContextual = function (name) {
            return this.type === types$1.name && this.value === name && !this.containsEsc;
        };
        // Consumes contextual keyword if possible.
        pp$9.eatContextual = function (name) {
            if (!this.isContextual(name)) {
                return false;
            }
            this.next();
            return true;
        };
        // Asserts that following token is given contextual keyword.
        pp$9.expectContextual = function (name) {
            if (!this.eatContextual(name)) {
                this.unexpected();
            }
        };
        // Test whether a semicolon can be inserted at the current position.
        pp$9.canInsertSemicolon = function () {
            return this.type === types$1.eof ||
                this.type === types$1.braceR ||
                lineBreak.test(this.input.slice(this.lastTokEnd, this.start));
        };
        pp$9.insertSemicolon = function () {
            if (this.canInsertSemicolon()) {
                if (this.options.onInsertedSemicolon) {
                    this.options.onInsertedSemicolon(this.lastTokEnd, this.lastTokEndLoc);
                }
                return true;
            }
        };
        // Consume a semicolon, or, failing that, see if we are allowed to
        // pretend that there is a semicolon at this position.
        pp$9.semicolon = function () {
            if (!this.eat(types$1.semi) && !this.insertSemicolon()) {
                this.unexpected();
            }
        };
        pp$9.afterTrailingComma = function (tokType, notNext) {
            if (this.type === tokType) {
                if (this.options.onTrailingComma) {
                    this.options.onTrailingComma(this.lastTokStart, this.lastTokStartLoc);
                }
                if (!notNext) {
                    this.next();
                }
                return true;
            }
        };
        // Expect a token of a given type. If found, consume it, otherwise,
        // raise an unexpected token error.
        pp$9.expect = function (type) {
            this.eat(type) || this.unexpected();
        };
        // Raise an unexpected token error.
        pp$9.unexpected = function (pos) {
            this.raise(pos != null ? pos : this.start, "Unexpected token");
        };
        var DestructuringErrors = function DestructuringErrors() {
            this.shorthandAssign =
                this.trailingComma =
                    this.parenthesizedAssign =
                        this.parenthesizedBind =
                            this.doubleProto =
                                -1;
        };
        pp$9.checkPatternErrors = function (refDestructuringErrors, isAssign) {
            if (!refDestructuringErrors) {
                return;
            }
            if (refDestructuringErrors.trailingComma > -1) {
                this.raiseRecoverable(refDestructuringErrors.trailingComma, "Comma is not permitted after the rest element");
            }
            var parens = isAssign ? refDestructuringErrors.parenthesizedAssign : refDestructuringErrors.parenthesizedBind;
            if (parens > -1) {
                this.raiseRecoverable(parens, isAssign ? "Assigning to rvalue" : "Parenthesized pattern");
            }
        };
        pp$9.checkExpressionErrors = function (refDestructuringErrors, andThrow) {
            if (!refDestructuringErrors) {
                return false;
            }
            var shorthandAssign = refDestructuringErrors.shorthandAssign;
            var doubleProto = refDestructuringErrors.doubleProto;
            if (!andThrow) {
                return shorthandAssign >= 0 || doubleProto >= 0;
            }
            if (shorthandAssign >= 0) {
                this.raise(shorthandAssign, "Shorthand property assignments are valid only in destructuring patterns");
            }
            if (doubleProto >= 0) {
                this.raiseRecoverable(doubleProto, "Redefinition of __proto__ property");
            }
        };
        pp$9.checkYieldAwaitInDefaultParams = function () {
            if (this.yieldPos && (!this.awaitPos || this.yieldPos < this.awaitPos)) {
                this.raise(this.yieldPos, "Yield expression cannot be a default value");
            }
            if (this.awaitPos) {
                this.raise(this.awaitPos, "Await expression cannot be a default value");
            }
        };
        pp$9.isSimpleAssignTarget = function (expr) {
            if (expr.type === "ParenthesizedExpression") {
                return this.isSimpleAssignTarget(expr.expression);
            }
            return expr.type === "Identifier" || expr.type === "MemberExpression";
        };
        var pp$8 = Parser.prototype;
        // ### Statement parsing
        // Parse a program. Initializes the parser, reads any number of
        // statements, and wraps them in a Program node.  Optionally takes a
        // `program` argument.  If present, the statements will be appended
        // to its body instead of creating a new node.
        pp$8.parseTopLevel = function (node) {
            var exports = Object.create(null);
            if (!node.body) {
                node.body = [];
            }
            while (this.type !== types$1.eof) {
                var stmt = this.parseStatement(null, true, exports);
                node.body.push(stmt);
            }
            if (this.inModule) {
                for (var i = 0, list = Object.keys(this.undefinedExports); i < list.length; i += 1) {
                    var name = list[i];
                    this.raiseRecoverable(this.undefinedExports[name].start, ("Export '" + name + "' is not defined"));
                }
            }
            this.adaptDirectivePrologue(node.body);
            this.next();
            node.sourceType = this.options.sourceType;
            return this.finishNode(node, "Program");
        };
        var loopLabel = { kind: "loop" }, switchLabel = { kind: "switch" };
        pp$8.isLet = function (context) {
            if (this.options.ecmaVersion < 6 || !this.isContextual("let")) {
                return false;
            }
            skipWhiteSpace.lastIndex = this.pos;
            var skip = skipWhiteSpace.exec(this.input);
            var next = this.pos + skip[0].length, nextCh = this.input.charCodeAt(next);
            // For ambiguous cases, determine if a LexicalDeclaration (or only a
            // Statement) is allowed here. If context is not empty then only a Statement
            // is allowed. However, `let [` is an explicit negative lookahead for
            // ExpressionStatement, so special-case it first.
            if (nextCh === 91 || nextCh === 92) {
                return true;
            } // '[', '/'
            if (context) {
                return false;
            }
            if (nextCh === 123 || nextCh > 0xd7ff && nextCh < 0xdc00) {
                return true;
            } // '{', astral
            if (isIdentifierStart(nextCh, true)) {
                var pos = next + 1;
                while (isIdentifierChar(nextCh = this.input.charCodeAt(pos), true)) {
                    ++pos;
                }
                if (nextCh === 92 || nextCh > 0xd7ff && nextCh < 0xdc00) {
                    return true;
                }
                var ident = this.input.slice(next, pos);
                if (!keywordRelationalOperator.test(ident)) {
                    return true;
                }
            }
            return false;
        };
        // check 'async [no LineTerminator here] function'
        // - 'async /*foo*/ function' is OK.
        // - 'async /*\n*/ function' is invalid.
        pp$8.isAsyncFunction = function () {
            if (this.options.ecmaVersion < 8 || !this.isContextual("async")) {
                return false;
            }
            skipWhiteSpace.lastIndex = this.pos;
            var skip = skipWhiteSpace.exec(this.input);
            var next = this.pos + skip[0].length, after;
            return !lineBreak.test(this.input.slice(this.pos, next)) &&
                this.input.slice(next, next + 8) === "function" &&
                (next + 8 === this.input.length ||
                    !(isIdentifierChar(after = this.input.charCodeAt(next + 8)) || after > 0xd7ff && after < 0xdc00));
        };
        // Parse a single statement.
        //
        // If expecting a statement and finding a slash operator, parse a
        // regular expression literal. This is to handle cases like
        // `if (foo) /blah/.exec(foo)`, where looking at the previous token
        // does not help.
        pp$8.parseStatement = function (context, topLevel, exports) {
            var starttype = this.type, node = this.startNode(), kind;
            if (this.isLet(context)) {
                starttype = types$1._var;
                kind = "let";
            }
            // Most types of statements are recognized by the keyword they
            // start with. Many are trivial to parse, some require a bit of
            // complexity.
            switch (starttype) {
                case types$1._break:
                case types$1._continue: return this.parseBreakContinueStatement(node, starttype.keyword);
                case types$1._debugger: return this.parseDebuggerStatement(node);
                case types$1._do: return this.parseDoStatement(node);
                case types$1._for: return this.parseForStatement(node);
                case types$1._function:
                    // Function as sole body of either an if statement or a labeled statement
                    // works, but not when it is part of a labeled statement that is the sole
                    // body of an if statement.
                    if ((context && (this.strict || context !== "if" && context !== "label")) && this.options.ecmaVersion >= 6) {
                        this.unexpected();
                    }
                    return this.parseFunctionStatement(node, false, !context);
                case types$1._class:
                    if (context) {
                        this.unexpected();
                    }
                    return this.parseClass(node, true);
                case types$1._if: return this.parseIfStatement(node);
                case types$1._return: return this.parseReturnStatement(node);
                case types$1._switch: return this.parseSwitchStatement(node);
                case types$1._throw: return this.parseThrowStatement(node);
                case types$1._try: return this.parseTryStatement(node);
                case types$1._const:
                case types$1._var:
                    kind = kind || this.value;
                    if (context && kind !== "var") {
                        this.unexpected();
                    }
                    return this.parseVarStatement(node, kind);
                case types$1._while: return this.parseWhileStatement(node);
                case types$1._with: return this.parseWithStatement(node);
                case types$1.braceL: return this.parseBlock(true, node);
                case types$1.semi: return this.parseEmptyStatement(node);
                case types$1._export:
                case types$1._import:
                    if (this.options.ecmaVersion > 10 && starttype === types$1._import) {
                        skipWhiteSpace.lastIndex = this.pos;
                        var skip = skipWhiteSpace.exec(this.input);
                        var next = this.pos + skip[0].length, nextCh = this.input.charCodeAt(next);
                        if (nextCh === 40 || nextCh === 46) // '(' or '.'
                         {
                            return this.parseExpressionStatement(node, this.parseExpression());
                        }
                    }
                    if (!this.options.allowImportExportEverywhere) {
                        if (!topLevel) {
                            this.raise(this.start, "'import' and 'export' may only appear at the top level");
                        }
                        if (!this.inModule) {
                            this.raise(this.start, "'import' and 'export' may appear only with 'sourceType: module'");
                        }
                    }
                    return starttype === types$1._import ? this.parseImport(node) : this.parseExport(node, exports);
                // If the statement does not start with a statement keyword or a
                // brace, it's an ExpressionStatement or LabeledStatement. We
                // simply start parsing an expression, and afterwards, if the
                // next token is a colon and the expression was a simple
                // Identifier node, we switch to interpreting it as a label.
                default:
                    if (this.isAsyncFunction()) {
                        if (context) {
                            this.unexpected();
                        }
                        this.next();
                        return this.parseFunctionStatement(node, true, !context);
                    }
                    var maybeName = this.value, expr = this.parseExpression();
                    if (starttype === types$1.name && expr.type === "Identifier" && this.eat(types$1.colon)) {
                        return this.parseLabeledStatement(node, maybeName, expr, context);
                    }
                    else {
                        return this.parseExpressionStatement(node, expr);
                    }
            }
        };
        pp$8.parseBreakContinueStatement = function (node, keyword) {
            var isBreak = keyword === "break";
            this.next();
            if (this.eat(types$1.semi) || this.insertSemicolon()) {
                node.label = null;
            }
            else if (this.type !== types$1.name) {
                this.unexpected();
            }
            else {
                node.label = this.parseIdent();
                this.semicolon();
            }
            // Verify that there is an actual destination to break or
            // continue to.
            var i = 0;
            for (; i < this.labels.length; ++i) {
                var lab = this.labels[i];
                if (node.label == null || lab.name === node.label.name) {
                    if (lab.kind != null && (isBreak || lab.kind === "loop")) {
                        break;
                    }
                    if (node.label && isBreak) {
                        break;
                    }
                }
            }
            if (i === this.labels.length) {
                this.raise(node.start, "Unsyntactic " + keyword);
            }
            return this.finishNode(node, isBreak ? "BreakStatement" : "ContinueStatement");
        };
        pp$8.parseDebuggerStatement = function (node) {
            this.next();
            this.semicolon();
            return this.finishNode(node, "DebuggerStatement");
        };
        pp$8.parseDoStatement = function (node) {
            this.next();
            this.labels.push(loopLabel);
            node.body = this.parseStatement("do");
            this.labels.pop();
            this.expect(types$1._while);
            node.test = this.parseParenExpression();
            if (this.options.ecmaVersion >= 6) {
                this.eat(types$1.semi);
            }
            else {
                this.semicolon();
            }
            return this.finishNode(node, "DoWhileStatement");
        };
        // Disambiguating between a `for` and a `for`/`in` or `for`/`of`
        // loop is non-trivial. Basically, we have to parse the init `var`
        // statement or expression, disallowing the `in` operator (see
        // the second parameter to `parseExpression`), and then check
        // whether the next token is `in` or `of`. When there is no init
        // part (semicolon immediately after the opening parenthesis), it
        // is a regular `for` loop.
        pp$8.parseForStatement = function (node) {
            this.next();
            var awaitAt = (this.options.ecmaVersion >= 9 && this.canAwait && this.eatContextual("await")) ? this.lastTokStart : -1;
            this.labels.push(loopLabel);
            this.enterScope(0);
            this.expect(types$1.parenL);
            if (this.type === types$1.semi) {
                if (awaitAt > -1) {
                    this.unexpected(awaitAt);
                }
                return this.parseFor(node, null);
            }
            var isLet = this.isLet();
            if (this.type === types$1._var || this.type === types$1._const || isLet) {
                var init$1 = this.startNode(), kind = isLet ? "let" : this.value;
                this.next();
                this.parseVar(init$1, true, kind);
                this.finishNode(init$1, "VariableDeclaration");
                if ((this.type === types$1._in || (this.options.ecmaVersion >= 6 && this.isContextual("of"))) && init$1.declarations.length === 1) {
                    if (this.options.ecmaVersion >= 9) {
                        if (this.type === types$1._in) {
                            if (awaitAt > -1) {
                                this.unexpected(awaitAt);
                            }
                        }
                        else {
                            node.await = awaitAt > -1;
                        }
                    }
                    return this.parseForIn(node, init$1);
                }
                if (awaitAt > -1) {
                    this.unexpected(awaitAt);
                }
                return this.parseFor(node, init$1);
            }
            var startsWithLet = this.isContextual("let"), isForOf = false;
            var refDestructuringErrors = new DestructuringErrors;
            var init = this.parseExpression(awaitAt > -1 ? "await" : true, refDestructuringErrors);
            if (this.type === types$1._in || (isForOf = this.options.ecmaVersion >= 6 && this.isContextual("of"))) {
                if (this.options.ecmaVersion >= 9) {
                    if (this.type === types$1._in) {
                        if (awaitAt > -1) {
                            this.unexpected(awaitAt);
                        }
                    }
                    else {
                        node.await = awaitAt > -1;
                    }
                }
                if (startsWithLet && isForOf) {
                    this.raise(init.start, "The left-hand side of a for-of loop may not start with 'let'.");
                }
                this.toAssignable(init, false, refDestructuringErrors);
                this.checkLValPattern(init);
                return this.parseForIn(node, init);
            }
            else {
                this.checkExpressionErrors(refDestructuringErrors, true);
            }
            if (awaitAt > -1) {
                this.unexpected(awaitAt);
            }
            return this.parseFor(node, init);
        };
        pp$8.parseFunctionStatement = function (node, isAsync, declarationPosition) {
            this.next();
            return this.parseFunction(node, FUNC_STATEMENT | (declarationPosition ? 0 : FUNC_HANGING_STATEMENT), false, isAsync);
        };
        pp$8.parseIfStatement = function (node) {
            this.next();
            node.test = this.parseParenExpression();
            // allow function declarations in branches, but only in non-strict mode
            node.consequent = this.parseStatement("if");
            node.alternate = this.eat(types$1._else) ? this.parseStatement("if") : null;
            return this.finishNode(node, "IfStatement");
        };
        pp$8.parseReturnStatement = function (node) {
            if (!this.inFunction && !this.options.allowReturnOutsideFunction) {
                this.raise(this.start, "'return' outside of function");
            }
            this.next();
            // In `return` (and `break`/`continue`), the keywords with
            // optional arguments, we eagerly look for a semicolon or the
            // possibility to insert one.
            if (this.eat(types$1.semi) || this.insertSemicolon()) {
                node.argument = null;
            }
            else {
                node.argument = this.parseExpression();
                this.semicolon();
            }
            return this.finishNode(node, "ReturnStatement");
        };
        pp$8.parseSwitchStatement = function (node) {
            this.next();
            node.discriminant = this.parseParenExpression();
            node.cases = [];
            this.expect(types$1.braceL);
            this.labels.push(switchLabel);
            this.enterScope(0);
            // Statements under must be grouped (by label) in SwitchCase
            // nodes. `cur` is used to keep the node that we are currently
            // adding statements to.
            var cur;
            for (var sawDefault = false; this.type !== types$1.braceR;) {
                if (this.type === types$1._case || this.type === types$1._default) {
                    var isCase = this.type === types$1._case;
                    if (cur) {
                        this.finishNode(cur, "SwitchCase");
                    }
                    node.cases.push(cur = this.startNode());
                    cur.consequent = [];
                    this.next();
                    if (isCase) {
                        cur.test = this.parseExpression();
                    }
                    else {
                        if (sawDefault) {
                            this.raiseRecoverable(this.lastTokStart, "Multiple default clauses");
                        }
                        sawDefault = true;
                        cur.test = null;
                    }
                    this.expect(types$1.colon);
                }
                else {
                    if (!cur) {
                        this.unexpected();
                    }
                    cur.consequent.push(this.parseStatement(null));
                }
            }
            this.exitScope();
            if (cur) {
                this.finishNode(cur, "SwitchCase");
            }
            this.next(); // Closing brace
            this.labels.pop();
            return this.finishNode(node, "SwitchStatement");
        };
        pp$8.parseThrowStatement = function (node) {
            this.next();
            if (lineBreak.test(this.input.slice(this.lastTokEnd, this.start))) {
                this.raise(this.lastTokEnd, "Illegal newline after throw");
            }
            node.argument = this.parseExpression();
            this.semicolon();
            return this.finishNode(node, "ThrowStatement");
        };
        // Reused empty array added for node fields that are always empty.
        var empty$1 = [];
        pp$8.parseCatchClauseParam = function () {
            var param = this.parseBindingAtom();
            var simple = param.type === "Identifier";
            this.enterScope(simple ? SCOPE_SIMPLE_CATCH : 0);
            this.checkLValPattern(param, simple ? BIND_SIMPLE_CATCH : BIND_LEXICAL);
            this.expect(types$1.parenR);
            return param;
        };
        pp$8.parseTryStatement = function (node) {
            this.next();
            node.block = this.parseBlock();
            node.handler = null;
            if (this.type === types$1._catch) {
                var clause = this.startNode();
                this.next();
                if (this.eat(types$1.parenL)) {
                    clause.param = this.parseCatchClauseParam();
                }
                else {
                    if (this.options.ecmaVersion < 10) {
                        this.unexpected();
                    }
                    clause.param = null;
                    this.enterScope(0);
                }
                clause.body = this.parseBlock(false);
                this.exitScope();
                node.handler = this.finishNode(clause, "CatchClause");
            }
            node.finalizer = this.eat(types$1._finally) ? this.parseBlock() : null;
            if (!node.handler && !node.finalizer) {
                this.raise(node.start, "Missing catch or finally clause");
            }
            return this.finishNode(node, "TryStatement");
        };
        pp$8.parseVarStatement = function (node, kind, allowMissingInitializer) {
            this.next();
            this.parseVar(node, false, kind, allowMissingInitializer);
            this.semicolon();
            return this.finishNode(node, "VariableDeclaration");
        };
        pp$8.parseWhileStatement = function (node) {
            this.next();
            node.test = this.parseParenExpression();
            this.labels.push(loopLabel);
            node.body = this.parseStatement("while");
            this.labels.pop();
            return this.finishNode(node, "WhileStatement");
        };
        pp$8.parseWithStatement = function (node) {
            if (this.strict) {
                this.raise(this.start, "'with' in strict mode");
            }
            this.next();
            node.object = this.parseParenExpression();
            node.body = this.parseStatement("with");
            return this.finishNode(node, "WithStatement");
        };
        pp$8.parseEmptyStatement = function (node) {
            this.next();
            return this.finishNode(node, "EmptyStatement");
        };
        pp$8.parseLabeledStatement = function (node, maybeName, expr, context) {
            for (var i$1 = 0, list = this.labels; i$1 < list.length; i$1 += 1) {
                var label = list[i$1];
                if (label.name === maybeName) {
                    this.raise(expr.start, "Label '" + maybeName + "' is already declared");
                }
            }
            var kind = this.type.isLoop ? "loop" : this.type === types$1._switch ? "switch" : null;
            for (var i = this.labels.length - 1; i >= 0; i--) {
                var label$1 = this.labels[i];
                if (label$1.statementStart === node.start) {
                    // Update information about previous labels on this node
                    label$1.statementStart = this.start;
                    label$1.kind = kind;
                }
                else {
                    break;
                }
            }
            this.labels.push({ name: maybeName, kind: kind, statementStart: this.start });
            node.body = this.parseStatement(context ? context.indexOf("label") === -1 ? context + "label" : context : "label");
            this.labels.pop();
            node.label = expr;
            return this.finishNode(node, "LabeledStatement");
        };
        pp$8.parseExpressionStatement = function (node, expr) {
            node.expression = expr;
            this.semicolon();
            return this.finishNode(node, "ExpressionStatement");
        };
        // Parse a semicolon-enclosed block of statements, handling `"use
        // strict"` declarations when `allowStrict` is true (used for
        // function bodies).
        pp$8.parseBlock = function (createNewLexicalScope, node, exitStrict) {
            if (createNewLexicalScope === void 0)
                createNewLexicalScope = true;
            if (node === void 0)
                node = this.startNode();
            node.body = [];
            this.expect(types$1.braceL);
            if (createNewLexicalScope) {
                this.enterScope(0);
            }
            while (this.type !== types$1.braceR) {
                var stmt = this.parseStatement(null);
                node.body.push(stmt);
            }
            if (exitStrict) {
                this.strict = false;
            }
            this.next();
            if (createNewLexicalScope) {
                this.exitScope();
            }
            return this.finishNode(node, "BlockStatement");
        };
        // Parse a regular `for` loop. The disambiguation code in
        // `parseStatement` will already have parsed the init statement or
        // expression.
        pp$8.parseFor = function (node, init) {
            node.init = init;
            this.expect(types$1.semi);
            node.test = this.type === types$1.semi ? null : this.parseExpression();
            this.expect(types$1.semi);
            node.update = this.type === types$1.parenR ? null : this.parseExpression();
            this.expect(types$1.parenR);
            node.body = this.parseStatement("for");
            this.exitScope();
            this.labels.pop();
            return this.finishNode(node, "ForStatement");
        };
        // Parse a `for`/`in` and `for`/`of` loop, which are almost
        // same from parser's perspective.
        pp$8.parseForIn = function (node, init) {
            var isForIn = this.type === types$1._in;
            this.next();
            if (init.type === "VariableDeclaration" &&
                init.declarations[0].init != null &&
                (!isForIn ||
                    this.options.ecmaVersion < 8 ||
                    this.strict ||
                    init.kind !== "var" ||
                    init.declarations[0].id.type !== "Identifier")) {
                this.raise(init.start, ((isForIn ? "for-in" : "for-of") + " loop variable declaration may not have an initializer"));
            }
            node.left = init;
            node.right = isForIn ? this.parseExpression() : this.parseMaybeAssign();
            this.expect(types$1.parenR);
            node.body = this.parseStatement("for");
            this.exitScope();
            this.labels.pop();
            return this.finishNode(node, isForIn ? "ForInStatement" : "ForOfStatement");
        };
        // Parse a list of variable declarations.
        pp$8.parseVar = function (node, isFor, kind, allowMissingInitializer) {
            node.declarations = [];
            node.kind = kind;
            for (;;) {
                var decl = this.startNode();
                this.parseVarId(decl, kind);
                if (this.eat(types$1.eq)) {
                    decl.init = this.parseMaybeAssign(isFor);
                }
                else if (!allowMissingInitializer && kind === "const" && !(this.type === types$1._in || (this.options.ecmaVersion >= 6 && this.isContextual("of")))) {
                    this.unexpected();
                }
                else if (!allowMissingInitializer && decl.id.type !== "Identifier" && !(isFor && (this.type === types$1._in || this.isContextual("of")))) {
                    this.raise(this.lastTokEnd, "Complex binding patterns require an initialization value");
                }
                else {
                    decl.init = null;
                }
                node.declarations.push(this.finishNode(decl, "VariableDeclarator"));
                if (!this.eat(types$1.comma)) {
                    break;
                }
            }
            return node;
        };
        pp$8.parseVarId = function (decl, kind) {
            decl.id = this.parseBindingAtom();
            this.checkLValPattern(decl.id, kind === "var" ? BIND_VAR : BIND_LEXICAL, false);
        };
        var FUNC_STATEMENT = 1, FUNC_HANGING_STATEMENT = 2, FUNC_NULLABLE_ID = 4;
        // Parse a function declaration or literal (depending on the
        // `statement & FUNC_STATEMENT`).
        // Remove `allowExpressionBody` for 7.0.0, as it is only called with false
        pp$8.parseFunction = function (node, statement, allowExpressionBody, isAsync, forInit) {
            this.initFunction(node);
            if (this.options.ecmaVersion >= 9 || this.options.ecmaVersion >= 6 && !isAsync) {
                if (this.type === types$1.star && (statement & FUNC_HANGING_STATEMENT)) {
                    this.unexpected();
                }
                node.generator = this.eat(types$1.star);
            }
            if (this.options.ecmaVersion >= 8) {
                node.async = !!isAsync;
            }
            if (statement & FUNC_STATEMENT) {
                node.id = (statement & FUNC_NULLABLE_ID) && this.type !== types$1.name ? null : this.parseIdent();
                if (node.id && !(statement & FUNC_HANGING_STATEMENT)) 
                // If it is a regular function declaration in sloppy mode, then it is
                // subject to Annex B semantics (BIND_FUNCTION). Otherwise, the binding
                // mode depends on properties of the current scope (see
                // treatFunctionsAsVar).
                {
                    this.checkLValSimple(node.id, (this.strict || node.generator || node.async) ? this.treatFunctionsAsVar ? BIND_VAR : BIND_LEXICAL : BIND_FUNCTION);
                }
            }
            var oldYieldPos = this.yieldPos, oldAwaitPos = this.awaitPos, oldAwaitIdentPos = this.awaitIdentPos;
            this.yieldPos = 0;
            this.awaitPos = 0;
            this.awaitIdentPos = 0;
            this.enterScope(functionFlags(node.async, node.generator));
            if (!(statement & FUNC_STATEMENT)) {
                node.id = this.type === types$1.name ? this.parseIdent() : null;
            }
            this.parseFunctionParams(node);
            this.parseFunctionBody(node, allowExpressionBody, false, forInit);
            this.yieldPos = oldYieldPos;
            this.awaitPos = oldAwaitPos;
            this.awaitIdentPos = oldAwaitIdentPos;
            return this.finishNode(node, (statement & FUNC_STATEMENT) ? "FunctionDeclaration" : "FunctionExpression");
        };
        pp$8.parseFunctionParams = function (node) {
            this.expect(types$1.parenL);
            node.params = this.parseBindingList(types$1.parenR, false, this.options.ecmaVersion >= 8);
            this.checkYieldAwaitInDefaultParams();
        };
        // Parse a class declaration or literal (depending on the
        // `isStatement` parameter).
        pp$8.parseClass = function (node, isStatement) {
            this.next();
            // ecma-262 14.6 Class Definitions
            // A class definition is always strict mode code.
            var oldStrict = this.strict;
            this.strict = true;
            this.parseClassId(node, isStatement);
            this.parseClassSuper(node);
            var privateNameMap = this.enterClassBody();
            var classBody = this.startNode();
            var hadConstructor = false;
            classBody.body = [];
            this.expect(types$1.braceL);
            while (this.type !== types$1.braceR) {
                var element = this.parseClassElement(node.superClass !== null);
                if (element) {
                    classBody.body.push(element);
                    if (element.type === "MethodDefinition" && element.kind === "constructor") {
                        if (hadConstructor) {
                            this.raiseRecoverable(element.start, "Duplicate constructor in the same class");
                        }
                        hadConstructor = true;
                    }
                    else if (element.key && element.key.type === "PrivateIdentifier" && isPrivateNameConflicted(privateNameMap, element)) {
                        this.raiseRecoverable(element.key.start, ("Identifier '#" + (element.key.name) + "' has already been declared"));
                    }
                }
            }
            this.strict = oldStrict;
            this.next();
            node.body = this.finishNode(classBody, "ClassBody");
            this.exitClassBody();
            return this.finishNode(node, isStatement ? "ClassDeclaration" : "ClassExpression");
        };
        pp$8.parseClassElement = function (constructorAllowsSuper) {
            if (this.eat(types$1.semi)) {
                return null;
            }
            var ecmaVersion = this.options.ecmaVersion;
            var node = this.startNode();
            var keyName = "";
            var isGenerator = false;
            var isAsync = false;
            var kind = "method";
            var isStatic = false;
            if (this.eatContextual("static")) {
                // Parse static init block
                if (ecmaVersion >= 13 && this.eat(types$1.braceL)) {
                    this.parseClassStaticBlock(node);
                    return node;
                }
                if (this.isClassElementNameStart() || this.type === types$1.star) {
                    isStatic = true;
                }
                else {
                    keyName = "static";
                }
            }
            node.static = isStatic;
            if (!keyName && ecmaVersion >= 8 && this.eatContextual("async")) {
                if ((this.isClassElementNameStart() || this.type === types$1.star) && !this.canInsertSemicolon()) {
                    isAsync = true;
                }
                else {
                    keyName = "async";
                }
            }
            if (!keyName && (ecmaVersion >= 9 || !isAsync) && this.eat(types$1.star)) {
                isGenerator = true;
            }
            if (!keyName && !isAsync && !isGenerator) {
                var lastValue = this.value;
                if (this.eatContextual("get") || this.eatContextual("set")) {
                    if (this.isClassElementNameStart()) {
                        kind = lastValue;
                    }
                    else {
                        keyName = lastValue;
                    }
                }
            }
            // Parse element name
            if (keyName) {
                // 'async', 'get', 'set', or 'static' were not a keyword contextually.
                // The last token is any of those. Make it the element name.
                node.computed = false;
                node.key = this.startNodeAt(this.lastTokStart, this.lastTokStartLoc);
                node.key.name = keyName;
                this.finishNode(node.key, "Identifier");
            }
            else {
                this.parseClassElementName(node);
            }
            // Parse element value
            if (ecmaVersion < 13 || this.type === types$1.parenL || kind !== "method" || isGenerator || isAsync) {
                var isConstructor = !node.static && checkKeyName(node, "constructor");
                var allowsDirectSuper = isConstructor && constructorAllowsSuper;
                // Couldn't move this check into the 'parseClassMethod' method for backward compatibility.
                if (isConstructor && kind !== "method") {
                    this.raise(node.key.start, "Constructor can't have get/set modifier");
                }
                node.kind = isConstructor ? "constructor" : kind;
                this.parseClassMethod(node, isGenerator, isAsync, allowsDirectSuper);
            }
            else {
                this.parseClassField(node);
            }
            return node;
        };
        pp$8.isClassElementNameStart = function () {
            return (this.type === types$1.name ||
                this.type === types$1.privateId ||
                this.type === types$1.num ||
                this.type === types$1.string ||
                this.type === types$1.bracketL ||
                this.type.keyword);
        };
        pp$8.parseClassElementName = function (element) {
            if (this.type === types$1.privateId) {
                if (this.value === "constructor") {
                    this.raise(this.start, "Classes can't have an element named '#constructor'");
                }
                element.computed = false;
                element.key = this.parsePrivateIdent();
            }
            else {
                this.parsePropertyName(element);
            }
        };
        pp$8.parseClassMethod = function (method, isGenerator, isAsync, allowsDirectSuper) {
            // Check key and flags
            var key = method.key;
            if (method.kind === "constructor") {
                if (isGenerator) {
                    this.raise(key.start, "Constructor can't be a generator");
                }
                if (isAsync) {
                    this.raise(key.start, "Constructor can't be an async method");
                }
            }
            else if (method.static && checkKeyName(method, "prototype")) {
                this.raise(key.start, "Classes may not have a static property named prototype");
            }
            // Parse value
            var value = method.value = this.parseMethod(isGenerator, isAsync, allowsDirectSuper);
            // Check value
            if (method.kind === "get" && value.params.length !== 0) {
                this.raiseRecoverable(value.start, "getter should have no params");
            }
            if (method.kind === "set" && value.params.length !== 1) {
                this.raiseRecoverable(value.start, "setter should have exactly one param");
            }
            if (method.kind === "set" && value.params[0].type === "RestElement") {
                this.raiseRecoverable(value.params[0].start, "Setter cannot use rest params");
            }
            return this.finishNode(method, "MethodDefinition");
        };
        pp$8.parseClassField = function (field) {
            if (checkKeyName(field, "constructor")) {
                this.raise(field.key.start, "Classes can't have a field named 'constructor'");
            }
            else if (field.static && checkKeyName(field, "prototype")) {
                this.raise(field.key.start, "Classes can't have a static field named 'prototype'");
            }
            if (this.eat(types$1.eq)) {
                // To raise SyntaxError if 'arguments' exists in the initializer.
                var scope = this.currentThisScope();
                var inClassFieldInit = scope.inClassFieldInit;
                scope.inClassFieldInit = true;
                field.value = this.parseMaybeAssign();
                scope.inClassFieldInit = inClassFieldInit;
            }
            else {
                field.value = null;
            }
            this.semicolon();
            return this.finishNode(field, "PropertyDefinition");
        };
        pp$8.parseClassStaticBlock = function (node) {
            node.body = [];
            var oldLabels = this.labels;
            this.labels = [];
            this.enterScope(SCOPE_CLASS_STATIC_BLOCK | SCOPE_SUPER);
            while (this.type !== types$1.braceR) {
                var stmt = this.parseStatement(null);
                node.body.push(stmt);
            }
            this.next();
            this.exitScope();
            this.labels = oldLabels;
            return this.finishNode(node, "StaticBlock");
        };
        pp$8.parseClassId = function (node, isStatement) {
            if (this.type === types$1.name) {
                node.id = this.parseIdent();
                if (isStatement) {
                    this.checkLValSimple(node.id, BIND_LEXICAL, false);
                }
            }
            else {
                if (isStatement === true) {
                    this.unexpected();
                }
                node.id = null;
            }
        };
        pp$8.parseClassSuper = function (node) {
            node.superClass = this.eat(types$1._extends) ? this.parseExprSubscripts(null, false) : null;
        };
        pp$8.enterClassBody = function () {
            var element = { declared: Object.create(null), used: [] };
            this.privateNameStack.push(element);
            return element.declared;
        };
        pp$8.exitClassBody = function () {
            var ref = this.privateNameStack.pop();
            var declared = ref.declared;
            var used = ref.used;
            if (!this.options.checkPrivateFields) {
                return;
            }
            var len = this.privateNameStack.length;
            var parent = len === 0 ? null : this.privateNameStack[len - 1];
            for (var i = 0; i < used.length; ++i) {
                var id = used[i];
                if (!hasOwn(declared, id.name)) {
                    if (parent) {
                        parent.used.push(id);
                    }
                    else {
                        this.raiseRecoverable(id.start, ("Private field '#" + (id.name) + "' must be declared in an enclosing class"));
                    }
                }
            }
        };
        function isPrivateNameConflicted(privateNameMap, element) {
            var name = element.key.name;
            var curr = privateNameMap[name];
            var next = "true";
            if (element.type === "MethodDefinition" && (element.kind === "get" || element.kind === "set")) {
                next = (element.static ? "s" : "i") + element.kind;
            }
            // `class { get #a(){}; static set #a(_){} }` is also conflict.
            if (curr === "iget" && next === "iset" ||
                curr === "iset" && next === "iget" ||
                curr === "sget" && next === "sset" ||
                curr === "sset" && next === "sget") {
                privateNameMap[name] = "true";
                return false;
            }
            else if (!curr) {
                privateNameMap[name] = next;
                return false;
            }
            else {
                return true;
            }
        }
        function checkKeyName(node, name) {
            var computed = node.computed;
            var key = node.key;
            return !computed && (key.type === "Identifier" && key.name === name ||
                key.type === "Literal" && key.value === name);
        }
        // Parses module export declaration.
        pp$8.parseExportAllDeclaration = function (node, exports) {
            if (this.options.ecmaVersion >= 11) {
                if (this.eatContextual("as")) {
                    node.exported = this.parseModuleExportName();
                    this.checkExport(exports, node.exported, this.lastTokStart);
                }
                else {
                    node.exported = null;
                }
            }
            this.expectContextual("from");
            if (this.type !== types$1.string) {
                this.unexpected();
            }
            node.source = this.parseExprAtom();
            this.semicolon();
            return this.finishNode(node, "ExportAllDeclaration");
        };
        pp$8.parseExport = function (node, exports) {
            this.next();
            // export * from '...'
            if (this.eat(types$1.star)) {
                return this.parseExportAllDeclaration(node, exports);
            }
            if (this.eat(types$1._default)) { // export default ...
                this.checkExport(exports, "default", this.lastTokStart);
                node.declaration = this.parseExportDefaultDeclaration();
                return this.finishNode(node, "ExportDefaultDeclaration");
            }
            // export var|const|let|function|class ...
            if (this.shouldParseExportStatement()) {
                node.declaration = this.parseExportDeclaration(node);
                if (node.declaration.type === "VariableDeclaration") {
                    this.checkVariableExport(exports, node.declaration.declarations);
                }
                else {
                    this.checkExport(exports, node.declaration.id, node.declaration.id.start);
                }
                node.specifiers = [];
                node.source = null;
            }
            else { // export { x, y as z } [from '...']
                node.declaration = null;
                node.specifiers = this.parseExportSpecifiers(exports);
                if (this.eatContextual("from")) {
                    if (this.type !== types$1.string) {
                        this.unexpected();
                    }
                    node.source = this.parseExprAtom();
                }
                else {
                    for (var i = 0, list = node.specifiers; i < list.length; i += 1) {
                        // check for keywords used as local names
                        var spec = list[i];
                        this.checkUnreserved(spec.local);
                        // check if export is defined
                        this.checkLocalExport(spec.local);
                        if (spec.local.type === "Literal") {
                            this.raise(spec.local.start, "A string literal cannot be used as an exported binding without `from`.");
                        }
                    }
                    node.source = null;
                }
                this.semicolon();
            }
            return this.finishNode(node, "ExportNamedDeclaration");
        };
        pp$8.parseExportDeclaration = function (node) {
            return this.parseStatement(null);
        };
        pp$8.parseExportDefaultDeclaration = function () {
            var isAsync;
            if (this.type === types$1._function || (isAsync = this.isAsyncFunction())) {
                var fNode = this.startNode();
                this.next();
                if (isAsync) {
                    this.next();
                }
                return this.parseFunction(fNode, FUNC_STATEMENT | FUNC_NULLABLE_ID, false, isAsync);
            }
            else if (this.type === types$1._class) {
                var cNode = this.startNode();
                return this.parseClass(cNode, "nullableID");
            }
            else {
                var declaration = this.parseMaybeAssign();
                this.semicolon();
                return declaration;
            }
        };
        pp$8.checkExport = function (exports, name, pos) {
            if (!exports) {
                return;
            }
            if (typeof name !== "string") {
                name = name.type === "Identifier" ? name.name : name.value;
            }
            if (hasOwn(exports, name)) {
                this.raiseRecoverable(pos, "Duplicate export '" + name + "'");
            }
            exports[name] = true;
        };
        pp$8.checkPatternExport = function (exports, pat) {
            var type = pat.type;
            if (type === "Identifier") {
                this.checkExport(exports, pat, pat.start);
            }
            else if (type === "ObjectPattern") {
                for (var i = 0, list = pat.properties; i < list.length; i += 1) {
                    var prop = list[i];
                    this.checkPatternExport(exports, prop);
                }
            }
            else if (type === "ArrayPattern") {
                for (var i$1 = 0, list$1 = pat.elements; i$1 < list$1.length; i$1 += 1) {
                    var elt = list$1[i$1];
                    if (elt) {
                        this.checkPatternExport(exports, elt);
                    }
                }
            }
            else if (type === "Property") {
                this.checkPatternExport(exports, pat.value);
            }
            else if (type === "AssignmentPattern") {
                this.checkPatternExport(exports, pat.left);
            }
            else if (type === "RestElement") {
                this.checkPatternExport(exports, pat.argument);
            }
        };
        pp$8.checkVariableExport = function (exports, decls) {
            if (!exports) {
                return;
            }
            for (var i = 0, list = decls; i < list.length; i += 1) {
                var decl = list[i];
                this.checkPatternExport(exports, decl.id);
            }
        };
        pp$8.shouldParseExportStatement = function () {
            return this.type.keyword === "var" ||
                this.type.keyword === "const" ||
                this.type.keyword === "class" ||
                this.type.keyword === "function" ||
                this.isLet() ||
                this.isAsyncFunction();
        };
        // Parses a comma-separated list of module exports.
        pp$8.parseExportSpecifier = function (exports) {
            var node = this.startNode();
            node.local = this.parseModuleExportName();
            node.exported = this.eatContextual("as") ? this.parseModuleExportName() : node.local;
            this.checkExport(exports, node.exported, node.exported.start);
            return this.finishNode(node, "ExportSpecifier");
        };
        pp$8.parseExportSpecifiers = function (exports) {
            var nodes = [], first = true;
            // export { x, y as z } [from '...']
            this.expect(types$1.braceL);
            while (!this.eat(types$1.braceR)) {
                if (!first) {
                    this.expect(types$1.comma);
                    if (this.afterTrailingComma(types$1.braceR)) {
                        break;
                    }
                }
                else {
                    first = false;
                }
                nodes.push(this.parseExportSpecifier(exports));
            }
            return nodes;
        };
        // Parses import declaration.
        pp$8.parseImport = function (node) {
            this.next();
            // import '...'
            if (this.type === types$1.string) {
                node.specifiers = empty$1;
                node.source = this.parseExprAtom();
            }
            else {
                node.specifiers = this.parseImportSpecifiers();
                this.expectContextual("from");
                node.source = this.type === types$1.string ? this.parseExprAtom() : this.unexpected();
            }
            this.semicolon();
            return this.finishNode(node, "ImportDeclaration");
        };
        // Parses a comma-separated list of module imports.
        pp$8.parseImportSpecifier = function () {
            var node = this.startNode();
            node.imported = this.parseModuleExportName();
            if (this.eatContextual("as")) {
                node.local = this.parseIdent();
            }
            else {
                this.checkUnreserved(node.imported);
                node.local = node.imported;
            }
            this.checkLValSimple(node.local, BIND_LEXICAL);
            return this.finishNode(node, "ImportSpecifier");
        };
        pp$8.parseImportDefaultSpecifier = function () {
            // import defaultObj, { x, y as z } from '...'
            var node = this.startNode();
            node.local = this.parseIdent();
            this.checkLValSimple(node.local, BIND_LEXICAL);
            return this.finishNode(node, "ImportDefaultSpecifier");
        };
        pp$8.parseImportNamespaceSpecifier = function () {
            var node = this.startNode();
            this.next();
            this.expectContextual("as");
            node.local = this.parseIdent();
            this.checkLValSimple(node.local, BIND_LEXICAL);
            return this.finishNode(node, "ImportNamespaceSpecifier");
        };
        pp$8.parseImportSpecifiers = function () {
            var nodes = [], first = true;
            if (this.type === types$1.name) {
                nodes.push(this.parseImportDefaultSpecifier());
                if (!this.eat(types$1.comma)) {
                    return nodes;
                }
            }
            if (this.type === types$1.star) {
                nodes.push(this.parseImportNamespaceSpecifier());
                return nodes;
            }
            this.expect(types$1.braceL);
            while (!this.eat(types$1.braceR)) {
                if (!first) {
                    this.expect(types$1.comma);
                    if (this.afterTrailingComma(types$1.braceR)) {
                        break;
                    }
                }
                else {
                    first = false;
                }
                nodes.push(this.parseImportSpecifier());
            }
            return nodes;
        };
        pp$8.parseModuleExportName = function () {
            if (this.options.ecmaVersion >= 13 && this.type === types$1.string) {
                var stringLiteral = this.parseLiteral(this.value);
                if (loneSurrogate.test(stringLiteral.value)) {
                    this.raise(stringLiteral.start, "An export name cannot include a lone surrogate.");
                }
                return stringLiteral;
            }
            return this.parseIdent(true);
        };
        // Set `ExpressionStatement#directive` property for directive prologues.
        pp$8.adaptDirectivePrologue = function (statements) {
            for (var i = 0; i < statements.length && this.isDirectiveCandidate(statements[i]); ++i) {
                statements[i].directive = statements[i].expression.raw.slice(1, -1);
            }
        };
        pp$8.isDirectiveCandidate = function (statement) {
            return (this.options.ecmaVersion >= 5 &&
                statement.type === "ExpressionStatement" &&
                statement.expression.type === "Literal" &&
                typeof statement.expression.value === "string" &&
                // Reject parenthesized strings.
                (this.input[statement.start] === "\"" || this.input[statement.start] === "'"));
        };
        var pp$7 = Parser.prototype;
        // Convert existing expression atom to assignable pattern
        // if possible.
        pp$7.toAssignable = function (node, isBinding, refDestructuringErrors) {
            if (this.options.ecmaVersion >= 6 && node) {
                switch (node.type) {
                    case "Identifier":
                        if (this.inAsync && node.name === "await") {
                            this.raise(node.start, "Cannot use 'await' as identifier inside an async function");
                        }
                        break;
                    case "ObjectPattern":
                    case "ArrayPattern":
                    case "AssignmentPattern":
                    case "RestElement":
                        break;
                    case "ObjectExpression":
                        node.type = "ObjectPattern";
                        if (refDestructuringErrors) {
                            this.checkPatternErrors(refDestructuringErrors, true);
                        }
                        for (var i = 0, list = node.properties; i < list.length; i += 1) {
                            var prop = list[i];
                            this.toAssignable(prop, isBinding);
                            // Early error:
                            //   AssignmentRestProperty[Yield, Await] :
                            //     `...` DestructuringAssignmentTarget[Yield, Await]
                            //
                            //   It is a Syntax Error if |DestructuringAssignmentTarget| is an |ArrayLiteral| or an |ObjectLiteral|.
                            if (prop.type === "RestElement" &&
                                (prop.argument.type === "ArrayPattern" || prop.argument.type === "ObjectPattern")) {
                                this.raise(prop.argument.start, "Unexpected token");
                            }
                        }
                        break;
                    case "Property":
                        // AssignmentProperty has type === "Property"
                        if (node.kind !== "init") {
                            this.raise(node.key.start, "Object pattern can't contain getter or setter");
                        }
                        this.toAssignable(node.value, isBinding);
                        break;
                    case "ArrayExpression":
                        node.type = "ArrayPattern";
                        if (refDestructuringErrors) {
                            this.checkPatternErrors(refDestructuringErrors, true);
                        }
                        this.toAssignableList(node.elements, isBinding);
                        break;
                    case "SpreadElement":
                        node.type = "RestElement";
                        this.toAssignable(node.argument, isBinding);
                        if (node.argument.type === "AssignmentPattern") {
                            this.raise(node.argument.start, "Rest elements cannot have a default value");
                        }
                        break;
                    case "AssignmentExpression":
                        if (node.operator !== "=") {
                            this.raise(node.left.end, "Only '=' operator can be used for specifying default value.");
                        }
                        node.type = "AssignmentPattern";
                        delete node.operator;
                        this.toAssignable(node.left, isBinding);
                        break;
                    case "ParenthesizedExpression":
                        this.toAssignable(node.expression, isBinding, refDestructuringErrors);
                        break;
                    case "ChainExpression":
                        this.raiseRecoverable(node.start, "Optional chaining cannot appear in left-hand side");
                        break;
                    case "MemberExpression":
                        if (!isBinding) {
                            break;
                        }
                    default:
                        this.raise(node.start, "Assigning to rvalue");
                }
            }
            else if (refDestructuringErrors) {
                this.checkPatternErrors(refDestructuringErrors, true);
            }
            return node;
        };
        // Convert list of expression atoms to binding list.
        pp$7.toAssignableList = function (exprList, isBinding) {
            var end = exprList.length;
            for (var i = 0; i < end; i++) {
                var elt = exprList[i];
                if (elt) {
                    this.toAssignable(elt, isBinding);
                }
            }
            if (end) {
                var last = exprList[end - 1];
                if (this.options.ecmaVersion === 6 && isBinding && last && last.type === "RestElement" && last.argument.type !== "Identifier") {
                    this.unexpected(last.argument.start);
                }
            }
            return exprList;
        };
        // Parses spread element.
        pp$7.parseSpread = function (refDestructuringErrors) {
            var node = this.startNode();
            this.next();
            node.argument = this.parseMaybeAssign(false, refDestructuringErrors);
            return this.finishNode(node, "SpreadElement");
        };
        pp$7.parseRestBinding = function () {
            var node = this.startNode();
            this.next();
            // RestElement inside of a function parameter must be an identifier
            if (this.options.ecmaVersion === 6 && this.type !== types$1.name) {
                this.unexpected();
            }
            node.argument = this.parseBindingAtom();
            return this.finishNode(node, "RestElement");
        };
        // Parses lvalue (assignable) atom.
        pp$7.parseBindingAtom = function () {
            if (this.options.ecmaVersion >= 6) {
                switch (this.type) {
                    case types$1.bracketL:
                        var node = this.startNode();
                        this.next();
                        node.elements = this.parseBindingList(types$1.bracketR, true, true);
                        return this.finishNode(node, "ArrayPattern");
                    case types$1.braceL:
                        return this.parseObj(true);
                }
            }
            return this.parseIdent();
        };
        pp$7.parseBindingList = function (close, allowEmpty, allowTrailingComma, allowModifiers) {
            var elts = [], first = true;
            while (!this.eat(close)) {
                if (first) {
                    first = false;
                }
                else {
                    this.expect(types$1.comma);
                }
                if (allowEmpty && this.type === types$1.comma) {
                    elts.push(null);
                }
                else if (allowTrailingComma && this.afterTrailingComma(close)) {
                    break;
                }
                else if (this.type === types$1.ellipsis) {
                    var rest = this.parseRestBinding();
                    this.parseBindingListItem(rest);
                    elts.push(rest);
                    if (this.type === types$1.comma) {
                        this.raiseRecoverable(this.start, "Comma is not permitted after the rest element");
                    }
                    this.expect(close);
                    break;
                }
                else {
                    elts.push(this.parseAssignableListItem(allowModifiers));
                }
            }
            return elts;
        };
        pp$7.parseAssignableListItem = function (allowModifiers) {
            var elem = this.parseMaybeDefault(this.start, this.startLoc);
            this.parseBindingListItem(elem);
            return elem;
        };
        pp$7.parseBindingListItem = function (param) {
            return param;
        };
        // Parses assignment pattern around given atom if possible.
        pp$7.parseMaybeDefault = function (startPos, startLoc, left) {
            left = left || this.parseBindingAtom();
            if (this.options.ecmaVersion < 6 || !this.eat(types$1.eq)) {
                return left;
            }
            var node = this.startNodeAt(startPos, startLoc);
            node.left = left;
            node.right = this.parseMaybeAssign();
            return this.finishNode(node, "AssignmentPattern");
        };
        // The following three functions all verify that a node is an lvalue —
        // something that can be bound, or assigned to. In order to do so, they perform
        // a variety of checks:
        //
        // - Check that none of the bound/assigned-to identifiers are reserved words.
        // - Record name declarations for bindings in the appropriate scope.
        // - Check duplicate argument names, if checkClashes is set.
        //
        // If a complex binding pattern is encountered (e.g., object and array
        // destructuring), the entire pattern is recursively checked.
        //
        // There are three versions of checkLVal*() appropriate for different
        // circumstances:
        //
        // - checkLValSimple() shall be used if the syntactic construct supports
        //   nothing other than identifiers and member expressions. Parenthesized
        //   expressions are also correctly handled. This is generally appropriate for
        //   constructs for which the spec says
        //
        //   > It is a Syntax Error if AssignmentTargetType of [the production] is not
        //   > simple.
        //
        //   It is also appropriate for checking if an identifier is valid and not
        //   defined elsewhere, like import declarations or function/class identifiers.
        //
        //   Examples where this is used include:
        //     a += …;
        //     import a from '…';
        //   where a is the node to be checked.
        //
        // - checkLValPattern() shall be used if the syntactic construct supports
        //   anything checkLValSimple() supports, as well as object and array
        //   destructuring patterns. This is generally appropriate for constructs for
        //   which the spec says
        //
        //   > It is a Syntax Error if [the production] is neither an ObjectLiteral nor
        //   > an ArrayLiteral and AssignmentTargetType of [the production] is not
        //   > simple.
        //
        //   Examples where this is used include:
        //     (a = …);
        //     const a = …;
        //     try { … } catch (a) { … }
        //   where a is the node to be checked.
        //
        // - checkLValInnerPattern() shall be used if the syntactic construct supports
        //   anything checkLValPattern() supports, as well as default assignment
        //   patterns, rest elements, and other constructs that may appear within an
        //   object or array destructuring pattern.
        //
        //   As a special case, function parameters also use checkLValInnerPattern(),
        //   as they also support defaults and rest constructs.
        //
        // These functions deliberately support both assignment and binding constructs,
        // as the logic for both is exceedingly similar. If the node is the target of
        // an assignment, then bindingType should be set to BIND_NONE. Otherwise, it
        // should be set to the appropriate BIND_* constant, like BIND_VAR or
        // BIND_LEXICAL.
        //
        // If the function is called with a non-BIND_NONE bindingType, then
        // additionally a checkClashes object may be specified to allow checking for
        // duplicate argument names. checkClashes is ignored if the provided construct
        // is an assignment (i.e., bindingType is BIND_NONE).
        pp$7.checkLValSimple = function (expr, bindingType, checkClashes) {
            if (bindingType === void 0)
                bindingType = BIND_NONE;
            var isBind = bindingType !== BIND_NONE;
            switch (expr.type) {
                case "Identifier":
                    if (this.strict && this.reservedWordsStrictBind.test(expr.name)) {
                        this.raiseRecoverable(expr.start, (isBind ? "Binding " : "Assigning to ") + expr.name + " in strict mode");
                    }
                    if (isBind) {
                        if (bindingType === BIND_LEXICAL && expr.name === "let") {
                            this.raiseRecoverable(expr.start, "let is disallowed as a lexically bound name");
                        }
                        if (checkClashes) {
                            if (hasOwn(checkClashes, expr.name)) {
                                this.raiseRecoverable(expr.start, "Argument name clash");
                            }
                            checkClashes[expr.name] = true;
                        }
                        if (bindingType !== BIND_OUTSIDE) {
                            this.declareName(expr.name, bindingType, expr.start);
                        }
                    }
                    break;
                case "ChainExpression":
                    this.raiseRecoverable(expr.start, "Optional chaining cannot appear in left-hand side");
                    break;
                case "MemberExpression":
                    if (isBind) {
                        this.raiseRecoverable(expr.start, "Binding member expression");
                    }
                    break;
                case "ParenthesizedExpression":
                    if (isBind) {
                        this.raiseRecoverable(expr.start, "Binding parenthesized expression");
                    }
                    return this.checkLValSimple(expr.expression, bindingType, checkClashes);
                default:
                    this.raise(expr.start, (isBind ? "Binding" : "Assigning to") + " rvalue");
            }
        };
        pp$7.checkLValPattern = function (expr, bindingType, checkClashes) {
            if (bindingType === void 0)
                bindingType = BIND_NONE;
            switch (expr.type) {
                case "ObjectPattern":
                    for (var i = 0, list = expr.properties; i < list.length; i += 1) {
                        var prop = list[i];
                        this.checkLValInnerPattern(prop, bindingType, checkClashes);
                    }
                    break;
                case "ArrayPattern":
                    for (var i$1 = 0, list$1 = expr.elements; i$1 < list$1.length; i$1 += 1) {
                        var elem = list$1[i$1];
                        if (elem) {
                            this.checkLValInnerPattern(elem, bindingType, checkClashes);
                        }
                    }
                    break;
                default:
                    this.checkLValSimple(expr, bindingType, checkClashes);
            }
        };
        pp$7.checkLValInnerPattern = function (expr, bindingType, checkClashes) {
            if (bindingType === void 0)
                bindingType = BIND_NONE;
            switch (expr.type) {
                case "Property":
                    // AssignmentProperty has type === "Property"
                    this.checkLValInnerPattern(expr.value, bindingType, checkClashes);
                    break;
                case "AssignmentPattern":
                    this.checkLValPattern(expr.left, bindingType, checkClashes);
                    break;
                case "RestElement":
                    this.checkLValPattern(expr.argument, bindingType, checkClashes);
                    break;
                default:
                    this.checkLValPattern(expr, bindingType, checkClashes);
            }
        };
        // The algorithm used to determine whether a regexp can appear at a
        // given point in the program is loosely based on sweet.js' approach.
        // See https://github.com/mozilla/sweet.js/wiki/design
        var TokContext = function TokContext(token, isExpr, preserveSpace, override, generator) {
            this.token = token;
            this.isExpr = !!isExpr;
            this.preserveSpace = !!preserveSpace;
            this.override = override;
            this.generator = !!generator;
        };
        var types = {
            b_stat: new TokContext("{", false),
            b_expr: new TokContext("{", true),
            b_tmpl: new TokContext("${", false),
            p_stat: new TokContext("(", false),
            p_expr: new TokContext("(", true),
            q_tmpl: new TokContext("`", true, true, function (p) { return p.tryReadTemplateToken(); }),
            f_stat: new TokContext("function", false),
            f_expr: new TokContext("function", true),
            f_expr_gen: new TokContext("function", true, false, null, true),
            f_gen: new TokContext("function", false, false, null, true)
        };
        var pp$6 = Parser.prototype;
        pp$6.initialContext = function () {
            return [types.b_stat];
        };
        pp$6.curContext = function () {
            return this.context[this.context.length - 1];
        };
        pp$6.braceIsBlock = function (prevType) {
            var parent = this.curContext();
            if (parent === types.f_expr || parent === types.f_stat) {
                return true;
            }
            if (prevType === types$1.colon && (parent === types.b_stat || parent === types.b_expr)) {
                return !parent.isExpr;
            }
            // The check for `tt.name && exprAllowed` detects whether we are
            // after a `yield` or `of` construct. See the `updateContext` for
            // `tt.name`.
            if (prevType === types$1._return || prevType === types$1.name && this.exprAllowed) {
                return lineBreak.test(this.input.slice(this.lastTokEnd, this.start));
            }
            if (prevType === types$1._else || prevType === types$1.semi || prevType === types$1.eof || prevType === types$1.parenR || prevType === types$1.arrow) {
                return true;
            }
            if (prevType === types$1.braceL) {
                return parent === types.b_stat;
            }
            if (prevType === types$1._var || prevType === types$1._const || prevType === types$1.name) {
                return false;
            }
            return !this.exprAllowed;
        };
        pp$6.inGeneratorContext = function () {
            for (var i = this.context.length - 1; i >= 1; i--) {
                var context = this.context[i];
                if (context.token === "function") {
                    return context.generator;
                }
            }
            return false;
        };
        pp$6.updateContext = function (prevType) {
            var update, type = this.type;
            if (type.keyword && prevType === types$1.dot) {
                this.exprAllowed = false;
            }
            else if (update = type.updateContext) {
                update.call(this, prevType);
            }
            else {
                this.exprAllowed = type.beforeExpr;
            }
        };
        // Used to handle edge cases when token context could not be inferred correctly during tokenization phase
        pp$6.overrideContext = function (tokenCtx) {
            if (this.curContext() !== tokenCtx) {
                this.context[this.context.length - 1] = tokenCtx;
            }
        };
        // Token-specific context update code
        types$1.parenR.updateContext = types$1.braceR.updateContext = function () {
            if (this.context.length === 1) {
                this.exprAllowed = true;
                return;
            }
            var out = this.context.pop();
            if (out === types.b_stat && this.curContext().token === "function") {
                out = this.context.pop();
            }
            this.exprAllowed = !out.isExpr;
        };
        types$1.braceL.updateContext = function (prevType) {
            this.context.push(this.braceIsBlock(prevType) ? types.b_stat : types.b_expr);
            this.exprAllowed = true;
        };
        types$1.dollarBraceL.updateContext = function () {
            this.context.push(types.b_tmpl);
            this.exprAllowed = true;
        };
        types$1.parenL.updateContext = function (prevType) {
            var statementParens = prevType === types$1._if || prevType === types$1._for || prevType === types$1._with || prevType === types$1._while;
            this.context.push(statementParens ? types.p_stat : types.p_expr);
            this.exprAllowed = true;
        };
        types$1.incDec.updateContext = function () {
            // tokExprAllowed stays unchanged
        };
        types$1._function.updateContext = types$1._class.updateContext = function (prevType) {
            if (prevType.beforeExpr && prevType !== types$1._else &&
                !(prevType === types$1.semi && this.curContext() !== types.p_stat) &&
                !(prevType === types$1._return && lineBreak.test(this.input.slice(this.lastTokEnd, this.start))) &&
                !((prevType === types$1.colon || prevType === types$1.braceL) && this.curContext() === types.b_stat)) {
                this.context.push(types.f_expr);
            }
            else {
                this.context.push(types.f_stat);
            }
            this.exprAllowed = false;
        };
        types$1.colon.updateContext = function () {
            if (this.curContext().token === "function") {
                this.context.pop();
            }
            this.exprAllowed = true;
        };
        types$1.backQuote.updateContext = function () {
            if (this.curContext() === types.q_tmpl) {
                this.context.pop();
            }
            else {
                this.context.push(types.q_tmpl);
            }
            this.exprAllowed = false;
        };
        types$1.star.updateContext = function (prevType) {
            if (prevType === types$1._function) {
                var index = this.context.length - 1;
                if (this.context[index] === types.f_expr) {
                    this.context[index] = types.f_expr_gen;
                }
                else {
                    this.context[index] = types.f_gen;
                }
            }
            this.exprAllowed = true;
        };
        types$1.name.updateContext = function (prevType) {
            var allowed = false;
            if (this.options.ecmaVersion >= 6 && prevType !== types$1.dot) {
                if (this.value === "of" && !this.exprAllowed ||
                    this.value === "yield" && this.inGeneratorContext()) {
                    allowed = true;
                }
            }
            this.exprAllowed = allowed;
        };
        // A recursive descent parser operates by defining functions for all
        // syntactic elements, and recursively calling those, each function
        // advancing the input stream and returning an AST node. Precedence
        // of constructs (for example, the fact that `!x[1]` means `!(x[1])`
        // instead of `(!x)[1]` is handled by the fact that the parser
        // function that parses unary prefix operators is called first, and
        // in turn calls the function that parses `[]` subscripts — that
        // way, it'll receive the node for `x[1]` already parsed, and wraps
        // *that* in the unary operator node.
        //
        // Acorn uses an [operator precedence parser][opp] to handle binary
        // operator precedence, because it is much more compact than using
        // the technique outlined above, which uses different, nesting
        // functions to specify precedence, for all of the ten binary
        // precedence levels that JavaScript defines.
        //
        // [opp]: http://en.wikipedia.org/wiki/Operator-precedence_parser
        var pp$5 = Parser.prototype;
        // Check if property name clashes with already added.
        // Object/class getters and setters are not allowed to clash —
        // either with each other or with an init property — and in
        // strict mode, init properties are also not allowed to be repeated.
        pp$5.checkPropClash = function (prop, propHash, refDestructuringErrors) {
            if (this.options.ecmaVersion >= 9 && prop.type === "SpreadElement") {
                return;
            }
            if (this.options.ecmaVersion >= 6 && (prop.computed || prop.method || prop.shorthand)) {
                return;
            }
            var key = prop.key;
            var name;
            switch (key.type) {
                case "Identifier":
                    name = key.name;
                    break;
                case "Literal":
                    name = String(key.value);
                    break;
                default: return;
            }
            var kind = prop.kind;
            if (this.options.ecmaVersion >= 6) {
                if (name === "__proto__" && kind === "init") {
                    if (propHash.proto) {
                        if (refDestructuringErrors) {
                            if (refDestructuringErrors.doubleProto < 0) {
                                refDestructuringErrors.doubleProto = key.start;
                            }
                        }
                        else {
                            this.raiseRecoverable(key.start, "Redefinition of __proto__ property");
                        }
                    }
                    propHash.proto = true;
                }
                return;
            }
            name = "$" + name;
            var other = propHash[name];
            if (other) {
                var redefinition;
                if (kind === "init") {
                    redefinition = this.strict && other.init || other.get || other.set;
                }
                else {
                    redefinition = other.init || other[kind];
                }
                if (redefinition) {
                    this.raiseRecoverable(key.start, "Redefinition of property");
                }
            }
            else {
                other = propHash[name] = {
                    init: false,
                    get: false,
                    set: false
                };
            }
            other[kind] = true;
        };
        // ### Expression parsing
        // These nest, from the most general expression type at the top to
        // 'atomic', nondivisible expression types at the bottom. Most of
        // the functions will simply let the function(s) below them parse,
        // and, *if* the syntactic construct they handle is present, wrap
        // the AST node that the inner parser gave them in another node.
        // Parse a full expression. The optional arguments are used to
        // forbid the `in` operator (in for loops initalization expressions)
        // and provide reference for storing '=' operator inside shorthand
        // property assignment in contexts where both object expression
        // and object pattern might appear (so it's possible to raise
        // delayed syntax error at correct position).
        pp$5.parseExpression = function (forInit, refDestructuringErrors) {
            var startPos = this.start, startLoc = this.startLoc;
            var expr = this.parseMaybeAssign(forInit, refDestructuringErrors);
            if (this.type === types$1.comma) {
                var node = this.startNodeAt(startPos, startLoc);
                node.expressions = [expr];
                while (this.eat(types$1.comma)) {
                    node.expressions.push(this.parseMaybeAssign(forInit, refDestructuringErrors));
                }
                return this.finishNode(node, "SequenceExpression");
            }
            return expr;
        };
        // Parse an assignment expression. This includes applications of
        // operators like `+=`.
        pp$5.parseMaybeAssign = function (forInit, refDestructuringErrors, afterLeftParse) {
            if (this.isContextual("yield")) {
                if (this.inGenerator) {
                    return this.parseYield(forInit);
                }
                // The tokenizer will assume an expression is allowed after
                // `yield`, but this isn't that kind of yield
                else {
                    this.exprAllowed = false;
                }
            }
            var ownDestructuringErrors = false, oldParenAssign = -1, oldTrailingComma = -1, oldDoubleProto = -1;
            if (refDestructuringErrors) {
                oldParenAssign = refDestructuringErrors.parenthesizedAssign;
                oldTrailingComma = refDestructuringErrors.trailingComma;
                oldDoubleProto = refDestructuringErrors.doubleProto;
                refDestructuringErrors.parenthesizedAssign = refDestructuringErrors.trailingComma = -1;
            }
            else {
                refDestructuringErrors = new DestructuringErrors;
                ownDestructuringErrors = true;
            }
            var startPos = this.start, startLoc = this.startLoc;
            if (this.type === types$1.parenL || this.type === types$1.name) {
                this.potentialArrowAt = this.start;
                this.potentialArrowInForAwait = forInit === "await";
            }
            var left = this.parseMaybeConditional(forInit, refDestructuringErrors);
            if (afterLeftParse) {
                left = afterLeftParse.call(this, left, startPos, startLoc);
            }
            if (this.type.isAssign) {
                var node = this.startNodeAt(startPos, startLoc);
                node.operator = this.value;
                if (this.type === types$1.eq) {
                    left = this.toAssignable(left, false, refDestructuringErrors);
                }
                if (!ownDestructuringErrors) {
                    refDestructuringErrors.parenthesizedAssign = refDestructuringErrors.trailingComma = refDestructuringErrors.doubleProto = -1;
                }
                if (refDestructuringErrors.shorthandAssign >= left.start) {
                    refDestructuringErrors.shorthandAssign = -1;
                } // reset because shorthand default was used correctly
                if (this.type === types$1.eq) {
                    this.checkLValPattern(left);
                }
                else {
                    this.checkLValSimple(left);
                }
                node.left = left;
                this.next();
                node.right = this.parseMaybeAssign(forInit);
                if (oldDoubleProto > -1) {
                    refDestructuringErrors.doubleProto = oldDoubleProto;
                }
                return this.finishNode(node, "AssignmentExpression");
            }
            else {
                if (ownDestructuringErrors) {
                    this.checkExpressionErrors(refDestructuringErrors, true);
                }
            }
            if (oldParenAssign > -1) {
                refDestructuringErrors.parenthesizedAssign = oldParenAssign;
            }
            if (oldTrailingComma > -1) {
                refDestructuringErrors.trailingComma = oldTrailingComma;
            }
            return left;
        };
        // Parse a ternary conditional (`?:`) operator.
        pp$5.parseMaybeConditional = function (forInit, refDestructuringErrors) {
            var startPos = this.start, startLoc = this.startLoc;
            var expr = this.parseExprOps(forInit, refDestructuringErrors);
            if (this.checkExpressionErrors(refDestructuringErrors)) {
                return expr;
            }
            if (this.eat(types$1.question)) {
                var node = this.startNodeAt(startPos, startLoc);
                node.test = expr;
                node.consequent = this.parseMaybeAssign();
                this.expect(types$1.colon);
                node.alternate = this.parseMaybeAssign(forInit);
                return this.finishNode(node, "ConditionalExpression");
            }
            return expr;
        };
        // Start the precedence parser.
        pp$5.parseExprOps = function (forInit, refDestructuringErrors) {
            var startPos = this.start, startLoc = this.startLoc;
            var expr = this.parseMaybeUnary(refDestructuringErrors, false, false, forInit);
            if (this.checkExpressionErrors(refDestructuringErrors)) {
                return expr;
            }
            return expr.start === startPos && expr.type === "ArrowFunctionExpression" ? expr : this.parseExprOp(expr, startPos, startLoc, -1, forInit);
        };
        // Parse binary operators with the operator precedence parsing
        // algorithm. `left` is the left-hand side of the operator.
        // `minPrec` provides context that allows the function to stop and
        // defer further parser to one of its callers when it encounters an
        // operator that has a lower precedence than the set it is parsing.
        pp$5.parseExprOp = function (left, leftStartPos, leftStartLoc, minPrec, forInit) {
            var prec = this.type.binop;
            if (prec != null && (!forInit || this.type !== types$1._in)) {
                if (prec > minPrec) {
                    var logical = this.type === types$1.logicalOR || this.type === types$1.logicalAND;
                    var coalesce = this.type === types$1.coalesce;
                    if (coalesce) {
                        // Handle the precedence of `tt.coalesce` as equal to the range of logical expressions.
                        // In other words, `node.right` shouldn't contain logical expressions in order to check the mixed error.
                        prec = types$1.logicalAND.binop;
                    }
                    var op = this.value;
                    this.next();
                    var startPos = this.start, startLoc = this.startLoc;
                    var right = this.parseExprOp(this.parseMaybeUnary(null, false, false, forInit), startPos, startLoc, prec, forInit);
                    var node = this.buildBinary(leftStartPos, leftStartLoc, left, right, op, logical || coalesce);
                    if ((logical && this.type === types$1.coalesce) || (coalesce && (this.type === types$1.logicalOR || this.type === types$1.logicalAND))) {
                        this.raiseRecoverable(this.start, "Logical expressions and coalesce expressions cannot be mixed. Wrap either by parentheses");
                    }
                    return this.parseExprOp(node, leftStartPos, leftStartLoc, minPrec, forInit);
                }
            }
            return left;
        };
        pp$5.buildBinary = function (startPos, startLoc, left, right, op, logical) {
            if (right.type === "PrivateIdentifier") {
                this.raise(right.start, "Private identifier can only be left side of binary expression");
            }
            var node = this.startNodeAt(startPos, startLoc);
            node.left = left;
            node.operator = op;
            node.right = right;
            return this.finishNode(node, logical ? "LogicalExpression" : "BinaryExpression");
        };
        // Parse unary operators, both prefix and postfix.
        pp$5.parseMaybeUnary = function (refDestructuringErrors, sawUnary, incDec, forInit) {
            var startPos = this.start, startLoc = this.startLoc, expr;
            if (this.isContextual("await") && this.canAwait) {
                expr = this.parseAwait(forInit);
                sawUnary = true;
            }
            else if (this.type.prefix) {
                var node = this.startNode(), update = this.type === types$1.incDec;
                node.operator = this.value;
                node.prefix = true;
                this.next();
                node.argument = this.parseMaybeUnary(null, true, update, forInit);
                this.checkExpressionErrors(refDestructuringErrors, true);
                if (update) {
                    this.checkLValSimple(node.argument);
                }
                else if (this.strict && node.operator === "delete" &&
                    node.argument.type === "Identifier") {
                    this.raiseRecoverable(node.start, "Deleting local variable in strict mode");
                }
                else if (node.operator === "delete" && isPrivateFieldAccess(node.argument)) {
                    this.raiseRecoverable(node.start, "Private fields can not be deleted");
                }
                else {
                    sawUnary = true;
                }
                expr = this.finishNode(node, update ? "UpdateExpression" : "UnaryExpression");
            }
            else if (!sawUnary && this.type === types$1.privateId) {
                if ((forInit || this.privateNameStack.length === 0) && this.options.checkPrivateFields) {
                    this.unexpected();
                }
                expr = this.parsePrivateIdent();
                // only could be private fields in 'in', such as #x in obj
                if (this.type !== types$1._in) {
                    this.unexpected();
                }
            }
            else {
                expr = this.parseExprSubscripts(refDestructuringErrors, forInit);
                if (this.checkExpressionErrors(refDestructuringErrors)) {
                    return expr;
                }
                while (this.type.postfix && !this.canInsertSemicolon()) {
                    var node$1 = this.startNodeAt(startPos, startLoc);
                    node$1.operator = this.value;
                    node$1.prefix = false;
                    node$1.argument = expr;
                    this.checkLValSimple(expr);
                    this.next();
                    expr = this.finishNode(node$1, "UpdateExpression");
                }
            }
            if (!incDec && this.eat(types$1.starstar)) {
                if (sawUnary) {
                    this.unexpected(this.lastTokStart);
                }
                else {
                    return this.buildBinary(startPos, startLoc, expr, this.parseMaybeUnary(null, false, false, forInit), "**", false);
                }
            }
            else {
                return expr;
            }
        };
        function isPrivateFieldAccess(node) {
            return (node.type === "MemberExpression" && node.property.type === "PrivateIdentifier" ||
                node.type === "ChainExpression" && isPrivateFieldAccess(node.expression));
        }
        // Parse call, dot, and `[]`-subscript expressions.
        pp$5.parseExprSubscripts = function (refDestructuringErrors, forInit) {
            var startPos = this.start, startLoc = this.startLoc;
            var expr = this.parseExprAtom(refDestructuringErrors, forInit);
            if (expr.type === "ArrowFunctionExpression" && this.input.slice(this.lastTokStart, this.lastTokEnd) !== ")") {
                return expr;
            }
            var result = this.parseSubscripts(expr, startPos, startLoc, false, forInit);
            if (refDestructuringErrors && result.type === "MemberExpression") {
                if (refDestructuringErrors.parenthesizedAssign >= result.start) {
                    refDestructuringErrors.parenthesizedAssign = -1;
                }
                if (refDestructuringErrors.parenthesizedBind >= result.start) {
                    refDestructuringErrors.parenthesizedBind = -1;
                }
                if (refDestructuringErrors.trailingComma >= result.start) {
                    refDestructuringErrors.trailingComma = -1;
                }
            }
            return result;
        };
        pp$5.parseSubscripts = function (base, startPos, startLoc, noCalls, forInit) {
            var maybeAsyncArrow = this.options.ecmaVersion >= 8 && base.type === "Identifier" && base.name === "async" &&
                this.lastTokEnd === base.end && !this.canInsertSemicolon() && base.end - base.start === 5 &&
                this.potentialArrowAt === base.start;
            var optionalChained = false;
            while (true) {
                var element = this.parseSubscript(base, startPos, startLoc, noCalls, maybeAsyncArrow, optionalChained, forInit);
                if (element.optional) {
                    optionalChained = true;
                }
                if (element === base || element.type === "ArrowFunctionExpression") {
                    if (optionalChained) {
                        var chainNode = this.startNodeAt(startPos, startLoc);
                        chainNode.expression = element;
                        element = this.finishNode(chainNode, "ChainExpression");
                    }
                    return element;
                }
                base = element;
            }
        };
        pp$5.shouldParseAsyncArrow = function () {
            return !this.canInsertSemicolon() && this.eat(types$1.arrow);
        };
        pp$5.parseSubscriptAsyncArrow = function (startPos, startLoc, exprList, forInit) {
            return this.parseArrowExpression(this.startNodeAt(startPos, startLoc), exprList, true, forInit);
        };
        pp$5.parseSubscript = function (base, startPos, startLoc, noCalls, maybeAsyncArrow, optionalChained, forInit) {
            var optionalSupported = this.options.ecmaVersion >= 11;
            var optional = optionalSupported && this.eat(types$1.questionDot);
            if (noCalls && optional) {
                this.raise(this.lastTokStart, "Optional chaining cannot appear in the callee of new expressions");
            }
            var computed = this.eat(types$1.bracketL);
            if (computed || (optional && this.type !== types$1.parenL && this.type !== types$1.backQuote) || this.eat(types$1.dot)) {
                var node = this.startNodeAt(startPos, startLoc);
                node.object = base;
                if (computed) {
                    node.property = this.parseExpression();
                    this.expect(types$1.bracketR);
                }
                else if (this.type === types$1.privateId && base.type !== "Super") {
                    node.property = this.parsePrivateIdent();
                }
                else {
                    node.property = this.parseIdent(this.options.allowReserved !== "never");
                }
                node.computed = !!computed;
                if (optionalSupported) {
                    node.optional = optional;
                }
                base = this.finishNode(node, "MemberExpression");
            }
            else if (!noCalls && this.eat(types$1.parenL)) {
                var refDestructuringErrors = new DestructuringErrors, oldYieldPos = this.yieldPos, oldAwaitPos = this.awaitPos, oldAwaitIdentPos = this.awaitIdentPos;
                this.yieldPos = 0;
                this.awaitPos = 0;
                this.awaitIdentPos = 0;
                var exprList = this.parseExprList(types$1.parenR, this.options.ecmaVersion >= 8, false, refDestructuringErrors);
                if (maybeAsyncArrow && !optional && this.shouldParseAsyncArrow()) {
                    this.checkPatternErrors(refDestructuringErrors, false);
                    this.checkYieldAwaitInDefaultParams();
                    if (this.awaitIdentPos > 0) {
                        this.raise(this.awaitIdentPos, "Cannot use 'await' as identifier inside an async function");
                    }
                    this.yieldPos = oldYieldPos;
                    this.awaitPos = oldAwaitPos;
                    this.awaitIdentPos = oldAwaitIdentPos;
                    return this.parseSubscriptAsyncArrow(startPos, startLoc, exprList, forInit);
                }
                this.checkExpressionErrors(refDestructuringErrors, true);
                this.yieldPos = oldYieldPos || this.yieldPos;
                this.awaitPos = oldAwaitPos || this.awaitPos;
                this.awaitIdentPos = oldAwaitIdentPos || this.awaitIdentPos;
                var node$1 = this.startNodeAt(startPos, startLoc);
                node$1.callee = base;
                node$1.arguments = exprList;
                if (optionalSupported) {
                    node$1.optional = optional;
                }
                base = this.finishNode(node$1, "CallExpression");
            }
            else if (this.type === types$1.backQuote) {
                if (optional || optionalChained) {
                    this.raise(this.start, "Optional chaining cannot appear in the tag of tagged template expressions");
                }
                var node$2 = this.startNodeAt(startPos, startLoc);
                node$2.tag = base;
                node$2.quasi = this.parseTemplate({ isTagged: true });
                base = this.finishNode(node$2, "TaggedTemplateExpression");
            }
            return base;
        };
        // Parse an atomic expression — either a single token that is an
        // expression, an expression started by a keyword like `function` or
        // `new`, or an expression wrapped in punctuation like `()`, `[]`,
        // or `{}`.
        pp$5.parseExprAtom = function (refDestructuringErrors, forInit, forNew) {
            // If a division operator appears in an expression position, the
            // tokenizer got confused, and we force it to read a regexp instead.
            if (this.type === types$1.slash) {
                this.readRegexp();
            }
            var node, canBeArrow = this.potentialArrowAt === this.start;
            switch (this.type) {
                case types$1._super:
                    if (!this.allowSuper) {
                        this.raise(this.start, "'super' keyword outside a method");
                    }
                    node = this.startNode();
                    this.next();
                    if (this.type === types$1.parenL && !this.allowDirectSuper) {
                        this.raise(node.start, "super() call outside constructor of a subclass");
                    }
                    // The `super` keyword can appear at below:
                    // SuperProperty:
                    //     super [ Expression ]
                    //     super . IdentifierName
                    // SuperCall:
                    //     super ( Arguments )
                    if (this.type !== types$1.dot && this.type !== types$1.bracketL && this.type !== types$1.parenL) {
                        this.unexpected();
                    }
                    return this.finishNode(node, "Super");
                case types$1._this:
                    node = this.startNode();
                    this.next();
                    return this.finishNode(node, "ThisExpression");
                case types$1.name:
                    var startPos = this.start, startLoc = this.startLoc, containsEsc = this.containsEsc;
                    var id = this.parseIdent(false);
                    if (this.options.ecmaVersion >= 8 && !containsEsc && id.name === "async" && !this.canInsertSemicolon() && this.eat(types$1._function)) {
                        this.overrideContext(types.f_expr);
                        return this.parseFunction(this.startNodeAt(startPos, startLoc), 0, false, true, forInit);
                    }
                    if (canBeArrow && !this.canInsertSemicolon()) {
                        if (this.eat(types$1.arrow)) {
                            return this.parseArrowExpression(this.startNodeAt(startPos, startLoc), [id], false, forInit);
                        }
                        if (this.options.ecmaVersion >= 8 && id.name === "async" && this.type === types$1.name && !containsEsc &&
                            (!this.potentialArrowInForAwait || this.value !== "of" || this.containsEsc)) {
                            id = this.parseIdent(false);
                            if (this.canInsertSemicolon() || !this.eat(types$1.arrow)) {
                                this.unexpected();
                            }
                            return this.parseArrowExpression(this.startNodeAt(startPos, startLoc), [id], true, forInit);
                        }
                    }
                    return id;
                case types$1.regexp:
                    var value = this.value;
                    node = this.parseLiteral(value.value);
                    node.regex = { pattern: value.pattern, flags: value.flags };
                    return node;
                case types$1.num:
                case types$1.string:
                    return this.parseLiteral(this.value);
                case types$1._null:
                case types$1._true:
                case types$1._false:
                    node = this.startNode();
                    node.value = this.type === types$1._null ? null : this.type === types$1._true;
                    node.raw = this.type.keyword;
                    this.next();
                    return this.finishNode(node, "Literal");
                case types$1.parenL:
                    var start = this.start, expr = this.parseParenAndDistinguishExpression(canBeArrow, forInit);
                    if (refDestructuringErrors) {
                        if (refDestructuringErrors.parenthesizedAssign < 0 && !this.isSimpleAssignTarget(expr)) {
                            refDestructuringErrors.parenthesizedAssign = start;
                        }
                        if (refDestructuringErrors.parenthesizedBind < 0) {
                            refDestructuringErrors.parenthesizedBind = start;
                        }
                    }
                    return expr;
                case types$1.bracketL:
                    node = this.startNode();
                    this.next();
                    node.elements = this.parseExprList(types$1.bracketR, true, true, refDestructuringErrors);
                    return this.finishNode(node, "ArrayExpression");
                case types$1.braceL:
                    this.overrideContext(types.b_expr);
                    return this.parseObj(false, refDestructuringErrors);
                case types$1._function:
                    node = this.startNode();
                    this.next();
                    return this.parseFunction(node, 0);
                case types$1._class:
                    return this.parseClass(this.startNode(), false);
                case types$1._new:
                    return this.parseNew();
                case types$1.backQuote:
                    return this.parseTemplate();
                case types$1._import:
                    if (this.options.ecmaVersion >= 11) {
                        return this.parseExprImport(forNew);
                    }
                    else {
                        return this.unexpected();
                    }
                default:
                    return this.parseExprAtomDefault();
            }
        };
        pp$5.parseExprAtomDefault = function () {
            this.unexpected();
        };
        pp$5.parseExprImport = function (forNew) {
            var node = this.startNode();
            // Consume `import` as an identifier for `import.meta`.
            // Because `this.parseIdent(true)` doesn't check escape sequences, it needs the check of `this.containsEsc`.
            if (this.containsEsc) {
                this.raiseRecoverable(this.start, "Escape sequence in keyword import");
            }
            this.next();
            if (this.type === types$1.parenL && !forNew) {
                return this.parseDynamicImport(node);
            }
            else if (this.type === types$1.dot) {
                var meta = this.startNodeAt(node.start, node.loc && node.loc.start);
                meta.name = "import";
                node.meta = this.finishNode(meta, "Identifier");
                return this.parseImportMeta(node);
            }
            else {
                this.unexpected();
            }
        };
        pp$5.parseDynamicImport = function (node) {
            this.next(); // skip `(`
            // Parse node.source.
            node.source = this.parseMaybeAssign();
            // Verify ending.
            if (!this.eat(types$1.parenR)) {
                var errorPos = this.start;
                if (this.eat(types$1.comma) && this.eat(types$1.parenR)) {
                    this.raiseRecoverable(errorPos, "Trailing comma is not allowed in import()");
                }
                else {
                    this.unexpected(errorPos);
                }
            }
            return this.finishNode(node, "ImportExpression");
        };
        pp$5.parseImportMeta = function (node) {
            this.next(); // skip `.`
            var containsEsc = this.containsEsc;
            node.property = this.parseIdent(true);
            if (node.property.name !== "meta") {
                this.raiseRecoverable(node.property.start, "The only valid meta property for import is 'import.meta'");
            }
            if (containsEsc) {
                this.raiseRecoverable(node.start, "'import.meta' must not contain escaped characters");
            }
            if (this.options.sourceType !== "module" && !this.options.allowImportExportEverywhere) {
                this.raiseRecoverable(node.start, "Cannot use 'import.meta' outside a module");
            }
            return this.finishNode(node, "MetaProperty");
        };
        pp$5.parseLiteral = function (value) {
            var node = this.startNode();
            node.value = value;
            node.raw = this.input.slice(this.start, this.end);
            if (node.raw.charCodeAt(node.raw.length - 1) === 110) {
                node.bigint = node.raw.slice(0, -1).replace(/_/g, "");
            }
            this.next();
            return this.finishNode(node, "Literal");
        };
        pp$5.parseParenExpression = function () {
            this.expect(types$1.parenL);
            var val = this.parseExpression();
            this.expect(types$1.parenR);
            return val;
        };
        pp$5.shouldParseArrow = function (exprList) {
            return !this.canInsertSemicolon();
        };
        pp$5.parseParenAndDistinguishExpression = function (canBeArrow, forInit) {
            var startPos = this.start, startLoc = this.startLoc, val, allowTrailingComma = this.options.ecmaVersion >= 8;
            if (this.options.ecmaVersion >= 6) {
                this.next();
                var innerStartPos = this.start, innerStartLoc = this.startLoc;
                var exprList = [], first = true, lastIsComma = false;
                var refDestructuringErrors = new DestructuringErrors, oldYieldPos = this.yieldPos, oldAwaitPos = this.awaitPos, spreadStart;
                this.yieldPos = 0;
                this.awaitPos = 0;
                // Do not save awaitIdentPos to allow checking awaits nested in parameters
                while (this.type !== types$1.parenR) {
                    first ? first = false : this.expect(types$1.comma);
                    if (allowTrailingComma && this.afterTrailingComma(types$1.parenR, true)) {
                        lastIsComma = true;
                        break;
                    }
                    else if (this.type === types$1.ellipsis) {
                        spreadStart = this.start;
                        exprList.push(this.parseParenItem(this.parseRestBinding()));
                        if (this.type === types$1.comma) {
                            this.raiseRecoverable(this.start, "Comma is not permitted after the rest element");
                        }
                        break;
                    }
                    else {
                        exprList.push(this.parseMaybeAssign(false, refDestructuringErrors, this.parseParenItem));
                    }
                }
                var innerEndPos = this.lastTokEnd, innerEndLoc = this.lastTokEndLoc;
                this.expect(types$1.parenR);
                if (canBeArrow && this.shouldParseArrow(exprList) && this.eat(types$1.arrow)) {
                    this.checkPatternErrors(refDestructuringErrors, false);
                    this.checkYieldAwaitInDefaultParams();
                    this.yieldPos = oldYieldPos;
                    this.awaitPos = oldAwaitPos;
                    return this.parseParenArrowList(startPos, startLoc, exprList, forInit);
                }
                if (!exprList.length || lastIsComma) {
                    this.unexpected(this.lastTokStart);
                }
                if (spreadStart) {
                    this.unexpected(spreadStart);
                }
                this.checkExpressionErrors(refDestructuringErrors, true);
                this.yieldPos = oldYieldPos || this.yieldPos;
                this.awaitPos = oldAwaitPos || this.awaitPos;
                if (exprList.length > 1) {
                    val = this.startNodeAt(innerStartPos, innerStartLoc);
                    val.expressions = exprList;
                    this.finishNodeAt(val, "SequenceExpression", innerEndPos, innerEndLoc);
                }
                else {
                    val = exprList[0];
                }
            }
            else {
                val = this.parseParenExpression();
            }
            if (this.options.preserveParens) {
                var par = this.startNodeAt(startPos, startLoc);
                par.expression = val;
                return this.finishNode(par, "ParenthesizedExpression");
            }
            else {
                return val;
            }
        };
        pp$5.parseParenItem = function (item) {
            return item;
        };
        pp$5.parseParenArrowList = function (startPos, startLoc, exprList, forInit) {
            return this.parseArrowExpression(this.startNodeAt(startPos, startLoc), exprList, false, forInit);
        };
        // New's precedence is slightly tricky. It must allow its argument to
        // be a `[]` or dot subscript expression, but not a call — at least,
        // not without wrapping it in parentheses. Thus, it uses the noCalls
        // argument to parseSubscripts to prevent it from consuming the
        // argument list.
        var empty = [];
        pp$5.parseNew = function () {
            if (this.containsEsc) {
                this.raiseRecoverable(this.start, "Escape sequence in keyword new");
            }
            var node = this.startNode();
            this.next();
            if (this.options.ecmaVersion >= 6 && this.type === types$1.dot) {
                var meta = this.startNodeAt(node.start, node.loc && node.loc.start);
                meta.name = "new";
                node.meta = this.finishNode(meta, "Identifier");
                this.next();
                var containsEsc = this.containsEsc;
                node.property = this.parseIdent(true);
                if (node.property.name !== "target") {
                    this.raiseRecoverable(node.property.start, "The only valid meta property for new is 'new.target'");
                }
                if (containsEsc) {
                    this.raiseRecoverable(node.start, "'new.target' must not contain escaped characters");
                }
                if (!this.allowNewDotTarget) {
                    this.raiseRecoverable(node.start, "'new.target' can only be used in functions and class static block");
                }
                return this.finishNode(node, "MetaProperty");
            }
            var startPos = this.start, startLoc = this.startLoc;
            node.callee = this.parseSubscripts(this.parseExprAtom(null, false, true), startPos, startLoc, true, false);
            if (this.eat(types$1.parenL)) {
                node.arguments = this.parseExprList(types$1.parenR, this.options.ecmaVersion >= 8, false);
            }
            else {
                node.arguments = empty;
            }
            return this.finishNode(node, "NewExpression");
        };
        // Parse template expression.
        pp$5.parseTemplateElement = function (ref) {
            var isTagged = ref.isTagged;
            var elem = this.startNode();
            if (this.type === types$1.invalidTemplate) {
                if (!isTagged) {
                    this.raiseRecoverable(this.start, "Bad escape sequence in untagged template literal");
                }
                elem.value = {
                    raw: this.value,
                    cooked: null
                };
            }
            else {
                elem.value = {
                    raw: this.input.slice(this.start, this.end).replace(/\r\n?/g, "\n"),
                    cooked: this.value
                };
            }
            this.next();
            elem.tail = this.type === types$1.backQuote;
            return this.finishNode(elem, "TemplateElement");
        };
        pp$5.parseTemplate = function (ref) {
            if (ref === void 0)
                ref = {};
            var isTagged = ref.isTagged;
            if (isTagged === void 0)
                isTagged = false;
            var node = this.startNode();
            this.next();
            node.expressions = [];
            var curElt = this.parseTemplateElement({ isTagged: isTagged });
            node.quasis = [curElt];
            while (!curElt.tail) {
                if (this.type === types$1.eof) {
                    this.raise(this.pos, "Unterminated template literal");
                }
                this.expect(types$1.dollarBraceL);
                node.expressions.push(this.parseExpression());
                this.expect(types$1.braceR);
                node.quasis.push(curElt = this.parseTemplateElement({ isTagged: isTagged }));
            }
            this.next();
            return this.finishNode(node, "TemplateLiteral");
        };
        pp$5.isAsyncProp = function (prop) {
            return !prop.computed && prop.key.type === "Identifier" && prop.key.name === "async" &&
                (this.type === types$1.name || this.type === types$1.num || this.type === types$1.string || this.type === types$1.bracketL || this.type.keyword || (this.options.ecmaVersion >= 9 && this.type === types$1.star)) &&
                !lineBreak.test(this.input.slice(this.lastTokEnd, this.start));
        };
        // Parse an object literal or binding pattern.
        pp$5.parseObj = function (isPattern, refDestructuringErrors) {
            var node = this.startNode(), first = true, propHash = {};
            node.properties = [];
            this.next();
            while (!this.eat(types$1.braceR)) {
                if (!first) {
                    this.expect(types$1.comma);
                    if (this.options.ecmaVersion >= 5 && this.afterTrailingComma(types$1.braceR)) {
                        break;
                    }
                }
                else {
                    first = false;
                }
                var prop = this.parseProperty(isPattern, refDestructuringErrors);
                if (!isPattern) {
                    this.checkPropClash(prop, propHash, refDestructuringErrors);
                }
                node.properties.push(prop);
            }
            return this.finishNode(node, isPattern ? "ObjectPattern" : "ObjectExpression");
        };
        pp$5.parseProperty = function (isPattern, refDestructuringErrors) {
            var prop = this.startNode(), isGenerator, isAsync, startPos, startLoc;
            if (this.options.ecmaVersion >= 9 && this.eat(types$1.ellipsis)) {
                if (isPattern) {
                    prop.argument = this.parseIdent(false);
                    if (this.type === types$1.comma) {
                        this.raiseRecoverable(this.start, "Comma is not permitted after the rest element");
                    }
                    return this.finishNode(prop, "RestElement");
                }
                // Parse argument.
                prop.argument = this.parseMaybeAssign(false, refDestructuringErrors);
                // To disallow trailing comma via `this.toAssignable()`.
                if (this.type === types$1.comma && refDestructuringErrors && refDestructuringErrors.trailingComma < 0) {
                    refDestructuringErrors.trailingComma = this.start;
                }
                // Finish
                return this.finishNode(prop, "SpreadElement");
            }
            if (this.options.ecmaVersion >= 6) {
                prop.method = false;
                prop.shorthand = false;
                if (isPattern || refDestructuringErrors) {
                    startPos = this.start;
                    startLoc = this.startLoc;
                }
                if (!isPattern) {
                    isGenerator = this.eat(types$1.star);
                }
            }
            var containsEsc = this.containsEsc;
            this.parsePropertyName(prop);
            if (!isPattern && !containsEsc && this.options.ecmaVersion >= 8 && !isGenerator && this.isAsyncProp(prop)) {
                isAsync = true;
                isGenerator = this.options.ecmaVersion >= 9 && this.eat(types$1.star);
                this.parsePropertyName(prop);
            }
            else {
                isAsync = false;
            }
            this.parsePropertyValue(prop, isPattern, isGenerator, isAsync, startPos, startLoc, refDestructuringErrors, containsEsc);
            return this.finishNode(prop, "Property");
        };
        pp$5.parseGetterSetter = function (prop) {
            prop.kind = prop.key.name;
            this.parsePropertyName(prop);
            prop.value = this.parseMethod(false);
            var paramCount = prop.kind === "get" ? 0 : 1;
            if (prop.value.params.length !== paramCount) {
                var start = prop.value.start;
                if (prop.kind === "get") {
                    this.raiseRecoverable(start, "getter should have no params");
                }
                else {
                    this.raiseRecoverable(start, "setter should have exactly one param");
                }
            }
            else {
                if (prop.kind === "set" && prop.value.params[0].type === "RestElement") {
                    this.raiseRecoverable(prop.value.params[0].start, "Setter cannot use rest params");
                }
            }
        };
        pp$5.parsePropertyValue = function (prop, isPattern, isGenerator, isAsync, startPos, startLoc, refDestructuringErrors, containsEsc) {
            if ((isGenerator || isAsync) && this.type === types$1.colon) {
                this.unexpected();
            }
            if (this.eat(types$1.colon)) {
                prop.value = isPattern ? this.parseMaybeDefault(this.start, this.startLoc) : this.parseMaybeAssign(false, refDestructuringErrors);
                prop.kind = "init";
            }
            else if (this.options.ecmaVersion >= 6 && this.type === types$1.parenL) {
                if (isPattern) {
                    this.unexpected();
                }
                prop.kind = "init";
                prop.method = true;
                prop.value = this.parseMethod(isGenerator, isAsync);
            }
            else if (!isPattern && !containsEsc &&
                this.options.ecmaVersion >= 5 && !prop.computed && prop.key.type === "Identifier" &&
                (prop.key.name === "get" || prop.key.name === "set") &&
                (this.type !== types$1.comma && this.type !== types$1.braceR && this.type !== types$1.eq)) {
                if (isGenerator || isAsync) {
                    this.unexpected();
                }
                this.parseGetterSetter(prop);
            }
            else if (this.options.ecmaVersion >= 6 && !prop.computed && prop.key.type === "Identifier") {
                if (isGenerator || isAsync) {
                    this.unexpected();
                }
                this.checkUnreserved(prop.key);
                if (prop.key.name === "await" && !this.awaitIdentPos) {
                    this.awaitIdentPos = startPos;
                }
                prop.kind = "init";
                if (isPattern) {
                    prop.value = this.parseMaybeDefault(startPos, startLoc, this.copyNode(prop.key));
                }
                else if (this.type === types$1.eq && refDestructuringErrors) {
                    if (refDestructuringErrors.shorthandAssign < 0) {
                        refDestructuringErrors.shorthandAssign = this.start;
                    }
                    prop.value = this.parseMaybeDefault(startPos, startLoc, this.copyNode(prop.key));
                }
                else {
                    prop.value = this.copyNode(prop.key);
                }
                prop.shorthand = true;
            }
            else {
                this.unexpected();
            }
        };
        pp$5.parsePropertyName = function (prop) {
            if (this.options.ecmaVersion >= 6) {
                if (this.eat(types$1.bracketL)) {
                    prop.computed = true;
                    prop.key = this.parseMaybeAssign();
                    this.expect(types$1.bracketR);
                    return prop.key;
                }
                else {
                    prop.computed = false;
                }
            }
            return prop.key = this.type === types$1.num || this.type === types$1.string ? this.parseExprAtom() : this.parseIdent(this.options.allowReserved !== "never");
        };
        // Initialize empty function node.
        pp$5.initFunction = function (node) {
            node.id = null;
            if (this.options.ecmaVersion >= 6) {
                node.generator = node.expression = false;
            }
            if (this.options.ecmaVersion >= 8) {
                node.async = false;
            }
        };
        // Parse object or class method.
        pp$5.parseMethod = function (isGenerator, isAsync, allowDirectSuper) {
            var node = this.startNode(), oldYieldPos = this.yieldPos, oldAwaitPos = this.awaitPos, oldAwaitIdentPos = this.awaitIdentPos;
            this.initFunction(node);
            if (this.options.ecmaVersion >= 6) {
                node.generator = isGenerator;
            }
            if (this.options.ecmaVersion >= 8) {
                node.async = !!isAsync;
            }
            this.yieldPos = 0;
            this.awaitPos = 0;
            this.awaitIdentPos = 0;
            this.enterScope(functionFlags(isAsync, node.generator) | SCOPE_SUPER | (allowDirectSuper ? SCOPE_DIRECT_SUPER : 0));
            this.expect(types$1.parenL);
            node.params = this.parseBindingList(types$1.parenR, false, this.options.ecmaVersion >= 8);
            this.checkYieldAwaitInDefaultParams();
            this.parseFunctionBody(node, false, true, false);
            this.yieldPos = oldYieldPos;
            this.awaitPos = oldAwaitPos;
            this.awaitIdentPos = oldAwaitIdentPos;
            return this.finishNode(node, "FunctionExpression");
        };
        // Parse arrow function expression with given parameters.
        pp$5.parseArrowExpression = function (node, params, isAsync, forInit) {
            var oldYieldPos = this.yieldPos, oldAwaitPos = this.awaitPos, oldAwaitIdentPos = this.awaitIdentPos;
            this.enterScope(functionFlags(isAsync, false) | SCOPE_ARROW);
            this.initFunction(node);
            if (this.options.ecmaVersion >= 8) {
                node.async = !!isAsync;
            }
            this.yieldPos = 0;
            this.awaitPos = 0;
            this.awaitIdentPos = 0;
            node.params = this.toAssignableList(params, true);
            this.parseFunctionBody(node, true, false, forInit);
            this.yieldPos = oldYieldPos;
            this.awaitPos = oldAwaitPos;
            this.awaitIdentPos = oldAwaitIdentPos;
            return this.finishNode(node, "ArrowFunctionExpression");
        };
        // Parse function body and check parameters.
        pp$5.parseFunctionBody = function (node, isArrowFunction, isMethod, forInit) {
            var isExpression = isArrowFunction && this.type !== types$1.braceL;
            var oldStrict = this.strict, useStrict = false;
            if (isExpression) {
                node.body = this.parseMaybeAssign(forInit);
                node.expression = true;
                this.checkParams(node, false);
            }
            else {
                var nonSimple = this.options.ecmaVersion >= 7 && !this.isSimpleParamList(node.params);
                if (!oldStrict || nonSimple) {
                    useStrict = this.strictDirective(this.end);
                    // If this is a strict mode function, verify that argument names
                    // are not repeated, and it does not try to bind the words `eval`
                    // or `arguments`.
                    if (useStrict && nonSimple) {
                        this.raiseRecoverable(node.start, "Illegal 'use strict' directive in function with non-simple parameter list");
                    }
                }
                // Start a new scope with regard to labels and the `inFunction`
                // flag (restore them to their old value afterwards).
                var oldLabels = this.labels;
                this.labels = [];
                if (useStrict) {
                    this.strict = true;
                }
                // Add the params to varDeclaredNames to ensure that an error is thrown
                // if a let/const declaration in the function clashes with one of the params.
                this.checkParams(node, !oldStrict && !useStrict && !isArrowFunction && !isMethod && this.isSimpleParamList(node.params));
                // Ensure the function name isn't a forbidden identifier in strict mode, e.g. 'eval'
                if (this.strict && node.id) {
                    this.checkLValSimple(node.id, BIND_OUTSIDE);
                }
                node.body = this.parseBlock(false, undefined, useStrict && !oldStrict);
                node.expression = false;
                this.adaptDirectivePrologue(node.body.body);
                this.labels = oldLabels;
            }
            this.exitScope();
        };
        pp$5.isSimpleParamList = function (params) {
            for (var i = 0, list = params; i < list.length; i += 1) {
                var param = list[i];
                if (param.type !== "Identifier") {
                    return false;
                }
            }
            return true;
        };
        // Checks function params for various disallowed patterns such as using "eval"
        // or "arguments" and duplicate parameters.
        pp$5.checkParams = function (node, allowDuplicates) {
            var nameHash = Object.create(null);
            for (var i = 0, list = node.params; i < list.length; i += 1) {
                var param = list[i];
                this.checkLValInnerPattern(param, BIND_VAR, allowDuplicates ? null : nameHash);
            }
        };
        // Parses a comma-separated list of expressions, and returns them as
        // an array. `close` is the token type that ends the list, and
        // `allowEmpty` can be turned on to allow subsequent commas with
        // nothing in between them to be parsed as `null` (which is needed
        // for array literals).
        pp$5.parseExprList = function (close, allowTrailingComma, allowEmpty, refDestructuringErrors) {
            var elts = [], first = true;
            while (!this.eat(close)) {
                if (!first) {
                    this.expect(types$1.comma);
                    if (allowTrailingComma && this.afterTrailingComma(close)) {
                        break;
                    }
                }
                else {
                    first = false;
                }
                var elt = (void 0);
                if (allowEmpty && this.type === types$1.comma) {
                    elt = null;
                }
                else if (this.type === types$1.ellipsis) {
                    elt = this.parseSpread(refDestructuringErrors);
                    if (refDestructuringErrors && this.type === types$1.comma && refDestructuringErrors.trailingComma < 0) {
                        refDestructuringErrors.trailingComma = this.start;
                    }
                }
                else {
                    elt = this.parseMaybeAssign(false, refDestructuringErrors);
                }
                elts.push(elt);
            }
            return elts;
        };
        pp$5.checkUnreserved = function (ref) {
            var start = ref.start;
            var end = ref.end;
            var name = ref.name;
            if (this.inGenerator && name === "yield") {
                this.raiseRecoverable(start, "Cannot use 'yield' as identifier inside a generator");
            }
            if (this.inAsync && name === "await") {
                this.raiseRecoverable(start, "Cannot use 'await' as identifier inside an async function");
            }
            if (this.currentThisScope().inClassFieldInit && name === "arguments") {
                this.raiseRecoverable(start, "Cannot use 'arguments' in class field initializer");
            }
            if (this.inClassStaticBlock && (name === "arguments" || name === "await")) {
                this.raise(start, ("Cannot use " + name + " in class static initialization block"));
            }
            if (this.keywords.test(name)) {
                this.raise(start, ("Unexpected keyword '" + name + "'"));
            }
            if (this.options.ecmaVersion < 6 &&
                this.input.slice(start, end).indexOf("\\") !== -1) {
                return;
            }
            var re = this.strict ? this.reservedWordsStrict : this.reservedWords;
            if (re.test(name)) {
                if (!this.inAsync && name === "await") {
                    this.raiseRecoverable(start, "Cannot use keyword 'await' outside an async function");
                }
                this.raiseRecoverable(start, ("The keyword '" + name + "' is reserved"));
            }
        };
        // Parse the next token as an identifier. If `liberal` is true (used
        // when parsing properties), it will also convert keywords into
        // identifiers.
        pp$5.parseIdent = function (liberal) {
            var node = this.parseIdentNode();
            this.next(!!liberal);
            this.finishNode(node, "Identifier");
            if (!liberal) {
                this.checkUnreserved(node);
                if (node.name === "await" && !this.awaitIdentPos) {
                    this.awaitIdentPos = node.start;
                }
            }
            return node;
        };
        pp$5.parseIdentNode = function () {
            var node = this.startNode();
            if (this.type === types$1.name) {
                node.name = this.value;
            }
            else if (this.type.keyword) {
                node.name = this.type.keyword;
                // To fix https://github.com/acornjs/acorn/issues/575
                // `class` and `function` keywords push new context into this.context.
                // But there is no chance to pop the context if the keyword is consumed as an identifier such as a property name.
                // If the previous token is a dot, this does not apply because the context-managing code already ignored the keyword
                if ((node.name === "class" || node.name === "function") &&
                    (this.lastTokEnd !== this.lastTokStart + 1 || this.input.charCodeAt(this.lastTokStart) !== 46)) {
                    this.context.pop();
                }
                this.type = types$1.name;
            }
            else {
                this.unexpected();
            }
            return node;
        };
        pp$5.parsePrivateIdent = function () {
            var node = this.startNode();
            if (this.type === types$1.privateId) {
                node.name = this.value;
            }
            else {
                this.unexpected();
            }
            this.next();
            this.finishNode(node, "PrivateIdentifier");
            // For validating existence
            if (this.options.checkPrivateFields) {
                if (this.privateNameStack.length === 0) {
                    this.raise(node.start, ("Private field '#" + (node.name) + "' must be declared in an enclosing class"));
                }
                else {
                    this.privateNameStack[this.privateNameStack.length - 1].used.push(node);
                }
            }
            return node;
        };
        // Parses yield expression inside generator.
        pp$5.parseYield = function (forInit) {
            if (!this.yieldPos) {
                this.yieldPos = this.start;
            }
            var node = this.startNode();
            this.next();
            if (this.type === types$1.semi || this.canInsertSemicolon() || (this.type !== types$1.star && !this.type.startsExpr)) {
                node.delegate = false;
                node.argument = null;
            }
            else {
                node.delegate = this.eat(types$1.star);
                node.argument = this.parseMaybeAssign(forInit);
            }
            return this.finishNode(node, "YieldExpression");
        };
        pp$5.parseAwait = function (forInit) {
            if (!this.awaitPos) {
                this.awaitPos = this.start;
            }
            var node = this.startNode();
            this.next();
            node.argument = this.parseMaybeUnary(null, true, false, forInit);
            return this.finishNode(node, "AwaitExpression");
        };
        var pp$4 = Parser.prototype;
        // This function is used to raise exceptions on parse errors. It
        // takes an offset integer (into the current `input`) to indicate
        // the location of the error, attaches the position to the end
        // of the error message, and then raises a `SyntaxError` with that
        // message.
        pp$4.raise = function (pos, message) {
            var loc = getLineInfo(this.input, pos);
            message += " (" + loc.line + ":" + loc.column + ")";
            var err = new SyntaxError(message);
            err.pos = pos;
            err.loc = loc;
            err.raisedAt = this.pos;
            throw err;
        };
        pp$4.raiseRecoverable = pp$4.raise;
        pp$4.curPosition = function () {
            if (this.options.locations) {
                return new Position(this.curLine, this.pos - this.lineStart);
            }
        };
        var pp$3 = Parser.prototype;
        var Scope = function Scope(flags) {
            this.flags = flags;
            // A list of var-declared names in the current lexical scope
            this.var = [];
            // A list of lexically-declared names in the current lexical scope
            this.lexical = [];
            // A list of lexically-declared FunctionDeclaration names in the current lexical scope
            this.functions = [];
            // A switch to disallow the identifier reference 'arguments'
            this.inClassFieldInit = false;
        };
        // The functions in this module keep track of declared variables in the current scope in order to detect duplicate variable names.
        pp$3.enterScope = function (flags) {
            this.scopeStack.push(new Scope(flags));
        };
        pp$3.exitScope = function () {
            this.scopeStack.pop();
        };
        // The spec says:
        // > At the top level of a function, or script, function declarations are
        // > treated like var declarations rather than like lexical declarations.
        pp$3.treatFunctionsAsVarInScope = function (scope) {
            return (scope.flags & SCOPE_FUNCTION) || !this.inModule && (scope.flags & SCOPE_TOP);
        };
        pp$3.declareName = function (name, bindingType, pos) {
            var redeclared = false;
            if (bindingType === BIND_LEXICAL) {
                var scope = this.currentScope();
                redeclared = scope.lexical.indexOf(name) > -1 || scope.functions.indexOf(name) > -1 || scope.var.indexOf(name) > -1;
                scope.lexical.push(name);
                if (this.inModule && (scope.flags & SCOPE_TOP)) {
                    delete this.undefinedExports[name];
                }
            }
            else if (bindingType === BIND_SIMPLE_CATCH) {
                var scope$1 = this.currentScope();
                scope$1.lexical.push(name);
            }
            else if (bindingType === BIND_FUNCTION) {
                var scope$2 = this.currentScope();
                if (this.treatFunctionsAsVar) {
                    redeclared = scope$2.lexical.indexOf(name) > -1;
                }
                else {
                    redeclared = scope$2.lexical.indexOf(name) > -1 || scope$2.var.indexOf(name) > -1;
                }
                scope$2.functions.push(name);
            }
            else {
                for (var i = this.scopeStack.length - 1; i >= 0; --i) {
                    var scope$3 = this.scopeStack[i];
                    if (scope$3.lexical.indexOf(name) > -1 && !((scope$3.flags & SCOPE_SIMPLE_CATCH) && scope$3.lexical[0] === name) ||
                        !this.treatFunctionsAsVarInScope(scope$3) && scope$3.functions.indexOf(name) > -1) {
                        redeclared = true;
                        break;
                    }
                    scope$3.var.push(name);
                    if (this.inModule && (scope$3.flags & SCOPE_TOP)) {
                        delete this.undefinedExports[name];
                    }
                    if (scope$3.flags & SCOPE_VAR) {
                        break;
                    }
                }
            }
            if (redeclared) {
                this.raiseRecoverable(pos, ("Identifier '" + name + "' has already been declared"));
            }
        };
        pp$3.checkLocalExport = function (id) {
            // scope.functions must be empty as Module code is always strict.
            if (this.scopeStack[0].lexical.indexOf(id.name) === -1 &&
                this.scopeStack[0].var.indexOf(id.name) === -1) {
                this.undefinedExports[id.name] = id;
            }
        };
        pp$3.currentScope = function () {
            return this.scopeStack[this.scopeStack.length - 1];
        };
        pp$3.currentVarScope = function () {
            for (var i = this.scopeStack.length - 1;; i--) {
                var scope = this.scopeStack[i];
                if (scope.flags & SCOPE_VAR) {
                    return scope;
                }
            }
        };
        // Could be useful for `this`, `new.target`, `super()`, `super.property`, and `super[property]`.
        pp$3.currentThisScope = function () {
            for (var i = this.scopeStack.length - 1;; i--) {
                var scope = this.scopeStack[i];
                if (scope.flags & SCOPE_VAR && !(scope.flags & SCOPE_ARROW)) {
                    return scope;
                }
            }
        };
        var Node = function Node(parser, pos, loc) {
            this.type = "";
            this.start = pos;
            this.end = 0;
            if (parser.options.locations) {
                this.loc = new SourceLocation(parser, loc);
            }
            if (parser.options.directSourceFile) {
                this.sourceFile = parser.options.directSourceFile;
            }
            if (parser.options.ranges) {
                this.range = [pos, 0];
            }
        };
        // Start an AST node, attaching a start offset.
        var pp$2 = Parser.prototype;
        pp$2.startNode = function () {
            return new Node(this, this.start, this.startLoc);
        };
        pp$2.startNodeAt = function (pos, loc) {
            return new Node(this, pos, loc);
        };
        // Finish an AST node, adding `type` and `end` properties.
        function finishNodeAt(node, type, pos, loc) {
            node.type = type;
            node.end = pos;
            if (this.options.locations) {
                node.loc.end = loc;
            }
            if (this.options.ranges) {
                node.range[1] = pos;
            }
            return node;
        }
        pp$2.finishNode = function (node, type) {
            return finishNodeAt.call(this, node, type, this.lastTokEnd, this.lastTokEndLoc);
        };
        // Finish node at given position
        pp$2.finishNodeAt = function (node, type, pos, loc) {
            return finishNodeAt.call(this, node, type, pos, loc);
        };
        pp$2.copyNode = function (node) {
            var newNode = new Node(this, node.start, this.startLoc);
            for (var prop in node) {
                newNode[prop] = node[prop];
            }
            return newNode;
        };
        // This file contains Unicode properties extracted from the ECMAScript specification.
        // The lists are extracted like so:
        // $$('#table-binary-unicode-properties > figure > table > tbody > tr > td:nth-child(1) code').map(el => el.innerText)
        // #table-binary-unicode-properties
        var ecma9BinaryProperties = "ASCII ASCII_Hex_Digit AHex Alphabetic Alpha Any Assigned Bidi_Control Bidi_C Bidi_Mirrored Bidi_M Case_Ignorable CI Cased Changes_When_Casefolded CWCF Changes_When_Casemapped CWCM Changes_When_Lowercased CWL Changes_When_NFKC_Casefolded CWKCF Changes_When_Titlecased CWT Changes_When_Uppercased CWU Dash Default_Ignorable_Code_Point DI Deprecated Dep Diacritic Dia Emoji Emoji_Component Emoji_Modifier Emoji_Modifier_Base Emoji_Presentation Extender Ext Grapheme_Base Gr_Base Grapheme_Extend Gr_Ext Hex_Digit Hex IDS_Binary_Operator IDSB IDS_Trinary_Operator IDST ID_Continue IDC ID_Start IDS Ideographic Ideo Join_Control Join_C Logical_Order_Exception LOE Lowercase Lower Math Noncharacter_Code_Point NChar Pattern_Syntax Pat_Syn Pattern_White_Space Pat_WS Quotation_Mark QMark Radical Regional_Indicator RI Sentence_Terminal STerm Soft_Dotted SD Terminal_Punctuation Term Unified_Ideograph UIdeo Uppercase Upper Variation_Selector VS White_Space space XID_Continue XIDC XID_Start XIDS";
        var ecma10BinaryProperties = ecma9BinaryProperties + " Extended_Pictographic";
        var ecma11BinaryProperties = ecma10BinaryProperties;
        var ecma12BinaryProperties = ecma11BinaryProperties + " EBase EComp EMod EPres ExtPict";
        var ecma13BinaryProperties = ecma12BinaryProperties;
        var ecma14BinaryProperties = ecma13BinaryProperties;
        var unicodeBinaryProperties = {
            9: ecma9BinaryProperties,
            10: ecma10BinaryProperties,
            11: ecma11BinaryProperties,
            12: ecma12BinaryProperties,
            13: ecma13BinaryProperties,
            14: ecma14BinaryProperties
        };
        // #table-binary-unicode-properties-of-strings
        var ecma14BinaryPropertiesOfStrings = "Basic_Emoji Emoji_Keycap_Sequence RGI_Emoji_Modifier_Sequence RGI_Emoji_Flag_Sequence RGI_Emoji_Tag_Sequence RGI_Emoji_ZWJ_Sequence RGI_Emoji";
        var unicodeBinaryPropertiesOfStrings = {
            9: "",
            10: "",
            11: "",
            12: "",
            13: "",
            14: ecma14BinaryPropertiesOfStrings
        };
        // #table-unicode-general-category-values
        var unicodeGeneralCategoryValues = "Cased_Letter LC Close_Punctuation Pe Connector_Punctuation Pc Control Cc cntrl Currency_Symbol Sc Dash_Punctuation Pd Decimal_Number Nd digit Enclosing_Mark Me Final_Punctuation Pf Format Cf Initial_Punctuation Pi Letter L Letter_Number Nl Line_Separator Zl Lowercase_Letter Ll Mark M Combining_Mark Math_Symbol Sm Modifier_Letter Lm Modifier_Symbol Sk Nonspacing_Mark Mn Number N Open_Punctuation Ps Other C Other_Letter Lo Other_Number No Other_Punctuation Po Other_Symbol So Paragraph_Separator Zp Private_Use Co Punctuation P punct Separator Z Space_Separator Zs Spacing_Mark Mc Surrogate Cs Symbol S Titlecase_Letter Lt Unassigned Cn Uppercase_Letter Lu";
        // #table-unicode-script-values
        var ecma9ScriptValues = "Adlam Adlm Ahom Anatolian_Hieroglyphs Hluw Arabic Arab Armenian Armn Avestan Avst Balinese Bali Bamum Bamu Bassa_Vah Bass Batak Batk Bengali Beng Bhaiksuki Bhks Bopomofo Bopo Brahmi Brah Braille Brai Buginese Bugi Buhid Buhd Canadian_Aboriginal Cans Carian Cari Caucasian_Albanian Aghb Chakma Cakm Cham Cham Cherokee Cher Common Zyyy Coptic Copt Qaac Cuneiform Xsux Cypriot Cprt Cyrillic Cyrl Deseret Dsrt Devanagari Deva Duployan Dupl Egyptian_Hieroglyphs Egyp Elbasan Elba Ethiopic Ethi Georgian Geor Glagolitic Glag Gothic Goth Grantha Gran Greek Grek Gujarati Gujr Gurmukhi Guru Han Hani Hangul Hang Hanunoo Hano Hatran Hatr Hebrew Hebr Hiragana Hira Imperial_Aramaic Armi Inherited Zinh Qaai Inscriptional_Pahlavi Phli Inscriptional_Parthian Prti Javanese Java Kaithi Kthi Kannada Knda Katakana Kana Kayah_Li Kali Kharoshthi Khar Khmer Khmr Khojki Khoj Khudawadi Sind Lao Laoo Latin Latn Lepcha Lepc Limbu Limb Linear_A Lina Linear_B Linb Lisu Lisu Lycian Lyci Lydian Lydi Mahajani Mahj Malayalam Mlym Mandaic Mand Manichaean Mani Marchen Marc Masaram_Gondi Gonm Meetei_Mayek Mtei Mende_Kikakui Mend Meroitic_Cursive Merc Meroitic_Hieroglyphs Mero Miao Plrd Modi Mongolian Mong Mro Mroo Multani Mult Myanmar Mymr Nabataean Nbat New_Tai_Lue Talu Newa Newa Nko Nkoo Nushu Nshu Ogham Ogam Ol_Chiki Olck Old_Hungarian Hung Old_Italic Ital Old_North_Arabian Narb Old_Permic Perm Old_Persian Xpeo Old_South_Arabian Sarb Old_Turkic Orkh Oriya Orya Osage Osge Osmanya Osma Pahawh_Hmong Hmng Palmyrene Palm Pau_Cin_Hau Pauc Phags_Pa Phag Phoenician Phnx Psalter_Pahlavi Phlp Rejang Rjng Runic Runr Samaritan Samr Saurashtra Saur Sharada Shrd Shavian Shaw Siddham Sidd SignWriting Sgnw Sinhala Sinh Sora_Sompeng Sora Soyombo Soyo Sundanese Sund Syloti_Nagri Sylo Syriac Syrc Tagalog Tglg Tagbanwa Tagb Tai_Le Tale Tai_Tham Lana Tai_Viet Tavt Takri Takr Tamil Taml Tangut Tang Telugu Telu Thaana Thaa Thai Thai Tibetan Tibt Tifinagh Tfng Tirhuta Tirh Ugaritic Ugar Vai Vaii Warang_Citi Wara Yi Yiii Zanabazar_Square Zanb";
        var ecma10ScriptValues = ecma9ScriptValues + " Dogra Dogr Gunjala_Gondi Gong Hanifi_Rohingya Rohg Makasar Maka Medefaidrin Medf Old_Sogdian Sogo Sogdian Sogd";
        var ecma11ScriptValues = ecma10ScriptValues + " Elymaic Elym Nandinagari Nand Nyiakeng_Puachue_Hmong Hmnp Wancho Wcho";
        var ecma12ScriptValues = ecma11ScriptValues + " Chorasmian Chrs Diak Dives_Akuru Khitan_Small_Script Kits Yezi Yezidi";
        var ecma13ScriptValues = ecma12ScriptValues + " Cypro_Minoan Cpmn Old_Uyghur Ougr Tangsa Tnsa Toto Vithkuqi Vith";
        var ecma14ScriptValues = ecma13ScriptValues + " Hrkt Katakana_Or_Hiragana Kawi Nag_Mundari Nagm Unknown Zzzz";
        var unicodeScriptValues = {
            9: ecma9ScriptValues,
            10: ecma10ScriptValues,
            11: ecma11ScriptValues,
            12: ecma12ScriptValues,
            13: ecma13ScriptValues,
            14: ecma14ScriptValues
        };
        var data = {};
        function buildUnicodeData(ecmaVersion) {
            var d = data[ecmaVersion] = {
                binary: wordsRegexp(unicodeBinaryProperties[ecmaVersion] + " " + unicodeGeneralCategoryValues),
                binaryOfStrings: wordsRegexp(unicodeBinaryPropertiesOfStrings[ecmaVersion]),
                nonBinary: {
                    General_Category: wordsRegexp(unicodeGeneralCategoryValues),
                    Script: wordsRegexp(unicodeScriptValues[ecmaVersion])
                }
            };
            d.nonBinary.Script_Extensions = d.nonBinary.Script;
            d.nonBinary.gc = d.nonBinary.General_Category;
            d.nonBinary.sc = d.nonBinary.Script;
            d.nonBinary.scx = d.nonBinary.Script_Extensions;
        }
        for (var i = 0, list = [9, 10, 11, 12, 13, 14]; i < list.length; i += 1) {
            var ecmaVersion = list[i];
            buildUnicodeData(ecmaVersion);
        }
        var pp$1 = Parser.prototype;
        var RegExpValidationState = function RegExpValidationState(parser) {
            this.parser = parser;
            this.validFlags = "gim" + (parser.options.ecmaVersion >= 6 ? "uy" : "") + (parser.options.ecmaVersion >= 9 ? "s" : "") + (parser.options.ecmaVersion >= 13 ? "d" : "") + (parser.options.ecmaVersion >= 15 ? "v" : "");
            this.unicodeProperties = data[parser.options.ecmaVersion >= 14 ? 14 : parser.options.ecmaVersion];
            this.source = "";
            this.flags = "";
            this.start = 0;
            this.switchU = false;
            this.switchV = false;
            this.switchN = false;
            this.pos = 0;
            this.lastIntValue = 0;
            this.lastStringValue = "";
            this.lastAssertionIsQuantifiable = false;
            this.numCapturingParens = 0;
            this.maxBackReference = 0;
            this.groupNames = [];
            this.backReferenceNames = [];
        };
        RegExpValidationState.prototype.reset = function reset(start, pattern, flags) {
            var unicodeSets = flags.indexOf("v") !== -1;
            var unicode = flags.indexOf("u") !== -1;
            this.start = start | 0;
            this.source = pattern + "";
            this.flags = flags;
            if (unicodeSets && this.parser.options.ecmaVersion >= 15) {
                this.switchU = true;
                this.switchV = true;
                this.switchN = true;
            }
            else {
                this.switchU = unicode && this.parser.options.ecmaVersion >= 6;
                this.switchV = false;
                this.switchN = unicode && this.parser.options.ecmaVersion >= 9;
            }
        };
        RegExpValidationState.prototype.raise = function raise(message) {
            this.parser.raiseRecoverable(this.start, ("Invalid regular expression: /" + (this.source) + "/: " + message));
        };
        // If u flag is given, this returns the code point at the index (it combines a surrogate pair).
        // Otherwise, this returns the code unit of the index (can be a part of a surrogate pair).
        RegExpValidationState.prototype.at = function at(i, forceU) {
            if (forceU === void 0)
                forceU = false;
            var s = this.source;
            var l = s.length;
            if (i >= l) {
                return -1;
            }
            var c = s.charCodeAt(i);
            if (!(forceU || this.switchU) || c <= 0xD7FF || c >= 0xE000 || i + 1 >= l) {
                return c;
            }
            var next = s.charCodeAt(i + 1);
            return next >= 0xDC00 && next <= 0xDFFF ? (c << 10) + next - 0x35FDC00 : c;
        };
        RegExpValidationState.prototype.nextIndex = function nextIndex(i, forceU) {
            if (forceU === void 0)
                forceU = false;
            var s = this.source;
            var l = s.length;
            if (i >= l) {
                return l;
            }
            var c = s.charCodeAt(i), next;
            if (!(forceU || this.switchU) || c <= 0xD7FF || c >= 0xE000 || i + 1 >= l ||
                (next = s.charCodeAt(i + 1)) < 0xDC00 || next > 0xDFFF) {
                return i + 1;
            }
            return i + 2;
        };
        RegExpValidationState.prototype.current = function current(forceU) {
            if (forceU === void 0)
                forceU = false;
            return this.at(this.pos, forceU);
        };
        RegExpValidationState.prototype.lookahead = function lookahead(forceU) {
            if (forceU === void 0)
                forceU = false;
            return this.at(this.nextIndex(this.pos, forceU), forceU);
        };
        RegExpValidationState.prototype.advance = function advance(forceU) {
            if (forceU === void 0)
                forceU = false;
            this.pos = this.nextIndex(this.pos, forceU);
        };
        RegExpValidationState.prototype.eat = function eat(ch, forceU) {
            if (forceU === void 0)
                forceU = false;
            if (this.current(forceU) === ch) {
                this.advance(forceU);
                return true;
            }
            return false;
        };
        RegExpValidationState.prototype.eatChars = function eatChars(chs, forceU) {
            if (forceU === void 0)
                forceU = false;
            var pos = this.pos;
            for (var i = 0, list = chs; i < list.length; i += 1) {
                var ch = list[i];
                var current = this.at(pos, forceU);
                if (current === -1 || current !== ch) {
                    return false;
                }
                pos = this.nextIndex(pos, forceU);
            }
            this.pos = pos;
            return true;
        };
        /**
         * Validate the flags part of a given RegExpLiteral.
         *
         * @param {RegExpValidationState} state The state to validate RegExp.
         * @returns {void}
         */
        pp$1.validateRegExpFlags = function (state) {
            var validFlags = state.validFlags;
            var flags = state.flags;
            var u = false;
            var v = false;
            for (var i = 0; i < flags.length; i++) {
                var flag = flags.charAt(i);
                if (validFlags.indexOf(flag) === -1) {
                    this.raise(state.start, "Invalid regular expression flag");
                }
                if (flags.indexOf(flag, i + 1) > -1) {
                    this.raise(state.start, "Duplicate regular expression flag");
                }
                if (flag === "u") {
                    u = true;
                }
                if (flag === "v") {
                    v = true;
                }
            }
            if (this.options.ecmaVersion >= 15 && u && v) {
                this.raise(state.start, "Invalid regular expression flag");
            }
        };
        /**
         * Validate the pattern part of a given RegExpLiteral.
         *
         * @param {RegExpValidationState} state The state to validate RegExp.
         * @returns {void}
         */
        pp$1.validateRegExpPattern = function (state) {
            this.regexp_pattern(state);
            // The goal symbol for the parse is |Pattern[~U, ~N]|. If the result of
            // parsing contains a |GroupName|, reparse with the goal symbol
            // |Pattern[~U, +N]| and use this result instead. Throw a *SyntaxError*
            // exception if _P_ did not conform to the grammar, if any elements of _P_
            // were not matched by the parse, or if any Early Error conditions exist.
            if (!state.switchN && this.options.ecmaVersion >= 9 && state.groupNames.length > 0) {
                state.switchN = true;
                this.regexp_pattern(state);
            }
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-Pattern
        pp$1.regexp_pattern = function (state) {
            state.pos = 0;
            state.lastIntValue = 0;
            state.lastStringValue = "";
            state.lastAssertionIsQuantifiable = false;
            state.numCapturingParens = 0;
            state.maxBackReference = 0;
            state.groupNames.length = 0;
            state.backReferenceNames.length = 0;
            this.regexp_disjunction(state);
            if (state.pos !== state.source.length) {
                // Make the same messages as V8.
                if (state.eat(0x29 /* ) */)) {
                    state.raise("Unmatched ')'");
                }
                if (state.eat(0x5D /* ] */) || state.eat(0x7D /* } */)) {
                    state.raise("Lone quantifier brackets");
                }
            }
            if (state.maxBackReference > state.numCapturingParens) {
                state.raise("Invalid escape");
            }
            for (var i = 0, list = state.backReferenceNames; i < list.length; i += 1) {
                var name = list[i];
                if (state.groupNames.indexOf(name) === -1) {
                    state.raise("Invalid named capture referenced");
                }
            }
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-Disjunction
        pp$1.regexp_disjunction = function (state) {
            this.regexp_alternative(state);
            while (state.eat(0x7C /* | */)) {
                this.regexp_alternative(state);
            }
            // Make the same message as V8.
            if (this.regexp_eatQuantifier(state, true)) {
                state.raise("Nothing to repeat");
            }
            if (state.eat(0x7B /* { */)) {
                state.raise("Lone quantifier brackets");
            }
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-Alternative
        pp$1.regexp_alternative = function (state) {
            while (state.pos < state.source.length && this.regexp_eatTerm(state)) { }
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-Term
        pp$1.regexp_eatTerm = function (state) {
            if (this.regexp_eatAssertion(state)) {
                // Handle `QuantifiableAssertion Quantifier` alternative.
                // `state.lastAssertionIsQuantifiable` is true if the last eaten Assertion
                // is a QuantifiableAssertion.
                if (state.lastAssertionIsQuantifiable && this.regexp_eatQuantifier(state)) {
                    // Make the same message as V8.
                    if (state.switchU) {
                        state.raise("Invalid quantifier");
                    }
                }
                return true;
            }
            if (state.switchU ? this.regexp_eatAtom(state) : this.regexp_eatExtendedAtom(state)) {
                this.regexp_eatQuantifier(state);
                return true;
            }
            return false;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-Assertion
        pp$1.regexp_eatAssertion = function (state) {
            var start = state.pos;
            state.lastAssertionIsQuantifiable = false;
            // ^, $
            if (state.eat(0x5E /* ^ */) || state.eat(0x24 /* $ */)) {
                return true;
            }
            // \b \B
            if (state.eat(0x5C /* \ */)) {
                if (state.eat(0x42 /* B */) || state.eat(0x62 /* b */)) {
                    return true;
                }
                state.pos = start;
            }
            // Lookahead / Lookbehind
            if (state.eat(0x28 /* ( */) && state.eat(0x3F /* ? */)) {
                var lookbehind = false;
                if (this.options.ecmaVersion >= 9) {
                    lookbehind = state.eat(0x3C /* < */);
                }
                if (state.eat(0x3D /* = */) || state.eat(0x21 /* ! */)) {
                    this.regexp_disjunction(state);
                    if (!state.eat(0x29 /* ) */)) {
                        state.raise("Unterminated group");
                    }
                    state.lastAssertionIsQuantifiable = !lookbehind;
                    return true;
                }
            }
            state.pos = start;
            return false;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-Quantifier
        pp$1.regexp_eatQuantifier = function (state, noError) {
            if (noError === void 0)
                noError = false;
            if (this.regexp_eatQuantifierPrefix(state, noError)) {
                state.eat(0x3F /* ? */);
                return true;
            }
            return false;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-QuantifierPrefix
        pp$1.regexp_eatQuantifierPrefix = function (state, noError) {
            return (state.eat(0x2A /* * */) ||
                state.eat(0x2B /* + */) ||
                state.eat(0x3F /* ? */) ||
                this.regexp_eatBracedQuantifier(state, noError));
        };
        pp$1.regexp_eatBracedQuantifier = function (state, noError) {
            var start = state.pos;
            if (state.eat(0x7B /* { */)) {
                var min = 0, max = -1;
                if (this.regexp_eatDecimalDigits(state)) {
                    min = state.lastIntValue;
                    if (state.eat(0x2C /* , */) && this.regexp_eatDecimalDigits(state)) {
                        max = state.lastIntValue;
                    }
                    if (state.eat(0x7D /* } */)) {
                        // SyntaxError in https://www.ecma-international.org/ecma-262/8.0/#sec-term
                        if (max !== -1 && max < min && !noError) {
                            state.raise("numbers out of order in {} quantifier");
                        }
                        return true;
                    }
                }
                if (state.switchU && !noError) {
                    state.raise("Incomplete quantifier");
                }
                state.pos = start;
            }
            return false;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-Atom
        pp$1.regexp_eatAtom = function (state) {
            return (this.regexp_eatPatternCharacters(state) ||
                state.eat(0x2E /* . */) ||
                this.regexp_eatReverseSolidusAtomEscape(state) ||
                this.regexp_eatCharacterClass(state) ||
                this.regexp_eatUncapturingGroup(state) ||
                this.regexp_eatCapturingGroup(state));
        };
        pp$1.regexp_eatReverseSolidusAtomEscape = function (state) {
            var start = state.pos;
            if (state.eat(0x5C /* \ */)) {
                if (this.regexp_eatAtomEscape(state)) {
                    return true;
                }
                state.pos = start;
            }
            return false;
        };
        pp$1.regexp_eatUncapturingGroup = function (state) {
            var start = state.pos;
            if (state.eat(0x28 /* ( */)) {
                if (state.eat(0x3F /* ? */) && state.eat(0x3A /* : */)) {
                    this.regexp_disjunction(state);
                    if (state.eat(0x29 /* ) */)) {
                        return true;
                    }
                    state.raise("Unterminated group");
                }
                state.pos = start;
            }
            return false;
        };
        pp$1.regexp_eatCapturingGroup = function (state) {
            if (state.eat(0x28 /* ( */)) {
                if (this.options.ecmaVersion >= 9) {
                    this.regexp_groupSpecifier(state);
                }
                else if (state.current() === 0x3F /* ? */) {
                    state.raise("Invalid group");
                }
                this.regexp_disjunction(state);
                if (state.eat(0x29 /* ) */)) {
                    state.numCapturingParens += 1;
                    return true;
                }
                state.raise("Unterminated group");
            }
            return false;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-ExtendedAtom
        pp$1.regexp_eatExtendedAtom = function (state) {
            return (state.eat(0x2E /* . */) ||
                this.regexp_eatReverseSolidusAtomEscape(state) ||
                this.regexp_eatCharacterClass(state) ||
                this.regexp_eatUncapturingGroup(state) ||
                this.regexp_eatCapturingGroup(state) ||
                this.regexp_eatInvalidBracedQuantifier(state) ||
                this.regexp_eatExtendedPatternCharacter(state));
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-InvalidBracedQuantifier
        pp$1.regexp_eatInvalidBracedQuantifier = function (state) {
            if (this.regexp_eatBracedQuantifier(state, true)) {
                state.raise("Nothing to repeat");
            }
            return false;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-SyntaxCharacter
        pp$1.regexp_eatSyntaxCharacter = function (state) {
            var ch = state.current();
            if (isSyntaxCharacter(ch)) {
                state.lastIntValue = ch;
                state.advance();
                return true;
            }
            return false;
        };
        function isSyntaxCharacter(ch) {
            return (ch === 0x24 /* $ */ ||
                ch >= 0x28 /* ( */ && ch <= 0x2B /* + */ ||
                ch === 0x2E /* . */ ||
                ch === 0x3F /* ? */ ||
                ch >= 0x5B /* [ */ && ch <= 0x5E /* ^ */ ||
                ch >= 0x7B /* { */ && ch <= 0x7D /* } */);
        }
        // https://www.ecma-international.org/ecma-262/8.0/#prod-PatternCharacter
        // But eat eager.
        pp$1.regexp_eatPatternCharacters = function (state) {
            var start = state.pos;
            var ch = 0;
            while ((ch = state.current()) !== -1 && !isSyntaxCharacter(ch)) {
                state.advance();
            }
            return state.pos !== start;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-ExtendedPatternCharacter
        pp$1.regexp_eatExtendedPatternCharacter = function (state) {
            var ch = state.current();
            if (ch !== -1 &&
                ch !== 0x24 /* $ */ &&
                !(ch >= 0x28 /* ( */ && ch <= 0x2B /* + */) &&
                ch !== 0x2E /* . */ &&
                ch !== 0x3F /* ? */ &&
                ch !== 0x5B /* [ */ &&
                ch !== 0x5E /* ^ */ &&
                ch !== 0x7C /* | */) {
                state.advance();
                return true;
            }
            return false;
        };
        // GroupSpecifier ::
        //   [empty]
        //   `?` GroupName
        pp$1.regexp_groupSpecifier = function (state) {
            if (state.eat(0x3F /* ? */)) {
                if (this.regexp_eatGroupName(state)) {
                    if (state.groupNames.indexOf(state.lastStringValue) !== -1) {
                        state.raise("Duplicate capture group name");
                    }
                    state.groupNames.push(state.lastStringValue);
                    return;
                }
                state.raise("Invalid group");
            }
        };
        // GroupName ::
        //   `<` RegExpIdentifierName `>`
        // Note: this updates `state.lastStringValue` property with the eaten name.
        pp$1.regexp_eatGroupName = function (state) {
            state.lastStringValue = "";
            if (state.eat(0x3C /* < */)) {
                if (this.regexp_eatRegExpIdentifierName(state) && state.eat(0x3E /* > */)) {
                    return true;
                }
                state.raise("Invalid capture group name");
            }
            return false;
        };
        // RegExpIdentifierName ::
        //   RegExpIdentifierStart
        //   RegExpIdentifierName RegExpIdentifierPart
        // Note: this updates `state.lastStringValue` property with the eaten name.
        pp$1.regexp_eatRegExpIdentifierName = function (state) {
            state.lastStringValue = "";
            if (this.regexp_eatRegExpIdentifierStart(state)) {
                state.lastStringValue += codePointToString(state.lastIntValue);
                while (this.regexp_eatRegExpIdentifierPart(state)) {
                    state.lastStringValue += codePointToString(state.lastIntValue);
                }
                return true;
            }
            return false;
        };
        // RegExpIdentifierStart ::
        //   UnicodeIDStart
        //   `$`
        //   `_`
        //   `\` RegExpUnicodeEscapeSequence[+U]
        pp$1.regexp_eatRegExpIdentifierStart = function (state) {
            var start = state.pos;
            var forceU = this.options.ecmaVersion >= 11;
            var ch = state.current(forceU);
            state.advance(forceU);
            if (ch === 0x5C /* \ */ && this.regexp_eatRegExpUnicodeEscapeSequence(state, forceU)) {
                ch = state.lastIntValue;
            }
            if (isRegExpIdentifierStart(ch)) {
                state.lastIntValue = ch;
                return true;
            }
            state.pos = start;
            return false;
        };
        function isRegExpIdentifierStart(ch) {
            return isIdentifierStart(ch, true) || ch === 0x24 /* $ */ || ch === 0x5F; /* _ */
        }
        // RegExpIdentifierPart ::
        //   UnicodeIDContinue
        //   `$`
        //   `_`
        //   `\` RegExpUnicodeEscapeSequence[+U]
        //   <ZWNJ>
        //   <ZWJ>
        pp$1.regexp_eatRegExpIdentifierPart = function (state) {
            var start = state.pos;
            var forceU = this.options.ecmaVersion >= 11;
            var ch = state.current(forceU);
            state.advance(forceU);
            if (ch === 0x5C /* \ */ && this.regexp_eatRegExpUnicodeEscapeSequence(state, forceU)) {
                ch = state.lastIntValue;
            }
            if (isRegExpIdentifierPart(ch)) {
                state.lastIntValue = ch;
                return true;
            }
            state.pos = start;
            return false;
        };
        function isRegExpIdentifierPart(ch) {
            return isIdentifierChar(ch, true) || ch === 0x24 /* $ */ || ch === 0x5F /* _ */ || ch === 0x200C /* <ZWNJ> */ || ch === 0x200D; /* <ZWJ> */
        }
        // https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-AtomEscape
        pp$1.regexp_eatAtomEscape = function (state) {
            if (this.regexp_eatBackReference(state) ||
                this.regexp_eatCharacterClassEscape(state) ||
                this.regexp_eatCharacterEscape(state) ||
                (state.switchN && this.regexp_eatKGroupName(state))) {
                return true;
            }
            if (state.switchU) {
                // Make the same message as V8.
                if (state.current() === 0x63 /* c */) {
                    state.raise("Invalid unicode escape");
                }
                state.raise("Invalid escape");
            }
            return false;
        };
        pp$1.regexp_eatBackReference = function (state) {
            var start = state.pos;
            if (this.regexp_eatDecimalEscape(state)) {
                var n = state.lastIntValue;
                if (state.switchU) {
                    // For SyntaxError in https://www.ecma-international.org/ecma-262/8.0/#sec-atomescape
                    if (n > state.maxBackReference) {
                        state.maxBackReference = n;
                    }
                    return true;
                }
                if (n <= state.numCapturingParens) {
                    return true;
                }
                state.pos = start;
            }
            return false;
        };
        pp$1.regexp_eatKGroupName = function (state) {
            if (state.eat(0x6B /* k */)) {
                if (this.regexp_eatGroupName(state)) {
                    state.backReferenceNames.push(state.lastStringValue);
                    return true;
                }
                state.raise("Invalid named reference");
            }
            return false;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-CharacterEscape
        pp$1.regexp_eatCharacterEscape = function (state) {
            return (this.regexp_eatControlEscape(state) ||
                this.regexp_eatCControlLetter(state) ||
                this.regexp_eatZero(state) ||
                this.regexp_eatHexEscapeSequence(state) ||
                this.regexp_eatRegExpUnicodeEscapeSequence(state, false) ||
                (!state.switchU && this.regexp_eatLegacyOctalEscapeSequence(state)) ||
                this.regexp_eatIdentityEscape(state));
        };
        pp$1.regexp_eatCControlLetter = function (state) {
            var start = state.pos;
            if (state.eat(0x63 /* c */)) {
                if (this.regexp_eatControlLetter(state)) {
                    return true;
                }
                state.pos = start;
            }
            return false;
        };
        pp$1.regexp_eatZero = function (state) {
            if (state.current() === 0x30 /* 0 */ && !isDecimalDigit(state.lookahead())) {
                state.lastIntValue = 0;
                state.advance();
                return true;
            }
            return false;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-ControlEscape
        pp$1.regexp_eatControlEscape = function (state) {
            var ch = state.current();
            if (ch === 0x74 /* t */) {
                state.lastIntValue = 0x09; /* \t */
                state.advance();
                return true;
            }
            if (ch === 0x6E /* n */) {
                state.lastIntValue = 0x0A; /* \n */
                state.advance();
                return true;
            }
            if (ch === 0x76 /* v */) {
                state.lastIntValue = 0x0B; /* \v */
                state.advance();
                return true;
            }
            if (ch === 0x66 /* f */) {
                state.lastIntValue = 0x0C; /* \f */
                state.advance();
                return true;
            }
            if (ch === 0x72 /* r */) {
                state.lastIntValue = 0x0D; /* \r */
                state.advance();
                return true;
            }
            return false;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-ControlLetter
        pp$1.regexp_eatControlLetter = function (state) {
            var ch = state.current();
            if (isControlLetter(ch)) {
                state.lastIntValue = ch % 0x20;
                state.advance();
                return true;
            }
            return false;
        };
        function isControlLetter(ch) {
            return ((ch >= 0x41 /* A */ && ch <= 0x5A /* Z */) ||
                (ch >= 0x61 /* a */ && ch <= 0x7A /* z */));
        }
        // https://www.ecma-international.org/ecma-262/8.0/#prod-RegExpUnicodeEscapeSequence
        pp$1.regexp_eatRegExpUnicodeEscapeSequence = function (state, forceU) {
            if (forceU === void 0)
                forceU = false;
            var start = state.pos;
            var switchU = forceU || state.switchU;
            if (state.eat(0x75 /* u */)) {
                if (this.regexp_eatFixedHexDigits(state, 4)) {
                    var lead = state.lastIntValue;
                    if (switchU && lead >= 0xD800 && lead <= 0xDBFF) {
                        var leadSurrogateEnd = state.pos;
                        if (state.eat(0x5C /* \ */) && state.eat(0x75 /* u */) && this.regexp_eatFixedHexDigits(state, 4)) {
                            var trail = state.lastIntValue;
                            if (trail >= 0xDC00 && trail <= 0xDFFF) {
                                state.lastIntValue = (lead - 0xD800) * 0x400 + (trail - 0xDC00) + 0x10000;
                                return true;
                            }
                        }
                        state.pos = leadSurrogateEnd;
                        state.lastIntValue = lead;
                    }
                    return true;
                }
                if (switchU &&
                    state.eat(0x7B /* { */) &&
                    this.regexp_eatHexDigits(state) &&
                    state.eat(0x7D /* } */) &&
                    isValidUnicode(state.lastIntValue)) {
                    return true;
                }
                if (switchU) {
                    state.raise("Invalid unicode escape");
                }
                state.pos = start;
            }
            return false;
        };
        function isValidUnicode(ch) {
            return ch >= 0 && ch <= 0x10FFFF;
        }
        // https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-IdentityEscape
        pp$1.regexp_eatIdentityEscape = function (state) {
            if (state.switchU) {
                if (this.regexp_eatSyntaxCharacter(state)) {
                    return true;
                }
                if (state.eat(0x2F /* / */)) {
                    state.lastIntValue = 0x2F; /* / */
                    return true;
                }
                return false;
            }
            var ch = state.current();
            if (ch !== 0x63 /* c */ && (!state.switchN || ch !== 0x6B /* k */)) {
                state.lastIntValue = ch;
                state.advance();
                return true;
            }
            return false;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-DecimalEscape
        pp$1.regexp_eatDecimalEscape = function (state) {
            state.lastIntValue = 0;
            var ch = state.current();
            if (ch >= 0x31 /* 1 */ && ch <= 0x39 /* 9 */) {
                do {
                    state.lastIntValue = 10 * state.lastIntValue + (ch - 0x30 /* 0 */);
                    state.advance();
                } while ((ch = state.current()) >= 0x30 /* 0 */ && ch <= 0x39 /* 9 */);
                return true;
            }
            return false;
        };
        // Return values used by character set parsing methods, needed to
        // forbid negation of sets that can match strings.
        var CharSetNone = 0; // Nothing parsed
        var CharSetOk = 1; // Construct parsed, cannot contain strings
        var CharSetString = 2; // Construct parsed, can contain strings
        // https://www.ecma-international.org/ecma-262/8.0/#prod-CharacterClassEscape
        pp$1.regexp_eatCharacterClassEscape = function (state) {
            var ch = state.current();
            if (isCharacterClassEscape(ch)) {
                state.lastIntValue = -1;
                state.advance();
                return CharSetOk;
            }
            var negate = false;
            if (state.switchU &&
                this.options.ecmaVersion >= 9 &&
                ((negate = ch === 0x50 /* P */) || ch === 0x70 /* p */)) {
                state.lastIntValue = -1;
                state.advance();
                var result;
                if (state.eat(0x7B /* { */) &&
                    (result = this.regexp_eatUnicodePropertyValueExpression(state)) &&
                    state.eat(0x7D /* } */)) {
                    if (negate && result === CharSetString) {
                        state.raise("Invalid property name");
                    }
                    return result;
                }
                state.raise("Invalid property name");
            }
            return CharSetNone;
        };
        function isCharacterClassEscape(ch) {
            return (ch === 0x64 /* d */ ||
                ch === 0x44 /* D */ ||
                ch === 0x73 /* s */ ||
                ch === 0x53 /* S */ ||
                ch === 0x77 /* w */ ||
                ch === 0x57 /* W */);
        }
        // UnicodePropertyValueExpression ::
        //   UnicodePropertyName `=` UnicodePropertyValue
        //   LoneUnicodePropertyNameOrValue
        pp$1.regexp_eatUnicodePropertyValueExpression = function (state) {
            var start = state.pos;
            // UnicodePropertyName `=` UnicodePropertyValue
            if (this.regexp_eatUnicodePropertyName(state) && state.eat(0x3D /* = */)) {
                var name = state.lastStringValue;
                if (this.regexp_eatUnicodePropertyValue(state)) {
                    var value = state.lastStringValue;
                    this.regexp_validateUnicodePropertyNameAndValue(state, name, value);
                    return CharSetOk;
                }
            }
            state.pos = start;
            // LoneUnicodePropertyNameOrValue
            if (this.regexp_eatLoneUnicodePropertyNameOrValue(state)) {
                var nameOrValue = state.lastStringValue;
                return this.regexp_validateUnicodePropertyNameOrValue(state, nameOrValue);
            }
            return CharSetNone;
        };
        pp$1.regexp_validateUnicodePropertyNameAndValue = function (state, name, value) {
            if (!hasOwn(state.unicodeProperties.nonBinary, name)) {
                state.raise("Invalid property name");
            }
            if (!state.unicodeProperties.nonBinary[name].test(value)) {
                state.raise("Invalid property value");
            }
        };
        pp$1.regexp_validateUnicodePropertyNameOrValue = function (state, nameOrValue) {
            if (state.unicodeProperties.binary.test(nameOrValue)) {
                return CharSetOk;
            }
            if (state.switchV && state.unicodeProperties.binaryOfStrings.test(nameOrValue)) {
                return CharSetString;
            }
            state.raise("Invalid property name");
        };
        // UnicodePropertyName ::
        //   UnicodePropertyNameCharacters
        pp$1.regexp_eatUnicodePropertyName = function (state) {
            var ch = 0;
            state.lastStringValue = "";
            while (isUnicodePropertyNameCharacter(ch = state.current())) {
                state.lastStringValue += codePointToString(ch);
                state.advance();
            }
            return state.lastStringValue !== "";
        };
        function isUnicodePropertyNameCharacter(ch) {
            return isControlLetter(ch) || ch === 0x5F; /* _ */
        }
        // UnicodePropertyValue ::
        //   UnicodePropertyValueCharacters
        pp$1.regexp_eatUnicodePropertyValue = function (state) {
            var ch = 0;
            state.lastStringValue = "";
            while (isUnicodePropertyValueCharacter(ch = state.current())) {
                state.lastStringValue += codePointToString(ch);
                state.advance();
            }
            return state.lastStringValue !== "";
        };
        function isUnicodePropertyValueCharacter(ch) {
            return isUnicodePropertyNameCharacter(ch) || isDecimalDigit(ch);
        }
        // LoneUnicodePropertyNameOrValue ::
        //   UnicodePropertyValueCharacters
        pp$1.regexp_eatLoneUnicodePropertyNameOrValue = function (state) {
            return this.regexp_eatUnicodePropertyValue(state);
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-CharacterClass
        pp$1.regexp_eatCharacterClass = function (state) {
            if (state.eat(0x5B /* [ */)) {
                var negate = state.eat(0x5E /* ^ */);
                var result = this.regexp_classContents(state);
                if (!state.eat(0x5D /* ] */)) {
                    state.raise("Unterminated character class");
                }
                if (negate && result === CharSetString) {
                    state.raise("Negated character class may contain strings");
                }
                return true;
            }
            return false;
        };
        // https://tc39.es/ecma262/#prod-ClassContents
        // https://www.ecma-international.org/ecma-262/8.0/#prod-ClassRanges
        pp$1.regexp_classContents = function (state) {
            if (state.current() === 0x5D /* ] */) {
                return CharSetOk;
            }
            if (state.switchV) {
                return this.regexp_classSetExpression(state);
            }
            this.regexp_nonEmptyClassRanges(state);
            return CharSetOk;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-NonemptyClassRanges
        // https://www.ecma-international.org/ecma-262/8.0/#prod-NonemptyClassRangesNoDash
        pp$1.regexp_nonEmptyClassRanges = function (state) {
            while (this.regexp_eatClassAtom(state)) {
                var left = state.lastIntValue;
                if (state.eat(0x2D /* - */) && this.regexp_eatClassAtom(state)) {
                    var right = state.lastIntValue;
                    if (state.switchU && (left === -1 || right === -1)) {
                        state.raise("Invalid character class");
                    }
                    if (left !== -1 && right !== -1 && left > right) {
                        state.raise("Range out of order in character class");
                    }
                }
            }
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-ClassAtom
        // https://www.ecma-international.org/ecma-262/8.0/#prod-ClassAtomNoDash
        pp$1.regexp_eatClassAtom = function (state) {
            var start = state.pos;
            if (state.eat(0x5C /* \ */)) {
                if (this.regexp_eatClassEscape(state)) {
                    return true;
                }
                if (state.switchU) {
                    // Make the same message as V8.
                    var ch$1 = state.current();
                    if (ch$1 === 0x63 /* c */ || isOctalDigit(ch$1)) {
                        state.raise("Invalid class escape");
                    }
                    state.raise("Invalid escape");
                }
                state.pos = start;
            }
            var ch = state.current();
            if (ch !== 0x5D /* ] */) {
                state.lastIntValue = ch;
                state.advance();
                return true;
            }
            return false;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-ClassEscape
        pp$1.regexp_eatClassEscape = function (state) {
            var start = state.pos;
            if (state.eat(0x62 /* b */)) {
                state.lastIntValue = 0x08; /* <BS> */
                return true;
            }
            if (state.switchU && state.eat(0x2D /* - */)) {
                state.lastIntValue = 0x2D; /* - */
                return true;
            }
            if (!state.switchU && state.eat(0x63 /* c */)) {
                if (this.regexp_eatClassControlLetter(state)) {
                    return true;
                }
                state.pos = start;
            }
            return (this.regexp_eatCharacterClassEscape(state) ||
                this.regexp_eatCharacterEscape(state));
        };
        // https://tc39.es/ecma262/#prod-ClassSetExpression
        // https://tc39.es/ecma262/#prod-ClassUnion
        // https://tc39.es/ecma262/#prod-ClassIntersection
        // https://tc39.es/ecma262/#prod-ClassSubtraction
        pp$1.regexp_classSetExpression = function (state) {
            var result = CharSetOk, subResult;
            if (this.regexp_eatClassSetRange(state))
                ;
            else if (subResult = this.regexp_eatClassSetOperand(state)) {
                if (subResult === CharSetString) {
                    result = CharSetString;
                }
                // https://tc39.es/ecma262/#prod-ClassIntersection
                var start = state.pos;
                while (state.eatChars([0x26, 0x26] /* && */)) {
                    if (state.current() !== 0x26 /* & */ &&
                        (subResult = this.regexp_eatClassSetOperand(state))) {
                        if (subResult !== CharSetString) {
                            result = CharSetOk;
                        }
                        continue;
                    }
                    state.raise("Invalid character in character class");
                }
                if (start !== state.pos) {
                    return result;
                }
                // https://tc39.es/ecma262/#prod-ClassSubtraction
                while (state.eatChars([0x2D, 0x2D] /* -- */)) {
                    if (this.regexp_eatClassSetOperand(state)) {
                        continue;
                    }
                    state.raise("Invalid character in character class");
                }
                if (start !== state.pos) {
                    return result;
                }
            }
            else {
                state.raise("Invalid character in character class");
            }
            // https://tc39.es/ecma262/#prod-ClassUnion
            for (;;) {
                if (this.regexp_eatClassSetRange(state)) {
                    continue;
                }
                subResult = this.regexp_eatClassSetOperand(state);
                if (!subResult) {
                    return result;
                }
                if (subResult === CharSetString) {
                    result = CharSetString;
                }
            }
        };
        // https://tc39.es/ecma262/#prod-ClassSetRange
        pp$1.regexp_eatClassSetRange = function (state) {
            var start = state.pos;
            if (this.regexp_eatClassSetCharacter(state)) {
                var left = state.lastIntValue;
                if (state.eat(0x2D /* - */) && this.regexp_eatClassSetCharacter(state)) {
                    var right = state.lastIntValue;
                    if (left !== -1 && right !== -1 && left > right) {
                        state.raise("Range out of order in character class");
                    }
                    return true;
                }
                state.pos = start;
            }
            return false;
        };
        // https://tc39.es/ecma262/#prod-ClassSetOperand
        pp$1.regexp_eatClassSetOperand = function (state) {
            if (this.regexp_eatClassSetCharacter(state)) {
                return CharSetOk;
            }
            return this.regexp_eatClassStringDisjunction(state) || this.regexp_eatNestedClass(state);
        };
        // https://tc39.es/ecma262/#prod-NestedClass
        pp$1.regexp_eatNestedClass = function (state) {
            var start = state.pos;
            if (state.eat(0x5B /* [ */)) {
                var negate = state.eat(0x5E /* ^ */);
                var result = this.regexp_classContents(state);
                if (state.eat(0x5D /* ] */)) {
                    if (negate && result === CharSetString) {
                        state.raise("Negated character class may contain strings");
                    }
                    return result;
                }
                state.pos = start;
            }
            if (state.eat(0x5C /* \ */)) {
                var result$1 = this.regexp_eatCharacterClassEscape(state);
                if (result$1) {
                    return result$1;
                }
                state.pos = start;
            }
            return null;
        };
        // https://tc39.es/ecma262/#prod-ClassStringDisjunction
        pp$1.regexp_eatClassStringDisjunction = function (state) {
            var start = state.pos;
            if (state.eatChars([0x5C, 0x71] /* \q */)) {
                if (state.eat(0x7B /* { */)) {
                    var result = this.regexp_classStringDisjunctionContents(state);
                    if (state.eat(0x7D /* } */)) {
                        return result;
                    }
                }
                else {
                    // Make the same message as V8.
                    state.raise("Invalid escape");
                }
                state.pos = start;
            }
            return null;
        };
        // https://tc39.es/ecma262/#prod-ClassStringDisjunctionContents
        pp$1.regexp_classStringDisjunctionContents = function (state) {
            var result = this.regexp_classString(state);
            while (state.eat(0x7C /* | */)) {
                if (this.regexp_classString(state) === CharSetString) {
                    result = CharSetString;
                }
            }
            return result;
        };
        // https://tc39.es/ecma262/#prod-ClassString
        // https://tc39.es/ecma262/#prod-NonEmptyClassString
        pp$1.regexp_classString = function (state) {
            var count = 0;
            while (this.regexp_eatClassSetCharacter(state)) {
                count++;
            }
            return count === 1 ? CharSetOk : CharSetString;
        };
        // https://tc39.es/ecma262/#prod-ClassSetCharacter
        pp$1.regexp_eatClassSetCharacter = function (state) {
            var start = state.pos;
            if (state.eat(0x5C /* \ */)) {
                if (this.regexp_eatCharacterEscape(state) ||
                    this.regexp_eatClassSetReservedPunctuator(state)) {
                    return true;
                }
                if (state.eat(0x62 /* b */)) {
                    state.lastIntValue = 0x08; /* <BS> */
                    return true;
                }
                state.pos = start;
                return false;
            }
            var ch = state.current();
            if (ch < 0 || ch === state.lookahead() && isClassSetReservedDoublePunctuatorCharacter(ch)) {
                return false;
            }
            if (isClassSetSyntaxCharacter(ch)) {
                return false;
            }
            state.advance();
            state.lastIntValue = ch;
            return true;
        };
        // https://tc39.es/ecma262/#prod-ClassSetReservedDoublePunctuator
        function isClassSetReservedDoublePunctuatorCharacter(ch) {
            return (ch === 0x21 /* ! */ ||
                ch >= 0x23 /* # */ && ch <= 0x26 /* & */ ||
                ch >= 0x2A /* * */ && ch <= 0x2C /* , */ ||
                ch === 0x2E /* . */ ||
                ch >= 0x3A /* : */ && ch <= 0x40 /* @ */ ||
                ch === 0x5E /* ^ */ ||
                ch === 0x60 /* ` */ ||
                ch === 0x7E /* ~ */);
        }
        // https://tc39.es/ecma262/#prod-ClassSetSyntaxCharacter
        function isClassSetSyntaxCharacter(ch) {
            return (ch === 0x28 /* ( */ ||
                ch === 0x29 /* ) */ ||
                ch === 0x2D /* - */ ||
                ch === 0x2F /* / */ ||
                ch >= 0x5B /* [ */ && ch <= 0x5D /* ] */ ||
                ch >= 0x7B /* { */ && ch <= 0x7D /* } */);
        }
        // https://tc39.es/ecma262/#prod-ClassSetReservedPunctuator
        pp$1.regexp_eatClassSetReservedPunctuator = function (state) {
            var ch = state.current();
            if (isClassSetReservedPunctuator(ch)) {
                state.lastIntValue = ch;
                state.advance();
                return true;
            }
            return false;
        };
        // https://tc39.es/ecma262/#prod-ClassSetReservedPunctuator
        function isClassSetReservedPunctuator(ch) {
            return (ch === 0x21 /* ! */ ||
                ch === 0x23 /* # */ ||
                ch === 0x25 /* % */ ||
                ch === 0x26 /* & */ ||
                ch === 0x2C /* , */ ||
                ch === 0x2D /* - */ ||
                ch >= 0x3A /* : */ && ch <= 0x3E /* > */ ||
                ch === 0x40 /* @ */ ||
                ch === 0x60 /* ` */ ||
                ch === 0x7E /* ~ */);
        }
        // https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-ClassControlLetter
        pp$1.regexp_eatClassControlLetter = function (state) {
            var ch = state.current();
            if (isDecimalDigit(ch) || ch === 0x5F /* _ */) {
                state.lastIntValue = ch % 0x20;
                state.advance();
                return true;
            }
            return false;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-HexEscapeSequence
        pp$1.regexp_eatHexEscapeSequence = function (state) {
            var start = state.pos;
            if (state.eat(0x78 /* x */)) {
                if (this.regexp_eatFixedHexDigits(state, 2)) {
                    return true;
                }
                if (state.switchU) {
                    state.raise("Invalid escape");
                }
                state.pos = start;
            }
            return false;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-DecimalDigits
        pp$1.regexp_eatDecimalDigits = function (state) {
            var start = state.pos;
            var ch = 0;
            state.lastIntValue = 0;
            while (isDecimalDigit(ch = state.current())) {
                state.lastIntValue = 10 * state.lastIntValue + (ch - 0x30 /* 0 */);
                state.advance();
            }
            return state.pos !== start;
        };
        function isDecimalDigit(ch) {
            return ch >= 0x30 /* 0 */ && ch <= 0x39; /* 9 */
        }
        // https://www.ecma-international.org/ecma-262/8.0/#prod-HexDigits
        pp$1.regexp_eatHexDigits = function (state) {
            var start = state.pos;
            var ch = 0;
            state.lastIntValue = 0;
            while (isHexDigit(ch = state.current())) {
                state.lastIntValue = 16 * state.lastIntValue + hexToInt(ch);
                state.advance();
            }
            return state.pos !== start;
        };
        function isHexDigit(ch) {
            return ((ch >= 0x30 /* 0 */ && ch <= 0x39 /* 9 */) ||
                (ch >= 0x41 /* A */ && ch <= 0x46 /* F */) ||
                (ch >= 0x61 /* a */ && ch <= 0x66 /* f */));
        }
        function hexToInt(ch) {
            if (ch >= 0x41 /* A */ && ch <= 0x46 /* F */) {
                return 10 + (ch - 0x41 /* A */);
            }
            if (ch >= 0x61 /* a */ && ch <= 0x66 /* f */) {
                return 10 + (ch - 0x61 /* a */);
            }
            return ch - 0x30; /* 0 */
        }
        // https://www.ecma-international.org/ecma-262/8.0/#prod-annexB-LegacyOctalEscapeSequence
        // Allows only 0-377(octal) i.e. 0-255(decimal).
        pp$1.regexp_eatLegacyOctalEscapeSequence = function (state) {
            if (this.regexp_eatOctalDigit(state)) {
                var n1 = state.lastIntValue;
                if (this.regexp_eatOctalDigit(state)) {
                    var n2 = state.lastIntValue;
                    if (n1 <= 3 && this.regexp_eatOctalDigit(state)) {
                        state.lastIntValue = n1 * 64 + n2 * 8 + state.lastIntValue;
                    }
                    else {
                        state.lastIntValue = n1 * 8 + n2;
                    }
                }
                else {
                    state.lastIntValue = n1;
                }
                return true;
            }
            return false;
        };
        // https://www.ecma-international.org/ecma-262/8.0/#prod-OctalDigit
        pp$1.regexp_eatOctalDigit = function (state) {
            var ch = state.current();
            if (isOctalDigit(ch)) {
                state.lastIntValue = ch - 0x30; /* 0 */
                state.advance();
                return true;
            }
            state.lastIntValue = 0;
            return false;
        };
        function isOctalDigit(ch) {
            return ch >= 0x30 /* 0 */ && ch <= 0x37; /* 7 */
        }
        // https://www.ecma-international.org/ecma-262/8.0/#prod-Hex4Digits
        // https://www.ecma-international.org/ecma-262/8.0/#prod-HexDigit
        // And HexDigit HexDigit in https://www.ecma-international.org/ecma-262/8.0/#prod-HexEscapeSequence
        pp$1.regexp_eatFixedHexDigits = function (state, length) {
            var start = state.pos;
            state.lastIntValue = 0;
            for (var i = 0; i < length; ++i) {
                var ch = state.current();
                if (!isHexDigit(ch)) {
                    state.pos = start;
                    return false;
                }
                state.lastIntValue = 16 * state.lastIntValue + hexToInt(ch);
                state.advance();
            }
            return true;
        };
        // Object type used to represent tokens. Note that normally, tokens
        // simply exist as properties on the parser object. This is only
        // used for the onToken callback and the external tokenizer.
        var Token = function Token(p) {
            this.type = p.type;
            this.value = p.value;
            this.start = p.start;
            this.end = p.end;
            if (p.options.locations) {
                this.loc = new SourceLocation(p, p.startLoc, p.endLoc);
            }
            if (p.options.ranges) {
                this.range = [p.start, p.end];
            }
        };
        // ## Tokenizer
        var pp = Parser.prototype;
        // Move to the next token
        pp.next = function (ignoreEscapeSequenceInKeyword) {
            if (!ignoreEscapeSequenceInKeyword && this.type.keyword && this.containsEsc) {
                this.raiseRecoverable(this.start, "Escape sequence in keyword " + this.type.keyword);
            }
            if (this.options.onToken) {
                this.options.onToken(new Token(this));
            }
            this.lastTokEnd = this.end;
            this.lastTokStart = this.start;
            this.lastTokEndLoc = this.endLoc;
            this.lastTokStartLoc = this.startLoc;
            this.nextToken();
        };
        pp.getToken = function () {
            this.next();
            return new Token(this);
        };
        // If we're in an ES6 environment, make parsers iterable
        if (typeof Symbol !== "undefined") {
            pp[Symbol.iterator] = function () {
                var this$1$1 = this;
                return {
                    next: function () {
                        var token = this$1$1.getToken();
                        return {
                            done: token.type === types$1.eof,
                            value: token
                        };
                    }
                };
            };
        }
        // Toggle strict mode. Re-reads the next number or string to please
        // pedantic tests (`"use strict"; 010;` should fail).
        // Read a single token, updating the parser object's token-related
        // properties.
        pp.nextToken = function () {
            var curContext = this.curContext();
            if (!curContext || !curContext.preserveSpace) {
                this.skipSpace();
            }
            this.start = this.pos;
            if (this.options.locations) {
                this.startLoc = this.curPosition();
            }
            if (this.pos >= this.input.length) {
                return this.finishToken(types$1.eof);
            }
            if (curContext.override) {
                return curContext.override(this);
            }
            else {
                this.readToken(this.fullCharCodeAtPos());
            }
        };
        pp.readToken = function (code) {
            // Identifier or keyword. '\uXXXX' sequences are allowed in
            // identifiers, so '\' also dispatches to that.
            if (isIdentifierStart(code, this.options.ecmaVersion >= 6) || code === 92 /* '\' */) {
                return this.readWord();
            }
            return this.getTokenFromCode(code);
        };
        pp.fullCharCodeAtPos = function () {
            var code = this.input.charCodeAt(this.pos);
            if (code <= 0xd7ff || code >= 0xdc00) {
                return code;
            }
            var next = this.input.charCodeAt(this.pos + 1);
            return next <= 0xdbff || next >= 0xe000 ? code : (code << 10) + next - 0x35fdc00;
        };
        pp.skipBlockComment = function () {
            var startLoc = this.options.onComment && this.curPosition();
            var start = this.pos, end = this.input.indexOf("*/", this.pos += 2);
            if (end === -1) {
                this.raise(this.pos - 2, "Unterminated comment");
            }
            this.pos = end + 2;
            if (this.options.locations) {
                for (var nextBreak = (void 0), pos = start; (nextBreak = nextLineBreak(this.input, pos, this.pos)) > -1;) {
                    ++this.curLine;
                    pos = this.lineStart = nextBreak;
                }
            }
            if (this.options.onComment) {
                this.options.onComment(true, this.input.slice(start + 2, end), start, this.pos, startLoc, this.curPosition());
            }
        };
        pp.skipLineComment = function (startSkip) {
            var start = this.pos;
            var startLoc = this.options.onComment && this.curPosition();
            var ch = this.input.charCodeAt(this.pos += startSkip);
            while (this.pos < this.input.length && !isNewLine(ch)) {
                ch = this.input.charCodeAt(++this.pos);
            }
            if (this.options.onComment) {
                this.options.onComment(false, this.input.slice(start + startSkip, this.pos), start, this.pos, startLoc, this.curPosition());
            }
        };
        // Called at the start of the parse and after every token. Skips
        // whitespace and comments, and.
        pp.skipSpace = function () {
            loop: while (this.pos < this.input.length) {
                var ch = this.input.charCodeAt(this.pos);
                switch (ch) {
                    case 32:
                    case 160: // ' '
                        ++this.pos;
                        break;
                    case 13:
                        if (this.input.charCodeAt(this.pos + 1) === 10) {
                            ++this.pos;
                        }
                    case 10:
                    case 8232:
                    case 8233:
                        ++this.pos;
                        if (this.options.locations) {
                            ++this.curLine;
                            this.lineStart = this.pos;
                        }
                        break;
                    case 47: // '/'
                        switch (this.input.charCodeAt(this.pos + 1)) {
                            case 42: // '*'
                                this.skipBlockComment();
                                break;
                            case 47:
                                this.skipLineComment(2);
                                break;
                            default:
                                break loop;
                        }
                        break;
                    default:
                        if (ch > 8 && ch < 14 || ch >= 5760 && nonASCIIwhitespace.test(String.fromCharCode(ch))) {
                            ++this.pos;
                        }
                        else {
                            break loop;
                        }
                }
            }
        };
        // Called at the end of every token. Sets `end`, `val`, and
        // maintains `context` and `exprAllowed`, and skips the space after
        // the token, so that the next one's `start` will point at the
        // right position.
        pp.finishToken = function (type, val) {
            this.end = this.pos;
            if (this.options.locations) {
                this.endLoc = this.curPosition();
            }
            var prevType = this.type;
            this.type = type;
            this.value = val;
            this.updateContext(prevType);
        };
        // ### Token reading
        // This is the function that is called to fetch the next token. It
        // is somewhat obscure, because it works in character codes rather
        // than characters, and because operator parsing has been inlined
        // into it.
        //
        // All in the name of speed.
        //
        pp.readToken_dot = function () {
            var next = this.input.charCodeAt(this.pos + 1);
            if (next >= 48 && next <= 57) {
                return this.readNumber(true);
            }
            var next2 = this.input.charCodeAt(this.pos + 2);
            if (this.options.ecmaVersion >= 6 && next === 46 && next2 === 46) { // 46 = dot '.'
                this.pos += 3;
                return this.finishToken(types$1.ellipsis);
            }
            else {
                ++this.pos;
                return this.finishToken(types$1.dot);
            }
        };
        pp.readToken_slash = function () {
            var next = this.input.charCodeAt(this.pos + 1);
            if (this.exprAllowed) {
                ++this.pos;
                return this.readRegexp();
            }
            if (next === 61) {
                return this.finishOp(types$1.assign, 2);
            }
            return this.finishOp(types$1.slash, 1);
        };
        pp.readToken_mult_modulo_exp = function (code) {
            var next = this.input.charCodeAt(this.pos + 1);
            var size = 1;
            var tokentype = code === 42 ? types$1.star : types$1.modulo;
            // exponentiation operator ** and **=
            if (this.options.ecmaVersion >= 7 && code === 42 && next === 42) {
                ++size;
                tokentype = types$1.starstar;
                next = this.input.charCodeAt(this.pos + 2);
            }
            if (next === 61) {
                return this.finishOp(types$1.assign, size + 1);
            }
            return this.finishOp(tokentype, size);
        };
        pp.readToken_pipe_amp = function (code) {
            var next = this.input.charCodeAt(this.pos + 1);
            if (next === code) {
                if (this.options.ecmaVersion >= 12) {
                    var next2 = this.input.charCodeAt(this.pos + 2);
                    if (next2 === 61) {
                        return this.finishOp(types$1.assign, 3);
                    }
                }
                return this.finishOp(code === 124 ? types$1.logicalOR : types$1.logicalAND, 2);
            }
            if (next === 61) {
                return this.finishOp(types$1.assign, 2);
            }
            return this.finishOp(code === 124 ? types$1.bitwiseOR : types$1.bitwiseAND, 1);
        };
        pp.readToken_caret = function () {
            var next = this.input.charCodeAt(this.pos + 1);
            if (next === 61) {
                return this.finishOp(types$1.assign, 2);
            }
            return this.finishOp(types$1.bitwiseXOR, 1);
        };
        pp.readToken_plus_min = function (code) {
            var next = this.input.charCodeAt(this.pos + 1);
            if (next === code) {
                if (next === 45 && !this.inModule && this.input.charCodeAt(this.pos + 2) === 62 &&
                    (this.lastTokEnd === 0 || lineBreak.test(this.input.slice(this.lastTokEnd, this.pos)))) {
                    // A `-->` line comment
                    this.skipLineComment(3);
                    this.skipSpace();
                    return this.nextToken();
                }
                return this.finishOp(types$1.incDec, 2);
            }
            if (next === 61) {
                return this.finishOp(types$1.assign, 2);
            }
            return this.finishOp(types$1.plusMin, 1);
        };
        pp.readToken_lt_gt = function (code) {
            var next = this.input.charCodeAt(this.pos + 1);
            var size = 1;
            if (next === code) {
                size = code === 62 && this.input.charCodeAt(this.pos + 2) === 62 ? 3 : 2;
                if (this.input.charCodeAt(this.pos + size) === 61) {
                    return this.finishOp(types$1.assign, size + 1);
                }
                return this.finishOp(types$1.bitShift, size);
            }
            if (next === 33 && code === 60 && !this.inModule && this.input.charCodeAt(this.pos + 2) === 45 &&
                this.input.charCodeAt(this.pos + 3) === 45) {
                // `<!--`, an XML-style comment that should be interpreted as a line comment
                this.skipLineComment(4);
                this.skipSpace();
                return this.nextToken();
            }
            if (next === 61) {
                size = 2;
            }
            return this.finishOp(types$1.relational, size);
        };
        pp.readToken_eq_excl = function (code) {
            var next = this.input.charCodeAt(this.pos + 1);
            if (next === 61) {
                return this.finishOp(types$1.equality, this.input.charCodeAt(this.pos + 2) === 61 ? 3 : 2);
            }
            if (code === 61 && next === 62 && this.options.ecmaVersion >= 6) { // '=>'
                this.pos += 2;
                return this.finishToken(types$1.arrow);
            }
            return this.finishOp(code === 61 ? types$1.eq : types$1.prefix, 1);
        };
        pp.readToken_question = function () {
            var ecmaVersion = this.options.ecmaVersion;
            if (ecmaVersion >= 11) {
                var next = this.input.charCodeAt(this.pos + 1);
                if (next === 46) {
                    var next2 = this.input.charCodeAt(this.pos + 2);
                    if (next2 < 48 || next2 > 57) {
                        return this.finishOp(types$1.questionDot, 2);
                    }
                }
                if (next === 63) {
                    if (ecmaVersion >= 12) {
                        var next2$1 = this.input.charCodeAt(this.pos + 2);
                        if (next2$1 === 61) {
                            return this.finishOp(types$1.assign, 3);
                        }
                    }
                    return this.finishOp(types$1.coalesce, 2);
                }
            }
            return this.finishOp(types$1.question, 1);
        };
        pp.readToken_numberSign = function () {
            var ecmaVersion = this.options.ecmaVersion;
            var code = 35; // '#'
            if (ecmaVersion >= 13) {
                ++this.pos;
                code = this.fullCharCodeAtPos();
                if (isIdentifierStart(code, true) || code === 92 /* '\' */) {
                    return this.finishToken(types$1.privateId, this.readWord1());
                }
            }
            this.raise(this.pos, "Unexpected character '" + codePointToString(code) + "'");
        };
        pp.getTokenFromCode = function (code) {
            switch (code) {
                // The interpretation of a dot depends on whether it is followed
                // by a digit or another two dots.
                case 46: // '.'
                    return this.readToken_dot();
                // Punctuation tokens.
                case 40:
                    ++this.pos;
                    return this.finishToken(types$1.parenL);
                case 41:
                    ++this.pos;
                    return this.finishToken(types$1.parenR);
                case 59:
                    ++this.pos;
                    return this.finishToken(types$1.semi);
                case 44:
                    ++this.pos;
                    return this.finishToken(types$1.comma);
                case 91:
                    ++this.pos;
                    return this.finishToken(types$1.bracketL);
                case 93:
                    ++this.pos;
                    return this.finishToken(types$1.bracketR);
                case 123:
                    ++this.pos;
                    return this.finishToken(types$1.braceL);
                case 125:
                    ++this.pos;
                    return this.finishToken(types$1.braceR);
                case 58:
                    ++this.pos;
                    return this.finishToken(types$1.colon);
                case 96: // '`'
                    if (this.options.ecmaVersion < 6) {
                        break;
                    }
                    ++this.pos;
                    return this.finishToken(types$1.backQuote);
                case 48: // '0'
                    var next = this.input.charCodeAt(this.pos + 1);
                    if (next === 120 || next === 88) {
                        return this.readRadixNumber(16);
                    } // '0x', '0X' - hex number
                    if (this.options.ecmaVersion >= 6) {
                        if (next === 111 || next === 79) {
                            return this.readRadixNumber(8);
                        } // '0o', '0O' - octal number
                        if (next === 98 || next === 66) {
                            return this.readRadixNumber(2);
                        } // '0b', '0B' - binary number
                    }
                // Anything else beginning with a digit is an integer, octal
                // number, or float.
                case 49:
                case 50:
                case 51:
                case 52:
                case 53:
                case 54:
                case 55:
                case 56:
                case 57: // 1-9
                    return this.readNumber(false);
                // Quotes produce strings.
                case 34:
                case 39: // '"', "'"
                    return this.readString(code);
                // Operators are parsed inline in tiny state machines. '=' (61) is
                // often referred to. `finishOp` simply skips the amount of
                // characters it is given as second argument, and returns a token
                // of the type given by its first argument.
                case 47: // '/'
                    return this.readToken_slash();
                case 37:
                case 42: // '%*'
                    return this.readToken_mult_modulo_exp(code);
                case 124:
                case 38: // '|&'
                    return this.readToken_pipe_amp(code);
                case 94: // '^'
                    return this.readToken_caret();
                case 43:
                case 45: // '+-'
                    return this.readToken_plus_min(code);
                case 60:
                case 62: // '<>'
                    return this.readToken_lt_gt(code);
                case 61:
                case 33: // '=!'
                    return this.readToken_eq_excl(code);
                case 63: // '?'
                    return this.readToken_question();
                case 126: // '~'
                    return this.finishOp(types$1.prefix, 1);
                case 35: // '#'
                    return this.readToken_numberSign();
            }
            this.raise(this.pos, "Unexpected character '" + codePointToString(code) + "'");
        };
        pp.finishOp = function (type, size) {
            var str = this.input.slice(this.pos, this.pos + size);
            this.pos += size;
            return this.finishToken(type, str);
        };
        pp.readRegexp = function () {
            var escaped, inClass, start = this.pos;
            for (;;) {
                if (this.pos >= this.input.length) {
                    this.raise(start, "Unterminated regular expression");
                }
                var ch = this.input.charAt(this.pos);
                if (lineBreak.test(ch)) {
                    this.raise(start, "Unterminated regular expression");
                }
                if (!escaped) {
                    if (ch === "[") {
                        inClass = true;
                    }
                    else if (ch === "]" && inClass) {
                        inClass = false;
                    }
                    else if (ch === "/" && !inClass) {
                        break;
                    }
                    escaped = ch === "\\";
                }
                else {
                    escaped = false;
                }
                ++this.pos;
            }
            var pattern = this.input.slice(start, this.pos);
            ++this.pos;
            var flagsStart = this.pos;
            var flags = this.readWord1();
            if (this.containsEsc) {
                this.unexpected(flagsStart);
            }
            // Validate pattern
            var state = this.regexpState || (this.regexpState = new RegExpValidationState(this));
            state.reset(start, pattern, flags);
            this.validateRegExpFlags(state);
            this.validateRegExpPattern(state);
            // Create Literal#value property value.
            var value = null;
            try {
                value = new RegExp(pattern, flags);
            }
            catch (e) {
                // ESTree requires null if it failed to instantiate RegExp object.
                // https://github.com/estree/estree/blob/a27003adf4fd7bfad44de9cef372a2eacd527b1c/es5.md#regexpliteral
            }
            return this.finishToken(types$1.regexp, { pattern: pattern, flags: flags, value: value });
        };
        // Read an integer in the given radix. Return null if zero digits
        // were read, the integer value otherwise. When `len` is given, this
        // will return `null` unless the integer has exactly `len` digits.
        pp.readInt = function (radix, len, maybeLegacyOctalNumericLiteral) {
            // `len` is used for character escape sequences. In that case, disallow separators.
            var allowSeparators = this.options.ecmaVersion >= 12 && len === undefined;
            // `maybeLegacyOctalNumericLiteral` is true if it doesn't have prefix (0x,0o,0b)
            // and isn't fraction part nor exponent part. In that case, if the first digit
            // is zero then disallow separators.
            var isLegacyOctalNumericLiteral = maybeLegacyOctalNumericLiteral && this.input.charCodeAt(this.pos) === 48;
            var start = this.pos, total = 0, lastCode = 0;
            for (var i = 0, e = len == null ? Infinity : len; i < e; ++i, ++this.pos) {
                var code = this.input.charCodeAt(this.pos), val = (void 0);
                if (allowSeparators && code === 95) {
                    if (isLegacyOctalNumericLiteral) {
                        this.raiseRecoverable(this.pos, "Numeric separator is not allowed in legacy octal numeric literals");
                    }
                    if (lastCode === 95) {
                        this.raiseRecoverable(this.pos, "Numeric separator must be exactly one underscore");
                    }
                    if (i === 0) {
                        this.raiseRecoverable(this.pos, "Numeric separator is not allowed at the first of digits");
                    }
                    lastCode = code;
                    continue;
                }
                if (code >= 97) {
                    val = code - 97 + 10;
                } // a
                else if (code >= 65) {
                    val = code - 65 + 10;
                } // A
                else if (code >= 48 && code <= 57) {
                    val = code - 48;
                } // 0-9
                else {
                    val = Infinity;
                }
                if (val >= radix) {
                    break;
                }
                lastCode = code;
                total = total * radix + val;
            }
            if (allowSeparators && lastCode === 95) {
                this.raiseRecoverable(this.pos - 1, "Numeric separator is not allowed at the last of digits");
            }
            if (this.pos === start || len != null && this.pos - start !== len) {
                return null;
            }
            return total;
        };
        function stringToNumber(str, isLegacyOctalNumericLiteral) {
            if (isLegacyOctalNumericLiteral) {
                return parseInt(str, 8);
            }
            // `parseFloat(value)` stops parsing at the first numeric separator then returns a wrong value.
            return parseFloat(str.replace(/_/g, ""));
        }
        function stringToBigInt(str) {
            if (typeof BigInt !== "function") {
                return null;
            }
            // `BigInt(value)` throws syntax error if the string contains numeric separators.
            return BigInt(str.replace(/_/g, ""));
        }
        pp.readRadixNumber = function (radix) {
            var start = this.pos;
            this.pos += 2; // 0x
            var val = this.readInt(radix);
            if (val == null) {
                this.raise(this.start + 2, "Expected number in radix " + radix);
            }
            if (this.options.ecmaVersion >= 11 && this.input.charCodeAt(this.pos) === 110) {
                val = stringToBigInt(this.input.slice(start, this.pos));
                ++this.pos;
            }
            else if (isIdentifierStart(this.fullCharCodeAtPos())) {
                this.raise(this.pos, "Identifier directly after number");
            }
            return this.finishToken(types$1.num, val);
        };
        // Read an integer, octal integer, or floating-point number.
        pp.readNumber = function (startsWithDot) {
            var start = this.pos;
            if (!startsWithDot && this.readInt(10, undefined, true) === null) {
                this.raise(start, "Invalid number");
            }
            var octal = this.pos - start >= 2 && this.input.charCodeAt(start) === 48;
            if (octal && this.strict) {
                this.raise(start, "Invalid number");
            }
            var next = this.input.charCodeAt(this.pos);
            if (!octal && !startsWithDot && this.options.ecmaVersion >= 11 && next === 110) {
                var val$1 = stringToBigInt(this.input.slice(start, this.pos));
                ++this.pos;
                if (isIdentifierStart(this.fullCharCodeAtPos())) {
                    this.raise(this.pos, "Identifier directly after number");
                }
                return this.finishToken(types$1.num, val$1);
            }
            if (octal && /[89]/.test(this.input.slice(start, this.pos))) {
                octal = false;
            }
            if (next === 46 && !octal) { // '.'
                ++this.pos;
                this.readInt(10);
                next = this.input.charCodeAt(this.pos);
            }
            if ((next === 69 || next === 101) && !octal) { // 'eE'
                next = this.input.charCodeAt(++this.pos);
                if (next === 43 || next === 45) {
                    ++this.pos;
                } // '+-'
                if (this.readInt(10) === null) {
                    this.raise(start, "Invalid number");
                }
            }
            if (isIdentifierStart(this.fullCharCodeAtPos())) {
                this.raise(this.pos, "Identifier directly after number");
            }
            var val = stringToNumber(this.input.slice(start, this.pos), octal);
            return this.finishToken(types$1.num, val);
        };
        // Read a string value, interpreting backslash-escapes.
        pp.readCodePoint = function () {
            var ch = this.input.charCodeAt(this.pos), code;
            if (ch === 123) { // '{'
                if (this.options.ecmaVersion < 6) {
                    this.unexpected();
                }
                var codePos = ++this.pos;
                code = this.readHexChar(this.input.indexOf("}", this.pos) - this.pos);
                ++this.pos;
                if (code > 0x10FFFF) {
                    this.invalidStringToken(codePos, "Code point out of bounds");
                }
            }
            else {
                code = this.readHexChar(4);
            }
            return code;
        };
        pp.readString = function (quote) {
            var out = "", chunkStart = ++this.pos;
            for (;;) {
                if (this.pos >= this.input.length) {
                    this.raise(this.start, "Unterminated string constant");
                }
                var ch = this.input.charCodeAt(this.pos);
                if (ch === quote) {
                    break;
                }
                if (ch === 92) { // '\'
                    out += this.input.slice(chunkStart, this.pos);
                    out += this.readEscapedChar(false);
                    chunkStart = this.pos;
                }
                else if (ch === 0x2028 || ch === 0x2029) {
                    if (this.options.ecmaVersion < 10) {
                        this.raise(this.start, "Unterminated string constant");
                    }
                    ++this.pos;
                    if (this.options.locations) {
                        this.curLine++;
                        this.lineStart = this.pos;
                    }
                }
                else {
                    if (isNewLine(ch)) {
                        this.raise(this.start, "Unterminated string constant");
                    }
                    ++this.pos;
                }
            }
            out += this.input.slice(chunkStart, this.pos++);
            return this.finishToken(types$1.string, out);
        };
        // Reads template string tokens.
        var INVALID_TEMPLATE_ESCAPE_ERROR = {};
        pp.tryReadTemplateToken = function () {
            this.inTemplateElement = true;
            try {
                this.readTmplToken();
            }
            catch (err) {
                if (err === INVALID_TEMPLATE_ESCAPE_ERROR) {
                    this.readInvalidTemplateToken();
                }
                else {
                    throw err;
                }
            }
            this.inTemplateElement = false;
        };
        pp.invalidStringToken = function (position, message) {
            if (this.inTemplateElement && this.options.ecmaVersion >= 9) {
                throw INVALID_TEMPLATE_ESCAPE_ERROR;
            }
            else {
                this.raise(position, message);
            }
        };
        pp.readTmplToken = function () {
            var out = "", chunkStart = this.pos;
            for (;;) {
                if (this.pos >= this.input.length) {
                    this.raise(this.start, "Unterminated template");
                }
                var ch = this.input.charCodeAt(this.pos);
                if (ch === 96 || ch === 36 && this.input.charCodeAt(this.pos + 1) === 123) { // '`', '${'
                    if (this.pos === this.start && (this.type === types$1.template || this.type === types$1.invalidTemplate)) {
                        if (ch === 36) {
                            this.pos += 2;
                            return this.finishToken(types$1.dollarBraceL);
                        }
                        else {
                            ++this.pos;
                            return this.finishToken(types$1.backQuote);
                        }
                    }
                    out += this.input.slice(chunkStart, this.pos);
                    return this.finishToken(types$1.template, out);
                }
                if (ch === 92) { // '\'
                    out += this.input.slice(chunkStart, this.pos);
                    out += this.readEscapedChar(true);
                    chunkStart = this.pos;
                }
                else if (isNewLine(ch)) {
                    out += this.input.slice(chunkStart, this.pos);
                    ++this.pos;
                    switch (ch) {
                        case 13:
                            if (this.input.charCodeAt(this.pos) === 10) {
                                ++this.pos;
                            }
                        case 10:
                            out += "\n";
                            break;
                        default:
                            out += String.fromCharCode(ch);
                            break;
                    }
                    if (this.options.locations) {
                        ++this.curLine;
                        this.lineStart = this.pos;
                    }
                    chunkStart = this.pos;
                }
                else {
                    ++this.pos;
                }
            }
        };
        // Reads a template token to search for the end, without validating any escape sequences
        pp.readInvalidTemplateToken = function () {
            for (; this.pos < this.input.length; this.pos++) {
                switch (this.input[this.pos]) {
                    case "\\":
                        ++this.pos;
                        break;
                    case "$":
                        if (this.input[this.pos + 1] !== "{") {
                            break;
                        }
                    // falls through
                    case "`":
                        return this.finishToken(types$1.invalidTemplate, this.input.slice(this.start, this.pos));
                    // no default
                }
            }
            this.raise(this.start, "Unterminated template");
        };
        // Used to read escaped characters
        pp.readEscapedChar = function (inTemplate) {
            var ch = this.input.charCodeAt(++this.pos);
            ++this.pos;
            switch (ch) {
                case 110: return "\n"; // 'n' -> '\n'
                case 114: return "\r"; // 'r' -> '\r'
                case 120: return String.fromCharCode(this.readHexChar(2)); // 'x'
                case 117: return codePointToString(this.readCodePoint()); // 'u'
                case 116: return "\t"; // 't' -> '\t'
                case 98: return "\b"; // 'b' -> '\b'
                case 118: return "\u000b"; // 'v' -> '\u000b'
                case 102: return "\f"; // 'f' -> '\f'
                case 13: if (this.input.charCodeAt(this.pos) === 10) {
                    ++this.pos;
                } // '\r\n'
                case 10: // ' \n'
                    if (this.options.locations) {
                        this.lineStart = this.pos;
                        ++this.curLine;
                    }
                    return "";
                case 56:
                case 57:
                    if (this.strict) {
                        this.invalidStringToken(this.pos - 1, "Invalid escape sequence");
                    }
                    if (inTemplate) {
                        var codePos = this.pos - 1;
                        this.invalidStringToken(codePos, "Invalid escape sequence in template string");
                    }
                default:
                    if (ch >= 48 && ch <= 55) {
                        var octalStr = this.input.substr(this.pos - 1, 3).match(/^[0-7]+/)[0];
                        var octal = parseInt(octalStr, 8);
                        if (octal > 255) {
                            octalStr = octalStr.slice(0, -1);
                            octal = parseInt(octalStr, 8);
                        }
                        this.pos += octalStr.length - 1;
                        ch = this.input.charCodeAt(this.pos);
                        if ((octalStr !== "0" || ch === 56 || ch === 57) && (this.strict || inTemplate)) {
                            this.invalidStringToken(this.pos - 1 - octalStr.length, inTemplate
                                ? "Octal literal in template string"
                                : "Octal literal in strict mode");
                        }
                        return String.fromCharCode(octal);
                    }
                    if (isNewLine(ch)) {
                        // Unicode new line characters after \ get removed from output in both
                        // template literals and strings
                        return "";
                    }
                    return String.fromCharCode(ch);
            }
        };
        // Used to read character escape sequences ('\x', '\u', '\U').
        pp.readHexChar = function (len) {
            var codePos = this.pos;
            var n = this.readInt(16, len);
            if (n === null) {
                this.invalidStringToken(codePos, "Bad character escape sequence");
            }
            return n;
        };
        // Read an identifier, and return it as a string. Sets `this.containsEsc`
        // to whether the word contained a '\u' escape.
        //
        // Incrementally adds only escaped chars, adding other chunks as-is
        // as a micro-optimization.
        pp.readWord1 = function () {
            this.containsEsc = false;
            var word = "", first = true, chunkStart = this.pos;
            var astral = this.options.ecmaVersion >= 6;
            while (this.pos < this.input.length) {
                var ch = this.fullCharCodeAtPos();
                if (isIdentifierChar(ch, astral)) {
                    this.pos += ch <= 0xffff ? 1 : 2;
                }
                else if (ch === 92) { // "\"
                    this.containsEsc = true;
                    word += this.input.slice(chunkStart, this.pos);
                    var escStart = this.pos;
                    if (this.input.charCodeAt(++this.pos) !== 117) // "u"
                     {
                        this.invalidStringToken(this.pos, "Expecting Unicode escape sequence \\uXXXX");
                    }
                    ++this.pos;
                    var esc = this.readCodePoint();
                    if (!(first ? isIdentifierStart : isIdentifierChar)(esc, astral)) {
                        this.invalidStringToken(escStart, "Invalid Unicode escape");
                    }
                    word += codePointToString(esc);
                    chunkStart = this.pos;
                }
                else {
                    break;
                }
                first = false;
            }
            return word + this.input.slice(chunkStart, this.pos);
        };
        // Read an identifier or keyword token. Will check for reserved
        // words when necessary.
        pp.readWord = function () {
            var word = this.readWord1();
            var type = types$1.name;
            if (this.keywords.test(word)) {
                type = keywords[word];
            }
            return this.finishToken(type, word);
        };
        // Acorn is a tiny, fast JavaScript parser written in JavaScript.
        //
        // Acorn was written by Marijn Haverbeke, Ingvar Stepanyan, and
        // various contributors and released under an MIT license.
        //
        // Git repositories for Acorn are available at
        //
        //     http://marijnhaverbeke.nl/git/acorn
        //     https://github.com/acornjs/acorn.git
        //
        // Please use the [github bug tracker][ghbt] to report issues.
        //
        // [ghbt]: https://github.com/acornjs/acorn/issues
        //
        // [walk]: util/walk.js
        var version = "8.11.3";
        Parser.acorn = {
            Parser: Parser,
            version: version,
            defaultOptions: defaultOptions,
            Position: Position,
            SourceLocation: SourceLocation,
            getLineInfo: getLineInfo,
            Node: Node,
            TokenType: TokenType,
            tokTypes: types$1,
            keywordTypes: keywords,
            TokContext: TokContext,
            tokContexts: types,
            isIdentifierChar: isIdentifierChar,
            isIdentifierStart: isIdentifierStart,
            Token: Token,
            isNewLine: isNewLine,
            lineBreak: lineBreak,
            lineBreakG: lineBreakG,
            nonASCIIwhitespace: nonASCIIwhitespace
        };
        // The main exported interface (under `self.acorn` when in the
        // browser) is a `parse` function that takes a code string and returns
        // an abstract syntax tree as specified by the [ESTree spec][estree].
        //
        // [estree]: https://github.com/estree/estree
        function parse(input, options) {
            return Parser.parse(input, options);
        }
        // This function tries to parse a single expression at a given
        // offset in a string. Useful for parsing mixed-language formats
        // that embed JavaScript expressions.
        function parseExpressionAt(input, pos, options) {
            return Parser.parseExpressionAt(input, pos, options);
        }
        // Acorn is organized as a tokenizer and a recursive-descent parser.
        // The `tokenizer` export provides an interface to the tokenizer.
        function tokenizer(input, options) {
            return Parser.tokenizer(input, options);
        }
        exports.Node = Node;
        exports.Parser = Parser;
        exports.Position = Position;
        exports.SourceLocation = SourceLocation;
        exports.TokContext = TokContext;
        exports.Token = Token;
        exports.TokenType = TokenType;
        exports.defaultOptions = defaultOptions;
        exports.getLineInfo = getLineInfo;
        exports.isIdentifierChar = isIdentifierChar;
        exports.isIdentifierStart = isIdentifierStart;
        exports.isNewLine = isNewLine;
        exports.keywordTypes = keywords;
        exports.lineBreak = lineBreak;
        exports.lineBreakG = lineBreakG;
        exports.nonASCIIwhitespace = nonASCIIwhitespace;
        exports.parse = parse;
        exports.parseExpressionAt = parseExpressionAt;
        exports.tokContexts = types;
        exports.tokTypes = types$1;
        exports.tokenizer = tokenizer;
        exports.version = version;
    }));
},
/* combine-source-map/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    var path = require('path');
    var convert = require(54) /* convert-source-map */;
    var memoize = require(55) /* lodash.memoize */;
    var createGenerator = require(56) /* inline-source-map */;
    var pathIsAbsolute = require(57) /* ./lib/path-is-absolute */;
    var mappingsFromMap = require(58) /* ./lib/mappings-from-map */;
    var protocolRx = /^[a-z]+:\/\//;
    /**
     * Rebases a relative path in 'sourceFile' to be relative
     * to the path where 'sourceFile' is located.
     *
     * This is necessary before adding relative paths to the
     * new combined map to ensure all paths are relative to their
     * original source.
     *
     * The 'sourceRoot' from the original source map is joined
     * as well to ensure the complete path.
     *
     * Resulting paths that are absolute are passed along directly.
     *
     * @param sourceFile {String} path to the original source file that references a map
     * @param relativeRoot {String} sourceRoot in sourceFile's map to combine with relativePath
     * @param relativePath {String} source path from sourceFile's map
     */
    var rebaseRelativePath = memoize(function (sourceFile, relativeRoot, relativePath) {
        if (!relativePath) {
            return relativePath;
        }
        // join relative path to root (e.g. 'src/' + 'file.js')
        var relativeRootedPath = relativeRoot ? path.join(relativeRoot, relativePath) : relativePath;
        relativeRootedPath = relativeRootedPath.replace(/\\/g, '/');
        sourceFile = sourceFile.replace(/\\/g, '/');
        if (sourceFile === relativeRootedPath || // same path,
            pathIsAbsolute(relativeRootedPath) || // absolute path, nor
            protocolRx.test(relativeRootedPath)) { // absolute protocol need rebasing
            return relativeRootedPath;
        }
        // make relative to source file
        return path.join(path.dirname(sourceFile), relativeRootedPath).replace(/\\/g, '/');
    }, function (a, b, c) {
        return a + '::' + b + '::' + c;
    });
    function resolveMap(source) {
        var gen = convert.fromSource(source);
        return gen ? gen.toObject() : null;
    }
    function hasInlinedSource(existingMap) {
        return existingMap.sourcesContent && !!existingMap.sourcesContent[0];
    }
    function Combiner(file, sourceRoot) {
        // since we include the original code in the map sourceRoot actually not needed
        this.generator = createGenerator({ file: file || 'generated.js', sourceRoot: sourceRoot });
    }
    Combiner.prototype._addGeneratedMap = function (sourceFile, source, offset) {
        this.generator.addGeneratedMappings(sourceFile, source, offset);
        this.generator.addSourceContent(sourceFile, source);
        return this;
    };
    Combiner.prototype._addExistingMap = function (sourceFile, source, existingMap, offset) {
        var mappings = mappingsFromMap(existingMap);
        // add all of the sources from the map
        for (var i = 0, len = existingMap.sources.length; i < len; i++) {
            if (!existingMap.sourcesContent)
                continue;
            this.generator.addSourceContent(rebaseRelativePath(sourceFile, existingMap.sourceRoot, existingMap.sources[i]), existingMap.sourcesContent[i]);
        }
        // add the mappings, preserving the original mapping 'source'
        mappings.forEach(function (mapping) {
            // Add the mappings one at a time because 'inline-source-map' doesn't handle
            // mapping source filenames. The mapping.source already takes sourceRoot into account
            // per the SMConsumer.eachMapping function, so pass null for the root here.
            this.generator.addMappings(rebaseRelativePath(sourceFile, null, mapping.source), [mapping], offset);
        }, this);
        return this;
    };
    /**
     * Adds map to underlying source map.
     * If source contains a source map comment that has the source of the original file inlined it will offset these
     * mappings and include them.
     * If no source map comment is found or it has no source inlined, mappings for the file will be generated and included
     *
     * @name addMap
     * @function
     * @param opts {Object} { sourceFile: {String}, source: {String} }
     * @param offset {Object} { line: {Number}, column: {Number} }
     */
    Combiner.prototype.addFile = function (opts, offset) {
        offset = offset || {};
        if (!offset.hasOwnProperty('line'))
            offset.line = 0;
        if (!offset.hasOwnProperty('column'))
            offset.column = 0;
        var existingMap = resolveMap(opts.source);
        return existingMap && hasInlinedSource(existingMap)
            ? this._addExistingMap(opts.sourceFile, opts.source, existingMap, offset)
            : this._addGeneratedMap(opts.sourceFile, opts.source, offset);
    };
    /**
    * @name base64
    * @function
    * @return {String} base64 encoded combined source map
    */
    Combiner.prototype.base64 = function () {
        return this.generator.base64Encode();
    };
    /**
     * @name comment
     * @function
     * @return {String} base64 encoded sourceMappingUrl comment of the combined source map
     */
    Combiner.prototype.comment = function () {
        return this.generator.inlineMappingUrl();
    };
    /**
     * @name create
     * @function
     * @param file {String} optional name of the generated file
     * @param sourceRoot {String} optional sourceRoot of the map to be generated
     * @return {Object} Combiner instance to which source maps can be added and later combined
     */
    exports.create = function (file, sourceRoot) { return new Combiner(file, sourceRoot); };
    /**
     * @name removeComments
     * @function
     * @param src
     * @return {String} src with all sourceMappingUrl comments removed
     */
    exports.removeComments = function (src) {
        if (!src.replace)
            return src;
        return src.replace(convert.commentRegex, '').replace(convert.mapFileCommentRegex, '');
    };
},
/* convert-source-map/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    Object.defineProperty(exports, 'commentRegex', {
        get: function getCommentRegex() {
            // Groups: 1: media type, 2: MIME type, 3: charset, 4: encoding, 5: data.
            return /^\s*?\/[\/\*][@#]\s+?sourceMappingURL=data:(((?:application|text)\/json)(?:;charset=([^;,]+?)?)?)?(?:;(base64))?,(.*?)$/mg;
        }
    });
    Object.defineProperty(exports, 'mapFileCommentRegex', {
        get: function getMapFileCommentRegex() {
            // Matches sourceMappingURL in either // or /* comment styles.
            return /(?:\/\/[@#][ \t]+?sourceMappingURL=([^\s'"`]+?)[ \t]*?$)|(?:\/\*[@#][ \t]+sourceMappingURL=([^*]+?)[ \t]*?(?:\*\/){1}[ \t]*?$)/mg;
        }
    });
    var decodeBase64;
    if (typeof Buffer !== 'undefined') {
        if (typeof Buffer.from === 'function') {
            decodeBase64 = decodeBase64WithBufferFrom;
        }
        else {
            decodeBase64 = decodeBase64WithNewBuffer;
        }
    }
    else {
        decodeBase64 = decodeBase64WithAtob;
    }
    function decodeBase64WithBufferFrom(base64) {
        return Buffer.from(base64, 'base64').toString();
    }
    function decodeBase64WithNewBuffer(base64) {
        if (typeof value === 'number') {
            throw new TypeError('The value to decode must not be of type number.');
        }
        return new Buffer(base64, 'base64').toString();
    }
    function decodeBase64WithAtob(base64) {
        return decodeURIComponent(escape(atob(base64)));
    }
    function stripComment(sm) {
        return sm.split(',').pop();
    }
    function readFromFileMap(sm, read) {
        var r = exports.mapFileCommentRegex.exec(sm);
        // for some odd reason //# .. captures in 1 and /* .. */ in 2
        var filename = r[1] || r[2];
        try {
            var sm = read(filename);
            if (sm != null && typeof sm.catch === 'function') {
                return sm.catch(throwError);
            }
            else {
                return sm;
            }
        }
        catch (e) {
            throwError(e);
        }
        function throwError(e) {
            throw new Error('An error occurred while trying to read the map file at ' + filename + '\n' + e.stack);
        }
    }
    function Converter(sm, opts) {
        opts = opts || {};
        if (opts.hasComment) {
            sm = stripComment(sm);
        }
        if (opts.encoding === 'base64') {
            sm = decodeBase64(sm);
        }
        else if (opts.encoding === 'uri') {
            sm = decodeURIComponent(sm);
        }
        if (opts.isJSON || opts.encoding) {
            sm = JSON.parse(sm);
        }
        this.sourcemap = sm;
    }
    Converter.prototype.toJSON = function (space) {
        return JSON.stringify(this.sourcemap, null, space);
    };
    if (typeof Buffer !== 'undefined') {
        if (typeof Buffer.from === 'function') {
            Converter.prototype.toBase64 = encodeBase64WithBufferFrom;
        }
        else {
            Converter.prototype.toBase64 = encodeBase64WithNewBuffer;
        }
    }
    else {
        Converter.prototype.toBase64 = encodeBase64WithBtoa;
    }
    function encodeBase64WithBufferFrom() {
        var json = this.toJSON();
        return Buffer.from(json, 'utf8').toString('base64');
    }
    function encodeBase64WithNewBuffer() {
        var json = this.toJSON();
        if (typeof json === 'number') {
            throw new TypeError('The json to encode must not be of type number.');
        }
        return new Buffer(json, 'utf8').toString('base64');
    }
    function encodeBase64WithBtoa() {
        var json = this.toJSON();
        return btoa(unescape(encodeURIComponent(json)));
    }
    Converter.prototype.toURI = function () {
        var json = this.toJSON();
        return encodeURIComponent(json);
    };
    Converter.prototype.toComment = function (options) {
        var encoding, content, data;
        if (options != null && options.encoding === 'uri') {
            encoding = '';
            content = this.toURI();
        }
        else {
            encoding = ';base64';
            content = this.toBase64();
        }
        data = 'sourceMappingURL=data:application/json;charset=utf-8' + encoding + ',' + content;
        return options != null && options.multiline ? '/*# ' + data + ' */' : '//# ' + data;
    };
    // returns copy instead of original
    Converter.prototype.toObject = function () {
        return JSON.parse(this.toJSON());
    };
    Converter.prototype.addProperty = function (key, value) {
        if (this.sourcemap.hasOwnProperty(key))
            throw new Error('property "' + key + '" already exists on the sourcemap, use set property instead');
        return this.setProperty(key, value);
    };
    Converter.prototype.setProperty = function (key, value) {
        this.sourcemap[key] = value;
        return this;
    };
    Converter.prototype.getProperty = function (key) {
        return this.sourcemap[key];
    };
    exports.fromObject = function (obj) {
        return new Converter(obj);
    };
    exports.fromJSON = function (json) {
        return new Converter(json, { isJSON: true });
    };
    exports.fromURI = function (uri) {
        return new Converter(uri, { encoding: 'uri' });
    };
    exports.fromBase64 = function (base64) {
        return new Converter(base64, { encoding: 'base64' });
    };
    exports.fromComment = function (comment) {
        var m, encoding;
        comment = comment
            .replace(/^\/\*/g, '//')
            .replace(/\*\/$/g, '');
        m = exports.commentRegex.exec(comment);
        encoding = m && m[4] || 'uri';
        return new Converter(comment, { encoding: encoding, hasComment: true });
    };
    function makeConverter(sm) {
        return new Converter(sm, { isJSON: true });
    }
    exports.fromMapFileComment = function (comment, read) {
        if (typeof read === 'string') {
            throw new Error('String directory paths are no longer supported with `fromMapFileComment`\n' +
                'Please review the Upgrading documentation at https://github.com/thlorenz/convert-source-map#upgrading');
        }
        var sm = readFromFileMap(comment, read);
        if (sm != null && typeof sm.then === 'function') {
            return sm.then(makeConverter);
        }
        else {
            return makeConverter(sm);
        }
    };
    // Finds last sourcemap comment in file or returns null if none was found
    exports.fromSource = function (content) {
        var m = content.match(exports.commentRegex);
        return m ? exports.fromComment(m.pop()) : null;
    };
    // Finds last sourcemap comment in file or returns null if none was found
    exports.fromMapFileSource = function (content, read) {
        if (typeof read === 'string') {
            throw new Error('String directory paths are no longer supported with `fromMapFileSource`\n' +
                'Please review the Upgrading documentation at https://github.com/thlorenz/convert-source-map#upgrading');
        }
        var m = content.match(exports.mapFileCommentRegex);
        return m ? exports.fromMapFileComment(m.pop(), read) : null;
    };
    exports.removeComments = function (src) {
        return src.replace(exports.commentRegex, '');
    };
    exports.removeMapFileComments = function (src) {
        return src.replace(exports.mapFileCommentRegex, '');
    };
    exports.generateMapFileComment = function (file, options) {
        var data = 'sourceMappingURL=' + file;
        return options && options.multiline ? '/*# ' + data + ' */' : '//# ' + data;
    };
},
/* lodash.memoize/index.js */ function _(require, module, exports, __esModule, __esExport) {/**
     * lodash 3.0.4 (Custom Build) <https://lodash.com/>
     * Build: `lodash modern modularize exports="npm" -o ./`
     * Copyright 2012-2015 The Dojo Foundation <http://dojofoundation.org/>
     * Based on Underscore.js 1.8.3 <http://underscorejs.org/LICENSE>
     * Copyright 2009-2015 Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
     * Available under MIT license <https://lodash.com/license>
     */
    /** Used as the `TypeError` message for "Functions" methods. */
    var FUNC_ERROR_TEXT = 'Expected a function';
    /** Used for native method references. */
    var objectProto = Object.prototype;
    /** Used to check objects for own properties. */
    var hasOwnProperty = objectProto.hasOwnProperty;
    /**
     * Creates a cache object to store key/value pairs.
     *
     * @private
     * @static
     * @name Cache
     * @memberOf _.memoize
     */
    function MapCache() {
        this.__data__ = {};
    }
    /**
     * Removes `key` and its value from the cache.
     *
     * @private
     * @name delete
     * @memberOf _.memoize.Cache
     * @param {string} key The key of the value to remove.
     * @returns {boolean} Returns `true` if the entry was removed successfully, else `false`.
     */
    function mapDelete(key) {
        return this.has(key) && delete this.__data__[key];
    }
    /**
     * Gets the cached value for `key`.
     *
     * @private
     * @name get
     * @memberOf _.memoize.Cache
     * @param {string} key The key of the value to get.
     * @returns {*} Returns the cached value.
     */
    function mapGet(key) {
        return key == '__proto__' ? undefined : this.__data__[key];
    }
    /**
     * Checks if a cached value for `key` exists.
     *
     * @private
     * @name has
     * @memberOf _.memoize.Cache
     * @param {string} key The key of the entry to check.
     * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
     */
    function mapHas(key) {
        return key != '__proto__' && hasOwnProperty.call(this.__data__, key);
    }
    /**
     * Sets `value` to `key` of the cache.
     *
     * @private
     * @name set
     * @memberOf _.memoize.Cache
     * @param {string} key The key of the value to cache.
     * @param {*} value The value to cache.
     * @returns {Object} Returns the cache object.
     */
    function mapSet(key, value) {
        if (key != '__proto__') {
            this.__data__[key] = value;
        }
        return this;
    }
    /**
     * Creates a function that memoizes the result of `func`. If `resolver` is
     * provided it determines the cache key for storing the result based on the
     * arguments provided to the memoized function. By default, the first argument
     * provided to the memoized function is coerced to a string and used as the
     * cache key. The `func` is invoked with the `this` binding of the memoized
     * function.
     *
     * **Note:** The cache is exposed as the `cache` property on the memoized
     * function. Its creation may be customized by replacing the `_.memoize.Cache`
     * constructor with one whose instances implement the [`Map`](https://people.mozilla.org/~jorendorff/es6-draft.html#sec-properties-of-the-map-prototype-object)
     * method interface of `get`, `has`, and `set`.
     *
     * @static
     * @memberOf _
     * @category Function
     * @param {Function} func The function to have its output memoized.
     * @param {Function} [resolver] The function to resolve the cache key.
     * @returns {Function} Returns the new memoizing function.
     * @example
     *
     * var upperCase = _.memoize(function(string) {
     *   return string.toUpperCase();
     * });
     *
     * upperCase('fred');
     * // => 'FRED'
     *
     * // modifying the result cache
     * upperCase.cache.set('fred', 'BARNEY');
     * upperCase('fred');
     * // => 'BARNEY'
     *
     * // replacing `_.memoize.Cache`
     * var object = { 'user': 'fred' };
     * var other = { 'user': 'barney' };
     * var identity = _.memoize(_.identity);
     *
     * identity(object);
     * // => { 'user': 'fred' }
     * identity(other);
     * // => { 'user': 'fred' }
     *
     * _.memoize.Cache = WeakMap;
     * var identity = _.memoize(_.identity);
     *
     * identity(object);
     * // => { 'user': 'fred' }
     * identity(other);
     * // => { 'user': 'barney' }
     */
    function memoize(func, resolver) {
        if (typeof func != 'function' || (resolver && typeof resolver != 'function')) {
            throw new TypeError(FUNC_ERROR_TEXT);
        }
        var memoized = function () {
            var args = arguments, key = resolver ? resolver.apply(this, args) : args[0], cache = memoized.cache;
            if (cache.has(key)) {
                return cache.get(key);
            }
            var result = func.apply(this, args);
            memoized.cache = cache.set(key, result);
            return result;
        };
        memoized.cache = new memoize.Cache;
        return memoized;
    }
    // Add functions to the `Map` cache.
    MapCache.prototype['delete'] = mapDelete;
    MapCache.prototype.get = mapGet;
    MapCache.prototype.has = mapHas;
    MapCache.prototype.set = mapSet;
    // Assign cache to `_.memoize`.
    memoize.Cache = MapCache;
    module.exports = memoize;
},
/* inline-source-map/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    var SourceMapGenerator = require(23) /* source-map */.SourceMapGenerator;
    function offsetMapping(mapping, offset) {
        return { line: offset.line + mapping.line, column: offset.column + mapping.column };
    }
    function newlinesIn(src) {
        if (!src)
            return 0;
        var newlines = src.match(/\n/g);
        return newlines ? newlines.length : 0;
    }
    function Generator(opts) {
        opts = opts || {};
        this.generator = new SourceMapGenerator({ file: opts.file || '', sourceRoot: opts.sourceRoot || '' });
        this.sourcesContent = undefined;
        this.opts = opts;
    }
    /**
     * Adds the given mappings to the generator and offsets them if offset is given
     *
     * @name addMappings
     * @function
     * @param sourceFile {String} name of the source file
     * @param mappings {Array{{Object}} each object has the form { original: { line: _, column: _ }, generated: { line: _, column: _ } }
     * @param offset {Object} offset to apply to each mapping. Has the form { line: _, column: _ }
     * @return {Object} the generator to allow chaining
     */
    Generator.prototype.addMappings = function (sourceFile, mappings, offset) {
        var generator = this.generator;
        offset = offset || {};
        offset.line = offset.hasOwnProperty('line') ? offset.line : 0;
        offset.column = offset.hasOwnProperty('column') ? offset.column : 0;
        mappings.forEach(function (m) {
            // only set source if we have original position to handle edgecase (see inline-source-map tests)
            generator.addMapping({
                source: m.original ? sourceFile : undefined,
                original: m.original,
                generated: offsetMapping(m.generated, offset)
            });
        });
        return this;
    };
    /**
     * Generates mappings for the given source, assuming that no translation from original to generated is necessary.
     *
     * @name addGeneratedMappings
     * @function
     * @param sourceFile {String} name of the source file
     * @param source {String} source of the file
     * @param offset {Object} offset to apply to each mapping. Has the form { line: _, column: _ }
     * @return {Object} the generator to allow chaining
     */
    Generator.prototype.addGeneratedMappings = function (sourceFile, source, offset) {
        var mappings = [], linesToGenerate = newlinesIn(source) + 1;
        for (var line = 1; line <= linesToGenerate; line++) {
            var location = { line: line, column: 0 };
            mappings.push({ original: location, generated: location });
        }
        return this.addMappings(sourceFile, mappings, offset);
    };
    /**
     * Adds source content for the given source file.
     *
     * @name addSourceContent
     * @function
     * @param sourceFile {String} The source file for which a mapping is included
     * @param sourcesContent {String} The content of the source file
     * @return {Object} The generator to allow chaining
     */
    Generator.prototype.addSourceContent = function (sourceFile, sourcesContent) {
        this.sourcesContent = this.sourcesContent || {};
        this.sourcesContent[sourceFile] = sourcesContent;
        return this;
    };
    /**
     * @name base64Encode
     * @function
     * @return {String} bas64 encoded representation of the added mappings
     */
    Generator.prototype.base64Encode = function () {
        var map = this.toString();
        if (Buffer.from) {
            return Buffer.from(map).toString('base64');
        }
        return new Buffer(map).toString('base64');
    };
    /**
     * @name inlineMappingUrl
     * @function
     * @return {String} comment with base64 encoded representation of the added mappings. Can be inlined at the end of the generated file.
     */
    Generator.prototype.inlineMappingUrl = function () {
        var charset = this.opts.charset || 'utf-8';
        return '//# sourceMappingURL=data:application/json;charset=' + charset + ';base64,' + this.base64Encode();
    };
    Generator.prototype.toJSON = function () {
        var map = this.generator.toJSON();
        if (!this.sourcesContent)
            return map;
        var toSourcesContent = (function (s) {
            if (typeof this.sourcesContent[s] === 'string') {
                return this.sourcesContent[s];
            }
            else {
                return null;
            }
        }).bind(this);
        map.sourcesContent = map.sources.map(toSourcesContent);
        return map;
    };
    Generator.prototype.toString = function () {
        return JSON.stringify(this);
    };
    Generator.prototype._mappings = function () {
        return this.generator._mappings._array;
    };
    Generator.prototype.gen = function () {
        return this.generator;
    };
    module.exports = function (opts) { return new Generator(opts); };
    module.exports.Generator = Generator;
},
/* combine-source-map/lib/path-is-absolute.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    function posix(path) {
        return path.charAt(0) === '/';
    }
    ;
    function win32(path) {
        // https://github.com/joyent/node/blob/b3fcc245fb25539909ef1d5eaa01dbf92e168633/lib/path.js#L56
        var splitDeviceRe = /^([a-zA-Z]:|[\\\/]{2}[^\\\/]+[\\\/]+[^\\\/]+)?([\\\/])?([\s\S]*?)$/;
        var result = splitDeviceRe.exec(path);
        var device = result[1] || '';
        var isUnc = !!device && device.charAt(1) !== ':';
        // UNC paths are always absolute
        return !!result[2] || isUnc;
    }
    ;
    module.exports = process.platform === 'win32' ? win32 : posix;
    module.exports.posix = posix;
    module.exports.win32 = win32;
},
/* combine-source-map/lib/mappings-from-map.js */ function _(require, module, exports, __esModule, __esExport) {
    var SMConsumer = require(23) /* source-map */.SourceMapConsumer;
    /**
     * @name mappingsFromMap
     * @function
     * @param map {Object} the JSON.parse()'ed map
     * @return {Array} array of mappings
     */
    module.exports = function (map) {
        var consumer = new SMConsumer(map);
        var mappings = [];
        consumer.eachMapping(function (mapping) {
            // only set source if we have original position to handle edgecase (see inline-source-map tests)
            mappings.push({
                original: mapping.originalColumn != null ? {
                    column: mapping.originalColumn,
                    line: mapping.originalLine
                } : undefined,
                generated: {
                    column: mapping.generatedColumn,
                    line: mapping.generatedLine
                },
                source: mapping.originalColumn != null ? mapping.source : undefined,
                name: mapping.name
            });
        });
        return mappings;
    };
},
/* graph.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.detect_cycles = void 0;
    function detect_cycles(graph) {
        const cycles = [];
        const state = new Map();
        for (const node of graph.keys()) {
            state.set(node, { visited: false, explored: false });
        }
        function detect_cycle(nodes) {
            const node = nodes[0];
            const entry = state.get(node);
            if (entry.visited) {
                return false;
            }
            if (entry.explored) {
                cycles.push(nodes);
                return true;
            }
            entry.explored = true;
            const neighbors = graph.get(node);
            for (const neighbor of neighbors) {
                const { visited } = state.get(neighbor);
                if (!visited) {
                    const cycle = detect_cycle([neighbor, ...nodes]);
                    if (cycle) {
                        break;
                    }
                }
            }
            entry.explored = false;
            entry.visited = true;
            return false;
        }
        for (const node of graph.keys()) {
            detect_cycle([node]);
        }
        return cycles;
    }
    exports.detect_cycles = detect_cycles;
    
},
/* styles.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.wrap_css_modules = exports.compile_styles = exports.collect_styles = void 0;
    const path_1 = require("path");
    const less_1 = __importDefault(require(61) /* less */);
    const chalk_1 = __importDefault(require(37) /* chalk */);
    const css_1 = __importDefault(require(206) /* css */);
    const sys_1 = require(20) /* ./sys */;
    function collect_styles(styles_dir) {
        const paths = [];
        for (const path of (0, sys_1.scan)(styles_dir, [".less", ".css"])) {
            if ((0, path_1.basename)(path).startsWith("_")) {
                continue;
            }
            paths.push(path);
        }
        return paths;
    }
    exports.collect_styles = collect_styles;
    async function compile_styles(paths, styles_dir, css_dir) {
        let success = true;
        for (const path of paths) {
            try {
                const style = (0, sys_1.read)(path);
                const { css } = await less_1.default.render(style, { filename: path });
                const dst = (0, sys_1.rename)(path, { base: styles_dir, dir: css_dir, ext: ".css" });
                (0, sys_1.write)(dst, css);
            }
            catch (error) {
                success = false;
                console.log(`${chalk_1.default.red("\u2717")} failed to compile ${chalk_1.default.magenta(path)}:`);
                console.log(`${error}`);
            }
        }
        return success;
    }
    exports.compile_styles = compile_styles;
    function wrap_css_modules(css_dir, js_dir, dts_dir, dts_internal_dir) {
        function* collect_classes(ast) {
            const { stylesheet } = ast;
            if (stylesheet == null) {
                return;
            }
            for (const rule of stylesheet.rules) {
                if (rule.type == "rule") {
                    const { selectors } = rule;
                    for (const selector of selectors ?? []) {
                        const classes = selector.match(/\.[A-Za-z0-9_-]+/g);
                        if (classes != null) {
                            for (const cls of classes) {
                                yield cls.substring(1);
                            }
                        }
                    }
                }
            }
        }
        for (const css_path of (0, sys_1.scan)(css_dir, [".css"])) {
            const sub_path = (0, path_1.relative)(css_dir, css_path);
            const css_in = (0, sys_1.read)(css_path);
            const ast = css_1.default.parse(css_in);
            const js = [];
            const dts = [];
            const dts_internal = [];
            dts_internal.push(`declare module "styles/${sub_path.replace(/\\/g, "/")}" {`);
            const classes = new Set(collect_classes(ast));
            for (const cls of classes) {
                if (!cls.startsWith("bk-")) {
                    continue;
                }
                const ident = cls.replace(/^bk-/, "").replace(/-/g, "_");
                js.push(`export const ${ident} = "${cls}"`);
                dts.push(`export const ${ident}: string`);
                dts_internal.push(`  export const ${ident}: string`);
            }
            const css_out = css_1.default.stringify(ast, { compress: true });
            js.push(`export default \`${css_out}\``);
            dts.push("export default \"\"");
            dts_internal.push("  export default \"\"");
            dts_internal.push("}");
            const js_file = `${(0, path_1.join)(js_dir, "styles", sub_path)}.js`;
            const dts_file = `${(0, path_1.join)(dts_dir, "styles", sub_path)}.d.ts`;
            const dts_internal_file = `${(0, path_1.join)(dts_internal_dir, "styles", sub_path)}.d.ts`;
            (0, sys_1.write)(js_file, `${js.join("\n")}\n`);
            (0, sys_1.write)(dts_file, `${dts.join("\n")}\n`);
            (0, sys_1.write)(dts_internal_file, `${dts_internal.join("\n")}\n`);
        }
    }
    exports.wrap_css_modules = wrap_css_modules;
    
},
/* less/index.js */ function _(require, module, exports, __esModule, __esExport) {
    module.exports = require(62) /* ./lib/less-node */.default;
},
/* less/lib/less-node/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var environment_1 = tslib_1.__importDefault(require(64) /* ./environment */);
    var file_manager_1 = tslib_1.__importDefault(require(67) /* ./file-manager */);
    var url_file_manager_1 = tslib_1.__importDefault(require(74) /* ./url-file-manager */);
    var less_1 = tslib_1.__importDefault(require(108) /* ../less */);
    var less = less_1.default(environment_1.default, [new file_manager_1.default(), new url_file_manager_1.default()]);
    var lessc_helper_1 = tslib_1.__importDefault(require(199) /* ./lessc-helper */);
    // allow people to create less with their own environment
    less.createFromEnvironment = less_1.default;
    less.lesscHelper = lessc_helper_1.default;
    less.PluginLoader = require(200) /* ./plugin-loader */.default;
    less.fs = require(68) /* ./fs */.default;
    less.FileManager = file_manager_1.default;
    less.UrlFileManager = url_file_manager_1.default;
    // Set up options
    less.options = require(201) /* ../less/default-options */.default();
    // provide image-size functionality
    require(202) /* ./image-size */.default(less.environment);
    exports.default = less;
    
},
/* tslib/tslib.js */ function _(require, module, exports, __esModule, __esExport) {
    /******************************************************************************
    Copyright (c) Microsoft Corporation.
    
    Permission to use, copy, modify, and/or distribute this software for any
    purpose with or without fee is hereby granted.
    
    THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
    REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
    AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
    INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
    LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
    OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
    PERFORMANCE OF THIS SOFTWARE.
    ***************************************************************************** */
    /* global global, define, Symbol, Reflect, Promise, SuppressedError */
    var __extends;
    var __assign;
    var __rest;
    var __decorate;
    var __param;
    var __esDecorate;
    var __runInitializers;
    var __propKey;
    var __setFunctionName;
    var __metadata;
    var __awaiter;
    var __generator;
    var __exportStar;
    var __values;
    var __read;
    var __spread;
    var __spreadArrays;
    var __spreadArray;
    var __await;
    var __asyncGenerator;
    var __asyncDelegator;
    var __asyncValues;
    var __makeTemplateObject;
    var __importStar;
    var __importDefault;
    var __classPrivateFieldGet;
    var __classPrivateFieldSet;
    var __classPrivateFieldIn;
    var __createBinding;
    var __addDisposableResource;
    var __disposeResources;
    (function (factory) {
        var root = typeof global === "object" ? global : typeof self === "object" ? self : typeof this === "object" ? this : {};
        if (typeof define === "function" && define.amd) {
            define("tslib", ["exports"], function (exports) { factory(createExporter(root, createExporter(exports))); });
        }
        else if (typeof module === "object" && typeof module.exports === "object") {
            factory(createExporter(root, createExporter(module.exports)));
        }
        else {
            factory(createExporter(root));
        }
        function createExporter(exports, previous) {
            if (exports !== root) {
                if (typeof Object.create === "function") {
                    Object.defineProperty(exports, "__esModule", { value: true });
                }
                else {
                    exports.__esModule = true;
                }
            }
            return function (id, v) { return exports[id] = previous ? previous(id, v) : v; };
        }
    })(function (exporter) {
        var extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b)
                if (Object.prototype.hasOwnProperty.call(b, p))
                    d[p] = b[p]; };
        __extends = function (d, b) {
            if (typeof b !== "function" && b !== null)
                throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
            extendStatics(d, b);
            function __() { this.constructor = d; }
            d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
        };
        __assign = Object.assign || function (t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s)
                    if (Object.prototype.hasOwnProperty.call(s, p))
                        t[p] = s[p];
            }
            return t;
        };
        __rest = function (s, e) {
            var t = {};
            for (var p in s)
                if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
                    t[p] = s[p];
            if (s != null && typeof Object.getOwnPropertySymbols === "function")
                for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
                    if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                        t[p[i]] = s[p[i]];
                }
            return t;
        };
        __decorate = function (decorators, target, key, desc) {
            var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
            if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
                r = Reflect.decorate(decorators, target, key, desc);
            else
                for (var i = decorators.length - 1; i >= 0; i--)
                    if (d = decorators[i])
                        r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
            return c > 3 && r && Object.defineProperty(target, key, r), r;
        };
        __param = function (paramIndex, decorator) {
            return function (target, key) { decorator(target, key, paramIndex); };
        };
        __esDecorate = function (ctor, descriptorIn, decorators, contextIn, initializers, extraInitializers) {
            function accept(f) { if (f !== void 0 && typeof f !== "function")
                throw new TypeError("Function expected"); return f; }
            var kind = contextIn.kind, key = kind === "getter" ? "get" : kind === "setter" ? "set" : "value";
            var target = !descriptorIn && ctor ? contextIn["static"] ? ctor : ctor.prototype : null;
            var descriptor = descriptorIn || (target ? Object.getOwnPropertyDescriptor(target, contextIn.name) : {});
            var _, done = false;
            for (var i = decorators.length - 1; i >= 0; i--) {
                var context = {};
                for (var p in contextIn)
                    context[p] = p === "access" ? {} : contextIn[p];
                for (var p in contextIn.access)
                    context.access[p] = contextIn.access[p];
                context.addInitializer = function (f) { if (done)
                    throw new TypeError("Cannot add initializers after decoration has completed"); extraInitializers.push(accept(f || null)); };
                var result = (0, decorators[i])(kind === "accessor" ? { get: descriptor.get, set: descriptor.set } : descriptor[key], context);
                if (kind === "accessor") {
                    if (result === void 0)
                        continue;
                    if (result === null || typeof result !== "object")
                        throw new TypeError("Object expected");
                    if (_ = accept(result.get))
                        descriptor.get = _;
                    if (_ = accept(result.set))
                        descriptor.set = _;
                    if (_ = accept(result.init))
                        initializers.unshift(_);
                }
                else if (_ = accept(result)) {
                    if (kind === "field")
                        initializers.unshift(_);
                    else
                        descriptor[key] = _;
                }
            }
            if (target)
                Object.defineProperty(target, contextIn.name, descriptor);
            done = true;
        };
        __runInitializers = function (thisArg, initializers, value) {
            var useValue = arguments.length > 2;
            for (var i = 0; i < initializers.length; i++) {
                value = useValue ? initializers[i].call(thisArg, value) : initializers[i].call(thisArg);
            }
            return useValue ? value : void 0;
        };
        __propKey = function (x) {
            return typeof x === "symbol" ? x : "".concat(x);
        };
        __setFunctionName = function (f, name, prefix) {
            if (typeof name === "symbol")
                name = name.description ? "[".concat(name.description, "]") : "";
            return Object.defineProperty(f, "name", { configurable: true, value: prefix ? "".concat(prefix, " ", name) : name });
        };
        __metadata = function (metadataKey, metadataValue) {
            if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
                return Reflect.metadata(metadataKey, metadataValue);
        };
        __awaiter = function (thisArg, _arguments, P, generator) {
            function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
            return new (P || (P = Promise))(function (resolve, reject) {
                function fulfilled(value) { try {
                    step(generator.next(value));
                }
                catch (e) {
                    reject(e);
                } }
                function rejected(value) { try {
                    step(generator["throw"](value));
                }
                catch (e) {
                    reject(e);
                } }
                function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
                step((generator = generator.apply(thisArg, _arguments || [])).next());
            });
        };
        __generator = function (thisArg, body) {
            var _ = { label: 0, sent: function () { if (t[0] & 1)
                    throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
            return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function () { return this; }), g;
            function verb(n) { return function (v) { return step([n, v]); }; }
            function step(op) {
                if (f)
                    throw new TypeError("Generator is already executing.");
                while (g && (g = 0, op[0] && (_ = 0)), _)
                    try {
                        if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done)
                            return t;
                        if (y = 0, t)
                            op = [op[0] & 2, t.value];
                        switch (op[0]) {
                            case 0:
                            case 1:
                                t = op;
                                break;
                            case 4:
                                _.label++;
                                return { value: op[1], done: false };
                            case 5:
                                _.label++;
                                y = op[1];
                                op = [0];
                                continue;
                            case 7:
                                op = _.ops.pop();
                                _.trys.pop();
                                continue;
                            default:
                                if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) {
                                    _ = 0;
                                    continue;
                                }
                                if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) {
                                    _.label = op[1];
                                    break;
                                }
                                if (op[0] === 6 && _.label < t[1]) {
                                    _.label = t[1];
                                    t = op;
                                    break;
                                }
                                if (t && _.label < t[2]) {
                                    _.label = t[2];
                                    _.ops.push(op);
                                    break;
                                }
                                if (t[2])
                                    _.ops.pop();
                                _.trys.pop();
                                continue;
                        }
                        op = body.call(thisArg, _);
                    }
                    catch (e) {
                        op = [6, e];
                        y = 0;
                    }
                    finally {
                        f = t = 0;
                    }
                if (op[0] & 5)
                    throw op[1];
                return { value: op[0] ? op[1] : void 0, done: true };
            }
        };
        __exportStar = function (m, o) {
            for (var p in m)
                if (p !== "default" && !Object.prototype.hasOwnProperty.call(o, p))
                    __createBinding(o, m, p);
        };
        __createBinding = Object.create ? (function (o, m, k, k2) {
            if (k2 === undefined)
                k2 = k;
            var desc = Object.getOwnPropertyDescriptor(m, k);
            if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
                desc = { enumerable: true, get: function () { return m[k]; } };
            }
            Object.defineProperty(o, k2, desc);
        }) : (function (o, m, k, k2) {
            if (k2 === undefined)
                k2 = k;
            o[k2] = m[k];
        });
        __values = function (o) {
            var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
            if (m)
                return m.call(o);
            if (o && typeof o.length === "number")
                return {
                    next: function () {
                        if (o && i >= o.length)
                            o = void 0;
                        return { value: o && o[i++], done: !o };
                    }
                };
            throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
        };
        __read = function (o, n) {
            var m = typeof Symbol === "function" && o[Symbol.iterator];
            if (!m)
                return o;
            var i = m.call(o), r, ar = [], e;
            try {
                while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
                    ar.push(r.value);
            }
            catch (error) {
                e = { error: error };
            }
            finally {
                try {
                    if (r && !r.done && (m = i["return"]))
                        m.call(i);
                }
                finally {
                    if (e)
                        throw e.error;
                }
            }
            return ar;
        };
        /** @deprecated */
        __spread = function () {
            for (var ar = [], i = 0; i < arguments.length; i++)
                ar = ar.concat(__read(arguments[i]));
            return ar;
        };
        /** @deprecated */
        __spreadArrays = function () {
            for (var s = 0, i = 0, il = arguments.length; i < il; i++)
                s += arguments[i].length;
            for (var r = Array(s), k = 0, i = 0; i < il; i++)
                for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
                    r[k] = a[j];
            return r;
        };
        __spreadArray = function (to, from, pack) {
            if (pack || arguments.length === 2)
                for (var i = 0, l = from.length, ar; i < l; i++) {
                    if (ar || !(i in from)) {
                        if (!ar)
                            ar = Array.prototype.slice.call(from, 0, i);
                        ar[i] = from[i];
                    }
                }
            return to.concat(ar || Array.prototype.slice.call(from));
        };
        __await = function (v) {
            return this instanceof __await ? (this.v = v, this) : new __await(v);
        };
        __asyncGenerator = function (thisArg, _arguments, generator) {
            if (!Symbol.asyncIterator)
                throw new TypeError("Symbol.asyncIterator is not defined.");
            var g = generator.apply(thisArg, _arguments || []), i, q = [];
            return i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i;
            function verb(n) { if (g[n])
                i[n] = function (v) { return new Promise(function (a, b) { q.push([n, v, a, b]) > 1 || resume(n, v); }); }; }
            function resume(n, v) { try {
                step(g[n](v));
            }
            catch (e) {
                settle(q[0][3], e);
            } }
            function step(r) { r.value instanceof __await ? Promise.resolve(r.value.v).then(fulfill, reject) : settle(q[0][2], r); }
            function fulfill(value) { resume("next", value); }
            function reject(value) { resume("throw", value); }
            function settle(f, v) { if (f(v), q.shift(), q.length)
                resume(q[0][0], q[0][1]); }
        };
        __asyncDelegator = function (o) {
            var i, p;
            return i = {}, verb("next"), verb("throw", function (e) { throw e; }), verb("return"), i[Symbol.iterator] = function () { return this; }, i;
            function verb(n, f) { i[n] = o[n] ? function (v) { return (p = !p) ? { value: __await(o[n](v)), done: false } : f ? f(v) : v; } : f; }
        };
        __asyncValues = function (o) {
            if (!Symbol.asyncIterator)
                throw new TypeError("Symbol.asyncIterator is not defined.");
            var m = o[Symbol.asyncIterator], i;
            return m ? m.call(o) : (o = typeof __values === "function" ? __values(o) : o[Symbol.iterator](), i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i);
            function verb(n) { i[n] = o[n] && function (v) { return new Promise(function (resolve, reject) { v = o[n](v), settle(resolve, reject, v.done, v.value); }); }; }
            function settle(resolve, reject, d, v) { Promise.resolve(v).then(function (v) { resolve({ value: v, done: d }); }, reject); }
        };
        __makeTemplateObject = function (cooked, raw) {
            if (Object.defineProperty) {
                Object.defineProperty(cooked, "raw", { value: raw });
            }
            else {
                cooked.raw = raw;
            }
            return cooked;
        };
        var __setModuleDefault = Object.create ? (function (o, v) {
            Object.defineProperty(o, "default", { enumerable: true, value: v });
        }) : function (o, v) {
            o["default"] = v;
        };
        __importStar = function (mod) {
            if (mod && mod.__esModule)
                return mod;
            var result = {};
            if (mod != null)
                for (var k in mod)
                    if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                        __createBinding(result, mod, k);
            __setModuleDefault(result, mod);
            return result;
        };
        __importDefault = function (mod) {
            return (mod && mod.__esModule) ? mod : { "default": mod };
        };
        __classPrivateFieldGet = function (receiver, state, kind, f) {
            if (kind === "a" && !f)
                throw new TypeError("Private accessor was defined without a getter");
            if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
                throw new TypeError("Cannot read private member from an object whose class did not declare it");
            return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
        };
        __classPrivateFieldSet = function (receiver, state, value, kind, f) {
            if (kind === "m")
                throw new TypeError("Private method is not writable");
            if (kind === "a" && !f)
                throw new TypeError("Private accessor was defined without a setter");
            if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
                throw new TypeError("Cannot write private member to an object whose class did not declare it");
            return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
        };
        __classPrivateFieldIn = function (state, receiver) {
            if (receiver === null || (typeof receiver !== "object" && typeof receiver !== "function"))
                throw new TypeError("Cannot use 'in' operator on non-object");
            return typeof state === "function" ? receiver === state : state.has(receiver);
        };
        __addDisposableResource = function (env, value, async) {
            if (value !== null && value !== void 0) {
                if (typeof value !== "object" && typeof value !== "function")
                    throw new TypeError("Object expected.");
                var dispose;
                if (async) {
                    if (!Symbol.asyncDispose)
                        throw new TypeError("Symbol.asyncDispose is not defined.");
                    dispose = value[Symbol.asyncDispose];
                }
                if (dispose === void 0) {
                    if (!Symbol.dispose)
                        throw new TypeError("Symbol.dispose is not defined.");
                    dispose = value[Symbol.dispose];
                }
                if (typeof dispose !== "function")
                    throw new TypeError("Object not disposable.");
                env.stack.push({ value: value, dispose: dispose, async: async });
            }
            else if (async) {
                env.stack.push({ async: true });
            }
            return value;
        };
        var _SuppressedError = typeof SuppressedError === "function" ? SuppressedError : function (error, suppressed, message) {
            var e = new Error(message);
            return e.name = "SuppressedError", e.error = error, e.suppressed = suppressed, e;
        };
        __disposeResources = function (env) {
            function fail(e) {
                env.error = env.hasError ? new _SuppressedError(e, env.error, "An error was suppressed during disposal.") : e;
                env.hasError = true;
            }
            function next() {
                while (env.stack.length) {
                    var rec = env.stack.pop();
                    try {
                        var result = rec.dispose && rec.dispose.call(rec.value);
                        if (rec.async)
                            return Promise.resolve(result).then(next, function (e) { fail(e); return next(); });
                    }
                    catch (e) {
                        fail(e);
                    }
                }
                if (env.hasError)
                    throw env.error;
            }
            return next();
        };
        exporter("__extends", __extends);
        exporter("__assign", __assign);
        exporter("__rest", __rest);
        exporter("__decorate", __decorate);
        exporter("__param", __param);
        exporter("__esDecorate", __esDecorate);
        exporter("__runInitializers", __runInitializers);
        exporter("__propKey", __propKey);
        exporter("__setFunctionName", __setFunctionName);
        exporter("__metadata", __metadata);
        exporter("__awaiter", __awaiter);
        exporter("__generator", __generator);
        exporter("__exportStar", __exportStar);
        exporter("__createBinding", __createBinding);
        exporter("__values", __values);
        exporter("__read", __read);
        exporter("__spread", __spread);
        exporter("__spreadArrays", __spreadArrays);
        exporter("__spreadArray", __spreadArray);
        exporter("__await", __await);
        exporter("__asyncGenerator", __asyncGenerator);
        exporter("__asyncDelegator", __asyncDelegator);
        exporter("__asyncValues", __asyncValues);
        exporter("__makeTemplateObject", __makeTemplateObject);
        exporter("__importStar", __importStar);
        exporter("__importDefault", __importDefault);
        exporter("__classPrivateFieldGet", __classPrivateFieldGet);
        exporter("__classPrivateFieldSet", __classPrivateFieldSet);
        exporter("__classPrivateFieldIn", __classPrivateFieldIn);
        exporter("__addDisposableResource", __addDisposableResource);
        exporter("__disposeResources", __disposeResources);
    });
},
/* less/lib/less-node/environment.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.default = {
        encodeBase64: function encodeBase64(str) {
            // Avoid Buffer constructor on newer versions of Node.js.
            var buffer = (Buffer.from ? Buffer.from(str) : (new Buffer(str)));
            return buffer.toString('base64');
        },
        mimeLookup: function (filename) {
            return require(65) /* mime */.lookup(filename);
        },
        charsetLookup: function (mime) {
            return require(65) /* mime */.charsets.lookup(mime);
        },
        getSourceMapGenerator: function getSourceMapGenerator() {
            return require(23) /* source-map */.SourceMapGenerator;
        }
    };
    
},
/* mime/mime.js */ function _(require, module, exports, __esModule, __esExport) {
    var path = require('path');
    var fs = require('fs');
    function Mime() {
        // Map of extension -> mime type
        this.types = Object.create(null);
        // Map of mime type -> extension
        this.extensions = Object.create(null);
    }
    /**
     * Define mimetype -> extension mappings.  Each key is a mime-type that maps
     * to an array of extensions associated with the type.  The first extension is
     * used as the default extension for the type.
     *
     * e.g. mime.define({'audio/ogg', ['oga', 'ogg', 'spx']});
     *
     * @param map (Object) type definitions
     */
    Mime.prototype.define = function (map) {
        for (var type in map) {
            var exts = map[type];
            for (var i = 0; i < exts.length; i++) {
                if (process.env.DEBUG_MIME && this.types[exts[i]]) {
                    console.warn((this._loading || "define()").replace(/.*\//, ''), 'changes "' + exts[i] + '" extension type from ' +
                        this.types[exts[i]] + ' to ' + type);
                }
                this.types[exts[i]] = type;
            }
            // Default extension is the first one we encounter
            if (!this.extensions[type]) {
                this.extensions[type] = exts[0];
            }
        }
    };
    /**
     * Load an Apache2-style ".types" file
     *
     * This may be called multiple times (it's expected).  Where files declare
     * overlapping types/extensions, the last file wins.
     *
     * @param file (String) path of file to load.
     */
    Mime.prototype.load = function (file) {
        this._loading = file;
        // Read file and split into lines
        var map = {}, content = fs.readFileSync(file, 'ascii'), lines = content.split(/[\r\n]+/);
        lines.forEach(function (line) {
            // Clean up whitespace/comments, and split into fields
            var fields = line.replace(/\s*#.*|^\s*|\s*$/g, '').split(/\s+/);
            map[fields.shift()] = fields;
        });
        this.define(map);
        this._loading = null;
    };
    /**
     * Lookup a mime type based on extension
     */
    Mime.prototype.lookup = function (path, fallback) {
        var ext = path.replace(/^.*[\.\/\\]/, '').toLowerCase();
        return this.types[ext] || fallback || this.default_type;
    };
    /**
     * Return file extension associated with a mime type
     */
    Mime.prototype.extension = function (mimeType) {
        var type = mimeType.match(/^\s*([^;\s]*)(?:;|\s|$)/)[1].toLowerCase();
        return this.extensions[type];
    };
    // Default instance
    var mime = new Mime();
    // Define built-in types
    mime.define(require(66) /* ./types.json */);
    // Default type
    mime.default_type = mime.lookup('bin');
    //
    // Additional API specific to the default instance
    //
    mime.Mime = Mime;
    /**
     * Lookup a charset based on mime type.
     */
    mime.charsets = {
        lookup: function (mimeType, fallback) {
            // Assume text types are utf8
            return (/^text\/|^application\/(javascript|json)/).test(mimeType) ? 'UTF-8' : fallback;
        }
    };
    module.exports = mime;
},
/* mime/types.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = { "application/andrew-inset": ["ez"], "application/applixware": ["aw"], "application/atom+xml": ["atom"], "application/atomcat+xml": ["atomcat"], "application/atomsvc+xml": ["atomsvc"], "application/bdoc": ["bdoc"], "application/ccxml+xml": ["ccxml"], "application/cdmi-capability": ["cdmia"], "application/cdmi-container": ["cdmic"], "application/cdmi-domain": ["cdmid"], "application/cdmi-object": ["cdmio"], "application/cdmi-queue": ["cdmiq"], "application/cu-seeme": ["cu"], "application/dash+xml": ["mpd"], "application/davmount+xml": ["davmount"], "application/docbook+xml": ["dbk"], "application/dssc+der": ["dssc"], "application/dssc+xml": ["xdssc"], "application/ecmascript": ["ecma"], "application/emma+xml": ["emma"], "application/epub+zip": ["epub"], "application/exi": ["exi"], "application/font-tdpfr": ["pfr"], "application/font-woff": [], "application/font-woff2": [], "application/geo+json": ["geojson"], "application/gml+xml": ["gml"], "application/gpx+xml": ["gpx"], "application/gxf": ["gxf"], "application/gzip": ["gz"], "application/hyperstudio": ["stk"], "application/inkml+xml": ["ink", "inkml"], "application/ipfix": ["ipfix"], "application/java-archive": ["jar", "war", "ear"], "application/java-serialized-object": ["ser"], "application/java-vm": ["class"], "application/javascript": ["js", "mjs"], "application/json": ["json", "map"], "application/json5": ["json5"], "application/jsonml+json": ["jsonml"], "application/ld+json": ["jsonld"], "application/lost+xml": ["lostxml"], "application/mac-binhex40": ["hqx"], "application/mac-compactpro": ["cpt"], "application/mads+xml": ["mads"], "application/manifest+json": ["webmanifest"], "application/marc": ["mrc"], "application/marcxml+xml": ["mrcx"], "application/mathematica": ["ma", "nb", "mb"], "application/mathml+xml": ["mathml"], "application/mbox": ["mbox"], "application/mediaservercontrol+xml": ["mscml"], "application/metalink+xml": ["metalink"], "application/metalink4+xml": ["meta4"], "application/mets+xml": ["mets"], "application/mods+xml": ["mods"], "application/mp21": ["m21", "mp21"], "application/mp4": ["mp4s", "m4p"], "application/msword": ["doc", "dot"], "application/mxf": ["mxf"], "application/octet-stream": ["bin", "dms", "lrf", "mar", "so", "dist", "distz", "pkg", "bpk", "dump", "elc", "deploy", "exe", "dll", "deb", "dmg", "iso", "img", "msi", "msp", "msm", "buffer"], "application/oda": ["oda"], "application/oebps-package+xml": ["opf"], "application/ogg": ["ogx"], "application/omdoc+xml": ["omdoc"], "application/onenote": ["onetoc", "onetoc2", "onetmp", "onepkg"], "application/oxps": ["oxps"], "application/patch-ops-error+xml": ["xer"], "application/pdf": ["pdf"], "application/pgp-encrypted": ["pgp"], "application/pgp-signature": ["asc", "sig"], "application/pics-rules": ["prf"], "application/pkcs10": ["p10"], "application/pkcs7-mime": ["p7m", "p7c"], "application/pkcs7-signature": ["p7s"], "application/pkcs8": ["p8"], "application/pkix-attr-cert": ["ac"], "application/pkix-cert": ["cer"], "application/pkix-crl": ["crl"], "application/pkix-pkipath": ["pkipath"], "application/pkixcmp": ["pki"], "application/pls+xml": ["pls"], "application/postscript": ["ai", "eps", "ps"], "application/prs.cww": ["cww"], "application/pskc+xml": ["pskcxml"], "application/raml+yaml": ["raml"], "application/rdf+xml": ["rdf"], "application/reginfo+xml": ["rif"], "application/relax-ng-compact-syntax": ["rnc"], "application/resource-lists+xml": ["rl"], "application/resource-lists-diff+xml": ["rld"], "application/rls-services+xml": ["rs"], "application/rpki-ghostbusters": ["gbr"], "application/rpki-manifest": ["mft"], "application/rpki-roa": ["roa"], "application/rsd+xml": ["rsd"], "application/rss+xml": ["rss"], "application/rtf": ["rtf"], "application/sbml+xml": ["sbml"], "application/scvp-cv-request": ["scq"], "application/scvp-cv-response": ["scs"], "application/scvp-vp-request": ["spq"], "application/scvp-vp-response": ["spp"], "application/sdp": ["sdp"], "application/set-payment-initiation": ["setpay"], "application/set-registration-initiation": ["setreg"], "application/shf+xml": ["shf"], "application/smil+xml": ["smi", "smil"], "application/sparql-query": ["rq"], "application/sparql-results+xml": ["srx"], "application/srgs": ["gram"], "application/srgs+xml": ["grxml"], "application/sru+xml": ["sru"], "application/ssdl+xml": ["ssdl"], "application/ssml+xml": ["ssml"], "application/tei+xml": ["tei", "teicorpus"], "application/thraud+xml": ["tfi"], "application/timestamped-data": ["tsd"], "application/vnd.3gpp.pic-bw-large": ["plb"], "application/vnd.3gpp.pic-bw-small": ["psb"], "application/vnd.3gpp.pic-bw-var": ["pvb"], "application/vnd.3gpp2.tcap": ["tcap"], "application/vnd.3m.post-it-notes": ["pwn"], "application/vnd.accpac.simply.aso": ["aso"], "application/vnd.accpac.simply.imp": ["imp"], "application/vnd.acucobol": ["acu"], "application/vnd.acucorp": ["atc", "acutc"], "application/vnd.adobe.air-application-installer-package+zip": ["air"], "application/vnd.adobe.formscentral.fcdt": ["fcdt"], "application/vnd.adobe.fxp": ["fxp", "fxpl"], "application/vnd.adobe.xdp+xml": ["xdp"], "application/vnd.adobe.xfdf": ["xfdf"], "application/vnd.ahead.space": ["ahead"], "application/vnd.airzip.filesecure.azf": ["azf"], "application/vnd.airzip.filesecure.azs": ["azs"], "application/vnd.amazon.ebook": ["azw"], "application/vnd.americandynamics.acc": ["acc"], "application/vnd.amiga.ami": ["ami"], "application/vnd.android.package-archive": ["apk"], "application/vnd.anser-web-certificate-issue-initiation": ["cii"], "application/vnd.anser-web-funds-transfer-initiation": ["fti"], "application/vnd.antix.game-component": ["atx"], "application/vnd.apple.installer+xml": ["mpkg"], "application/vnd.apple.mpegurl": ["m3u8"], "application/vnd.apple.pkpass": ["pkpass"], "application/vnd.aristanetworks.swi": ["swi"], "application/vnd.astraea-software.iota": ["iota"], "application/vnd.audiograph": ["aep"], "application/vnd.blueice.multipass": ["mpm"], "application/vnd.bmi": ["bmi"], "application/vnd.businessobjects": ["rep"], "application/vnd.chemdraw+xml": ["cdxml"], "application/vnd.chipnuts.karaoke-mmd": ["mmd"], "application/vnd.cinderella": ["cdy"], "application/vnd.claymore": ["cla"], "application/vnd.cloanto.rp9": ["rp9"], "application/vnd.clonk.c4group": ["c4g", "c4d", "c4f", "c4p", "c4u"], "application/vnd.cluetrust.cartomobile-config": ["c11amc"], "application/vnd.cluetrust.cartomobile-config-pkg": ["c11amz"], "application/vnd.commonspace": ["csp"], "application/vnd.contact.cmsg": ["cdbcmsg"], "application/vnd.cosmocaller": ["cmc"], "application/vnd.crick.clicker": ["clkx"], "application/vnd.crick.clicker.keyboard": ["clkk"], "application/vnd.crick.clicker.palette": ["clkp"], "application/vnd.crick.clicker.template": ["clkt"], "application/vnd.crick.clicker.wordbank": ["clkw"], "application/vnd.criticaltools.wbs+xml": ["wbs"], "application/vnd.ctc-posml": ["pml"], "application/vnd.cups-ppd": ["ppd"], "application/vnd.curl.car": ["car"], "application/vnd.curl.pcurl": ["pcurl"], "application/vnd.dart": ["dart"], "application/vnd.data-vision.rdz": ["rdz"], "application/vnd.dece.data": ["uvf", "uvvf", "uvd", "uvvd"], "application/vnd.dece.ttml+xml": ["uvt", "uvvt"], "application/vnd.dece.unspecified": ["uvx", "uvvx"], "application/vnd.dece.zip": ["uvz", "uvvz"], "application/vnd.denovo.fcselayout-link": ["fe_launch"], "application/vnd.dna": ["dna"], "application/vnd.dolby.mlp": ["mlp"], "application/vnd.dpgraph": ["dpg"], "application/vnd.dreamfactory": ["dfac"], "application/vnd.ds-keypoint": ["kpxx"], "application/vnd.dvb.ait": ["ait"], "application/vnd.dvb.service": ["svc"], "application/vnd.dynageo": ["geo"], "application/vnd.ecowin.chart": ["mag"], "application/vnd.enliven": ["nml"], "application/vnd.epson.esf": ["esf"], "application/vnd.epson.msf": ["msf"], "application/vnd.epson.quickanime": ["qam"], "application/vnd.epson.salt": ["slt"], "application/vnd.epson.ssf": ["ssf"], "application/vnd.eszigno3+xml": ["es3", "et3"], "application/vnd.ezpix-album": ["ez2"], "application/vnd.ezpix-package": ["ez3"], "application/vnd.fdf": ["fdf"], "application/vnd.fdsn.mseed": ["mseed"], "application/vnd.fdsn.seed": ["seed", "dataless"], "application/vnd.flographit": ["gph"], "application/vnd.fluxtime.clip": ["ftc"], "application/vnd.framemaker": ["fm", "frame", "maker", "book"], "application/vnd.frogans.fnc": ["fnc"], "application/vnd.frogans.ltf": ["ltf"], "application/vnd.fsc.weblaunch": ["fsc"], "application/vnd.fujitsu.oasys": ["oas"], "application/vnd.fujitsu.oasys2": ["oa2"], "application/vnd.fujitsu.oasys3": ["oa3"], "application/vnd.fujitsu.oasysgp": ["fg5"], "application/vnd.fujitsu.oasysprs": ["bh2"], "application/vnd.fujixerox.ddd": ["ddd"], "application/vnd.fujixerox.docuworks": ["xdw"], "application/vnd.fujixerox.docuworks.binder": ["xbd"], "application/vnd.fuzzysheet": ["fzs"], "application/vnd.genomatix.tuxedo": ["txd"], "application/vnd.geogebra.file": ["ggb"], "application/vnd.geogebra.tool": ["ggt"], "application/vnd.geometry-explorer": ["gex", "gre"], "application/vnd.geonext": ["gxt"], "application/vnd.geoplan": ["g2w"], "application/vnd.geospace": ["g3w"], "application/vnd.gmx": ["gmx"], "application/vnd.google-apps.document": ["gdoc"], "application/vnd.google-apps.presentation": ["gslides"], "application/vnd.google-apps.spreadsheet": ["gsheet"], "application/vnd.google-earth.kml+xml": ["kml"], "application/vnd.google-earth.kmz": ["kmz"], "application/vnd.grafeq": ["gqf", "gqs"], "application/vnd.groove-account": ["gac"], "application/vnd.groove-help": ["ghf"], "application/vnd.groove-identity-message": ["gim"], "application/vnd.groove-injector": ["grv"], "application/vnd.groove-tool-message": ["gtm"], "application/vnd.groove-tool-template": ["tpl"], "application/vnd.groove-vcard": ["vcg"], "application/vnd.hal+xml": ["hal"], "application/vnd.handheld-entertainment+xml": ["zmm"], "application/vnd.hbci": ["hbci"], "application/vnd.hhe.lesson-player": ["les"], "application/vnd.hp-hpgl": ["hpgl"], "application/vnd.hp-hpid": ["hpid"], "application/vnd.hp-hps": ["hps"], "application/vnd.hp-jlyt": ["jlt"], "application/vnd.hp-pcl": ["pcl"], "application/vnd.hp-pclxl": ["pclxl"], "application/vnd.hydrostatix.sof-data": ["sfd-hdstx"], "application/vnd.ibm.minipay": ["mpy"], "application/vnd.ibm.modcap": ["afp", "listafp", "list3820"], "application/vnd.ibm.rights-management": ["irm"], "application/vnd.ibm.secure-container": ["sc"], "application/vnd.iccprofile": ["icc", "icm"], "application/vnd.igloader": ["igl"], "application/vnd.immervision-ivp": ["ivp"], "application/vnd.immervision-ivu": ["ivu"], "application/vnd.insors.igm": ["igm"], "application/vnd.intercon.formnet": ["xpw", "xpx"], "application/vnd.intergeo": ["i2g"], "application/vnd.intu.qbo": ["qbo"], "application/vnd.intu.qfx": ["qfx"], "application/vnd.ipunplugged.rcprofile": ["rcprofile"], "application/vnd.irepository.package+xml": ["irp"], "application/vnd.is-xpr": ["xpr"], "application/vnd.isac.fcs": ["fcs"], "application/vnd.jam": ["jam"], "application/vnd.jcp.javame.midlet-rms": ["rms"], "application/vnd.jisp": ["jisp"], "application/vnd.joost.joda-archive": ["joda"], "application/vnd.kahootz": ["ktz", "ktr"], "application/vnd.kde.karbon": ["karbon"], "application/vnd.kde.kchart": ["chrt"], "application/vnd.kde.kformula": ["kfo"], "application/vnd.kde.kivio": ["flw"], "application/vnd.kde.kontour": ["kon"], "application/vnd.kde.kpresenter": ["kpr", "kpt"], "application/vnd.kde.kspread": ["ksp"], "application/vnd.kde.kword": ["kwd", "kwt"], "application/vnd.kenameaapp": ["htke"], "application/vnd.kidspiration": ["kia"], "application/vnd.kinar": ["kne", "knp"], "application/vnd.koan": ["skp", "skd", "skt", "skm"], "application/vnd.kodak-descriptor": ["sse"], "application/vnd.las.las+xml": ["lasxml"], "application/vnd.llamagraphics.life-balance.desktop": ["lbd"], "application/vnd.llamagraphics.life-balance.exchange+xml": ["lbe"], "application/vnd.lotus-1-2-3": ["123"], "application/vnd.lotus-approach": ["apr"], "application/vnd.lotus-freelance": ["pre"], "application/vnd.lotus-notes": ["nsf"], "application/vnd.lotus-organizer": ["org"], "application/vnd.lotus-screencam": ["scm"], "application/vnd.lotus-wordpro": ["lwp"], "application/vnd.macports.portpkg": ["portpkg"], "application/vnd.mcd": ["mcd"], "application/vnd.medcalcdata": ["mc1"], "application/vnd.mediastation.cdkey": ["cdkey"], "application/vnd.mfer": ["mwf"], "application/vnd.mfmp": ["mfm"], "application/vnd.micrografx.flo": ["flo"], "application/vnd.micrografx.igx": ["igx"], "application/vnd.mif": ["mif"], "application/vnd.mobius.daf": ["daf"], "application/vnd.mobius.dis": ["dis"], "application/vnd.mobius.mbk": ["mbk"], "application/vnd.mobius.mqy": ["mqy"], "application/vnd.mobius.msl": ["msl"], "application/vnd.mobius.plc": ["plc"], "application/vnd.mobius.txf": ["txf"], "application/vnd.mophun.application": ["mpn"], "application/vnd.mophun.certificate": ["mpc"], "application/vnd.mozilla.xul+xml": ["xul"], "application/vnd.ms-artgalry": ["cil"], "application/vnd.ms-cab-compressed": ["cab"], "application/vnd.ms-excel": ["xls", "xlm", "xla", "xlc", "xlt", "xlw"], "application/vnd.ms-excel.addin.macroenabled.12": ["xlam"], "application/vnd.ms-excel.sheet.binary.macroenabled.12": ["xlsb"], "application/vnd.ms-excel.sheet.macroenabled.12": ["xlsm"], "application/vnd.ms-excel.template.macroenabled.12": ["xltm"], "application/vnd.ms-fontobject": ["eot"], "application/vnd.ms-htmlhelp": ["chm"], "application/vnd.ms-ims": ["ims"], "application/vnd.ms-lrm": ["lrm"], "application/vnd.ms-officetheme": ["thmx"], "application/vnd.ms-outlook": ["msg"], "application/vnd.ms-pki.seccat": ["cat"], "application/vnd.ms-pki.stl": ["stl"], "application/vnd.ms-powerpoint": ["ppt", "pps", "pot"], "application/vnd.ms-powerpoint.addin.macroenabled.12": ["ppam"], "application/vnd.ms-powerpoint.presentation.macroenabled.12": ["pptm"], "application/vnd.ms-powerpoint.slide.macroenabled.12": ["sldm"], "application/vnd.ms-powerpoint.slideshow.macroenabled.12": ["ppsm"], "application/vnd.ms-powerpoint.template.macroenabled.12": ["potm"], "application/vnd.ms-project": ["mpp", "mpt"], "application/vnd.ms-word.document.macroenabled.12": ["docm"], "application/vnd.ms-word.template.macroenabled.12": ["dotm"], "application/vnd.ms-works": ["wps", "wks", "wcm", "wdb"], "application/vnd.ms-wpl": ["wpl"], "application/vnd.ms-xpsdocument": ["xps"], "application/vnd.mseq": ["mseq"], "application/vnd.musician": ["mus"], "application/vnd.muvee.style": ["msty"], "application/vnd.mynfc": ["taglet"], "application/vnd.neurolanguage.nlu": ["nlu"], "application/vnd.nitf": ["ntf", "nitf"], "application/vnd.noblenet-directory": ["nnd"], "application/vnd.noblenet-sealer": ["nns"], "application/vnd.noblenet-web": ["nnw"], "application/vnd.nokia.n-gage.data": ["ngdat"], "application/vnd.nokia.n-gage.symbian.install": ["n-gage"], "application/vnd.nokia.radio-preset": ["rpst"], "application/vnd.nokia.radio-presets": ["rpss"], "application/vnd.novadigm.edm": ["edm"], "application/vnd.novadigm.edx": ["edx"], "application/vnd.novadigm.ext": ["ext"], "application/vnd.oasis.opendocument.chart": ["odc"], "application/vnd.oasis.opendocument.chart-template": ["otc"], "application/vnd.oasis.opendocument.database": ["odb"], "application/vnd.oasis.opendocument.formula": ["odf"], "application/vnd.oasis.opendocument.formula-template": ["odft"], "application/vnd.oasis.opendocument.graphics": ["odg"], "application/vnd.oasis.opendocument.graphics-template": ["otg"], "application/vnd.oasis.opendocument.image": ["odi"], "application/vnd.oasis.opendocument.image-template": ["oti"], "application/vnd.oasis.opendocument.presentation": ["odp"], "application/vnd.oasis.opendocument.presentation-template": ["otp"], "application/vnd.oasis.opendocument.spreadsheet": ["ods"], "application/vnd.oasis.opendocument.spreadsheet-template": ["ots"], "application/vnd.oasis.opendocument.text": ["odt"], "application/vnd.oasis.opendocument.text-master": ["odm"], "application/vnd.oasis.opendocument.text-template": ["ott"], "application/vnd.oasis.opendocument.text-web": ["oth"], "application/vnd.olpc-sugar": ["xo"], "application/vnd.oma.dd2+xml": ["dd2"], "application/vnd.openofficeorg.extension": ["oxt"], "application/vnd.openxmlformats-officedocument.presentationml.presentation": ["pptx"], "application/vnd.openxmlformats-officedocument.presentationml.slide": ["sldx"], "application/vnd.openxmlformats-officedocument.presentationml.slideshow": ["ppsx"], "application/vnd.openxmlformats-officedocument.presentationml.template": ["potx"], "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet": ["xlsx"], "application/vnd.openxmlformats-officedocument.spreadsheetml.template": ["xltx"], "application/vnd.openxmlformats-officedocument.wordprocessingml.document": ["docx"], "application/vnd.openxmlformats-officedocument.wordprocessingml.template": ["dotx"], "application/vnd.osgeo.mapguide.package": ["mgp"], "application/vnd.osgi.dp": ["dp"], "application/vnd.osgi.subsystem": ["esa"], "application/vnd.palm": ["pdb", "pqa", "oprc"], "application/vnd.pawaafile": ["paw"], "application/vnd.pg.format": ["str"], "application/vnd.pg.osasli": ["ei6"], "application/vnd.picsel": ["efif"], "application/vnd.pmi.widget": ["wg"], "application/vnd.pocketlearn": ["plf"], "application/vnd.powerbuilder6": ["pbd"], "application/vnd.previewsystems.box": ["box"], "application/vnd.proteus.magazine": ["mgz"], "application/vnd.publishare-delta-tree": ["qps"], "application/vnd.pvi.ptid1": ["ptid"], "application/vnd.quark.quarkxpress": ["qxd", "qxt", "qwd", "qwt", "qxl", "qxb"], "application/vnd.realvnc.bed": ["bed"], "application/vnd.recordare.musicxml": ["mxl"], "application/vnd.recordare.musicxml+xml": ["musicxml"], "application/vnd.rig.cryptonote": ["cryptonote"], "application/vnd.rim.cod": ["cod"], "application/vnd.rn-realmedia": ["rm"], "application/vnd.rn-realmedia-vbr": ["rmvb"], "application/vnd.route66.link66+xml": ["link66"], "application/vnd.sailingtracker.track": ["st"], "application/vnd.seemail": ["see"], "application/vnd.sema": ["sema"], "application/vnd.semd": ["semd"], "application/vnd.semf": ["semf"], "application/vnd.shana.informed.formdata": ["ifm"], "application/vnd.shana.informed.formtemplate": ["itp"], "application/vnd.shana.informed.interchange": ["iif"], "application/vnd.shana.informed.package": ["ipk"], "application/vnd.simtech-mindmapper": ["twd", "twds"], "application/vnd.smaf": ["mmf"], "application/vnd.smart.teacher": ["teacher"], "application/vnd.solent.sdkm+xml": ["sdkm", "sdkd"], "application/vnd.spotfire.dxp": ["dxp"], "application/vnd.spotfire.sfs": ["sfs"], "application/vnd.stardivision.calc": ["sdc"], "application/vnd.stardivision.draw": ["sda"], "application/vnd.stardivision.impress": ["sdd"], "application/vnd.stardivision.math": ["smf"], "application/vnd.stardivision.writer": ["sdw", "vor"], "application/vnd.stardivision.writer-global": ["sgl"], "application/vnd.stepmania.package": ["smzip"], "application/vnd.stepmania.stepchart": ["sm"], "application/vnd.sun.wadl+xml": ["wadl"], "application/vnd.sun.xml.calc": ["sxc"], "application/vnd.sun.xml.calc.template": ["stc"], "application/vnd.sun.xml.draw": ["sxd"], "application/vnd.sun.xml.draw.template": ["std"], "application/vnd.sun.xml.impress": ["sxi"], "application/vnd.sun.xml.impress.template": ["sti"], "application/vnd.sun.xml.math": ["sxm"], "application/vnd.sun.xml.writer": ["sxw"], "application/vnd.sun.xml.writer.global": ["sxg"], "application/vnd.sun.xml.writer.template": ["stw"], "application/vnd.sus-calendar": ["sus", "susp"], "application/vnd.svd": ["svd"], "application/vnd.symbian.install": ["sis", "sisx"], "application/vnd.syncml+xml": ["xsm"], "application/vnd.syncml.dm+wbxml": ["bdm"], "application/vnd.syncml.dm+xml": ["xdm"], "application/vnd.tao.intent-module-archive": ["tao"], "application/vnd.tcpdump.pcap": ["pcap", "cap", "dmp"], "application/vnd.tmobile-livetv": ["tmo"], "application/vnd.trid.tpt": ["tpt"], "application/vnd.triscape.mxs": ["mxs"], "application/vnd.trueapp": ["tra"], "application/vnd.ufdl": ["ufd", "ufdl"], "application/vnd.uiq.theme": ["utz"], "application/vnd.umajin": ["umj"], "application/vnd.unity": ["unityweb"], "application/vnd.uoml+xml": ["uoml"], "application/vnd.vcx": ["vcx"], "application/vnd.visio": ["vsd", "vst", "vss", "vsw"], "application/vnd.visionary": ["vis"], "application/vnd.vsf": ["vsf"], "application/vnd.wap.wbxml": ["wbxml"], "application/vnd.wap.wmlc": ["wmlc"], "application/vnd.wap.wmlscriptc": ["wmlsc"], "application/vnd.webturbo": ["wtb"], "application/vnd.wolfram.player": ["nbp"], "application/vnd.wordperfect": ["wpd"], "application/vnd.wqd": ["wqd"], "application/vnd.wt.stf": ["stf"], "application/vnd.xara": ["xar"], "application/vnd.xfdl": ["xfdl"], "application/vnd.yamaha.hv-dic": ["hvd"], "application/vnd.yamaha.hv-script": ["hvs"], "application/vnd.yamaha.hv-voice": ["hvp"], "application/vnd.yamaha.openscoreformat": ["osf"], "application/vnd.yamaha.openscoreformat.osfpvg+xml": ["osfpvg"], "application/vnd.yamaha.smaf-audio": ["saf"], "application/vnd.yamaha.smaf-phrase": ["spf"], "application/vnd.yellowriver-custom-menu": ["cmp"], "application/vnd.zul": ["zir", "zirz"], "application/vnd.zzazz.deck+xml": ["zaz"], "application/voicexml+xml": ["vxml"], "application/wasm": ["wasm"], "application/widget": ["wgt"], "application/winhlp": ["hlp"], "application/wsdl+xml": ["wsdl"], "application/wspolicy+xml": ["wspolicy"], "application/x-7z-compressed": ["7z"], "application/x-abiword": ["abw"], "application/x-ace-compressed": ["ace"], "application/x-apple-diskimage": [], "application/x-arj": ["arj"], "application/x-authorware-bin": ["aab", "x32", "u32", "vox"], "application/x-authorware-map": ["aam"], "application/x-authorware-seg": ["aas"], "application/x-bcpio": ["bcpio"], "application/x-bdoc": [], "application/x-bittorrent": ["torrent"], "application/x-blorb": ["blb", "blorb"], "application/x-bzip": ["bz"], "application/x-bzip2": ["bz2", "boz"], "application/x-cbr": ["cbr", "cba", "cbt", "cbz", "cb7"], "application/x-cdlink": ["vcd"], "application/x-cfs-compressed": ["cfs"], "application/x-chat": ["chat"], "application/x-chess-pgn": ["pgn"], "application/x-chrome-extension": ["crx"], "application/x-cocoa": ["cco"], "application/x-conference": ["nsc"], "application/x-cpio": ["cpio"], "application/x-csh": ["csh"], "application/x-debian-package": ["udeb"], "application/x-dgc-compressed": ["dgc"], "application/x-director": ["dir", "dcr", "dxr", "cst", "cct", "cxt", "w3d", "fgd", "swa"], "application/x-doom": ["wad"], "application/x-dtbncx+xml": ["ncx"], "application/x-dtbook+xml": ["dtb"], "application/x-dtbresource+xml": ["res"], "application/x-dvi": ["dvi"], "application/x-envoy": ["evy"], "application/x-eva": ["eva"], "application/x-font-bdf": ["bdf"], "application/x-font-ghostscript": ["gsf"], "application/x-font-linux-psf": ["psf"], "application/x-font-pcf": ["pcf"], "application/x-font-snf": ["snf"], "application/x-font-type1": ["pfa", "pfb", "pfm", "afm"], "application/x-freearc": ["arc"], "application/x-futuresplash": ["spl"], "application/x-gca-compressed": ["gca"], "application/x-glulx": ["ulx"], "application/x-gnumeric": ["gnumeric"], "application/x-gramps-xml": ["gramps"], "application/x-gtar": ["gtar"], "application/x-hdf": ["hdf"], "application/x-httpd-php": ["php"], "application/x-install-instructions": ["install"], "application/x-iso9660-image": [], "application/x-java-archive-diff": ["jardiff"], "application/x-java-jnlp-file": ["jnlp"], "application/x-latex": ["latex"], "application/x-lua-bytecode": ["luac"], "application/x-lzh-compressed": ["lzh", "lha"], "application/x-makeself": ["run"], "application/x-mie": ["mie"], "application/x-mobipocket-ebook": ["prc", "mobi"], "application/x-ms-application": ["application"], "application/x-ms-shortcut": ["lnk"], "application/x-ms-wmd": ["wmd"], "application/x-ms-wmz": ["wmz"], "application/x-ms-xbap": ["xbap"], "application/x-msaccess": ["mdb"], "application/x-msbinder": ["obd"], "application/x-mscardfile": ["crd"], "application/x-msclip": ["clp"], "application/x-msdos-program": [], "application/x-msdownload": ["com", "bat"], "application/x-msmediaview": ["mvb", "m13", "m14"], "application/x-msmetafile": ["wmf", "emf", "emz"], "application/x-msmoney": ["mny"], "application/x-mspublisher": ["pub"], "application/x-msschedule": ["scd"], "application/x-msterminal": ["trm"], "application/x-mswrite": ["wri"], "application/x-netcdf": ["nc", "cdf"], "application/x-ns-proxy-autoconfig": ["pac"], "application/x-nzb": ["nzb"], "application/x-perl": ["pl", "pm"], "application/x-pilot": [], "application/x-pkcs12": ["p12", "pfx"], "application/x-pkcs7-certificates": ["p7b", "spc"], "application/x-pkcs7-certreqresp": ["p7r"], "application/x-rar-compressed": ["rar"], "application/x-redhat-package-manager": ["rpm"], "application/x-research-info-systems": ["ris"], "application/x-sea": ["sea"], "application/x-sh": ["sh"], "application/x-shar": ["shar"], "application/x-shockwave-flash": ["swf"], "application/x-silverlight-app": ["xap"], "application/x-sql": ["sql"], "application/x-stuffit": ["sit"], "application/x-stuffitx": ["sitx"], "application/x-subrip": ["srt"], "application/x-sv4cpio": ["sv4cpio"], "application/x-sv4crc": ["sv4crc"], "application/x-t3vm-image": ["t3"], "application/x-tads": ["gam"], "application/x-tar": ["tar"], "application/x-tcl": ["tcl", "tk"], "application/x-tex": ["tex"], "application/x-tex-tfm": ["tfm"], "application/x-texinfo": ["texinfo", "texi"], "application/x-tgif": ["obj"], "application/x-ustar": ["ustar"], "application/x-virtualbox-hdd": ["hdd"], "application/x-virtualbox-ova": ["ova"], "application/x-virtualbox-ovf": ["ovf"], "application/x-virtualbox-vbox": ["vbox"], "application/x-virtualbox-vbox-extpack": ["vbox-extpack"], "application/x-virtualbox-vdi": ["vdi"], "application/x-virtualbox-vhd": ["vhd"], "application/x-virtualbox-vmdk": ["vmdk"], "application/x-wais-source": ["src"], "application/x-web-app-manifest+json": ["webapp"], "application/x-x509-ca-cert": ["der", "crt", "pem"], "application/x-xfig": ["fig"], "application/x-xliff+xml": ["xlf"], "application/x-xpinstall": ["xpi"], "application/x-xz": ["xz"], "application/x-zmachine": ["z1", "z2", "z3", "z4", "z5", "z6", "z7", "z8"], "application/xaml+xml": ["xaml"], "application/xcap-diff+xml": ["xdf"], "application/xenc+xml": ["xenc"], "application/xhtml+xml": ["xhtml", "xht"], "application/xml": ["xml", "xsl", "xsd", "rng"], "application/xml-dtd": ["dtd"], "application/xop+xml": ["xop"], "application/xproc+xml": ["xpl"], "application/xslt+xml": ["xslt"], "application/xspf+xml": ["xspf"], "application/xv+xml": ["mxml", "xhvml", "xvml", "xvm"], "application/yang": ["yang"], "application/yin+xml": ["yin"], "application/zip": ["zip"], "audio/3gpp": [], "audio/adpcm": ["adp"], "audio/basic": ["au", "snd"], "audio/midi": ["mid", "midi", "kar", "rmi"], "audio/mp3": [], "audio/mp4": ["m4a", "mp4a"], "audio/mpeg": ["mpga", "mp2", "mp2a", "mp3", "m2a", "m3a"], "audio/ogg": ["oga", "ogg", "spx"], "audio/s3m": ["s3m"], "audio/silk": ["sil"], "audio/vnd.dece.audio": ["uva", "uvva"], "audio/vnd.digital-winds": ["eol"], "audio/vnd.dra": ["dra"], "audio/vnd.dts": ["dts"], "audio/vnd.dts.hd": ["dtshd"], "audio/vnd.lucent.voice": ["lvp"], "audio/vnd.ms-playready.media.pya": ["pya"], "audio/vnd.nuera.ecelp4800": ["ecelp4800"], "audio/vnd.nuera.ecelp7470": ["ecelp7470"], "audio/vnd.nuera.ecelp9600": ["ecelp9600"], "audio/vnd.rip": ["rip"], "audio/wav": ["wav"], "audio/wave": [], "audio/webm": ["weba"], "audio/x-aac": ["aac"], "audio/x-aiff": ["aif", "aiff", "aifc"], "audio/x-caf": ["caf"], "audio/x-flac": ["flac"], "audio/x-m4a": [], "audio/x-matroska": ["mka"], "audio/x-mpegurl": ["m3u"], "audio/x-ms-wax": ["wax"], "audio/x-ms-wma": ["wma"], "audio/x-pn-realaudio": ["ram", "ra"], "audio/x-pn-realaudio-plugin": ["rmp"], "audio/x-realaudio": [], "audio/x-wav": [], "audio/xm": ["xm"], "chemical/x-cdx": ["cdx"], "chemical/x-cif": ["cif"], "chemical/x-cmdf": ["cmdf"], "chemical/x-cml": ["cml"], "chemical/x-csml": ["csml"], "chemical/x-xyz": ["xyz"], "font/collection": ["ttc"], "font/otf": ["otf"], "font/ttf": ["ttf"], "font/woff": ["woff"], "font/woff2": ["woff2"], "image/apng": ["apng"], "image/bmp": ["bmp"], "image/cgm": ["cgm"], "image/g3fax": ["g3"], "image/gif": ["gif"], "image/ief": ["ief"], "image/jp2": ["jp2", "jpg2"], "image/jpeg": ["jpeg", "jpg", "jpe"], "image/jpm": ["jpm"], "image/jpx": ["jpx", "jpf"], "image/ktx": ["ktx"], "image/png": ["png"], "image/prs.btif": ["btif"], "image/sgi": ["sgi"], "image/svg+xml": ["svg", "svgz"], "image/tiff": ["tiff", "tif"], "image/vnd.adobe.photoshop": ["psd"], "image/vnd.dece.graphic": ["uvi", "uvvi", "uvg", "uvvg"], "image/vnd.djvu": ["djvu", "djv"], "image/vnd.dvb.subtitle": [], "image/vnd.dwg": ["dwg"], "image/vnd.dxf": ["dxf"], "image/vnd.fastbidsheet": ["fbs"], "image/vnd.fpx": ["fpx"], "image/vnd.fst": ["fst"], "image/vnd.fujixerox.edmics-mmr": ["mmr"], "image/vnd.fujixerox.edmics-rlc": ["rlc"], "image/vnd.ms-modi": ["mdi"], "image/vnd.ms-photo": ["wdp"], "image/vnd.net-fpx": ["npx"], "image/vnd.wap.wbmp": ["wbmp"], "image/vnd.xiff": ["xif"], "image/webp": ["webp"], "image/x-3ds": ["3ds"], "image/x-cmu-raster": ["ras"], "image/x-cmx": ["cmx"], "image/x-freehand": ["fh", "fhc", "fh4", "fh5", "fh7"], "image/x-icon": ["ico"], "image/x-jng": ["jng"], "image/x-mrsid-image": ["sid"], "image/x-ms-bmp": [], "image/x-pcx": ["pcx"], "image/x-pict": ["pic", "pct"], "image/x-portable-anymap": ["pnm"], "image/x-portable-bitmap": ["pbm"], "image/x-portable-graymap": ["pgm"], "image/x-portable-pixmap": ["ppm"], "image/x-rgb": ["rgb"], "image/x-tga": ["tga"], "image/x-xbitmap": ["xbm"], "image/x-xpixmap": ["xpm"], "image/x-xwindowdump": ["xwd"], "message/rfc822": ["eml", "mime"], "model/gltf+json": ["gltf"], "model/gltf-binary": ["glb"], "model/iges": ["igs", "iges"], "model/mesh": ["msh", "mesh", "silo"], "model/vnd.collada+xml": ["dae"], "model/vnd.dwf": ["dwf"], "model/vnd.gdl": ["gdl"], "model/vnd.gtw": ["gtw"], "model/vnd.mts": ["mts"], "model/vnd.vtu": ["vtu"], "model/vrml": ["wrl", "vrml"], "model/x3d+binary": ["x3db", "x3dbz"], "model/x3d+vrml": ["x3dv", "x3dvz"], "model/x3d+xml": ["x3d", "x3dz"], "text/cache-manifest": ["appcache", "manifest"], "text/calendar": ["ics", "ifb"], "text/coffeescript": ["coffee", "litcoffee"], "text/css": ["css"], "text/csv": ["csv"], "text/hjson": ["hjson"], "text/html": ["html", "htm", "shtml"], "text/jade": ["jade"], "text/jsx": ["jsx"], "text/less": ["less"], "text/markdown": ["markdown", "md"], "text/mathml": ["mml"], "text/n3": ["n3"], "text/plain": ["txt", "text", "conf", "def", "list", "log", "in", "ini"], "text/prs.lines.tag": ["dsc"], "text/richtext": ["rtx"], "text/rtf": [], "text/sgml": ["sgml", "sgm"], "text/slim": ["slim", "slm"], "text/stylus": ["stylus", "styl"], "text/tab-separated-values": ["tsv"], "text/troff": ["t", "tr", "roff", "man", "me", "ms"], "text/turtle": ["ttl"], "text/uri-list": ["uri", "uris", "urls"], "text/vcard": ["vcard"], "text/vnd.curl": ["curl"], "text/vnd.curl.dcurl": ["dcurl"], "text/vnd.curl.mcurl": ["mcurl"], "text/vnd.curl.scurl": ["scurl"], "text/vnd.dvb.subtitle": ["sub"], "text/vnd.fly": ["fly"], "text/vnd.fmi.flexstor": ["flx"], "text/vnd.graphviz": ["gv"], "text/vnd.in3d.3dml": ["3dml"], "text/vnd.in3d.spot": ["spot"], "text/vnd.sun.j2me.app-descriptor": ["jad"], "text/vnd.wap.wml": ["wml"], "text/vnd.wap.wmlscript": ["wmls"], "text/vtt": ["vtt"], "text/x-asm": ["s", "asm"], "text/x-c": ["c", "cc", "cxx", "cpp", "h", "hh", "dic"], "text/x-component": ["htc"], "text/x-fortran": ["f", "for", "f77", "f90"], "text/x-handlebars-template": ["hbs"], "text/x-java-source": ["java"], "text/x-lua": ["lua"], "text/x-markdown": ["mkd"], "text/x-nfo": ["nfo"], "text/x-opml": ["opml"], "text/x-org": [], "text/x-pascal": ["p", "pas"], "text/x-processing": ["pde"], "text/x-sass": ["sass"], "text/x-scss": ["scss"], "text/x-setext": ["etx"], "text/x-sfv": ["sfv"], "text/x-suse-ymp": ["ymp"], "text/x-uuencode": ["uu"], "text/x-vcalendar": ["vcs"], "text/x-vcard": ["vcf"], "text/xml": [], "text/yaml": ["yaml", "yml"], "video/3gpp": ["3gp", "3gpp"], "video/3gpp2": ["3g2"], "video/h261": ["h261"], "video/h263": ["h263"], "video/h264": ["h264"], "video/jpeg": ["jpgv"], "video/jpm": ["jpgm"], "video/mj2": ["mj2", "mjp2"], "video/mp2t": ["ts"], "video/mp4": ["mp4", "mp4v", "mpg4"], "video/mpeg": ["mpeg", "mpg", "mpe", "m1v", "m2v"], "video/ogg": ["ogv"], "video/quicktime": ["qt", "mov"], "video/vnd.dece.hd": ["uvh", "uvvh"], "video/vnd.dece.mobile": ["uvm", "uvvm"], "video/vnd.dece.pd": ["uvp", "uvvp"], "video/vnd.dece.sd": ["uvs", "uvvs"], "video/vnd.dece.video": ["uvv", "uvvv"], "video/vnd.dvb.file": ["dvb"], "video/vnd.fvt": ["fvt"], "video/vnd.mpegurl": ["mxu", "m4u"], "video/vnd.ms-playready.media.pyv": ["pyv"], "video/vnd.uvvu.mp4": ["uvu", "uvvu"], "video/vnd.vivo": ["viv"], "video/webm": ["webm"], "video/x-f4v": ["f4v"], "video/x-fli": ["fli"], "video/x-flv": ["flv"], "video/x-m4v": ["m4v"], "video/x-matroska": ["mkv", "mk3d", "mks"], "video/x-mng": ["mng"], "video/x-ms-asf": ["asf", "asx"], "video/x-ms-vob": ["vob"], "video/x-ms-wm": ["wm"], "video/x-ms-wmv": ["wmv"], "video/x-ms-wmx": ["wmx"], "video/x-ms-wvx": ["wvx"], "video/x-msvideo": ["avi"], "video/x-sgi-movie": ["movie"], "video/x-smv": ["smv"], "x-conference/x-cooltalk": ["ice"] };
    module.exports = json;
},
/* less/lib/less-node/file-manager.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var path_1 = tslib_1.__importDefault(require("path"));
    var fs_1 = tslib_1.__importDefault(require(68) /* ./fs */);
    var abstract_file_manager_js_1 = tslib_1.__importDefault(require(73) /* ../less/environment/abstract-file-manager.js */);
    var FileManager = function () { };
    FileManager.prototype = Object.assign(new abstract_file_manager_js_1.default(), {
        supports: function () {
            return true;
        },
        supportsSync: function () {
            return true;
        },
        loadFile: function (filename, currentDirectory, options, environment, callback) {
            var fullFilename;
            var isAbsoluteFilename = this.isPathAbsolute(filename);
            var filenamesTried = [];
            var self = this;
            var prefix = filename.slice(0, 1);
            var explicit = prefix === '.' || prefix === '/';
            var result = null;
            var isNodeModule = false;
            var npmPrefix = 'npm://';
            options = options || {};
            var paths = isAbsoluteFilename ? [''] : [currentDirectory];
            if (options.paths) {
                paths.push.apply(paths, options.paths);
            }
            if (!isAbsoluteFilename && paths.indexOf('.') === -1) {
                paths.push('.');
            }
            var prefixes = options.prefixes || [''];
            var fileParts = this.extractUrlParts(filename);
            if (options.syncImport) {
                getFileData(returnData, returnData);
                if (callback) {
                    callback(result.error, result);
                }
                else {
                    return result;
                }
            }
            else {
                // promise is guaranteed to be asyncronous
                // which helps as it allows the file handle
                // to be closed before it continues with the next file
                return new Promise(getFileData);
            }
            function returnData(data) {
                if (!data.filename) {
                    result = { error: data };
                }
                else {
                    result = data;
                }
            }
            function getFileData(fulfill, reject) {
                (function tryPathIndex(i) {
                    function tryWithExtension() {
                        var extFilename = options.ext ? self.tryAppendExtension(fullFilename, options.ext) : fullFilename;
                        if (extFilename !== fullFilename && !explicit && paths[i] === '.') {
                            try {
                                fullFilename = require.resolve(extFilename);
                                isNodeModule = true;
                            }
                            catch (e) {
                                filenamesTried.push(npmPrefix + extFilename);
                                fullFilename = extFilename;
                            }
                        }
                        else {
                            fullFilename = extFilename;
                        }
                    }
                    if (i < paths.length) {
                        (function tryPrefix(j) {
                            if (j < prefixes.length) {
                                isNodeModule = false;
                                fullFilename = fileParts.rawPath + prefixes[j] + fileParts.filename;
                                if (paths[i]) {
                                    fullFilename = path_1.default.join(paths[i], fullFilename);
                                }
                                if (!explicit && paths[i] === '.') {
                                    try {
                                        fullFilename = require.resolve(fullFilename);
                                        isNodeModule = true;
                                    }
                                    catch (e) {
                                        filenamesTried.push(npmPrefix + fullFilename);
                                        tryWithExtension();
                                    }
                                }
                                else {
                                    tryWithExtension();
                                }
                                var readFileArgs = [fullFilename];
                                if (!options.rawBuffer) {
                                    readFileArgs.push('utf-8');
                                }
                                if (options.syncImport) {
                                    try {
                                        var data = fs_1.default.readFileSync.apply(this, readFileArgs);
                                        fulfill({ contents: data, filename: fullFilename });
                                    }
                                    catch (e) {
                                        filenamesTried.push(isNodeModule ? npmPrefix + fullFilename : fullFilename);
                                        return tryPrefix(j + 1);
                                    }
                                }
                                else {
                                    readFileArgs.push(function (e, data) {
                                        if (e) {
                                            filenamesTried.push(isNodeModule ? npmPrefix + fullFilename : fullFilename);
                                            return tryPrefix(j + 1);
                                        }
                                        fulfill({ contents: data, filename: fullFilename });
                                    });
                                    fs_1.default.readFile.apply(this, readFileArgs);
                                }
                            }
                            else {
                                tryPathIndex(i + 1);
                            }
                        })(0);
                    }
                    else {
                        reject({ type: 'File', message: "'" + filename + "' wasn't found. Tried - " + filenamesTried.join(',') });
                    }
                }(0));
            }
        },
        loadFileSync: function (filename, currentDirectory, options, environment) {
            options.syncImport = true;
            return this.loadFile(filename, currentDirectory, options, environment);
        }
    });
    exports.default = FileManager;
    
},
/* less/lib/less-node/fs.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var fs;
    try {
        fs = require(69) /* graceful-fs */;
    }
    catch (e) {
        fs = require('fs');
    }
    exports.default = fs;
    
},
/* graceful-fs/graceful-fs.js */ function _(require, module, exports, __esModule, __esExport) {
    var fs = require('fs');
    var polyfills = require(70) /* ./polyfills.js */;
    var legacy = require(71) /* ./legacy-streams.js */;
    var clone = require(72) /* ./clone.js */;
    var util = require('util');
    /* istanbul ignore next - node 0.x polyfill */
    var gracefulQueue;
    var previousSymbol;
    /* istanbul ignore else - node 0.x polyfill */
    if (typeof Symbol === 'function' && typeof Symbol.for === 'function') {
        gracefulQueue = Symbol.for('graceful-fs.queue');
        // This is used in testing by future versions
        previousSymbol = Symbol.for('graceful-fs.previous');
    }
    else {
        gracefulQueue = '___graceful-fs.queue';
        previousSymbol = '___graceful-fs.previous';
    }
    function noop() { }
    function publishQueue(context, queue) {
        Object.defineProperty(context, gracefulQueue, {
            get: function () {
                return queue;
            }
        });
    }
    var debug = noop;
    if (util.debuglog)
        debug = util.debuglog('gfs4');
    else if (/\bgfs4\b/i.test(process.env.NODE_DEBUG || ''))
        debug = function () {
            var m = util.format.apply(util, arguments);
            m = 'GFS4: ' + m.split(/\n/).join('\nGFS4: ');
            console.error(m);
        };
    // Once time initialization
    if (!fs[gracefulQueue]) {
        // This queue can be shared by multiple loaded instances
        var queue = global[gracefulQueue] || [];
        publishQueue(fs, queue);
        // Patch fs.close/closeSync to shared queue version, because we need
        // to retry() whenever a close happens *anywhere* in the program.
        // This is essential when multiple graceful-fs instances are
        // in play at the same time.
        fs.close = (function (fs$close) {
            function close(fd, cb) {
                return fs$close.call(fs, fd, function (err) {
                    // This function uses the graceful-fs shared queue
                    if (!err) {
                        resetQueue();
                    }
                    if (typeof cb === 'function')
                        cb.apply(this, arguments);
                });
            }
            Object.defineProperty(close, previousSymbol, {
                value: fs$close
            });
            return close;
        })(fs.close);
        fs.closeSync = (function (fs$closeSync) {
            function closeSync(fd) {
                // This function uses the graceful-fs shared queue
                fs$closeSync.apply(fs, arguments);
                resetQueue();
            }
            Object.defineProperty(closeSync, previousSymbol, {
                value: fs$closeSync
            });
            return closeSync;
        })(fs.closeSync);
        if (/\bgfs4\b/i.test(process.env.NODE_DEBUG || '')) {
            process.on('exit', function () {
                debug(fs[gracefulQueue]);
                require('assert').equal(fs[gracefulQueue].length, 0);
            });
        }
    }
    if (!global[gracefulQueue]) {
        publishQueue(global, fs[gracefulQueue]);
    }
    module.exports = patch(clone(fs));
    if (process.env.TEST_GRACEFUL_FS_GLOBAL_PATCH && !fs.__patched) {
        module.exports = patch(fs);
        fs.__patched = true;
    }
    function patch(fs) {
        // Everything that references the open() function needs to be in here
        polyfills(fs);
        fs.gracefulify = patch;
        fs.createReadStream = createReadStream;
        fs.createWriteStream = createWriteStream;
        var fs$readFile = fs.readFile;
        fs.readFile = readFile;
        function readFile(path, options, cb) {
            if (typeof options === 'function')
                cb = options, options = null;
            return go$readFile(path, options, cb);
            function go$readFile(path, options, cb, startTime) {
                return fs$readFile(path, options, function (err) {
                    if (err && (err.code === 'EMFILE' || err.code === 'ENFILE'))
                        enqueue([go$readFile, [path, options, cb], err, startTime || Date.now(), Date.now()]);
                    else {
                        if (typeof cb === 'function')
                            cb.apply(this, arguments);
                    }
                });
            }
        }
        var fs$writeFile = fs.writeFile;
        fs.writeFile = writeFile;
        function writeFile(path, data, options, cb) {
            if (typeof options === 'function')
                cb = options, options = null;
            return go$writeFile(path, data, options, cb);
            function go$writeFile(path, data, options, cb, startTime) {
                return fs$writeFile(path, data, options, function (err) {
                    if (err && (err.code === 'EMFILE' || err.code === 'ENFILE'))
                        enqueue([go$writeFile, [path, data, options, cb], err, startTime || Date.now(), Date.now()]);
                    else {
                        if (typeof cb === 'function')
                            cb.apply(this, arguments);
                    }
                });
            }
        }
        var fs$appendFile = fs.appendFile;
        if (fs$appendFile)
            fs.appendFile = appendFile;
        function appendFile(path, data, options, cb) {
            if (typeof options === 'function')
                cb = options, options = null;
            return go$appendFile(path, data, options, cb);
            function go$appendFile(path, data, options, cb, startTime) {
                return fs$appendFile(path, data, options, function (err) {
                    if (err && (err.code === 'EMFILE' || err.code === 'ENFILE'))
                        enqueue([go$appendFile, [path, data, options, cb], err, startTime || Date.now(), Date.now()]);
                    else {
                        if (typeof cb === 'function')
                            cb.apply(this, arguments);
                    }
                });
            }
        }
        var fs$copyFile = fs.copyFile;
        if (fs$copyFile)
            fs.copyFile = copyFile;
        function copyFile(src, dest, flags, cb) {
            if (typeof flags === 'function') {
                cb = flags;
                flags = 0;
            }
            return go$copyFile(src, dest, flags, cb);
            function go$copyFile(src, dest, flags, cb, startTime) {
                return fs$copyFile(src, dest, flags, function (err) {
                    if (err && (err.code === 'EMFILE' || err.code === 'ENFILE'))
                        enqueue([go$copyFile, [src, dest, flags, cb], err, startTime || Date.now(), Date.now()]);
                    else {
                        if (typeof cb === 'function')
                            cb.apply(this, arguments);
                    }
                });
            }
        }
        var fs$readdir = fs.readdir;
        fs.readdir = readdir;
        var noReaddirOptionVersions = /^v[0-5]\./;
        function readdir(path, options, cb) {
            if (typeof options === 'function')
                cb = options, options = null;
            var go$readdir = noReaddirOptionVersions.test(process.version)
                ? function go$readdir(path, options, cb, startTime) {
                    return fs$readdir(path, fs$readdirCallback(path, options, cb, startTime));
                }
                : function go$readdir(path, options, cb, startTime) {
                    return fs$readdir(path, options, fs$readdirCallback(path, options, cb, startTime));
                };
            return go$readdir(path, options, cb);
            function fs$readdirCallback(path, options, cb, startTime) {
                return function (err, files) {
                    if (err && (err.code === 'EMFILE' || err.code === 'ENFILE'))
                        enqueue([
                            go$readdir,
                            [path, options, cb],
                            err,
                            startTime || Date.now(),
                            Date.now()
                        ]);
                    else {
                        if (files && files.sort)
                            files.sort();
                        if (typeof cb === 'function')
                            cb.call(this, err, files);
                    }
                };
            }
        }
        if (process.version.substr(0, 4) === 'v0.8') {
            var legStreams = legacy(fs);
            ReadStream = legStreams.ReadStream;
            WriteStream = legStreams.WriteStream;
        }
        var fs$ReadStream = fs.ReadStream;
        if (fs$ReadStream) {
            ReadStream.prototype = Object.create(fs$ReadStream.prototype);
            ReadStream.prototype.open = ReadStream$open;
        }
        var fs$WriteStream = fs.WriteStream;
        if (fs$WriteStream) {
            WriteStream.prototype = Object.create(fs$WriteStream.prototype);
            WriteStream.prototype.open = WriteStream$open;
        }
        Object.defineProperty(fs, 'ReadStream', {
            get: function () {
                return ReadStream;
            },
            set: function (val) {
                ReadStream = val;
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(fs, 'WriteStream', {
            get: function () {
                return WriteStream;
            },
            set: function (val) {
                WriteStream = val;
            },
            enumerable: true,
            configurable: true
        });
        // legacy names
        var FileReadStream = ReadStream;
        Object.defineProperty(fs, 'FileReadStream', {
            get: function () {
                return FileReadStream;
            },
            set: function (val) {
                FileReadStream = val;
            },
            enumerable: true,
            configurable: true
        });
        var FileWriteStream = WriteStream;
        Object.defineProperty(fs, 'FileWriteStream', {
            get: function () {
                return FileWriteStream;
            },
            set: function (val) {
                FileWriteStream = val;
            },
            enumerable: true,
            configurable: true
        });
        function ReadStream(path, options) {
            if (this instanceof ReadStream)
                return fs$ReadStream.apply(this, arguments), this;
            else
                return ReadStream.apply(Object.create(ReadStream.prototype), arguments);
        }
        function ReadStream$open() {
            var that = this;
            open(that.path, that.flags, that.mode, function (err, fd) {
                if (err) {
                    if (that.autoClose)
                        that.destroy();
                    that.emit('error', err);
                }
                else {
                    that.fd = fd;
                    that.emit('open', fd);
                    that.read();
                }
            });
        }
        function WriteStream(path, options) {
            if (this instanceof WriteStream)
                return fs$WriteStream.apply(this, arguments), this;
            else
                return WriteStream.apply(Object.create(WriteStream.prototype), arguments);
        }
        function WriteStream$open() {
            var that = this;
            open(that.path, that.flags, that.mode, function (err, fd) {
                if (err) {
                    that.destroy();
                    that.emit('error', err);
                }
                else {
                    that.fd = fd;
                    that.emit('open', fd);
                }
            });
        }
        function createReadStream(path, options) {
            return new fs.ReadStream(path, options);
        }
        function createWriteStream(path, options) {
            return new fs.WriteStream(path, options);
        }
        var fs$open = fs.open;
        fs.open = open;
        function open(path, flags, mode, cb) {
            if (typeof mode === 'function')
                cb = mode, mode = null;
            return go$open(path, flags, mode, cb);
            function go$open(path, flags, mode, cb, startTime) {
                return fs$open(path, flags, mode, function (err, fd) {
                    if (err && (err.code === 'EMFILE' || err.code === 'ENFILE'))
                        enqueue([go$open, [path, flags, mode, cb], err, startTime || Date.now(), Date.now()]);
                    else {
                        if (typeof cb === 'function')
                            cb.apply(this, arguments);
                    }
                });
            }
        }
        return fs;
    }
    function enqueue(elem) {
        debug('ENQUEUE', elem[0].name, elem[1]);
        fs[gracefulQueue].push(elem);
        retry();
    }
    // keep track of the timeout between retry() calls
    var retryTimer;
    // reset the startTime and lastTime to now
    // this resets the start of the 60 second overall timeout as well as the
    // delay between attempts so that we'll retry these jobs sooner
    function resetQueue() {
        var now = Date.now();
        for (var i = 0; i < fs[gracefulQueue].length; ++i) {
            // entries that are only a length of 2 are from an older version, don't
            // bother modifying those since they'll be retried anyway.
            if (fs[gracefulQueue][i].length > 2) {
                fs[gracefulQueue][i][3] = now; // startTime
                fs[gracefulQueue][i][4] = now; // lastTime
            }
        }
        // call retry to make sure we're actively processing the queue
        retry();
    }
    function retry() {
        // clear the timer and remove it to help prevent unintended concurrency
        clearTimeout(retryTimer);
        retryTimer = undefined;
        if (fs[gracefulQueue].length === 0)
            return;
        var elem = fs[gracefulQueue].shift();
        var fn = elem[0];
        var args = elem[1];
        // these items may be unset if they were added by an older graceful-fs
        var err = elem[2];
        var startTime = elem[3];
        var lastTime = elem[4];
        // if we don't have a startTime we have no way of knowing if we've waited
        // long enough, so go ahead and retry this item now
        if (startTime === undefined) {
            debug('RETRY', fn.name, args);
            fn.apply(null, args);
        }
        else if (Date.now() - startTime >= 60000) {
            // it's been more than 60 seconds total, bail now
            debug('TIMEOUT', fn.name, args);
            var cb = args.pop();
            if (typeof cb === 'function')
                cb.call(null, err);
        }
        else {
            // the amount of time between the last attempt and right now
            var sinceAttempt = Date.now() - lastTime;
            // the amount of time between when we first tried, and when we last tried
            // rounded up to at least 1
            var sinceStart = Math.max(lastTime - startTime, 1);
            // backoff. wait longer than the total time we've been retrying, but only
            // up to a maximum of 100ms
            var desiredDelay = Math.min(sinceStart * 1.2, 100);
            // it's been long enough since the last retry, do it again
            if (sinceAttempt >= desiredDelay) {
                debug('RETRY', fn.name, args);
                fn.apply(null, args.concat([startTime]));
            }
            else {
                // if we can't do this job yet, push it to the end of the queue
                // and let the next iteration check again
                fs[gracefulQueue].push(elem);
            }
        }
        // schedule our next run if one isn't already scheduled
        if (retryTimer === undefined) {
            retryTimer = setTimeout(retry, 0);
        }
    }
},
/* graceful-fs/polyfills.js */ function _(require, module, exports, __esModule, __esExport) {
    var constants = require('constants');
    var origCwd = process.cwd;
    var cwd = null;
    var platform = process.env.GRACEFUL_FS_PLATFORM || process.platform;
    process.cwd = function () {
        if (!cwd)
            cwd = origCwd.call(process);
        return cwd;
    };
    try {
        process.cwd();
    }
    catch (er) { }
    // This check is needed until node.js 12 is required
    if (typeof process.chdir === 'function') {
        var chdir = process.chdir;
        process.chdir = function (d) {
            cwd = null;
            chdir.call(process, d);
        };
        if (Object.setPrototypeOf)
            Object.setPrototypeOf(process.chdir, chdir);
    }
    module.exports = patch;
    function patch(fs) {
        // (re-)implement some things that are known busted or missing.
        // lchmod, broken prior to 0.6.2
        // back-port the fix here.
        if (constants.hasOwnProperty('O_SYMLINK') &&
            process.version.match(/^v0\.6\.[0-2]|^v0\.5\./)) {
            patchLchmod(fs);
        }
        // lutimes implementation, or no-op
        if (!fs.lutimes) {
            patchLutimes(fs);
        }
        // https://github.com/isaacs/node-graceful-fs/issues/4
        // Chown should not fail on einval or eperm if non-root.
        // It should not fail on enosys ever, as this just indicates
        // that a fs doesn't support the intended operation.
        fs.chown = chownFix(fs.chown);
        fs.fchown = chownFix(fs.fchown);
        fs.lchown = chownFix(fs.lchown);
        fs.chmod = chmodFix(fs.chmod);
        fs.fchmod = chmodFix(fs.fchmod);
        fs.lchmod = chmodFix(fs.lchmod);
        fs.chownSync = chownFixSync(fs.chownSync);
        fs.fchownSync = chownFixSync(fs.fchownSync);
        fs.lchownSync = chownFixSync(fs.lchownSync);
        fs.chmodSync = chmodFixSync(fs.chmodSync);
        fs.fchmodSync = chmodFixSync(fs.fchmodSync);
        fs.lchmodSync = chmodFixSync(fs.lchmodSync);
        fs.stat = statFix(fs.stat);
        fs.fstat = statFix(fs.fstat);
        fs.lstat = statFix(fs.lstat);
        fs.statSync = statFixSync(fs.statSync);
        fs.fstatSync = statFixSync(fs.fstatSync);
        fs.lstatSync = statFixSync(fs.lstatSync);
        // if lchmod/lchown do not exist, then make them no-ops
        if (fs.chmod && !fs.lchmod) {
            fs.lchmod = function (path, mode, cb) {
                if (cb)
                    process.nextTick(cb);
            };
            fs.lchmodSync = function () { };
        }
        if (fs.chown && !fs.lchown) {
            fs.lchown = function (path, uid, gid, cb) {
                if (cb)
                    process.nextTick(cb);
            };
            fs.lchownSync = function () { };
        }
        // on Windows, A/V software can lock the directory, causing this
        // to fail with an EACCES or EPERM if the directory contains newly
        // created files.  Try again on failure, for up to 60 seconds.
        // Set the timeout this long because some Windows Anti-Virus, such as Parity
        // bit9, may lock files for up to a minute, causing npm package install
        // failures. Also, take care to yield the scheduler. Windows scheduling gives
        // CPU to a busy looping process, which can cause the program causing the lock
        // contention to be starved of CPU by node, so the contention doesn't resolve.
        if (platform === "win32") {
            fs.rename = typeof fs.rename !== 'function' ? fs.rename
                : (function (fs$rename) {
                    function rename(from, to, cb) {
                        var start = Date.now();
                        var backoff = 0;
                        fs$rename(from, to, function CB(er) {
                            if (er
                                && (er.code === "EACCES" || er.code === "EPERM" || er.code === "EBUSY")
                                && Date.now() - start < 60000) {
                                setTimeout(function () {
                                    fs.stat(to, function (stater, st) {
                                        if (stater && stater.code === "ENOENT")
                                            fs$rename(from, to, CB);
                                        else
                                            cb(er);
                                    });
                                }, backoff);
                                if (backoff < 100)
                                    backoff += 10;
                                return;
                            }
                            if (cb)
                                cb(er);
                        });
                    }
                    if (Object.setPrototypeOf)
                        Object.setPrototypeOf(rename, fs$rename);
                    return rename;
                })(fs.rename);
        }
        // if read() returns EAGAIN, then just try it again.
        fs.read = typeof fs.read !== 'function' ? fs.read
            : (function (fs$read) {
                function read(fd, buffer, offset, length, position, callback_) {
                    var callback;
                    if (callback_ && typeof callback_ === 'function') {
                        var eagCounter = 0;
                        callback = function (er, _, __) {
                            if (er && er.code === 'EAGAIN' && eagCounter < 10) {
                                eagCounter++;
                                return fs$read.call(fs, fd, buffer, offset, length, position, callback);
                            }
                            callback_.apply(this, arguments);
                        };
                    }
                    return fs$read.call(fs, fd, buffer, offset, length, position, callback);
                }
                // This ensures `util.promisify` works as it does for native `fs.read`.
                if (Object.setPrototypeOf)
                    Object.setPrototypeOf(read, fs$read);
                return read;
            })(fs.read);
        fs.readSync = typeof fs.readSync !== 'function' ? fs.readSync
            : (function (fs$readSync) {
                return function (fd, buffer, offset, length, position) {
                    var eagCounter = 0;
                    while (true) {
                        try {
                            return fs$readSync.call(fs, fd, buffer, offset, length, position);
                        }
                        catch (er) {
                            if (er.code === 'EAGAIN' && eagCounter < 10) {
                                eagCounter++;
                                continue;
                            }
                            throw er;
                        }
                    }
                };
            })(fs.readSync);
        function patchLchmod(fs) {
            fs.lchmod = function (path, mode, callback) {
                fs.open(path, constants.O_WRONLY | constants.O_SYMLINK, mode, function (err, fd) {
                    if (err) {
                        if (callback)
                            callback(err);
                        return;
                    }
                    // prefer to return the chmod error, if one occurs,
                    // but still try to close, and report closing errors if they occur.
                    fs.fchmod(fd, mode, function (err) {
                        fs.close(fd, function (err2) {
                            if (callback)
                                callback(err || err2);
                        });
                    });
                });
            };
            fs.lchmodSync = function (path, mode) {
                var fd = fs.openSync(path, constants.O_WRONLY | constants.O_SYMLINK, mode);
                // prefer to return the chmod error, if one occurs,
                // but still try to close, and report closing errors if they occur.
                var threw = true;
                var ret;
                try {
                    ret = fs.fchmodSync(fd, mode);
                    threw = false;
                }
                finally {
                    if (threw) {
                        try {
                            fs.closeSync(fd);
                        }
                        catch (er) { }
                    }
                    else {
                        fs.closeSync(fd);
                    }
                }
                return ret;
            };
        }
        function patchLutimes(fs) {
            if (constants.hasOwnProperty("O_SYMLINK") && fs.futimes) {
                fs.lutimes = function (path, at, mt, cb) {
                    fs.open(path, constants.O_SYMLINK, function (er, fd) {
                        if (er) {
                            if (cb)
                                cb(er);
                            return;
                        }
                        fs.futimes(fd, at, mt, function (er) {
                            fs.close(fd, function (er2) {
                                if (cb)
                                    cb(er || er2);
                            });
                        });
                    });
                };
                fs.lutimesSync = function (path, at, mt) {
                    var fd = fs.openSync(path, constants.O_SYMLINK);
                    var ret;
                    var threw = true;
                    try {
                        ret = fs.futimesSync(fd, at, mt);
                        threw = false;
                    }
                    finally {
                        if (threw) {
                            try {
                                fs.closeSync(fd);
                            }
                            catch (er) { }
                        }
                        else {
                            fs.closeSync(fd);
                        }
                    }
                    return ret;
                };
            }
            else if (fs.futimes) {
                fs.lutimes = function (_a, _b, _c, cb) { if (cb)
                    process.nextTick(cb); };
                fs.lutimesSync = function () { };
            }
        }
        function chmodFix(orig) {
            if (!orig)
                return orig;
            return function (target, mode, cb) {
                return orig.call(fs, target, mode, function (er) {
                    if (chownErOk(er))
                        er = null;
                    if (cb)
                        cb.apply(this, arguments);
                });
            };
        }
        function chmodFixSync(orig) {
            if (!orig)
                return orig;
            return function (target, mode) {
                try {
                    return orig.call(fs, target, mode);
                }
                catch (er) {
                    if (!chownErOk(er))
                        throw er;
                }
            };
        }
        function chownFix(orig) {
            if (!orig)
                return orig;
            return function (target, uid, gid, cb) {
                return orig.call(fs, target, uid, gid, function (er) {
                    if (chownErOk(er))
                        er = null;
                    if (cb)
                        cb.apply(this, arguments);
                });
            };
        }
        function chownFixSync(orig) {
            if (!orig)
                return orig;
            return function (target, uid, gid) {
                try {
                    return orig.call(fs, target, uid, gid);
                }
                catch (er) {
                    if (!chownErOk(er))
                        throw er;
                }
            };
        }
        function statFix(orig) {
            if (!orig)
                return orig;
            // Older versions of Node erroneously returned signed integers for
            // uid + gid.
            return function (target, options, cb) {
                if (typeof options === 'function') {
                    cb = options;
                    options = null;
                }
                function callback(er, stats) {
                    if (stats) {
                        if (stats.uid < 0)
                            stats.uid += 0x100000000;
                        if (stats.gid < 0)
                            stats.gid += 0x100000000;
                    }
                    if (cb)
                        cb.apply(this, arguments);
                }
                return options ? orig.call(fs, target, options, callback)
                    : orig.call(fs, target, callback);
            };
        }
        function statFixSync(orig) {
            if (!orig)
                return orig;
            // Older versions of Node erroneously returned signed integers for
            // uid + gid.
            return function (target, options) {
                var stats = options ? orig.call(fs, target, options)
                    : orig.call(fs, target);
                if (stats) {
                    if (stats.uid < 0)
                        stats.uid += 0x100000000;
                    if (stats.gid < 0)
                        stats.gid += 0x100000000;
                }
                return stats;
            };
        }
        // ENOSYS means that the fs doesn't support the op. Just ignore
        // that, because it doesn't matter.
        //
        // if there's no getuid, or if getuid() is something other
        // than 0, and the error is EINVAL or EPERM, then just ignore
        // it.
        //
        // This specific case is a silent failure in cp, install, tar,
        // and most other unix tools that manage permissions.
        //
        // When running as root, or if other types of errors are
        // encountered, then it's strict.
        function chownErOk(er) {
            if (!er)
                return true;
            if (er.code === "ENOSYS")
                return true;
            var nonroot = !process.getuid || process.getuid() !== 0;
            if (nonroot) {
                if (er.code === "EINVAL" || er.code === "EPERM")
                    return true;
            }
            return false;
        }
    }
},
/* graceful-fs/legacy-streams.js */ function _(require, module, exports, __esModule, __esExport) {
    var Stream = require('stream').Stream;
    module.exports = legacy;
    function legacy(fs) {
        return {
            ReadStream: ReadStream,
            WriteStream: WriteStream
        };
        function ReadStream(path, options) {
            if (!(this instanceof ReadStream))
                return new ReadStream(path, options);
            Stream.call(this);
            var self = this;
            this.path = path;
            this.fd = null;
            this.readable = true;
            this.paused = false;
            this.flags = 'r';
            this.mode = 438; /*=0666*/
            this.bufferSize = 64 * 1024;
            options = options || {};
            // Mixin options into this
            var keys = Object.keys(options);
            for (var index = 0, length = keys.length; index < length; index++) {
                var key = keys[index];
                this[key] = options[key];
            }
            if (this.encoding)
                this.setEncoding(this.encoding);
            if (this.start !== undefined) {
                if ('number' !== typeof this.start) {
                    throw TypeError('start must be a Number');
                }
                if (this.end === undefined) {
                    this.end = Infinity;
                }
                else if ('number' !== typeof this.end) {
                    throw TypeError('end must be a Number');
                }
                if (this.start > this.end) {
                    throw new Error('start must be <= end');
                }
                this.pos = this.start;
            }
            if (this.fd !== null) {
                process.nextTick(function () {
                    self._read();
                });
                return;
            }
            fs.open(this.path, this.flags, this.mode, function (err, fd) {
                if (err) {
                    self.emit('error', err);
                    self.readable = false;
                    return;
                }
                self.fd = fd;
                self.emit('open', fd);
                self._read();
            });
        }
        function WriteStream(path, options) {
            if (!(this instanceof WriteStream))
                return new WriteStream(path, options);
            Stream.call(this);
            this.path = path;
            this.fd = null;
            this.writable = true;
            this.flags = 'w';
            this.encoding = 'binary';
            this.mode = 438; /*=0666*/
            this.bytesWritten = 0;
            options = options || {};
            // Mixin options into this
            var keys = Object.keys(options);
            for (var index = 0, length = keys.length; index < length; index++) {
                var key = keys[index];
                this[key] = options[key];
            }
            if (this.start !== undefined) {
                if ('number' !== typeof this.start) {
                    throw TypeError('start must be a Number');
                }
                if (this.start < 0) {
                    throw new Error('start must be >= zero');
                }
                this.pos = this.start;
            }
            this.busy = false;
            this._queue = [];
            if (this.fd === null) {
                this._open = fs.open;
                this._queue.push([this._open, this.path, this.flags, this.mode, undefined]);
                this.flush();
            }
        }
    }
},
/* graceful-fs/clone.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = clone;
    var getPrototypeOf = Object.getPrototypeOf || function (obj) {
        return obj.__proto__;
    };
    function clone(obj) {
        if (obj === null || typeof obj !== 'object')
            return obj;
        if (obj instanceof Object)
            var copy = { __proto__: getPrototypeOf(obj) };
        else
            var copy = Object.create(null);
        Object.getOwnPropertyNames(obj).forEach(function (key) {
            Object.defineProperty(copy, key, Object.getOwnPropertyDescriptor(obj, key));
        });
        return copy;
    }
},
/* less/lib/less/environment/abstract-file-manager.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var AbstractFileManager = /** @class */ (function () {
        function AbstractFileManager() {
        }
        AbstractFileManager.prototype.getPath = function (filename) {
            var j = filename.lastIndexOf('?');
            if (j > 0) {
                filename = filename.slice(0, j);
            }
            j = filename.lastIndexOf('/');
            if (j < 0) {
                j = filename.lastIndexOf('\\');
            }
            if (j < 0) {
                return '';
            }
            return filename.slice(0, j + 1);
        };
        AbstractFileManager.prototype.tryAppendExtension = function (path, ext) {
            return /(\.[a-z]*$)|([?;].*)$/.test(path) ? path : path + ext;
        };
        AbstractFileManager.prototype.tryAppendLessExtension = function (path) {
            return this.tryAppendExtension(path, '.less');
        };
        AbstractFileManager.prototype.supportsSync = function () {
            return false;
        };
        AbstractFileManager.prototype.alwaysMakePathsAbsolute = function () {
            return false;
        };
        AbstractFileManager.prototype.isPathAbsolute = function (filename) {
            return (/^(?:[a-z-]+:|\/|\\|#)/i).test(filename);
        };
        // TODO: pull out / replace?
        AbstractFileManager.prototype.join = function (basePath, laterPath) {
            if (!basePath) {
                return laterPath;
            }
            return basePath + laterPath;
        };
        AbstractFileManager.prototype.pathDiff = function (url, baseUrl) {
            // diff between two paths to create a relative path
            var urlParts = this.extractUrlParts(url);
            var baseUrlParts = this.extractUrlParts(baseUrl);
            var i;
            var max;
            var urlDirectories;
            var baseUrlDirectories;
            var diff = '';
            if (urlParts.hostPart !== baseUrlParts.hostPart) {
                return '';
            }
            max = Math.max(baseUrlParts.directories.length, urlParts.directories.length);
            for (i = 0; i < max; i++) {
                if (baseUrlParts.directories[i] !== urlParts.directories[i]) {
                    break;
                }
            }
            baseUrlDirectories = baseUrlParts.directories.slice(i);
            urlDirectories = urlParts.directories.slice(i);
            for (i = 0; i < baseUrlDirectories.length - 1; i++) {
                diff += '../';
            }
            for (i = 0; i < urlDirectories.length - 1; i++) {
                diff += urlDirectories[i] + "/";
            }
            return diff;
        };
        /**
         * Helper function, not part of API.
         * This should be replaceable by newer Node / Browser APIs
         *
         * @param {string} url
         * @param {string} baseUrl
         */
        AbstractFileManager.prototype.extractUrlParts = function (url, baseUrl) {
            // urlParts[1] = protocol://hostname/ OR /
            // urlParts[2] = / if path relative to host base
            // urlParts[3] = directories
            // urlParts[4] = filename
            // urlParts[5] = parameters
            var urlPartsRegex = /^((?:[a-z-]+:)?\/{2}(?:[^/?#]*\/)|([/\\]))?((?:[^/\\?#]*[/\\])*)([^/\\?#]*)([#?].*)?$/i;
            var urlParts = url.match(urlPartsRegex);
            var returner = {};
            var rawDirectories = [];
            var directories = [];
            var i;
            var baseUrlParts;
            if (!urlParts) {
                throw new Error("Could not parse sheet href - '" + url + "'");
            }
            // Stylesheets in IE don't always return the full path
            if (baseUrl && (!urlParts[1] || urlParts[2])) {
                baseUrlParts = baseUrl.match(urlPartsRegex);
                if (!baseUrlParts) {
                    throw new Error("Could not parse page url - '" + baseUrl + "'");
                }
                urlParts[1] = urlParts[1] || baseUrlParts[1] || '';
                if (!urlParts[2]) {
                    urlParts[3] = baseUrlParts[3] + urlParts[3];
                }
            }
            if (urlParts[3]) {
                rawDirectories = urlParts[3].replace(/\\/g, '/').split('/');
                // collapse '..' and skip '.'
                for (i = 0; i < rawDirectories.length; i++) {
                    if (rawDirectories[i] === '..') {
                        directories.pop();
                    }
                    else if (rawDirectories[i] !== '.') {
                        directories.push(rawDirectories[i]);
                    }
                }
            }
            returner.hostPart = urlParts[1];
            returner.directories = directories;
            returner.rawPath = (urlParts[1] || '') + rawDirectories.join('/');
            returner.path = (urlParts[1] || '') + directories.join('/');
            returner.filename = urlParts[4];
            returner.fileUrl = returner.path + (urlParts[4] || '');
            returner.url = returner.fileUrl + (urlParts[5] || '');
            return returner;
        };
        return AbstractFileManager;
    }());
    exports.default = AbstractFileManager;
    
},
/* less/lib/less-node/url-file-manager.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    /* eslint-disable no-unused-vars */
    /**
     * @todo - remove top eslint rule when FileManagers have JSDoc type
     * and are TS-type-checked
     */
    var isUrlRe = /^(?:https?:)?\/\//i;
    var url_1 = tslib_1.__importDefault(require("url"));
    var request;
    var abstract_file_manager_js_1 = tslib_1.__importDefault(require(73) /* ../less/environment/abstract-file-manager.js */);
    var logger_1 = tslib_1.__importDefault(require(75) /* ../less/logger */);
    var UrlFileManager = function () { };
    UrlFileManager.prototype = Object.assign(new abstract_file_manager_js_1.default(), {
        supports: function (filename, currentDirectory, options, environment) {
            return isUrlRe.test(filename) || isUrlRe.test(currentDirectory);
        },
        loadFile: function (filename, currentDirectory, options, environment) {
            return new Promise(function (fulfill, reject) {
                if (request === undefined) {
                    try {
                        request = require(76) /* needle */;
                    }
                    catch (e) {
                        request = null;
                    }
                }
                if (!request) {
                    reject({ type: 'File', message: 'optional dependency \'needle\' required to import over http(s)\n' });
                    return;
                }
                var urlStr = isUrlRe.test(filename) ? filename : url_1.default.resolve(currentDirectory, filename);
                /** native-request currently has a bug */
                var hackUrlStr = urlStr.indexOf('?') === -1 ? urlStr + '?' : urlStr;
                request.get(hackUrlStr, { follow_max: 5 }, function (err, resp, body) {
                    if (err || resp && resp.statusCode >= 400) {
                        var message = resp && resp.statusCode === 404
                            ? "resource '" + urlStr + "' was not found\n"
                            : "resource '" + urlStr + "' gave this Error:\n  " + (err || resp.statusMessage || resp.statusCode) + "\n";
                        reject({ type: 'File', message: message });
                        return;
                    }
                    if (resp.statusCode >= 300) {
                        reject({ type: 'File', message: "resource '" + urlStr + "' caused too many redirects" });
                        return;
                    }
                    body = body.toString('utf8');
                    if (!body) {
                        logger_1.default.warn("Warning: Empty body (HTTP " + resp.statusCode + ") returned by \"" + urlStr + "\"");
                    }
                    fulfill({ contents: body || '', filename: urlStr });
                });
            });
        }
    });
    exports.default = UrlFileManager;
    
},
/* less/lib/less/logger.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.default = {
        error: function (msg) {
            this._fireEvent('error', msg);
        },
        warn: function (msg) {
            this._fireEvent('warn', msg);
        },
        info: function (msg) {
            this._fireEvent('info', msg);
        },
        debug: function (msg) {
            this._fireEvent('debug', msg);
        },
        addListener: function (listener) {
            this._listeners.push(listener);
        },
        removeListener: function (listener) {
            for (var i = 0; i < this._listeners.length; i++) {
                if (this._listeners[i] === listener) {
                    this._listeners.splice(i, 1);
                    return;
                }
            }
        },
        _fireEvent: function (type, msg) {
            for (var i = 0; i < this._listeners.length; i++) {
                var logFunction = this._listeners[i][type];
                if (logFunction) {
                    logFunction(msg);
                }
            }
        },
        _listeners: []
    };
    
},
/* needle/lib/needle.js */ function _(require, module, exports, __esModule, __esExport) {//////////////////////////////////////////
    // Needle -- HTTP Client for Node.js
    // Written by Tomás Pollak <tomas@forkhq.com>
    // (c) 2012-2023 - Fork Ltd.
    // MIT Licensed
    //////////////////////////////////////////
    var fs = require('fs'), http = require('http'), https = require('https'), url = require('url'), stream = require('stream'), debug = require('util').debuglog('needle'), stringify = require(77) /* ./querystring */.build, multipart = require(78) /* ./multipart */, auth = require(79) /* ./auth */, cookies = require(80) /* ./cookies */, parsers = require(81) /* ./parsers */, decoder = require(83) /* ./decoder */, utils = require(106) /* ./utils */;
    //////////////////////////////////////////
    // variabilia
    var version = require(107) /* ../package.json */.version;
    var user_agent = 'Needle/' + version;
    user_agent += ' (Node.js ' + process.version + '; ' + process.platform + ' ' + process.arch + ')';
    var tls_options = 'pfx key passphrase cert ca ciphers rejectUnauthorized secureProtocol checkServerIdentity family';
    // older versions of node (< 0.11.4) prevent the runtime from exiting
    // because of connections in keep-alive state. so if this is the case
    // we'll default new requests to set a Connection: close header.
    var close_by_default = !http.Agent || http.Agent.defaultMaxSockets != Infinity;
    // see if we have Object.assign. otherwise fall back to util._extend
    var extend = Object.assign ? Object.assign : require('util')._extend;
    // these are the status codes that Needle interprets as redirects.
    var redirect_codes = [301, 302, 303, 307, 308];
    //////////////////////////////////////////
    // decompressors for gzip/deflate/br bodies
    function bind_opts(fn, options) {
        return fn.bind(null, options);
    }
    var decompressors = {};
    try {
        var zlib = require('zlib');
        // Enable Z_SYNC_FLUSH to avoid Z_BUF_ERROR errors (Node PR #2595)
        var zlib_options = {
            flush: zlib.Z_SYNC_FLUSH,
            finishFlush: zlib.Z_SYNC_FLUSH
        };
        var br_options = {
            flush: zlib.BROTLI_OPERATION_FLUSH,
            finishFlush: zlib.BROTLI_OPERATION_FLUSH
        };
        decompressors['x-deflate'] = bind_opts(zlib.Inflate, zlib_options);
        decompressors['deflate'] = bind_opts(zlib.Inflate, zlib_options);
        decompressors['x-gzip'] = bind_opts(zlib.Gunzip, zlib_options);
        decompressors['gzip'] = bind_opts(zlib.Gunzip, zlib_options);
        if (typeof zlib.BrotliDecompress === 'function') {
            decompressors['br'] = bind_opts(zlib.BrotliDecompress, br_options);
        }
    }
    catch (e) { /* zlib not available */ }
    //////////////////////////////////////////
    // options and aliases
    var defaults = {
        // data
        boundary: '--------------------NODENEEDLEHTTPCLIENT',
        encoding: 'utf8',
        parse_response: 'all', // same as true. valid options: 'json', 'xml' or false/null
        proxy: null,
        // agent & headers
        agent: null,
        headers: {},
        accept: '*/*',
        user_agent: user_agent,
        // numbers
        open_timeout: 10000,
        response_timeout: 0,
        read_timeout: 0,
        follow_max: 0,
        stream_length: -1,
        // abort signal
        signal: null,
        // booleans
        compressed: false,
        decode_response: true,
        parse_cookies: true,
        follow_set_cookies: false,
        follow_set_referer: false,
        follow_keep_method: false,
        follow_if_same_host: false,
        follow_if_same_protocol: false,
        follow_if_same_location: false,
        use_proxy_from_env_var: true
    };
    var aliased = {
        options: {
            decode: 'decode_response',
            parse: 'parse_response',
            timeout: 'open_timeout',
            follow: 'follow_max'
        },
        inverted: {}
    };
    // only once, invert aliased keys so we can get passed options.
    Object.keys(aliased.options).map(function (k) {
        var value = aliased.options[k];
        aliased.inverted[value] = k;
    });
    //////////////////////////////////////////
    // helpers
    function keys_by_type(type) {
        return Object.keys(defaults).map(function (el) {
            if (defaults[el] !== null && defaults[el].constructor == type)
                return el;
        }).filter(function (el) { return el; });
    }
    //////////////////////////////////////////
    // the main act
    function Needle(method, uri, data, options, callback) {
        // if (!(this instanceof Needle)) {
        //   return new Needle(method, uri, data, options, callback);
        // }
        if (typeof uri !== 'string')
            throw new TypeError('URL must be a string, not ' + uri);
        this.method = method.toLowerCase();
        this.uri = uri;
        this.data = data;
        if (typeof options == 'function') {
            this.callback = options;
            this.options = {};
        }
        else {
            this.callback = callback;
            this.options = options;
        }
    }
    Needle.prototype.setup = function (uri, options) {
        function get_option(key, fallback) {
            // if original is in options, return that value
            if (typeof options[key] != 'undefined')
                return options[key];
            // otherwise, return value from alias or fallback/undefined
            return typeof options[aliased.inverted[key]] != 'undefined'
                ? options[aliased.inverted[key]] : fallback;
        }
        function check_value(expected, key) {
            var value = get_option(key), type = typeof value;
            if (type != 'undefined' && type != expected)
                throw new TypeError(type + ' received for ' + key + ', but expected a ' + expected);
            return (type == expected) ? value : defaults[key];
        }
        //////////////////////////////////////////////////
        // the basics
        var config = {
            http_opts: {
                agent: get_option('agent', defaults.agent),
                localAddress: get_option('localAddress', undefined),
                lookup: get_option('lookup', undefined),
                signal: get_option('signal', defaults.signal)
            }, // passed later to http.request() directly
            headers: {},
            output: options.output,
            proxy: get_option('proxy', defaults.proxy),
            parser: get_option('parse_response', defaults.parse_response),
            encoding: options.encoding || (options.multipart ? 'binary' : defaults.encoding)
        };
        keys_by_type(Boolean).forEach(function (key) {
            config[key] = check_value('boolean', key);
        });
        keys_by_type(Number).forEach(function (key) {
            config[key] = check_value('number', key);
        });
        if (config.http_opts.signal && !(config.http_opts.signal instanceof AbortSignal))
            throw new TypeError(typeof config.http_opts.signal + ' received for signal, but expected an AbortSignal');
        // populate http_opts with given TLS options
        tls_options.split(' ').forEach(function (key) {
            if (typeof options[key] != 'undefined') {
                if (config.http_opts.agent) { // pass option to existing agent
                    config.http_opts.agent.options[key] = options[key];
                }
                else {
                    config.http_opts[key] = options[key];
                }
            }
        });
        //////////////////////////////////////////////////
        // headers, cookies
        for (var key in defaults.headers)
            config.headers[key] = defaults.headers[key];
        config.headers['accept'] = options.accept || defaults.accept;
        config.headers['user-agent'] = options.user_agent || defaults.user_agent;
        if (options.content_type)
            config.headers['content-type'] = options.content_type;
        // set connection header if opts.connection was passed, or if node < 0.11.4 (close)
        if (options.connection || close_by_default)
            config.headers['connection'] = options.connection || 'close';
        if ((options.compressed || defaults.compressed) && typeof zlib != 'undefined')
            config.headers['accept-encoding'] = decompressors['br'] ? 'gzip, deflate, br' : 'gzip, deflate';
        if (options.cookies)
            config.headers['cookie'] = cookies.write(options.cookies);
        //////////////////////////////////////////////////
        // basic/digest auth
        if (uri.match(/[^\/]@/)) { // url contains user:pass@host, so parse it.
            var parts = (url.parse(uri).auth || '').split(':');
            options.username = parts[0];
            options.password = parts[1];
        }
        if (options.username) {
            if (options.auth && (options.auth == 'auto' || options.auth == 'digest')) {
                config.credentials = [options.username, options.password];
            }
            else {
                config.headers['authorization'] = auth.basic(options.username, options.password);
            }
        }
        if (config.use_proxy_from_env_var) {
            var env_proxy = utils.get_env_var(['HTTP_PROXY', 'HTTPS_PROXY'], true);
            if (!config.proxy && env_proxy)
                config.proxy = env_proxy;
        }
        // if proxy is present, set auth header from either url or proxy_user option.
        if (config.proxy) {
            if (!config.use_proxy_from_env_var || utils.should_proxy_to(uri)) {
                if (config.proxy.indexOf('http') === -1)
                    config.proxy = 'http://' + config.proxy;
                if (config.proxy.indexOf('@') !== -1) {
                    var proxy = (url.parse(config.proxy).auth || '').split(':');
                    options.proxy_user = proxy[0];
                    options.proxy_pass = proxy[1];
                }
                if (options.proxy_user)
                    config.headers['proxy-authorization'] = auth.basic(options.proxy_user, options.proxy_pass);
            }
            else {
                delete config.proxy;
            }
        }
        // now that all our headers are set, overwrite them if instructed.
        for (var h in options.headers)
            config.headers[h.toLowerCase()] = options.headers[h];
        config.uri_modifier = get_option('uri_modifier', null);
        return config;
    };
    Needle.prototype.start = function () {
        var out = new stream.PassThrough({ objectMode: false }), uri = this.uri, data = this.data, method = this.method, callback = (typeof this.options == 'function') ? this.options : this.callback, options = this.options || {};
        // if no 'http' is found on URL, prepend it.
        if (uri.indexOf('http') === -1)
            uri = uri.replace(/^(\/\/)?/, 'http://');
        var self = this, body, waiting = false, config = this.setup(uri, options);
        // unless options.json was set to false, assume boss also wants JSON if content-type matches.
        var json = options.json || (options.json !== false && config.headers['content-type'] == 'application/json');
        if (data) {
            if (options.multipart) { // boss says we do multipart. so we do it.
                var boundary = options.boundary || defaults.boundary;
                waiting = true;
                multipart.build(data, boundary, function (err, parts) {
                    if (err)
                        throw (err);
                    config.headers['content-type'] = 'multipart/form-data; boundary=' + boundary;
                    next(parts);
                });
            }
            else if (utils.is_stream(data)) {
                if (method == 'get')
                    throw new Error('Refusing to pipe() a stream via GET. Did you mean .post?');
                if (config.stream_length > 0 || (config.stream_length === 0 && data.path)) {
                    // ok, let's get the stream's length and set it as the content-length header.
                    // this prevents some servers from cutting us off before all the data is sent.
                    waiting = true;
                    utils.get_stream_length(data, config.stream_length, function (length) {
                        data.length = length;
                        next(data);
                    });
                }
                else {
                    // if the boss doesn't want us to get the stream's length, or if it doesn't
                    // have a file descriptor for that purpose, then just head on.
                    body = data;
                }
            }
            else if (Buffer.isBuffer(data)) {
                body = data; // use the raw buffer as request body.
            }
            else if (method == 'get' && !json) {
                // append the data to the URI as a querystring.
                uri = uri.replace(/\?.*|$/, '?' + stringify(data));
            }
            else { // string or object data, no multipart.
                // if string, leave it as it is, otherwise, stringify.
                body = (typeof (data) === 'string') ? data
                    : json ? JSON.stringify(data) : stringify(data);
                // ensure we have a buffer so bytecount is correct.
                body = Buffer.from(body, config.encoding);
            }
        }
        function next(body) {
            if (body) {
                if (body.length)
                    config.headers['content-length'] = body.length;
                // if no content-type was passed, determine if json or not.
                if (!config.headers['content-type']) {
                    config.headers['content-type'] = json
                        ? 'application/json; charset=utf-8'
                        : 'application/x-www-form-urlencoded'; // no charset says W3 spec.
                }
            }
            // unless a specific accept header was set, assume json: true wants JSON back.
            if (options.json && (!options.accept && !(options.headers || {}).accept))
                config.headers['accept'] = 'application/json';
            self.send_request(1, method, uri, config, body, out, callback);
        }
        if (!waiting)
            next(body);
        return out;
    };
    Needle.prototype.get_request_opts = function (method, uri, config) {
        var opts = config.http_opts, proxy = config.proxy, remote = proxy ? url.parse(proxy) : url.parse(uri);
        opts.protocol = remote.protocol;
        opts.host = remote.hostname;
        opts.port = remote.port || (remote.protocol == 'https:' ? 443 : 80);
        opts.path = proxy ? uri : remote.pathname + (remote.search || '');
        opts.method = method;
        opts.headers = config.headers;
        if (!opts.headers['host']) {
            // if using proxy, make sure the host header shows the final destination
            var target = proxy ? url.parse(uri) : remote;
            opts.headers['host'] = target.hostname;
            // and if a non standard port was passed, append it to the port header
            if (target.port && [80, 443].indexOf(target.port) === -1) {
                opts.headers['host'] += ':' + target.port;
            }
        }
        return opts;
    };
    Needle.prototype.should_follow = function (location, config, original) {
        if (!location)
            return false;
        // returns true if location contains matching property (host or protocol)
        function matches(property) {
            var property = original[property];
            return location.indexOf(property) !== -1;
        }
        // first, check whether the requested location is actually different from the original
        if (!config.follow_if_same_location && location === original)
            return false;
        if (config.follow_if_same_host && !matches('host'))
            return false; // host does not match, so not following
        if (config.follow_if_same_protocol && !matches('protocol'))
            return false; // procotol does not match, so not following
        return true;
    };
    Needle.prototype.send_request = function (count, method, uri, config, post_data, out, callback) {
        if (typeof config.uri_modifier === 'function') {
            var modified_uri = config.uri_modifier(uri);
            debug('Modifying request URI', uri + ' => ' + modified_uri);
            uri = modified_uri;
        }
        var request, timer, returned = 0, self = this, request_opts = this.get_request_opts(method, uri, config), protocol = request_opts.protocol == 'https:' ? https : http, signal = request_opts.signal;
        function done(err, resp) {
            if (returned++ > 0)
                return debug('Already finished, stopping here.');
            if (timer)
                clearTimeout(timer);
            request.removeListener('error', had_error);
            out.done = true;
            // An error can still be fired after closing.  In particular, on macOS.
            // See also:
            //  - https://github.com/tomas/needle/issues/391
            //  - https://github.com/less/less.js/issues/3693
            //  - https://github.com/nodejs/node/issues/27916
            request.once('error', function () { });
            if (callback)
                return callback(err, resp, resp ? resp.body : undefined);
            // NOTE: this event used to be called 'end', but the behaviour was confusing
            // when errors ocurred, because the stream would still emit an 'end' event.
            out.emit('done', err);
            // trigger the 'done' event on streams we're being piped to, if any
            var pipes = out._readableState.pipes || [];
            if (!pipes.forEach)
                pipes = [pipes];
            pipes.forEach(function (st) { st.emit('done', err); });
        }
        function had_error(err) {
            debug('Request error', err);
            out.emit('err', err);
            done(err || new Error('Unknown error when making request.'));
        }
        function abort_handler() {
            out.emit('err', new Error('Aborted by signal.'));
            request.destroy();
        }
        function set_timeout(type, milisecs) {
            if (timer)
                clearTimeout(timer);
            if (milisecs <= 0)
                return;
            timer = setTimeout(function () {
                out.emit('timeout', type);
                request.destroy();
                // also invoke done() to terminate job on read_timeout
                if (type == 'read')
                    done(new Error(type + ' timeout'));
                signal && signal.removeEventListener('abort', abort_handler);
            }, milisecs);
        }
        debug('Making request #' + count, request_opts);
        request = protocol.request(request_opts, function (resp) {
            var headers = resp.headers;
            debug('Got response', resp.statusCode, headers);
            out.emit('response', resp);
            set_timeout('read', config.read_timeout);
            // if we got cookies, parse them unless we were instructed not to. make sure to include any
            // cookies that might have been set on previous redirects.
            if (config.parse_cookies && (headers['set-cookie'] || config.previous_resp_cookies)) {
                resp.cookies = extend(config.previous_resp_cookies || {}, cookies.read(headers['set-cookie']));
                debug('Got cookies', resp.cookies);
            }
            // if redirect code is found, determine if we should follow it according to the given options.
            if (redirect_codes.indexOf(resp.statusCode) !== -1 && self.should_follow(headers.location, config, uri)) {
                // clear timer before following redirects to prevent unexpected setTimeout consequence
                clearTimeout(timer);
                if (count <= config.follow_max) {
                    out.emit('redirect', headers.location);
                    // unless 'follow_keep_method' is true, rewrite the request to GET before continuing.
                    if (!config.follow_keep_method) {
                        method = 'GET';
                        post_data = null;
                        delete config.headers['content-length']; // in case the original was a multipart POST request.
                    }
                    // if follow_set_cookies is true, insert cookies in the next request's headers.
                    // we set both the original request cookies plus any response cookies we might have received.
                    if (config.follow_set_cookies && utils.host_and_ports_match(headers.location, uri)) {
                        var request_cookies = cookies.read(config.headers['cookie']);
                        config.previous_resp_cookies = resp.cookies;
                        if (Object.keys(request_cookies).length || Object.keys(resp.cookies || {}).length) {
                            config.headers['cookie'] = cookies.write(extend(request_cookies, resp.cookies));
                        }
                    }
                    else if (config.headers['cookie']) {
                        debug('Clearing original request cookie', config.headers['cookie']);
                        delete config.headers['cookie'];
                    }
                    if (config.follow_set_referer)
                        config.headers['referer'] = encodeURI(uri); // the original, not the destination URL.
                    config.headers['host'] = null; // clear previous Host header to avoid conflicts.
                    var redirect_url = utils.resolve_url(headers.location, uri);
                    debug('Redirecting to ' + redirect_url.toString());
                    return self.send_request(++count, method, redirect_url.toString(), config, post_data, out, callback);
                }
                else if (config.follow_max > 0) {
                    return done(new Error('Max redirects reached. Possible loop in: ' + headers.location));
                }
            }
            // if auth is requested and credentials were not passed, resend request, provided we have user/pass.
            if (resp.statusCode == 401 && headers['www-authenticate'] && config.credentials) {
                if (!config.headers['authorization']) { // only if authentication hasn't been sent
                    var auth_header = auth.header(headers['www-authenticate'], config.credentials, request_opts);
                    if (auth_header) {
                        config.headers['authorization'] = auth_header;
                        return self.send_request(count, method, uri, config, post_data, out, callback);
                    }
                }
            }
            // ok, so we got a valid (non-redirect & authorized) response. let's notify the stream guys.
            out.emit('header', resp.statusCode, headers);
            out.emit('headers', headers);
            var pipeline = [], mime = utils.parse_content_type(headers['content-type']), text_response = mime.type && (mime.type.indexOf('text/') != -1 || !!mime.type.match(/(\/|\+)(xml|json)$/));
            // To start, if our body is compressed and we're able to inflate it, do it.
            if (headers['content-encoding'] && decompressors[headers['content-encoding']]) {
                var decompressor = decompressors[headers['content-encoding']]();
                // make sure we catch errors triggered by the decompressor.
                decompressor.on('error', had_error);
                pipeline.push(decompressor);
            }
            // If parse is enabled and we have a parser for it, then go for it.
            if (config.parser && parsers[mime.type]) {
                // If a specific parser was requested, make sure we don't parse other types.
                var parser_name = config.parser.toString().toLowerCase();
                if (['xml', 'json'].indexOf(parser_name) == -1 || parsers[mime.type].name == parser_name) {
                    // OK, so either we're parsing all content types or the one requested matches.
                    out.parser = parsers[mime.type].name;
                    pipeline.push(parsers[mime.type].fn());
                    // Set objectMode on out stream to improve performance.
                    out._writableState.objectMode = true;
                    out._readableState.objectMode = true;
                }
                // If we're not parsing, and unless decoding was disabled, we'll try
                // decoding non UTF-8 bodies to UTF-8, using the iconv-lite library.
            }
            else if (text_response && config.decode_response && mime.charset) {
                pipeline.push(decoder(mime.charset));
            }
            // And `out` is the stream we finally push the decoded/parsed output to.
            pipeline.push(out);
            // Now, release the kraken!
            utils.pump_streams([resp].concat(pipeline), function (err) {
                if (err)
                    debug(err);
                // on node v8.x, if an error ocurrs on the receiving end,
                // then we want to abort the request to avoid having dangling sockets
                if (err && err.message == 'write after end')
                    request.destroy();
            });
            // If the user has requested and output file, pipe the output stream to it.
            // In stream mode, we will still get the response stream to play with.
            if (config.output && resp.statusCode == 200) {
                // for some reason, simply piping resp to the writable stream doesn't
                // work all the time (stream gets cut in the middle with no warning).
                // so we'll manually need to do the readable/write(chunk) trick.
                var file = fs.createWriteStream(config.output);
                file.on('error', had_error);
                out.on('end', function () {
                    if (file.writable)
                        file.end();
                });
                file.on('close', function () {
                    delete out.file;
                });
                out.on('readable', function () {
                    var chunk;
                    while ((chunk = this.read()) !== null) {
                        if (file.writable)
                            file.write(chunk);
                        // if callback was requested, also push it to resp.body
                        if (resp.body)
                            resp.body.push(chunk);
                    }
                });
                out.file = file;
            }
            // Only aggregate the full body if a callback was requested.
            if (callback) {
                resp.raw = [];
                resp.body = [];
                resp.bytes = 0;
                // Gather and count the amount of (raw) bytes using a PassThrough stream.
                var clean_pipe = new stream.PassThrough();
                clean_pipe.on('readable', function () {
                    var chunk;
                    while ((chunk = this.read()) != null) {
                        resp.bytes += chunk.length;
                        resp.raw.push(chunk);
                    }
                });
                utils.pump_streams([resp, clean_pipe], function (err) {
                    if (err)
                        debug(err);
                });
                // Listen on the 'readable' event to aggregate the chunks, but only if
                // file output wasn't requested. Otherwise we'd have two stream readers.
                if (!config.output || resp.statusCode != 200) {
                    out.on('readable', function () {
                        var chunk;
                        while ((chunk = this.read()) !== null) {
                            // We're either pushing buffers or objects, never strings.
                            if (typeof chunk == 'string')
                                chunk = Buffer.from(chunk);
                            // Push all chunks to resp.body. We'll bind them in resp.end().
                            resp.body.push(chunk);
                        }
                    });
                }
            }
            // And set the .body property once all data is in.
            out.on('end', function () {
                if (resp.body) { // callback mode
                    // we want to be able to access to the raw data later, so keep a reference.
                    resp.raw = Buffer.concat(resp.raw);
                    // if parse was successful, we should have an array with one object
                    if (resp.body[0] !== undefined && !Buffer.isBuffer(resp.body[0])) {
                        // that's our body right there.
                        resp.body = resp.body[0];
                        // set the parser property on our response. we may want to check.
                        if (out.parser)
                            resp.parser = out.parser;
                    }
                    else { // we got one or several buffers. string or binary.
                        resp.body = Buffer.concat(resp.body);
                        // if we're here and parsed is true, it means we tried to but it didn't work.
                        // so given that we got a text response, let's stringify it.
                        if (text_response || out.parser) {
                            resp.body = resp.body.toString();
                        }
                    }
                }
                // if an output file is being written to, make sure the callback
                // is triggered after all data has been written to it.
                if (out.file) {
                    out.file.on('close', function () {
                        done(null, resp);
                    });
                }
                else { // elvis has left the building.
                    done(null, resp);
                }
            });
            // out.on('error', function(err) {
            //   had_error(err);
            //   if (err.code == 'ERR_STREAM_DESTROYED' || err.code == 'ERR_STREAM_PREMATURE_CLOSE') {
            //     request.abort();
            //   }
            // })
        }); // end request call
        // unless open_timeout was disabled, set a timeout to abort the request.
        set_timeout('open', config.open_timeout);
        // handle errors on the request object. things might get bumpy.
        request.on('error', had_error);
        // make sure timer is cleared if request is aborted (issue #257)
        request.once('abort', function () {
            if (timer)
                clearTimeout(timer);
        });
        // set response timeout once we get a valid socket
        request.once('socket', function (socket) {
            if (socket.connecting) {
                socket.once('connect', function () {
                    set_timeout('response', config.response_timeout);
                });
            }
            else {
                set_timeout('response', config.response_timeout);
            }
        });
        if (post_data) {
            if (utils.is_stream(post_data)) {
                utils.pump_streams([post_data, request], function (err) {
                    if (err)
                        debug(err);
                });
            }
            else {
                request.write(post_data, config.encoding);
                request.end();
            }
        }
        else {
            request.end();
        }
        if (signal) { // abort signal given, so handle it
            if (signal.aborted === true) {
                abort_handler();
            }
            else {
                signal.addEventListener('abort', abort_handler, { once: true });
            }
        }
        out.abort = function () { request.destroy(); }; // easier access
        out.request = request;
        return out;
    };
    //////////////////////////////////////////
    // exports
    if (typeof Promise !== 'undefined') {
        module.exports = function () {
            var verb, args = [].slice.call(arguments);
            if (args[0].match(/\.|\//)) // first argument looks like a URL
                verb = (args.length > 2) ? 'post' : 'get';
            else
                verb = args.shift();
            if (verb.match(/get|head/i) && args.length == 2)
                args.splice(1, 0, null); // assume no data if head/get with two args (url, options)
            return new Promise(function (resolve, reject) {
                module.exports.request(verb, args[0], args[1], args[2], function (err, resp) {
                    return err ? reject(err) : resolve(resp);
                });
            });
        };
    }
    module.exports.version = version;
    module.exports.defaults = function (obj) {
        for (var key in obj) {
            var target_key = aliased.options[key] || key;
            if (defaults.hasOwnProperty(target_key) && typeof obj[key] != 'undefined') {
                if (target_key != 'parse_response' && target_key != 'proxy' && target_key != 'agent' && target_key != 'signal') {
                    // ensure type matches the original, except for proxy/parse_response that can be null/bool or string, and signal that can be null/AbortSignal
                    var valid_type = defaults[target_key].constructor.name;
                    if (obj[key].constructor.name != valid_type)
                        throw new TypeError('Invalid type for ' + key + ', should be ' + valid_type);
                }
                else if (target_key === 'signal' && obj[key] !== null && !(obj[key] instanceof AbortSignal)) {
                    throw new TypeError('Invalid type for ' + key + ', should be AbortSignal');
                }
                defaults[target_key] = obj[key];
            }
            else {
                throw new Error('Invalid property for defaults:' + target_key);
            }
        }
        return defaults;
    };
    'head get'.split(' ').forEach(function (method) {
        module.exports[method] = function (uri, options, callback) {
            return new Needle(method, uri, null, options, callback).start();
        };
    });
    'post put patch delete'.split(' ').forEach(function (method) {
        module.exports[method] = function (uri, data, options, callback) {
            return new Needle(method, uri, data, options, callback).start();
        };
    });
    module.exports.request = function (method, uri, data, opts, callback) {
        return new Needle(method, uri, data, opts, callback).start();
    };
},
/* needle/lib/querystring.js */ function _(require, module, exports, __esModule, __esExport) {// based on the qs module, but handles null objects as expected
    // fixes by Tomas Pollak.
    var toString = Object.prototype.toString;
    function stringify(obj, prefix) {
        if (prefix && (obj === null || typeof obj == 'undefined')) {
            return prefix + '=';
        }
        else if (toString.call(obj) == '[object Array]') {
            return stringifyArray(obj, prefix);
        }
        else if (toString.call(obj) == '[object Object]') {
            return stringifyObject(obj, prefix);
        }
        else if (toString.call(obj) == '[object Date]') {
            return obj.toISOString();
        }
        else if (prefix) { // string inside array or hash
            return prefix + '=' + encodeURIComponent(String(obj));
        }
        else if (String(obj).indexOf('=') !== -1) { // string with equal sign
            return String(obj);
        }
        else {
            throw new TypeError('Cannot build a querystring out of: ' + obj);
        }
    }
    ;
    function stringifyArray(arr, prefix) {
        var ret = [];
        for (var i = 0, len = arr.length; i < len; i++) {
            if (prefix)
                ret.push(stringify(arr[i], prefix + '[]'));
            else
                ret.push(stringify(arr[i]));
        }
        return ret.join('&');
    }
    function stringifyObject(obj, prefix) {
        var ret = [];
        Object.keys(obj).forEach(function (key) {
            ret.push(stringify(obj[key], prefix
                ? prefix + '[' + encodeURIComponent(key) + ']'
                : encodeURIComponent(key)));
        });
        return ret.join('&');
    }
    exports.build = stringify;
},
/* needle/lib/multipart.js */ function _(require, module, exports, __esModule, __esExport) {
    var readFile = require('fs').readFile, basename = require('path').basename;
    exports.build = function (data, boundary, callback) {
        if (typeof data != 'object' || typeof data.pipe == 'function')
            return callback(new Error('Multipart builder expects data as key/val object.'));
        var body = '', object = flatten(data), count = Object.keys(object).length;
        if (count === 0)
            return callback(new Error('Empty multipart body. Invalid data.'));
        function done(err, section) {
            if (err)
                return callback(err);
            if (section)
                body += section;
            --count || callback(null, body + '--' + boundary + '--');
        }
        ;
        for (var key in object) {
            var value = object[key];
            if (value === null || typeof value == 'undefined') {
                done();
            }
            else if (Buffer.isBuffer(value)) {
                var part = { buffer: value, content_type: 'application/octet-stream' };
                generate_part(key, part, boundary, done);
            }
            else {
                var part = (value.buffer || value.file || value.content_type) ? value : { value: value };
                generate_part(key, part, boundary, done);
            }
        }
    };
    function generate_part(name, part, boundary, callback) {
        var return_part = '--' + boundary + '\r\n';
        return_part += 'Content-Disposition: form-data; name="' + name + '"';
        function append(data, filename) {
            if (data) {
                var binary = part.content_type.indexOf('text') == -1;
                return_part += '; filename="' + encodeURIComponent(filename) + '"\r\n';
                if (binary)
                    return_part += 'Content-Transfer-Encoding: binary\r\n';
                return_part += 'Content-Type: ' + part.content_type + '\r\n\r\n';
                return_part += binary ? data.toString('binary') : data.toString('utf8');
            }
            callback(null, return_part + '\r\n');
        }
        ;
        if ((part.file || part.buffer) && part.content_type) {
            var filename = part.filename ? part.filename : part.file ? basename(part.file) : name;
            if (part.buffer)
                return append(part.buffer, filename);
            readFile(part.file, function (err, data) {
                if (err)
                    return callback(err);
                append(data, filename);
            });
        }
        else {
            if (typeof part.value == 'object')
                return callback(new Error('Object received for ' + name + ', expected string.'));
            if (part.content_type) {
                return_part += '\r\n';
                return_part += 'Content-Type: ' + part.content_type;
            }
            return_part += '\r\n\r\n';
            return_part += Buffer.from(String(part.value), 'utf8').toString('binary');
            append();
        }
    }
    // flattens nested objects for multipart body
    function flatten(object, into, prefix) {
        into = into || {};
        for (var key in object) {
            var prefix_key = prefix ? prefix + '[' + key + ']' : key;
            var prop = object[key];
            if (prop && typeof prop === 'object' && !(prop.buffer || prop.file || prop.content_type))
                flatten(prop, into, prefix_key);
            else
                into[prefix_key] = prop;
        }
        return into;
    }
},
/* needle/lib/auth.js */ function _(require, module, exports, __esModule, __esExport) {
    var createHash = require('crypto').createHash;
    function get_header(header, credentials, opts) {
        var type = header.split(' ')[0], user = credentials[0], pass = credentials[1];
        if (type == 'Digest') {
            return digest.generate(header, user, pass, opts.method, opts.path);
        }
        else if (type == 'Basic') {
            return basic(user, pass);
        }
    }
    ////////////////////
    // basic
    function md5(string) {
        return createHash('md5').update(string).digest('hex');
    }
    function basic(user, pass) {
        var str = typeof pass == 'undefined' ? user : [user, pass].join(':');
        return 'Basic ' + Buffer.from(str).toString('base64');
    }
    ////////////////////
    // digest
    // logic inspired from https://github.com/simme/node-http-digest-client
    var digest = {};
    digest.parse_header = function (header) {
        var challenge = {}, matches = header.match(/([a-z0-9_-]+)="?([a-z0-9_=\/\.@\s-\+:)()]+)"?/gi);
        for (var i = 0, l = matches.length; i < l; i++) {
            var parts = matches[i].split('='), key = parts.shift(), val = parts.join('=').replace(/^"/, '').replace(/"$/, '');
            challenge[key] = val;
        }
        return challenge;
    };
    digest.update_nc = function (nc) {
        var max = 99999999;
        nc++;
        if (nc > max)
            nc = 1;
        var padding = new Array(8).join('0') + '';
        nc = nc + '';
        return padding.substr(0, 8 - nc.length) + nc;
    };
    digest.generate = function (header, user, pass, method, path) {
        var nc = 1, cnonce = null, challenge = digest.parse_header(header);
        var ha1 = md5(user + ':' + challenge.realm + ':' + pass), ha2 = md5(method.toUpperCase() + ':' + path), resp = [ha1, challenge.nonce];
        if (typeof challenge.qop === 'string') {
            cnonce = md5(Math.random().toString(36)).substr(0, 8);
            nc = digest.update_nc(nc);
            resp = resp.concat(nc, cnonce);
            resp = resp.concat(challenge.qop, ha2);
        }
        else {
            resp = resp.concat(ha2);
        }
        var params = {
            uri: path,
            realm: challenge.realm,
            nonce: challenge.nonce,
            username: user,
            response: md5(resp.join(':'))
        };
        if (challenge.qop) {
            params.qop = challenge.qop;
        }
        if (challenge.opaque) {
            params.opaque = challenge.opaque;
        }
        if (cnonce) {
            params.nc = nc;
            params.cnonce = cnonce;
        }
        header = [];
        for (var k in params)
            header.push(k + '="' + params[k] + '"');
        return 'Digest ' + header.join(', ');
    };
    module.exports = {
        header: get_header,
        basic: basic,
        digest: digest.generate
    };
},
/* needle/lib/cookies.js */ function _(require, module, exports, __esModule, __esExport) {
    //  Simple cookie handling implementation based on the standard RFC 6265.
    //
    //  This module just has two functionalities:
    //    - Parse a set-cookie-header as a key value object
    //    - Write a cookie-string from a key value object
    //
    //  All cookie attributes are ignored.
    var unescape = require('querystring').unescape;
    var COOKIE_PAIR = /^([^=\s]+)\s*=\s*("?)\s*(.*)\s*\2\s*$/;
    var EXCLUDED_CHARS = /[\x00-\x1F\x7F\x3B\x3B\s\"\,\\"%]/g;
    var TRAILING_SEMICOLON = /\x3B+$/;
    var SEP_SEMICOLON = /\s*\x3B\s*/;
    // i know these should be 'const', but I'd like to keep
    // supporting earlier node.js versions as long as I can. :)
    var KEY_INDEX = 1; // index of key from COOKIE_PAIR match
    var VALUE_INDEX = 3; // index of value from COOKIE_PAIR match
    // Returns a copy str trimmed and without trainling semicolon.
    function cleanCookieString(str) {
        return str.trim().replace(/\x3B+$/, '');
    }
    function getFirstPair(str) {
        var index = str.indexOf('\x3B');
        return index === -1 ? str : str.substr(0, index);
    }
    // Returns a encoded copy of str based on RFC6265 S4.1.1.
    function encodeCookieComponent(str) {
        return str.toString().replace(EXCLUDED_CHARS, encodeURIComponent);
    }
    // Parses a set-cookie-string based on the standard defined in RFC6265 S4.1.1.
    function parseSetCookieString(str) {
        str = cleanCookieString(str);
        str = getFirstPair(str);
        var res = COOKIE_PAIR.exec(str);
        if (!res || !res[VALUE_INDEX])
            return null;
        return {
            name: unescape(res[KEY_INDEX]),
            value: unescape(res[VALUE_INDEX])
        };
    }
    // Parses a set-cookie-header and returns a key/value object.
    // Each key represents the name of a cookie.
    function parseSetCookieHeader(header) {
        if (!header)
            return {};
        header = Array.isArray(header) ? header : [header];
        return header.reduce(function (res, str) {
            var cookie = parseSetCookieString(str);
            if (cookie)
                res[cookie.name] = cookie.value;
            return res;
        }, {});
    }
    // Writes a set-cookie-string based on the standard definded in RFC6265 S4.1.1.
    function writeCookieString(obj) {
        return Object.keys(obj).reduce(function (str, name) {
            var encodedName = encodeCookieComponent(name);
            var encodedValue = encodeCookieComponent(obj[name]);
            str += (str ? '; ' : '') + encodedName + '=' + encodedValue;
            return str;
        }, '');
    }
    // returns a key/val object from an array of cookie strings
    exports.read = parseSetCookieHeader;
    // writes a cookie string header
    exports.write = writeCookieString;
},
/* needle/lib/parsers.js */ function _(require, module, exports, __esModule, __esExport) {//////////////////////////////////////////
    // Defines mappings between content-type
    // and the appropriate parsers.
    //////////////////////////////////////////
    var Transform = require('stream').Transform;
    var sax = require(82) /* sax */;
    function parseXML(str, cb) {
        var obj, current, parser = sax.parser(true, { trim: true, lowercase: true });
        parser.onerror = parser.onend = done;
        function done(err) {
            parser.onerror = parser.onend = function () { };
            cb(err, obj);
        }
        function newElement(name, attributes) {
            return {
                name: name || '',
                value: '',
                attributes: attributes || {},
                children: []
            };
        }
        parser.oncdata = parser.ontext = function (t) {
            if (current)
                current.value += t;
        };
        parser.onopentag = function (node) {
            var element = newElement(node.name, node.attributes);
            if (current) {
                element.parent = current;
                current.children.push(element);
            }
            else { // root object
                obj = element;
            }
            current = element;
        };
        parser.onclosetag = function () {
            if (typeof current.parent !== 'undefined') {
                var just_closed = current;
                current = current.parent;
                delete just_closed.parent;
            }
        };
        parser.write(str).close();
    }
    function parserFactory(name, fn) {
        function parser() {
            var chunks = [], stream = new Transform({ objectMode: true });
            // Buffer all our data
            stream._transform = function (chunk, encoding, done) {
                chunks.push(chunk);
                done();
            };
            // And call the parser when all is there.
            stream._flush = function (done) {
                var self = this, data = Buffer.concat(chunks);
                try {
                    fn(data, function (err, result) {
                        if (err)
                            throw err;
                        self.push(result);
                    });
                }
                catch (err) {
                    self.push(data); // just pass the original data
                }
                finally {
                    done();
                }
            };
            return stream;
        }
        return { fn: parser, name: name };
    }
    var parsers = {};
    function buildParser(name, types, fn) {
        var parser = parserFactory(name, fn);
        types.forEach(function (type) {
            parsers[type] = parser;
        });
    }
    buildParser('json', [
        'application/json',
        'application/hal+json',
        'text/javascript',
        'application/vnd.api+json'
    ], function (buffer, cb) {
        var err, data;
        try {
            data = JSON.parse(buffer);
        }
        catch (e) {
            err = e;
        }
        cb(err, data);
    });
    buildParser('xml', [
        'text/xml',
        'application/xml',
        'application/rdf+xml',
        'application/rss+xml',
        'application/atom+xml'
    ], function (buffer, cb) {
        parseXML(buffer.toString(), function (err, obj) {
            cb(err, obj);
        });
    });
    module.exports = parsers;
    module.exports.use = buildParser;
},
/* sax/lib/sax.js */ function _(require, module, exports, __esModule, __esExport) {
    ;
    (function (sax) {
        sax.parser = function (strict, opt) { return new SAXParser(strict, opt); };
        sax.SAXParser = SAXParser;
        sax.SAXStream = SAXStream;
        sax.createStream = createStream;
        // When we pass the MAX_BUFFER_LENGTH position, start checking for buffer overruns.
        // When we check, schedule the next check for MAX_BUFFER_LENGTH - (max(buffer lengths)),
        // since that's the earliest that a buffer overrun could occur.  This way, checks are
        // as rare as required, but as often as necessary to ensure never crossing this bound.
        // Furthermore, buffers are only tested at most once per write(), so passing a very
        // large string into write() might have undesirable effects, but this is manageable by
        // the caller, so it is assumed to be safe.  Thus, a call to write() may, in the extreme
        // edge case, result in creating at most one complete copy of the string passed in.
        // Set to Infinity to have unlimited buffers.
        sax.MAX_BUFFER_LENGTH = 64 * 1024;
        var buffers = [
            'comment', 'sgmlDecl', 'textNode', 'tagName', 'doctype',
            'procInstName', 'procInstBody', 'entity', 'attribName',
            'attribValue', 'cdata', 'script'
        ];
        sax.EVENTS = [
            'text',
            'processinginstruction',
            'sgmldeclaration',
            'doctype',
            'comment',
            'opentagstart',
            'attribute',
            'opentag',
            'closetag',
            'opencdata',
            'cdata',
            'closecdata',
            'error',
            'end',
            'ready',
            'script',
            'opennamespace',
            'closenamespace'
        ];
        function SAXParser(strict, opt) {
            if (!(this instanceof SAXParser)) {
                return new SAXParser(strict, opt);
            }
            var parser = this;
            clearBuffers(parser);
            parser.q = parser.c = '';
            parser.bufferCheckPosition = sax.MAX_BUFFER_LENGTH;
            parser.opt = opt || {};
            parser.opt.lowercase = parser.opt.lowercase || parser.opt.lowercasetags;
            parser.looseCase = parser.opt.lowercase ? 'toLowerCase' : 'toUpperCase';
            parser.tags = [];
            parser.closed = parser.closedRoot = parser.sawRoot = false;
            parser.tag = parser.error = null;
            parser.strict = !!strict;
            parser.noscript = !!(strict || parser.opt.noscript);
            parser.state = S.BEGIN;
            parser.strictEntities = parser.opt.strictEntities;
            parser.ENTITIES = parser.strictEntities ? Object.create(sax.XML_ENTITIES) : Object.create(sax.ENTITIES);
            parser.attribList = [];
            // namespaces form a prototype chain.
            // it always points at the current tag,
            // which protos to its parent tag.
            if (parser.opt.xmlns) {
                parser.ns = Object.create(rootNS);
            }
            // mostly just for error reporting
            parser.trackPosition = parser.opt.position !== false;
            if (parser.trackPosition) {
                parser.position = parser.line = parser.column = 0;
            }
            emit(parser, 'onready');
        }
        if (!Object.create) {
            Object.create = function (o) {
                function F() { }
                F.prototype = o;
                var newf = new F();
                return newf;
            };
        }
        if (!Object.keys) {
            Object.keys = function (o) {
                var a = [];
                for (var i in o)
                    if (o.hasOwnProperty(i))
                        a.push(i);
                return a;
            };
        }
        function checkBufferLength(parser) {
            var maxAllowed = Math.max(sax.MAX_BUFFER_LENGTH, 10);
            var maxActual = 0;
            for (var i = 0, l = buffers.length; i < l; i++) {
                var len = parser[buffers[i]].length;
                if (len > maxAllowed) {
                    // Text/cdata nodes can get big, and since they're buffered,
                    // we can get here under normal conditions.
                    // Avoid issues by emitting the text node now,
                    // so at least it won't get any bigger.
                    switch (buffers[i]) {
                        case 'textNode':
                            closeText(parser);
                            break;
                        case 'cdata':
                            emitNode(parser, 'oncdata', parser.cdata);
                            parser.cdata = '';
                            break;
                        case 'script':
                            emitNode(parser, 'onscript', parser.script);
                            parser.script = '';
                            break;
                        default:
                            error(parser, 'Max buffer length exceeded: ' + buffers[i]);
                    }
                }
                maxActual = Math.max(maxActual, len);
            }
            // schedule the next check for the earliest possible buffer overrun.
            var m = sax.MAX_BUFFER_LENGTH - maxActual;
            parser.bufferCheckPosition = m + parser.position;
        }
        function clearBuffers(parser) {
            for (var i = 0, l = buffers.length; i < l; i++) {
                parser[buffers[i]] = '';
            }
        }
        function flushBuffers(parser) {
            closeText(parser);
            if (parser.cdata !== '') {
                emitNode(parser, 'oncdata', parser.cdata);
                parser.cdata = '';
            }
            if (parser.script !== '') {
                emitNode(parser, 'onscript', parser.script);
                parser.script = '';
            }
        }
        SAXParser.prototype = {
            end: function () { end(this); },
            write: write,
            resume: function () { this.error = null; return this; },
            close: function () { return this.write(null); },
            flush: function () { flushBuffers(this); }
        };
        var Stream;
        try {
            Stream = require('stream').Stream;
        }
        catch (ex) {
            Stream = function () { };
        }
        if (!Stream)
            Stream = function () { };
        var streamWraps = sax.EVENTS.filter(function (ev) {
            return ev !== 'error' && ev !== 'end';
        });
        function createStream(strict, opt) {
            return new SAXStream(strict, opt);
        }
        function SAXStream(strict, opt) {
            if (!(this instanceof SAXStream)) {
                return new SAXStream(strict, opt);
            }
            Stream.apply(this);
            this._parser = new SAXParser(strict, opt);
            this.writable = true;
            this.readable = true;
            var me = this;
            this._parser.onend = function () {
                me.emit('end');
            };
            this._parser.onerror = function (er) {
                me.emit('error', er);
                // if didn't throw, then means error was handled.
                // go ahead and clear error, so we can write again.
                me._parser.error = null;
            };
            this._decoder = null;
            streamWraps.forEach(function (ev) {
                Object.defineProperty(me, 'on' + ev, {
                    get: function () {
                        return me._parser['on' + ev];
                    },
                    set: function (h) {
                        if (!h) {
                            me.removeAllListeners(ev);
                            me._parser['on' + ev] = h;
                            return h;
                        }
                        me.on(ev, h);
                    },
                    enumerable: true,
                    configurable: false
                });
            });
        }
        SAXStream.prototype = Object.create(Stream.prototype, {
            constructor: {
                value: SAXStream
            }
        });
        SAXStream.prototype.write = function (data) {
            if (typeof Buffer === 'function' &&
                typeof Buffer.isBuffer === 'function' &&
                Buffer.isBuffer(data)) {
                if (!this._decoder) {
                    var SD = require('string_decoder').StringDecoder;
                    this._decoder = new SD('utf8');
                }
                data = this._decoder.write(data);
            }
            this._parser.write(data.toString());
            this.emit('data', data);
            return true;
        };
        SAXStream.prototype.end = function (chunk) {
            if (chunk && chunk.length) {
                this.write(chunk);
            }
            this._parser.end();
            return true;
        };
        SAXStream.prototype.on = function (ev, handler) {
            var me = this;
            if (!me._parser['on' + ev] && streamWraps.indexOf(ev) !== -1) {
                me._parser['on' + ev] = function () {
                    var args = arguments.length === 1 ? [arguments[0]] : Array.apply(null, arguments);
                    args.splice(0, 0, ev);
                    me.emit.apply(me, args);
                };
            }
            return Stream.prototype.on.call(me, ev, handler);
        };
        // this really needs to be replaced with character classes.
        // XML allows all manner of ridiculous numbers and digits.
        var CDATA = '[CDATA[';
        var DOCTYPE = 'DOCTYPE';
        var XML_NAMESPACE = 'http://www.w3.org/XML/1998/namespace';
        var XMLNS_NAMESPACE = 'http://www.w3.org/2000/xmlns/';
        var rootNS = { xml: XML_NAMESPACE, xmlns: XMLNS_NAMESPACE };
        // http://www.w3.org/TR/REC-xml/#NT-NameStartChar
        // This implementation works on strings, a single character at a time
        // as such, it cannot ever support astral-plane characters (10000-EFFFF)
        // without a significant breaking change to either this  parser, or the
        // JavaScript language.  Implementation of an emoji-capable xml parser
        // is left as an exercise for the reader.
        var nameStart = /[:_A-Za-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD]/;
        var nameBody = /[:_A-Za-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD\u00B7\u0300-\u036F\u203F-\u2040.\d-]/;
        var entityStart = /[#:_A-Za-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD]/;
        var entityBody = /[#:_A-Za-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD\u00B7\u0300-\u036F\u203F-\u2040.\d-]/;
        function isWhitespace(c) {
            return c === ' ' || c === '\n' || c === '\r' || c === '\t';
        }
        function isQuote(c) {
            return c === '"' || c === '\'';
        }
        function isAttribEnd(c) {
            return c === '>' || isWhitespace(c);
        }
        function isMatch(regex, c) {
            return regex.test(c);
        }
        function notMatch(regex, c) {
            return !isMatch(regex, c);
        }
        var S = 0;
        sax.STATE = {
            BEGIN: S++, // leading byte order mark or whitespace
            BEGIN_WHITESPACE: S++, // leading whitespace
            TEXT: S++, // general stuff
            TEXT_ENTITY: S++, // &amp and such.
            OPEN_WAKA: S++, // <
            SGML_DECL: S++, // <!BLARG
            SGML_DECL_QUOTED: S++, // <!BLARG foo "bar
            DOCTYPE: S++, // <!DOCTYPE
            DOCTYPE_QUOTED: S++, // <!DOCTYPE "//blah
            DOCTYPE_DTD: S++, // <!DOCTYPE "//blah" [ ...
            DOCTYPE_DTD_QUOTED: S++, // <!DOCTYPE "//blah" [ "foo
            COMMENT_STARTING: S++, // <!-
            COMMENT: S++, // <!--
            COMMENT_ENDING: S++, // <!-- blah -
            COMMENT_ENDED: S++, // <!-- blah --
            CDATA: S++, // <![CDATA[ something
            CDATA_ENDING: S++, // ]
            CDATA_ENDING_2: S++, // ]]
            PROC_INST: S++, // <?hi
            PROC_INST_BODY: S++, // <?hi there
            PROC_INST_ENDING: S++, // <?hi "there" ?
            OPEN_TAG: S++, // <strong
            OPEN_TAG_SLASH: S++, // <strong /
            ATTRIB: S++, // <a
            ATTRIB_NAME: S++, // <a foo
            ATTRIB_NAME_SAW_WHITE: S++, // <a foo _
            ATTRIB_VALUE: S++, // <a foo=
            ATTRIB_VALUE_QUOTED: S++, // <a foo="bar
            ATTRIB_VALUE_CLOSED: S++, // <a foo="bar"
            ATTRIB_VALUE_UNQUOTED: S++, // <a foo=bar
            ATTRIB_VALUE_ENTITY_Q: S++, // <foo bar="&quot;"
            ATTRIB_VALUE_ENTITY_U: S++, // <foo bar=&quot
            CLOSE_TAG: S++, // </a
            CLOSE_TAG_SAW_WHITE: S++, // </a   >
            SCRIPT: S++, // <script> ...
            SCRIPT_ENDING: S++ // <script> ... <
        };
        sax.XML_ENTITIES = {
            'amp': '&',
            'gt': '>',
            'lt': '<',
            'quot': '"',
            'apos': "'"
        };
        sax.ENTITIES = {
            'amp': '&',
            'gt': '>',
            'lt': '<',
            'quot': '"',
            'apos': "'",
            'AElig': 198,
            'Aacute': 193,
            'Acirc': 194,
            'Agrave': 192,
            'Aring': 197,
            'Atilde': 195,
            'Auml': 196,
            'Ccedil': 199,
            'ETH': 208,
            'Eacute': 201,
            'Ecirc': 202,
            'Egrave': 200,
            'Euml': 203,
            'Iacute': 205,
            'Icirc': 206,
            'Igrave': 204,
            'Iuml': 207,
            'Ntilde': 209,
            'Oacute': 211,
            'Ocirc': 212,
            'Ograve': 210,
            'Oslash': 216,
            'Otilde': 213,
            'Ouml': 214,
            'THORN': 222,
            'Uacute': 218,
            'Ucirc': 219,
            'Ugrave': 217,
            'Uuml': 220,
            'Yacute': 221,
            'aacute': 225,
            'acirc': 226,
            'aelig': 230,
            'agrave': 224,
            'aring': 229,
            'atilde': 227,
            'auml': 228,
            'ccedil': 231,
            'eacute': 233,
            'ecirc': 234,
            'egrave': 232,
            'eth': 240,
            'euml': 235,
            'iacute': 237,
            'icirc': 238,
            'igrave': 236,
            'iuml': 239,
            'ntilde': 241,
            'oacute': 243,
            'ocirc': 244,
            'ograve': 242,
            'oslash': 248,
            'otilde': 245,
            'ouml': 246,
            'szlig': 223,
            'thorn': 254,
            'uacute': 250,
            'ucirc': 251,
            'ugrave': 249,
            'uuml': 252,
            'yacute': 253,
            'yuml': 255,
            'copy': 169,
            'reg': 174,
            'nbsp': 160,
            'iexcl': 161,
            'cent': 162,
            'pound': 163,
            'curren': 164,
            'yen': 165,
            'brvbar': 166,
            'sect': 167,
            'uml': 168,
            'ordf': 170,
            'laquo': 171,
            'not': 172,
            'shy': 173,
            'macr': 175,
            'deg': 176,
            'plusmn': 177,
            'sup1': 185,
            'sup2': 178,
            'sup3': 179,
            'acute': 180,
            'micro': 181,
            'para': 182,
            'middot': 183,
            'cedil': 184,
            'ordm': 186,
            'raquo': 187,
            'frac14': 188,
            'frac12': 189,
            'frac34': 190,
            'iquest': 191,
            'times': 215,
            'divide': 247,
            'OElig': 338,
            'oelig': 339,
            'Scaron': 352,
            'scaron': 353,
            'Yuml': 376,
            'fnof': 402,
            'circ': 710,
            'tilde': 732,
            'Alpha': 913,
            'Beta': 914,
            'Gamma': 915,
            'Delta': 916,
            'Epsilon': 917,
            'Zeta': 918,
            'Eta': 919,
            'Theta': 920,
            'Iota': 921,
            'Kappa': 922,
            'Lambda': 923,
            'Mu': 924,
            'Nu': 925,
            'Xi': 926,
            'Omicron': 927,
            'Pi': 928,
            'Rho': 929,
            'Sigma': 931,
            'Tau': 932,
            'Upsilon': 933,
            'Phi': 934,
            'Chi': 935,
            'Psi': 936,
            'Omega': 937,
            'alpha': 945,
            'beta': 946,
            'gamma': 947,
            'delta': 948,
            'epsilon': 949,
            'zeta': 950,
            'eta': 951,
            'theta': 952,
            'iota': 953,
            'kappa': 954,
            'lambda': 955,
            'mu': 956,
            'nu': 957,
            'xi': 958,
            'omicron': 959,
            'pi': 960,
            'rho': 961,
            'sigmaf': 962,
            'sigma': 963,
            'tau': 964,
            'upsilon': 965,
            'phi': 966,
            'chi': 967,
            'psi': 968,
            'omega': 969,
            'thetasym': 977,
            'upsih': 978,
            'piv': 982,
            'ensp': 8194,
            'emsp': 8195,
            'thinsp': 8201,
            'zwnj': 8204,
            'zwj': 8205,
            'lrm': 8206,
            'rlm': 8207,
            'ndash': 8211,
            'mdash': 8212,
            'lsquo': 8216,
            'rsquo': 8217,
            'sbquo': 8218,
            'ldquo': 8220,
            'rdquo': 8221,
            'bdquo': 8222,
            'dagger': 8224,
            'Dagger': 8225,
            'bull': 8226,
            'hellip': 8230,
            'permil': 8240,
            'prime': 8242,
            'Prime': 8243,
            'lsaquo': 8249,
            'rsaquo': 8250,
            'oline': 8254,
            'frasl': 8260,
            'euro': 8364,
            'image': 8465,
            'weierp': 8472,
            'real': 8476,
            'trade': 8482,
            'alefsym': 8501,
            'larr': 8592,
            'uarr': 8593,
            'rarr': 8594,
            'darr': 8595,
            'harr': 8596,
            'crarr': 8629,
            'lArr': 8656,
            'uArr': 8657,
            'rArr': 8658,
            'dArr': 8659,
            'hArr': 8660,
            'forall': 8704,
            'part': 8706,
            'exist': 8707,
            'empty': 8709,
            'nabla': 8711,
            'isin': 8712,
            'notin': 8713,
            'ni': 8715,
            'prod': 8719,
            'sum': 8721,
            'minus': 8722,
            'lowast': 8727,
            'radic': 8730,
            'prop': 8733,
            'infin': 8734,
            'ang': 8736,
            'and': 8743,
            'or': 8744,
            'cap': 8745,
            'cup': 8746,
            'int': 8747,
            'there4': 8756,
            'sim': 8764,
            'cong': 8773,
            'asymp': 8776,
            'ne': 8800,
            'equiv': 8801,
            'le': 8804,
            'ge': 8805,
            'sub': 8834,
            'sup': 8835,
            'nsub': 8836,
            'sube': 8838,
            'supe': 8839,
            'oplus': 8853,
            'otimes': 8855,
            'perp': 8869,
            'sdot': 8901,
            'lceil': 8968,
            'rceil': 8969,
            'lfloor': 8970,
            'rfloor': 8971,
            'lang': 9001,
            'rang': 9002,
            'loz': 9674,
            'spades': 9824,
            'clubs': 9827,
            'hearts': 9829,
            'diams': 9830
        };
        Object.keys(sax.ENTITIES).forEach(function (key) {
            var e = sax.ENTITIES[key];
            var s = typeof e === 'number' ? String.fromCharCode(e) : e;
            sax.ENTITIES[key] = s;
        });
        for (var s in sax.STATE) {
            sax.STATE[sax.STATE[s]] = s;
        }
        // shorthand
        S = sax.STATE;
        function emit(parser, event, data) {
            parser[event] && parser[event](data);
        }
        function emitNode(parser, nodeType, data) {
            if (parser.textNode)
                closeText(parser);
            emit(parser, nodeType, data);
        }
        function closeText(parser) {
            parser.textNode = textopts(parser.opt, parser.textNode);
            if (parser.textNode)
                emit(parser, 'ontext', parser.textNode);
            parser.textNode = '';
        }
        function textopts(opt, text) {
            if (opt.trim)
                text = text.trim();
            if (opt.normalize)
                text = text.replace(/\s+/g, ' ');
            return text;
        }
        function error(parser, er) {
            closeText(parser);
            if (parser.trackPosition) {
                er += '\nLine: ' + parser.line +
                    '\nColumn: ' + parser.column +
                    '\nChar: ' + parser.c;
            }
            er = new Error(er);
            parser.error = er;
            emit(parser, 'onerror', er);
            return parser;
        }
        function end(parser) {
            if (parser.sawRoot && !parser.closedRoot)
                strictFail(parser, 'Unclosed root tag');
            if ((parser.state !== S.BEGIN) &&
                (parser.state !== S.BEGIN_WHITESPACE) &&
                (parser.state !== S.TEXT)) {
                error(parser, 'Unexpected end');
            }
            closeText(parser);
            parser.c = '';
            parser.closed = true;
            emit(parser, 'onend');
            SAXParser.call(parser, parser.strict, parser.opt);
            return parser;
        }
        function strictFail(parser, message) {
            if (typeof parser !== 'object' || !(parser instanceof SAXParser)) {
                throw new Error('bad call to strictFail');
            }
            if (parser.strict) {
                error(parser, message);
            }
        }
        function newTag(parser) {
            if (!parser.strict)
                parser.tagName = parser.tagName[parser.looseCase]();
            var parent = parser.tags[parser.tags.length - 1] || parser;
            var tag = parser.tag = { name: parser.tagName, attributes: {} };
            // will be overridden if tag contails an xmlns="foo" or xmlns:foo="bar"
            if (parser.opt.xmlns) {
                tag.ns = parent.ns;
            }
            parser.attribList.length = 0;
            emitNode(parser, 'onopentagstart', tag);
        }
        function qname(name, attribute) {
            var i = name.indexOf(':');
            var qualName = i < 0 ? ['', name] : name.split(':');
            var prefix = qualName[0];
            var local = qualName[1];
            // <x "xmlns"="http://foo">
            if (attribute && name === 'xmlns') {
                prefix = 'xmlns';
                local = '';
            }
            return { prefix: prefix, local: local };
        }
        function attrib(parser) {
            if (!parser.strict) {
                parser.attribName = parser.attribName[parser.looseCase]();
            }
            if (parser.attribList.indexOf(parser.attribName) !== -1 ||
                parser.tag.attributes.hasOwnProperty(parser.attribName)) {
                parser.attribName = parser.attribValue = '';
                return;
            }
            if (parser.opt.xmlns) {
                var qn = qname(parser.attribName, true);
                var prefix = qn.prefix;
                var local = qn.local;
                if (prefix === 'xmlns') {
                    // namespace binding attribute. push the binding into scope
                    if (local === 'xml' && parser.attribValue !== XML_NAMESPACE) {
                        strictFail(parser, 'xml: prefix must be bound to ' + XML_NAMESPACE + '\n' +
                            'Actual: ' + parser.attribValue);
                    }
                    else if (local === 'xmlns' && parser.attribValue !== XMLNS_NAMESPACE) {
                        strictFail(parser, 'xmlns: prefix must be bound to ' + XMLNS_NAMESPACE + '\n' +
                            'Actual: ' + parser.attribValue);
                    }
                    else {
                        var tag = parser.tag;
                        var parent = parser.tags[parser.tags.length - 1] || parser;
                        if (tag.ns === parent.ns) {
                            tag.ns = Object.create(parent.ns);
                        }
                        tag.ns[local] = parser.attribValue;
                    }
                }
                // defer onattribute events until all attributes have been seen
                // so any new bindings can take effect. preserve attribute order
                // so deferred events can be emitted in document order
                parser.attribList.push([parser.attribName, parser.attribValue]);
            }
            else {
                // in non-xmlns mode, we can emit the event right away
                parser.tag.attributes[parser.attribName] = parser.attribValue;
                emitNode(parser, 'onattribute', {
                    name: parser.attribName,
                    value: parser.attribValue
                });
            }
            parser.attribName = parser.attribValue = '';
        }
        function openTag(parser, selfClosing) {
            if (parser.opt.xmlns) {
                // emit namespace binding events
                var tag = parser.tag;
                // add namespace info to tag
                var qn = qname(parser.tagName);
                tag.prefix = qn.prefix;
                tag.local = qn.local;
                tag.uri = tag.ns[qn.prefix] || '';
                if (tag.prefix && !tag.uri) {
                    strictFail(parser, 'Unbound namespace prefix: ' +
                        JSON.stringify(parser.tagName));
                    tag.uri = qn.prefix;
                }
                var parent = parser.tags[parser.tags.length - 1] || parser;
                if (tag.ns && parent.ns !== tag.ns) {
                    Object.keys(tag.ns).forEach(function (p) {
                        emitNode(parser, 'onopennamespace', {
                            prefix: p,
                            uri: tag.ns[p]
                        });
                    });
                }
                // handle deferred onattribute events
                // Note: do not apply default ns to attributes:
                //   http://www.w3.org/TR/REC-xml-names/#defaulting
                for (var i = 0, l = parser.attribList.length; i < l; i++) {
                    var nv = parser.attribList[i];
                    var name = nv[0];
                    var value = nv[1];
                    var qualName = qname(name, true);
                    var prefix = qualName.prefix;
                    var local = qualName.local;
                    var uri = prefix === '' ? '' : (tag.ns[prefix] || '');
                    var a = {
                        name: name,
                        value: value,
                        prefix: prefix,
                        local: local,
                        uri: uri
                    };
                    // if there's any attributes with an undefined namespace,
                    // then fail on them now.
                    if (prefix && prefix !== 'xmlns' && !uri) {
                        strictFail(parser, 'Unbound namespace prefix: ' +
                            JSON.stringify(prefix));
                        a.uri = prefix;
                    }
                    parser.tag.attributes[name] = a;
                    emitNode(parser, 'onattribute', a);
                }
                parser.attribList.length = 0;
            }
            parser.tag.isSelfClosing = !!selfClosing;
            // process the tag
            parser.sawRoot = true;
            parser.tags.push(parser.tag);
            emitNode(parser, 'onopentag', parser.tag);
            if (!selfClosing) {
                // special case for <script> in non-strict mode.
                if (!parser.noscript && parser.tagName.toLowerCase() === 'script') {
                    parser.state = S.SCRIPT;
                }
                else {
                    parser.state = S.TEXT;
                }
                parser.tag = null;
                parser.tagName = '';
            }
            parser.attribName = parser.attribValue = '';
            parser.attribList.length = 0;
        }
        function closeTag(parser) {
            if (!parser.tagName) {
                strictFail(parser, 'Weird empty close tag.');
                parser.textNode += '</>';
                parser.state = S.TEXT;
                return;
            }
            if (parser.script) {
                if (parser.tagName !== 'script') {
                    parser.script += '</' + parser.tagName + '>';
                    parser.tagName = '';
                    parser.state = S.SCRIPT;
                    return;
                }
                emitNode(parser, 'onscript', parser.script);
                parser.script = '';
            }
            // first make sure that the closing tag actually exists.
            // <a><b></c></b></a> will close everything, otherwise.
            var t = parser.tags.length;
            var tagName = parser.tagName;
            if (!parser.strict) {
                tagName = tagName[parser.looseCase]();
            }
            var closeTo = tagName;
            while (t--) {
                var close = parser.tags[t];
                if (close.name !== closeTo) {
                    // fail the first time in strict mode
                    strictFail(parser, 'Unexpected close tag');
                }
                else {
                    break;
                }
            }
            // didn't find it.  we already failed for strict, so just abort.
            if (t < 0) {
                strictFail(parser, 'Unmatched closing tag: ' + parser.tagName);
                parser.textNode += '</' + parser.tagName + '>';
                parser.state = S.TEXT;
                return;
            }
            parser.tagName = tagName;
            var s = parser.tags.length;
            while (s-- > t) {
                var tag = parser.tag = parser.tags.pop();
                parser.tagName = parser.tag.name;
                emitNode(parser, 'onclosetag', parser.tagName);
                var x = {};
                for (var i in tag.ns) {
                    x[i] = tag.ns[i];
                }
                var parent = parser.tags[parser.tags.length - 1] || parser;
                if (parser.opt.xmlns && tag.ns !== parent.ns) {
                    // remove namespace bindings introduced by tag
                    Object.keys(tag.ns).forEach(function (p) {
                        var n = tag.ns[p];
                        emitNode(parser, 'onclosenamespace', { prefix: p, uri: n });
                    });
                }
            }
            if (t === 0)
                parser.closedRoot = true;
            parser.tagName = parser.attribValue = parser.attribName = '';
            parser.attribList.length = 0;
            parser.state = S.TEXT;
        }
        function parseEntity(parser) {
            var entity = parser.entity;
            var entityLC = entity.toLowerCase();
            var num;
            var numStr = '';
            if (parser.ENTITIES[entity]) {
                return parser.ENTITIES[entity];
            }
            if (parser.ENTITIES[entityLC]) {
                return parser.ENTITIES[entityLC];
            }
            entity = entityLC;
            if (entity.charAt(0) === '#') {
                if (entity.charAt(1) === 'x') {
                    entity = entity.slice(2);
                    num = parseInt(entity, 16);
                    numStr = num.toString(16);
                }
                else {
                    entity = entity.slice(1);
                    num = parseInt(entity, 10);
                    numStr = num.toString(10);
                }
            }
            entity = entity.replace(/^0+/, '');
            if (isNaN(num) || numStr.toLowerCase() !== entity) {
                strictFail(parser, 'Invalid character entity');
                return '&' + parser.entity + ';';
            }
            return String.fromCodePoint(num);
        }
        function beginWhiteSpace(parser, c) {
            if (c === '<') {
                parser.state = S.OPEN_WAKA;
                parser.startTagPosition = parser.position;
            }
            else if (!isWhitespace(c)) {
                // have to process this as a text node.
                // weird, but happens.
                strictFail(parser, 'Non-whitespace before first tag.');
                parser.textNode = c;
                parser.state = S.TEXT;
            }
        }
        function charAt(chunk, i) {
            var result = '';
            if (i < chunk.length) {
                result = chunk.charAt(i);
            }
            return result;
        }
        function write(chunk) {
            var parser = this;
            if (this.error) {
                throw this.error;
            }
            if (parser.closed) {
                return error(parser, 'Cannot write after close. Assign an onready handler.');
            }
            if (chunk === null) {
                return end(parser);
            }
            if (typeof chunk === 'object') {
                chunk = chunk.toString();
            }
            var i = 0;
            var c = '';
            while (true) {
                c = charAt(chunk, i++);
                parser.c = c;
                if (!c) {
                    break;
                }
                if (parser.trackPosition) {
                    parser.position++;
                    if (c === '\n') {
                        parser.line++;
                        parser.column = 0;
                    }
                    else {
                        parser.column++;
                    }
                }
                switch (parser.state) {
                    case S.BEGIN:
                        parser.state = S.BEGIN_WHITESPACE;
                        if (c === '\uFEFF') {
                            continue;
                        }
                        beginWhiteSpace(parser, c);
                        continue;
                    case S.BEGIN_WHITESPACE:
                        beginWhiteSpace(parser, c);
                        continue;
                    case S.TEXT:
                        if (parser.sawRoot && !parser.closedRoot) {
                            var starti = i - 1;
                            while (c && c !== '<' && c !== '&') {
                                c = charAt(chunk, i++);
                                if (c && parser.trackPosition) {
                                    parser.position++;
                                    if (c === '\n') {
                                        parser.line++;
                                        parser.column = 0;
                                    }
                                    else {
                                        parser.column++;
                                    }
                                }
                            }
                            parser.textNode += chunk.substring(starti, i - 1);
                        }
                        if (c === '<' && !(parser.sawRoot && parser.closedRoot && !parser.strict)) {
                            parser.state = S.OPEN_WAKA;
                            parser.startTagPosition = parser.position;
                        }
                        else {
                            if (!isWhitespace(c) && (!parser.sawRoot || parser.closedRoot)) {
                                strictFail(parser, 'Text data outside of root node.');
                            }
                            if (c === '&') {
                                parser.state = S.TEXT_ENTITY;
                            }
                            else {
                                parser.textNode += c;
                            }
                        }
                        continue;
                    case S.SCRIPT:
                        // only non-strict
                        if (c === '<') {
                            parser.state = S.SCRIPT_ENDING;
                        }
                        else {
                            parser.script += c;
                        }
                        continue;
                    case S.SCRIPT_ENDING:
                        if (c === '/') {
                            parser.state = S.CLOSE_TAG;
                        }
                        else {
                            parser.script += '<' + c;
                            parser.state = S.SCRIPT;
                        }
                        continue;
                    case S.OPEN_WAKA:
                        // either a /, ?, !, or text is coming next.
                        if (c === '!') {
                            parser.state = S.SGML_DECL;
                            parser.sgmlDecl = '';
                        }
                        else if (isWhitespace(c)) {
                            // wait for it...
                        }
                        else if (isMatch(nameStart, c)) {
                            parser.state = S.OPEN_TAG;
                            parser.tagName = c;
                        }
                        else if (c === '/') {
                            parser.state = S.CLOSE_TAG;
                            parser.tagName = '';
                        }
                        else if (c === '?') {
                            parser.state = S.PROC_INST;
                            parser.procInstName = parser.procInstBody = '';
                        }
                        else {
                            strictFail(parser, 'Unencoded <');
                            // if there was some whitespace, then add that in.
                            if (parser.startTagPosition + 1 < parser.position) {
                                var pad = parser.position - parser.startTagPosition;
                                c = new Array(pad).join(' ') + c;
                            }
                            parser.textNode += '<' + c;
                            parser.state = S.TEXT;
                        }
                        continue;
                    case S.SGML_DECL:
                        if ((parser.sgmlDecl + c).toUpperCase() === CDATA) {
                            emitNode(parser, 'onopencdata');
                            parser.state = S.CDATA;
                            parser.sgmlDecl = '';
                            parser.cdata = '';
                        }
                        else if (parser.sgmlDecl + c === '--') {
                            parser.state = S.COMMENT;
                            parser.comment = '';
                            parser.sgmlDecl = '';
                        }
                        else if ((parser.sgmlDecl + c).toUpperCase() === DOCTYPE) {
                            parser.state = S.DOCTYPE;
                            if (parser.doctype || parser.sawRoot) {
                                strictFail(parser, 'Inappropriately located doctype declaration');
                            }
                            parser.doctype = '';
                            parser.sgmlDecl = '';
                        }
                        else if (c === '>') {
                            emitNode(parser, 'onsgmldeclaration', parser.sgmlDecl);
                            parser.sgmlDecl = '';
                            parser.state = S.TEXT;
                        }
                        else if (isQuote(c)) {
                            parser.state = S.SGML_DECL_QUOTED;
                            parser.sgmlDecl += c;
                        }
                        else {
                            parser.sgmlDecl += c;
                        }
                        continue;
                    case S.SGML_DECL_QUOTED:
                        if (c === parser.q) {
                            parser.state = S.SGML_DECL;
                            parser.q = '';
                        }
                        parser.sgmlDecl += c;
                        continue;
                    case S.DOCTYPE:
                        if (c === '>') {
                            parser.state = S.TEXT;
                            emitNode(parser, 'ondoctype', parser.doctype);
                            parser.doctype = true; // just remember that we saw it.
                        }
                        else {
                            parser.doctype += c;
                            if (c === '[') {
                                parser.state = S.DOCTYPE_DTD;
                            }
                            else if (isQuote(c)) {
                                parser.state = S.DOCTYPE_QUOTED;
                                parser.q = c;
                            }
                        }
                        continue;
                    case S.DOCTYPE_QUOTED:
                        parser.doctype += c;
                        if (c === parser.q) {
                            parser.q = '';
                            parser.state = S.DOCTYPE;
                        }
                        continue;
                    case S.DOCTYPE_DTD:
                        parser.doctype += c;
                        if (c === ']') {
                            parser.state = S.DOCTYPE;
                        }
                        else if (isQuote(c)) {
                            parser.state = S.DOCTYPE_DTD_QUOTED;
                            parser.q = c;
                        }
                        continue;
                    case S.DOCTYPE_DTD_QUOTED:
                        parser.doctype += c;
                        if (c === parser.q) {
                            parser.state = S.DOCTYPE_DTD;
                            parser.q = '';
                        }
                        continue;
                    case S.COMMENT:
                        if (c === '-') {
                            parser.state = S.COMMENT_ENDING;
                        }
                        else {
                            parser.comment += c;
                        }
                        continue;
                    case S.COMMENT_ENDING:
                        if (c === '-') {
                            parser.state = S.COMMENT_ENDED;
                            parser.comment = textopts(parser.opt, parser.comment);
                            if (parser.comment) {
                                emitNode(parser, 'oncomment', parser.comment);
                            }
                            parser.comment = '';
                        }
                        else {
                            parser.comment += '-' + c;
                            parser.state = S.COMMENT;
                        }
                        continue;
                    case S.COMMENT_ENDED:
                        if (c !== '>') {
                            strictFail(parser, 'Malformed comment');
                            // allow <!-- blah -- bloo --> in non-strict mode,
                            // which is a comment of " blah -- bloo "
                            parser.comment += '--' + c;
                            parser.state = S.COMMENT;
                        }
                        else {
                            parser.state = S.TEXT;
                        }
                        continue;
                    case S.CDATA:
                        if (c === ']') {
                            parser.state = S.CDATA_ENDING;
                        }
                        else {
                            parser.cdata += c;
                        }
                        continue;
                    case S.CDATA_ENDING:
                        if (c === ']') {
                            parser.state = S.CDATA_ENDING_2;
                        }
                        else {
                            parser.cdata += ']' + c;
                            parser.state = S.CDATA;
                        }
                        continue;
                    case S.CDATA_ENDING_2:
                        if (c === '>') {
                            if (parser.cdata) {
                                emitNode(parser, 'oncdata', parser.cdata);
                            }
                            emitNode(parser, 'onclosecdata');
                            parser.cdata = '';
                            parser.state = S.TEXT;
                        }
                        else if (c === ']') {
                            parser.cdata += ']';
                        }
                        else {
                            parser.cdata += ']]' + c;
                            parser.state = S.CDATA;
                        }
                        continue;
                    case S.PROC_INST:
                        if (c === '?') {
                            parser.state = S.PROC_INST_ENDING;
                        }
                        else if (isWhitespace(c)) {
                            parser.state = S.PROC_INST_BODY;
                        }
                        else {
                            parser.procInstName += c;
                        }
                        continue;
                    case S.PROC_INST_BODY:
                        if (!parser.procInstBody && isWhitespace(c)) {
                            continue;
                        }
                        else if (c === '?') {
                            parser.state = S.PROC_INST_ENDING;
                        }
                        else {
                            parser.procInstBody += c;
                        }
                        continue;
                    case S.PROC_INST_ENDING:
                        if (c === '>') {
                            emitNode(parser, 'onprocessinginstruction', {
                                name: parser.procInstName,
                                body: parser.procInstBody
                            });
                            parser.procInstName = parser.procInstBody = '';
                            parser.state = S.TEXT;
                        }
                        else {
                            parser.procInstBody += '?' + c;
                            parser.state = S.PROC_INST_BODY;
                        }
                        continue;
                    case S.OPEN_TAG:
                        if (isMatch(nameBody, c)) {
                            parser.tagName += c;
                        }
                        else {
                            newTag(parser);
                            if (c === '>') {
                                openTag(parser);
                            }
                            else if (c === '/') {
                                parser.state = S.OPEN_TAG_SLASH;
                            }
                            else {
                                if (!isWhitespace(c)) {
                                    strictFail(parser, 'Invalid character in tag name');
                                }
                                parser.state = S.ATTRIB;
                            }
                        }
                        continue;
                    case S.OPEN_TAG_SLASH:
                        if (c === '>') {
                            openTag(parser, true);
                            closeTag(parser);
                        }
                        else {
                            strictFail(parser, 'Forward-slash in opening tag not followed by >');
                            parser.state = S.ATTRIB;
                        }
                        continue;
                    case S.ATTRIB:
                        // haven't read the attribute name yet.
                        if (isWhitespace(c)) {
                            continue;
                        }
                        else if (c === '>') {
                            openTag(parser);
                        }
                        else if (c === '/') {
                            parser.state = S.OPEN_TAG_SLASH;
                        }
                        else if (isMatch(nameStart, c)) {
                            parser.attribName = c;
                            parser.attribValue = '';
                            parser.state = S.ATTRIB_NAME;
                        }
                        else {
                            strictFail(parser, 'Invalid attribute name');
                        }
                        continue;
                    case S.ATTRIB_NAME:
                        if (c === '=') {
                            parser.state = S.ATTRIB_VALUE;
                        }
                        else if (c === '>') {
                            strictFail(parser, 'Attribute without value');
                            parser.attribValue = parser.attribName;
                            attrib(parser);
                            openTag(parser);
                        }
                        else if (isWhitespace(c)) {
                            parser.state = S.ATTRIB_NAME_SAW_WHITE;
                        }
                        else if (isMatch(nameBody, c)) {
                            parser.attribName += c;
                        }
                        else {
                            strictFail(parser, 'Invalid attribute name');
                        }
                        continue;
                    case S.ATTRIB_NAME_SAW_WHITE:
                        if (c === '=') {
                            parser.state = S.ATTRIB_VALUE;
                        }
                        else if (isWhitespace(c)) {
                            continue;
                        }
                        else {
                            strictFail(parser, 'Attribute without value');
                            parser.tag.attributes[parser.attribName] = '';
                            parser.attribValue = '';
                            emitNode(parser, 'onattribute', {
                                name: parser.attribName,
                                value: ''
                            });
                            parser.attribName = '';
                            if (c === '>') {
                                openTag(parser);
                            }
                            else if (isMatch(nameStart, c)) {
                                parser.attribName = c;
                                parser.state = S.ATTRIB_NAME;
                            }
                            else {
                                strictFail(parser, 'Invalid attribute name');
                                parser.state = S.ATTRIB;
                            }
                        }
                        continue;
                    case S.ATTRIB_VALUE:
                        if (isWhitespace(c)) {
                            continue;
                        }
                        else if (isQuote(c)) {
                            parser.q = c;
                            parser.state = S.ATTRIB_VALUE_QUOTED;
                        }
                        else {
                            strictFail(parser, 'Unquoted attribute value');
                            parser.state = S.ATTRIB_VALUE_UNQUOTED;
                            parser.attribValue = c;
                        }
                        continue;
                    case S.ATTRIB_VALUE_QUOTED:
                        if (c !== parser.q) {
                            if (c === '&') {
                                parser.state = S.ATTRIB_VALUE_ENTITY_Q;
                            }
                            else {
                                parser.attribValue += c;
                            }
                            continue;
                        }
                        attrib(parser);
                        parser.q = '';
                        parser.state = S.ATTRIB_VALUE_CLOSED;
                        continue;
                    case S.ATTRIB_VALUE_CLOSED:
                        if (isWhitespace(c)) {
                            parser.state = S.ATTRIB;
                        }
                        else if (c === '>') {
                            openTag(parser);
                        }
                        else if (c === '/') {
                            parser.state = S.OPEN_TAG_SLASH;
                        }
                        else if (isMatch(nameStart, c)) {
                            strictFail(parser, 'No whitespace between attributes');
                            parser.attribName = c;
                            parser.attribValue = '';
                            parser.state = S.ATTRIB_NAME;
                        }
                        else {
                            strictFail(parser, 'Invalid attribute name');
                        }
                        continue;
                    case S.ATTRIB_VALUE_UNQUOTED:
                        if (!isAttribEnd(c)) {
                            if (c === '&') {
                                parser.state = S.ATTRIB_VALUE_ENTITY_U;
                            }
                            else {
                                parser.attribValue += c;
                            }
                            continue;
                        }
                        attrib(parser);
                        if (c === '>') {
                            openTag(parser);
                        }
                        else {
                            parser.state = S.ATTRIB;
                        }
                        continue;
                    case S.CLOSE_TAG:
                        if (!parser.tagName) {
                            if (isWhitespace(c)) {
                                continue;
                            }
                            else if (notMatch(nameStart, c)) {
                                if (parser.script) {
                                    parser.script += '</' + c;
                                    parser.state = S.SCRIPT;
                                }
                                else {
                                    strictFail(parser, 'Invalid tagname in closing tag.');
                                }
                            }
                            else {
                                parser.tagName = c;
                            }
                        }
                        else if (c === '>') {
                            closeTag(parser);
                        }
                        else if (isMatch(nameBody, c)) {
                            parser.tagName += c;
                        }
                        else if (parser.script) {
                            parser.script += '</' + parser.tagName;
                            parser.tagName = '';
                            parser.state = S.SCRIPT;
                        }
                        else {
                            if (!isWhitespace(c)) {
                                strictFail(parser, 'Invalid tagname in closing tag');
                            }
                            parser.state = S.CLOSE_TAG_SAW_WHITE;
                        }
                        continue;
                    case S.CLOSE_TAG_SAW_WHITE:
                        if (isWhitespace(c)) {
                            continue;
                        }
                        if (c === '>') {
                            closeTag(parser);
                        }
                        else {
                            strictFail(parser, 'Invalid characters in closing tag');
                        }
                        continue;
                    case S.TEXT_ENTITY:
                    case S.ATTRIB_VALUE_ENTITY_Q:
                    case S.ATTRIB_VALUE_ENTITY_U:
                        var returnState;
                        var buffer;
                        switch (parser.state) {
                            case S.TEXT_ENTITY:
                                returnState = S.TEXT;
                                buffer = 'textNode';
                                break;
                            case S.ATTRIB_VALUE_ENTITY_Q:
                                returnState = S.ATTRIB_VALUE_QUOTED;
                                buffer = 'attribValue';
                                break;
                            case S.ATTRIB_VALUE_ENTITY_U:
                                returnState = S.ATTRIB_VALUE_UNQUOTED;
                                buffer = 'attribValue';
                                break;
                        }
                        if (c === ';') {
                            if (parser.opt.unparsedEntities) {
                                var parsedEntity = parseEntity(parser);
                                parser.entity = '';
                                parser.state = returnState;
                                parser.write(parsedEntity);
                            }
                            else {
                                parser[buffer] += parseEntity(parser);
                                parser.entity = '';
                                parser.state = returnState;
                            }
                        }
                        else if (isMatch(parser.entity.length ? entityBody : entityStart, c)) {
                            parser.entity += c;
                        }
                        else {
                            strictFail(parser, 'Invalid character in entity name');
                            parser[buffer] += '&' + parser.entity + c;
                            parser.entity = '';
                            parser.state = returnState;
                        }
                        continue;
                    default: /* istanbul ignore next */ {
                        throw new Error(parser, 'Unknown state: ' + parser.state);
                    }
                }
            } // while
            if (parser.position >= parser.bufferCheckPosition) {
                checkBufferLength(parser);
            }
            return parser;
        }
        /*! http://mths.be/fromcodepoint v0.1.0 by @mathias */
        /* istanbul ignore next */
        if (!String.fromCodePoint) {
            (function () {
                var stringFromCharCode = String.fromCharCode;
                var floor = Math.floor;
                var fromCodePoint = function () {
                    var MAX_SIZE = 0x4000;
                    var codeUnits = [];
                    var highSurrogate;
                    var lowSurrogate;
                    var index = -1;
                    var length = arguments.length;
                    if (!length) {
                        return '';
                    }
                    var result = '';
                    while (++index < length) {
                        var codePoint = Number(arguments[index]);
                        if (!isFinite(codePoint) || // `NaN`, `+Infinity`, or `-Infinity`
                            codePoint < 0 || // not a valid Unicode code point
                            codePoint > 0x10FFFF || // not a valid Unicode code point
                            floor(codePoint) !== codePoint // not an integer
                        ) {
                            throw RangeError('Invalid code point: ' + codePoint);
                        }
                        if (codePoint <= 0xFFFF) { // BMP code point
                            codeUnits.push(codePoint);
                        }
                        else { // Astral code point; split in surrogate halves
                            // http://mathiasbynens.be/notes/javascript-encoding#surrogate-formulae
                            codePoint -= 0x10000;
                            highSurrogate = (codePoint >> 10) + 0xD800;
                            lowSurrogate = (codePoint % 0x400) + 0xDC00;
                            codeUnits.push(highSurrogate, lowSurrogate);
                        }
                        if (index + 1 === length || codeUnits.length > MAX_SIZE) {
                            result += stringFromCharCode.apply(null, codeUnits);
                            codeUnits.length = 0;
                        }
                    }
                    return result;
                };
                /* istanbul ignore next */
                if (Object.defineProperty) {
                    Object.defineProperty(String, 'fromCodePoint', {
                        value: fromCodePoint,
                        configurable: true,
                        writable: true
                    });
                }
                else {
                    String.fromCodePoint = fromCodePoint;
                }
            }());
        }
    })(typeof exports === 'undefined' ? this.sax = {} : exports);
},
/* needle/lib/decoder.js */ function _(require, module, exports, __esModule, __esExport) {
    var iconv, inherits = require('util').inherits, stream = require('stream');
    var regex = /(?:charset|encoding)\s*=\s*['"]? *([\w\-]+)/i;
    inherits(StreamDecoder, stream.Transform);
    function StreamDecoder(charset) {
        if (!(this instanceof StreamDecoder))
            return new StreamDecoder(charset);
        stream.Transform.call(this, charset);
        this.charset = charset;
        this.parsed_chunk = false;
    }
    StreamDecoder.prototype._transform = function (chunk, encoding, done) {
        // try to get charset from chunk, but just once
        if (!this.parsed_chunk && (this.charset == 'utf-8' || this.charset == 'utf8')) {
            this.parsed_chunk = true;
            var matches = regex.exec(chunk.toString());
            if (matches) {
                var found = matches[1].toLowerCase().replace('utf8', 'utf-8'); // canonicalize;
                // set charset, but only if iconv can handle it
                if (iconv.encodingExists(found))
                    this.charset = found;
            }
        }
        // if charset is already utf-8 or given encoding isn't supported, just pass through
        if (this.charset == 'utf-8' || !iconv.encodingExists(this.charset)) {
            this.push(chunk);
            return done();
        }
        // initialize stream decoder if not present
        var self = this;
        if (!this.decoder) {
            this.decoder = iconv.decodeStream(this.charset);
            this.decoder.on('data', function (decoded_chunk) {
                self.push(decoded_chunk);
            });
        }
        ;
        this.decoder.write(chunk);
        done();
    };
    module.exports = function (charset) {
        try {
            if (!iconv)
                iconv = require(84) /* iconv-lite */;
        }
        catch (e) {
            /* iconv not found */
        }
        if (iconv)
            return new StreamDecoder(charset);
        else
            return new stream.PassThrough;
    };
},
/* iconv-lite/lib/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // Some environments don't have global Buffer (e.g. React Native).
    // Solution would be installing npm modules "buffer" and "stream" explicitly.
    var Buffer = require(85) /* safer-buffer */.Buffer;
    var bomHandling = require(86) /* ./bom-handling */, iconv = module.exports;
    // All codecs and aliases are kept here, keyed by encoding name/alias.
    // They are lazy loaded in `iconv.getCodec` from `encodings/index.js`.
    iconv.encodings = null;
    // Characters emitted in case of error.
    iconv.defaultCharUnicode = '�';
    iconv.defaultCharSingleByte = '?';
    // Public API.
    iconv.encode = function encode(str, encoding, options) {
        str = "" + (str || ""); // Ensure string.
        var encoder = iconv.getEncoder(encoding, options);
        var res = encoder.write(str);
        var trail = encoder.end();
        return (trail && trail.length > 0) ? Buffer.concat([res, trail]) : res;
    };
    iconv.decode = function decode(buf, encoding, options) {
        if (typeof buf === 'string') {
            if (!iconv.skipDecodeWarning) {
                console.error('Iconv-lite warning: decode()-ing strings is deprecated. Refer to https://github.com/ashtuchkin/iconv-lite/wiki/Use-Buffers-when-decoding');
                iconv.skipDecodeWarning = true;
            }
            buf = Buffer.from("" + (buf || ""), "binary"); // Ensure buffer.
        }
        var decoder = iconv.getDecoder(encoding, options);
        var res = decoder.write(buf);
        var trail = decoder.end();
        return trail ? (res + trail) : res;
    };
    iconv.encodingExists = function encodingExists(enc) {
        try {
            iconv.getCodec(enc);
            return true;
        }
        catch (e) {
            return false;
        }
    };
    // Legacy aliases to convert functions
    iconv.toEncoding = iconv.encode;
    iconv.fromEncoding = iconv.decode;
    // Search for a codec in iconv.encodings. Cache codec data in iconv._codecDataCache.
    iconv._codecDataCache = {};
    iconv.getCodec = function getCodec(encoding) {
        if (!iconv.encodings)
            iconv.encodings = require(87) /* ../encodings */; // Lazy load all encoding definitions.
        // Canonicalize encoding name: strip all non-alphanumeric chars and appended year.
        var enc = iconv._canonicalizeEncoding(encoding);
        // Traverse iconv.encodings to find actual codec.
        var codecOptions = {};
        while (true) {
            var codec = iconv._codecDataCache[enc];
            if (codec)
                return codec;
            var codecDef = iconv.encodings[enc];
            switch (typeof codecDef) {
                case "string": // Direct alias to other encoding.
                    enc = codecDef;
                    break;
                case "object": // Alias with options. Can be layered.
                    for (var key in codecDef)
                        codecOptions[key] = codecDef[key];
                    if (!codecOptions.encodingName)
                        codecOptions.encodingName = enc;
                    enc = codecDef.type;
                    break;
                case "function": // Codec itself.
                    if (!codecOptions.encodingName)
                        codecOptions.encodingName = enc;
                    // The codec function must load all tables and return object with .encoder and .decoder methods.
                    // It'll be called only once (for each different options object).
                    codec = new codecDef(codecOptions, iconv);
                    iconv._codecDataCache[codecOptions.encodingName] = codec; // Save it to be reused later.
                    return codec;
                default:
                    throw new Error("Encoding not recognized: '" + encoding + "' (searched as: '" + enc + "')");
            }
        }
    };
    iconv._canonicalizeEncoding = function (encoding) {
        // Canonicalize encoding name: strip all non-alphanumeric chars and appended year.
        return ('' + encoding).toLowerCase().replace(/:\d{4}$|[^0-9a-z]/g, "");
    };
    iconv.getEncoder = function getEncoder(encoding, options) {
        var codec = iconv.getCodec(encoding), encoder = new codec.encoder(options, codec);
        if (codec.bomAware && options && options.addBOM)
            encoder = new bomHandling.PrependBOM(encoder, options);
        return encoder;
    };
    iconv.getDecoder = function getDecoder(encoding, options) {
        var codec = iconv.getCodec(encoding), decoder = new codec.decoder(options, codec);
        if (codec.bomAware && !(options && options.stripBOM === false))
            decoder = new bomHandling.StripBOM(decoder, options);
        return decoder;
    };
    // Load extensions in Node. All of them are omitted in Browserify build via 'browser' field in package.json.
    var nodeVer = typeof process !== 'undefined' && process.versions && process.versions.node;
    if (nodeVer) {
        // Load streaming support in Node v0.10+
        var nodeVerArr = nodeVer.split(".").map(Number);
        if (nodeVerArr[0] > 0 || nodeVerArr[1] >= 10) {
            require(104) /* ./streams */(iconv);
        }
        // Load Node primitive extensions.
        require(105) /* ./extend-node */(iconv);
    }
    if ("Ā" != "\u0100") {
        console.error("iconv-lite warning: javascript files use encoding different from utf-8. See https://github.com/ashtuchkin/iconv-lite/wiki/Javascript-source-file-encodings for more info.");
    }
},
/* safer-buffer/safer.js */ function _(require, module, exports, __esModule, __esExport) {/* eslint-disable node/no-deprecated-api */
    'use strict';
    var buffer = require('buffer');
    var Buffer = buffer.Buffer;
    var safer = {};
    var key;
    for (key in buffer) {
        if (!buffer.hasOwnProperty(key))
            continue;
        if (key === 'SlowBuffer' || key === 'Buffer')
            continue;
        safer[key] = buffer[key];
    }
    var Safer = safer.Buffer = {};
    for (key in Buffer) {
        if (!Buffer.hasOwnProperty(key))
            continue;
        if (key === 'allocUnsafe' || key === 'allocUnsafeSlow')
            continue;
        Safer[key] = Buffer[key];
    }
    safer.Buffer.prototype = Buffer.prototype;
    if (!Safer.from || Safer.from === Uint8Array.from) {
        Safer.from = function (value, encodingOrOffset, length) {
            if (typeof value === 'number') {
                throw new TypeError('The "value" argument must not be of type number. Received type ' + typeof value);
            }
            if (value && typeof value.length === 'undefined') {
                throw new TypeError('The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type ' + typeof value);
            }
            return Buffer(value, encodingOrOffset, length);
        };
    }
    if (!Safer.alloc) {
        Safer.alloc = function (size, fill, encoding) {
            if (typeof size !== 'number') {
                throw new TypeError('The "size" argument must be of type number. Received type ' + typeof size);
            }
            if (size < 0 || size >= 2 * (1 << 30)) {
                throw new RangeError('The value "' + size + '" is invalid for option "size"');
            }
            var buf = Buffer(size);
            if (!fill || fill.length === 0) {
                buf.fill(0);
            }
            else if (typeof encoding === 'string') {
                buf.fill(fill, encoding);
            }
            else {
                buf.fill(fill);
            }
            return buf;
        };
    }
    if (!safer.kStringMaxLength) {
        try {
            safer.kStringMaxLength = process.binding('buffer').kStringMaxLength;
        }
        catch (e) {
            // we can't determine kStringMaxLength in environments where process.binding
            // is unsupported, so let's not set it
        }
    }
    if (!safer.constants) {
        safer.constants = {
            MAX_LENGTH: safer.kMaxLength
        };
        if (safer.kStringMaxLength) {
            safer.constants.MAX_STRING_LENGTH = safer.kStringMaxLength;
        }
    }
    module.exports = safer;
},
/* iconv-lite/lib/bom-handling.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var BOMChar = '\uFEFF';
    exports.PrependBOM = PrependBOMWrapper;
    function PrependBOMWrapper(encoder, options) {
        this.encoder = encoder;
        this.addBOM = true;
    }
    PrependBOMWrapper.prototype.write = function (str) {
        if (this.addBOM) {
            str = BOMChar + str;
            this.addBOM = false;
        }
        return this.encoder.write(str);
    };
    PrependBOMWrapper.prototype.end = function () {
        return this.encoder.end();
    };
    //------------------------------------------------------------------------------
    exports.StripBOM = StripBOMWrapper;
    function StripBOMWrapper(decoder, options) {
        this.decoder = decoder;
        this.pass = false;
        this.options = options || {};
    }
    StripBOMWrapper.prototype.write = function (buf) {
        var res = this.decoder.write(buf);
        if (this.pass || !res)
            return res;
        if (res[0] === BOMChar) {
            res = res.slice(1);
            if (typeof this.options.stripBOM === 'function')
                this.options.stripBOM();
        }
        this.pass = true;
        return res;
    };
    StripBOMWrapper.prototype.end = function () {
        return this.decoder.end();
    };
},
/* iconv-lite/encodings/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // Update this array if you add/rename/remove files in this directory.
    // We support Browserify by skipping automatic module discovery and requiring modules directly.
    var modules = [
        require(88) /* ./internal */,
        require(89) /* ./utf16 */,
        require(90) /* ./utf7 */,
        require(91) /* ./sbcs-codec */,
        require(92) /* ./sbcs-data */,
        require(93) /* ./sbcs-data-generated */,
        require(94) /* ./dbcs-codec */,
        require(95) /* ./dbcs-data */,
    ];
    // Put all encoding/alias/codec definitions to single object and export it. 
    for (var i = 0; i < modules.length; i++) {
        var module = modules[i];
        for (var enc in module)
            if (Object.prototype.hasOwnProperty.call(module, enc))
                exports[enc] = module[enc];
    }
},
/* iconv-lite/encodings/internal.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var Buffer = require(85) /* safer-buffer */.Buffer;
    // Export Node.js internal encodings.
    module.exports = {
        // Encodings
        utf8: { type: "_internal", bomAware: true },
        cesu8: { type: "_internal", bomAware: true },
        unicode11utf8: "utf8",
        ucs2: { type: "_internal", bomAware: true },
        utf16le: "ucs2",
        binary: { type: "_internal" },
        base64: { type: "_internal" },
        hex: { type: "_internal" },
        // Codec.
        _internal: InternalCodec,
    };
    //------------------------------------------------------------------------------
    function InternalCodec(codecOptions, iconv) {
        this.enc = codecOptions.encodingName;
        this.bomAware = codecOptions.bomAware;
        if (this.enc === "base64")
            this.encoder = InternalEncoderBase64;
        else if (this.enc === "cesu8") {
            this.enc = "utf8"; // Use utf8 for decoding.
            this.encoder = InternalEncoderCesu8;
            // Add decoder for versions of Node not supporting CESU-8
            if (Buffer.from('eda0bdedb2a9', 'hex').toString() !== '💩') {
                this.decoder = InternalDecoderCesu8;
                this.defaultCharUnicode = iconv.defaultCharUnicode;
            }
        }
    }
    InternalCodec.prototype.encoder = InternalEncoder;
    InternalCodec.prototype.decoder = InternalDecoder;
    //------------------------------------------------------------------------------
    // We use node.js internal decoder. Its signature is the same as ours.
    var StringDecoder = require('string_decoder').StringDecoder;
    if (!StringDecoder.prototype.end) // Node v0.8 doesn't have this method.
        StringDecoder.prototype.end = function () { };
    function InternalDecoder(options, codec) {
        StringDecoder.call(this, codec.enc);
    }
    InternalDecoder.prototype = StringDecoder.prototype;
    //------------------------------------------------------------------------------
    // Encoder is mostly trivial
    function InternalEncoder(options, codec) {
        this.enc = codec.enc;
    }
    InternalEncoder.prototype.write = function (str) {
        return Buffer.from(str, this.enc);
    };
    InternalEncoder.prototype.end = function () {
    };
    //------------------------------------------------------------------------------
    // Except base64 encoder, which must keep its state.
    function InternalEncoderBase64(options, codec) {
        this.prevStr = '';
    }
    InternalEncoderBase64.prototype.write = function (str) {
        str = this.prevStr + str;
        var completeQuads = str.length - (str.length % 4);
        this.prevStr = str.slice(completeQuads);
        str = str.slice(0, completeQuads);
        return Buffer.from(str, "base64");
    };
    InternalEncoderBase64.prototype.end = function () {
        return Buffer.from(this.prevStr, "base64");
    };
    //------------------------------------------------------------------------------
    // CESU-8 encoder is also special.
    function InternalEncoderCesu8(options, codec) {
    }
    InternalEncoderCesu8.prototype.write = function (str) {
        var buf = Buffer.alloc(str.length * 3), bufIdx = 0;
        for (var i = 0; i < str.length; i++) {
            var charCode = str.charCodeAt(i);
            // Naive implementation, but it works because CESU-8 is especially easy
            // to convert from UTF-16 (which all JS strings are encoded in).
            if (charCode < 0x80)
                buf[bufIdx++] = charCode;
            else if (charCode < 0x800) {
                buf[bufIdx++] = 0xC0 + (charCode >>> 6);
                buf[bufIdx++] = 0x80 + (charCode & 0x3f);
            }
            else { // charCode will always be < 0x10000 in javascript.
                buf[bufIdx++] = 0xE0 + (charCode >>> 12);
                buf[bufIdx++] = 0x80 + ((charCode >>> 6) & 0x3f);
                buf[bufIdx++] = 0x80 + (charCode & 0x3f);
            }
        }
        return buf.slice(0, bufIdx);
    };
    InternalEncoderCesu8.prototype.end = function () {
    };
    //------------------------------------------------------------------------------
    // CESU-8 decoder is not implemented in Node v4.0+
    function InternalDecoderCesu8(options, codec) {
        this.acc = 0;
        this.contBytes = 0;
        this.accBytes = 0;
        this.defaultCharUnicode = codec.defaultCharUnicode;
    }
    InternalDecoderCesu8.prototype.write = function (buf) {
        var acc = this.acc, contBytes = this.contBytes, accBytes = this.accBytes, res = '';
        for (var i = 0; i < buf.length; i++) {
            var curByte = buf[i];
            if ((curByte & 0xC0) !== 0x80) { // Leading byte
                if (contBytes > 0) { // Previous code is invalid
                    res += this.defaultCharUnicode;
                    contBytes = 0;
                }
                if (curByte < 0x80) { // Single-byte code
                    res += String.fromCharCode(curByte);
                }
                else if (curByte < 0xE0) { // Two-byte code
                    acc = curByte & 0x1F;
                    contBytes = 1;
                    accBytes = 1;
                }
                else if (curByte < 0xF0) { // Three-byte code
                    acc = curByte & 0x0F;
                    contBytes = 2;
                    accBytes = 1;
                }
                else { // Four or more are not supported for CESU-8.
                    res += this.defaultCharUnicode;
                }
            }
            else { // Continuation byte
                if (contBytes > 0) { // We're waiting for it.
                    acc = (acc << 6) | (curByte & 0x3f);
                    contBytes--;
                    accBytes++;
                    if (contBytes === 0) {
                        // Check for overlong encoding, but support Modified UTF-8 (encoding NULL as C0 80)
                        if (accBytes === 2 && acc < 0x80 && acc > 0)
                            res += this.defaultCharUnicode;
                        else if (accBytes === 3 && acc < 0x800)
                            res += this.defaultCharUnicode;
                        else
                            // Actually add character.
                            res += String.fromCharCode(acc);
                    }
                }
                else { // Unexpected continuation byte
                    res += this.defaultCharUnicode;
                }
            }
        }
        this.acc = acc;
        this.contBytes = contBytes;
        this.accBytes = accBytes;
        return res;
    };
    InternalDecoderCesu8.prototype.end = function () {
        var res = 0;
        if (this.contBytes > 0)
            res += this.defaultCharUnicode;
        return res;
    };
},
/* iconv-lite/encodings/utf16.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var Buffer = require(85) /* safer-buffer */.Buffer;
    // Note: UTF16-LE (or UCS2) codec is Node.js native. See encodings/internal.js
    // == UTF16-BE codec. ==========================================================
    exports.utf16be = Utf16BECodec;
    function Utf16BECodec() {
    }
    Utf16BECodec.prototype.encoder = Utf16BEEncoder;
    Utf16BECodec.prototype.decoder = Utf16BEDecoder;
    Utf16BECodec.prototype.bomAware = true;
    // -- Encoding
    function Utf16BEEncoder() {
    }
    Utf16BEEncoder.prototype.write = function (str) {
        var buf = Buffer.from(str, 'ucs2');
        for (var i = 0; i < buf.length; i += 2) {
            var tmp = buf[i];
            buf[i] = buf[i + 1];
            buf[i + 1] = tmp;
        }
        return buf;
    };
    Utf16BEEncoder.prototype.end = function () {
    };
    // -- Decoding
    function Utf16BEDecoder() {
        this.overflowByte = -1;
    }
    Utf16BEDecoder.prototype.write = function (buf) {
        if (buf.length == 0)
            return '';
        var buf2 = Buffer.alloc(buf.length + 1), i = 0, j = 0;
        if (this.overflowByte !== -1) {
            buf2[0] = buf[0];
            buf2[1] = this.overflowByte;
            i = 1;
            j = 2;
        }
        for (; i < buf.length - 1; i += 2, j += 2) {
            buf2[j] = buf[i + 1];
            buf2[j + 1] = buf[i];
        }
        this.overflowByte = (i == buf.length - 1) ? buf[buf.length - 1] : -1;
        return buf2.slice(0, j).toString('ucs2');
    };
    Utf16BEDecoder.prototype.end = function () {
    };
    // == UTF-16 codec =============================================================
    // Decoder chooses automatically from UTF-16LE and UTF-16BE using BOM and space-based heuristic.
    // Defaults to UTF-16LE, as it's prevalent and default in Node.
    // http://en.wikipedia.org/wiki/UTF-16 and http://encoding.spec.whatwg.org/#utf-16le
    // Decoder default can be changed: iconv.decode(buf, 'utf16', {defaultEncoding: 'utf-16be'});
    // Encoder uses UTF-16LE and prepends BOM (which can be overridden with addBOM: false).
    exports.utf16 = Utf16Codec;
    function Utf16Codec(codecOptions, iconv) {
        this.iconv = iconv;
    }
    Utf16Codec.prototype.encoder = Utf16Encoder;
    Utf16Codec.prototype.decoder = Utf16Decoder;
    // -- Encoding (pass-through)
    function Utf16Encoder(options, codec) {
        options = options || {};
        if (options.addBOM === undefined)
            options.addBOM = true;
        this.encoder = codec.iconv.getEncoder('utf-16le', options);
    }
    Utf16Encoder.prototype.write = function (str) {
        return this.encoder.write(str);
    };
    Utf16Encoder.prototype.end = function () {
        return this.encoder.end();
    };
    // -- Decoding
    function Utf16Decoder(options, codec) {
        this.decoder = null;
        this.initialBytes = [];
        this.initialBytesLen = 0;
        this.options = options || {};
        this.iconv = codec.iconv;
    }
    Utf16Decoder.prototype.write = function (buf) {
        if (!this.decoder) {
            // Codec is not chosen yet. Accumulate initial bytes.
            this.initialBytes.push(buf);
            this.initialBytesLen += buf.length;
            if (this.initialBytesLen < 16) // We need more bytes to use space heuristic (see below)
                return '';
            // We have enough bytes -> detect endianness.
            var buf = Buffer.concat(this.initialBytes), encoding = detectEncoding(buf, this.options.defaultEncoding);
            this.decoder = this.iconv.getDecoder(encoding, this.options);
            this.initialBytes.length = this.initialBytesLen = 0;
        }
        return this.decoder.write(buf);
    };
    Utf16Decoder.prototype.end = function () {
        if (!this.decoder) {
            var buf = Buffer.concat(this.initialBytes), encoding = detectEncoding(buf, this.options.defaultEncoding);
            this.decoder = this.iconv.getDecoder(encoding, this.options);
            var res = this.decoder.write(buf), trail = this.decoder.end();
            return trail ? (res + trail) : res;
        }
        return this.decoder.end();
    };
    function detectEncoding(buf, defaultEncoding) {
        var enc = defaultEncoding || 'utf-16le';
        if (buf.length >= 2) {
            // Check BOM.
            if (buf[0] == 0xFE && buf[1] == 0xFF) // UTF-16BE BOM
                enc = 'utf-16be';
            else if (buf[0] == 0xFF && buf[1] == 0xFE) // UTF-16LE BOM
                enc = 'utf-16le';
            else {
                // No BOM found. Try to deduce encoding from initial content.
                // Most of the time, the content has ASCII chars (U+00**), but the opposite (U+**00) is uncommon.
                // So, we count ASCII as if it was LE or BE, and decide from that.
                var asciiCharsLE = 0, asciiCharsBE = 0, // Counts of chars in both positions
                _len = Math.min(buf.length - (buf.length % 2), 64); // Len is always even.
                for (var i = 0; i < _len; i += 2) {
                    if (buf[i] === 0 && buf[i + 1] !== 0)
                        asciiCharsBE++;
                    if (buf[i] !== 0 && buf[i + 1] === 0)
                        asciiCharsLE++;
                }
                if (asciiCharsBE > asciiCharsLE)
                    enc = 'utf-16be';
                else if (asciiCharsBE < asciiCharsLE)
                    enc = 'utf-16le';
            }
        }
        return enc;
    }
},
/* iconv-lite/encodings/utf7.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var Buffer = require(85) /* safer-buffer */.Buffer;
    // UTF-7 codec, according to https://tools.ietf.org/html/rfc2152
    // See also below a UTF-7-IMAP codec, according to http://tools.ietf.org/html/rfc3501#section-5.1.3
    exports.utf7 = Utf7Codec;
    exports.unicode11utf7 = 'utf7'; // Alias UNICODE-1-1-UTF-7
    function Utf7Codec(codecOptions, iconv) {
        this.iconv = iconv;
    }
    ;
    Utf7Codec.prototype.encoder = Utf7Encoder;
    Utf7Codec.prototype.decoder = Utf7Decoder;
    Utf7Codec.prototype.bomAware = true;
    // -- Encoding
    var nonDirectChars = /[^A-Za-z0-9'\(\),-\.\/:\? \n\r\t]+/g;
    function Utf7Encoder(options, codec) {
        this.iconv = codec.iconv;
    }
    Utf7Encoder.prototype.write = function (str) {
        // Naive implementation.
        // Non-direct chars are encoded as "+<base64>-"; single "+" char is encoded as "+-".
        return Buffer.from(str.replace(nonDirectChars, function (chunk) {
            return "+" + (chunk === '+' ? '' :
                this.iconv.encode(chunk, 'utf16-be').toString('base64').replace(/=+$/, ''))
                + "-";
        }.bind(this)));
    };
    Utf7Encoder.prototype.end = function () {
    };
    // -- Decoding
    function Utf7Decoder(options, codec) {
        this.iconv = codec.iconv;
        this.inBase64 = false;
        this.base64Accum = '';
    }
    var base64Regex = /[A-Za-z0-9\/+]/;
    var base64Chars = [];
    for (var i = 0; i < 256; i++)
        base64Chars[i] = base64Regex.test(String.fromCharCode(i));
    var plusChar = '+'.charCodeAt(0), minusChar = '-'.charCodeAt(0), andChar = '&'.charCodeAt(0);
    Utf7Decoder.prototype.write = function (buf) {
        var res = "", lastI = 0, inBase64 = this.inBase64, base64Accum = this.base64Accum;
        // The decoder is more involved as we must handle chunks in stream.
        for (var i = 0; i < buf.length; i++) {
            if (!inBase64) { // We're in direct mode.
                // Write direct chars until '+'
                if (buf[i] == plusChar) {
                    res += this.iconv.decode(buf.slice(lastI, i), "ascii"); // Write direct chars.
                    lastI = i + 1;
                    inBase64 = true;
                }
            }
            else { // We decode base64.
                if (!base64Chars[buf[i]]) { // Base64 ended.
                    if (i == lastI && buf[i] == minusChar) { // "+-" -> "+"
                        res += "+";
                    }
                    else {
                        var b64str = base64Accum + buf.slice(lastI, i).toString();
                        res += this.iconv.decode(Buffer.from(b64str, 'base64'), "utf16-be");
                    }
                    if (buf[i] != minusChar) // Minus is absorbed after base64.
                        i--;
                    lastI = i + 1;
                    inBase64 = false;
                    base64Accum = '';
                }
            }
        }
        if (!inBase64) {
            res += this.iconv.decode(buf.slice(lastI), "ascii"); // Write direct chars.
        }
        else {
            var b64str = base64Accum + buf.slice(lastI).toString();
            var canBeDecoded = b64str.length - (b64str.length % 8); // Minimal chunk: 2 quads -> 2x3 bytes -> 3 chars.
            base64Accum = b64str.slice(canBeDecoded); // The rest will be decoded in future.
            b64str = b64str.slice(0, canBeDecoded);
            res += this.iconv.decode(Buffer.from(b64str, 'base64'), "utf16-be");
        }
        this.inBase64 = inBase64;
        this.base64Accum = base64Accum;
        return res;
    };
    Utf7Decoder.prototype.end = function () {
        var res = "";
        if (this.inBase64 && this.base64Accum.length > 0)
            res = this.iconv.decode(Buffer.from(this.base64Accum, 'base64'), "utf16-be");
        this.inBase64 = false;
        this.base64Accum = '';
        return res;
    };
    // UTF-7-IMAP codec.
    // RFC3501 Sec. 5.1.3 Modified UTF-7 (http://tools.ietf.org/html/rfc3501#section-5.1.3)
    // Differences:
    //  * Base64 part is started by "&" instead of "+"
    //  * Direct characters are 0x20-0x7E, except "&" (0x26)
    //  * In Base64, "," is used instead of "/"
    //  * Base64 must not be used to represent direct characters.
    //  * No implicit shift back from Base64 (should always end with '-')
    //  * String must end in non-shifted position.
    //  * "-&" while in base64 is not allowed.
    exports.utf7imap = Utf7IMAPCodec;
    function Utf7IMAPCodec(codecOptions, iconv) {
        this.iconv = iconv;
    }
    ;
    Utf7IMAPCodec.prototype.encoder = Utf7IMAPEncoder;
    Utf7IMAPCodec.prototype.decoder = Utf7IMAPDecoder;
    Utf7IMAPCodec.prototype.bomAware = true;
    // -- Encoding
    function Utf7IMAPEncoder(options, codec) {
        this.iconv = codec.iconv;
        this.inBase64 = false;
        this.base64Accum = Buffer.alloc(6);
        this.base64AccumIdx = 0;
    }
    Utf7IMAPEncoder.prototype.write = function (str) {
        var inBase64 = this.inBase64, base64Accum = this.base64Accum, base64AccumIdx = this.base64AccumIdx, buf = Buffer.alloc(str.length * 5 + 10), bufIdx = 0;
        for (var i = 0; i < str.length; i++) {
            var uChar = str.charCodeAt(i);
            if (0x20 <= uChar && uChar <= 0x7E) { // Direct character or '&'.
                if (inBase64) {
                    if (base64AccumIdx > 0) {
                        bufIdx += buf.write(base64Accum.slice(0, base64AccumIdx).toString('base64').replace(/\//g, ',').replace(/=+$/, ''), bufIdx);
                        base64AccumIdx = 0;
                    }
                    buf[bufIdx++] = minusChar; // Write '-', then go to direct mode.
                    inBase64 = false;
                }
                if (!inBase64) {
                    buf[bufIdx++] = uChar; // Write direct character
                    if (uChar === andChar) // Ampersand -> '&-'
                        buf[bufIdx++] = minusChar;
                }
            }
            else { // Non-direct character
                if (!inBase64) {
                    buf[bufIdx++] = andChar; // Write '&', then go to base64 mode.
                    inBase64 = true;
                }
                if (inBase64) {
                    base64Accum[base64AccumIdx++] = uChar >> 8;
                    base64Accum[base64AccumIdx++] = uChar & 0xFF;
                    if (base64AccumIdx == base64Accum.length) {
                        bufIdx += buf.write(base64Accum.toString('base64').replace(/\//g, ','), bufIdx);
                        base64AccumIdx = 0;
                    }
                }
            }
        }
        this.inBase64 = inBase64;
        this.base64AccumIdx = base64AccumIdx;
        return buf.slice(0, bufIdx);
    };
    Utf7IMAPEncoder.prototype.end = function () {
        var buf = Buffer.alloc(10), bufIdx = 0;
        if (this.inBase64) {
            if (this.base64AccumIdx > 0) {
                bufIdx += buf.write(this.base64Accum.slice(0, this.base64AccumIdx).toString('base64').replace(/\//g, ',').replace(/=+$/, ''), bufIdx);
                this.base64AccumIdx = 0;
            }
            buf[bufIdx++] = minusChar; // Write '-', then go to direct mode.
            this.inBase64 = false;
        }
        return buf.slice(0, bufIdx);
    };
    // -- Decoding
    function Utf7IMAPDecoder(options, codec) {
        this.iconv = codec.iconv;
        this.inBase64 = false;
        this.base64Accum = '';
    }
    var base64IMAPChars = base64Chars.slice();
    base64IMAPChars[','.charCodeAt(0)] = true;
    Utf7IMAPDecoder.prototype.write = function (buf) {
        var res = "", lastI = 0, inBase64 = this.inBase64, base64Accum = this.base64Accum;
        // The decoder is more involved as we must handle chunks in stream.
        // It is forgiving, closer to standard UTF-7 (for example, '-' is optional at the end).
        for (var i = 0; i < buf.length; i++) {
            if (!inBase64) { // We're in direct mode.
                // Write direct chars until '&'
                if (buf[i] == andChar) {
                    res += this.iconv.decode(buf.slice(lastI, i), "ascii"); // Write direct chars.
                    lastI = i + 1;
                    inBase64 = true;
                }
            }
            else { // We decode base64.
                if (!base64IMAPChars[buf[i]]) { // Base64 ended.
                    if (i == lastI && buf[i] == minusChar) { // "&-" -> "&"
                        res += "&";
                    }
                    else {
                        var b64str = base64Accum + buf.slice(lastI, i).toString().replace(/,/g, '/');
                        res += this.iconv.decode(Buffer.from(b64str, 'base64'), "utf16-be");
                    }
                    if (buf[i] != minusChar) // Minus may be absorbed after base64.
                        i--;
                    lastI = i + 1;
                    inBase64 = false;
                    base64Accum = '';
                }
            }
        }
        if (!inBase64) {
            res += this.iconv.decode(buf.slice(lastI), "ascii"); // Write direct chars.
        }
        else {
            var b64str = base64Accum + buf.slice(lastI).toString().replace(/,/g, '/');
            var canBeDecoded = b64str.length - (b64str.length % 8); // Minimal chunk: 2 quads -> 2x3 bytes -> 3 chars.
            base64Accum = b64str.slice(canBeDecoded); // The rest will be decoded in future.
            b64str = b64str.slice(0, canBeDecoded);
            res += this.iconv.decode(Buffer.from(b64str, 'base64'), "utf16-be");
        }
        this.inBase64 = inBase64;
        this.base64Accum = base64Accum;
        return res;
    };
    Utf7IMAPDecoder.prototype.end = function () {
        var res = "";
        if (this.inBase64 && this.base64Accum.length > 0)
            res = this.iconv.decode(Buffer.from(this.base64Accum, 'base64'), "utf16-be");
        this.inBase64 = false;
        this.base64Accum = '';
        return res;
    };
},
/* iconv-lite/encodings/sbcs-codec.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var Buffer = require(85) /* safer-buffer */.Buffer;
    // Single-byte codec. Needs a 'chars' string parameter that contains 256 or 128 chars that
    // correspond to encoded bytes (if 128 - then lower half is ASCII). 
    exports._sbcs = SBCSCodec;
    function SBCSCodec(codecOptions, iconv) {
        if (!codecOptions)
            throw new Error("SBCS codec is called without the data.");
        // Prepare char buffer for decoding.
        if (!codecOptions.chars || (codecOptions.chars.length !== 128 && codecOptions.chars.length !== 256))
            throw new Error("Encoding '" + codecOptions.type + "' has incorrect 'chars' (must be of len 128 or 256)");
        if (codecOptions.chars.length === 128) {
            var asciiString = "";
            for (var i = 0; i < 128; i++)
                asciiString += String.fromCharCode(i);
            codecOptions.chars = asciiString + codecOptions.chars;
        }
        this.decodeBuf = Buffer.from(codecOptions.chars, 'ucs2');
        // Encoding buffer.
        var encodeBuf = Buffer.alloc(65536, iconv.defaultCharSingleByte.charCodeAt(0));
        for (var i = 0; i < codecOptions.chars.length; i++)
            encodeBuf[codecOptions.chars.charCodeAt(i)] = i;
        this.encodeBuf = encodeBuf;
    }
    SBCSCodec.prototype.encoder = SBCSEncoder;
    SBCSCodec.prototype.decoder = SBCSDecoder;
    function SBCSEncoder(options, codec) {
        this.encodeBuf = codec.encodeBuf;
    }
    SBCSEncoder.prototype.write = function (str) {
        var buf = Buffer.alloc(str.length);
        for (var i = 0; i < str.length; i++)
            buf[i] = this.encodeBuf[str.charCodeAt(i)];
        return buf;
    };
    SBCSEncoder.prototype.end = function () {
    };
    function SBCSDecoder(options, codec) {
        this.decodeBuf = codec.decodeBuf;
    }
    SBCSDecoder.prototype.write = function (buf) {
        // Strings are immutable in JS -> we use ucs2 buffer to speed up computations.
        var decodeBuf = this.decodeBuf;
        var newBuf = Buffer.alloc(buf.length * 2);
        var idx1 = 0, idx2 = 0;
        for (var i = 0; i < buf.length; i++) {
            idx1 = buf[i] * 2;
            idx2 = i * 2;
            newBuf[idx2] = decodeBuf[idx1];
            newBuf[idx2 + 1] = decodeBuf[idx1 + 1];
        }
        return newBuf.toString('ucs2');
    };
    SBCSDecoder.prototype.end = function () {
    };
},
/* iconv-lite/encodings/sbcs-data.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // Manually added data to be used by sbcs codec in addition to generated one.
    module.exports = {
        // Not supported by iconv, not sure why.
        "10029": "maccenteuro",
        "maccenteuro": {
            "type": "_sbcs",
            "chars": "ÄĀāÉĄÖÜáąČäčĆćéŹźĎíďĒēĖóėôöõúĚěü†°Ę£§•¶ß®©™ę¨≠ģĮįĪ≤≥īĶ∂∑łĻļĽľĹĺŅņŃ¬√ńŇ∆«»… ňŐÕőŌ–—“”‘’÷◊ōŔŕŘ‹›řŖŗŠ‚„šŚśÁŤťÍŽžŪÓÔūŮÚůŰűŲųÝýķŻŁżĢˇ"
        },
        "808": "cp808",
        "ibm808": "cp808",
        "cp808": {
            "type": "_sbcs",
            "chars": "АБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмноп░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀рстуфхцчшщъыьэюяЁёЄєЇїЎў°∙·√№€■ "
        },
        "mik": {
            "type": "_sbcs",
            "chars": "АБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмнопрстуфхцчшщъыьэюя└┴┬├─┼╣║╚╔╩╦╠═╬┐░▒▓│┤№§╗╝┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞φε∩≡±≥≤⌠⌡÷≈°∙·√ⁿ²■ "
        },
        // Aliases of generated encodings.
        "ascii8bit": "ascii",
        "usascii": "ascii",
        "ansix34": "ascii",
        "ansix341968": "ascii",
        "ansix341986": "ascii",
        "csascii": "ascii",
        "cp367": "ascii",
        "ibm367": "ascii",
        "isoir6": "ascii",
        "iso646us": "ascii",
        "iso646irv": "ascii",
        "us": "ascii",
        "latin1": "iso88591",
        "latin2": "iso88592",
        "latin3": "iso88593",
        "latin4": "iso88594",
        "latin5": "iso88599",
        "latin6": "iso885910",
        "latin7": "iso885913",
        "latin8": "iso885914",
        "latin9": "iso885915",
        "latin10": "iso885916",
        "csisolatin1": "iso88591",
        "csisolatin2": "iso88592",
        "csisolatin3": "iso88593",
        "csisolatin4": "iso88594",
        "csisolatincyrillic": "iso88595",
        "csisolatinarabic": "iso88596",
        "csisolatingreek": "iso88597",
        "csisolatinhebrew": "iso88598",
        "csisolatin5": "iso88599",
        "csisolatin6": "iso885910",
        "l1": "iso88591",
        "l2": "iso88592",
        "l3": "iso88593",
        "l4": "iso88594",
        "l5": "iso88599",
        "l6": "iso885910",
        "l7": "iso885913",
        "l8": "iso885914",
        "l9": "iso885915",
        "l10": "iso885916",
        "isoir14": "iso646jp",
        "isoir57": "iso646cn",
        "isoir100": "iso88591",
        "isoir101": "iso88592",
        "isoir109": "iso88593",
        "isoir110": "iso88594",
        "isoir144": "iso88595",
        "isoir127": "iso88596",
        "isoir126": "iso88597",
        "isoir138": "iso88598",
        "isoir148": "iso88599",
        "isoir157": "iso885910",
        "isoir166": "tis620",
        "isoir179": "iso885913",
        "isoir199": "iso885914",
        "isoir203": "iso885915",
        "isoir226": "iso885916",
        "cp819": "iso88591",
        "ibm819": "iso88591",
        "cyrillic": "iso88595",
        "arabic": "iso88596",
        "arabic8": "iso88596",
        "ecma114": "iso88596",
        "asmo708": "iso88596",
        "greek": "iso88597",
        "greek8": "iso88597",
        "ecma118": "iso88597",
        "elot928": "iso88597",
        "hebrew": "iso88598",
        "hebrew8": "iso88598",
        "turkish": "iso88599",
        "turkish8": "iso88599",
        "thai": "iso885911",
        "thai8": "iso885911",
        "celtic": "iso885914",
        "celtic8": "iso885914",
        "isoceltic": "iso885914",
        "tis6200": "tis620",
        "tis62025291": "tis620",
        "tis62025330": "tis620",
        "10000": "macroman",
        "10006": "macgreek",
        "10007": "maccyrillic",
        "10079": "maciceland",
        "10081": "macturkish",
        "cspc8codepage437": "cp437",
        "cspc775baltic": "cp775",
        "cspc850multilingual": "cp850",
        "cspcp852": "cp852",
        "cspc862latinhebrew": "cp862",
        "cpgr": "cp869",
        "msee": "cp1250",
        "mscyrl": "cp1251",
        "msansi": "cp1252",
        "msgreek": "cp1253",
        "msturk": "cp1254",
        "mshebr": "cp1255",
        "msarab": "cp1256",
        "winbaltrim": "cp1257",
        "cp20866": "koi8r",
        "20866": "koi8r",
        "ibm878": "koi8r",
        "cskoi8r": "koi8r",
        "cp21866": "koi8u",
        "21866": "koi8u",
        "ibm1168": "koi8u",
        "strk10482002": "rk1048",
        "tcvn5712": "tcvn",
        "tcvn57121": "tcvn",
        "gb198880": "iso646cn",
        "cn": "iso646cn",
        "csiso14jisc6220ro": "iso646jp",
        "jisc62201969ro": "iso646jp",
        "jp": "iso646jp",
        "cshproman8": "hproman8",
        "r8": "hproman8",
        "roman8": "hproman8",
        "xroman8": "hproman8",
        "ibm1051": "hproman8",
        "mac": "macintosh",
        "csmacintosh": "macintosh",
    };
},
/* iconv-lite/encodings/sbcs-data-generated.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // Generated data for sbcs codec. Don't edit manually. Regenerate using generation/gen-sbcs.js script.
    module.exports = {
        "437": "cp437",
        "737": "cp737",
        "775": "cp775",
        "850": "cp850",
        "852": "cp852",
        "855": "cp855",
        "856": "cp856",
        "857": "cp857",
        "858": "cp858",
        "860": "cp860",
        "861": "cp861",
        "862": "cp862",
        "863": "cp863",
        "864": "cp864",
        "865": "cp865",
        "866": "cp866",
        "869": "cp869",
        "874": "windows874",
        "922": "cp922",
        "1046": "cp1046",
        "1124": "cp1124",
        "1125": "cp1125",
        "1129": "cp1129",
        "1133": "cp1133",
        "1161": "cp1161",
        "1162": "cp1162",
        "1163": "cp1163",
        "1250": "windows1250",
        "1251": "windows1251",
        "1252": "windows1252",
        "1253": "windows1253",
        "1254": "windows1254",
        "1255": "windows1255",
        "1256": "windows1256",
        "1257": "windows1257",
        "1258": "windows1258",
        "28591": "iso88591",
        "28592": "iso88592",
        "28593": "iso88593",
        "28594": "iso88594",
        "28595": "iso88595",
        "28596": "iso88596",
        "28597": "iso88597",
        "28598": "iso88598",
        "28599": "iso88599",
        "28600": "iso885910",
        "28601": "iso885911",
        "28603": "iso885913",
        "28604": "iso885914",
        "28605": "iso885915",
        "28606": "iso885916",
        "windows874": {
            "type": "_sbcs",
            "chars": "€����…�����������‘’“”•–—�������� กขฃคฅฆงจฉชซฌญฎฏฐฑฒณดตถทธนบปผฝพฟภมยรฤลฦวศษสหฬอฮฯะัาำิีึืฺุู����฿เแโใไๅๆ็่้๊๋์ํ๎๏๐๑๒๓๔๕๖๗๘๙๚๛����"
        },
        "win874": "windows874",
        "cp874": "windows874",
        "windows1250": {
            "type": "_sbcs",
            "chars": "€�‚�„…†‡�‰Š‹ŚŤŽŹ�‘’“”•–—�™š›śťžź ˇ˘Ł¤Ą¦§¨©Ş«¬­®Ż°±˛ł´µ¶·¸ąş»Ľ˝ľżŔÁÂĂÄĹĆÇČÉĘËĚÍÎĎĐŃŇÓÔŐÖ×ŘŮÚŰÜÝŢßŕáâăäĺćçčéęëěíîďđńňóôőö÷řůúűüýţ˙"
        },
        "win1250": "windows1250",
        "cp1250": "windows1250",
        "windows1251": {
            "type": "_sbcs",
            "chars": "ЂЃ‚ѓ„…†‡€‰Љ‹ЊЌЋЏђ‘’“”•–—�™љ›њќћџ ЎўЈ¤Ґ¦§Ё©Є«¬­®Ї°±Ііґµ¶·ё№є»јЅѕїАБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмнопрстуфхцчшщъыьэюя"
        },
        "win1251": "windows1251",
        "cp1251": "windows1251",
        "windows1252": {
            "type": "_sbcs",
            "chars": "€�‚ƒ„…†‡ˆ‰Š‹Œ�Ž��‘’“”•–—˜™š›œ�žŸ ¡¢£¤¥¦§¨©ª«¬­®¯°±²³´µ¶·¸¹º»¼½¾¿ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏÐÑÒÓÔÕÖ×ØÙÚÛÜÝÞßàáâãäåæçèéêëìíîïðñòóôõö÷øùúûüýþÿ"
        },
        "win1252": "windows1252",
        "cp1252": "windows1252",
        "windows1253": {
            "type": "_sbcs",
            "chars": "€�‚ƒ„…†‡�‰�‹�����‘’“”•–—�™�›���� ΅Ά£¤¥¦§¨©�«¬­®―°±²³΄µ¶·ΈΉΊ»Ό½ΎΏΐΑΒΓΔΕΖΗΘΙΚΛΜΝΞΟΠΡ�ΣΤΥΦΧΨΩΪΫάέήίΰαβγδεζηθικλμνξοπρςστυφχψωϊϋόύώ�"
        },
        "win1253": "windows1253",
        "cp1253": "windows1253",
        "windows1254": {
            "type": "_sbcs",
            "chars": "€�‚ƒ„…†‡ˆ‰Š‹Œ����‘’“”•–—˜™š›œ��Ÿ ¡¢£¤¥¦§¨©ª«¬­®¯°±²³´µ¶·¸¹º»¼½¾¿ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏĞÑÒÓÔÕÖ×ØÙÚÛÜİŞßàáâãäåæçèéêëìíîïğñòóôõö÷øùúûüışÿ"
        },
        "win1254": "windows1254",
        "cp1254": "windows1254",
        "windows1255": {
            "type": "_sbcs",
            "chars": "€�‚ƒ„…†‡ˆ‰�‹�����‘’“”•–—˜™�›���� ¡¢£₪¥¦§¨©×«¬­®¯°±²³´µ¶·¸¹÷»¼½¾¿ְֱֲֳִֵֶַָֹֺֻּֽ־ֿ׀ׁׂ׃װױײ׳״�������אבגדהוזחטיךכלםמןנסעףפץצקרשת��‎‏�"
        },
        "win1255": "windows1255",
        "cp1255": "windows1255",
        "windows1256": {
            "type": "_sbcs",
            "chars": "€پ‚ƒ„…†‡ˆ‰ٹ‹Œچژڈگ‘’“”•–—ک™ڑ›œ‌‍ں ،¢£¤¥¦§¨©ھ«¬­®¯°±²³´µ¶·¸¹؛»¼½¾؟ہءآأؤإئابةتثجحخدذرزسشصض×طظعغـفقكàلâمنهوçèéêëىيîïًٌٍَôُِ÷ّùْûü‎‏ے"
        },
        "win1256": "windows1256",
        "cp1256": "windows1256",
        "windows1257": {
            "type": "_sbcs",
            "chars": "€�‚�„…†‡�‰�‹�¨ˇ¸�‘’“”•–—�™�›�¯˛� �¢£¤�¦§Ø©Ŗ«¬­®Æ°±²³´µ¶·ø¹ŗ»¼½¾æĄĮĀĆÄÅĘĒČÉŹĖĢĶĪĻŠŃŅÓŌÕÖ×ŲŁŚŪÜŻŽßąįāćäåęēčéźėģķīļšńņóōõö÷ųłśūüżž˙"
        },
        "win1257": "windows1257",
        "cp1257": "windows1257",
        "windows1258": {
            "type": "_sbcs",
            "chars": "€�‚ƒ„…†‡ˆ‰�‹Œ����‘’“”•–—˜™�›œ��Ÿ ¡¢£¤¥¦§¨©ª«¬­®¯°±²³´µ¶·¸¹º»¼½¾¿ÀÁÂĂÄÅÆÇÈÉÊË̀ÍÎÏĐÑ̉ÓÔƠÖ×ØÙÚÛÜỮßàáâăäåæçèéêë́íîïđṇ̃óôơö÷øùúûüư₫ÿ"
        },
        "win1258": "windows1258",
        "cp1258": "windows1258",
        "iso88591": {
            "type": "_sbcs",
            "chars": " ¡¢£¤¥¦§¨©ª«¬­®¯°±²³´µ¶·¸¹º»¼½¾¿ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏÐÑÒÓÔÕÖ×ØÙÚÛÜÝÞßàáâãäåæçèéêëìíîïðñòóôõö÷øùúûüýþÿ"
        },
        "cp28591": "iso88591",
        "iso88592": {
            "type": "_sbcs",
            "chars": " Ą˘Ł¤ĽŚ§¨ŠŞŤŹ­ŽŻ°ą˛ł´ľśˇ¸šşťź˝žżŔÁÂĂÄĹĆÇČÉĘËĚÍÎĎĐŃŇÓÔŐÖ×ŘŮÚŰÜÝŢßŕáâăäĺćçčéęëěíîďđńňóôőö÷řůúűüýţ˙"
        },
        "cp28592": "iso88592",
        "iso88593": {
            "type": "_sbcs",
            "chars": " Ħ˘£¤�Ĥ§¨İŞĞĴ­�Ż°ħ²³´µĥ·¸ışğĵ½�żÀÁÂ�ÄĊĈÇÈÉÊËÌÍÎÏ�ÑÒÓÔĠÖ×ĜÙÚÛÜŬŜßàáâ�äċĉçèéêëìíîï�ñòóôġö÷ĝùúûüŭŝ˙"
        },
        "cp28593": "iso88593",
        "iso88594": {
            "type": "_sbcs",
            "chars": " ĄĸŖ¤ĨĻ§¨ŠĒĢŦ­Ž¯°ą˛ŗ´ĩļˇ¸šēģŧŊžŋĀÁÂÃÄÅÆĮČÉĘËĖÍÎĪĐŅŌĶÔÕÖ×ØŲÚÛÜŨŪßāáâãäåæįčéęëėíîīđņōķôõö÷øųúûüũū˙"
        },
        "cp28594": "iso88594",
        "iso88595": {
            "type": "_sbcs",
            "chars": " ЁЂЃЄЅІЇЈЉЊЋЌ­ЎЏАБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмнопрстуфхцчшщъыьэюя№ёђѓєѕіїјљњћќ§ўџ"
        },
        "cp28595": "iso88595",
        "iso88596": {
            "type": "_sbcs",
            "chars": " ���¤�������،­�������������؛���؟�ءآأؤإئابةتثجحخدذرزسشصضطظعغ�����ـفقكلمنهوىيًٌٍَُِّْ�������������"
        },
        "cp28596": "iso88596",
        "iso88597": {
            "type": "_sbcs",
            "chars": " ‘’£€₯¦§¨©ͺ«¬­�―°±²³΄΅Ά·ΈΉΊ»Ό½ΎΏΐΑΒΓΔΕΖΗΘΙΚΛΜΝΞΟΠΡ�ΣΤΥΦΧΨΩΪΫάέήίΰαβγδεζηθικλμνξοπρςστυφχψωϊϋόύώ�"
        },
        "cp28597": "iso88597",
        "iso88598": {
            "type": "_sbcs",
            "chars": " �¢£¤¥¦§¨©×«¬­®¯°±²³´µ¶·¸¹÷»¼½¾��������������������������������‗אבגדהוזחטיךכלםמןנסעףפץצקרשת��‎‏�"
        },
        "cp28598": "iso88598",
        "iso88599": {
            "type": "_sbcs",
            "chars": " ¡¢£¤¥¦§¨©ª«¬­®¯°±²³´µ¶·¸¹º»¼½¾¿ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏĞÑÒÓÔÕÖ×ØÙÚÛÜİŞßàáâãäåæçèéêëìíîïğñòóôõö÷øùúûüışÿ"
        },
        "cp28599": "iso88599",
        "iso885910": {
            "type": "_sbcs",
            "chars": " ĄĒĢĪĨĶ§ĻĐŠŦŽ­ŪŊ°ąēģīĩķ·ļđšŧž―ūŋĀÁÂÃÄÅÆĮČÉĘËĖÍÎÏÐŅŌÓÔÕÖŨØŲÚÛÜÝÞßāáâãäåæįčéęëėíîïðņōóôõöũøųúûüýþĸ"
        },
        "cp28600": "iso885910",
        "iso885911": {
            "type": "_sbcs",
            "chars": " กขฃคฅฆงจฉชซฌญฎฏฐฑฒณดตถทธนบปผฝพฟภมยรฤลฦวศษสหฬอฮฯะัาำิีึืฺุู����฿เแโใไๅๆ็่้๊๋์ํ๎๏๐๑๒๓๔๕๖๗๘๙๚๛����"
        },
        "cp28601": "iso885911",
        "iso885913": {
            "type": "_sbcs",
            "chars": " ”¢£¤„¦§Ø©Ŗ«¬­®Æ°±²³“µ¶·ø¹ŗ»¼½¾æĄĮĀĆÄÅĘĒČÉŹĖĢĶĪĻŠŃŅÓŌÕÖ×ŲŁŚŪÜŻŽßąįāćäåęēčéźėģķīļšńņóōõö÷ųłśūüżž’"
        },
        "cp28603": "iso885913",
        "iso885914": {
            "type": "_sbcs",
            "chars": " Ḃḃ£ĊċḊ§Ẁ©ẂḋỲ­®ŸḞḟĠġṀṁ¶ṖẁṗẃṠỳẄẅṡÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏŴÑÒÓÔÕÖṪØÙÚÛÜÝŶßàáâãäåæçèéêëìíîïŵñòóôõöṫøùúûüýŷÿ"
        },
        "cp28604": "iso885914",
        "iso885915": {
            "type": "_sbcs",
            "chars": " ¡¢£€¥Š§š©ª«¬­®¯°±²³Žµ¶·ž¹º»ŒœŸ¿ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏÐÑÒÓÔÕÖ×ØÙÚÛÜÝÞßàáâãäåæçèéêëìíîïðñòóôõö÷øùúûüýþÿ"
        },
        "cp28605": "iso885915",
        "iso885916": {
            "type": "_sbcs",
            "chars": " ĄąŁ€„Š§š©Ș«Ź­źŻ°±ČłŽ”¶·žčș»ŒœŸżÀÁÂĂÄĆÆÇÈÉÊËÌÍÎÏĐŃÒÓÔŐÖŚŰÙÚÛÜĘȚßàáâăäćæçèéêëìíîïđńòóôőöśűùúûüęțÿ"
        },
        "cp28606": "iso885916",
        "cp437": {
            "type": "_sbcs",
            "chars": "ÇüéâäàåçêëèïîìÄÅÉæÆôöòûùÿÖÜ¢£¥₧ƒáíóúñÑªº¿⌐¬½¼¡«»░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞φε∩≡±≥≤⌠⌡÷≈°∙·√ⁿ²■ "
        },
        "ibm437": "cp437",
        "csibm437": "cp437",
        "cp737": {
            "type": "_sbcs",
            "chars": "ΑΒΓΔΕΖΗΘΙΚΛΜΝΞΟΠΡΣΤΥΦΧΨΩαβγδεζηθικλμνξοπρσςτυφχψ░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀ωάέήϊίόύϋώΆΈΉΊΌΎΏ±≥≤ΪΫ÷≈°∙·√ⁿ²■ "
        },
        "ibm737": "cp737",
        "csibm737": "cp737",
        "cp775": {
            "type": "_sbcs",
            "chars": "ĆüéāäģåćłēŖŗīŹÄÅÉæÆōöĢ¢ŚśÖÜø£Ø×¤ĀĪóŻżź”¦©®¬½¼Ł«»░▒▓│┤ĄČĘĖ╣║╗╝ĮŠ┐└┴┬├─┼ŲŪ╚╔╩╦╠═╬Žąčęėįšųūž┘┌█▄▌▐▀ÓßŌŃõÕµńĶķĻļņĒŅ’­±“¾¶§÷„°∙·¹³²■ "
        },
        "ibm775": "cp775",
        "csibm775": "cp775",
        "cp850": {
            "type": "_sbcs",
            "chars": "ÇüéâäàåçêëèïîìÄÅÉæÆôöòûùÿÖÜø£Ø×ƒáíóúñÑªº¿®¬½¼¡«»░▒▓│┤ÁÂÀ©╣║╗╝¢¥┐└┴┬├─┼ãÃ╚╔╩╦╠═╬¤ðÐÊËÈıÍÎÏ┘┌█▄¦Ì▀ÓßÔÒõÕµþÞÚÛÙýÝ¯´­±‗¾¶§÷¸°¨·¹³²■ "
        },
        "ibm850": "cp850",
        "csibm850": "cp850",
        "cp852": {
            "type": "_sbcs",
            "chars": "ÇüéâäůćçłëŐőîŹÄĆÉĹĺôöĽľŚśÖÜŤťŁ×čáíóúĄąŽžĘę¬źČş«»░▒▓│┤ÁÂĚŞ╣║╗╝Żż┐└┴┬├─┼Ăă╚╔╩╦╠═╬¤đĐĎËďŇÍÎě┘┌█▄ŢŮ▀ÓßÔŃńňŠšŔÚŕŰýÝţ´­˝˛ˇ˘§÷¸°¨˙űŘř■ "
        },
        "ibm852": "cp852",
        "csibm852": "cp852",
        "cp855": {
            "type": "_sbcs",
            "chars": "ђЂѓЃёЁєЄѕЅіІїЇјЈљЉњЊћЋќЌўЎџЏюЮъЪаАбБцЦдДеЕфФгГ«»░▒▓│┤хХиИ╣║╗╝йЙ┐└┴┬├─┼кК╚╔╩╦╠═╬¤лЛмМнНоОп┘┌█▄Пя▀ЯрРсСтТуУжЖвВьЬ№­ыЫзЗшШэЭщЩчЧ§■ "
        },
        "ibm855": "cp855",
        "csibm855": "cp855",
        "cp856": {
            "type": "_sbcs",
            "chars": "אבגדהוזחטיךכלםמןנסעףפץצקרשת�£�×����������®¬½¼�«»░▒▓│┤���©╣║╗╝¢¥┐└┴┬├─┼��╚╔╩╦╠═╬¤���������┘┌█▄¦�▀������µ�������¯´­±‗¾¶§÷¸°¨·¹³²■ "
        },
        "ibm856": "cp856",
        "csibm856": "cp856",
        "cp857": {
            "type": "_sbcs",
            "chars": "ÇüéâäàåçêëèïîıÄÅÉæÆôöòûùİÖÜø£ØŞşáíóúñÑĞğ¿®¬½¼¡«»░▒▓│┤ÁÂÀ©╣║╗╝¢¥┐└┴┬├─┼ãÃ╚╔╩╦╠═╬¤ºªÊËÈ�ÍÎÏ┘┌█▄¦Ì▀ÓßÔÒõÕµ�×ÚÛÙìÿ¯´­±�¾¶§÷¸°¨·¹³²■ "
        },
        "ibm857": "cp857",
        "csibm857": "cp857",
        "cp858": {
            "type": "_sbcs",
            "chars": "ÇüéâäàåçêëèïîìÄÅÉæÆôöòûùÿÖÜø£Ø×ƒáíóúñÑªº¿®¬½¼¡«»░▒▓│┤ÁÂÀ©╣║╗╝¢¥┐└┴┬├─┼ãÃ╚╔╩╦╠═╬¤ðÐÊËÈ€ÍÎÏ┘┌█▄¦Ì▀ÓßÔÒõÕµþÞÚÛÙýÝ¯´­±‗¾¶§÷¸°¨·¹³²■ "
        },
        "ibm858": "cp858",
        "csibm858": "cp858",
        "cp860": {
            "type": "_sbcs",
            "chars": "ÇüéâãàÁçêÊèÍÔìÃÂÉÀÈôõòÚùÌÕÜ¢£Ù₧ÓáíóúñÑªº¿Ò¬½¼¡«»░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞φε∩≡±≥≤⌠⌡÷≈°∙·√ⁿ²■ "
        },
        "ibm860": "cp860",
        "csibm860": "cp860",
        "cp861": {
            "type": "_sbcs",
            "chars": "ÇüéâäàåçêëèÐðÞÄÅÉæÆôöþûÝýÖÜø£Ø₧ƒáíóúÁÍÓÚ¿⌐¬½¼¡«»░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞φε∩≡±≥≤⌠⌡÷≈°∙·√ⁿ²■ "
        },
        "ibm861": "cp861",
        "csibm861": "cp861",
        "cp862": {
            "type": "_sbcs",
            "chars": "אבגדהוזחטיךכלםמןנסעףפץצקרשת¢£¥₧ƒáíóúñÑªº¿⌐¬½¼¡«»░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞φε∩≡±≥≤⌠⌡÷≈°∙·√ⁿ²■ "
        },
        "ibm862": "cp862",
        "csibm862": "cp862",
        "cp863": {
            "type": "_sbcs",
            "chars": "ÇüéâÂà¶çêëèïî‗À§ÉÈÊôËÏûù¤ÔÜ¢£ÙÛƒ¦´óú¨¸³¯Î⌐¬½¼¾«»░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞φε∩≡±≥≤⌠⌡÷≈°∙·√ⁿ²■ "
        },
        "ibm863": "cp863",
        "csibm863": "cp863",
        "cp864": {
            "type": "_sbcs",
            "chars": "\u0000\u0001\u0002\u0003\u0004\u0005\u0006\u0007\b\t\n\u000b\f\r\u000e\u000f\u0010\u0011\u0012\u0013\u0014\u0015\u0016\u0017\u0018\u0019\u001a\u001b\u001c\u001d\u001e\u001f !\"#$٪&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~°·∙√▒─│┼┤┬├┴┐┌└┘β∞φ±½¼≈«»ﻷﻸ��ﻻﻼ� ­ﺂ£¤ﺄ��ﺎﺏﺕﺙ،ﺝﺡﺥ٠١٢٣٤٥٦٧٨٩ﻑ؛ﺱﺵﺹ؟¢ﺀﺁﺃﺅﻊﺋﺍﺑﺓﺗﺛﺟﺣﺧﺩﺫﺭﺯﺳﺷﺻﺿﻁﻅﻋﻏ¦¬÷×ﻉـﻓﻗﻛﻟﻣﻧﻫﻭﻯﻳﺽﻌﻎﻍﻡﹽّﻥﻩﻬﻰﻲﻐﻕﻵﻶﻝﻙﻱ■�"
        },
        "ibm864": "cp864",
        "csibm864": "cp864",
        "cp865": {
            "type": "_sbcs",
            "chars": "ÇüéâäàåçêëèïîìÄÅÉæÆôöòûùÿÖÜø£Ø₧ƒáíóúñÑªº¿⌐¬½¼¡«¤░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞φε∩≡±≥≤⌠⌡÷≈°∙·√ⁿ²■ "
        },
        "ibm865": "cp865",
        "csibm865": "cp865",
        "cp866": {
            "type": "_sbcs",
            "chars": "АБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмноп░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀рстуфхцчшщъыьэюяЁёЄєЇїЎў°∙·√№¤■ "
        },
        "ibm866": "cp866",
        "csibm866": "cp866",
        "cp869": {
            "type": "_sbcs",
            "chars": "������Ά�·¬¦‘’Έ―ΉΊΪΌ��ΎΫ©Ώ²³ά£έήίϊΐόύΑΒΓΔΕΖΗ½ΘΙ«»░▒▓│┤ΚΛΜΝ╣║╗╝ΞΟ┐└┴┬├─┼ΠΡ╚╔╩╦╠═╬ΣΤΥΦΧΨΩαβγ┘┌█▄δε▀ζηθικλμνξοπρσςτ΄­±υφχ§ψ΅°¨ωϋΰώ■ "
        },
        "ibm869": "cp869",
        "csibm869": "cp869",
        "cp922": {
            "type": "_sbcs",
            "chars": " ¡¢£¤¥¦§¨©ª«¬­®‾°±²³´µ¶·¸¹º»¼½¾¿ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏŠÑÒÓÔÕÖ×ØÙÚÛÜÝŽßàáâãäåæçèéêëìíîïšñòóôõö÷øùúûüýžÿ"
        },
        "ibm922": "cp922",
        "csibm922": "cp922",
        "cp1046": {
            "type": "_sbcs",
            "chars": "ﺈ×÷ﹱ■│─┐┌└┘ﹹﹻﹽﹿﹷﺊﻰﻳﻲﻎﻏﻐﻶﻸﻺﻼ ¤ﺋﺑﺗﺛﺟﺣ،­ﺧﺳ٠١٢٣٤٥٦٧٨٩ﺷ؛ﺻﺿﻊ؟ﻋءآأؤإئابةتثجحخدذرزسشصضطﻇعغﻌﺂﺄﺎﻓـفقكلمنهوىيًٌٍَُِّْﻗﻛﻟﻵﻷﻹﻻﻣﻧﻬﻩ�"
        },
        "ibm1046": "cp1046",
        "csibm1046": "cp1046",
        "cp1124": {
            "type": "_sbcs",
            "chars": " ЁЂҐЄЅІЇЈЉЊЋЌ­ЎЏАБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмнопрстуфхцчшщъыьэюя№ёђґєѕіїјљњћќ§ўџ"
        },
        "ibm1124": "cp1124",
        "csibm1124": "cp1124",
        "cp1125": {
            "type": "_sbcs",
            "chars": "АБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмноп░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀рстуфхцчшщъыьэюяЁёҐґЄєІіЇї·√№¤■ "
        },
        "ibm1125": "cp1125",
        "csibm1125": "cp1125",
        "cp1129": {
            "type": "_sbcs",
            "chars": " ¡¢£¤¥¦§œ©ª«¬­®¯°±²³Ÿµ¶·Œ¹º»¼½¾¿ÀÁÂĂÄÅÆÇÈÉÊË̀ÍÎÏĐÑ̉ÓÔƠÖ×ØÙÚÛÜỮßàáâăäåæçèéêë́íîïđṇ̃óôơö÷øùúûüư₫ÿ"
        },
        "ibm1129": "cp1129",
        "csibm1129": "cp1129",
        "cp1133": {
            "type": "_sbcs",
            "chars": " ກຂຄງຈສຊຍດຕຖທນບປຜຝພຟມຢຣລວຫອຮ���ຯະາຳິີຶືຸູຼັົຽ���ເແໂໃໄ່້໊໋໌ໍໆ�ໜໝ₭����������������໐໑໒໓໔໕໖໗໘໙��¢¬¦�"
        },
        "ibm1133": "cp1133",
        "csibm1133": "cp1133",
        "cp1161": {
            "type": "_sbcs",
            "chars": "��������������������������������่กขฃคฅฆงจฉชซฌญฎฏฐฑฒณดตถทธนบปผฝพฟภมยรฤลฦวศษสหฬอฮฯะัาำิีึืฺุู้๊๋€฿เแโใไๅๆ็่้๊๋์ํ๎๏๐๑๒๓๔๕๖๗๘๙๚๛¢¬¦ "
        },
        "ibm1161": "cp1161",
        "csibm1161": "cp1161",
        "cp1162": {
            "type": "_sbcs",
            "chars": "€…‘’“”•–— กขฃคฅฆงจฉชซฌญฎฏฐฑฒณดตถทธนบปผฝพฟภมยรฤลฦวศษสหฬอฮฯะัาำิีึืฺุู����฿เแโใไๅๆ็่้๊๋์ํ๎๏๐๑๒๓๔๕๖๗๘๙๚๛����"
        },
        "ibm1162": "cp1162",
        "csibm1162": "cp1162",
        "cp1163": {
            "type": "_sbcs",
            "chars": " ¡¢£€¥¦§œ©ª«¬­®¯°±²³Ÿµ¶·Œ¹º»¼½¾¿ÀÁÂĂÄÅÆÇÈÉÊË̀ÍÎÏĐÑ̉ÓÔƠÖ×ØÙÚÛÜỮßàáâăäåæçèéêë́íîïđṇ̃óôơö÷øùúûüư₫ÿ"
        },
        "ibm1163": "cp1163",
        "csibm1163": "cp1163",
        "maccroatian": {
            "type": "_sbcs",
            "chars": "ÄÅÇÉÑÖÜáàâäãåçéèêëíìîïñóòôöõúùûü†°¢£§•¶ß®Š™´¨≠ŽØ∞±≤≥∆µ∂∑∏š∫ªºΩžø¿¡¬√ƒ≈Ć«Č… ÀÃÕŒœĐ—“”‘’÷◊�©⁄¤‹›Æ»–·‚„‰ÂćÁčÈÍÎÏÌÓÔđÒÚÛÙıˆ˜¯πË˚¸Êæˇ"
        },
        "maccyrillic": {
            "type": "_sbcs",
            "chars": "АБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯ†°¢£§•¶І®©™Ђђ≠Ѓѓ∞±≤≥іµ∂ЈЄєЇїЉљЊњјЅ¬√ƒ≈∆«»… ЋћЌќѕ–—“”‘’÷„ЎўЏџ№Ёёяабвгдежзийклмнопрстуфхцчшщъыьэю¤"
        },
        "macgreek": {
            "type": "_sbcs",
            "chars": "Ä¹²É³ÖÜ΅àâä΄¨çéèêë£™îï•½‰ôö¦­ùûü†ΓΔΘΛΞΠß®©ΣΪ§≠°·Α±≤≥¥ΒΕΖΗΙΚΜΦΫΨΩάΝ¬ΟΡ≈Τ«»… ΥΧΆΈœ–―“”‘’÷ΉΊΌΎέήίόΏύαβψδεφγηιξκλμνοπώρστθωςχυζϊϋΐΰ�"
        },
        "maciceland": {
            "type": "_sbcs",
            "chars": "ÄÅÇÉÑÖÜáàâäãåçéèêëíìîïñóòôöõúùûüÝ°¢£§•¶ß®©™´¨≠ÆØ∞±≤≥¥µ∂∑∏π∫ªºΩæø¿¡¬√ƒ≈∆«»… ÀÃÕŒœ–—“”‘’÷◊ÿŸ⁄¤ÐðÞþý·‚„‰ÂÊÁËÈÍÎÏÌÓÔ�ÒÚÛÙıˆ˜¯˘˙˚¸˝˛ˇ"
        },
        "macroman": {
            "type": "_sbcs",
            "chars": "ÄÅÇÉÑÖÜáàâäãåçéèêëíìîïñóòôöõúùûü†°¢£§•¶ß®©™´¨≠ÆØ∞±≤≥¥µ∂∑∏π∫ªºΩæø¿¡¬√ƒ≈∆«»… ÀÃÕŒœ–—“”‘’÷◊ÿŸ⁄¤‹›ﬁﬂ‡·‚„‰ÂÊÁËÈÍÎÏÌÓÔ�ÒÚÛÙıˆ˜¯˘˙˚¸˝˛ˇ"
        },
        "macromania": {
            "type": "_sbcs",
            "chars": "ÄÅÇÉÑÖÜáàâäãåçéèêëíìîïñóòôöõúùûü†°¢£§•¶ß®©™´¨≠ĂŞ∞±≤≥¥µ∂∑∏π∫ªºΩăş¿¡¬√ƒ≈∆«»… ÀÃÕŒœ–—“”‘’÷◊ÿŸ⁄¤‹›Ţţ‡·‚„‰ÂÊÁËÈÍÎÏÌÓÔ�ÒÚÛÙıˆ˜¯˘˙˚¸˝˛ˇ"
        },
        "macthai": {
            "type": "_sbcs",
            "chars": "«»…“”�•‘’� กขฃคฅฆงจฉชซฌญฎฏฐฑฒณดตถทธนบปผฝพฟภมยรฤลฦวศษสหฬอฮฯะัาำิีึืฺุู﻿​–—฿เแโใไๅๆ็่้๊๋์ํ™๏๐๑๒๓๔๕๖๗๘๙®©����"
        },
        "macturkish": {
            "type": "_sbcs",
            "chars": "ÄÅÇÉÑÖÜáàâäãåçéèêëíìîïñóòôöõúùûü†°¢£§•¶ß®©™´¨≠ÆØ∞±≤≥¥µ∂∑∏π∫ªºΩæø¿¡¬√ƒ≈∆«»… ÀÃÕŒœ–—“”‘’÷◊ÿŸĞğİıŞş‡·‚„‰ÂÊÁËÈÍÎÏÌÓÔ�ÒÚÛÙ�ˆ˜¯˘˙˚¸˝˛ˇ"
        },
        "macukraine": {
            "type": "_sbcs",
            "chars": "АБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯ†°Ґ£§•¶І®©™Ђђ≠Ѓѓ∞±≤≥іµґЈЄєЇїЉљЊњјЅ¬√ƒ≈∆«»… ЋћЌќѕ–—“”‘’÷„ЎўЏџ№Ёёяабвгдежзийклмнопрстуфхцчшщъыьэю¤"
        },
        "koi8r": {
            "type": "_sbcs",
            "chars": "─│┌┐└┘├┤┬┴┼▀▄█▌▐░▒▓⌠■∙√≈≤≥ ⌡°²·÷═║╒ё╓╔╕╖╗╘╙╚╛╜╝╞╟╠╡Ё╢╣╤╥╦╧╨╩╪╫╬©юабцдефгхийклмнопярстужвьызшэщчъЮАБЦДЕФГХИЙКЛМНОПЯРСТУЖВЬЫЗШЭЩЧЪ"
        },
        "koi8u": {
            "type": "_sbcs",
            "chars": "─│┌┐└┘├┤┬┴┼▀▄█▌▐░▒▓⌠■∙√≈≤≥ ⌡°²·÷═║╒ёє╔ії╗╘╙╚╛ґ╝╞╟╠╡ЁЄ╣ІЇ╦╧╨╩╪Ґ╬©юабцдефгхийклмнопярстужвьызшэщчъЮАБЦДЕФГХИЙКЛМНОПЯРСТУЖВЬЫЗШЭЩЧЪ"
        },
        "koi8ru": {
            "type": "_sbcs",
            "chars": "─│┌┐└┘├┤┬┴┼▀▄█▌▐░▒▓⌠■∙√≈≤≥ ⌡°²·÷═║╒ёє╔ії╗╘╙╚╛ґў╞╟╠╡ЁЄ╣ІЇ╦╧╨╩╪ҐЎ©юабцдефгхийклмнопярстужвьызшэщчъЮАБЦДЕФГХИЙКЛМНОПЯРСТУЖВЬЫЗШЭЩЧЪ"
        },
        "koi8t": {
            "type": "_sbcs",
            "chars": "қғ‚Ғ„…†‡�‰ҳ‹ҲҷҶ�Қ‘’“”•–—�™�›�����ӯӮё¤ӣ¦§���«¬­®�°±²Ё�Ӣ¶·�№�»���©юабцдефгхийклмнопярстужвьызшэщчъЮАБЦДЕФГХИЙКЛМНОПЯРСТУЖВЬЫЗШЭЩЧЪ"
        },
        "armscii8": {
            "type": "_sbcs",
            "chars": " �և։)(»«—.՝,-֊…՜՛՞ԱաԲբԳգԴդԵեԶզԷէԸըԹթԺժԻիԼլԽխԾծԿկՀհՁձՂղՃճՄմՅյՆնՇշՈոՉչՊպՋջՌռՍսՎվՏտՐրՑցՒւՓփՔքՕօՖֆ՚�"
        },
        "rk1048": {
            "type": "_sbcs",
            "chars": "ЂЃ‚ѓ„…†‡€‰Љ‹ЊҚҺЏђ‘’“”•–—�™љ›њқһџ ҰұӘ¤Ө¦§Ё©Ғ«¬­®Ү°±Ііөµ¶·ё№ғ»әҢңүАБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмнопрстуфхцчшщъыьэюя"
        },
        "tcvn": {
            "type": "_sbcs",
            "chars": "\u0000ÚỤ\u0003ỪỬỮ\u0007\b\t\n\u000b\f\r\u000e\u000f\u0010ỨỰỲỶỸÝỴ\u0018\u0019\u001a\u001b\u001c\u001d\u001e\u001f !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~ÀẢÃÁẠẶẬÈẺẼÉẸỆÌỈĨÍỊÒỎÕÓỌỘỜỞỠỚỢÙỦŨ ĂÂÊÔƠƯĐăâêôơưđẶ̀̀̉̃́àảãáạẲằẳẵắẴẮẦẨẪẤỀặầẩẫấậèỂẻẽéẹềểễếệìỉỄẾỒĩíịòỔỏõóọồổỗốộờởỡớợùỖủũúụừửữứựỳỷỹýỵỐ"
        },
        "georgianacademy": {
            "type": "_sbcs",
            "chars": "‚ƒ„…†‡ˆ‰Š‹Œ‘’“”•–—˜™š›œŸ ¡¢£¤¥¦§¨©ª«¬­®¯°±²³´µ¶·¸¹º»¼½¾¿აბგდევზთიკლმნოპჟრსტუფქღყშჩცძწჭხჯჰჱჲჳჴჵჶçèéêëìíîïðñòóôõö÷øùúûüýþÿ"
        },
        "georgianps": {
            "type": "_sbcs",
            "chars": "‚ƒ„…†‡ˆ‰Š‹Œ‘’“”•–—˜™š›œŸ ¡¢£¤¥¦§¨©ª«¬­®¯°±²³´µ¶·¸¹º»¼½¾¿აბგდევზჱთიკლმნჲოპჟრსტჳუფქღყშჩცძწჭხჴჯჰჵæçèéêëìíîïðñòóôõö÷øùúûüýþÿ"
        },
        "pt154": {
            "type": "_sbcs",
            "chars": "ҖҒӮғ„…ҶҮҲүҠӢҢҚҺҸҗ‘’“”•–—ҳҷҡӣңқһҹ ЎўЈӨҘҰ§Ё©Ә«¬ӯ®Ҝ°ұІіҙө¶·ё№ә»јҪҫҝАБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмнопрстуфхцчшщъыьэюя"
        },
        "viscii": {
            "type": "_sbcs",
            "chars": "\u0000\u0001Ẳ\u0003\u0004ẴẪ\u0007\b\t\n\u000b\f\r\u000e\u000f\u0010\u0011\u0012\u0013Ỷ\u0015\u0016\u0017\u0018Ỹ\u001a\u001b\u001c\u001dỴ\u001f !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~ẠẮẰẶẤẦẨẬẼẸẾỀỂỄỆỐỒỔỖỘỢỚỜỞỊỎỌỈỦŨỤỲÕắằặấầẩậẽẹếềểễệốồổỗỠƠộờởịỰỨỪỬơớƯÀÁÂÃẢĂẳẵÈÉÊẺÌÍĨỳĐứÒÓÔạỷừửÙÚỹỵÝỡưàáâãảăữẫèéêẻìíĩỉđựòóôõỏọụùúũủýợỮ"
        },
        "iso646cn": {
            "type": "_sbcs",
            "chars": "\u0000\u0001\u0002\u0003\u0004\u0005\u0006\u0007\b\t\n\u000b\f\r\u000e\u000f\u0010\u0011\u0012\u0013\u0014\u0015\u0016\u0017\u0018\u0019\u001a\u001b\u001c\u001d\u001e\u001f !\"#¥%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}‾��������������������������������������������������������������������������������������������������������������������������������"
        },
        "iso646jp": {
            "type": "_sbcs",
            "chars": "\u0000\u0001\u0002\u0003\u0004\u0005\u0006\u0007\b\t\n\u000b\f\r\u000e\u000f\u0010\u0011\u0012\u0013\u0014\u0015\u0016\u0017\u0018\u0019\u001a\u001b\u001c\u001d\u001e\u001f !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[¥]^_`abcdefghijklmnopqrstuvwxyz{|}‾��������������������������������������������������������������������������������������������������������������������������������"
        },
        "hproman8": {
            "type": "_sbcs",
            "chars": " ÀÂÈÊËÎÏ´ˋˆ¨˜ÙÛ₤¯Ýý°ÇçÑñ¡¿¤£¥§ƒ¢âêôûáéóúàèòùäëöüÅîØÆåíøæÄìÖÜÉïßÔÁÃãÐðÍÌÓÒÕõŠšÚŸÿÞþ·µ¶¾—¼½ªº«■»±�"
        },
        "macintosh": {
            "type": "_sbcs",
            "chars": "ÄÅÇÉÑÖÜáàâäãåçéèêëíìîïñóòôöõúùûü†°¢£§•¶ß®©™´¨≠ÆØ∞±≤≥¥µ∂∑∏π∫ªºΩæø¿¡¬√ƒ≈∆«»… ÀÃÕŒœ–—“”‘’÷◊ÿŸ⁄¤‹›ﬁﬂ‡·‚„‰ÂÊÁËÈÍÎÏÌÓÔ�ÒÚÛÙıˆ˜¯˘˙˚¸˝˛ˇ"
        },
        "ascii": {
            "type": "_sbcs",
            "chars": "��������������������������������������������������������������������������������������������������������������������������������"
        },
        "tis620": {
            "type": "_sbcs",
            "chars": "���������������������������������กขฃคฅฆงจฉชซฌญฎฏฐฑฒณดตถทธนบปผฝพฟภมยรฤลฦวศษสหฬอฮฯะัาำิีึืฺุู����฿เแโใไๅๆ็่้๊๋์ํ๎๏๐๑๒๓๔๕๖๗๘๙๚๛����"
        }
    };
},
/* iconv-lite/encodings/dbcs-codec.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var Buffer = require(85) /* safer-buffer */.Buffer;
    // Multibyte codec. In this scheme, a character is represented by 1 or more bytes.
    // Our codec supports UTF-16 surrogates, extensions for GB18030 and unicode sequences.
    // To save memory and loading time, we read table files only when requested.
    exports._dbcs = DBCSCodec;
    var UNASSIGNED = -1, GB18030_CODE = -2, SEQ_START = -10, NODE_START = -1000, UNASSIGNED_NODE = new Array(0x100), DEF_CHAR = -1;
    for (var i = 0; i < 0x100; i++)
        UNASSIGNED_NODE[i] = UNASSIGNED;
    // Class DBCSCodec reads and initializes mapping tables.
    function DBCSCodec(codecOptions, iconv) {
        this.encodingName = codecOptions.encodingName;
        if (!codecOptions)
            throw new Error("DBCS codec is called without the data.");
        if (!codecOptions.table)
            throw new Error("Encoding '" + this.encodingName + "' has no data.");
        // Load tables.
        var mappingTable = codecOptions.table();
        // Decode tables: MBCS -> Unicode.
        // decodeTables is a trie, encoded as an array of arrays of integers. Internal arrays are trie nodes and all have len = 256.
        // Trie root is decodeTables[0].
        // Values: >=  0 -> unicode character code. can be > 0xFFFF
        //         == UNASSIGNED -> unknown/unassigned sequence.
        //         == GB18030_CODE -> this is the end of a GB18030 4-byte sequence.
        //         <= NODE_START -> index of the next node in our trie to process next byte.
        //         <= SEQ_START  -> index of the start of a character code sequence, in decodeTableSeq.
        this.decodeTables = [];
        this.decodeTables[0] = UNASSIGNED_NODE.slice(0); // Create root node.
        // Sometimes a MBCS char corresponds to a sequence of unicode chars. We store them as arrays of integers here. 
        this.decodeTableSeq = [];
        // Actual mapping tables consist of chunks. Use them to fill up decode tables.
        for (var i = 0; i < mappingTable.length; i++)
            this._addDecodeChunk(mappingTable[i]);
        this.defaultCharUnicode = iconv.defaultCharUnicode;
        // Encode tables: Unicode -> DBCS.
        // `encodeTable` is array mapping from unicode char to encoded char. All its values are integers for performance.
        // Because it can be sparse, it is represented as array of buckets by 256 chars each. Bucket can be null.
        // Values: >=  0 -> it is a normal char. Write the value (if <=256 then 1 byte, if <=65536 then 2 bytes, etc.).
        //         == UNASSIGNED -> no conversion found. Output a default char.
        //         <= SEQ_START  -> it's an index in encodeTableSeq, see below. The character starts a sequence.
        this.encodeTable = [];
        // `encodeTableSeq` is used when a sequence of unicode characters is encoded as a single code. We use a tree of
        // objects where keys correspond to characters in sequence and leafs are the encoded dbcs values. A special DEF_CHAR key
        // means end of sequence (needed when one sequence is a strict subsequence of another).
        // Objects are kept separately from encodeTable to increase performance.
        this.encodeTableSeq = [];
        // Some chars can be decoded, but need not be encoded.
        var skipEncodeChars = {};
        if (codecOptions.encodeSkipVals)
            for (var i = 0; i < codecOptions.encodeSkipVals.length; i++) {
                var val = codecOptions.encodeSkipVals[i];
                if (typeof val === 'number')
                    skipEncodeChars[val] = true;
                else
                    for (var j = val.from; j <= val.to; j++)
                        skipEncodeChars[j] = true;
            }
        // Use decode trie to recursively fill out encode tables.
        this._fillEncodeTable(0, 0, skipEncodeChars);
        // Add more encoding pairs when needed.
        if (codecOptions.encodeAdd) {
            for (var uChar in codecOptions.encodeAdd)
                if (Object.prototype.hasOwnProperty.call(codecOptions.encodeAdd, uChar))
                    this._setEncodeChar(uChar.charCodeAt(0), codecOptions.encodeAdd[uChar]);
        }
        this.defCharSB = this.encodeTable[0][iconv.defaultCharSingleByte.charCodeAt(0)];
        if (this.defCharSB === UNASSIGNED)
            this.defCharSB = this.encodeTable[0]['?'];
        if (this.defCharSB === UNASSIGNED)
            this.defCharSB = "?".charCodeAt(0);
        // Load & create GB18030 tables when needed.
        if (typeof codecOptions.gb18030 === 'function') {
            this.gb18030 = codecOptions.gb18030(); // Load GB18030 ranges.
            // Add GB18030 decode tables.
            var thirdByteNodeIdx = this.decodeTables.length;
            var thirdByteNode = this.decodeTables[thirdByteNodeIdx] = UNASSIGNED_NODE.slice(0);
            var fourthByteNodeIdx = this.decodeTables.length;
            var fourthByteNode = this.decodeTables[fourthByteNodeIdx] = UNASSIGNED_NODE.slice(0);
            for (var i = 0x81; i <= 0xFE; i++) {
                var secondByteNodeIdx = NODE_START - this.decodeTables[0][i];
                var secondByteNode = this.decodeTables[secondByteNodeIdx];
                for (var j = 0x30; j <= 0x39; j++)
                    secondByteNode[j] = NODE_START - thirdByteNodeIdx;
            }
            for (var i = 0x81; i <= 0xFE; i++)
                thirdByteNode[i] = NODE_START - fourthByteNodeIdx;
            for (var i = 0x30; i <= 0x39; i++)
                fourthByteNode[i] = GB18030_CODE;
        }
    }
    DBCSCodec.prototype.encoder = DBCSEncoder;
    DBCSCodec.prototype.decoder = DBCSDecoder;
    // Decoder helpers
    DBCSCodec.prototype._getDecodeTrieNode = function (addr) {
        var bytes = [];
        for (; addr > 0; addr >>= 8)
            bytes.push(addr & 0xFF);
        if (bytes.length == 0)
            bytes.push(0);
        var node = this.decodeTables[0];
        for (var i = bytes.length - 1; i > 0; i--) { // Traverse nodes deeper into the trie.
            var val = node[bytes[i]];
            if (val == UNASSIGNED) { // Create new node.
                node[bytes[i]] = NODE_START - this.decodeTables.length;
                this.decodeTables.push(node = UNASSIGNED_NODE.slice(0));
            }
            else if (val <= NODE_START) { // Existing node.
                node = this.decodeTables[NODE_START - val];
            }
            else
                throw new Error("Overwrite byte in " + this.encodingName + ", addr: " + addr.toString(16));
        }
        return node;
    };
    DBCSCodec.prototype._addDecodeChunk = function (chunk) {
        // First element of chunk is the hex mbcs code where we start.
        var curAddr = parseInt(chunk[0], 16);
        // Choose the decoding node where we'll write our chars.
        var writeTable = this._getDecodeTrieNode(curAddr);
        curAddr = curAddr & 0xFF;
        // Write all other elements of the chunk to the table.
        for (var k = 1; k < chunk.length; k++) {
            var part = chunk[k];
            if (typeof part === "string") { // String, write as-is.
                for (var l = 0; l < part.length;) {
                    var code = part.charCodeAt(l++);
                    if (0xD800 <= code && code < 0xDC00) { // Decode surrogate
                        var codeTrail = part.charCodeAt(l++);
                        if (0xDC00 <= codeTrail && codeTrail < 0xE000)
                            writeTable[curAddr++] = 0x10000 + (code - 0xD800) * 0x400 + (codeTrail - 0xDC00);
                        else
                            throw new Error("Incorrect surrogate pair in " + this.encodingName + " at chunk " + chunk[0]);
                    }
                    else if (0x0FF0 < code && code <= 0x0FFF) { // Character sequence (our own encoding used)
                        var len = 0xFFF - code + 2;
                        var seq = [];
                        for (var m = 0; m < len; m++)
                            seq.push(part.charCodeAt(l++)); // Simple variation: don't support surrogates or subsequences in seq.
                        writeTable[curAddr++] = SEQ_START - this.decodeTableSeq.length;
                        this.decodeTableSeq.push(seq);
                    }
                    else
                        writeTable[curAddr++] = code; // Basic char
                }
            }
            else if (typeof part === "number") { // Integer, meaning increasing sequence starting with prev character.
                var charCode = writeTable[curAddr - 1] + 1;
                for (var l = 0; l < part; l++)
                    writeTable[curAddr++] = charCode++;
            }
            else
                throw new Error("Incorrect type '" + typeof part + "' given in " + this.encodingName + " at chunk " + chunk[0]);
        }
        if (curAddr > 0xFF)
            throw new Error("Incorrect chunk in " + this.encodingName + " at addr " + chunk[0] + ": too long" + curAddr);
    };
    // Encoder helpers
    DBCSCodec.prototype._getEncodeBucket = function (uCode) {
        var high = uCode >> 8; // This could be > 0xFF because of astral characters.
        if (this.encodeTable[high] === undefined)
            this.encodeTable[high] = UNASSIGNED_NODE.slice(0); // Create bucket on demand.
        return this.encodeTable[high];
    };
    DBCSCodec.prototype._setEncodeChar = function (uCode, dbcsCode) {
        var bucket = this._getEncodeBucket(uCode);
        var low = uCode & 0xFF;
        if (bucket[low] <= SEQ_START)
            this.encodeTableSeq[SEQ_START - bucket[low]][DEF_CHAR] = dbcsCode; // There's already a sequence, set a single-char subsequence of it.
        else if (bucket[low] == UNASSIGNED)
            bucket[low] = dbcsCode;
    };
    DBCSCodec.prototype._setEncodeSequence = function (seq, dbcsCode) {
        // Get the root of character tree according to first character of the sequence.
        var uCode = seq[0];
        var bucket = this._getEncodeBucket(uCode);
        var low = uCode & 0xFF;
        var node;
        if (bucket[low] <= SEQ_START) {
            // There's already a sequence with  - use it.
            node = this.encodeTableSeq[SEQ_START - bucket[low]];
        }
        else {
            // There was no sequence object - allocate a new one.
            node = {};
            if (bucket[low] !== UNASSIGNED)
                node[DEF_CHAR] = bucket[low]; // If a char was set before - make it a single-char subsequence.
            bucket[low] = SEQ_START - this.encodeTableSeq.length;
            this.encodeTableSeq.push(node);
        }
        // Traverse the character tree, allocating new nodes as needed.
        for (var j = 1; j < seq.length - 1; j++) {
            var oldVal = node[uCode];
            if (typeof oldVal === 'object')
                node = oldVal;
            else {
                node = node[uCode] = {};
                if (oldVal !== undefined)
                    node[DEF_CHAR] = oldVal;
            }
        }
        // Set the leaf to given dbcsCode.
        uCode = seq[seq.length - 1];
        node[uCode] = dbcsCode;
    };
    DBCSCodec.prototype._fillEncodeTable = function (nodeIdx, prefix, skipEncodeChars) {
        var node = this.decodeTables[nodeIdx];
        for (var i = 0; i < 0x100; i++) {
            var uCode = node[i];
            var mbCode = prefix + i;
            if (skipEncodeChars[mbCode])
                continue;
            if (uCode >= 0)
                this._setEncodeChar(uCode, mbCode);
            else if (uCode <= NODE_START)
                this._fillEncodeTable(NODE_START - uCode, mbCode << 8, skipEncodeChars);
            else if (uCode <= SEQ_START)
                this._setEncodeSequence(this.decodeTableSeq[SEQ_START - uCode], mbCode);
        }
    };
    // == Encoder ==================================================================
    function DBCSEncoder(options, codec) {
        // Encoder state
        this.leadSurrogate = -1;
        this.seqObj = undefined;
        // Static data
        this.encodeTable = codec.encodeTable;
        this.encodeTableSeq = codec.encodeTableSeq;
        this.defaultCharSingleByte = codec.defCharSB;
        this.gb18030 = codec.gb18030;
    }
    DBCSEncoder.prototype.write = function (str) {
        var newBuf = Buffer.alloc(str.length * (this.gb18030 ? 4 : 3)), leadSurrogate = this.leadSurrogate, seqObj = this.seqObj, nextChar = -1, i = 0, j = 0;
        while (true) {
            // 0. Get next character.
            if (nextChar === -1) {
                if (i == str.length)
                    break;
                var uCode = str.charCodeAt(i++);
            }
            else {
                var uCode = nextChar;
                nextChar = -1;
            }
            // 1. Handle surrogates.
            if (0xD800 <= uCode && uCode < 0xE000) { // Char is one of surrogates.
                if (uCode < 0xDC00) { // We've got lead surrogate.
                    if (leadSurrogate === -1) {
                        leadSurrogate = uCode;
                        continue;
                    }
                    else {
                        leadSurrogate = uCode;
                        // Double lead surrogate found.
                        uCode = UNASSIGNED;
                    }
                }
                else { // We've got trail surrogate.
                    if (leadSurrogate !== -1) {
                        uCode = 0x10000 + (leadSurrogate - 0xD800) * 0x400 + (uCode - 0xDC00);
                        leadSurrogate = -1;
                    }
                    else {
                        // Incomplete surrogate pair - only trail surrogate found.
                        uCode = UNASSIGNED;
                    }
                }
            }
            else if (leadSurrogate !== -1) {
                // Incomplete surrogate pair - only lead surrogate found.
                nextChar = uCode;
                uCode = UNASSIGNED; // Write an error, then current char.
                leadSurrogate = -1;
            }
            // 2. Convert uCode character.
            var dbcsCode = UNASSIGNED;
            if (seqObj !== undefined && uCode != UNASSIGNED) { // We are in the middle of the sequence
                var resCode = seqObj[uCode];
                if (typeof resCode === 'object') { // Sequence continues.
                    seqObj = resCode;
                    continue;
                }
                else if (typeof resCode == 'number') { // Sequence finished. Write it.
                    dbcsCode = resCode;
                }
                else if (resCode == undefined) { // Current character is not part of the sequence.
                    // Try default character for this sequence
                    resCode = seqObj[DEF_CHAR];
                    if (resCode !== undefined) {
                        dbcsCode = resCode; // Found. Write it.
                        nextChar = uCode; // Current character will be written too in the next iteration.
                    }
                    else {
                        // TODO: What if we have no default? (resCode == undefined)
                        // Then, we should write first char of the sequence as-is and try the rest recursively.
                        // Didn't do it for now because no encoding has this situation yet.
                        // Currently, just skip the sequence and write current char.
                    }
                }
                seqObj = undefined;
            }
            else if (uCode >= 0) { // Regular character
                var subtable = this.encodeTable[uCode >> 8];
                if (subtable !== undefined)
                    dbcsCode = subtable[uCode & 0xFF];
                if (dbcsCode <= SEQ_START) { // Sequence start
                    seqObj = this.encodeTableSeq[SEQ_START - dbcsCode];
                    continue;
                }
                if (dbcsCode == UNASSIGNED && this.gb18030) {
                    // Use GB18030 algorithm to find character(s) to write.
                    var idx = findIdx(this.gb18030.uChars, uCode);
                    if (idx != -1) {
                        var dbcsCode = this.gb18030.gbChars[idx] + (uCode - this.gb18030.uChars[idx]);
                        newBuf[j++] = 0x81 + Math.floor(dbcsCode / 12600);
                        dbcsCode = dbcsCode % 12600;
                        newBuf[j++] = 0x30 + Math.floor(dbcsCode / 1260);
                        dbcsCode = dbcsCode % 1260;
                        newBuf[j++] = 0x81 + Math.floor(dbcsCode / 10);
                        dbcsCode = dbcsCode % 10;
                        newBuf[j++] = 0x30 + dbcsCode;
                        continue;
                    }
                }
            }
            // 3. Write dbcsCode character.
            if (dbcsCode === UNASSIGNED)
                dbcsCode = this.defaultCharSingleByte;
            if (dbcsCode < 0x100) {
                newBuf[j++] = dbcsCode;
            }
            else if (dbcsCode < 0x10000) {
                newBuf[j++] = dbcsCode >> 8; // high byte
                newBuf[j++] = dbcsCode & 0xFF; // low byte
            }
            else {
                newBuf[j++] = dbcsCode >> 16;
                newBuf[j++] = (dbcsCode >> 8) & 0xFF;
                newBuf[j++] = dbcsCode & 0xFF;
            }
        }
        this.seqObj = seqObj;
        this.leadSurrogate = leadSurrogate;
        return newBuf.slice(0, j);
    };
    DBCSEncoder.prototype.end = function () {
        if (this.leadSurrogate === -1 && this.seqObj === undefined)
            return; // All clean. Most often case.
        var newBuf = Buffer.alloc(10), j = 0;
        if (this.seqObj) { // We're in the sequence.
            var dbcsCode = this.seqObj[DEF_CHAR];
            if (dbcsCode !== undefined) { // Write beginning of the sequence.
                if (dbcsCode < 0x100) {
                    newBuf[j++] = dbcsCode;
                }
                else {
                    newBuf[j++] = dbcsCode >> 8; // high byte
                    newBuf[j++] = dbcsCode & 0xFF; // low byte
                }
            }
            else {
                // See todo above.
            }
            this.seqObj = undefined;
        }
        if (this.leadSurrogate !== -1) {
            // Incomplete surrogate pair - only lead surrogate found.
            newBuf[j++] = this.defaultCharSingleByte;
            this.leadSurrogate = -1;
        }
        return newBuf.slice(0, j);
    };
    // Export for testing
    DBCSEncoder.prototype.findIdx = findIdx;
    // == Decoder ==================================================================
    function DBCSDecoder(options, codec) {
        // Decoder state
        this.nodeIdx = 0;
        this.prevBuf = Buffer.alloc(0);
        // Static data
        this.decodeTables = codec.decodeTables;
        this.decodeTableSeq = codec.decodeTableSeq;
        this.defaultCharUnicode = codec.defaultCharUnicode;
        this.gb18030 = codec.gb18030;
    }
    DBCSDecoder.prototype.write = function (buf) {
        var newBuf = Buffer.alloc(buf.length * 2), nodeIdx = this.nodeIdx, prevBuf = this.prevBuf, prevBufOffset = this.prevBuf.length, seqStart = -this.prevBuf.length, // idx of the start of current parsed sequence.
        uCode;
        if (prevBufOffset > 0) // Make prev buf overlap a little to make it easier to slice later.
            prevBuf = Buffer.concat([prevBuf, buf.slice(0, 10)]);
        for (var i = 0, j = 0; i < buf.length; i++) {
            var curByte = (i >= 0) ? buf[i] : prevBuf[i + prevBufOffset];
            // Lookup in current trie node.
            var uCode = this.decodeTables[nodeIdx][curByte];
            if (uCode >= 0) {
                // Normal character, just use it.
            }
            else if (uCode === UNASSIGNED) { // Unknown char.
                // TODO: Callback with seq.
                //var curSeq = (seqStart >= 0) ? buf.slice(seqStart, i+1) : prevBuf.slice(seqStart + prevBufOffset, i+1 + prevBufOffset);
                i = seqStart; // Try to parse again, after skipping first byte of the sequence ('i' will be incremented by 'for' cycle).
                uCode = this.defaultCharUnicode.charCodeAt(0);
            }
            else if (uCode === GB18030_CODE) {
                var curSeq = (seqStart >= 0) ? buf.slice(seqStart, i + 1) : prevBuf.slice(seqStart + prevBufOffset, i + 1 + prevBufOffset);
                var ptr = (curSeq[0] - 0x81) * 12600 + (curSeq[1] - 0x30) * 1260 + (curSeq[2] - 0x81) * 10 + (curSeq[3] - 0x30);
                var idx = findIdx(this.gb18030.gbChars, ptr);
                uCode = this.gb18030.uChars[idx] + ptr - this.gb18030.gbChars[idx];
            }
            else if (uCode <= NODE_START) { // Go to next trie node.
                nodeIdx = NODE_START - uCode;
                continue;
            }
            else if (uCode <= SEQ_START) { // Output a sequence of chars.
                var seq = this.decodeTableSeq[SEQ_START - uCode];
                for (var k = 0; k < seq.length - 1; k++) {
                    uCode = seq[k];
                    newBuf[j++] = uCode & 0xFF;
                    newBuf[j++] = uCode >> 8;
                }
                uCode = seq[seq.length - 1];
            }
            else
                throw new Error("iconv-lite internal error: invalid decoding table value " + uCode + " at " + nodeIdx + "/" + curByte);
            // Write the character to buffer, handling higher planes using surrogate pair.
            if (uCode > 0xFFFF) {
                uCode -= 0x10000;
                var uCodeLead = 0xD800 + Math.floor(uCode / 0x400);
                newBuf[j++] = uCodeLead & 0xFF;
                newBuf[j++] = uCodeLead >> 8;
                uCode = 0xDC00 + uCode % 0x400;
            }
            newBuf[j++] = uCode & 0xFF;
            newBuf[j++] = uCode >> 8;
            // Reset trie node.
            nodeIdx = 0;
            seqStart = i + 1;
        }
        this.nodeIdx = nodeIdx;
        this.prevBuf = (seqStart >= 0) ? buf.slice(seqStart) : prevBuf.slice(seqStart + prevBufOffset);
        return newBuf.slice(0, j).toString('ucs2');
    };
    DBCSDecoder.prototype.end = function () {
        var ret = '';
        // Try to parse all remaining chars.
        while (this.prevBuf.length > 0) {
            // Skip 1 character in the buffer.
            ret += this.defaultCharUnicode;
            var buf = this.prevBuf.slice(1);
            // Parse remaining as usual.
            this.prevBuf = Buffer.alloc(0);
            this.nodeIdx = 0;
            if (buf.length > 0)
                ret += this.write(buf);
        }
        this.nodeIdx = 0;
        return ret;
    };
    // Binary search for GB18030. Returns largest i such that table[i] <= val.
    function findIdx(table, val) {
        if (table[0] > val)
            return -1;
        var l = 0, r = table.length;
        while (l < r - 1) { // always table[l] <= val < table[r]
            var mid = l + Math.floor((r - l + 1) / 2);
            if (table[mid] <= val)
                l = mid;
            else
                r = mid;
        }
        return l;
    }
},
/* iconv-lite/encodings/dbcs-data.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    // Description of supported double byte encodings and aliases.
    // Tables are not require()-d until they are needed to speed up library load.
    // require()-s are direct to support Browserify.
    module.exports = {
        // == Japanese/ShiftJIS ====================================================
        // All japanese encodings are based on JIS X set of standards:
        // JIS X 0201 - Single-byte encoding of ASCII + ¥ + Kana chars at 0xA1-0xDF.
        // JIS X 0208 - Main set of 6879 characters, placed in 94x94 plane, to be encoded by 2 bytes. 
        //              Has several variations in 1978, 1983, 1990 and 1997.
        // JIS X 0212 - Supplementary plane of 6067 chars in 94x94 plane. 1990. Effectively dead.
        // JIS X 0213 - Extension and modern replacement of 0208 and 0212. Total chars: 11233.
        //              2 planes, first is superset of 0208, second - revised 0212.
        //              Introduced in 2000, revised 2004. Some characters are in Unicode Plane 2 (0x2xxxx)
        // Byte encodings are:
        //  * Shift_JIS: Compatible with 0201, uses not defined chars in top half as lead bytes for double-byte
        //               encoding of 0208. Lead byte ranges: 0x81-0x9F, 0xE0-0xEF; Trail byte ranges: 0x40-0x7E, 0x80-0x9E, 0x9F-0xFC.
        //               Windows CP932 is a superset of Shift_JIS. Some companies added more chars, notably KDDI.
        //  * EUC-JP:    Up to 3 bytes per character. Used mostly on *nixes.
        //               0x00-0x7F       - lower part of 0201
        //               0x8E, 0xA1-0xDF - upper part of 0201
        //               (0xA1-0xFE)x2   - 0208 plane (94x94).
        //               0x8F, (0xA1-0xFE)x2 - 0212 plane (94x94).
        //  * JIS X 208: 7-bit, direct encoding of 0208. Byte ranges: 0x21-0x7E (94 values). Uncommon.
        //               Used as-is in ISO2022 family.
        //  * ISO2022-JP: Stateful encoding, with escape sequences to switch between ASCII, 
        //                0201-1976 Roman, 0208-1978, 0208-1983.
        //  * ISO2022-JP-1: Adds esc seq for 0212-1990.
        //  * ISO2022-JP-2: Adds esc seq for GB2313-1980, KSX1001-1992, ISO8859-1, ISO8859-7.
        //  * ISO2022-JP-3: Adds esc seq for 0201-1976 Kana set, 0213-2000 Planes 1, 2.
        //  * ISO2022-JP-2004: Adds 0213-2004 Plane 1.
        //
        // After JIS X 0213 appeared, Shift_JIS-2004, EUC-JISX0213 and ISO2022-JP-2004 followed, with just changing the planes.
        //
        // Overall, it seems that it's a mess :( http://www8.plala.or.jp/tkubota1/unicode-symbols-map2.html
        'shiftjis': {
            type: '_dbcs',
            table: function () { return require(96) /* ./tables/shiftjis.json */; },
            encodeAdd: { '\u00a5': 0x5C, '\u203E': 0x7E },
            encodeSkipVals: [{ from: 0xED40, to: 0xF940 }],
        },
        'csshiftjis': 'shiftjis',
        'mskanji': 'shiftjis',
        'sjis': 'shiftjis',
        'windows31j': 'shiftjis',
        'ms31j': 'shiftjis',
        'xsjis': 'shiftjis',
        'windows932': 'shiftjis',
        'ms932': 'shiftjis',
        '932': 'shiftjis',
        'cp932': 'shiftjis',
        'eucjp': {
            type: '_dbcs',
            table: function () { return require(97) /* ./tables/eucjp.json */; },
            encodeAdd: { '\u00a5': 0x5C, '\u203E': 0x7E },
        },
        // TODO: KDDI extension to Shift_JIS
        // TODO: IBM CCSID 942 = CP932, but F0-F9 custom chars and other char changes.
        // TODO: IBM CCSID 943 = Shift_JIS = CP932 with original Shift_JIS lower 128 chars.
        // == Chinese/GBK ==========================================================
        // http://en.wikipedia.org/wiki/GBK
        // We mostly implement W3C recommendation: https://www.w3.org/TR/encoding/#gbk-encoder
        // Oldest GB2312 (1981, ~7600 chars) is a subset of CP936
        'gb2312': 'cp936',
        'gb231280': 'cp936',
        'gb23121980': 'cp936',
        'csgb2312': 'cp936',
        'csiso58gb231280': 'cp936',
        'euccn': 'cp936',
        // Microsoft's CP936 is a subset and approximation of GBK.
        'windows936': 'cp936',
        'ms936': 'cp936',
        '936': 'cp936',
        'cp936': {
            type: '_dbcs',
            table: function () { return require(98) /* ./tables/cp936.json */; },
        },
        // GBK (~22000 chars) is an extension of CP936 that added user-mapped chars and some other.
        'gbk': {
            type: '_dbcs',
            table: function () { return require(98) /* ./tables/cp936.json */.concat(require(99) /* ./tables/gbk-added.json */); },
        },
        'xgbk': 'gbk',
        'isoir58': 'gbk',
        // GB18030 is an algorithmic extension of GBK.
        // Main source: https://www.w3.org/TR/encoding/#gbk-encoder
        // http://icu-project.org/docs/papers/gb18030.html
        // http://source.icu-project.org/repos/icu/data/trunk/charset/data/xml/gb-18030-2000.xml
        // http://www.khngai.com/chinese/charmap/tblgbk.php?page=0
        'gb18030': {
            type: '_dbcs',
            table: function () { return require(98) /* ./tables/cp936.json */.concat(require(99) /* ./tables/gbk-added.json */); },
            gb18030: function () { return require(100) /* ./tables/gb18030-ranges.json */; },
            encodeSkipVals: [0x80],
            encodeAdd: { '€': 0xA2E3 },
        },
        'chinese': 'gb18030',
        // == Korean ===============================================================
        // EUC-KR, KS_C_5601 and KS X 1001 are exactly the same.
        'windows949': 'cp949',
        'ms949': 'cp949',
        '949': 'cp949',
        'cp949': {
            type: '_dbcs',
            table: function () { return require(101) /* ./tables/cp949.json */; },
        },
        'cseuckr': 'cp949',
        'csksc56011987': 'cp949',
        'euckr': 'cp949',
        'isoir149': 'cp949',
        'korean': 'cp949',
        'ksc56011987': 'cp949',
        'ksc56011989': 'cp949',
        'ksc5601': 'cp949',
        // == Big5/Taiwan/Hong Kong ================================================
        // There are lots of tables for Big5 and cp950. Please see the following links for history:
        // http://moztw.org/docs/big5/  http://www.haible.de/bruno/charsets/conversion-tables/Big5.html
        // Variations, in roughly number of defined chars:
        //  * Windows CP 950: Microsoft variant of Big5. Canonical: http://www.unicode.org/Public/MAPPINGS/VENDORS/MICSFT/WINDOWS/CP950.TXT
        //  * Windows CP 951: Microsoft variant of Big5-HKSCS-2001. Seems to be never public. http://me.abelcheung.org/articles/research/what-is-cp951/
        //  * Big5-2003 (Taiwan standard) almost superset of cp950.
        //  * Unicode-at-on (UAO) / Mozilla 1.8. Falling out of use on the Web. Not supported by other browsers.
        //  * Big5-HKSCS (-2001, -2004, -2008). Hong Kong standard. 
        //    many unicode code points moved from PUA to Supplementary plane (U+2XXXX) over the years.
        //    Plus, it has 4 combining sequences.
        //    Seems that Mozilla refused to support it for 10 yrs. https://bugzilla.mozilla.org/show_bug.cgi?id=162431 https://bugzilla.mozilla.org/show_bug.cgi?id=310299
        //    because big5-hkscs is the only encoding to include astral characters in non-algorithmic way.
        //    Implementations are not consistent within browsers; sometimes labeled as just big5.
        //    MS Internet Explorer switches from big5 to big5-hkscs when a patch applied.
        //    Great discussion & recap of what's going on https://bugzilla.mozilla.org/show_bug.cgi?id=912470#c31
        //    In the encoder, it might make sense to support encoding old PUA mappings to Big5 bytes seq-s.
        //    Official spec: http://www.ogcio.gov.hk/en/business/tech_promotion/ccli/terms/doc/2003cmp_2008.txt
        //                   http://www.ogcio.gov.hk/tc/business/tech_promotion/ccli/terms/doc/hkscs-2008-big5-iso.txt
        // 
        // Current understanding of how to deal with Big5(-HKSCS) is in the Encoding Standard, http://encoding.spec.whatwg.org/#big5-encoder
        // Unicode mapping (http://www.unicode.org/Public/MAPPINGS/OBSOLETE/EASTASIA/OTHER/BIG5.TXT) is said to be wrong.
        'windows950': 'cp950',
        'ms950': 'cp950',
        '950': 'cp950',
        'cp950': {
            type: '_dbcs',
            table: function () { return require(102) /* ./tables/cp950.json */; },
        },
        // Big5 has many variations and is an extension of cp950. We use Encoding Standard's as a consensus.
        'big5': 'big5hkscs',
        'big5hkscs': {
            type: '_dbcs',
            table: function () { return require(102) /* ./tables/cp950.json */.concat(require(103) /* ./tables/big5-added.json */); },
            encodeSkipVals: [0xa2cc],
        },
        'cnbig5': 'big5hkscs',
        'csbig5': 'big5hkscs',
        'xxbig5': 'big5hkscs',
    };
},
/* iconv-lite/encodings/tables/shiftjis.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = [
        ["0", "\u0000", 128],
        ["a1", "｡", 62],
        ["8140", "　、。，．・：；？！゛゜´｀¨＾￣＿ヽヾゝゞ〃仝々〆〇ー―‐／＼～∥｜…‥‘’“”（）〔〕［］｛｝〈", 9, "＋－±×"],
        ["8180", "÷＝≠＜＞≦≧∞∴♂♀°′″℃￥＄￠￡％＃＆＊＠§☆★○●◎◇◆□■△▲▽▼※〒→←↑↓〓"],
        ["81b8", "∈∋⊆⊇⊂⊃∪∩"],
        ["81c8", "∧∨￢⇒⇔∀∃"],
        ["81da", "∠⊥⌒∂∇≡≒≪≫√∽∝∵∫∬"],
        ["81f0", "Å‰♯♭♪†‡¶"],
        ["81fc", "◯"],
        ["824f", "０", 9],
        ["8260", "Ａ", 25],
        ["8281", "ａ", 25],
        ["829f", "ぁ", 82],
        ["8340", "ァ", 62],
        ["8380", "ム", 22],
        ["839f", "Α", 16, "Σ", 6],
        ["83bf", "α", 16, "σ", 6],
        ["8440", "А", 5, "ЁЖ", 25],
        ["8470", "а", 5, "ёж", 7],
        ["8480", "о", 17],
        ["849f", "─│┌┐┘└├┬┤┴┼━┃┏┓┛┗┣┳┫┻╋┠┯┨┷┿┝┰┥┸╂"],
        ["8740", "①", 19, "Ⅰ", 9],
        ["875f", "㍉㌔㌢㍍㌘㌧㌃㌶㍑㍗㌍㌦㌣㌫㍊㌻㎜㎝㎞㎎㎏㏄㎡"],
        ["877e", "㍻"],
        ["8780", "〝〟№㏍℡㊤", 4, "㈱㈲㈹㍾㍽㍼≒≡∫∮∑√⊥∠∟⊿∵∩∪"],
        ["889f", "亜唖娃阿哀愛挨姶逢葵茜穐悪握渥旭葦芦鯵梓圧斡扱宛姐虻飴絢綾鮎或粟袷安庵按暗案闇鞍杏以伊位依偉囲夷委威尉惟意慰易椅為畏異移維緯胃萎衣謂違遺医井亥域育郁磯一壱溢逸稲茨芋鰯允印咽員因姻引飲淫胤蔭"],
        ["8940", "院陰隠韻吋右宇烏羽迂雨卯鵜窺丑碓臼渦嘘唄欝蔚鰻姥厩浦瓜閏噂云運雲荏餌叡営嬰影映曳栄永泳洩瑛盈穎頴英衛詠鋭液疫益駅悦謁越閲榎厭円"],
        ["8980", "園堰奄宴延怨掩援沿演炎焔煙燕猿縁艶苑薗遠鉛鴛塩於汚甥凹央奥往応押旺横欧殴王翁襖鴬鴎黄岡沖荻億屋憶臆桶牡乙俺卸恩温穏音下化仮何伽価佳加可嘉夏嫁家寡科暇果架歌河火珂禍禾稼箇花苛茄荷華菓蝦課嘩貨迦過霞蚊俄峨我牙画臥芽蛾賀雅餓駕介会解回塊壊廻快怪悔恢懐戒拐改"],
        ["8a40", "魁晦械海灰界皆絵芥蟹開階貝凱劾外咳害崖慨概涯碍蓋街該鎧骸浬馨蛙垣柿蛎鈎劃嚇各廓拡撹格核殻獲確穫覚角赫較郭閣隔革学岳楽額顎掛笠樫"],
        ["8a80", "橿梶鰍潟割喝恰括活渇滑葛褐轄且鰹叶椛樺鞄株兜竃蒲釜鎌噛鴨栢茅萱粥刈苅瓦乾侃冠寒刊勘勧巻喚堪姦完官寛干幹患感慣憾換敢柑桓棺款歓汗漢澗潅環甘監看竿管簡緩缶翰肝艦莞観諌貫還鑑間閑関陥韓館舘丸含岸巌玩癌眼岩翫贋雁頑顔願企伎危喜器基奇嬉寄岐希幾忌揮机旗既期棋棄"],
        ["8b40", "機帰毅気汽畿祈季稀紀徽規記貴起軌輝飢騎鬼亀偽儀妓宜戯技擬欺犠疑祇義蟻誼議掬菊鞠吉吃喫桔橘詰砧杵黍却客脚虐逆丘久仇休及吸宮弓急救"],
        ["8b80", "朽求汲泣灸球究窮笈級糾給旧牛去居巨拒拠挙渠虚許距鋸漁禦魚亨享京供侠僑兇競共凶協匡卿叫喬境峡強彊怯恐恭挟教橋況狂狭矯胸脅興蕎郷鏡響饗驚仰凝尭暁業局曲極玉桐粁僅勤均巾錦斤欣欽琴禁禽筋緊芹菌衿襟謹近金吟銀九倶句区狗玖矩苦躯駆駈駒具愚虞喰空偶寓遇隅串櫛釧屑屈"],
        ["8c40", "掘窟沓靴轡窪熊隈粂栗繰桑鍬勲君薫訓群軍郡卦袈祁係傾刑兄啓圭珪型契形径恵慶慧憩掲携敬景桂渓畦稽系経継繋罫茎荊蛍計詣警軽頚鶏芸迎鯨"],
        ["8c80", "劇戟撃激隙桁傑欠決潔穴結血訣月件倹倦健兼券剣喧圏堅嫌建憲懸拳捲検権牽犬献研硯絹県肩見謙賢軒遣鍵険顕験鹸元原厳幻弦減源玄現絃舷言諺限乎個古呼固姑孤己庫弧戸故枯湖狐糊袴股胡菰虎誇跨鈷雇顧鼓五互伍午呉吾娯後御悟梧檎瑚碁語誤護醐乞鯉交佼侯候倖光公功効勾厚口向"],
        ["8d40", "后喉坑垢好孔孝宏工巧巷幸広庚康弘恒慌抗拘控攻昂晃更杭校梗構江洪浩港溝甲皇硬稿糠紅紘絞綱耕考肯肱腔膏航荒行衡講貢購郊酵鉱砿鋼閤降"],
        ["8d80", "項香高鴻剛劫号合壕拷濠豪轟麹克刻告国穀酷鵠黒獄漉腰甑忽惚骨狛込此頃今困坤墾婚恨懇昏昆根梱混痕紺艮魂些佐叉唆嵯左差査沙瑳砂詐鎖裟坐座挫債催再最哉塞妻宰彩才採栽歳済災采犀砕砦祭斎細菜裁載際剤在材罪財冴坂阪堺榊肴咲崎埼碕鷺作削咋搾昨朔柵窄策索錯桜鮭笹匙冊刷"],
        ["8e40", "察拶撮擦札殺薩雑皐鯖捌錆鮫皿晒三傘参山惨撒散桟燦珊産算纂蚕讃賛酸餐斬暫残仕仔伺使刺司史嗣四士始姉姿子屍市師志思指支孜斯施旨枝止"],
        ["8e80", "死氏獅祉私糸紙紫肢脂至視詞詩試誌諮資賜雌飼歯事似侍児字寺慈持時次滋治爾璽痔磁示而耳自蒔辞汐鹿式識鴫竺軸宍雫七叱執失嫉室悉湿漆疾質実蔀篠偲柴芝屡蕊縞舎写射捨赦斜煮社紗者謝車遮蛇邪借勺尺杓灼爵酌釈錫若寂弱惹主取守手朱殊狩珠種腫趣酒首儒受呪寿授樹綬需囚収周"],
        ["8f40", "宗就州修愁拾洲秀秋終繍習臭舟蒐衆襲讐蹴輯週酋酬集醜什住充十従戎柔汁渋獣縦重銃叔夙宿淑祝縮粛塾熟出術述俊峻春瞬竣舜駿准循旬楯殉淳"],
        ["8f80", "準潤盾純巡遵醇順処初所暑曙渚庶緒署書薯藷諸助叙女序徐恕鋤除傷償勝匠升召哨商唱嘗奨妾娼宵将小少尚庄床廠彰承抄招掌捷昇昌昭晶松梢樟樵沼消渉湘焼焦照症省硝礁祥称章笑粧紹肖菖蒋蕉衝裳訟証詔詳象賞醤鉦鍾鐘障鞘上丈丞乗冗剰城場壌嬢常情擾条杖浄状畳穣蒸譲醸錠嘱埴飾"],
        ["9040", "拭植殖燭織職色触食蝕辱尻伸信侵唇娠寝審心慎振新晋森榛浸深申疹真神秦紳臣芯薪親診身辛進針震人仁刃塵壬尋甚尽腎訊迅陣靭笥諏須酢図厨"],
        ["9080", "逗吹垂帥推水炊睡粋翠衰遂酔錐錘随瑞髄崇嵩数枢趨雛据杉椙菅頗雀裾澄摺寸世瀬畝是凄制勢姓征性成政整星晴棲栖正清牲生盛精聖声製西誠誓請逝醒青静斉税脆隻席惜戚斥昔析石積籍績脊責赤跡蹟碩切拙接摂折設窃節説雪絶舌蝉仙先千占宣専尖川戦扇撰栓栴泉浅洗染潜煎煽旋穿箭線"],
        ["9140", "繊羨腺舛船薦詮賎践選遷銭銑閃鮮前善漸然全禅繕膳糎噌塑岨措曾曽楚狙疏疎礎祖租粗素組蘇訴阻遡鼠僧創双叢倉喪壮奏爽宋層匝惣想捜掃挿掻"],
        ["9180", "操早曹巣槍槽漕燥争痩相窓糟総綜聡草荘葬蒼藻装走送遭鎗霜騒像増憎臓蔵贈造促側則即息捉束測足速俗属賊族続卒袖其揃存孫尊損村遜他多太汰詑唾堕妥惰打柁舵楕陀駄騨体堆対耐岱帯待怠態戴替泰滞胎腿苔袋貸退逮隊黛鯛代台大第醍題鷹滝瀧卓啄宅托択拓沢濯琢託鐸濁諾茸凧蛸只"],
        ["9240", "叩但達辰奪脱巽竪辿棚谷狸鱈樽誰丹単嘆坦担探旦歎淡湛炭短端箪綻耽胆蛋誕鍛団壇弾断暖檀段男談値知地弛恥智池痴稚置致蜘遅馳築畜竹筑蓄"],
        ["9280", "逐秩窒茶嫡着中仲宙忠抽昼柱注虫衷註酎鋳駐樗瀦猪苧著貯丁兆凋喋寵帖帳庁弔張彫徴懲挑暢朝潮牒町眺聴脹腸蝶調諜超跳銚長頂鳥勅捗直朕沈珍賃鎮陳津墜椎槌追鎚痛通塚栂掴槻佃漬柘辻蔦綴鍔椿潰坪壷嬬紬爪吊釣鶴亭低停偵剃貞呈堤定帝底庭廷弟悌抵挺提梯汀碇禎程締艇訂諦蹄逓"],
        ["9340", "邸鄭釘鼎泥摘擢敵滴的笛適鏑溺哲徹撤轍迭鉄典填天展店添纏甜貼転顛点伝殿澱田電兎吐堵塗妬屠徒斗杜渡登菟賭途都鍍砥砺努度土奴怒倒党冬"],
        ["9380", "凍刀唐塔塘套宕島嶋悼投搭東桃梼棟盗淘湯涛灯燈当痘祷等答筒糖統到董蕩藤討謄豆踏逃透鐙陶頭騰闘働動同堂導憧撞洞瞳童胴萄道銅峠鴇匿得徳涜特督禿篤毒独読栃橡凸突椴届鳶苫寅酉瀞噸屯惇敦沌豚遁頓呑曇鈍奈那内乍凪薙謎灘捺鍋楢馴縄畷南楠軟難汝二尼弐迩匂賑肉虹廿日乳入"],
        ["9440", "如尿韮任妊忍認濡禰祢寧葱猫熱年念捻撚燃粘乃廼之埜嚢悩濃納能脳膿農覗蚤巴把播覇杷波派琶破婆罵芭馬俳廃拝排敗杯盃牌背肺輩配倍培媒梅"],
        ["9480", "楳煤狽買売賠陪這蝿秤矧萩伯剥博拍柏泊白箔粕舶薄迫曝漠爆縛莫駁麦函箱硲箸肇筈櫨幡肌畑畠八鉢溌発醗髪伐罰抜筏閥鳩噺塙蛤隼伴判半反叛帆搬斑板氾汎版犯班畔繁般藩販範釆煩頒飯挽晩番盤磐蕃蛮匪卑否妃庇彼悲扉批披斐比泌疲皮碑秘緋罷肥被誹費避非飛樋簸備尾微枇毘琵眉美"],
        ["9540", "鼻柊稗匹疋髭彦膝菱肘弼必畢筆逼桧姫媛紐百謬俵彪標氷漂瓢票表評豹廟描病秒苗錨鋲蒜蛭鰭品彬斌浜瀕貧賓頻敏瓶不付埠夫婦富冨布府怖扶敷"],
        ["9580", "斧普浮父符腐膚芙譜負賦赴阜附侮撫武舞葡蕪部封楓風葺蕗伏副復幅服福腹複覆淵弗払沸仏物鮒分吻噴墳憤扮焚奮粉糞紛雰文聞丙併兵塀幣平弊柄並蔽閉陛米頁僻壁癖碧別瞥蔑箆偏変片篇編辺返遍便勉娩弁鞭保舗鋪圃捕歩甫補輔穂募墓慕戊暮母簿菩倣俸包呆報奉宝峰峯崩庖抱捧放方朋"],
        ["9640", "法泡烹砲縫胞芳萌蓬蜂褒訪豊邦鋒飽鳳鵬乏亡傍剖坊妨帽忘忙房暴望某棒冒紡肪膨謀貌貿鉾防吠頬北僕卜墨撲朴牧睦穆釦勃没殆堀幌奔本翻凡盆"],
        ["9680", "摩磨魔麻埋妹昧枚毎哩槙幕膜枕鮪柾鱒桝亦俣又抹末沫迄侭繭麿万慢満漫蔓味未魅巳箕岬密蜜湊蓑稔脈妙粍民眠務夢無牟矛霧鵡椋婿娘冥名命明盟迷銘鳴姪牝滅免棉綿緬面麺摸模茂妄孟毛猛盲網耗蒙儲木黙目杢勿餅尤戻籾貰問悶紋門匁也冶夜爺耶野弥矢厄役約薬訳躍靖柳薮鑓愉愈油癒"],
        ["9740", "諭輸唯佑優勇友宥幽悠憂揖有柚湧涌猶猷由祐裕誘遊邑郵雄融夕予余与誉輿預傭幼妖容庸揚揺擁曜楊様洋溶熔用窯羊耀葉蓉要謡踊遥陽養慾抑欲"],
        ["9780", "沃浴翌翼淀羅螺裸来莱頼雷洛絡落酪乱卵嵐欄濫藍蘭覧利吏履李梨理璃痢裏裡里離陸律率立葎掠略劉流溜琉留硫粒隆竜龍侶慮旅虜了亮僚両凌寮料梁涼猟療瞭稜糧良諒遼量陵領力緑倫厘林淋燐琳臨輪隣鱗麟瑠塁涙累類令伶例冷励嶺怜玲礼苓鈴隷零霊麗齢暦歴列劣烈裂廉恋憐漣煉簾練聯"],
        ["9840", "蓮連錬呂魯櫓炉賂路露労婁廊弄朗楼榔浪漏牢狼篭老聾蝋郎六麓禄肋録論倭和話歪賄脇惑枠鷲亙亘鰐詫藁蕨椀湾碗腕"],
        ["989f", "弌丐丕个丱丶丼丿乂乖乘亂亅豫亊舒弍于亞亟亠亢亰亳亶从仍仄仆仂仗仞仭仟价伉佚估佛佝佗佇佶侈侏侘佻佩佰侑佯來侖儘俔俟俎俘俛俑俚俐俤俥倚倨倔倪倥倅伜俶倡倩倬俾俯們倆偃假會偕偐偈做偖偬偸傀傚傅傴傲"],
        ["9940", "僉僊傳僂僖僞僥僭僣僮價僵儉儁儂儖儕儔儚儡儺儷儼儻儿兀兒兌兔兢竸兩兪兮冀冂囘册冉冏冑冓冕冖冤冦冢冩冪冫决冱冲冰况冽凅凉凛几處凩凭"],
        ["9980", "凰凵凾刄刋刔刎刧刪刮刳刹剏剄剋剌剞剔剪剴剩剳剿剽劍劔劒剱劈劑辨辧劬劭劼劵勁勍勗勞勣勦飭勠勳勵勸勹匆匈甸匍匐匏匕匚匣匯匱匳匸區卆卅丗卉卍凖卞卩卮夘卻卷厂厖厠厦厥厮厰厶參簒雙叟曼燮叮叨叭叺吁吽呀听吭吼吮吶吩吝呎咏呵咎呟呱呷呰咒呻咀呶咄咐咆哇咢咸咥咬哄哈咨"],
        ["9a40", "咫哂咤咾咼哘哥哦唏唔哽哮哭哺哢唹啀啣啌售啜啅啖啗唸唳啝喙喀咯喊喟啻啾喘喞單啼喃喩喇喨嗚嗅嗟嗄嗜嗤嗔嘔嗷嘖嗾嗽嘛嗹噎噐營嘴嘶嘲嘸"],
        ["9a80", "噫噤嘯噬噪嚆嚀嚊嚠嚔嚏嚥嚮嚶嚴囂嚼囁囃囀囈囎囑囓囗囮囹圀囿圄圉圈國圍圓團圖嗇圜圦圷圸坎圻址坏坩埀垈坡坿垉垓垠垳垤垪垰埃埆埔埒埓堊埖埣堋堙堝塲堡塢塋塰毀塒堽塹墅墹墟墫墺壞墻墸墮壅壓壑壗壙壘壥壜壤壟壯壺壹壻壼壽夂夊夐夛梦夥夬夭夲夸夾竒奕奐奎奚奘奢奠奧奬奩"],
        ["9b40", "奸妁妝佞侫妣妲姆姨姜妍姙姚娥娟娑娜娉娚婀婬婉娵娶婢婪媚媼媾嫋嫂媽嫣嫗嫦嫩嫖嫺嫻嬌嬋嬖嬲嫐嬪嬶嬾孃孅孀孑孕孚孛孥孩孰孳孵學斈孺宀"],
        ["9b80", "它宦宸寃寇寉寔寐寤實寢寞寥寫寰寶寳尅將專對尓尠尢尨尸尹屁屆屎屓屐屏孱屬屮乢屶屹岌岑岔妛岫岻岶岼岷峅岾峇峙峩峽峺峭嶌峪崋崕崗嵜崟崛崑崔崢崚崙崘嵌嵒嵎嵋嵬嵳嵶嶇嶄嶂嶢嶝嶬嶮嶽嶐嶷嶼巉巍巓巒巖巛巫已巵帋帚帙帑帛帶帷幄幃幀幎幗幔幟幢幤幇幵并幺麼广庠廁廂廈廐廏"],
        ["9c40", "廖廣廝廚廛廢廡廨廩廬廱廳廰廴廸廾弃弉彝彜弋弑弖弩弭弸彁彈彌彎弯彑彖彗彙彡彭彳彷徃徂彿徊很徑徇從徙徘徠徨徭徼忖忻忤忸忱忝悳忿怡恠"],
        ["9c80", "怙怐怩怎怱怛怕怫怦怏怺恚恁恪恷恟恊恆恍恣恃恤恂恬恫恙悁悍惧悃悚悄悛悖悗悒悧悋惡悸惠惓悴忰悽惆悵惘慍愕愆惶惷愀惴惺愃愡惻惱愍愎慇愾愨愧慊愿愼愬愴愽慂慄慳慷慘慙慚慫慴慯慥慱慟慝慓慵憙憖憇憬憔憚憊憑憫憮懌懊應懷懈懃懆憺懋罹懍懦懣懶懺懴懿懽懼懾戀戈戉戍戌戔戛"],
        ["9d40", "戞戡截戮戰戲戳扁扎扞扣扛扠扨扼抂抉找抒抓抖拔抃抔拗拑抻拏拿拆擔拈拜拌拊拂拇抛拉挌拮拱挧挂挈拯拵捐挾捍搜捏掖掎掀掫捶掣掏掉掟掵捫"],
        ["9d80", "捩掾揩揀揆揣揉插揶揄搖搴搆搓搦搶攝搗搨搏摧摯摶摎攪撕撓撥撩撈撼據擒擅擇撻擘擂擱擧舉擠擡抬擣擯攬擶擴擲擺攀擽攘攜攅攤攣攫攴攵攷收攸畋效敖敕敍敘敞敝敲數斂斃變斛斟斫斷旃旆旁旄旌旒旛旙无旡旱杲昊昃旻杳昵昶昴昜晏晄晉晁晞晝晤晧晨晟晢晰暃暈暎暉暄暘暝曁暹曉暾暼"],
        ["9e40", "曄暸曖曚曠昿曦曩曰曵曷朏朖朞朦朧霸朮朿朶杁朸朷杆杞杠杙杣杤枉杰枩杼杪枌枋枦枡枅枷柯枴柬枳柩枸柤柞柝柢柮枹柎柆柧檜栞框栩桀桍栲桎"],
        ["9e80", "梳栫桙档桷桿梟梏梭梔條梛梃檮梹桴梵梠梺椏梍桾椁棊椈棘椢椦棡椌棍棔棧棕椶椒椄棗棣椥棹棠棯椨椪椚椣椡棆楹楷楜楸楫楔楾楮椹楴椽楙椰楡楞楝榁楪榲榮槐榿槁槓榾槎寨槊槝榻槃榧樮榑榠榜榕榴槞槨樂樛槿權槹槲槧樅榱樞槭樔槫樊樒櫁樣樓橄樌橲樶橸橇橢橙橦橈樸樢檐檍檠檄檢檣"],
        ["9f40", "檗蘗檻櫃櫂檸檳檬櫞櫑櫟檪櫚櫪櫻欅蘖櫺欒欖鬱欟欸欷盜欹飮歇歃歉歐歙歔歛歟歡歸歹歿殀殄殃殍殘殕殞殤殪殫殯殲殱殳殷殼毆毋毓毟毬毫毳毯"],
        ["9f80", "麾氈氓气氛氤氣汞汕汢汪沂沍沚沁沛汾汨汳沒沐泄泱泓沽泗泅泝沮沱沾沺泛泯泙泪洟衍洶洫洽洸洙洵洳洒洌浣涓浤浚浹浙涎涕濤涅淹渕渊涵淇淦涸淆淬淞淌淨淒淅淺淙淤淕淪淮渭湮渮渙湲湟渾渣湫渫湶湍渟湃渺湎渤滿渝游溂溪溘滉溷滓溽溯滄溲滔滕溏溥滂溟潁漑灌滬滸滾漿滲漱滯漲滌"],
        ["e040", "漾漓滷澆潺潸澁澀潯潛濳潭澂潼潘澎澑濂潦澳澣澡澤澹濆澪濟濕濬濔濘濱濮濛瀉瀋濺瀑瀁瀏濾瀛瀚潴瀝瀘瀟瀰瀾瀲灑灣炙炒炯烱炬炸炳炮烟烋烝"],
        ["e080", "烙焉烽焜焙煥煕熈煦煢煌煖煬熏燻熄熕熨熬燗熹熾燒燉燔燎燠燬燧燵燼燹燿爍爐爛爨爭爬爰爲爻爼爿牀牆牋牘牴牾犂犁犇犒犖犢犧犹犲狃狆狄狎狒狢狠狡狹狷倏猗猊猜猖猝猴猯猩猥猾獎獏默獗獪獨獰獸獵獻獺珈玳珎玻珀珥珮珞璢琅瑯琥珸琲琺瑕琿瑟瑙瑁瑜瑩瑰瑣瑪瑶瑾璋璞璧瓊瓏瓔珱"],
        ["e140", "瓠瓣瓧瓩瓮瓲瓰瓱瓸瓷甄甃甅甌甎甍甕甓甞甦甬甼畄畍畊畉畛畆畚畩畤畧畫畭畸當疆疇畴疊疉疂疔疚疝疥疣痂疳痃疵疽疸疼疱痍痊痒痙痣痞痾痿"],
        ["e180", "痼瘁痰痺痲痳瘋瘍瘉瘟瘧瘠瘡瘢瘤瘴瘰瘻癇癈癆癜癘癡癢癨癩癪癧癬癰癲癶癸發皀皃皈皋皎皖皓皙皚皰皴皸皹皺盂盍盖盒盞盡盥盧盪蘯盻眈眇眄眩眤眞眥眦眛眷眸睇睚睨睫睛睥睿睾睹瞎瞋瞑瞠瞞瞰瞶瞹瞿瞼瞽瞻矇矍矗矚矜矣矮矼砌砒礦砠礪硅碎硴碆硼碚碌碣碵碪碯磑磆磋磔碾碼磅磊磬"],
        ["e240", "磧磚磽磴礇礒礑礙礬礫祀祠祗祟祚祕祓祺祿禊禝禧齋禪禮禳禹禺秉秕秧秬秡秣稈稍稘稙稠稟禀稱稻稾稷穃穗穉穡穢穩龝穰穹穽窈窗窕窘窖窩竈窰"],
        ["e280", "窶竅竄窿邃竇竊竍竏竕竓站竚竝竡竢竦竭竰笂笏笊笆笳笘笙笞笵笨笶筐筺笄筍笋筌筅筵筥筴筧筰筱筬筮箝箘箟箍箜箚箋箒箏筝箙篋篁篌篏箴篆篝篩簑簔篦篥籠簀簇簓篳篷簗簍篶簣簧簪簟簷簫簽籌籃籔籏籀籐籘籟籤籖籥籬籵粃粐粤粭粢粫粡粨粳粲粱粮粹粽糀糅糂糘糒糜糢鬻糯糲糴糶糺紆"],
        ["e340", "紂紜紕紊絅絋紮紲紿紵絆絳絖絎絲絨絮絏絣經綉絛綏絽綛綺綮綣綵緇綽綫總綢綯緜綸綟綰緘緝緤緞緻緲緡縅縊縣縡縒縱縟縉縋縢繆繦縻縵縹繃縷"],
        ["e380", "縲縺繧繝繖繞繙繚繹繪繩繼繻纃緕繽辮繿纈纉續纒纐纓纔纖纎纛纜缸缺罅罌罍罎罐网罕罔罘罟罠罨罩罧罸羂羆羃羈羇羌羔羞羝羚羣羯羲羹羮羶羸譱翅翆翊翕翔翡翦翩翳翹飜耆耄耋耒耘耙耜耡耨耿耻聊聆聒聘聚聟聢聨聳聲聰聶聹聽聿肄肆肅肛肓肚肭冐肬胛胥胙胝胄胚胖脉胯胱脛脩脣脯腋"],
        ["e440", "隋腆脾腓腑胼腱腮腥腦腴膃膈膊膀膂膠膕膤膣腟膓膩膰膵膾膸膽臀臂膺臉臍臑臙臘臈臚臟臠臧臺臻臾舁舂舅與舊舍舐舖舩舫舸舳艀艙艘艝艚艟艤"],
        ["e480", "艢艨艪艫舮艱艷艸艾芍芒芫芟芻芬苡苣苟苒苴苳苺莓范苻苹苞茆苜茉苙茵茴茖茲茱荀茹荐荅茯茫茗茘莅莚莪莟莢莖茣莎莇莊荼莵荳荵莠莉莨菴萓菫菎菽萃菘萋菁菷萇菠菲萍萢萠莽萸蔆菻葭萪萼蕚蒄葷葫蒭葮蒂葩葆萬葯葹萵蓊葢蒹蒿蒟蓙蓍蒻蓚蓐蓁蓆蓖蒡蔡蓿蓴蔗蔘蔬蔟蔕蔔蓼蕀蕣蕘蕈"],
        ["e540", "蕁蘂蕋蕕薀薤薈薑薊薨蕭薔薛藪薇薜蕷蕾薐藉薺藏薹藐藕藝藥藜藹蘊蘓蘋藾藺蘆蘢蘚蘰蘿虍乕虔號虧虱蚓蚣蚩蚪蚋蚌蚶蚯蛄蛆蚰蛉蠣蚫蛔蛞蛩蛬"],
        ["e580", "蛟蛛蛯蜒蜆蜈蜀蜃蛻蜑蜉蜍蛹蜊蜴蜿蜷蜻蜥蜩蜚蝠蝟蝸蝌蝎蝴蝗蝨蝮蝙蝓蝣蝪蠅螢螟螂螯蟋螽蟀蟐雖螫蟄螳蟇蟆螻蟯蟲蟠蠏蠍蟾蟶蟷蠎蟒蠑蠖蠕蠢蠡蠱蠶蠹蠧蠻衄衂衒衙衞衢衫袁衾袞衵衽袵衲袂袗袒袮袙袢袍袤袰袿袱裃裄裔裘裙裝裹褂裼裴裨裲褄褌褊褓襃褞褥褪褫襁襄褻褶褸襌褝襠襞"],
        ["e640", "襦襤襭襪襯襴襷襾覃覈覊覓覘覡覩覦覬覯覲覺覽覿觀觚觜觝觧觴觸訃訖訐訌訛訝訥訶詁詛詒詆詈詼詭詬詢誅誂誄誨誡誑誥誦誚誣諄諍諂諚諫諳諧"],
        ["e680", "諤諱謔諠諢諷諞諛謌謇謚諡謖謐謗謠謳鞫謦謫謾謨譁譌譏譎證譖譛譚譫譟譬譯譴譽讀讌讎讒讓讖讙讚谺豁谿豈豌豎豐豕豢豬豸豺貂貉貅貊貍貎貔豼貘戝貭貪貽貲貳貮貶賈賁賤賣賚賽賺賻贄贅贊贇贏贍贐齎贓賍贔贖赧赭赱赳趁趙跂趾趺跏跚跖跌跛跋跪跫跟跣跼踈踉跿踝踞踐踟蹂踵踰踴蹊"],
        ["e740", "蹇蹉蹌蹐蹈蹙蹤蹠踪蹣蹕蹶蹲蹼躁躇躅躄躋躊躓躑躔躙躪躡躬躰軆躱躾軅軈軋軛軣軼軻軫軾輊輅輕輒輙輓輜輟輛輌輦輳輻輹轅轂輾轌轉轆轎轗轜"],
        ["e780", "轢轣轤辜辟辣辭辯辷迚迥迢迪迯邇迴逅迹迺逑逕逡逍逞逖逋逧逶逵逹迸遏遐遑遒逎遉逾遖遘遞遨遯遶隨遲邂遽邁邀邊邉邏邨邯邱邵郢郤扈郛鄂鄒鄙鄲鄰酊酖酘酣酥酩酳酲醋醉醂醢醫醯醪醵醴醺釀釁釉釋釐釖釟釡釛釼釵釶鈞釿鈔鈬鈕鈑鉞鉗鉅鉉鉤鉈銕鈿鉋鉐銜銖銓銛鉚鋏銹銷鋩錏鋺鍄錮"],
        ["e840", "錙錢錚錣錺錵錻鍜鍠鍼鍮鍖鎰鎬鎭鎔鎹鏖鏗鏨鏥鏘鏃鏝鏐鏈鏤鐚鐔鐓鐃鐇鐐鐶鐫鐵鐡鐺鑁鑒鑄鑛鑠鑢鑞鑪鈩鑰鑵鑷鑽鑚鑼鑾钁鑿閂閇閊閔閖閘閙"],
        ["e880", "閠閨閧閭閼閻閹閾闊濶闃闍闌闕闔闖關闡闥闢阡阨阮阯陂陌陏陋陷陜陞陝陟陦陲陬隍隘隕隗險隧隱隲隰隴隶隸隹雎雋雉雍襍雜霍雕雹霄霆霈霓霎霑霏霖霙霤霪霰霹霽霾靄靆靈靂靉靜靠靤靦靨勒靫靱靹鞅靼鞁靺鞆鞋鞏鞐鞜鞨鞦鞣鞳鞴韃韆韈韋韜韭齏韲竟韶韵頏頌頸頤頡頷頽顆顏顋顫顯顰"],
        ["e940", "顱顴顳颪颯颱颶飄飃飆飩飫餃餉餒餔餘餡餝餞餤餠餬餮餽餾饂饉饅饐饋饑饒饌饕馗馘馥馭馮馼駟駛駝駘駑駭駮駱駲駻駸騁騏騅駢騙騫騷驅驂驀驃"],
        ["e980", "騾驕驍驛驗驟驢驥驤驩驫驪骭骰骼髀髏髑髓體髞髟髢髣髦髯髫髮髴髱髷髻鬆鬘鬚鬟鬢鬣鬥鬧鬨鬩鬪鬮鬯鬲魄魃魏魍魎魑魘魴鮓鮃鮑鮖鮗鮟鮠鮨鮴鯀鯊鮹鯆鯏鯑鯒鯣鯢鯤鯔鯡鰺鯲鯱鯰鰕鰔鰉鰓鰌鰆鰈鰒鰊鰄鰮鰛鰥鰤鰡鰰鱇鰲鱆鰾鱚鱠鱧鱶鱸鳧鳬鳰鴉鴈鳫鴃鴆鴪鴦鶯鴣鴟鵄鴕鴒鵁鴿鴾鵆鵈"],
        ["ea40", "鵝鵞鵤鵑鵐鵙鵲鶉鶇鶫鵯鵺鶚鶤鶩鶲鷄鷁鶻鶸鶺鷆鷏鷂鷙鷓鷸鷦鷭鷯鷽鸚鸛鸞鹵鹹鹽麁麈麋麌麒麕麑麝麥麩麸麪麭靡黌黎黏黐黔黜點黝黠黥黨黯"],
        ["ea80", "黴黶黷黹黻黼黽鼇鼈皷鼕鼡鼬鼾齊齒齔齣齟齠齡齦齧齬齪齷齲齶龕龜龠堯槇遙瑤凜熙"],
        ["ed40", "纊褜鍈銈蓜俉炻昱棈鋹曻彅丨仡仼伀伃伹佖侒侊侚侔俍偀倢俿倞偆偰偂傔僴僘兊兤冝冾凬刕劜劦勀勛匀匇匤卲厓厲叝﨎咜咊咩哿喆坙坥垬埈埇﨏"],
        ["ed80", "塚增墲夋奓奛奝奣妤妺孖寀甯寘寬尞岦岺峵崧嵓﨑嵂嵭嶸嶹巐弡弴彧德忞恝悅悊惞惕愠惲愑愷愰憘戓抦揵摠撝擎敎昀昕昻昉昮昞昤晥晗晙晴晳暙暠暲暿曺朎朗杦枻桒柀栁桄棏﨓楨﨔榘槢樰橫橆橳橾櫢櫤毖氿汜沆汯泚洄涇浯涖涬淏淸淲淼渹湜渧渼溿澈澵濵瀅瀇瀨炅炫焏焄煜煆煇凞燁燾犱"],
        ["ee40", "犾猤猪獷玽珉珖珣珒琇珵琦琪琩琮瑢璉璟甁畯皂皜皞皛皦益睆劯砡硎硤硺礰礼神祥禔福禛竑竧靖竫箞精絈絜綷綠緖繒罇羡羽茁荢荿菇菶葈蒴蕓蕙"],
        ["ee80", "蕫﨟薰蘒﨡蠇裵訒訷詹誧誾諟諸諶譓譿賰賴贒赶﨣軏﨤逸遧郞都鄕鄧釚釗釞釭釮釤釥鈆鈐鈊鈺鉀鈼鉎鉙鉑鈹鉧銧鉷鉸鋧鋗鋙鋐﨧鋕鋠鋓錥錡鋻﨨錞鋿錝錂鍰鍗鎤鏆鏞鏸鐱鑅鑈閒隆﨩隝隯霳霻靃靍靏靑靕顗顥飯飼餧館馞驎髙髜魵魲鮏鮱鮻鰀鵰鵫鶴鸙黑"],
        ["eeef", "ⅰ", 9, "￢￤＇＂"],
        ["f040", "", 62],
        ["f080", "", 124],
        ["f140", "", 62],
        ["f180", "", 124],
        ["f240", "", 62],
        ["f280", "", 124],
        ["f340", "", 62],
        ["f380", "", 124],
        ["f440", "", 62],
        ["f480", "", 124],
        ["f540", "", 62],
        ["f580", "", 124],
        ["f640", "", 62],
        ["f680", "", 124],
        ["f740", "", 62],
        ["f780", "", 124],
        ["f840", "", 62],
        ["f880", "", 124],
        ["f940", ""],
        ["fa40", "ⅰ", 9, "Ⅰ", 9, "￢￤＇＂㈱№℡∵纊褜鍈銈蓜俉炻昱棈鋹曻彅丨仡仼伀伃伹佖侒侊侚侔俍偀倢俿倞偆偰偂傔僴僘兊"],
        ["fa80", "兤冝冾凬刕劜劦勀勛匀匇匤卲厓厲叝﨎咜咊咩哿喆坙坥垬埈埇﨏塚增墲夋奓奛奝奣妤妺孖寀甯寘寬尞岦岺峵崧嵓﨑嵂嵭嶸嶹巐弡弴彧德忞恝悅悊惞惕愠惲愑愷愰憘戓抦揵摠撝擎敎昀昕昻昉昮昞昤晥晗晙晴晳暙暠暲暿曺朎朗杦枻桒柀栁桄棏﨓楨﨔榘槢樰橫橆橳橾櫢櫤毖氿汜沆汯泚洄涇浯"],
        ["fb40", "涖涬淏淸淲淼渹湜渧渼溿澈澵濵瀅瀇瀨炅炫焏焄煜煆煇凞燁燾犱犾猤猪獷玽珉珖珣珒琇珵琦琪琩琮瑢璉璟甁畯皂皜皞皛皦益睆劯砡硎硤硺礰礼神"],
        ["fb80", "祥禔福禛竑竧靖竫箞精絈絜綷綠緖繒罇羡羽茁荢荿菇菶葈蒴蕓蕙蕫﨟薰蘒﨡蠇裵訒訷詹誧誾諟諸諶譓譿賰賴贒赶﨣軏﨤逸遧郞都鄕鄧釚釗釞釭釮釤釥鈆鈐鈊鈺鉀鈼鉎鉙鉑鈹鉧銧鉷鉸鋧鋗鋙鋐﨧鋕鋠鋓錥錡鋻﨨錞鋿錝錂鍰鍗鎤鏆鏞鏸鐱鑅鑈閒隆﨩隝隯霳霻靃靍靏靑靕顗顥飯飼餧館馞驎髙"],
        ["fc40", "髜魵魲鮏鮱鮻鰀鵰鵫鶴鸙黑"]
    ];
    module.exports = json;
},
/* iconv-lite/encodings/tables/eucjp.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = [
        ["0", "\u0000", 127],
        ["8ea1", "｡", 62],
        ["a1a1", "　、。，．・：；？！゛゜´｀¨＾￣＿ヽヾゝゞ〃仝々〆〇ー―‐／＼～∥｜…‥‘’“”（）〔〕［］｛｝〈", 9, "＋－±×÷＝≠＜＞≦≧∞∴♂♀°′″℃￥＄￠￡％＃＆＊＠§☆★○●◎◇"],
        ["a2a1", "◆□■△▲▽▼※〒→←↑↓〓"],
        ["a2ba", "∈∋⊆⊇⊂⊃∪∩"],
        ["a2ca", "∧∨￢⇒⇔∀∃"],
        ["a2dc", "∠⊥⌒∂∇≡≒≪≫√∽∝∵∫∬"],
        ["a2f2", "Å‰♯♭♪†‡¶"],
        ["a2fe", "◯"],
        ["a3b0", "０", 9],
        ["a3c1", "Ａ", 25],
        ["a3e1", "ａ", 25],
        ["a4a1", "ぁ", 82],
        ["a5a1", "ァ", 85],
        ["a6a1", "Α", 16, "Σ", 6],
        ["a6c1", "α", 16, "σ", 6],
        ["a7a1", "А", 5, "ЁЖ", 25],
        ["a7d1", "а", 5, "ёж", 25],
        ["a8a1", "─│┌┐┘└├┬┤┴┼━┃┏┓┛┗┣┳┫┻╋┠┯┨┷┿┝┰┥┸╂"],
        ["ada1", "①", 19, "Ⅰ", 9],
        ["adc0", "㍉㌔㌢㍍㌘㌧㌃㌶㍑㍗㌍㌦㌣㌫㍊㌻㎜㎝㎞㎎㎏㏄㎡"],
        ["addf", "㍻〝〟№㏍℡㊤", 4, "㈱㈲㈹㍾㍽㍼≒≡∫∮∑√⊥∠∟⊿∵∩∪"],
        ["b0a1", "亜唖娃阿哀愛挨姶逢葵茜穐悪握渥旭葦芦鯵梓圧斡扱宛姐虻飴絢綾鮎或粟袷安庵按暗案闇鞍杏以伊位依偉囲夷委威尉惟意慰易椅為畏異移維緯胃萎衣謂違遺医井亥域育郁磯一壱溢逸稲茨芋鰯允印咽員因姻引飲淫胤蔭"],
        ["b1a1", "院陰隠韻吋右宇烏羽迂雨卯鵜窺丑碓臼渦嘘唄欝蔚鰻姥厩浦瓜閏噂云運雲荏餌叡営嬰影映曳栄永泳洩瑛盈穎頴英衛詠鋭液疫益駅悦謁越閲榎厭円園堰奄宴延怨掩援沿演炎焔煙燕猿縁艶苑薗遠鉛鴛塩於汚甥凹央奥往応"],
        ["b2a1", "押旺横欧殴王翁襖鴬鴎黄岡沖荻億屋憶臆桶牡乙俺卸恩温穏音下化仮何伽価佳加可嘉夏嫁家寡科暇果架歌河火珂禍禾稼箇花苛茄荷華菓蝦課嘩貨迦過霞蚊俄峨我牙画臥芽蛾賀雅餓駕介会解回塊壊廻快怪悔恢懐戒拐改"],
        ["b3a1", "魁晦械海灰界皆絵芥蟹開階貝凱劾外咳害崖慨概涯碍蓋街該鎧骸浬馨蛙垣柿蛎鈎劃嚇各廓拡撹格核殻獲確穫覚角赫較郭閣隔革学岳楽額顎掛笠樫橿梶鰍潟割喝恰括活渇滑葛褐轄且鰹叶椛樺鞄株兜竃蒲釜鎌噛鴨栢茅萱"],
        ["b4a1", "粥刈苅瓦乾侃冠寒刊勘勧巻喚堪姦完官寛干幹患感慣憾換敢柑桓棺款歓汗漢澗潅環甘監看竿管簡緩缶翰肝艦莞観諌貫還鑑間閑関陥韓館舘丸含岸巌玩癌眼岩翫贋雁頑顔願企伎危喜器基奇嬉寄岐希幾忌揮机旗既期棋棄"],
        ["b5a1", "機帰毅気汽畿祈季稀紀徽規記貴起軌輝飢騎鬼亀偽儀妓宜戯技擬欺犠疑祇義蟻誼議掬菊鞠吉吃喫桔橘詰砧杵黍却客脚虐逆丘久仇休及吸宮弓急救朽求汲泣灸球究窮笈級糾給旧牛去居巨拒拠挙渠虚許距鋸漁禦魚亨享京"],
        ["b6a1", "供侠僑兇競共凶協匡卿叫喬境峡強彊怯恐恭挟教橋況狂狭矯胸脅興蕎郷鏡響饗驚仰凝尭暁業局曲極玉桐粁僅勤均巾錦斤欣欽琴禁禽筋緊芹菌衿襟謹近金吟銀九倶句区狗玖矩苦躯駆駈駒具愚虞喰空偶寓遇隅串櫛釧屑屈"],
        ["b7a1", "掘窟沓靴轡窪熊隈粂栗繰桑鍬勲君薫訓群軍郡卦袈祁係傾刑兄啓圭珪型契形径恵慶慧憩掲携敬景桂渓畦稽系経継繋罫茎荊蛍計詣警軽頚鶏芸迎鯨劇戟撃激隙桁傑欠決潔穴結血訣月件倹倦健兼券剣喧圏堅嫌建憲懸拳捲"],
        ["b8a1", "検権牽犬献研硯絹県肩見謙賢軒遣鍵険顕験鹸元原厳幻弦減源玄現絃舷言諺限乎個古呼固姑孤己庫弧戸故枯湖狐糊袴股胡菰虎誇跨鈷雇顧鼓五互伍午呉吾娯後御悟梧檎瑚碁語誤護醐乞鯉交佼侯候倖光公功効勾厚口向"],
        ["b9a1", "后喉坑垢好孔孝宏工巧巷幸広庚康弘恒慌抗拘控攻昂晃更杭校梗構江洪浩港溝甲皇硬稿糠紅紘絞綱耕考肯肱腔膏航荒行衡講貢購郊酵鉱砿鋼閤降項香高鴻剛劫号合壕拷濠豪轟麹克刻告国穀酷鵠黒獄漉腰甑忽惚骨狛込"],
        ["baa1", "此頃今困坤墾婚恨懇昏昆根梱混痕紺艮魂些佐叉唆嵯左差査沙瑳砂詐鎖裟坐座挫債催再最哉塞妻宰彩才採栽歳済災采犀砕砦祭斎細菜裁載際剤在材罪財冴坂阪堺榊肴咲崎埼碕鷺作削咋搾昨朔柵窄策索錯桜鮭笹匙冊刷"],
        ["bba1", "察拶撮擦札殺薩雑皐鯖捌錆鮫皿晒三傘参山惨撒散桟燦珊産算纂蚕讃賛酸餐斬暫残仕仔伺使刺司史嗣四士始姉姿子屍市師志思指支孜斯施旨枝止死氏獅祉私糸紙紫肢脂至視詞詩試誌諮資賜雌飼歯事似侍児字寺慈持時"],
        ["bca1", "次滋治爾璽痔磁示而耳自蒔辞汐鹿式識鴫竺軸宍雫七叱執失嫉室悉湿漆疾質実蔀篠偲柴芝屡蕊縞舎写射捨赦斜煮社紗者謝車遮蛇邪借勺尺杓灼爵酌釈錫若寂弱惹主取守手朱殊狩珠種腫趣酒首儒受呪寿授樹綬需囚収周"],
        ["bda1", "宗就州修愁拾洲秀秋終繍習臭舟蒐衆襲讐蹴輯週酋酬集醜什住充十従戎柔汁渋獣縦重銃叔夙宿淑祝縮粛塾熟出術述俊峻春瞬竣舜駿准循旬楯殉淳準潤盾純巡遵醇順処初所暑曙渚庶緒署書薯藷諸助叙女序徐恕鋤除傷償"],
        ["bea1", "勝匠升召哨商唱嘗奨妾娼宵将小少尚庄床廠彰承抄招掌捷昇昌昭晶松梢樟樵沼消渉湘焼焦照症省硝礁祥称章笑粧紹肖菖蒋蕉衝裳訟証詔詳象賞醤鉦鍾鐘障鞘上丈丞乗冗剰城場壌嬢常情擾条杖浄状畳穣蒸譲醸錠嘱埴飾"],
        ["bfa1", "拭植殖燭織職色触食蝕辱尻伸信侵唇娠寝審心慎振新晋森榛浸深申疹真神秦紳臣芯薪親診身辛進針震人仁刃塵壬尋甚尽腎訊迅陣靭笥諏須酢図厨逗吹垂帥推水炊睡粋翠衰遂酔錐錘随瑞髄崇嵩数枢趨雛据杉椙菅頗雀裾"],
        ["c0a1", "澄摺寸世瀬畝是凄制勢姓征性成政整星晴棲栖正清牲生盛精聖声製西誠誓請逝醒青静斉税脆隻席惜戚斥昔析石積籍績脊責赤跡蹟碩切拙接摂折設窃節説雪絶舌蝉仙先千占宣専尖川戦扇撰栓栴泉浅洗染潜煎煽旋穿箭線"],
        ["c1a1", "繊羨腺舛船薦詮賎践選遷銭銑閃鮮前善漸然全禅繕膳糎噌塑岨措曾曽楚狙疏疎礎祖租粗素組蘇訴阻遡鼠僧創双叢倉喪壮奏爽宋層匝惣想捜掃挿掻操早曹巣槍槽漕燥争痩相窓糟総綜聡草荘葬蒼藻装走送遭鎗霜騒像増憎"],
        ["c2a1", "臓蔵贈造促側則即息捉束測足速俗属賊族続卒袖其揃存孫尊損村遜他多太汰詑唾堕妥惰打柁舵楕陀駄騨体堆対耐岱帯待怠態戴替泰滞胎腿苔袋貸退逮隊黛鯛代台大第醍題鷹滝瀧卓啄宅托択拓沢濯琢託鐸濁諾茸凧蛸只"],
        ["c3a1", "叩但達辰奪脱巽竪辿棚谷狸鱈樽誰丹単嘆坦担探旦歎淡湛炭短端箪綻耽胆蛋誕鍛団壇弾断暖檀段男談値知地弛恥智池痴稚置致蜘遅馳築畜竹筑蓄逐秩窒茶嫡着中仲宙忠抽昼柱注虫衷註酎鋳駐樗瀦猪苧著貯丁兆凋喋寵"],
        ["c4a1", "帖帳庁弔張彫徴懲挑暢朝潮牒町眺聴脹腸蝶調諜超跳銚長頂鳥勅捗直朕沈珍賃鎮陳津墜椎槌追鎚痛通塚栂掴槻佃漬柘辻蔦綴鍔椿潰坪壷嬬紬爪吊釣鶴亭低停偵剃貞呈堤定帝底庭廷弟悌抵挺提梯汀碇禎程締艇訂諦蹄逓"],
        ["c5a1", "邸鄭釘鼎泥摘擢敵滴的笛適鏑溺哲徹撤轍迭鉄典填天展店添纏甜貼転顛点伝殿澱田電兎吐堵塗妬屠徒斗杜渡登菟賭途都鍍砥砺努度土奴怒倒党冬凍刀唐塔塘套宕島嶋悼投搭東桃梼棟盗淘湯涛灯燈当痘祷等答筒糖統到"],
        ["c6a1", "董蕩藤討謄豆踏逃透鐙陶頭騰闘働動同堂導憧撞洞瞳童胴萄道銅峠鴇匿得徳涜特督禿篤毒独読栃橡凸突椴届鳶苫寅酉瀞噸屯惇敦沌豚遁頓呑曇鈍奈那内乍凪薙謎灘捺鍋楢馴縄畷南楠軟難汝二尼弐迩匂賑肉虹廿日乳入"],
        ["c7a1", "如尿韮任妊忍認濡禰祢寧葱猫熱年念捻撚燃粘乃廼之埜嚢悩濃納能脳膿農覗蚤巴把播覇杷波派琶破婆罵芭馬俳廃拝排敗杯盃牌背肺輩配倍培媒梅楳煤狽買売賠陪這蝿秤矧萩伯剥博拍柏泊白箔粕舶薄迫曝漠爆縛莫駁麦"],
        ["c8a1", "函箱硲箸肇筈櫨幡肌畑畠八鉢溌発醗髪伐罰抜筏閥鳩噺塙蛤隼伴判半反叛帆搬斑板氾汎版犯班畔繁般藩販範釆煩頒飯挽晩番盤磐蕃蛮匪卑否妃庇彼悲扉批披斐比泌疲皮碑秘緋罷肥被誹費避非飛樋簸備尾微枇毘琵眉美"],
        ["c9a1", "鼻柊稗匹疋髭彦膝菱肘弼必畢筆逼桧姫媛紐百謬俵彪標氷漂瓢票表評豹廟描病秒苗錨鋲蒜蛭鰭品彬斌浜瀕貧賓頻敏瓶不付埠夫婦富冨布府怖扶敷斧普浮父符腐膚芙譜負賦赴阜附侮撫武舞葡蕪部封楓風葺蕗伏副復幅服"],
        ["caa1", "福腹複覆淵弗払沸仏物鮒分吻噴墳憤扮焚奮粉糞紛雰文聞丙併兵塀幣平弊柄並蔽閉陛米頁僻壁癖碧別瞥蔑箆偏変片篇編辺返遍便勉娩弁鞭保舗鋪圃捕歩甫補輔穂募墓慕戊暮母簿菩倣俸包呆報奉宝峰峯崩庖抱捧放方朋"],
        ["cba1", "法泡烹砲縫胞芳萌蓬蜂褒訪豊邦鋒飽鳳鵬乏亡傍剖坊妨帽忘忙房暴望某棒冒紡肪膨謀貌貿鉾防吠頬北僕卜墨撲朴牧睦穆釦勃没殆堀幌奔本翻凡盆摩磨魔麻埋妹昧枚毎哩槙幕膜枕鮪柾鱒桝亦俣又抹末沫迄侭繭麿万慢満"],
        ["cca1", "漫蔓味未魅巳箕岬密蜜湊蓑稔脈妙粍民眠務夢無牟矛霧鵡椋婿娘冥名命明盟迷銘鳴姪牝滅免棉綿緬面麺摸模茂妄孟毛猛盲網耗蒙儲木黙目杢勿餅尤戻籾貰問悶紋門匁也冶夜爺耶野弥矢厄役約薬訳躍靖柳薮鑓愉愈油癒"],
        ["cda1", "諭輸唯佑優勇友宥幽悠憂揖有柚湧涌猶猷由祐裕誘遊邑郵雄融夕予余与誉輿預傭幼妖容庸揚揺擁曜楊様洋溶熔用窯羊耀葉蓉要謡踊遥陽養慾抑欲沃浴翌翼淀羅螺裸来莱頼雷洛絡落酪乱卵嵐欄濫藍蘭覧利吏履李梨理璃"],
        ["cea1", "痢裏裡里離陸律率立葎掠略劉流溜琉留硫粒隆竜龍侶慮旅虜了亮僚両凌寮料梁涼猟療瞭稜糧良諒遼量陵領力緑倫厘林淋燐琳臨輪隣鱗麟瑠塁涙累類令伶例冷励嶺怜玲礼苓鈴隷零霊麗齢暦歴列劣烈裂廉恋憐漣煉簾練聯"],
        ["cfa1", "蓮連錬呂魯櫓炉賂路露労婁廊弄朗楼榔浪漏牢狼篭老聾蝋郎六麓禄肋録論倭和話歪賄脇惑枠鷲亙亘鰐詫藁蕨椀湾碗腕"],
        ["d0a1", "弌丐丕个丱丶丼丿乂乖乘亂亅豫亊舒弍于亞亟亠亢亰亳亶从仍仄仆仂仗仞仭仟价伉佚估佛佝佗佇佶侈侏侘佻佩佰侑佯來侖儘俔俟俎俘俛俑俚俐俤俥倚倨倔倪倥倅伜俶倡倩倬俾俯們倆偃假會偕偐偈做偖偬偸傀傚傅傴傲"],
        ["d1a1", "僉僊傳僂僖僞僥僭僣僮價僵儉儁儂儖儕儔儚儡儺儷儼儻儿兀兒兌兔兢竸兩兪兮冀冂囘册冉冏冑冓冕冖冤冦冢冩冪冫决冱冲冰况冽凅凉凛几處凩凭凰凵凾刄刋刔刎刧刪刮刳刹剏剄剋剌剞剔剪剴剩剳剿剽劍劔劒剱劈劑辨"],
        ["d2a1", "辧劬劭劼劵勁勍勗勞勣勦飭勠勳勵勸勹匆匈甸匍匐匏匕匚匣匯匱匳匸區卆卅丗卉卍凖卞卩卮夘卻卷厂厖厠厦厥厮厰厶參簒雙叟曼燮叮叨叭叺吁吽呀听吭吼吮吶吩吝呎咏呵咎呟呱呷呰咒呻咀呶咄咐咆哇咢咸咥咬哄哈咨"],
        ["d3a1", "咫哂咤咾咼哘哥哦唏唔哽哮哭哺哢唹啀啣啌售啜啅啖啗唸唳啝喙喀咯喊喟啻啾喘喞單啼喃喩喇喨嗚嗅嗟嗄嗜嗤嗔嘔嗷嘖嗾嗽嘛嗹噎噐營嘴嘶嘲嘸噫噤嘯噬噪嚆嚀嚊嚠嚔嚏嚥嚮嚶嚴囂嚼囁囃囀囈囎囑囓囗囮囹圀囿圄圉"],
        ["d4a1", "圈國圍圓團圖嗇圜圦圷圸坎圻址坏坩埀垈坡坿垉垓垠垳垤垪垰埃埆埔埒埓堊埖埣堋堙堝塲堡塢塋塰毀塒堽塹墅墹墟墫墺壞墻墸墮壅壓壑壗壙壘壥壜壤壟壯壺壹壻壼壽夂夊夐夛梦夥夬夭夲夸夾竒奕奐奎奚奘奢奠奧奬奩"],
        ["d5a1", "奸妁妝佞侫妣妲姆姨姜妍姙姚娥娟娑娜娉娚婀婬婉娵娶婢婪媚媼媾嫋嫂媽嫣嫗嫦嫩嫖嫺嫻嬌嬋嬖嬲嫐嬪嬶嬾孃孅孀孑孕孚孛孥孩孰孳孵學斈孺宀它宦宸寃寇寉寔寐寤實寢寞寥寫寰寶寳尅將專對尓尠尢尨尸尹屁屆屎屓"],
        ["d6a1", "屐屏孱屬屮乢屶屹岌岑岔妛岫岻岶岼岷峅岾峇峙峩峽峺峭嶌峪崋崕崗嵜崟崛崑崔崢崚崙崘嵌嵒嵎嵋嵬嵳嵶嶇嶄嶂嶢嶝嶬嶮嶽嶐嶷嶼巉巍巓巒巖巛巫已巵帋帚帙帑帛帶帷幄幃幀幎幗幔幟幢幤幇幵并幺麼广庠廁廂廈廐廏"],
        ["d7a1", "廖廣廝廚廛廢廡廨廩廬廱廳廰廴廸廾弃弉彝彜弋弑弖弩弭弸彁彈彌彎弯彑彖彗彙彡彭彳彷徃徂彿徊很徑徇從徙徘徠徨徭徼忖忻忤忸忱忝悳忿怡恠怙怐怩怎怱怛怕怫怦怏怺恚恁恪恷恟恊恆恍恣恃恤恂恬恫恙悁悍惧悃悚"],
        ["d8a1", "悄悛悖悗悒悧悋惡悸惠惓悴忰悽惆悵惘慍愕愆惶惷愀惴惺愃愡惻惱愍愎慇愾愨愧慊愿愼愬愴愽慂慄慳慷慘慙慚慫慴慯慥慱慟慝慓慵憙憖憇憬憔憚憊憑憫憮懌懊應懷懈懃懆憺懋罹懍懦懣懶懺懴懿懽懼懾戀戈戉戍戌戔戛"],
        ["d9a1", "戞戡截戮戰戲戳扁扎扞扣扛扠扨扼抂抉找抒抓抖拔抃抔拗拑抻拏拿拆擔拈拜拌拊拂拇抛拉挌拮拱挧挂挈拯拵捐挾捍搜捏掖掎掀掫捶掣掏掉掟掵捫捩掾揩揀揆揣揉插揶揄搖搴搆搓搦搶攝搗搨搏摧摯摶摎攪撕撓撥撩撈撼"],
        ["daa1", "據擒擅擇撻擘擂擱擧舉擠擡抬擣擯攬擶擴擲擺攀擽攘攜攅攤攣攫攴攵攷收攸畋效敖敕敍敘敞敝敲數斂斃變斛斟斫斷旃旆旁旄旌旒旛旙无旡旱杲昊昃旻杳昵昶昴昜晏晄晉晁晞晝晤晧晨晟晢晰暃暈暎暉暄暘暝曁暹曉暾暼"],
        ["dba1", "曄暸曖曚曠昿曦曩曰曵曷朏朖朞朦朧霸朮朿朶杁朸朷杆杞杠杙杣杤枉杰枩杼杪枌枋枦枡枅枷柯枴柬枳柩枸柤柞柝柢柮枹柎柆柧檜栞框栩桀桍栲桎梳栫桙档桷桿梟梏梭梔條梛梃檮梹桴梵梠梺椏梍桾椁棊椈棘椢椦棡椌棍"],
        ["dca1", "棔棧棕椶椒椄棗棣椥棹棠棯椨椪椚椣椡棆楹楷楜楸楫楔楾楮椹楴椽楙椰楡楞楝榁楪榲榮槐榿槁槓榾槎寨槊槝榻槃榧樮榑榠榜榕榴槞槨樂樛槿權槹槲槧樅榱樞槭樔槫樊樒櫁樣樓橄樌橲樶橸橇橢橙橦橈樸樢檐檍檠檄檢檣"],
        ["dda1", "檗蘗檻櫃櫂檸檳檬櫞櫑櫟檪櫚櫪櫻欅蘖櫺欒欖鬱欟欸欷盜欹飮歇歃歉歐歙歔歛歟歡歸歹歿殀殄殃殍殘殕殞殤殪殫殯殲殱殳殷殼毆毋毓毟毬毫毳毯麾氈氓气氛氤氣汞汕汢汪沂沍沚沁沛汾汨汳沒沐泄泱泓沽泗泅泝沮沱沾"],
        ["dea1", "沺泛泯泙泪洟衍洶洫洽洸洙洵洳洒洌浣涓浤浚浹浙涎涕濤涅淹渕渊涵淇淦涸淆淬淞淌淨淒淅淺淙淤淕淪淮渭湮渮渙湲湟渾渣湫渫湶湍渟湃渺湎渤滿渝游溂溪溘滉溷滓溽溯滄溲滔滕溏溥滂溟潁漑灌滬滸滾漿滲漱滯漲滌"],
        ["dfa1", "漾漓滷澆潺潸澁澀潯潛濳潭澂潼潘澎澑濂潦澳澣澡澤澹濆澪濟濕濬濔濘濱濮濛瀉瀋濺瀑瀁瀏濾瀛瀚潴瀝瀘瀟瀰瀾瀲灑灣炙炒炯烱炬炸炳炮烟烋烝烙焉烽焜焙煥煕熈煦煢煌煖煬熏燻熄熕熨熬燗熹熾燒燉燔燎燠燬燧燵燼"],
        ["e0a1", "燹燿爍爐爛爨爭爬爰爲爻爼爿牀牆牋牘牴牾犂犁犇犒犖犢犧犹犲狃狆狄狎狒狢狠狡狹狷倏猗猊猜猖猝猴猯猩猥猾獎獏默獗獪獨獰獸獵獻獺珈玳珎玻珀珥珮珞璢琅瑯琥珸琲琺瑕琿瑟瑙瑁瑜瑩瑰瑣瑪瑶瑾璋璞璧瓊瓏瓔珱"],
        ["e1a1", "瓠瓣瓧瓩瓮瓲瓰瓱瓸瓷甄甃甅甌甎甍甕甓甞甦甬甼畄畍畊畉畛畆畚畩畤畧畫畭畸當疆疇畴疊疉疂疔疚疝疥疣痂疳痃疵疽疸疼疱痍痊痒痙痣痞痾痿痼瘁痰痺痲痳瘋瘍瘉瘟瘧瘠瘡瘢瘤瘴瘰瘻癇癈癆癜癘癡癢癨癩癪癧癬癰"],
        ["e2a1", "癲癶癸發皀皃皈皋皎皖皓皙皚皰皴皸皹皺盂盍盖盒盞盡盥盧盪蘯盻眈眇眄眩眤眞眥眦眛眷眸睇睚睨睫睛睥睿睾睹瞎瞋瞑瞠瞞瞰瞶瞹瞿瞼瞽瞻矇矍矗矚矜矣矮矼砌砒礦砠礪硅碎硴碆硼碚碌碣碵碪碯磑磆磋磔碾碼磅磊磬"],
        ["e3a1", "磧磚磽磴礇礒礑礙礬礫祀祠祗祟祚祕祓祺祿禊禝禧齋禪禮禳禹禺秉秕秧秬秡秣稈稍稘稙稠稟禀稱稻稾稷穃穗穉穡穢穩龝穰穹穽窈窗窕窘窖窩竈窰窶竅竄窿邃竇竊竍竏竕竓站竚竝竡竢竦竭竰笂笏笊笆笳笘笙笞笵笨笶筐"],
        ["e4a1", "筺笄筍笋筌筅筵筥筴筧筰筱筬筮箝箘箟箍箜箚箋箒箏筝箙篋篁篌篏箴篆篝篩簑簔篦篥籠簀簇簓篳篷簗簍篶簣簧簪簟簷簫簽籌籃籔籏籀籐籘籟籤籖籥籬籵粃粐粤粭粢粫粡粨粳粲粱粮粹粽糀糅糂糘糒糜糢鬻糯糲糴糶糺紆"],
        ["e5a1", "紂紜紕紊絅絋紮紲紿紵絆絳絖絎絲絨絮絏絣經綉絛綏絽綛綺綮綣綵緇綽綫總綢綯緜綸綟綰緘緝緤緞緻緲緡縅縊縣縡縒縱縟縉縋縢繆繦縻縵縹繃縷縲縺繧繝繖繞繙繚繹繪繩繼繻纃緕繽辮繿纈纉續纒纐纓纔纖纎纛纜缸缺"],
        ["e6a1", "罅罌罍罎罐网罕罔罘罟罠罨罩罧罸羂羆羃羈羇羌羔羞羝羚羣羯羲羹羮羶羸譱翅翆翊翕翔翡翦翩翳翹飜耆耄耋耒耘耙耜耡耨耿耻聊聆聒聘聚聟聢聨聳聲聰聶聹聽聿肄肆肅肛肓肚肭冐肬胛胥胙胝胄胚胖脉胯胱脛脩脣脯腋"],
        ["e7a1", "隋腆脾腓腑胼腱腮腥腦腴膃膈膊膀膂膠膕膤膣腟膓膩膰膵膾膸膽臀臂膺臉臍臑臙臘臈臚臟臠臧臺臻臾舁舂舅與舊舍舐舖舩舫舸舳艀艙艘艝艚艟艤艢艨艪艫舮艱艷艸艾芍芒芫芟芻芬苡苣苟苒苴苳苺莓范苻苹苞茆苜茉苙"],
        ["e8a1", "茵茴茖茲茱荀茹荐荅茯茫茗茘莅莚莪莟莢莖茣莎莇莊荼莵荳荵莠莉莨菴萓菫菎菽萃菘萋菁菷萇菠菲萍萢萠莽萸蔆菻葭萪萼蕚蒄葷葫蒭葮蒂葩葆萬葯葹萵蓊葢蒹蒿蒟蓙蓍蒻蓚蓐蓁蓆蓖蒡蔡蓿蓴蔗蔘蔬蔟蔕蔔蓼蕀蕣蕘蕈"],
        ["e9a1", "蕁蘂蕋蕕薀薤薈薑薊薨蕭薔薛藪薇薜蕷蕾薐藉薺藏薹藐藕藝藥藜藹蘊蘓蘋藾藺蘆蘢蘚蘰蘿虍乕虔號虧虱蚓蚣蚩蚪蚋蚌蚶蚯蛄蛆蚰蛉蠣蚫蛔蛞蛩蛬蛟蛛蛯蜒蜆蜈蜀蜃蛻蜑蜉蜍蛹蜊蜴蜿蜷蜻蜥蜩蜚蝠蝟蝸蝌蝎蝴蝗蝨蝮蝙"],
        ["eaa1", "蝓蝣蝪蠅螢螟螂螯蟋螽蟀蟐雖螫蟄螳蟇蟆螻蟯蟲蟠蠏蠍蟾蟶蟷蠎蟒蠑蠖蠕蠢蠡蠱蠶蠹蠧蠻衄衂衒衙衞衢衫袁衾袞衵衽袵衲袂袗袒袮袙袢袍袤袰袿袱裃裄裔裘裙裝裹褂裼裴裨裲褄褌褊褓襃褞褥褪褫襁襄褻褶褸襌褝襠襞"],
        ["eba1", "襦襤襭襪襯襴襷襾覃覈覊覓覘覡覩覦覬覯覲覺覽覿觀觚觜觝觧觴觸訃訖訐訌訛訝訥訶詁詛詒詆詈詼詭詬詢誅誂誄誨誡誑誥誦誚誣諄諍諂諚諫諳諧諤諱謔諠諢諷諞諛謌謇謚諡謖謐謗謠謳鞫謦謫謾謨譁譌譏譎證譖譛譚譫"],
        ["eca1", "譟譬譯譴譽讀讌讎讒讓讖讙讚谺豁谿豈豌豎豐豕豢豬豸豺貂貉貅貊貍貎貔豼貘戝貭貪貽貲貳貮貶賈賁賤賣賚賽賺賻贄贅贊贇贏贍贐齎贓賍贔贖赧赭赱赳趁趙跂趾趺跏跚跖跌跛跋跪跫跟跣跼踈踉跿踝踞踐踟蹂踵踰踴蹊"],
        ["eda1", "蹇蹉蹌蹐蹈蹙蹤蹠踪蹣蹕蹶蹲蹼躁躇躅躄躋躊躓躑躔躙躪躡躬躰軆躱躾軅軈軋軛軣軼軻軫軾輊輅輕輒輙輓輜輟輛輌輦輳輻輹轅轂輾轌轉轆轎轗轜轢轣轤辜辟辣辭辯辷迚迥迢迪迯邇迴逅迹迺逑逕逡逍逞逖逋逧逶逵逹迸"],
        ["eea1", "遏遐遑遒逎遉逾遖遘遞遨遯遶隨遲邂遽邁邀邊邉邏邨邯邱邵郢郤扈郛鄂鄒鄙鄲鄰酊酖酘酣酥酩酳酲醋醉醂醢醫醯醪醵醴醺釀釁釉釋釐釖釟釡釛釼釵釶鈞釿鈔鈬鈕鈑鉞鉗鉅鉉鉤鉈銕鈿鉋鉐銜銖銓銛鉚鋏銹銷鋩錏鋺鍄錮"],
        ["efa1", "錙錢錚錣錺錵錻鍜鍠鍼鍮鍖鎰鎬鎭鎔鎹鏖鏗鏨鏥鏘鏃鏝鏐鏈鏤鐚鐔鐓鐃鐇鐐鐶鐫鐵鐡鐺鑁鑒鑄鑛鑠鑢鑞鑪鈩鑰鑵鑷鑽鑚鑼鑾钁鑿閂閇閊閔閖閘閙閠閨閧閭閼閻閹閾闊濶闃闍闌闕闔闖關闡闥闢阡阨阮阯陂陌陏陋陷陜陞"],
        ["f0a1", "陝陟陦陲陬隍隘隕隗險隧隱隲隰隴隶隸隹雎雋雉雍襍雜霍雕雹霄霆霈霓霎霑霏霖霙霤霪霰霹霽霾靄靆靈靂靉靜靠靤靦靨勒靫靱靹鞅靼鞁靺鞆鞋鞏鞐鞜鞨鞦鞣鞳鞴韃韆韈韋韜韭齏韲竟韶韵頏頌頸頤頡頷頽顆顏顋顫顯顰"],
        ["f1a1", "顱顴顳颪颯颱颶飄飃飆飩飫餃餉餒餔餘餡餝餞餤餠餬餮餽餾饂饉饅饐饋饑饒饌饕馗馘馥馭馮馼駟駛駝駘駑駭駮駱駲駻駸騁騏騅駢騙騫騷驅驂驀驃騾驕驍驛驗驟驢驥驤驩驫驪骭骰骼髀髏髑髓體髞髟髢髣髦髯髫髮髴髱髷"],
        ["f2a1", "髻鬆鬘鬚鬟鬢鬣鬥鬧鬨鬩鬪鬮鬯鬲魄魃魏魍魎魑魘魴鮓鮃鮑鮖鮗鮟鮠鮨鮴鯀鯊鮹鯆鯏鯑鯒鯣鯢鯤鯔鯡鰺鯲鯱鯰鰕鰔鰉鰓鰌鰆鰈鰒鰊鰄鰮鰛鰥鰤鰡鰰鱇鰲鱆鰾鱚鱠鱧鱶鱸鳧鳬鳰鴉鴈鳫鴃鴆鴪鴦鶯鴣鴟鵄鴕鴒鵁鴿鴾鵆鵈"],
        ["f3a1", "鵝鵞鵤鵑鵐鵙鵲鶉鶇鶫鵯鵺鶚鶤鶩鶲鷄鷁鶻鶸鶺鷆鷏鷂鷙鷓鷸鷦鷭鷯鷽鸚鸛鸞鹵鹹鹽麁麈麋麌麒麕麑麝麥麩麸麪麭靡黌黎黏黐黔黜點黝黠黥黨黯黴黶黷黹黻黼黽鼇鼈皷鼕鼡鼬鼾齊齒齔齣齟齠齡齦齧齬齪齷齲齶龕龜龠"],
        ["f4a1", "堯槇遙瑤凜熙"],
        ["f9a1", "纊褜鍈銈蓜俉炻昱棈鋹曻彅丨仡仼伀伃伹佖侒侊侚侔俍偀倢俿倞偆偰偂傔僴僘兊兤冝冾凬刕劜劦勀勛匀匇匤卲厓厲叝﨎咜咊咩哿喆坙坥垬埈埇﨏塚增墲夋奓奛奝奣妤妺孖寀甯寘寬尞岦岺峵崧嵓﨑嵂嵭嶸嶹巐弡弴彧德"],
        ["faa1", "忞恝悅悊惞惕愠惲愑愷愰憘戓抦揵摠撝擎敎昀昕昻昉昮昞昤晥晗晙晴晳暙暠暲暿曺朎朗杦枻桒柀栁桄棏﨓楨﨔榘槢樰橫橆橳橾櫢櫤毖氿汜沆汯泚洄涇浯涖涬淏淸淲淼渹湜渧渼溿澈澵濵瀅瀇瀨炅炫焏焄煜煆煇凞燁燾犱"],
        ["fba1", "犾猤猪獷玽珉珖珣珒琇珵琦琪琩琮瑢璉璟甁畯皂皜皞皛皦益睆劯砡硎硤硺礰礼神祥禔福禛竑竧靖竫箞精絈絜綷綠緖繒罇羡羽茁荢荿菇菶葈蒴蕓蕙蕫﨟薰蘒﨡蠇裵訒訷詹誧誾諟諸諶譓譿賰賴贒赶﨣軏﨤逸遧郞都鄕鄧釚"],
        ["fca1", "釗釞釭釮釤釥鈆鈐鈊鈺鉀鈼鉎鉙鉑鈹鉧銧鉷鉸鋧鋗鋙鋐﨧鋕鋠鋓錥錡鋻﨨錞鋿錝錂鍰鍗鎤鏆鏞鏸鐱鑅鑈閒隆﨩隝隯霳霻靃靍靏靑靕顗顥飯飼餧館馞驎髙髜魵魲鮏鮱鮻鰀鵰鵫鶴鸙黑"],
        ["fcf1", "ⅰ", 9, "￢￤＇＂"],
        ["8fa2af", "˘ˇ¸˙˝¯˛˚～΄΅"],
        ["8fa2c2", "¡¦¿"],
        ["8fa2eb", "ºª©®™¤№"],
        ["8fa6e1", "ΆΈΉΊΪ"],
        ["8fa6e7", "Ό"],
        ["8fa6e9", "ΎΫ"],
        ["8fa6ec", "Ώ"],
        ["8fa6f1", "άέήίϊΐόςύϋΰώ"],
        ["8fa7c2", "Ђ", 10, "ЎЏ"],
        ["8fa7f2", "ђ", 10, "ўџ"],
        ["8fa9a1", "ÆĐ"],
        ["8fa9a4", "Ħ"],
        ["8fa9a6", "Ĳ"],
        ["8fa9a8", "ŁĿ"],
        ["8fa9ab", "ŊØŒ"],
        ["8fa9af", "ŦÞ"],
        ["8fa9c1", "æđðħıĳĸłŀŉŋøœßŧþ"],
        ["8faaa1", "ÁÀÄÂĂǍĀĄÅÃĆĈČÇĊĎÉÈËÊĚĖĒĘ"],
        ["8faaba", "ĜĞĢĠĤÍÌÏÎǏİĪĮĨĴĶĹĽĻŃŇŅÑÓÒÖÔǑŐŌÕŔŘŖŚŜŠŞŤŢÚÙÜÛŬǓŰŪŲŮŨǗǛǙǕŴÝŸŶŹŽŻ"],
        ["8faba1", "áàäâăǎāąåãćĉčçċďéèëêěėēęǵĝğ"],
        ["8fabbd", "ġĥíìïîǐ"],
        ["8fabc5", "īįĩĵķĺľļńňņñóòöôǒőōõŕřŗśŝšşťţúùüûŭǔűūųůũǘǜǚǖŵýÿŷźžż"],
        ["8fb0a1", "丂丄丅丌丒丟丣两丨丫丮丯丰丵乀乁乄乇乑乚乜乣乨乩乴乵乹乿亍亖亗亝亯亹仃仐仚仛仠仡仢仨仯仱仳仵份仾仿伀伂伃伈伋伌伒伕伖众伙伮伱你伳伵伷伹伻伾佀佂佈佉佋佌佒佔佖佘佟佣佪佬佮佱佷佸佹佺佽佾侁侂侄"],
        ["8fb1a1", "侅侉侊侌侎侐侒侓侔侗侙侚侞侟侲侷侹侻侼侽侾俀俁俅俆俈俉俋俌俍俏俒俜俠俢俰俲俼俽俿倀倁倄倇倊倌倎倐倓倗倘倛倜倝倞倢倧倮倰倲倳倵偀偁偂偅偆偊偌偎偑偒偓偗偙偟偠偢偣偦偧偪偭偰偱倻傁傃傄傆傊傎傏傐"],
        ["8fb2a1", "傒傓傔傖傛傜傞", 4, "傪傯傰傹傺傽僀僃僄僇僌僎僐僓僔僘僜僝僟僢僤僦僨僩僯僱僶僺僾儃儆儇儈儋儌儍儎僲儐儗儙儛儜儝儞儣儧儨儬儭儯儱儳儴儵儸儹兂兊兏兓兕兗兘兟兤兦兾冃冄冋冎冘冝冡冣冭冸冺冼冾冿凂"],
        ["8fb3a1", "凈减凑凒凓凕凘凞凢凥凮凲凳凴凷刁刂刅划刓刕刖刘刢刨刱刲刵刼剅剉剕剗剘剚剜剟剠剡剦剮剷剸剹劀劂劅劊劌劓劕劖劗劘劚劜劤劥劦劧劯劰劶劷劸劺劻劽勀勄勆勈勌勏勑勔勖勛勜勡勥勨勩勪勬勰勱勴勶勷匀匃匊匋"],
        ["8fb4a1", "匌匑匓匘匛匜匞匟匥匧匨匩匫匬匭匰匲匵匼匽匾卂卌卋卙卛卡卣卥卬卭卲卹卾厃厇厈厎厓厔厙厝厡厤厪厫厯厲厴厵厷厸厺厽叀叅叏叒叓叕叚叝叞叠另叧叵吂吓吚吡吧吨吪启吱吴吵呃呄呇呍呏呞呢呤呦呧呩呫呭呮呴呿"],
        ["8fb5a1", "咁咃咅咈咉咍咑咕咖咜咟咡咦咧咩咪咭咮咱咷咹咺咻咿哆哊响哎哠哪哬哯哶哼哾哿唀唁唅唈唉唌唍唎唕唪唫唲唵唶唻唼唽啁啇啉啊啍啐啑啘啚啛啞啠啡啤啦啿喁喂喆喈喎喏喑喒喓喔喗喣喤喭喲喿嗁嗃嗆嗉嗋嗌嗎嗑嗒"],
        ["8fb6a1", "嗓嗗嗘嗛嗞嗢嗩嗶嗿嘅嘈嘊嘍", 5, "嘙嘬嘰嘳嘵嘷嘹嘻嘼嘽嘿噀噁噃噄噆噉噋噍噏噔噞噠噡噢噣噦噩噭噯噱噲噵嚄嚅嚈嚋嚌嚕嚙嚚嚝嚞嚟嚦嚧嚨嚩嚫嚬嚭嚱嚳嚷嚾囅囉囊囋囏囐囌囍囙囜囝囟囡囤", 4, "囱囫园"],
        ["8fb7a1", "囶囷圁圂圇圊圌圑圕圚圛圝圠圢圣圤圥圩圪圬圮圯圳圴圽圾圿坅坆坌坍坒坢坥坧坨坫坭", 4, "坳坴坵坷坹坺坻坼坾垁垃垌垔垗垙垚垜垝垞垟垡垕垧垨垩垬垸垽埇埈埌埏埕埝埞埤埦埧埩埭埰埵埶埸埽埾埿堃堄堈堉埡"],
        ["8fb8a1", "堌堍堛堞堟堠堦堧堭堲堹堿塉塌塍塏塐塕塟塡塤塧塨塸塼塿墀墁墇墈墉墊墌墍墏墐墔墖墝墠墡墢墦墩墱墲壄墼壂壈壍壎壐壒壔壖壚壝壡壢壩壳夅夆夋夌夒夓夔虁夝夡夣夤夨夯夰夳夵夶夿奃奆奒奓奙奛奝奞奟奡奣奫奭"],
        ["8fb9a1", "奯奲奵奶她奻奼妋妌妎妒妕妗妟妤妧妭妮妯妰妳妷妺妼姁姃姄姈姊姍姒姝姞姟姣姤姧姮姯姱姲姴姷娀娄娌娍娎娒娓娞娣娤娧娨娪娭娰婄婅婇婈婌婐婕婞婣婥婧婭婷婺婻婾媋媐媓媖媙媜媞媟媠媢媧媬媱媲媳媵媸媺媻媿"],
        ["8fbaa1", "嫄嫆嫈嫏嫚嫜嫠嫥嫪嫮嫵嫶嫽嬀嬁嬈嬗嬴嬙嬛嬝嬡嬥嬭嬸孁孋孌孒孖孞孨孮孯孼孽孾孿宁宄宆宊宎宐宑宓宔宖宨宩宬宭宯宱宲宷宺宼寀寁寍寏寖", 4, "寠寯寱寴寽尌尗尞尟尣尦尩尫尬尮尰尲尵尶屙屚屜屢屣屧屨屩"],
        ["8fbba1", "屭屰屴屵屺屻屼屽岇岈岊岏岒岝岟岠岢岣岦岪岲岴岵岺峉峋峒峝峗峮峱峲峴崁崆崍崒崫崣崤崦崧崱崴崹崽崿嵂嵃嵆嵈嵕嵑嵙嵊嵟嵠嵡嵢嵤嵪嵭嵰嵹嵺嵾嵿嶁嶃嶈嶊嶒嶓嶔嶕嶙嶛嶟嶠嶧嶫嶰嶴嶸嶹巃巇巋巐巎巘巙巠巤"],
        ["8fbca1", "巩巸巹帀帇帍帒帔帕帘帟帠帮帨帲帵帾幋幐幉幑幖幘幛幜幞幨幪", 4, "幰庀庋庎庢庤庥庨庪庬庱庳庽庾庿廆廌廋廎廑廒廔廕廜廞廥廫异弆弇弈弎弙弜弝弡弢弣弤弨弫弬弮弰弴弶弻弽弿彀彄彅彇彍彐彔彘彛彠彣彤彧"],
        ["8fbda1", "彯彲彴彵彸彺彽彾徉徍徏徖徜徝徢徧徫徤徬徯徰徱徸忄忇忈忉忋忐", 4, "忞忡忢忨忩忪忬忭忮忯忲忳忶忺忼怇怊怍怓怔怗怘怚怟怤怭怳怵恀恇恈恉恌恑恔恖恗恝恡恧恱恾恿悂悆悈悊悎悑悓悕悘悝悞悢悤悥您悰悱悷"],
        ["8fbea1", "悻悾惂惄惈惉惊惋惎惏惔惕惙惛惝惞惢惥惲惵惸惼惽愂愇愊愌愐", 4, "愖愗愙愜愞愢愪愫愰愱愵愶愷愹慁慅慆慉慞慠慬慲慸慻慼慿憀憁憃憄憋憍憒憓憗憘憜憝憟憠憥憨憪憭憸憹憼懀懁懂懎懏懕懜懝懞懟懡懢懧懩懥"],
        ["8fbfa1", "懬懭懯戁戃戄戇戓戕戜戠戢戣戧戩戫戹戽扂扃扄扆扌扐扑扒扔扖扚扜扤扭扯扳扺扽抍抎抏抐抦抨抳抶抷抺抾抿拄拎拕拖拚拪拲拴拼拽挃挄挊挋挍挐挓挖挘挩挪挭挵挶挹挼捁捂捃捄捆捊捋捎捒捓捔捘捛捥捦捬捭捱捴捵"],
        ["8fc0a1", "捸捼捽捿掂掄掇掊掐掔掕掙掚掞掤掦掭掮掯掽揁揅揈揎揑揓揔揕揜揠揥揪揬揲揳揵揸揹搉搊搐搒搔搘搞搠搢搤搥搩搪搯搰搵搽搿摋摏摑摒摓摔摚摛摜摝摟摠摡摣摭摳摴摻摽撅撇撏撐撑撘撙撛撝撟撡撣撦撨撬撳撽撾撿"],
        ["8fc1a1", "擄擉擊擋擌擎擐擑擕擗擤擥擩擪擭擰擵擷擻擿攁攄攈攉攊攏攓攔攖攙攛攞攟攢攦攩攮攱攺攼攽敃敇敉敐敒敔敟敠敧敫敺敽斁斅斊斒斕斘斝斠斣斦斮斲斳斴斿旂旈旉旎旐旔旖旘旟旰旲旴旵旹旾旿昀昄昈昉昍昑昒昕昖昝"],
        ["8fc2a1", "昞昡昢昣昤昦昩昪昫昬昮昰昱昳昹昷晀晅晆晊晌晑晎晗晘晙晛晜晠晡曻晪晫晬晾晳晵晿晷晸晹晻暀晼暋暌暍暐暒暙暚暛暜暟暠暤暭暱暲暵暻暿曀曂曃曈曌曎曏曔曛曟曨曫曬曮曺朅朇朎朓朙朜朠朢朳朾杅杇杈杌杔杕杝"],
        ["8fc3a1", "杦杬杮杴杶杻极构枎枏枑枓枖枘枙枛枰枱枲枵枻枼枽柹柀柂柃柅柈柉柒柗柙柜柡柦柰柲柶柷桒栔栙栝栟栨栧栬栭栯栰栱栳栻栿桄桅桊桌桕桗桘桛桫桮", 4, "桵桹桺桻桼梂梄梆梈梖梘梚梜梡梣梥梩梪梮梲梻棅棈棌棏"],
        ["8fc4a1", "棐棑棓棖棙棜棝棥棨棪棫棬棭棰棱棵棶棻棼棽椆椉椊椐椑椓椖椗椱椳椵椸椻楂楅楉楎楗楛楣楤楥楦楨楩楬楰楱楲楺楻楿榀榍榒榖榘榡榥榦榨榫榭榯榷榸榺榼槅槈槑槖槗槢槥槮槯槱槳槵槾樀樁樃樏樑樕樚樝樠樤樨樰樲"],
        ["8fc5a1", "樴樷樻樾樿橅橆橉橊橎橐橑橒橕橖橛橤橧橪橱橳橾檁檃檆檇檉檋檑檛檝檞檟檥檫檯檰檱檴檽檾檿櫆櫉櫈櫌櫐櫔櫕櫖櫜櫝櫤櫧櫬櫰櫱櫲櫼櫽欂欃欆欇欉欏欐欑欗欛欞欤欨欫欬欯欵欶欻欿歆歊歍歒歖歘歝歠歧歫歮歰歵歽"],
        ["8fc6a1", "歾殂殅殗殛殟殠殢殣殨殩殬殭殮殰殸殹殽殾毃毄毉毌毖毚毡毣毦毧毮毱毷毹毿氂氄氅氉氍氎氐氒氙氟氦氧氨氬氮氳氵氶氺氻氿汊汋汍汏汒汔汙汛汜汫汭汯汴汶汸汹汻沅沆沇沉沔沕沗沘沜沟沰沲沴泂泆泍泏泐泑泒泔泖"],
        ["8fc7a1", "泚泜泠泧泩泫泬泮泲泴洄洇洊洎洏洑洓洚洦洧洨汧洮洯洱洹洼洿浗浞浟浡浥浧浯浰浼涂涇涑涒涔涖涗涘涪涬涴涷涹涽涿淄淈淊淎淏淖淛淝淟淠淢淥淩淯淰淴淶淼渀渄渞渢渧渲渶渹渻渼湄湅湈湉湋湏湑湒湓湔湗湜湝湞"],
        ["8fc8a1", "湢湣湨湳湻湽溍溓溙溠溧溭溮溱溳溻溿滀滁滃滇滈滊滍滎滏滫滭滮滹滻滽漄漈漊漌漍漖漘漚漛漦漩漪漯漰漳漶漻漼漭潏潑潒潓潗潙潚潝潞潡潢潨潬潽潾澃澇澈澋澌澍澐澒澓澔澖澚澟澠澥澦澧澨澮澯澰澵澶澼濅濇濈濊"],
        ["8fc9a1", "濚濞濨濩濰濵濹濼濽瀀瀅瀆瀇瀍瀗瀠瀣瀯瀴瀷瀹瀼灃灄灈灉灊灋灔灕灝灞灎灤灥灬灮灵灶灾炁炅炆炔", 4, "炛炤炫炰炱炴炷烊烑烓烔烕烖烘烜烤烺焃", 4, "焋焌焏焞焠焫焭焯焰焱焸煁煅煆煇煊煋煐煒煗煚煜煞煠"],
        ["8fcaa1", "煨煹熀熅熇熌熒熚熛熠熢熯熰熲熳熺熿燀燁燄燋燌燓燖燙燚燜燸燾爀爇爈爉爓爗爚爝爟爤爫爯爴爸爹牁牂牃牅牎牏牐牓牕牖牚牜牞牠牣牨牫牮牯牱牷牸牻牼牿犄犉犍犎犓犛犨犭犮犱犴犾狁狇狉狌狕狖狘狟狥狳狴狺狻"],
        ["8fcba1", "狾猂猄猅猇猋猍猒猓猘猙猞猢猤猧猨猬猱猲猵猺猻猽獃獍獐獒獖獘獝獞獟獠獦獧獩獫獬獮獯獱獷獹獼玀玁玃玅玆玎玐玓玕玗玘玜玞玟玠玢玥玦玪玫玭玵玷玹玼玽玿珅珆珉珋珌珏珒珓珖珙珝珡珣珦珧珩珴珵珷珹珺珻珽"],
        ["8fcca1", "珿琀琁琄琇琊琑琚琛琤琦琨", 9, "琹瑀瑃瑄瑆瑇瑋瑍瑑瑒瑗瑝瑢瑦瑧瑨瑫瑭瑮瑱瑲璀璁璅璆璇璉璏璐璑璒璘璙璚璜璟璠璡璣璦璨璩璪璫璮璯璱璲璵璹璻璿瓈瓉瓌瓐瓓瓘瓚瓛瓞瓟瓤瓨瓪瓫瓯瓴瓺瓻瓼瓿甆"],
        ["8fcda1", "甒甖甗甠甡甤甧甩甪甯甶甹甽甾甿畀畃畇畈畎畐畒畗畞畟畡畯畱畹", 5, "疁疅疐疒疓疕疙疜疢疤疴疺疿痀痁痄痆痌痎痏痗痜痟痠痡痤痧痬痮痯痱痹瘀瘂瘃瘄瘇瘈瘊瘌瘏瘒瘓瘕瘖瘙瘛瘜瘝瘞瘣瘥瘦瘩瘭瘲瘳瘵瘸瘹"],
        ["8fcea1", "瘺瘼癊癀癁癃癄癅癉癋癕癙癟癤癥癭癮癯癱癴皁皅皌皍皕皛皜皝皟皠皢", 6, "皪皭皽盁盅盉盋盌盎盔盙盠盦盨盬盰盱盶盹盼眀眆眊眎眒眔眕眗眙眚眜眢眨眭眮眯眴眵眶眹眽眾睂睅睆睊睍睎睏睒睖睗睜睞睟睠睢"],
        ["8fcfa1", "睤睧睪睬睰睲睳睴睺睽瞀瞄瞌瞍瞔瞕瞖瞚瞟瞢瞧瞪瞮瞯瞱瞵瞾矃矉矑矒矕矙矞矟矠矤矦矪矬矰矱矴矸矻砅砆砉砍砎砑砝砡砢砣砭砮砰砵砷硃硄硇硈硌硎硒硜硞硠硡硣硤硨硪确硺硾碊碏碔碘碡碝碞碟碤碨碬碭碰碱碲碳"],
        ["8fd0a1", "碻碽碿磇磈磉磌磎磒磓磕磖磤磛磟磠磡磦磪磲磳礀磶磷磺磻磿礆礌礐礚礜礞礟礠礥礧礩礭礱礴礵礻礽礿祄祅祆祊祋祏祑祔祘祛祜祧祩祫祲祹祻祼祾禋禌禑禓禔禕禖禘禛禜禡禨禩禫禯禱禴禸离秂秄秇秈秊秏秔秖秚秝秞"],
        ["8fd1a1", "秠秢秥秪秫秭秱秸秼稂稃稇稉稊稌稑稕稛稞稡稧稫稭稯稰稴稵稸稹稺穄穅穇穈穌穕穖穙穜穝穟穠穥穧穪穭穵穸穾窀窂窅窆窊窋窐窑窔窞窠窣窬窳窵窹窻窼竆竉竌竎竑竛竨竩竫竬竱竴竻竽竾笇笔笟笣笧笩笪笫笭笮笯笰"],
        ["8fd2a1", "笱笴笽笿筀筁筇筎筕筠筤筦筩筪筭筯筲筳筷箄箉箎箐箑箖箛箞箠箥箬箯箰箲箵箶箺箻箼箽篂篅篈篊篔篖篗篙篚篛篨篪篲篴篵篸篹篺篼篾簁簂簃簄簆簉簋簌簎簏簙簛簠簥簦簨簬簱簳簴簶簹簺籆籊籕籑籒籓籙", 5],
        ["8fd3a1", "籡籣籧籩籭籮籰籲籹籼籽粆粇粏粔粞粠粦粰粶粷粺粻粼粿糄糇糈糉糍糏糓糔糕糗糙糚糝糦糩糫糵紃紇紈紉紏紑紒紓紖紝紞紣紦紪紭紱紼紽紾絀絁絇絈絍絑絓絗絙絚絜絝絥絧絪絰絸絺絻絿綁綂綃綅綆綈綋綌綍綑綖綗綝"],
        ["8fd4a1", "綞綦綧綪綳綶綷綹緂", 4, "緌緍緎緗緙縀緢緥緦緪緫緭緱緵緶緹緺縈縐縑縕縗縜縝縠縧縨縬縭縯縳縶縿繄繅繇繎繐繒繘繟繡繢繥繫繮繯繳繸繾纁纆纇纊纍纑纕纘纚纝纞缼缻缽缾缿罃罄罇罏罒罓罛罜罝罡罣罤罥罦罭"],
        ["8fd5a1", "罱罽罾罿羀羋羍羏羐羑羖羗羜羡羢羦羪羭羴羼羿翀翃翈翎翏翛翟翣翥翨翬翮翯翲翺翽翾翿耇耈耊耍耎耏耑耓耔耖耝耞耟耠耤耦耬耮耰耴耵耷耹耺耼耾聀聄聠聤聦聭聱聵肁肈肎肜肞肦肧肫肸肹胈胍胏胒胔胕胗胘胠胭胮"],
        ["8fd6a1", "胰胲胳胶胹胺胾脃脋脖脗脘脜脞脠脤脧脬脰脵脺脼腅腇腊腌腒腗腠腡腧腨腩腭腯腷膁膐膄膅膆膋膎膖膘膛膞膢膮膲膴膻臋臃臅臊臎臏臕臗臛臝臞臡臤臫臬臰臱臲臵臶臸臹臽臿舀舃舏舓舔舙舚舝舡舢舨舲舴舺艃艄艅艆"],
        ["8fd7a1", "艋艎艏艑艖艜艠艣艧艭艴艻艽艿芀芁芃芄芇芉芊芎芑芔芖芘芚芛芠芡芣芤芧芨芩芪芮芰芲芴芷芺芼芾芿苆苐苕苚苠苢苤苨苪苭苯苶苷苽苾茀茁茇茈茊茋荔茛茝茞茟茡茢茬茭茮茰茳茷茺茼茽荂荃荄荇荍荎荑荕荖荗荰荸"],
        ["8fd8a1", "荽荿莀莂莄莆莍莒莔莕莘莙莛莜莝莦莧莩莬莾莿菀菇菉菏菐菑菔菝荓菨菪菶菸菹菼萁萆萊萏萑萕萙莭萯萹葅葇葈葊葍葏葑葒葖葘葙葚葜葠葤葥葧葪葰葳葴葶葸葼葽蒁蒅蒒蒓蒕蒞蒦蒨蒩蒪蒯蒱蒴蒺蒽蒾蓀蓂蓇蓈蓌蓏蓓"],
        ["8fd9a1", "蓜蓧蓪蓯蓰蓱蓲蓷蔲蓺蓻蓽蔂蔃蔇蔌蔎蔐蔜蔞蔢蔣蔤蔥蔧蔪蔫蔯蔳蔴蔶蔿蕆蕏", 4, "蕖蕙蕜", 6, "蕤蕫蕯蕹蕺蕻蕽蕿薁薅薆薉薋薌薏薓薘薝薟薠薢薥薧薴薶薷薸薼薽薾薿藂藇藊藋藎薭藘藚藟藠藦藨藭藳藶藼"],
        ["8fdaa1", "藿蘀蘄蘅蘍蘎蘐蘑蘒蘘蘙蘛蘞蘡蘧蘩蘶蘸蘺蘼蘽虀虂虆虒虓虖虗虘虙虝虠", 4, "虩虬虯虵虶虷虺蚍蚑蚖蚘蚚蚜蚡蚦蚧蚨蚭蚱蚳蚴蚵蚷蚸蚹蚿蛀蛁蛃蛅蛑蛒蛕蛗蛚蛜蛠蛣蛥蛧蚈蛺蛼蛽蜄蜅蜇蜋蜎蜏蜐蜓蜔蜙蜞蜟蜡蜣"],
        ["8fdba1", "蜨蜮蜯蜱蜲蜹蜺蜼蜽蜾蝀蝃蝅蝍蝘蝝蝡蝤蝥蝯蝱蝲蝻螃", 6, "螋螌螐螓螕螗螘螙螞螠螣螧螬螭螮螱螵螾螿蟁蟈蟉蟊蟎蟕蟖蟙蟚蟜蟟蟢蟣蟤蟪蟫蟭蟱蟳蟸蟺蟿蠁蠃蠆蠉蠊蠋蠐蠙蠒蠓蠔蠘蠚蠛蠜蠞蠟蠨蠭蠮蠰蠲蠵"],
        ["8fdca1", "蠺蠼衁衃衅衈衉衊衋衎衑衕衖衘衚衜衟衠衤衩衱衹衻袀袘袚袛袜袟袠袨袪袺袽袾裀裊", 4, "裑裒裓裛裞裧裯裰裱裵裷褁褆褍褎褏褕褖褘褙褚褜褠褦褧褨褰褱褲褵褹褺褾襀襂襅襆襉襏襒襗襚襛襜襡襢襣襫襮襰襳襵襺"],
        ["8fdda1", "襻襼襽覉覍覐覔覕覛覜覟覠覥覰覴覵覶覷覼觔", 4, "觥觩觫觭觱觳觶觹觽觿訄訅訇訏訑訒訔訕訞訠訢訤訦訫訬訯訵訷訽訾詀詃詅詇詉詍詎詓詖詗詘詜詝詡詥詧詵詶詷詹詺詻詾詿誀誃誆誋誏誐誒誖誗誙誟誧誩誮誯誳"],
        ["8fdea1", "誶誷誻誾諃諆諈諉諊諑諓諔諕諗諝諟諬諰諴諵諶諼諿謅謆謋謑謜謞謟謊謭謰謷謼譂", 4, "譈譒譓譔譙譍譞譣譭譶譸譹譼譾讁讄讅讋讍讏讔讕讜讞讟谸谹谽谾豅豇豉豋豏豑豓豔豗豘豛豝豙豣豤豦豨豩豭豳豵豶豻豾貆"],
        ["8fdfa1", "貇貋貐貒貓貙貛貜貤貹貺賅賆賉賋賏賖賕賙賝賡賨賬賯賰賲賵賷賸賾賿贁贃贉贒贗贛赥赩赬赮赿趂趄趈趍趐趑趕趞趟趠趦趫趬趯趲趵趷趹趻跀跅跆跇跈跊跎跑跔跕跗跙跤跥跧跬跰趼跱跲跴跽踁踄踅踆踋踑踔踖踠踡踢"],
        ["8fe0a1", "踣踦踧踱踳踶踷踸踹踽蹀蹁蹋蹍蹎蹏蹔蹛蹜蹝蹞蹡蹢蹩蹬蹭蹯蹰蹱蹹蹺蹻躂躃躉躐躒躕躚躛躝躞躢躧躩躭躮躳躵躺躻軀軁軃軄軇軏軑軔軜軨軮軰軱軷軹軺軭輀輂輇輈輏輐輖輗輘輞輠輡輣輥輧輨輬輭輮輴輵輶輷輺轀轁"],
        ["8fe1a1", "轃轇轏轑", 4, "轘轝轞轥辝辠辡辤辥辦辵辶辸达迀迁迆迊迋迍运迒迓迕迠迣迤迨迮迱迵迶迻迾适逄逈逌逘逛逨逩逯逪逬逭逳逴逷逿遃遄遌遛遝遢遦遧遬遰遴遹邅邈邋邌邎邐邕邗邘邙邛邠邡邢邥邰邲邳邴邶邽郌邾郃"],
        ["8fe2a1", "郄郅郇郈郕郗郘郙郜郝郟郥郒郶郫郯郰郴郾郿鄀鄄鄅鄆鄈鄍鄐鄔鄖鄗鄘鄚鄜鄞鄠鄥鄢鄣鄧鄩鄮鄯鄱鄴鄶鄷鄹鄺鄼鄽酃酇酈酏酓酗酙酚酛酡酤酧酭酴酹酺酻醁醃醅醆醊醎醑醓醔醕醘醞醡醦醨醬醭醮醰醱醲醳醶醻醼醽醿"],
        ["8fe3a1", "釂釃釅釓釔釗釙釚釞釤釥釩釪釬", 5, "釷釹釻釽鈀鈁鈄鈅鈆鈇鈉鈊鈌鈐鈒鈓鈖鈘鈜鈝鈣鈤鈥鈦鈨鈮鈯鈰鈳鈵鈶鈸鈹鈺鈼鈾鉀鉂鉃鉆鉇鉊鉍鉎鉏鉑鉘鉙鉜鉝鉠鉡鉥鉧鉨鉩鉮鉯鉰鉵", 4, "鉻鉼鉽鉿銈銉銊銍銎銒銗"],
        ["8fe4a1", "銙銟銠銤銥銧銨銫銯銲銶銸銺銻銼銽銿", 4, "鋅鋆鋇鋈鋋鋌鋍鋎鋐鋓鋕鋗鋘鋙鋜鋝鋟鋠鋡鋣鋥鋧鋨鋬鋮鋰鋹鋻鋿錀錂錈錍錑錔錕錜錝錞錟錡錤錥錧錩錪錳錴錶錷鍇鍈鍉鍐鍑鍒鍕鍗鍘鍚鍞鍤鍥鍧鍩鍪鍭鍯鍰鍱鍳鍴鍶"],
        ["8fe5a1", "鍺鍽鍿鎀鎁鎂鎈鎊鎋鎍鎏鎒鎕鎘鎛鎞鎡鎣鎤鎦鎨鎫鎴鎵鎶鎺鎩鏁鏄鏅鏆鏇鏉", 4, "鏓鏙鏜鏞鏟鏢鏦鏧鏹鏷鏸鏺鏻鏽鐁鐂鐄鐈鐉鐍鐎鐏鐕鐖鐗鐟鐮鐯鐱鐲鐳鐴鐻鐿鐽鑃鑅鑈鑊鑌鑕鑙鑜鑟鑡鑣鑨鑫鑭鑮鑯鑱鑲钄钃镸镹"],
        ["8fe6a1", "镾閄閈閌閍閎閝閞閟閡閦閩閫閬閴閶閺閽閿闆闈闉闋闐闑闒闓闙闚闝闞闟闠闤闦阝阞阢阤阥阦阬阱阳阷阸阹阺阼阽陁陒陔陖陗陘陡陮陴陻陼陾陿隁隂隃隄隉隑隖隚隝隟隤隥隦隩隮隯隳隺雊雒嶲雘雚雝雞雟雩雯雱雺霂"],
        ["8fe7a1", "霃霅霉霚霛霝霡霢霣霨霱霳靁靃靊靎靏靕靗靘靚靛靣靧靪靮靳靶靷靸靻靽靿鞀鞉鞕鞖鞗鞙鞚鞞鞟鞢鞬鞮鞱鞲鞵鞶鞸鞹鞺鞼鞾鞿韁韄韅韇韉韊韌韍韎韐韑韔韗韘韙韝韞韠韛韡韤韯韱韴韷韸韺頇頊頙頍頎頔頖頜頞頠頣頦"],
        ["8fe8a1", "頫頮頯頰頲頳頵頥頾顄顇顊顑顒顓顖顗顙顚顢顣顥顦顪顬颫颭颮颰颴颷颸颺颻颿飂飅飈飌飡飣飥飦飧飪飳飶餂餇餈餑餕餖餗餚餛餜餟餢餦餧餫餱", 4, "餹餺餻餼饀饁饆饇饈饍饎饔饘饙饛饜饞饟饠馛馝馟馦馰馱馲馵"],
        ["8fe9a1", "馹馺馽馿駃駉駓駔駙駚駜駞駧駪駫駬駰駴駵駹駽駾騂騃騄騋騌騐騑騖騞騠騢騣騤騧騭騮騳騵騶騸驇驁驄驊驋驌驎驑驔驖驝骪骬骮骯骲骴骵骶骹骻骾骿髁髃髆髈髎髐髒髕髖髗髛髜髠髤髥髧髩髬髲髳髵髹髺髽髿", 4],
        ["8feaa1", "鬄鬅鬈鬉鬋鬌鬍鬎鬐鬒鬖鬙鬛鬜鬠鬦鬫鬭鬳鬴鬵鬷鬹鬺鬽魈魋魌魕魖魗魛魞魡魣魥魦魨魪", 4, "魳魵魷魸魹魿鮀鮄鮅鮆鮇鮉鮊鮋鮍鮏鮐鮔鮚鮝鮞鮦鮧鮩鮬鮰鮱鮲鮷鮸鮻鮼鮾鮿鯁鯇鯈鯎鯐鯗鯘鯝鯟鯥鯧鯪鯫鯯鯳鯷鯸"],
        ["8feba1", "鯹鯺鯽鯿鰀鰂鰋鰏鰑鰖鰘鰙鰚鰜鰞鰢鰣鰦", 4, "鰱鰵鰶鰷鰽鱁鱃鱄鱅鱉鱊鱎鱏鱐鱓鱔鱖鱘鱛鱝鱞鱟鱣鱩鱪鱜鱫鱨鱮鱰鱲鱵鱷鱻鳦鳲鳷鳹鴋鴂鴑鴗鴘鴜鴝鴞鴯鴰鴲鴳鴴鴺鴼鵅鴽鵂鵃鵇鵊鵓鵔鵟鵣鵢鵥鵩鵪鵫鵰鵶鵷鵻"],
        ["8feca1", "鵼鵾鶃鶄鶆鶊鶍鶎鶒鶓鶕鶖鶗鶘鶡鶪鶬鶮鶱鶵鶹鶼鶿鷃鷇鷉鷊鷔鷕鷖鷗鷚鷞鷟鷠鷥鷧鷩鷫鷮鷰鷳鷴鷾鸊鸂鸇鸎鸐鸑鸒鸕鸖鸙鸜鸝鹺鹻鹼麀麂麃麄麅麇麎麏麖麘麛麞麤麨麬麮麯麰麳麴麵黆黈黋黕黟黤黧黬黭黮黰黱黲黵"],
        ["8feda1", "黸黿鼂鼃鼉鼏鼐鼑鼒鼔鼖鼗鼙鼚鼛鼟鼢鼦鼪鼫鼯鼱鼲鼴鼷鼹鼺鼼鼽鼿齁齃", 4, "齓齕齖齗齘齚齝齞齨齩齭", 4, "齳齵齺齽龏龐龑龒龔龖龗龞龡龢龣龥"]
    ];
    module.exports = json;
},
/* iconv-lite/encodings/tables/cp936.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = [
        ["0", "\u0000", 127, "€"],
        ["8140", "丂丄丅丆丏丒丗丟丠両丣並丩丮丯丱丳丵丷丼乀乁乂乄乆乊乑乕乗乚乛乢乣乤乥乧乨乪", 5, "乲乴", 9, "乿", 6, "亇亊"],
        ["8180", "亐亖亗亙亜亝亞亣亪亯亰亱亴亶亷亸亹亼亽亾仈仌仏仐仒仚仛仜仠仢仦仧仩仭仮仯仱仴仸仹仺仼仾伀伂", 6, "伋伌伒", 4, "伜伝伡伣伨伩伬伭伮伱伳伵伷伹伻伾", 4, "佄佅佇", 5, "佒佔佖佡佢佦佨佪佫佭佮佱佲併佷佸佹佺佽侀侁侂侅來侇侊侌侎侐侒侓侕侖侘侙侚侜侞侟価侢"],
        ["8240", "侤侫侭侰", 4, "侶", 8, "俀俁係俆俇俈俉俋俌俍俒", 4, "俙俛俠俢俤俥俧俫俬俰俲俴俵俶俷俹俻俼俽俿", 11],
        ["8280", "個倎倐們倓倕倖倗倛倝倞倠倢倣値倧倫倯", 10, "倻倽倿偀偁偂偄偅偆偉偊偋偍偐", 4, "偖偗偘偙偛偝", 7, "偦", 5, "偭", 8, "偸偹偺偼偽傁傂傃傄傆傇傉傊傋傌傎", 20, "傤傦傪傫傭", 4, "傳", 6, "傼"],
        ["8340", "傽", 17, "僐", 5, "僗僘僙僛", 10, "僨僩僪僫僯僰僱僲僴僶", 4, "僼", 9, "儈"],
        ["8380", "儉儊儌", 5, "儓", 13, "儢", 28, "兂兇兊兌兎兏児兒兓兗兘兙兛兝", 4, "兣兤兦內兩兪兯兲兺兾兿冃冄円冇冊冋冎冏冐冑冓冔冘冚冝冞冟冡冣冦", 4, "冭冮冴冸冹冺冾冿凁凂凃凅凈凊凍凎凐凒", 5],
        ["8440", "凘凙凚凜凞凟凢凣凥", 5, "凬凮凱凲凴凷凾刄刅刉刋刌刏刐刓刔刕刜刞刟刡刢刣別刦刧刪刬刯刱刲刴刵刼刾剄", 5, "剋剎剏剒剓剕剗剘"],
        ["8480", "剙剚剛剝剟剠剢剣剤剦剨剫剬剭剮剰剱剳", 9, "剾劀劃", 4, "劉", 6, "劑劒劔", 6, "劜劤劥劦劧劮劯劰労", 9, "勀勁勂勄勅勆勈勊勌勍勎勏勑勓勔動勗務", 5, "勠勡勢勣勥", 10, "勱", 7, "勻勼勽匁匂匃匄匇匉匊匋匌匎"],
        ["8540", "匑匒匓匔匘匛匜匞匟匢匤匥匧匨匩匫匬匭匯", 9, "匼匽區卂卄卆卋卌卍卐協単卙卛卝卥卨卪卬卭卲卶卹卻卼卽卾厀厁厃厇厈厊厎厏"],
        ["8580", "厐", 4, "厖厗厙厛厜厞厠厡厤厧厪厫厬厭厯", 6, "厷厸厹厺厼厽厾叀參", 4, "収叏叐叒叓叕叚叜叝叞叡叢叧叴叺叾叿吀吂吅吇吋吔吘吙吚吜吢吤吥吪吰吳吶吷吺吽吿呁呂呄呅呇呉呌呍呎呏呑呚呝", 4, "呣呥呧呩", 7, "呴呹呺呾呿咁咃咅咇咈咉咊咍咑咓咗咘咜咞咟咠咡"],
        ["8640", "咢咥咮咰咲咵咶咷咹咺咼咾哃哅哊哋哖哘哛哠", 4, "哫哬哯哰哱哴", 5, "哻哾唀唂唃唄唅唈唊", 4, "唒唓唕", 5, "唜唝唞唟唡唥唦"],
        ["8680", "唨唩唫唭唲唴唵唶唸唹唺唻唽啀啂啅啇啈啋", 4, "啑啒啓啔啗", 4, "啝啞啟啠啢啣啨啩啫啯", 5, "啹啺啽啿喅喆喌喍喎喐喒喓喕喖喗喚喛喞喠", 6, "喨", 8, "喲喴営喸喺喼喿", 4, "嗆嗇嗈嗊嗋嗎嗏嗐嗕嗗", 4, "嗞嗠嗢嗧嗩嗭嗮嗰嗱嗴嗶嗸", 4, "嗿嘂嘃嘄嘅"],
        ["8740", "嘆嘇嘊嘋嘍嘐", 7, "嘙嘚嘜嘝嘠嘡嘢嘥嘦嘨嘩嘪嘫嘮嘯嘰嘳嘵嘷嘸嘺嘼嘽嘾噀", 11, "噏", 4, "噕噖噚噛噝", 4],
        ["8780", "噣噥噦噧噭噮噯噰噲噳噴噵噷噸噹噺噽", 7, "嚇", 6, "嚐嚑嚒嚔", 14, "嚤", 10, "嚰", 6, "嚸嚹嚺嚻嚽", 12, "囋", 8, "囕囖囘囙囜団囥", 5, "囬囮囯囲図囶囷囸囻囼圀圁圂圅圇國", 6],
        ["8840", "園", 9, "圝圞圠圡圢圤圥圦圧圫圱圲圴", 4, "圼圽圿坁坃坄坅坆坈坉坋坒", 4, "坘坙坢坣坥坧坬坮坰坱坲坴坵坸坹坺坽坾坿垀"],
        ["8880", "垁垇垈垉垊垍", 4, "垔", 6, "垜垝垞垟垥垨垪垬垯垰垱垳垵垶垷垹", 8, "埄", 6, "埌埍埐埑埓埖埗埛埜埞埡埢埣埥", 7, "埮埰埱埲埳埵埶執埻埼埾埿堁堃堄堅堈堉堊堌堎堏堐堒堓堔堖堗堘堚堛堜堝堟堢堣堥", 4, "堫", 4, "報堲堳場堶", 7],
        ["8940", "堾", 5, "塅", 6, "塎塏塐塒塓塕塖塗塙", 4, "塟", 5, "塦", 4, "塭", 16, "塿墂墄墆墇墈墊墋墌"],
        ["8980", "墍", 4, "墔", 4, "墛墜墝墠", 7, "墪", 17, "墽墾墿壀壂壃壄壆", 10, "壒壓壔壖", 13, "壥", 5, "壭壯壱売壴壵壷壸壺", 7, "夃夅夆夈", 4, "夎夐夑夒夓夗夘夛夝夞夠夡夢夣夦夨夬夰夲夳夵夶夻"],
        ["8a40", "夽夾夿奀奃奅奆奊奌奍奐奒奓奙奛", 4, "奡奣奤奦", 12, "奵奷奺奻奼奾奿妀妅妉妋妌妎妏妐妑妔妕妘妚妛妜妝妟妠妡妢妦"],
        ["8a80", "妧妬妭妰妱妳", 5, "妺妼妽妿", 6, "姇姈姉姌姍姎姏姕姖姙姛姞", 4, "姤姦姧姩姪姫姭", 11, "姺姼姽姾娀娂娊娋娍娎娏娐娒娔娕娖娗娙娚娛娝娞娡娢娤娦娧娨娪", 6, "娳娵娷", 4, "娽娾娿婁", 4, "婇婈婋", 9, "婖婗婘婙婛", 5],
        ["8b40", "婡婣婤婥婦婨婩婫", 8, "婸婹婻婼婽婾媀", 17, "媓", 6, "媜", 13, "媫媬"],
        ["8b80", "媭", 4, "媴媶媷媹", 4, "媿嫀嫃", 5, "嫊嫋嫍", 4, "嫓嫕嫗嫙嫚嫛嫝嫞嫟嫢嫤嫥嫧嫨嫪嫬", 4, "嫲", 22, "嬊", 11, "嬘", 25, "嬳嬵嬶嬸", 7, "孁", 6],
        ["8c40", "孈", 7, "孒孖孞孠孡孧孨孫孭孮孯孲孴孶孷學孹孻孼孾孿宂宆宊宍宎宐宑宒宔宖実宧宨宩宬宭宮宯宱宲宷宺宻宼寀寁寃寈寉寊寋寍寎寏"],
        ["8c80", "寑寔", 8, "寠寢寣實寧審", 4, "寯寱", 6, "寽対尀専尃尅將專尋尌對導尐尒尓尗尙尛尞尟尠尡尣尦尨尩尪尫尭尮尯尰尲尳尵尶尷屃屄屆屇屌屍屒屓屔屖屗屘屚屛屜屝屟屢層屧", 6, "屰屲", 6, "屻屼屽屾岀岃", 4, "岉岊岋岎岏岒岓岕岝", 4, "岤", 4],
        ["8d40", "岪岮岯岰岲岴岶岹岺岻岼岾峀峂峃峅", 5, "峌", 5, "峓", 5, "峚", 6, "峢峣峧峩峫峬峮峯峱", 9, "峼", 4],
        ["8d80", "崁崄崅崈", 5, "崏", 4, "崕崗崘崙崚崜崝崟", 4, "崥崨崪崫崬崯", 4, "崵", 7, "崿", 7, "嵈嵉嵍", 10, "嵙嵚嵜嵞", 10, "嵪嵭嵮嵰嵱嵲嵳嵵", 12, "嶃", 21, "嶚嶛嶜嶞嶟嶠"],
        ["8e40", "嶡", 21, "嶸", 12, "巆", 6, "巎", 12, "巜巟巠巣巤巪巬巭"],
        ["8e80", "巰巵巶巸", 4, "巿帀帄帇帉帊帋帍帎帒帓帗帞", 7, "帨", 4, "帯帰帲", 4, "帹帺帾帿幀幁幃幆", 5, "幍", 6, "幖", 4, "幜幝幟幠幣", 14, "幵幷幹幾庁庂広庅庈庉庌庍庎庒庘庛庝庡庢庣庤庨", 4, "庮", 4, "庴庺庻庼庽庿", 6],
        ["8f40", "廆廇廈廋", 5, "廔廕廗廘廙廚廜", 11, "廩廫", 8, "廵廸廹廻廼廽弅弆弇弉弌弍弎弐弒弔弖弙弚弜弝弞弡弢弣弤"],
        ["8f80", "弨弫弬弮弰弲", 6, "弻弽弾弿彁", 14, "彑彔彙彚彛彜彞彟彠彣彥彧彨彫彮彯彲彴彵彶彸彺彽彾彿徃徆徍徎徏徑従徔徖徚徛徝從徟徠徢", 5, "復徫徬徯", 5, "徶徸徹徺徻徾", 4, "忇忈忊忋忎忓忔忕忚忛応忞忟忢忣忥忦忨忩忬忯忰忲忳忴忶忷忹忺忼怇"],
        ["9040", "怈怉怋怌怐怑怓怗怘怚怞怟怢怣怤怬怭怮怰", 4, "怶", 4, "怽怾恀恄", 6, "恌恎恏恑恓恔恖恗恘恛恜恞恟恠恡恥恦恮恱恲恴恵恷恾悀"],
        ["9080", "悁悂悅悆悇悈悊悋悎悏悐悑悓悕悗悘悙悜悞悡悢悤悥悧悩悪悮悰悳悵悶悷悹悺悽", 7, "惇惈惉惌", 4, "惒惓惔惖惗惙惛惞惡", 4, "惪惱惲惵惷惸惻", 4, "愂愃愄愅愇愊愋愌愐", 4, "愖愗愘愙愛愜愝愞愡愢愥愨愩愪愬", 18, "慀", 6],
        ["9140", "慇慉態慍慏慐慒慓慔慖", 6, "慞慟慠慡慣慤慥慦慩", 6, "慱慲慳慴慶慸", 18, "憌憍憏", 4, "憕"],
        ["9180", "憖", 6, "憞", 8, "憪憫憭", 9, "憸", 5, "憿懀懁懃", 4, "應懌", 4, "懓懕", 16, "懧", 13, "懶", 8, "戀", 5, "戇戉戓戔戙戜戝戞戠戣戦戧戨戩戫戭戯戰戱戲戵戶戸", 4, "扂扄扅扆扊"],
        ["9240", "扏扐払扖扗扙扚扜", 6, "扤扥扨扱扲扴扵扷扸扺扻扽抁抂抃抅抆抇抈抋", 5, "抔抙抜抝択抣抦抧抩抪抭抮抯抰抲抳抴抶抷抸抺抾拀拁"],
        ["9280", "拃拋拏拑拕拝拞拠拡拤拪拫拰拲拵拸拹拺拻挀挃挄挅挆挊挋挌挍挏挐挒挓挔挕挗挘挙挜挦挧挩挬挭挮挰挱挳", 5, "挻挼挾挿捀捁捄捇捈捊捑捒捓捔捖", 7, "捠捤捥捦捨捪捫捬捯捰捲捳捴捵捸捹捼捽捾捿掁掃掄掅掆掋掍掑掓掔掕掗掙", 6, "採掤掦掫掯掱掲掵掶掹掻掽掿揀"],
        ["9340", "揁揂揃揅揇揈揊揋揌揑揓揔揕揗", 6, "揟揢揤", 4, "揫揬揮揯揰揱揳揵揷揹揺揻揼揾搃搄搆", 4, "損搎搑搒搕", 5, "搝搟搢搣搤"],
        ["9380", "搥搧搨搩搫搮", 5, "搵", 4, "搻搼搾摀摂摃摉摋", 6, "摓摕摖摗摙", 4, "摟", 7, "摨摪摫摬摮", 9, "摻", 6, "撃撆撈", 8, "撓撔撗撘撚撛撜撝撟", 4, "撥撦撧撨撪撫撯撱撲撳撴撶撹撻撽撾撿擁擃擄擆", 6, "擏擑擓擔擕擖擙據"],
        ["9440", "擛擜擝擟擠擡擣擥擧", 24, "攁", 7, "攊", 7, "攓", 4, "攙", 8],
        ["9480", "攢攣攤攦", 4, "攬攭攰攱攲攳攷攺攼攽敀", 4, "敆敇敊敋敍敎敐敒敓敔敗敘敚敜敟敠敡敤敥敧敨敩敪敭敮敯敱敳敵敶數", 14, "斈斉斊斍斎斏斒斔斕斖斘斚斝斞斠斢斣斦斨斪斬斮斱", 7, "斺斻斾斿旀旂旇旈旉旊旍旐旑旓旔旕旘", 7, "旡旣旤旪旫"],
        ["9540", "旲旳旴旵旸旹旻", 4, "昁昄昅昇昈昉昋昍昐昑昒昖昗昘昚昛昜昞昡昢昣昤昦昩昪昫昬昮昰昲昳昷", 4, "昽昿晀時晄", 6, "晍晎晐晑晘"],
        ["9580", "晙晛晜晝晞晠晢晣晥晧晩", 4, "晱晲晳晵晸晹晻晼晽晿暀暁暃暅暆暈暉暊暋暍暎暏暐暒暓暔暕暘", 4, "暞", 8, "暩", 4, "暯", 4, "暵暶暷暸暺暻暼暽暿", 25, "曚曞", 7, "曧曨曪", 5, "曱曵曶書曺曻曽朁朂會"],
        ["9640", "朄朅朆朇朌朎朏朑朒朓朖朘朙朚朜朞朠", 5, "朧朩朮朰朲朳朶朷朸朹朻朼朾朿杁杄杅杇杊杋杍杒杔杕杗", 4, "杝杢杣杤杦杧杫杬杮東杴杶"],
        ["9680", "杸杹杺杻杽枀枂枃枅枆枈枊枌枍枎枏枑枒枓枔枖枙枛枟枠枡枤枦枩枬枮枱枲枴枹", 7, "柂柅", 9, "柕柖柗柛柟柡柣柤柦柧柨柪柫柭柮柲柵", 7, "柾栁栂栃栄栆栍栐栒栔栕栘", 4, "栞栟栠栢", 6, "栫", 6, "栴栵栶栺栻栿桇桋桍桏桒桖", 5],
        ["9740", "桜桝桞桟桪桬", 7, "桵桸", 8, "梂梄梇", 7, "梐梑梒梔梕梖梘", 9, "梣梤梥梩梪梫梬梮梱梲梴梶梷梸"],
        ["9780", "梹", 6, "棁棃", 5, "棊棌棎棏棐棑棓棔棖棗棙棛", 4, "棡棢棤", 9, "棯棲棳棴棶棷棸棻棽棾棿椀椂椃椄椆", 4, "椌椏椑椓", 11, "椡椢椣椥", 7, "椮椯椱椲椳椵椶椷椸椺椻椼椾楀楁楃", 16, "楕楖楘楙楛楜楟"],
        ["9840", "楡楢楤楥楧楨楩楪楬業楯楰楲", 4, "楺楻楽楾楿榁榃榅榊榋榌榎", 5, "榖榗榙榚榝", 9, "榩榪榬榮榯榰榲榳榵榶榸榹榺榼榽"],
        ["9880", "榾榿槀槂", 7, "構槍槏槑槒槓槕", 5, "槜槝槞槡", 11, "槮槯槰槱槳", 9, "槾樀", 9, "樋", 11, "標", 5, "樠樢", 5, "権樫樬樭樮樰樲樳樴樶", 6, "樿", 4, "橅橆橈", 7, "橑", 6, "橚"],
        ["9940", "橜", 4, "橢橣橤橦", 10, "橲", 6, "橺橻橽橾橿檁檂檃檅", 8, "檏檒", 4, "檘", 7, "檡", 5],
        ["9980", "檧檨檪檭", 114, "欥欦欨", 6],
        ["9a40", "欯欰欱欳欴欵欶欸欻欼欽欿歀歁歂歄歅歈歊歋歍", 11, "歚", 7, "歨歩歫", 13, "歺歽歾歿殀殅殈"],
        ["9a80", "殌殎殏殐殑殔殕殗殘殙殜", 4, "殢", 7, "殫", 7, "殶殸", 6, "毀毃毄毆", 4, "毌毎毐毑毘毚毜", 4, "毢", 7, "毬毭毮毰毱毲毴毶毷毸毺毻毼毾", 6, "氈", 4, "氎氒気氜氝氞氠氣氥氫氬氭氱氳氶氷氹氺氻氼氾氿汃汄汅汈汋", 4, "汑汒汓汖汘"],
        ["9b40", "汙汚汢汣汥汦汧汫", 4, "汱汳汵汷汸決汻汼汿沀沄沇沊沋沍沎沑沒沕沖沗沘沚沜沝沞沠沢沨沬沯沰沴沵沶沷沺泀況泂泃泆泇泈泋泍泎泏泑泒泘"],
        ["9b80", "泙泚泜泝泟泤泦泧泩泬泭泲泴泹泿洀洂洃洅洆洈洉洊洍洏洐洑洓洔洕洖洘洜洝洟", 5, "洦洨洩洬洭洯洰洴洶洷洸洺洿浀浂浄浉浌浐浕浖浗浘浛浝浟浡浢浤浥浧浨浫浬浭浰浱浲浳浵浶浹浺浻浽", 4, "涃涄涆涇涊涋涍涏涐涒涖", 4, "涜涢涥涬涭涰涱涳涴涶涷涹", 5, "淁淂淃淈淉淊"],
        ["9c40", "淍淎淏淐淒淓淔淕淗淚淛淜淟淢淣淥淧淨淩淪淭淯淰淲淴淵淶淸淺淽", 7, "渆渇済渉渋渏渒渓渕渘渙減渜渞渟渢渦渧渨渪測渮渰渱渳渵"],
        ["9c80", "渶渷渹渻", 7, "湅", 7, "湏湐湑湒湕湗湙湚湜湝湞湠", 10, "湬湭湯", 14, "満溁溂溄溇溈溊", 4, "溑", 6, "溙溚溛溝溞溠溡溣溤溦溨溩溫溬溭溮溰溳溵溸溹溼溾溿滀滃滄滅滆滈滉滊滌滍滎滐滒滖滘滙滛滜滝滣滧滪", 5],
        ["9d40", "滰滱滲滳滵滶滷滸滺", 7, "漃漄漅漇漈漊", 4, "漐漑漒漖", 9, "漡漢漣漥漦漧漨漬漮漰漲漴漵漷", 6, "漿潀潁潂"],
        ["9d80", "潃潄潅潈潉潊潌潎", 9, "潙潚潛潝潟潠潡潣潤潥潧", 5, "潯潰潱潳潵潶潷潹潻潽", 6, "澅澆澇澊澋澏", 12, "澝澞澟澠澢", 4, "澨", 10, "澴澵澷澸澺", 5, "濁濃", 5, "濊", 6, "濓", 10, "濟濢濣濤濥"],
        ["9e40", "濦", 7, "濰", 32, "瀒", 7, "瀜", 6, "瀤", 6],
        ["9e80", "瀫", 9, "瀶瀷瀸瀺", 17, "灍灎灐", 13, "灟", 11, "灮灱灲灳灴灷灹灺灻災炁炂炃炄炆炇炈炋炌炍炏炐炑炓炗炘炚炛炞", 12, "炰炲炴炵炶為炾炿烄烅烆烇烉烋", 12, "烚"],
        ["9f40", "烜烝烞烠烡烢烣烥烪烮烰", 6, "烸烺烻烼烾", 10, "焋", 4, "焑焒焔焗焛", 10, "焧", 7, "焲焳焴"],
        ["9f80", "焵焷", 13, "煆煇煈煉煋煍煏", 12, "煝煟", 4, "煥煩", 4, "煯煰煱煴煵煶煷煹煻煼煾", 5, "熅", 4, "熋熌熍熎熐熑熒熓熕熖熗熚", 4, "熡", 6, "熩熪熫熭", 5, "熴熶熷熸熺", 8, "燄", 9, "燏", 4],
        ["a040", "燖", 9, "燡燢燣燤燦燨", 5, "燯", 9, "燺", 11, "爇", 19],
        ["a080", "爛爜爞", 9, "爩爫爭爮爯爲爳爴爺爼爾牀", 6, "牉牊牋牎牏牐牑牓牔牕牗牘牚牜牞牠牣牤牥牨牪牫牬牭牰牱牳牴牶牷牸牻牼牽犂犃犅", 4, "犌犎犐犑犓", 11, "犠", 11, "犮犱犲犳犵犺", 6, "狅狆狇狉狊狋狌狏狑狓狔狕狖狘狚狛"],
        ["a1a1", "　、。·ˉˇ¨〃々—～‖…‘’“”〔〕〈", 7, "〖〗【】±×÷∶∧∨∑∏∪∩∈∷√⊥∥∠⌒⊙∫∮≡≌≈∽∝≠≮≯≤≥∞∵∴♂♀°′″℃＄¤￠￡‰§№☆★○●◎◇◆□■△▲※→←↑↓〓"],
        ["a2a1", "ⅰ", 9],
        ["a2b1", "⒈", 19, "⑴", 19, "①", 9],
        ["a2e5", "㈠", 9],
        ["a2f1", "Ⅰ", 11],
        ["a3a1", "！＂＃￥％", 88, "￣"],
        ["a4a1", "ぁ", 82],
        ["a5a1", "ァ", 85],
        ["a6a1", "Α", 16, "Σ", 6],
        ["a6c1", "α", 16, "σ", 6],
        ["a6e0", "︵︶︹︺︿﹀︽︾﹁﹂﹃﹄"],
        ["a6ee", "︻︼︷︸︱"],
        ["a6f4", "︳︴"],
        ["a7a1", "А", 5, "ЁЖ", 25],
        ["a7d1", "а", 5, "ёж", 25],
        ["a840", "ˊˋ˙–―‥‵℅℉↖↗↘↙∕∟∣≒≦≧⊿═", 35, "▁", 6],
        ["a880", "█", 7, "▓▔▕▼▽◢◣◤◥☉⊕〒〝〞"],
        ["a8a1", "āáǎàēéěèīíǐìōóǒòūúǔùǖǘǚǜüêɑ"],
        ["a8bd", "ńň"],
        ["a8c0", "ɡ"],
        ["a8c5", "ㄅ", 36],
        ["a940", "〡", 8, "㊣㎎㎏㎜㎝㎞㎡㏄㏎㏑㏒㏕︰￢￤"],
        ["a959", "℡㈱"],
        ["a95c", "‐"],
        ["a960", "ー゛゜ヽヾ〆ゝゞ﹉", 9, "﹔﹕﹖﹗﹙", 8],
        ["a980", "﹢", 4, "﹨﹩﹪﹫"],
        ["a996", "〇"],
        ["a9a4", "─", 75],
        ["aa40", "狜狝狟狢", 5, "狪狫狵狶狹狽狾狿猀猂猄", 5, "猋猌猍猏猐猑猒猔猘猙猚猟猠猣猤猦猧猨猭猯猰猲猳猵猶猺猻猼猽獀", 8],
        ["aa80", "獉獊獋獌獎獏獑獓獔獕獖獘", 7, "獡", 10, "獮獰獱"],
        ["ab40", "獲", 11, "獿", 4, "玅玆玈玊玌玍玏玐玒玓玔玕玗玘玙玚玜玝玞玠玡玣", 5, "玪玬玭玱玴玵玶玸玹玼玽玾玿珁珃", 4],
        ["ab80", "珋珌珎珒", 6, "珚珛珜珝珟珡珢珣珤珦珨珪珫珬珮珯珰珱珳", 4],
        ["ac40", "珸", 10, "琄琇琈琋琌琍琎琑", 8, "琜", 5, "琣琤琧琩琫琭琯琱琲琷", 4, "琽琾琿瑀瑂", 11],
        ["ac80", "瑎", 6, "瑖瑘瑝瑠", 12, "瑮瑯瑱", 4, "瑸瑹瑺"],
        ["ad40", "瑻瑼瑽瑿璂璄璅璆璈璉璊璌璍璏璑", 10, "璝璟", 7, "璪", 15, "璻", 12],
        ["ad80", "瓈", 9, "瓓", 8, "瓝瓟瓡瓥瓧", 6, "瓰瓱瓲"],
        ["ae40", "瓳瓵瓸", 6, "甀甁甂甃甅", 7, "甎甐甒甔甕甖甗甛甝甞甠", 4, "甦甧甪甮甴甶甹甼甽甿畁畂畃畄畆畇畉畊畍畐畑畒畓畕畖畗畘"],
        ["ae80", "畝", 7, "畧畨畩畫", 6, "畳畵當畷畺", 4, "疀疁疂疄疅疇"],
        ["af40", "疈疉疊疌疍疎疐疓疕疘疛疜疞疢疦", 4, "疭疶疷疺疻疿痀痁痆痋痌痎痏痐痑痓痗痙痚痜痝痟痠痡痥痩痬痭痮痯痲痳痵痶痷痸痺痻痽痾瘂瘄瘆瘇"],
        ["af80", "瘈瘉瘋瘍瘎瘏瘑瘒瘓瘔瘖瘚瘜瘝瘞瘡瘣瘧瘨瘬瘮瘯瘱瘲瘶瘷瘹瘺瘻瘽癁療癄"],
        ["b040", "癅", 6, "癎", 5, "癕癗", 4, "癝癟癠癡癢癤", 6, "癬癭癮癰", 7, "癹発發癿皀皁皃皅皉皊皌皍皏皐皒皔皕皗皘皚皛"],
        ["b080", "皜", 7, "皥", 8, "皯皰皳皵", 9, "盀盁盃啊阿埃挨哎唉哀皑癌蔼矮艾碍爱隘鞍氨安俺按暗岸胺案肮昂盎凹敖熬翱袄傲奥懊澳芭捌扒叭吧笆八疤巴拔跋靶把耙坝霸罢爸白柏百摆佰败拜稗斑班搬扳般颁板版扮拌伴瓣半办绊邦帮梆榜膀绑棒磅蚌镑傍谤苞胞包褒剥"],
        ["b140", "盄盇盉盋盌盓盕盙盚盜盝盞盠", 4, "盦", 7, "盰盳盵盶盷盺盻盽盿眀眂眃眅眆眊県眎", 10, "眛眜眝眞眡眣眤眥眧眪眫"],
        ["b180", "眬眮眰", 4, "眹眻眽眾眿睂睄睅睆睈", 7, "睒", 7, "睜薄雹保堡饱宝抱报暴豹鲍爆杯碑悲卑北辈背贝钡倍狈备惫焙被奔苯本笨崩绷甭泵蹦迸逼鼻比鄙笔彼碧蓖蔽毕毙毖币庇痹闭敝弊必辟壁臂避陛鞭边编贬扁便变卞辨辩辫遍标彪膘表鳖憋别瘪彬斌濒滨宾摈兵冰柄丙秉饼炳"],
        ["b240", "睝睞睟睠睤睧睩睪睭", 11, "睺睻睼瞁瞂瞃瞆", 5, "瞏瞐瞓", 11, "瞡瞣瞤瞦瞨瞫瞭瞮瞯瞱瞲瞴瞶", 4],
        ["b280", "瞼瞾矀", 12, "矎", 8, "矘矙矚矝", 4, "矤病并玻菠播拨钵波博勃搏铂箔伯帛舶脖膊渤泊驳捕卜哺补埠不布步簿部怖擦猜裁材才财睬踩采彩菜蔡餐参蚕残惭惨灿苍舱仓沧藏操糙槽曹草厕策侧册测层蹭插叉茬茶查碴搽察岔差诧拆柴豺搀掺蝉馋谗缠铲产阐颤昌猖"],
        ["b340", "矦矨矪矯矰矱矲矴矵矷矹矺矻矼砃", 5, "砊砋砎砏砐砓砕砙砛砞砠砡砢砤砨砪砫砮砯砱砲砳砵砶砽砿硁硂硃硄硆硈硉硊硋硍硏硑硓硔硘硙硚"],
        ["b380", "硛硜硞", 11, "硯", 7, "硸硹硺硻硽", 6, "场尝常长偿肠厂敞畅唱倡超抄钞朝嘲潮巢吵炒车扯撤掣彻澈郴臣辰尘晨忱沉陈趁衬撑称城橙成呈乘程惩澄诚承逞骋秤吃痴持匙池迟弛驰耻齿侈尺赤翅斥炽充冲虫崇宠抽酬畴踌稠愁筹仇绸瞅丑臭初出橱厨躇锄雏滁除楚"],
        ["b440", "碄碅碆碈碊碋碏碐碒碔碕碖碙碝碞碠碢碤碦碨", 7, "碵碶碷碸確碻碼碽碿磀磂磃磄磆磇磈磌磍磎磏磑磒磓磖磗磘磚", 9],
        ["b480", "磤磥磦磧磩磪磫磭", 4, "磳磵磶磸磹磻", 5, "礂礃礄礆", 6, "础储矗搐触处揣川穿椽传船喘串疮窗幢床闯创吹炊捶锤垂春椿醇唇淳纯蠢戳绰疵茨磁雌辞慈瓷词此刺赐次聪葱囱匆从丛凑粗醋簇促蹿篡窜摧崔催脆瘁粹淬翠村存寸磋撮搓措挫错搭达答瘩打大呆歹傣戴带殆代贷袋待逮"],
        ["b540", "礍", 5, "礔", 9, "礟", 4, "礥", 14, "礵", 4, "礽礿祂祃祄祅祇祊", 8, "祔祕祘祙祡祣"],
        ["b580", "祤祦祩祪祫祬祮祰", 6, "祹祻", 4, "禂禃禆禇禈禉禋禌禍禎禐禑禒怠耽担丹单郸掸胆旦氮但惮淡诞弹蛋当挡党荡档刀捣蹈倒岛祷导到稻悼道盗德得的蹬灯登等瞪凳邓堤低滴迪敌笛狄涤翟嫡抵底地蒂第帝弟递缔颠掂滇碘点典靛垫电佃甸店惦奠淀殿碉叼雕凋刁掉吊钓调跌爹碟蝶迭谍叠"],
        ["b640", "禓", 6, "禛", 11, "禨", 10, "禴", 4, "禼禿秂秄秅秇秈秊秌秎秏秐秓秔秖秗秙", 5, "秠秡秢秥秨秪"],
        ["b680", "秬秮秱", 6, "秹秺秼秾秿稁稄稅稇稈稉稊稌稏", 4, "稕稖稘稙稛稜丁盯叮钉顶鼎锭定订丢东冬董懂动栋侗恫冻洞兜抖斗陡豆逗痘都督毒犊独读堵睹赌杜镀肚度渡妒端短锻段断缎堆兑队对墩吨蹲敦顿囤钝盾遁掇哆多夺垛躲朵跺舵剁惰堕蛾峨鹅俄额讹娥恶厄扼遏鄂饿恩而儿耳尔饵洱二"],
        ["b740", "稝稟稡稢稤", 14, "稴稵稶稸稺稾穀", 5, "穇", 9, "穒", 4, "穘", 16],
        ["b780", "穩", 6, "穱穲穳穵穻穼穽穾窂窅窇窉窊窋窌窎窏窐窓窔窙窚窛窞窡窢贰发罚筏伐乏阀法珐藩帆番翻樊矾钒繁凡烦反返范贩犯饭泛坊芳方肪房防妨仿访纺放菲非啡飞肥匪诽吠肺废沸费芬酚吩氛分纷坟焚汾粉奋份忿愤粪丰封枫蜂峰锋风疯烽逢冯缝讽奉凤佛否夫敷肤孵扶拂辐幅氟符伏俘服"],
        ["b840", "窣窤窧窩窪窫窮", 4, "窴", 10, "竀", 10, "竌", 9, "竗竘竚竛竜竝竡竢竤竧", 5, "竮竰竱竲竳"],
        ["b880", "竴", 4, "竻竼竾笀笁笂笅笇笉笌笍笎笐笒笓笖笗笘笚笜笝笟笡笢笣笧笩笭浮涪福袱弗甫抚辅俯釜斧脯腑府腐赴副覆赋复傅付阜父腹负富讣附妇缚咐噶嘎该改概钙盖溉干甘杆柑竿肝赶感秆敢赣冈刚钢缸肛纲岗港杠篙皋高膏羔糕搞镐稿告哥歌搁戈鸽胳疙割革葛格蛤阁隔铬个各给根跟耕更庚羹"],
        ["b940", "笯笰笲笴笵笶笷笹笻笽笿", 5, "筆筈筊筍筎筓筕筗筙筜筞筟筡筣", 10, "筯筰筳筴筶筸筺筼筽筿箁箂箃箄箆", 6, "箎箏"],
        ["b980", "箑箒箓箖箘箙箚箛箞箟箠箣箤箥箮箯箰箲箳箵箶箷箹", 7, "篂篃範埂耿梗工攻功恭龚供躬公宫弓巩汞拱贡共钩勾沟苟狗垢构购够辜菇咕箍估沽孤姑鼓古蛊骨谷股故顾固雇刮瓜剐寡挂褂乖拐怪棺关官冠观管馆罐惯灌贯光广逛瑰规圭硅归龟闺轨鬼诡癸桂柜跪贵刽辊滚棍锅郭国果裹过哈"],
        ["ba40", "篅篈築篊篋篍篎篏篐篒篔", 4, "篛篜篞篟篠篢篣篤篧篨篩篫篬篭篯篰篲", 4, "篸篹篺篻篽篿", 7, "簈簉簊簍簎簐", 5, "簗簘簙"],
        ["ba80", "簚", 4, "簠", 5, "簨簩簫", 12, "簹", 5, "籂骸孩海氦亥害骇酣憨邯韩含涵寒函喊罕翰撼捍旱憾悍焊汗汉夯杭航壕嚎豪毫郝好耗号浩呵喝荷菏核禾和何合盒貉阂河涸赫褐鹤贺嘿黑痕很狠恨哼亨横衡恒轰哄烘虹鸿洪宏弘红喉侯猴吼厚候后呼乎忽瑚壶葫胡蝴狐糊湖"],
        ["bb40", "籃", 9, "籎", 36, "籵", 5, "籾", 9],
        ["bb80", "粈粊", 6, "粓粔粖粙粚粛粠粡粣粦粧粨粩粫粬粭粯粰粴", 4, "粺粻弧虎唬护互沪户花哗华猾滑画划化话槐徊怀淮坏欢环桓还缓换患唤痪豢焕涣宦幻荒慌黄磺蝗簧皇凰惶煌晃幌恍谎灰挥辉徽恢蛔回毁悔慧卉惠晦贿秽会烩汇讳诲绘荤昏婚魂浑混豁活伙火获或惑霍货祸击圾基机畸稽积箕"],
        ["bc40", "粿糀糂糃糄糆糉糋糎", 6, "糘糚糛糝糞糡", 6, "糩", 5, "糰", 7, "糹糺糼", 13, "紋", 5],
        ["bc80", "紑", 14, "紡紣紤紥紦紨紩紪紬紭紮細", 6, "肌饥迹激讥鸡姬绩缉吉极棘辑籍集及急疾汲即嫉级挤几脊己蓟技冀季伎祭剂悸济寄寂计记既忌际妓继纪嘉枷夹佳家加荚颊贾甲钾假稼价架驾嫁歼监坚尖笺间煎兼肩艰奸缄茧检柬碱硷拣捡简俭剪减荐槛鉴践贱见键箭件"],
        ["bd40", "紷", 54, "絯", 7],
        ["bd80", "絸", 32, "健舰剑饯渐溅涧建僵姜将浆江疆蒋桨奖讲匠酱降蕉椒礁焦胶交郊浇骄娇嚼搅铰矫侥脚狡角饺缴绞剿教酵轿较叫窖揭接皆秸街阶截劫节桔杰捷睫竭洁结解姐戒藉芥界借介疥诫届巾筋斤金今津襟紧锦仅谨进靳晋禁近烬浸"],
        ["be40", "継", 12, "綧", 6, "綯", 42],
        ["be80", "線", 32, "尽劲荆兢茎睛晶鲸京惊精粳经井警景颈静境敬镜径痉靖竟竞净炯窘揪究纠玖韭久灸九酒厩救旧臼舅咎就疚鞠拘狙疽居驹菊局咀矩举沮聚拒据巨具距踞锯俱句惧炬剧捐鹃娟倦眷卷绢撅攫抉掘倔爵觉决诀绝均菌钧军君峻"],
        ["bf40", "緻", 62],
        ["bf80", "縺縼", 4, "繂", 4, "繈", 21, "俊竣浚郡骏喀咖卡咯开揩楷凯慨刊堪勘坎砍看康慷糠扛抗亢炕考拷烤靠坷苛柯棵磕颗科壳咳可渴克刻客课肯啃垦恳坑吭空恐孔控抠口扣寇枯哭窟苦酷库裤夸垮挎跨胯块筷侩快宽款匡筐狂框矿眶旷况亏盔岿窥葵奎魁傀"],
        ["c040", "繞", 35, "纃", 23, "纜纝纞"],
        ["c080", "纮纴纻纼绖绤绬绹缊缐缞缷缹缻", 6, "罃罆", 9, "罒罓馈愧溃坤昆捆困括扩廓阔垃拉喇蜡腊辣啦莱来赖蓝婪栏拦篮阑兰澜谰揽览懒缆烂滥琅榔狼廊郎朗浪捞劳牢老佬姥酪烙涝勒乐雷镭蕾磊累儡垒擂肋类泪棱楞冷厘梨犁黎篱狸离漓理李里鲤礼莉荔吏栗丽厉励砾历利傈例俐"],
        ["c140", "罖罙罛罜罝罞罠罣", 4, "罫罬罭罯罰罳罵罶罷罸罺罻罼罽罿羀羂", 7, "羋羍羏", 4, "羕", 4, "羛羜羠羢羣羥羦羨", 6, "羱"],
        ["c180", "羳", 4, "羺羻羾翀翂翃翄翆翇翈翉翋翍翏", 4, "翖翗翙", 5, "翢翣痢立粒沥隶力璃哩俩联莲连镰廉怜涟帘敛脸链恋炼练粮凉梁粱良两辆量晾亮谅撩聊僚疗燎寥辽潦了撂镣廖料列裂烈劣猎琳林磷霖临邻鳞淋凛赁吝拎玲菱零龄铃伶羚凌灵陵岭领另令溜琉榴硫馏留刘瘤流柳六龙聋咙笼窿"],
        ["c240", "翤翧翨翪翫翬翭翯翲翴", 6, "翽翾翿耂耇耈耉耊耎耏耑耓耚耛耝耞耟耡耣耤耫", 5, "耲耴耹耺耼耾聀聁聄聅聇聈聉聎聏聐聑聓聕聖聗"],
        ["c280", "聙聛", 13, "聫", 5, "聲", 11, "隆垄拢陇楼娄搂篓漏陋芦卢颅庐炉掳卤虏鲁麓碌露路赂鹿潞禄录陆戮驴吕铝侣旅履屡缕虑氯律率滤绿峦挛孪滦卵乱掠略抡轮伦仑沦纶论萝螺罗逻锣箩骡裸落洛骆络妈麻玛码蚂马骂嘛吗埋买麦卖迈脉瞒馒蛮满蔓曼慢漫"],
        ["c340", "聾肁肂肅肈肊肍", 5, "肔肕肗肙肞肣肦肧肨肬肰肳肵肶肸肹肻胅胇", 4, "胏", 6, "胘胟胠胢胣胦胮胵胷胹胻胾胿脀脁脃脄脅脇脈脋"],
        ["c380", "脌脕脗脙脛脜脝脟", 12, "脭脮脰脳脴脵脷脹", 4, "脿谩芒茫盲氓忙莽猫茅锚毛矛铆卯茂冒帽貌贸么玫枚梅酶霉煤没眉媒镁每美昧寐妹媚门闷们萌蒙檬盟锰猛梦孟眯醚靡糜迷谜弥米秘觅泌蜜密幂棉眠绵冕免勉娩缅面苗描瞄藐秒渺庙妙蔑灭民抿皿敏悯闽明螟鸣铭名命谬摸"],
        ["c440", "腀", 5, "腇腉腍腎腏腒腖腗腘腛", 4, "腡腢腣腤腦腨腪腫腬腯腲腳腵腶腷腸膁膃", 4, "膉膋膌膍膎膐膒", 5, "膙膚膞", 4, "膤膥"],
        ["c480", "膧膩膫", 7, "膴", 5, "膼膽膾膿臄臅臇臈臉臋臍", 6, "摹蘑模膜磨摩魔抹末莫墨默沫漠寞陌谋牟某拇牡亩姆母墓暮幕募慕木目睦牧穆拿哪呐钠那娜纳氖乃奶耐奈南男难囊挠脑恼闹淖呢馁内嫩能妮霓倪泥尼拟你匿腻逆溺蔫拈年碾撵捻念娘酿鸟尿捏聂孽啮镊镍涅您柠狞凝宁"],
        ["c540", "臔", 14, "臤臥臦臨臩臫臮", 4, "臵", 5, "臽臿舃與", 4, "舎舏舑舓舕", 5, "舝舠舤舥舦舧舩舮舲舺舼舽舿"],
        ["c580", "艀艁艂艃艅艆艈艊艌艍艎艐", 7, "艙艛艜艝艞艠", 7, "艩拧泞牛扭钮纽脓浓农弄奴努怒女暖虐疟挪懦糯诺哦欧鸥殴藕呕偶沤啪趴爬帕怕琶拍排牌徘湃派攀潘盘磐盼畔判叛乓庞旁耪胖抛咆刨炮袍跑泡呸胚培裴赔陪配佩沛喷盆砰抨烹澎彭蓬棚硼篷膨朋鹏捧碰坯砒霹批披劈琵毗"],
        ["c640", "艪艫艬艭艱艵艶艷艸艻艼芀芁芃芅芆芇芉芌芐芓芔芕芖芚芛芞芠芢芣芧芲芵芶芺芻芼芿苀苂苃苅苆苉苐苖苙苚苝苢苧苨苩苪苬苭苮苰苲苳苵苶苸"],
        ["c680", "苺苼", 4, "茊茋茍茐茒茓茖茘茙茝", 9, "茩茪茮茰茲茷茻茽啤脾疲皮匹痞僻屁譬篇偏片骗飘漂瓢票撇瞥拼频贫品聘乒坪苹萍平凭瓶评屏坡泼颇婆破魄迫粕剖扑铺仆莆葡菩蒲埔朴圃普浦谱曝瀑期欺栖戚妻七凄漆柒沏其棋奇歧畦崎脐齐旗祈祁骑起岂乞企启契砌器气迄弃汽泣讫掐"],
        ["c740", "茾茿荁荂荄荅荈荊", 4, "荓荕", 4, "荝荢荰", 6, "荹荺荾", 6, "莇莈莊莋莌莍莏莐莑莔莕莖莗莙莚莝莟莡", 6, "莬莭莮"],
        ["c780", "莯莵莻莾莿菂菃菄菆菈菉菋菍菎菐菑菒菓菕菗菙菚菛菞菢菣菤菦菧菨菫菬菭恰洽牵扦钎铅千迁签仟谦乾黔钱钳前潜遣浅谴堑嵌欠歉枪呛腔羌墙蔷强抢橇锹敲悄桥瞧乔侨巧鞘撬翘峭俏窍切茄且怯窃钦侵亲秦琴勤芹擒禽寝沁青轻氢倾卿清擎晴氰情顷请庆琼穷秋丘邱球求囚酋泅趋区蛆曲躯屈驱渠"],
        ["c840", "菮華菳", 4, "菺菻菼菾菿萀萂萅萇萈萉萊萐萒", 5, "萙萚萛萞", 5, "萩", 7, "萲", 5, "萹萺萻萾", 7, "葇葈葉"],
        ["c880", "葊", 6, "葒", 4, "葘葝葞葟葠葢葤", 4, "葪葮葯葰葲葴葷葹葻葼取娶龋趣去圈颧权醛泉全痊拳犬券劝缺炔瘸却鹊榷确雀裙群然燃冉染瓤壤攘嚷让饶扰绕惹热壬仁人忍韧任认刃妊纫扔仍日戎茸蓉荣融熔溶容绒冗揉柔肉茹蠕儒孺如辱乳汝入褥软阮蕊瑞锐闰润若弱撒洒萨腮鳃塞赛三叁"],
        ["c940", "葽", 4, "蒃蒄蒅蒆蒊蒍蒏", 7, "蒘蒚蒛蒝蒞蒟蒠蒢", 12, "蒰蒱蒳蒵蒶蒷蒻蒼蒾蓀蓂蓃蓅蓆蓇蓈蓋蓌蓎蓏蓒蓔蓕蓗"],
        ["c980", "蓘", 4, "蓞蓡蓢蓤蓧", 4, "蓭蓮蓯蓱", 10, "蓽蓾蔀蔁蔂伞散桑嗓丧搔骚扫嫂瑟色涩森僧莎砂杀刹沙纱傻啥煞筛晒珊苫杉山删煽衫闪陕擅赡膳善汕扇缮墒伤商赏晌上尚裳梢捎稍烧芍勺韶少哨邵绍奢赊蛇舌舍赦摄射慑涉社设砷申呻伸身深娠绅神沈审婶甚肾慎渗声生甥牲升绳"],
        ["ca40", "蔃", 8, "蔍蔎蔏蔐蔒蔔蔕蔖蔘蔙蔛蔜蔝蔞蔠蔢", 8, "蔭", 9, "蔾", 4, "蕄蕅蕆蕇蕋", 10],
        ["ca80", "蕗蕘蕚蕛蕜蕝蕟", 4, "蕥蕦蕧蕩", 8, "蕳蕵蕶蕷蕸蕼蕽蕿薀薁省盛剩胜圣师失狮施湿诗尸虱十石拾时什食蚀实识史矢使屎驶始式示士世柿事拭誓逝势是嗜噬适仕侍释饰氏市恃室视试收手首守寿授售受瘦兽蔬枢梳殊抒输叔舒淑疏书赎孰熟薯暑曙署蜀黍鼠属术述树束戍竖墅庶数漱"],
        ["cb40", "薂薃薆薈", 6, "薐", 10, "薝", 6, "薥薦薧薩薫薬薭薱", 5, "薸薺", 6, "藂", 6, "藊", 4, "藑藒"],
        ["cb80", "藔藖", 5, "藝", 6, "藥藦藧藨藪", 14, "恕刷耍摔衰甩帅栓拴霜双爽谁水睡税吮瞬顺舜说硕朔烁斯撕嘶思私司丝死肆寺嗣四伺似饲巳松耸怂颂送宋讼诵搜艘擞嗽苏酥俗素速粟僳塑溯宿诉肃酸蒜算虽隋随绥髓碎岁穗遂隧祟孙损笋蓑梭唆缩琐索锁所塌他它她塔"],
        ["cc40", "藹藺藼藽藾蘀", 4, "蘆", 10, "蘒蘓蘔蘕蘗", 15, "蘨蘪", 13, "蘹蘺蘻蘽蘾蘿虀"],
        ["cc80", "虁", 11, "虒虓處", 4, "虛虜虝號虠虡虣", 7, "獭挞蹋踏胎苔抬台泰酞太态汰坍摊贪瘫滩坛檀痰潭谭谈坦毯袒碳探叹炭汤塘搪堂棠膛唐糖倘躺淌趟烫掏涛滔绦萄桃逃淘陶讨套特藤腾疼誊梯剔踢锑提题蹄啼体替嚏惕涕剃屉天添填田甜恬舔腆挑条迢眺跳贴铁帖厅听烃"],
        ["cd40", "虭虯虰虲", 6, "蚃", 6, "蚎", 4, "蚔蚖", 5, "蚞", 4, "蚥蚦蚫蚭蚮蚲蚳蚷蚸蚹蚻", 4, "蛁蛂蛃蛅蛈蛌蛍蛒蛓蛕蛖蛗蛚蛜"],
        ["cd80", "蛝蛠蛡蛢蛣蛥蛦蛧蛨蛪蛫蛬蛯蛵蛶蛷蛺蛻蛼蛽蛿蜁蜄蜅蜆蜋蜌蜎蜏蜐蜑蜔蜖汀廷停亭庭挺艇通桐酮瞳同铜彤童桶捅筒统痛偷投头透凸秃突图徒途涂屠土吐兔湍团推颓腿蜕褪退吞屯臀拖托脱鸵陀驮驼椭妥拓唾挖哇蛙洼娃瓦袜歪外豌弯湾玩顽丸烷完碗挽晚皖惋宛婉万腕汪王亡枉网往旺望忘妄威"],
        ["ce40", "蜙蜛蜝蜟蜠蜤蜦蜧蜨蜪蜫蜬蜭蜯蜰蜲蜳蜵蜶蜸蜹蜺蜼蜽蝀", 6, "蝊蝋蝍蝏蝐蝑蝒蝔蝕蝖蝘蝚", 5, "蝡蝢蝦", 7, "蝯蝱蝲蝳蝵"],
        ["ce80", "蝷蝸蝹蝺蝿螀螁螄螆螇螉螊螌螎", 4, "螔螕螖螘", 6, "螠", 4, "巍微危韦违桅围唯惟为潍维苇萎委伟伪尾纬未蔚味畏胃喂魏位渭谓尉慰卫瘟温蚊文闻纹吻稳紊问嗡翁瓮挝蜗涡窝我斡卧握沃巫呜钨乌污诬屋无芜梧吾吴毋武五捂午舞伍侮坞戊雾晤物勿务悟误昔熙析西硒矽晰嘻吸锡牺"],
        ["cf40", "螥螦螧螩螪螮螰螱螲螴螶螷螸螹螻螼螾螿蟁", 4, "蟇蟈蟉蟌", 4, "蟔", 6, "蟜蟝蟞蟟蟡蟢蟣蟤蟦蟧蟨蟩蟫蟬蟭蟯", 9],
        ["cf80", "蟺蟻蟼蟽蟿蠀蠁蠂蠄", 5, "蠋", 7, "蠔蠗蠘蠙蠚蠜", 4, "蠣稀息希悉膝夕惜熄烯溪汐犀檄袭席习媳喜铣洗系隙戏细瞎虾匣霞辖暇峡侠狭下厦夏吓掀锨先仙鲜纤咸贤衔舷闲涎弦嫌显险现献县腺馅羡宪陷限线相厢镶香箱襄湘乡翔祥详想响享项巷橡像向象萧硝霄削哮嚣销消宵淆晓"],
        ["d040", "蠤", 13, "蠳", 5, "蠺蠻蠽蠾蠿衁衂衃衆", 5, "衎", 5, "衕衖衘衚", 6, "衦衧衪衭衯衱衳衴衵衶衸衹衺"],
        ["d080", "衻衼袀袃袆袇袉袊袌袎袏袐袑袓袔袕袗", 4, "袝", 4, "袣袥", 5, "小孝校肖啸笑效楔些歇蝎鞋协挟携邪斜胁谐写械卸蟹懈泄泻谢屑薪芯锌欣辛新忻心信衅星腥猩惺兴刑型形邢行醒幸杏性姓兄凶胸匈汹雄熊休修羞朽嗅锈秀袖绣墟戌需虚嘘须徐许蓄酗叙旭序畜恤絮婿绪续轩喧宣悬旋玄"],
        ["d140", "袬袮袯袰袲", 4, "袸袹袺袻袽袾袿裀裃裄裇裈裊裋裌裍裏裐裑裓裖裗裚", 4, "裠裡裦裧裩", 6, "裲裵裶裷裺裻製裿褀褁褃", 5],
        ["d180", "褉褋", 4, "褑褔", 4, "褜", 4, "褢褣褤褦褧褨褩褬褭褮褯褱褲褳褵褷选癣眩绚靴薛学穴雪血勋熏循旬询寻驯巡殉汛训讯逊迅压押鸦鸭呀丫芽牙蚜崖衙涯雅哑亚讶焉咽阉烟淹盐严研蜒岩延言颜阎炎沿奄掩眼衍演艳堰燕厌砚雁唁彦焰宴谚验殃央鸯秧杨扬佯疡羊洋阳氧仰痒养样漾邀腰妖瑶"],
        ["d240", "褸", 8, "襂襃襅", 24, "襠", 5, "襧", 19, "襼"],
        ["d280", "襽襾覀覂覄覅覇", 26, "摇尧遥窑谣姚咬舀药要耀椰噎耶爷野冶也页掖业叶曳腋夜液一壹医揖铱依伊衣颐夷遗移仪胰疑沂宜姨彝椅蚁倚已乙矣以艺抑易邑屹亿役臆逸肄疫亦裔意毅忆义益溢诣议谊译异翼翌绎茵荫因殷音阴姻吟银淫寅饮尹引隐"],
        ["d340", "覢", 30, "觃觍觓觔觕觗觘觙觛觝觟觠觡觢觤觧觨觩觪觬觭觮觰觱觲觴", 6],
        ["d380", "觻", 4, "訁", 5, "計", 21, "印英樱婴鹰应缨莹萤营荧蝇迎赢盈影颖硬映哟拥佣臃痈庸雍踊蛹咏泳涌永恿勇用幽优悠忧尤由邮铀犹油游酉有友右佑釉诱又幼迂淤于盂榆虞愚舆余俞逾鱼愉渝渔隅予娱雨与屿禹宇语羽玉域芋郁吁遇喻峪御愈欲狱育誉"],
        ["d440", "訞", 31, "訿", 8, "詉", 21],
        ["d480", "詟", 25, "詺", 6, "浴寓裕预豫驭鸳渊冤元垣袁原援辕园员圆猿源缘远苑愿怨院曰约越跃钥岳粤月悦阅耘云郧匀陨允运蕴酝晕韵孕匝砸杂栽哉灾宰载再在咱攒暂赞赃脏葬遭糟凿藻枣早澡蚤躁噪造皂灶燥责择则泽贼怎增憎曾赠扎喳渣札轧"],
        ["d540", "誁", 7, "誋", 7, "誔", 46],
        ["d580", "諃", 32, "铡闸眨栅榨咋乍炸诈摘斋宅窄债寨瞻毡詹粘沾盏斩辗崭展蘸栈占战站湛绽樟章彰漳张掌涨杖丈帐账仗胀瘴障招昭找沼赵照罩兆肇召遮折哲蛰辙者锗蔗这浙珍斟真甄砧臻贞针侦枕疹诊震振镇阵蒸挣睁征狰争怔整拯正政"],
        ["d640", "諤", 34, "謈", 27],
        ["d680", "謤謥謧", 30, "帧症郑证芝枝支吱蜘知肢脂汁之织职直植殖执值侄址指止趾只旨纸志挚掷至致置帜峙制智秩稚质炙痔滞治窒中盅忠钟衷终种肿重仲众舟周州洲诌粥轴肘帚咒皱宙昼骤珠株蛛朱猪诸诛逐竹烛煮拄瞩嘱主著柱助蛀贮铸筑"],
        ["d740", "譆", 31, "譧", 4, "譭", 25],
        ["d780", "讇", 24, "讬讱讻诇诐诪谉谞住注祝驻抓爪拽专砖转撰赚篆桩庄装妆撞壮状椎锥追赘坠缀谆准捉拙卓桌琢茁酌啄着灼浊兹咨资姿滋淄孜紫仔籽滓子自渍字鬃棕踪宗综总纵邹走奏揍租足卒族祖诅阻组钻纂嘴醉最罪尊遵昨左佐柞做作坐座"],
        ["d840", "谸", 8, "豂豃豄豅豈豊豋豍", 7, "豖豗豘豙豛", 5, "豣", 6, "豬", 6, "豴豵豶豷豻", 6, "貃貄貆貇"],
        ["d880", "貈貋貍", 6, "貕貖貗貙", 20, "亍丌兀丐廿卅丕亘丞鬲孬噩丨禺丿匕乇夭爻卮氐囟胤馗毓睾鼗丶亟鼐乜乩亓芈孛啬嘏仄厍厝厣厥厮靥赝匚叵匦匮匾赜卦卣刂刈刎刭刳刿剀剌剞剡剜蒯剽劂劁劐劓冂罔亻仃仉仂仨仡仫仞伛仳伢佤仵伥伧伉伫佞佧攸佚佝"],
        ["d940", "貮", 62],
        ["d980", "賭", 32, "佟佗伲伽佶佴侑侉侃侏佾佻侪佼侬侔俦俨俪俅俚俣俜俑俟俸倩偌俳倬倏倮倭俾倜倌倥倨偾偃偕偈偎偬偻傥傧傩傺僖儆僭僬僦僮儇儋仝氽佘佥俎龠汆籴兮巽黉馘冁夔勹匍訇匐凫夙兕亠兖亳衮袤亵脔裒禀嬴蠃羸冫冱冽冼"],
        ["da40", "贎", 14, "贠赑赒赗赟赥赨赩赪赬赮赯赱赲赸", 8, "趂趃趆趇趈趉趌", 4, "趒趓趕", 9, "趠趡"],
        ["da80", "趢趤", 12, "趲趶趷趹趻趽跀跁跂跅跇跈跉跊跍跐跒跓跔凇冖冢冥讠讦讧讪讴讵讷诂诃诋诏诎诒诓诔诖诘诙诜诟诠诤诨诩诮诰诳诶诹诼诿谀谂谄谇谌谏谑谒谔谕谖谙谛谘谝谟谠谡谥谧谪谫谮谯谲谳谵谶卩卺阝阢阡阱阪阽阼陂陉陔陟陧陬陲陴隈隍隗隰邗邛邝邙邬邡邴邳邶邺"],
        ["db40", "跕跘跙跜跠跡跢跥跦跧跩跭跮跰跱跲跴跶跼跾", 6, "踆踇踈踋踍踎踐踑踒踓踕", 7, "踠踡踤", 4, "踫踭踰踲踳踴踶踷踸踻踼踾"],
        ["db80", "踿蹃蹅蹆蹌", 4, "蹓", 5, "蹚", 11, "蹧蹨蹪蹫蹮蹱邸邰郏郅邾郐郄郇郓郦郢郜郗郛郫郯郾鄄鄢鄞鄣鄱鄯鄹酃酆刍奂劢劬劭劾哿勐勖勰叟燮矍廴凵凼鬯厶弁畚巯坌垩垡塾墼壅壑圩圬圪圳圹圮圯坜圻坂坩垅坫垆坼坻坨坭坶坳垭垤垌垲埏垧垴垓垠埕埘埚埙埒垸埴埯埸埤埝"],
        ["dc40", "蹳蹵蹷", 4, "蹽蹾躀躂躃躄躆躈", 6, "躑躒躓躕", 6, "躝躟", 11, "躭躮躰躱躳", 6, "躻", 7],
        ["dc80", "軃", 10, "軏", 21, "堋堍埽埭堀堞堙塄堠塥塬墁墉墚墀馨鼙懿艹艽艿芏芊芨芄芎芑芗芙芫芸芾芰苈苊苣芘芷芮苋苌苁芩芴芡芪芟苄苎芤苡茉苷苤茏茇苜苴苒苘茌苻苓茑茚茆茔茕苠苕茜荑荛荜茈莒茼茴茱莛荞茯荏荇荃荟荀茗荠茭茺茳荦荥"],
        ["dd40", "軥", 62],
        ["dd80", "輤", 32, "荨茛荩荬荪荭荮莰荸莳莴莠莪莓莜莅荼莶莩荽莸荻莘莞莨莺莼菁萁菥菘堇萘萋菝菽菖萜萸萑萆菔菟萏萃菸菹菪菅菀萦菰菡葜葑葚葙葳蒇蒈葺蒉葸萼葆葩葶蒌蒎萱葭蓁蓍蓐蓦蒽蓓蓊蒿蒺蓠蒡蒹蒴蒗蓥蓣蔌甍蔸蓰蔹蔟蔺"],
        ["de40", "轅", 32, "轪辀辌辒辝辠辡辢辤辥辦辧辪辬辭辮辯農辳辴辵辷辸辺辻込辿迀迃迆"],
        ["de80", "迉", 4, "迏迒迖迗迚迠迡迣迧迬迯迱迲迴迵迶迺迻迼迾迿逇逈逌逎逓逕逘蕖蔻蓿蓼蕙蕈蕨蕤蕞蕺瞢蕃蕲蕻薤薨薇薏蕹薮薜薅薹薷薰藓藁藜藿蘧蘅蘩蘖蘼廾弈夼奁耷奕奚奘匏尢尥尬尴扌扪抟抻拊拚拗拮挢拶挹捋捃掭揶捱捺掎掴捭掬掊捩掮掼揲揸揠揿揄揞揎摒揆掾摅摁搋搛搠搌搦搡摞撄摭撖"],
        ["df40", "這逜連逤逥逧", 5, "逰", 4, "逷逹逺逽逿遀遃遅遆遈", 4, "過達違遖遙遚遜", 5, "遤遦遧適遪遫遬遯", 4, "遶", 6, "遾邁"],
        ["df80", "還邅邆邇邉邊邌", 4, "邒邔邖邘邚邜邞邟邠邤邥邧邨邩邫邭邲邷邼邽邿郀摺撷撸撙撺擀擐擗擤擢攉攥攮弋忒甙弑卟叱叽叩叨叻吒吖吆呋呒呓呔呖呃吡呗呙吣吲咂咔呷呱呤咚咛咄呶呦咝哐咭哂咴哒咧咦哓哔呲咣哕咻咿哌哙哚哜咩咪咤哝哏哞唛哧唠哽唔哳唢唣唏唑唧唪啧喏喵啉啭啁啕唿啐唼"],
        ["e040", "郂郃郆郈郉郋郌郍郒郔郕郖郘郙郚郞郟郠郣郤郥郩郪郬郮郰郱郲郳郵郶郷郹郺郻郼郿鄀鄁鄃鄅", 19, "鄚鄛鄜"],
        ["e080", "鄝鄟鄠鄡鄤", 10, "鄰鄲", 6, "鄺", 8, "酄唷啖啵啶啷唳唰啜喋嗒喃喱喹喈喁喟啾嗖喑啻嗟喽喾喔喙嗪嗷嗉嘟嗑嗫嗬嗔嗦嗝嗄嗯嗥嗲嗳嗌嗍嗨嗵嗤辔嘞嘈嘌嘁嘤嘣嗾嘀嘧嘭噘嘹噗嘬噍噢噙噜噌噔嚆噤噱噫噻噼嚅嚓嚯囔囗囝囡囵囫囹囿圄圊圉圜帏帙帔帑帱帻帼"],
        ["e140", "酅酇酈酑酓酔酕酖酘酙酛酜酟酠酦酧酨酫酭酳酺酻酼醀", 4, "醆醈醊醎醏醓", 6, "醜", 5, "醤", 5, "醫醬醰醱醲醳醶醷醸醹醻"],
        ["e180", "醼", 10, "釈釋釐釒", 9, "針", 8, "帷幄幔幛幞幡岌屺岍岐岖岈岘岙岑岚岜岵岢岽岬岫岱岣峁岷峄峒峤峋峥崂崃崧崦崮崤崞崆崛嵘崾崴崽嵬嵛嵯嵝嵫嵋嵊嵩嵴嶂嶙嶝豳嶷巅彳彷徂徇徉後徕徙徜徨徭徵徼衢彡犭犰犴犷犸狃狁狎狍狒狨狯狩狲狴狷猁狳猃狺"],
        ["e240", "釦", 62],
        ["e280", "鈥", 32, "狻猗猓猡猊猞猝猕猢猹猥猬猸猱獐獍獗獠獬獯獾舛夥飧夤夂饣饧", 5, "饴饷饽馀馄馇馊馍馐馑馓馔馕庀庑庋庖庥庠庹庵庾庳赓廒廑廛廨廪膺忄忉忖忏怃忮怄忡忤忾怅怆忪忭忸怙怵怦怛怏怍怩怫怊怿怡恸恹恻恺恂"],
        ["e340", "鉆", 45, "鉵", 16],
        ["e380", "銆", 7, "銏", 24, "恪恽悖悚悭悝悃悒悌悛惬悻悱惝惘惆惚悴愠愦愕愣惴愀愎愫慊慵憬憔憧憷懔懵忝隳闩闫闱闳闵闶闼闾阃阄阆阈阊阋阌阍阏阒阕阖阗阙阚丬爿戕氵汔汜汊沣沅沐沔沌汨汩汴汶沆沩泐泔沭泷泸泱泗沲泠泖泺泫泮沱泓泯泾"],
        ["e440", "銨", 5, "銯", 24, "鋉", 31],
        ["e480", "鋩", 32, "洹洧洌浃浈洇洄洙洎洫浍洮洵洚浏浒浔洳涑浯涞涠浞涓涔浜浠浼浣渚淇淅淞渎涿淠渑淦淝淙渖涫渌涮渫湮湎湫溲湟溆湓湔渲渥湄滟溱溘滠漭滢溥溧溽溻溷滗溴滏溏滂溟潢潆潇漤漕滹漯漶潋潴漪漉漩澉澍澌潸潲潼潺濑"],
        ["e540", "錊", 51, "錿", 10],
        ["e580", "鍊", 31, "鍫濉澧澹澶濂濡濮濞濠濯瀚瀣瀛瀹瀵灏灞宀宄宕宓宥宸甯骞搴寤寮褰寰蹇謇辶迓迕迥迮迤迩迦迳迨逅逄逋逦逑逍逖逡逵逶逭逯遄遑遒遐遨遘遢遛暹遴遽邂邈邃邋彐彗彖彘尻咫屐屙孱屣屦羼弪弩弭艴弼鬻屮妁妃妍妩妪妣"],
        ["e640", "鍬", 34, "鎐", 27],
        ["e680", "鎬", 29, "鏋鏌鏍妗姊妫妞妤姒妲妯姗妾娅娆姝娈姣姘姹娌娉娲娴娑娣娓婀婧婊婕娼婢婵胬媪媛婷婺媾嫫媲嫒嫔媸嫠嫣嫱嫖嫦嫘嫜嬉嬗嬖嬲嬷孀尕尜孚孥孳孑孓孢驵驷驸驺驿驽骀骁骅骈骊骐骒骓骖骘骛骜骝骟骠骢骣骥骧纟纡纣纥纨纩"],
        ["e740", "鏎", 7, "鏗", 54],
        ["e780", "鐎", 32, "纭纰纾绀绁绂绉绋绌绐绔绗绛绠绡绨绫绮绯绱绲缍绶绺绻绾缁缂缃缇缈缋缌缏缑缒缗缙缜缛缟缡", 6, "缪缫缬缭缯", 4, "缵幺畿巛甾邕玎玑玮玢玟珏珂珑玷玳珀珉珈珥珙顼琊珩珧珞玺珲琏琪瑛琦琥琨琰琮琬"],
        ["e840", "鐯", 14, "鐿", 43, "鑬鑭鑮鑯"],
        ["e880", "鑰", 20, "钑钖钘铇铏铓铔铚铦铻锜锠琛琚瑁瑜瑗瑕瑙瑷瑭瑾璜璎璀璁璇璋璞璨璩璐璧瓒璺韪韫韬杌杓杞杈杩枥枇杪杳枘枧杵枨枞枭枋杷杼柰栉柘栊柩枰栌柙枵柚枳柝栀柃枸柢栎柁柽栲栳桠桡桎桢桄桤梃栝桕桦桁桧桀栾桊桉栩梵梏桴桷梓桫棂楮棼椟椠棹"],
        ["e940", "锧锳锽镃镈镋镕镚镠镮镴镵長", 7, "門", 42],
        ["e980", "閫", 32, "椤棰椋椁楗棣椐楱椹楠楂楝榄楫榀榘楸椴槌榇榈槎榉楦楣楹榛榧榻榫榭槔榱槁槊槟榕槠榍槿樯槭樗樘橥槲橄樾檠橐橛樵檎橹樽樨橘橼檑檐檩檗檫猷獒殁殂殇殄殒殓殍殚殛殡殪轫轭轱轲轳轵轶轸轷轹轺轼轾辁辂辄辇辋"],
        ["ea40", "闌", 27, "闬闿阇阓阘阛阞阠阣", 6, "阫阬阭阯阰阷阸阹阺阾陁陃陊陎陏陑陒陓陖陗"],
        ["ea80", "陘陙陚陜陝陞陠陣陥陦陫陭", 4, "陳陸", 12, "隇隉隊辍辎辏辘辚軎戋戗戛戟戢戡戥戤戬臧瓯瓴瓿甏甑甓攴旮旯旰昊昙杲昃昕昀炅曷昝昴昱昶昵耆晟晔晁晏晖晡晗晷暄暌暧暝暾曛曜曦曩贲贳贶贻贽赀赅赆赈赉赇赍赕赙觇觊觋觌觎觏觐觑牮犟牝牦牯牾牿犄犋犍犏犒挈挲掰"],
        ["eb40", "隌階隑隒隓隕隖隚際隝", 9, "隨", 7, "隱隲隴隵隷隸隺隻隿雂雃雈雊雋雐雑雓雔雖", 9, "雡", 6, "雫"],
        ["eb80", "雬雭雮雰雱雲雴雵雸雺電雼雽雿霂霃霅霊霋霌霐霑霒霔霕霗", 4, "霝霟霠搿擘耄毪毳毽毵毹氅氇氆氍氕氘氙氚氡氩氤氪氲攵敕敫牍牒牖爰虢刖肟肜肓肼朊肽肱肫肭肴肷胧胨胩胪胛胂胄胙胍胗朐胝胫胱胴胭脍脎胲胼朕脒豚脶脞脬脘脲腈腌腓腴腙腚腱腠腩腼腽腭腧塍媵膈膂膑滕膣膪臌朦臊膻"],
        ["ec40", "霡", 8, "霫霬霮霯霱霳", 4, "霺霻霼霽霿", 18, "靔靕靗靘靚靜靝靟靣靤靦靧靨靪", 7],
        ["ec80", "靲靵靷", 4, "靽", 7, "鞆", 4, "鞌鞎鞏鞐鞓鞕鞖鞗鞙", 4, "臁膦欤欷欹歃歆歙飑飒飓飕飙飚殳彀毂觳斐齑斓於旆旄旃旌旎旒旖炀炜炖炝炻烀炷炫炱烨烊焐焓焖焯焱煳煜煨煅煲煊煸煺熘熳熵熨熠燠燔燧燹爝爨灬焘煦熹戾戽扃扈扉礻祀祆祉祛祜祓祚祢祗祠祯祧祺禅禊禚禧禳忑忐"],
        ["ed40", "鞞鞟鞡鞢鞤", 6, "鞬鞮鞰鞱鞳鞵", 46],
        ["ed80", "韤韥韨韮", 4, "韴韷", 23, "怼恝恚恧恁恙恣悫愆愍慝憩憝懋懑戆肀聿沓泶淼矶矸砀砉砗砘砑斫砭砜砝砹砺砻砟砼砥砬砣砩硎硭硖硗砦硐硇硌硪碛碓碚碇碜碡碣碲碹碥磔磙磉磬磲礅磴礓礤礞礴龛黹黻黼盱眄眍盹眇眈眚眢眙眭眦眵眸睐睑睇睃睚睨"],
        ["ee40", "頏", 62],
        ["ee80", "顎", 32, "睢睥睿瞍睽瞀瞌瞑瞟瞠瞰瞵瞽町畀畎畋畈畛畲畹疃罘罡罟詈罨罴罱罹羁罾盍盥蠲钅钆钇钋钊钌钍钏钐钔钗钕钚钛钜钣钤钫钪钭钬钯钰钲钴钶", 4, "钼钽钿铄铈", 6, "铐铑铒铕铖铗铙铘铛铞铟铠铢铤铥铧铨铪"],
        ["ef40", "顯", 5, "颋颎颒颕颙颣風", 37, "飏飐飔飖飗飛飜飝飠", 4],
        ["ef80", "飥飦飩", 30, "铩铫铮铯铳铴铵铷铹铼铽铿锃锂锆锇锉锊锍锎锏锒", 4, "锘锛锝锞锟锢锪锫锩锬锱锲锴锶锷锸锼锾锿镂锵镄镅镆镉镌镎镏镒镓镔镖镗镘镙镛镞镟镝镡镢镤", 8, "镯镱镲镳锺矧矬雉秕秭秣秫稆嵇稃稂稞稔"],
        ["f040", "餈", 4, "餎餏餑", 28, "餯", 26],
        ["f080", "饊", 9, "饖", 12, "饤饦饳饸饹饻饾馂馃馉稹稷穑黏馥穰皈皎皓皙皤瓞瓠甬鸠鸢鸨", 4, "鸲鸱鸶鸸鸷鸹鸺鸾鹁鹂鹄鹆鹇鹈鹉鹋鹌鹎鹑鹕鹗鹚鹛鹜鹞鹣鹦", 6, "鹱鹭鹳疒疔疖疠疝疬疣疳疴疸痄疱疰痃痂痖痍痣痨痦痤痫痧瘃痱痼痿瘐瘀瘅瘌瘗瘊瘥瘘瘕瘙"],
        ["f140", "馌馎馚", 10, "馦馧馩", 47],
        ["f180", "駙", 32, "瘛瘼瘢瘠癀瘭瘰瘿瘵癃瘾瘳癍癞癔癜癖癫癯翊竦穸穹窀窆窈窕窦窠窬窨窭窳衤衩衲衽衿袂袢裆袷袼裉裢裎裣裥裱褚裼裨裾裰褡褙褓褛褊褴褫褶襁襦襻疋胥皲皴矜耒耔耖耜耠耢耥耦耧耩耨耱耋耵聃聆聍聒聩聱覃顸颀颃"],
        ["f240", "駺", 62],
        ["f280", "騹", 32, "颉颌颍颏颔颚颛颞颟颡颢颥颦虍虔虬虮虿虺虼虻蚨蚍蚋蚬蚝蚧蚣蚪蚓蚩蚶蛄蚵蛎蚰蚺蚱蚯蛉蛏蚴蛩蛱蛲蛭蛳蛐蜓蛞蛴蛟蛘蛑蜃蜇蛸蜈蜊蜍蜉蜣蜻蜞蜥蜮蜚蜾蝈蜴蜱蜩蜷蜿螂蜢蝽蝾蝻蝠蝰蝌蝮螋蝓蝣蝼蝤蝙蝥螓螯螨蟒"],
        ["f340", "驚", 17, "驲骃骉骍骎骔骕骙骦骩", 6, "骲骳骴骵骹骻骽骾骿髃髄髆", 4, "髍髎髏髐髒體髕髖髗髙髚髛髜"],
        ["f380", "髝髞髠髢髣髤髥髧髨髩髪髬髮髰", 8, "髺髼", 6, "鬄鬅鬆蟆螈螅螭螗螃螫蟥螬螵螳蟋蟓螽蟑蟀蟊蟛蟪蟠蟮蠖蠓蟾蠊蠛蠡蠹蠼缶罂罄罅舐竺竽笈笃笄笕笊笫笏筇笸笪笙笮笱笠笥笤笳笾笞筘筚筅筵筌筝筠筮筻筢筲筱箐箦箧箸箬箝箨箅箪箜箢箫箴篑篁篌篝篚篥篦篪簌篾篼簏簖簋"],
        ["f440", "鬇鬉", 5, "鬐鬑鬒鬔", 10, "鬠鬡鬢鬤", 10, "鬰鬱鬳", 7, "鬽鬾鬿魀魆魊魋魌魎魐魒魓魕", 5],
        ["f480", "魛", 32, "簟簪簦簸籁籀臾舁舂舄臬衄舡舢舣舭舯舨舫舸舻舳舴舾艄艉艋艏艚艟艨衾袅袈裘裟襞羝羟羧羯羰羲籼敉粑粝粜粞粢粲粼粽糁糇糌糍糈糅糗糨艮暨羿翎翕翥翡翦翩翮翳糸絷綦綮繇纛麸麴赳趄趔趑趱赧赭豇豉酊酐酎酏酤"],
        ["f540", "魼", 62],
        ["f580", "鮻", 32, "酢酡酰酩酯酽酾酲酴酹醌醅醐醍醑醢醣醪醭醮醯醵醴醺豕鹾趸跫踅蹙蹩趵趿趼趺跄跖跗跚跞跎跏跛跆跬跷跸跣跹跻跤踉跽踔踝踟踬踮踣踯踺蹀踹踵踽踱蹉蹁蹂蹑蹒蹊蹰蹶蹼蹯蹴躅躏躔躐躜躞豸貂貊貅貘貔斛觖觞觚觜"],
        ["f640", "鯜", 62],
        ["f680", "鰛", 32, "觥觫觯訾謦靓雩雳雯霆霁霈霏霎霪霭霰霾龀龃龅", 5, "龌黾鼋鼍隹隼隽雎雒瞿雠銎銮鋈錾鍪鏊鎏鐾鑫鱿鲂鲅鲆鲇鲈稣鲋鲎鲐鲑鲒鲔鲕鲚鲛鲞", 5, "鲥", 4, "鲫鲭鲮鲰", 7, "鲺鲻鲼鲽鳄鳅鳆鳇鳊鳋"],
        ["f740", "鰼", 62],
        ["f780", "鱻鱽鱾鲀鲃鲄鲉鲊鲌鲏鲓鲖鲗鲘鲙鲝鲪鲬鲯鲹鲾", 4, "鳈鳉鳑鳒鳚鳛鳠鳡鳌", 4, "鳓鳔鳕鳗鳘鳙鳜鳝鳟鳢靼鞅鞑鞒鞔鞯鞫鞣鞲鞴骱骰骷鹘骶骺骼髁髀髅髂髋髌髑魅魃魇魉魈魍魑飨餍餮饕饔髟髡髦髯髫髻髭髹鬈鬏鬓鬟鬣麽麾縻麂麇麈麋麒鏖麝麟黛黜黝黠黟黢黩黧黥黪黯鼢鼬鼯鼹鼷鼽鼾齄"],
        ["f840", "鳣", 62],
        ["f880", "鴢", 32],
        ["f940", "鵃", 62],
        ["f980", "鶂", 32],
        ["fa40", "鶣", 62],
        ["fa80", "鷢", 32],
        ["fb40", "鸃", 27, "鸤鸧鸮鸰鸴鸻鸼鹀鹍鹐鹒鹓鹔鹖鹙鹝鹟鹠鹡鹢鹥鹮鹯鹲鹴", 9, "麀"],
        ["fb80", "麁麃麄麅麆麉麊麌", 5, "麔", 8, "麞麠", 5, "麧麨麩麪"],
        ["fc40", "麫", 8, "麵麶麷麹麺麼麿", 4, "黅黆黇黈黊黋黌黐黒黓黕黖黗黙黚點黡黣黤黦黨黫黬黭黮黰", 8, "黺黽黿", 6],
        ["fc80", "鼆", 4, "鼌鼏鼑鼒鼔鼕鼖鼘鼚", 5, "鼡鼣", 8, "鼭鼮鼰鼱"],
        ["fd40", "鼲", 4, "鼸鼺鼼鼿", 4, "齅", 10, "齒", 38],
        ["fd80", "齹", 5, "龁龂龍", 11, "龜龝龞龡", 4, "郎凉秊裏隣"],
        ["fe40", "兀嗀﨎﨏﨑﨓﨔礼﨟蘒﨡﨣﨤﨧﨨﨩"]
    ];
    module.exports = json;
},
/* iconv-lite/encodings/tables/gbk-added.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = [
        ["a140", "", 62],
        ["a180", "", 32],
        ["a240", "", 62],
        ["a280", "", 32],
        ["a2ab", "", 5],
        ["a2e3", "€"],
        ["a2ef", ""],
        ["a2fd", ""],
        ["a340", "", 62],
        ["a380", "", 31, "　"],
        ["a440", "", 62],
        ["a480", "", 32],
        ["a4f4", "", 10],
        ["a540", "", 62],
        ["a580", "", 32],
        ["a5f7", "", 7],
        ["a640", "", 62],
        ["a680", "", 32],
        ["a6b9", "", 7],
        ["a6d9", "", 6],
        ["a6ec", ""],
        ["a6f3", ""],
        ["a6f6", "", 8],
        ["a740", "", 62],
        ["a780", "", 32],
        ["a7c2", "", 14],
        ["a7f2", "", 12],
        ["a896", "", 10],
        ["a8bc", ""],
        ["a8bf", "ǹ"],
        ["a8c1", ""],
        ["a8ea", "", 20],
        ["a958", ""],
        ["a95b", ""],
        ["a95d", ""],
        ["a989", "〾⿰", 11],
        ["a997", "", 12],
        ["a9f0", "", 14],
        ["aaa1", "", 93],
        ["aba1", "", 93],
        ["aca1", "", 93],
        ["ada1", "", 93],
        ["aea1", "", 93],
        ["afa1", "", 93],
        ["d7fa", "", 4],
        ["f8a1", "", 93],
        ["f9a1", "", 93],
        ["faa1", "", 93],
        ["fba1", "", 93],
        ["fca1", "", 93],
        ["fda1", "", 93],
        ["fe50", "⺁⺄㑳㑇⺈⺋㖞㘚㘎⺌⺗㥮㤘㧏㧟㩳㧐㭎㱮㳠⺧⺪䁖䅟⺮䌷⺳⺶⺷䎱䎬⺻䏝䓖䙡䙌"],
        ["fe80", "䜣䜩䝼䞍⻊䥇䥺䥽䦂䦃䦅䦆䦟䦛䦷䦶䲣䲟䲠䲡䱷䲢䴓", 6, "䶮", 93]
    ];
    module.exports = json;
},
/* iconv-lite/encodings/tables/gb18030-ranges.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = { "uChars": [128, 165, 169, 178, 184, 216, 226, 235, 238, 244, 248, 251, 253, 258, 276, 284, 300, 325, 329, 334, 364, 463, 465, 467, 469, 471, 473, 475, 477, 506, 594, 610, 712, 716, 730, 930, 938, 962, 970, 1026, 1104, 1106, 8209, 8215, 8218, 8222, 8231, 8241, 8244, 8246, 8252, 8365, 8452, 8454, 8458, 8471, 8482, 8556, 8570, 8596, 8602, 8713, 8720, 8722, 8726, 8731, 8737, 8740, 8742, 8748, 8751, 8760, 8766, 8777, 8781, 8787, 8802, 8808, 8816, 8854, 8858, 8870, 8896, 8979, 9322, 9372, 9548, 9588, 9616, 9622, 9634, 9652, 9662, 9672, 9676, 9680, 9702, 9735, 9738, 9793, 9795, 11906, 11909, 11913, 11917, 11928, 11944, 11947, 11951, 11956, 11960, 11964, 11979, 12284, 12292, 12312, 12319, 12330, 12351, 12436, 12447, 12535, 12543, 12586, 12842, 12850, 12964, 13200, 13215, 13218, 13253, 13263, 13267, 13270, 13384, 13428, 13727, 13839, 13851, 14617, 14703, 14801, 14816, 14964, 15183, 15471, 15585, 16471, 16736, 17208, 17325, 17330, 17374, 17623, 17997, 18018, 18212, 18218, 18301, 18318, 18760, 18811, 18814, 18820, 18823, 18844, 18848, 18872, 19576, 19620, 19738, 19887, 40870, 59244, 59336, 59367, 59413, 59417, 59423, 59431, 59437, 59443, 59452, 59460, 59478, 59493, 63789, 63866, 63894, 63976, 63986, 64016, 64018, 64021, 64025, 64034, 64037, 64042, 65074, 65093, 65107, 65112, 65127, 65132, 65375, 65510, 65536], "gbChars": [0, 36, 38, 45, 50, 81, 89, 95, 96, 100, 103, 104, 105, 109, 126, 133, 148, 172, 175, 179, 208, 306, 307, 308, 309, 310, 311, 312, 313, 341, 428, 443, 544, 545, 558, 741, 742, 749, 750, 805, 819, 820, 7922, 7924, 7925, 7927, 7934, 7943, 7944, 7945, 7950, 8062, 8148, 8149, 8152, 8164, 8174, 8236, 8240, 8262, 8264, 8374, 8380, 8381, 8384, 8388, 8390, 8392, 8393, 8394, 8396, 8401, 8406, 8416, 8419, 8424, 8437, 8439, 8445, 8482, 8485, 8496, 8521, 8603, 8936, 8946, 9046, 9050, 9063, 9066, 9076, 9092, 9100, 9108, 9111, 9113, 9131, 9162, 9164, 9218, 9219, 11329, 11331, 11334, 11336, 11346, 11361, 11363, 11366, 11370, 11372, 11375, 11389, 11682, 11686, 11687, 11692, 11694, 11714, 11716, 11723, 11725, 11730, 11736, 11982, 11989, 12102, 12336, 12348, 12350, 12384, 12393, 12395, 12397, 12510, 12553, 12851, 12962, 12973, 13738, 13823, 13919, 13933, 14080, 14298, 14585, 14698, 15583, 15847, 16318, 16434, 16438, 16481, 16729, 17102, 17122, 17315, 17320, 17402, 17418, 17859, 17909, 17911, 17915, 17916, 17936, 17939, 17961, 18664, 18703, 18814, 18962, 19043, 33469, 33470, 33471, 33484, 33485, 33490, 33497, 33501, 33505, 33513, 33520, 33536, 33550, 37845, 37921, 37948, 38029, 38038, 38064, 38065, 38066, 38069, 38075, 38076, 38078, 39108, 39109, 39113, 39114, 39115, 39116, 39265, 39394, 189000] };
    module.exports = json;
},
/* iconv-lite/encodings/tables/cp949.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = [
        ["0", "\u0000", 127],
        ["8141", "갂갃갅갆갋", 4, "갘갞갟갡갢갣갥", 6, "갮갲갳갴"],
        ["8161", "갵갶갷갺갻갽갾갿걁", 9, "걌걎", 5, "걕"],
        ["8181", "걖걗걙걚걛걝", 18, "걲걳걵걶걹걻", 4, "겂겇겈겍겎겏겑겒겓겕", 6, "겞겢", 5, "겫겭겮겱", 6, "겺겾겿곀곂곃곅곆곇곉곊곋곍", 7, "곖곘", 7, "곢곣곥곦곩곫곭곮곲곴곷", 4, "곾곿괁괂괃괅괇", 4, "괎괐괒괓"],
        ["8241", "괔괕괖괗괙괚괛괝괞괟괡", 7, "괪괫괮", 5],
        ["8261", "괶괷괹괺괻괽", 6, "굆굈굊", 5, "굑굒굓굕굖굗"],
        ["8281", "굙", 7, "굢굤", 7, "굮굯굱굲굷굸굹굺굾궀궃", 4, "궊궋궍궎궏궑", 10, "궞", 5, "궥", 17, "궸", 7, "귂귃귅귆귇귉", 6, "귒귔", 7, "귝귞귟귡귢귣귥", 18],
        ["8341", "귺귻귽귾긂", 5, "긊긌긎", 5, "긕", 7],
        ["8361", "긝", 18, "긲긳긵긶긹긻긼"],
        ["8381", "긽긾긿깂깄깇깈깉깋깏깑깒깓깕깗", 4, "깞깢깣깤깦깧깪깫깭깮깯깱", 6, "깺깾", 5, "꺆", 5, "꺍", 46, "꺿껁껂껃껅", 6, "껎껒", 5, "껚껛껝", 8],
        ["8441", "껦껧껩껪껬껮", 5, "껵껶껷껹껺껻껽", 8],
        ["8461", "꼆꼉꼊꼋꼌꼎꼏꼑", 18],
        ["8481", "꼤", 7, "꼮꼯꼱꼳꼵", 6, "꼾꽀꽄꽅꽆꽇꽊", 5, "꽑", 10, "꽞", 5, "꽦", 18, "꽺", 5, "꾁꾂꾃꾅꾆꾇꾉", 6, "꾒꾓꾔꾖", 5, "꾝", 26, "꾺꾻꾽꾾"],
        ["8541", "꾿꿁", 5, "꿊꿌꿏", 4, "꿕", 6, "꿝", 4],
        ["8561", "꿢", 5, "꿪", 5, "꿲꿳꿵꿶꿷꿹", 6, "뀂뀃"],
        ["8581", "뀅", 6, "뀍뀎뀏뀑뀒뀓뀕", 6, "뀞", 9, "뀩", 26, "끆끇끉끋끍끏끐끑끒끖끘끚끛끜끞", 29, "끾끿낁낂낃낅", 6, "낎낐낒", 5, "낛낝낞낣낤"],
        ["8641", "낥낦낧낪낰낲낶낷낹낺낻낽", 6, "냆냊", 5, "냒"],
        ["8661", "냓냕냖냗냙", 6, "냡냢냣냤냦", 10],
        ["8681", "냱", 22, "넊넍넎넏넑넔넕넖넗넚넞", 4, "넦넧넩넪넫넭", 6, "넶넺", 5, "녂녃녅녆녇녉", 6, "녒녓녖녗녙녚녛녝녞녟녡", 22, "녺녻녽녾녿놁놃", 4, "놊놌놎놏놐놑놕놖놗놙놚놛놝"],
        ["8741", "놞", 9, "놩", 15],
        ["8761", "놹", 18, "뇍뇎뇏뇑뇒뇓뇕"],
        ["8781", "뇖", 5, "뇞뇠", 7, "뇪뇫뇭뇮뇯뇱", 7, "뇺뇼뇾", 5, "눆눇눉눊눍", 6, "눖눘눚", 5, "눡", 18, "눵", 6, "눽", 26, "뉙뉚뉛뉝뉞뉟뉡", 6, "뉪", 4],
        ["8841", "뉯", 4, "뉶", 5, "뉽", 6, "늆늇늈늊", 4],
        ["8861", "늏늒늓늕늖늗늛", 4, "늢늤늧늨늩늫늭늮늯늱늲늳늵늶늷"],
        ["8881", "늸", 15, "닊닋닍닎닏닑닓", 4, "닚닜닞닟닠닡닣닧닩닪닰닱닲닶닼닽닾댂댃댅댆댇댉", 6, "댒댖", 5, "댝", 54, "덗덙덚덝덠덡덢덣"],
        ["8941", "덦덨덪덬덭덯덲덳덵덶덷덹", 6, "뎂뎆", 5, "뎍"],
        ["8961", "뎎뎏뎑뎒뎓뎕", 10, "뎢", 5, "뎩뎪뎫뎭"],
        ["8981", "뎮", 21, "돆돇돉돊돍돏돑돒돓돖돘돚돜돞돟돡돢돣돥돦돧돩", 18, "돽", 18, "됑", 6, "됙됚됛됝됞됟됡", 6, "됪됬", 7, "됵", 15],
        ["8a41", "둅", 10, "둒둓둕둖둗둙", 6, "둢둤둦"],
        ["8a61", "둧", 4, "둭", 18, "뒁뒂"],
        ["8a81", "뒃", 4, "뒉", 19, "뒞", 5, "뒥뒦뒧뒩뒪뒫뒭", 7, "뒶뒸뒺", 5, "듁듂듃듅듆듇듉", 6, "듑듒듓듔듖", 5, "듞듟듡듢듥듧", 4, "듮듰듲", 5, "듹", 26, "딖딗딙딚딝"],
        ["8b41", "딞", 5, "딦딫", 4, "딲딳딵딶딷딹", 6, "땂땆"],
        ["8b61", "땇땈땉땊땎땏땑땒땓땕", 6, "땞땢", 8],
        ["8b81", "땫", 52, "떢떣떥떦떧떩떬떭떮떯떲떶", 4, "떾떿뗁뗂뗃뗅", 6, "뗎뗒", 5, "뗙", 18, "뗭", 18],
        ["8c41", "똀", 15, "똒똓똕똖똗똙", 4],
        ["8c61", "똞", 6, "똦", 5, "똭", 6, "똵", 5],
        ["8c81", "똻", 12, "뙉", 26, "뙥뙦뙧뙩", 50, "뚞뚟뚡뚢뚣뚥", 5, "뚭뚮뚯뚰뚲", 16],
        ["8d41", "뛃", 16, "뛕", 8],
        ["8d61", "뛞", 17, "뛱뛲뛳뛵뛶뛷뛹뛺"],
        ["8d81", "뛻", 4, "뜂뜃뜄뜆", 33, "뜪뜫뜭뜮뜱", 6, "뜺뜼", 7, "띅띆띇띉띊띋띍", 6, "띖", 9, "띡띢띣띥띦띧띩", 6, "띲띴띶", 5, "띾띿랁랂랃랅", 6, "랎랓랔랕랚랛랝랞"],
        ["8e41", "랟랡", 6, "랪랮", 5, "랶랷랹", 8],
        ["8e61", "럂", 4, "럈럊", 19],
        ["8e81", "럞", 13, "럮럯럱럲럳럵", 6, "럾렂", 4, "렊렋렍렎렏렑", 6, "렚렜렞", 5, "렦렧렩렪렫렭", 6, "렶렺", 5, "롁롂롃롅", 11, "롒롔", 7, "롞롟롡롢롣롥", 6, "롮롰롲", 5, "롹롺롻롽", 7],
        ["8f41", "뢅", 7, "뢎", 17],
        ["8f61", "뢠", 7, "뢩", 6, "뢱뢲뢳뢵뢶뢷뢹", 4],
        ["8f81", "뢾뢿룂룄룆", 5, "룍룎룏룑룒룓룕", 7, "룞룠룢", 5, "룪룫룭룮룯룱", 6, "룺룼룾", 5, "뤅", 18, "뤙", 6, "뤡", 26, "뤾뤿륁륂륃륅", 6, "륍륎륐륒", 5],
        ["9041", "륚륛륝륞륟륡", 6, "륪륬륮", 5, "륶륷륹륺륻륽"],
        ["9061", "륾", 5, "릆릈릋릌릏", 15],
        ["9081", "릟", 12, "릮릯릱릲릳릵", 6, "릾맀맂", 5, "맊맋맍맓", 4, "맚맜맟맠맢맦맧맩맪맫맭", 6, "맶맻", 4, "먂", 5, "먉", 11, "먖", 33, "먺먻먽먾먿멁멃멄멅멆"],
        ["9141", "멇멊멌멏멐멑멒멖멗멙멚멛멝", 6, "멦멪", 5],
        ["9161", "멲멳멵멶멷멹", 9, "몆몈몉몊몋몍", 5],
        ["9181", "몓", 20, "몪몭몮몯몱몳", 4, "몺몼몾", 5, "뫅뫆뫇뫉", 14, "뫚", 33, "뫽뫾뫿묁묂묃묅", 7, "묎묐묒", 5, "묙묚묛묝묞묟묡", 6],
        ["9241", "묨묪묬", 7, "묷묹묺묿", 4, "뭆뭈뭊뭋뭌뭎뭑뭒"],
        ["9261", "뭓뭕뭖뭗뭙", 7, "뭢뭤", 7, "뭭", 4],
        ["9281", "뭲", 21, "뮉뮊뮋뮍뮎뮏뮑", 18, "뮥뮦뮧뮩뮪뮫뮭", 6, "뮵뮶뮸", 7, "믁믂믃믅믆믇믉", 6, "믑믒믔", 35, "믺믻믽믾밁"],
        ["9341", "밃", 4, "밊밎밐밒밓밙밚밠밡밢밣밦밨밪밫밬밮밯밲밳밵"],
        ["9361", "밶밷밹", 6, "뱂뱆뱇뱈뱊뱋뱎뱏뱑", 8],
        ["9381", "뱚뱛뱜뱞", 37, "벆벇벉벊벍벏", 4, "벖벘벛", 4, "벢벣벥벦벩", 6, "벲벶", 5, "벾벿볁볂볃볅", 7, "볎볒볓볔볖볗볙볚볛볝", 22, "볷볹볺볻볽"],
        ["9441", "볾", 5, "봆봈봊", 5, "봑봒봓봕", 8],
        ["9461", "봞", 5, "봥", 6, "봭", 12],
        ["9481", "봺", 5, "뵁", 6, "뵊뵋뵍뵎뵏뵑", 6, "뵚", 9, "뵥뵦뵧뵩", 22, "붂붃붅붆붋", 4, "붒붔붖붗붘붛붝", 6, "붥", 10, "붱", 6, "붹", 24],
        ["9541", "뷒뷓뷖뷗뷙뷚뷛뷝", 11, "뷪", 5, "뷱"],
        ["9561", "뷲뷳뷵뷶뷷뷹", 6, "븁븂븄븆", 5, "븎븏븑븒븓"],
        ["9581", "븕", 6, "븞븠", 35, "빆빇빉빊빋빍빏", 4, "빖빘빜빝빞빟빢빣빥빦빧빩빫", 4, "빲빶", 4, "빾빿뺁뺂뺃뺅", 6, "뺎뺒", 5, "뺚", 13, "뺩", 14],
        ["9641", "뺸", 23, "뻒뻓"],
        ["9661", "뻕뻖뻙", 6, "뻡뻢뻦", 5, "뻭", 8],
        ["9681", "뻶", 10, "뼂", 5, "뼊", 13, "뼚뼞", 33, "뽂뽃뽅뽆뽇뽉", 6, "뽒뽓뽔뽖", 44],
        ["9741", "뾃", 16, "뾕", 8],
        ["9761", "뾞", 17, "뾱", 7],
        ["9781", "뾹", 11, "뿆", 5, "뿎뿏뿑뿒뿓뿕", 6, "뿝뿞뿠뿢", 89, "쀽쀾쀿"],
        ["9841", "쁀", 16, "쁒", 5, "쁙쁚쁛"],
        ["9861", "쁝쁞쁟쁡", 6, "쁪", 15],
        ["9881", "쁺", 21, "삒삓삕삖삗삙", 6, "삢삤삦", 5, "삮삱삲삷", 4, "삾샂샃샄샆샇샊샋샍샎샏샑", 6, "샚샞", 5, "샦샧샩샪샫샭", 6, "샶샸샺", 5, "섁섂섃섅섆섇섉", 6, "섑섒섓섔섖", 5, "섡섢섥섨섩섪섫섮"],
        ["9941", "섲섳섴섵섷섺섻섽섾섿셁", 6, "셊셎", 5, "셖셗"],
        ["9961", "셙셚셛셝", 6, "셦셪", 5, "셱셲셳셵셶셷셹셺셻"],
        ["9981", "셼", 8, "솆", 5, "솏솑솒솓솕솗", 4, "솞솠솢솣솤솦솧솪솫솭솮솯솱", 11, "솾", 5, "쇅쇆쇇쇉쇊쇋쇍", 6, "쇕쇖쇙", 6, "쇡쇢쇣쇥쇦쇧쇩", 6, "쇲쇴", 7, "쇾쇿숁숂숃숅", 6, "숎숐숒", 5, "숚숛숝숞숡숢숣"],
        ["9a41", "숤숥숦숧숪숬숮숰숳숵", 16],
        ["9a61", "쉆쉇쉉", 6, "쉒쉓쉕쉖쉗쉙", 6, "쉡쉢쉣쉤쉦"],
        ["9a81", "쉧", 4, "쉮쉯쉱쉲쉳쉵", 6, "쉾슀슂", 5, "슊", 5, "슑", 6, "슙슚슜슞", 5, "슦슧슩슪슫슮", 5, "슶슸슺", 33, "싞싟싡싢싥", 5, "싮싰싲싳싴싵싷싺싽싾싿쌁", 6, "쌊쌋쌎쌏"],
        ["9b41", "쌐쌑쌒쌖쌗쌙쌚쌛쌝", 6, "쌦쌧쌪", 8],
        ["9b61", "쌳", 17, "썆", 7],
        ["9b81", "썎", 25, "썪썫썭썮썯썱썳", 4, "썺썻썾", 5, "쎅쎆쎇쎉쎊쎋쎍", 50, "쏁", 22, "쏚"],
        ["9c41", "쏛쏝쏞쏡쏣", 4, "쏪쏫쏬쏮", 5, "쏶쏷쏹", 5],
        ["9c61", "쏿", 8, "쐉", 6, "쐑", 9],
        ["9c81", "쐛", 8, "쐥", 6, "쐭쐮쐯쐱쐲쐳쐵", 6, "쐾", 9, "쑉", 26, "쑦쑧쑩쑪쑫쑭", 6, "쑶쑷쑸쑺", 5, "쒁", 18, "쒕", 6, "쒝", 12],
        ["9d41", "쒪", 13, "쒹쒺쒻쒽", 8],
        ["9d61", "쓆", 25],
        ["9d81", "쓠", 8, "쓪", 5, "쓲쓳쓵쓶쓷쓹쓻쓼쓽쓾씂", 9, "씍씎씏씑씒씓씕", 6, "씝", 10, "씪씫씭씮씯씱", 6, "씺씼씾", 5, "앆앇앋앏앐앑앒앖앚앛앜앟앢앣앥앦앧앩", 6, "앲앶", 5, "앾앿얁얂얃얅얆얈얉얊얋얎얐얒얓얔"],
        ["9e41", "얖얙얚얛얝얞얟얡", 7, "얪", 9, "얶"],
        ["9e61", "얷얺얿", 4, "엋엍엏엒엓엕엖엗엙", 6, "엢엤엦엧"],
        ["9e81", "엨엩엪엫엯엱엲엳엵엸엹엺엻옂옃옄옉옊옋옍옎옏옑", 6, "옚옝", 6, "옦옧옩옪옫옯옱옲옶옸옺옼옽옾옿왂왃왅왆왇왉", 6, "왒왖", 5, "왞왟왡", 10, "왭왮왰왲", 5, "왺왻왽왾왿욁", 6, "욊욌욎", 5, "욖욗욙욚욛욝", 6, "욦"],
        ["9f41", "욨욪", 5, "욲욳욵욶욷욻", 4, "웂웄웆", 5, "웎"],
        ["9f61", "웏웑웒웓웕", 6, "웞웟웢", 5, "웪웫웭웮웯웱웲"],
        ["9f81", "웳", 4, "웺웻웼웾", 5, "윆윇윉윊윋윍", 6, "윖윘윚", 5, "윢윣윥윦윧윩", 6, "윲윴윶윸윹윺윻윾윿읁읂읃읅", 4, "읋읎읐읙읚읛읝읞읟읡", 6, "읩읪읬", 7, "읶읷읹읺읻읿잀잁잂잆잋잌잍잏잒잓잕잙잛", 4, "잢잧", 4, "잮잯잱잲잳잵잶잷"],
        ["a041", "잸잹잺잻잾쟂", 5, "쟊쟋쟍쟏쟑", 6, "쟙쟚쟛쟜"],
        ["a061", "쟞", 5, "쟥쟦쟧쟩쟪쟫쟭", 13],
        ["a081", "쟻", 4, "젂젃젅젆젇젉젋", 4, "젒젔젗", 4, "젞젟젡젢젣젥", 6, "젮젰젲", 5, "젹젺젻젽젾젿졁", 6, "졊졋졎", 5, "졕", 26, "졲졳졵졶졷졹졻", 4, "좂좄좈좉좊좎", 5, "좕", 7, "좞좠좢좣좤"],
        ["a141", "좥좦좧좩", 18, "좾좿죀죁"],
        ["a161", "죂죃죅죆죇죉죊죋죍", 6, "죖죘죚", 5, "죢죣죥"],
        ["a181", "죦", 14, "죶", 5, "죾죿줁줂줃줇", 4, "줎　、。·‥…¨〃­―∥＼∼‘’“”〔〕〈", 9, "±×÷≠≤≥∞∴°′″℃Å￠￡￥♂♀∠⊥⌒∂∇≡≒§※☆★○●◎◇◆□■△▲▽▼→←↑↓↔〓≪≫√∽∝∵∫∬∈∋⊆⊇⊂⊃∪∩∧∨￢"],
        ["a241", "줐줒", 5, "줙", 18],
        ["a261", "줭", 6, "줵", 18],
        ["a281", "쥈", 7, "쥒쥓쥕쥖쥗쥙", 6, "쥢쥤", 7, "쥭쥮쥯⇒⇔∀∃´～ˇ˘˝˚˙¸˛¡¿ː∮∑∏¤℉‰◁◀▷▶♤♠♡♥♧♣⊙◈▣◐◑▒▤▥▨▧▦▩♨☏☎☜☞¶†‡↕↗↙↖↘♭♩♪♬㉿㈜№㏇™㏂㏘℡€®"],
        ["a341", "쥱쥲쥳쥵", 6, "쥽", 10, "즊즋즍즎즏"],
        ["a361", "즑", 6, "즚즜즞", 16],
        ["a381", "즯", 16, "짂짃짅짆짉짋", 4, "짒짔짗짘짛！", 58, "￦］", 32, "￣"],
        ["a441", "짞짟짡짣짥짦짨짩짪짫짮짲", 5, "짺짻짽짾짿쨁쨂쨃쨄"],
        ["a461", "쨅쨆쨇쨊쨎", 5, "쨕쨖쨗쨙", 12],
        ["a481", "쨦쨧쨨쨪", 28, "ㄱ", 93],
        ["a541", "쩇", 4, "쩎쩏쩑쩒쩓쩕", 6, "쩞쩢", 5, "쩩쩪"],
        ["a561", "쩫", 17, "쩾", 5, "쪅쪆"],
        ["a581", "쪇", 16, "쪙", 14, "ⅰ", 9],
        ["a5b0", "Ⅰ", 9],
        ["a5c1", "Α", 16, "Σ", 6],
        ["a5e1", "α", 16, "σ", 6],
        ["a641", "쪨", 19, "쪾쪿쫁쫂쫃쫅"],
        ["a661", "쫆", 5, "쫎쫐쫒쫔쫕쫖쫗쫚", 5, "쫡", 6],
        ["a681", "쫨쫩쫪쫫쫭", 6, "쫵", 18, "쬉쬊─│┌┐┘└├┬┤┴┼━┃┏┓┛┗┣┳┫┻╋┠┯┨┷┿┝┰┥┸╂┒┑┚┙┖┕┎┍┞┟┡┢┦┧┩┪┭┮┱┲┵┶┹┺┽┾╀╁╃", 7],
        ["a741", "쬋", 4, "쬑쬒쬓쬕쬖쬗쬙", 6, "쬢", 7],
        ["a761", "쬪", 22, "쭂쭃쭄"],
        ["a781", "쭅쭆쭇쭊쭋쭍쭎쭏쭑", 6, "쭚쭛쭜쭞", 5, "쭥", 7, "㎕㎖㎗ℓ㎘㏄㎣㎤㎥㎦㎙", 9, "㏊㎍㎎㎏㏏㎈㎉㏈㎧㎨㎰", 9, "㎀", 4, "㎺", 5, "㎐", 4, "Ω㏀㏁㎊㎋㎌㏖㏅㎭㎮㎯㏛㎩㎪㎫㎬㏝㏐㏓㏃㏉㏜㏆"],
        ["a841", "쭭", 10, "쭺", 14],
        ["a861", "쮉", 18, "쮝", 6],
        ["a881", "쮤", 19, "쮹", 11, "ÆÐªĦ"],
        ["a8a6", "Ĳ"],
        ["a8a8", "ĿŁØŒºÞŦŊ"],
        ["a8b1", "㉠", 27, "ⓐ", 25, "①", 14, "½⅓⅔¼¾⅛⅜⅝⅞"],
        ["a941", "쯅", 14, "쯕", 10],
        ["a961", "쯠쯡쯢쯣쯥쯦쯨쯪", 18],
        ["a981", "쯽", 14, "찎찏찑찒찓찕", 6, "찞찟찠찣찤æđðħıĳĸŀłøœßþŧŋŉ㈀", 27, "⒜", 25, "⑴", 14, "¹²³⁴ⁿ₁₂₃₄"],
        ["aa41", "찥찦찪찫찭찯찱", 6, "찺찿", 4, "챆챇챉챊챋챍챎"],
        ["aa61", "챏", 4, "챖챚", 5, "챡챢챣챥챧챩", 6, "챱챲"],
        ["aa81", "챳챴챶", 29, "ぁ", 82],
        ["ab41", "첔첕첖첗첚첛첝첞첟첡", 6, "첪첮", 5, "첶첷첹"],
        ["ab61", "첺첻첽", 6, "쳆쳈쳊", 5, "쳑쳒쳓쳕", 5],
        ["ab81", "쳛", 8, "쳥", 6, "쳭쳮쳯쳱", 12, "ァ", 85],
        ["ac41", "쳾쳿촀촂", 5, "촊촋촍촎촏촑", 6, "촚촜촞촟촠"],
        ["ac61", "촡촢촣촥촦촧촩촪촫촭", 11, "촺", 4],
        ["ac81", "촿", 28, "쵝쵞쵟А", 5, "ЁЖ", 25],
        ["acd1", "а", 5, "ёж", 25],
        ["ad41", "쵡쵢쵣쵥", 6, "쵮쵰쵲", 5, "쵹", 7],
        ["ad61", "춁", 6, "춉", 10, "춖춗춙춚춛춝춞춟"],
        ["ad81", "춠춡춢춣춦춨춪", 5, "춱", 18, "췅"],
        ["ae41", "췆", 5, "췍췎췏췑", 16],
        ["ae61", "췢", 5, "췩췪췫췭췮췯췱", 6, "췺췼췾", 4],
        ["ae81", "츃츅츆츇츉츊츋츍", 6, "츕츖츗츘츚", 5, "츢츣츥츦츧츩츪츫"],
        ["af41", "츬츭츮츯츲츴츶", 19],
        ["af61", "칊", 13, "칚칛칝칞칢", 5, "칪칬"],
        ["af81", "칮", 5, "칶칷칹칺칻칽", 6, "캆캈캊", 5, "캒캓캕캖캗캙"],
        ["b041", "캚", 5, "캢캦", 5, "캮", 12],
        ["b061", "캻", 5, "컂", 19],
        ["b081", "컖", 13, "컦컧컩컪컭", 6, "컶컺", 5, "가각간갇갈갉갊감", 7, "같", 4, "갠갤갬갭갯갰갱갸갹갼걀걋걍걔걘걜거걱건걷걸걺검겁것겄겅겆겉겊겋게겐겔겜겝겟겠겡겨격겪견겯결겸겹겻겼경곁계곈곌곕곗고곡곤곧골곪곬곯곰곱곳공곶과곽관괄괆"],
        ["b141", "켂켃켅켆켇켉", 6, "켒켔켖", 5, "켝켞켟켡켢켣"],
        ["b161", "켥", 6, "켮켲", 5, "켹", 11],
        ["b181", "콅", 14, "콖콗콙콚콛콝", 6, "콦콨콪콫콬괌괍괏광괘괜괠괩괬괭괴괵괸괼굄굅굇굉교굔굘굡굣구국군굳굴굵굶굻굼굽굿궁궂궈궉권궐궜궝궤궷귀귁귄귈귐귑귓규균귤그극근귿글긁금급긋긍긔기긱긴긷길긺김깁깃깅깆깊까깍깎깐깔깖깜깝깟깠깡깥깨깩깬깰깸"],
        ["b241", "콭콮콯콲콳콵콶콷콹", 6, "쾁쾂쾃쾄쾆", 5, "쾍"],
        ["b261", "쾎", 18, "쾢", 5, "쾩"],
        ["b281", "쾪", 5, "쾱", 18, "쿅", 6, "깹깻깼깽꺄꺅꺌꺼꺽꺾껀껄껌껍껏껐껑께껙껜껨껫껭껴껸껼꼇꼈꼍꼐꼬꼭꼰꼲꼴꼼꼽꼿꽁꽂꽃꽈꽉꽐꽜꽝꽤꽥꽹꾀꾄꾈꾐꾑꾕꾜꾸꾹꾼꿀꿇꿈꿉꿋꿍꿎꿔꿜꿨꿩꿰꿱꿴꿸뀀뀁뀄뀌뀐뀔뀜뀝뀨끄끅끈끊끌끎끓끔끕끗끙"],
        ["b341", "쿌", 19, "쿢쿣쿥쿦쿧쿩"],
        ["b361", "쿪", 5, "쿲쿴쿶", 5, "쿽쿾쿿퀁퀂퀃퀅", 5],
        ["b381", "퀋", 5, "퀒", 5, "퀙", 19, "끝끼끽낀낄낌낍낏낑나낙낚난낟날낡낢남납낫", 4, "낱낳내낵낸낼냄냅냇냈냉냐냑냔냘냠냥너넉넋넌널넒넓넘넙넛넜넝넣네넥넨넬넴넵넷넸넹녀녁년녈념녑녔녕녘녜녠노녹논놀놂놈놉놋농높놓놔놘놜놨뇌뇐뇔뇜뇝"],
        ["b441", "퀮", 5, "퀶퀷퀹퀺퀻퀽", 6, "큆큈큊", 5],
        ["b461", "큑큒큓큕큖큗큙", 6, "큡", 10, "큮큯"],
        ["b481", "큱큲큳큵", 6, "큾큿킀킂", 18, "뇟뇨뇩뇬뇰뇹뇻뇽누눅눈눋눌눔눕눗눙눠눴눼뉘뉜뉠뉨뉩뉴뉵뉼늄늅늉느늑는늘늙늚늠늡늣능늦늪늬늰늴니닉닌닐닒님닙닛닝닢다닥닦단닫", 4, "닳담답닷", 4, "닿대댁댄댈댐댑댓댔댕댜더덕덖던덛덜덞덟덤덥"],
        ["b541", "킕", 14, "킦킧킩킪킫킭", 5],
        ["b561", "킳킶킸킺", 5, "탂탃탅탆탇탊", 5, "탒탖", 4],
        ["b581", "탛탞탟탡탢탣탥", 6, "탮탲", 5, "탹", 11, "덧덩덫덮데덱덴델뎀뎁뎃뎄뎅뎌뎐뎔뎠뎡뎨뎬도독돈돋돌돎돐돔돕돗동돛돝돠돤돨돼됐되된될됨됩됫됴두둑둔둘둠둡둣둥둬뒀뒈뒝뒤뒨뒬뒵뒷뒹듀듄듈듐듕드득든듣들듦듬듭듯등듸디딕딘딛딜딤딥딧딨딩딪따딱딴딸"],
        ["b641", "턅", 7, "턎", 17],
        ["b661", "턠", 15, "턲턳턵턶턷턹턻턼턽턾"],
        ["b681", "턿텂텆", 5, "텎텏텑텒텓텕", 6, "텞텠텢", 5, "텩텪텫텭땀땁땃땄땅땋때땍땐땔땜땝땟땠땡떠떡떤떨떪떫떰떱떳떴떵떻떼떽뗀뗄뗌뗍뗏뗐뗑뗘뗬또똑똔똘똥똬똴뙈뙤뙨뚜뚝뚠뚤뚫뚬뚱뛔뛰뛴뛸뜀뜁뜅뜨뜩뜬뜯뜰뜸뜹뜻띄띈띌띔띕띠띤띨띰띱띳띵라락란랄람랍랏랐랑랒랖랗"],
        ["b741", "텮", 13, "텽", 6, "톅톆톇톉톊"],
        ["b761", "톋", 20, "톢톣톥톦톧"],
        ["b781", "톩", 6, "톲톴톶톷톸톹톻톽톾톿퇁", 14, "래랙랜랠램랩랫랬랭랴략랸럇량러럭런럴럼럽럿렀렁렇레렉렌렐렘렙렛렝려력련렬렴렵렷렸령례롄롑롓로록론롤롬롭롯롱롸롼뢍뢨뢰뢴뢸룀룁룃룅료룐룔룝룟룡루룩룬룰룸룹룻룽뤄뤘뤠뤼뤽륀륄륌륏륑류륙륜률륨륩"],
        ["b841", "퇐", 7, "퇙", 17],
        ["b861", "퇫", 8, "퇵퇶퇷퇹", 13],
        ["b881", "툈툊", 5, "툑", 24, "륫륭르륵른를름릅릇릉릊릍릎리릭린릴림립릿링마막만많", 4, "맘맙맛망맞맡맣매맥맨맬맴맵맷맸맹맺먀먁먈먕머먹먼멀멂멈멉멋멍멎멓메멕멘멜멤멥멧멨멩며멱면멸몃몄명몇몌모목몫몬몰몲몸몹못몽뫄뫈뫘뫙뫼"],
        ["b941", "툪툫툮툯툱툲툳툵", 6, "툾퉀퉂", 5, "퉉퉊퉋퉌"],
        ["b961", "퉍", 14, "퉝", 6, "퉥퉦퉧퉨"],
        ["b981", "퉩", 22, "튂튃튅튆튇튉튊튋튌묀묄묍묏묑묘묜묠묩묫무묵묶문묻물묽묾뭄뭅뭇뭉뭍뭏뭐뭔뭘뭡뭣뭬뮈뮌뮐뮤뮨뮬뮴뮷므믄믈믐믓미믹민믿밀밂밈밉밋밌밍및밑바", 4, "받", 4, "밤밥밧방밭배백밴밸뱀뱁뱃뱄뱅뱉뱌뱍뱐뱝버벅번벋벌벎범법벗"],
        ["ba41", "튍튎튏튒튓튔튖", 5, "튝튞튟튡튢튣튥", 6, "튭"],
        ["ba61", "튮튯튰튲", 5, "튺튻튽튾틁틃", 4, "틊틌", 5],
        ["ba81", "틒틓틕틖틗틙틚틛틝", 6, "틦", 9, "틲틳틵틶틷틹틺벙벚베벡벤벧벨벰벱벳벴벵벼벽변별볍볏볐병볕볘볜보복볶본볼봄봅봇봉봐봔봤봬뵀뵈뵉뵌뵐뵘뵙뵤뵨부북분붇불붉붊붐붑붓붕붙붚붜붤붰붸뷔뷕뷘뷜뷩뷰뷴뷸븀븃븅브븍븐블븜븝븟비빅빈빌빎빔빕빗빙빚빛빠빡빤"],
        ["bb41", "틻", 4, "팂팄팆", 5, "팏팑팒팓팕팗", 4, "팞팢팣"],
        ["bb61", "팤팦팧팪팫팭팮팯팱", 6, "팺팾", 5, "퍆퍇퍈퍉"],
        ["bb81", "퍊", 31, "빨빪빰빱빳빴빵빻빼빽뺀뺄뺌뺍뺏뺐뺑뺘뺙뺨뻐뻑뻔뻗뻘뻠뻣뻤뻥뻬뼁뼈뼉뼘뼙뼛뼜뼝뽀뽁뽄뽈뽐뽑뽕뾔뾰뿅뿌뿍뿐뿔뿜뿟뿡쀼쁑쁘쁜쁠쁨쁩삐삑삔삘삠삡삣삥사삭삯산삳살삵삶삼삽삿샀상샅새색샌샐샘샙샛샜생샤"],
        ["bc41", "퍪", 17, "퍾퍿펁펂펃펅펆펇"],
        ["bc61", "펈펉펊펋펎펒", 5, "펚펛펝펞펟펡", 6, "펪펬펮"],
        ["bc81", "펯", 4, "펵펶펷펹펺펻펽", 6, "폆폇폊", 5, "폑", 5, "샥샨샬샴샵샷샹섀섄섈섐섕서", 4, "섣설섦섧섬섭섯섰성섶세섹센셀셈셉셋셌셍셔셕션셜셤셥셧셨셩셰셴셸솅소속솎손솔솖솜솝솟송솥솨솩솬솰솽쇄쇈쇌쇔쇗쇘쇠쇤쇨쇰쇱쇳쇼쇽숀숄숌숍숏숑수숙순숟술숨숩숫숭"],
        ["bd41", "폗폙", 7, "폢폤", 7, "폮폯폱폲폳폵폶폷"],
        ["bd61", "폸폹폺폻폾퐀퐂", 5, "퐉", 13],
        ["bd81", "퐗", 5, "퐞", 25, "숯숱숲숴쉈쉐쉑쉔쉘쉠쉥쉬쉭쉰쉴쉼쉽쉿슁슈슉슐슘슛슝스슥슨슬슭슴습슷승시식신싣실싫심십싯싱싶싸싹싻싼쌀쌈쌉쌌쌍쌓쌔쌕쌘쌜쌤쌥쌨쌩썅써썩썬썰썲썸썹썼썽쎄쎈쎌쏀쏘쏙쏜쏟쏠쏢쏨쏩쏭쏴쏵쏸쐈쐐쐤쐬쐰"],
        ["be41", "퐸", 7, "푁푂푃푅", 14],
        ["be61", "푔", 7, "푝푞푟푡푢푣푥", 7, "푮푰푱푲"],
        ["be81", "푳", 4, "푺푻푽푾풁풃", 4, "풊풌풎", 5, "풕", 8, "쐴쐼쐽쑈쑤쑥쑨쑬쑴쑵쑹쒀쒔쒜쒸쒼쓩쓰쓱쓴쓸쓺쓿씀씁씌씐씔씜씨씩씬씰씸씹씻씽아악안앉않알앍앎앓암압앗았앙앝앞애액앤앨앰앱앳앴앵야약얀얄얇얌얍얏양얕얗얘얜얠얩어억언얹얻얼얽얾엄", 6, "엌엎"],
        ["bf41", "풞", 10, "풪", 14],
        ["bf61", "풹", 18, "퓍퓎퓏퓑퓒퓓퓕"],
        ["bf81", "퓖", 5, "퓝퓞퓠", 7, "퓩퓪퓫퓭퓮퓯퓱", 6, "퓹퓺퓼에엑엔엘엠엡엣엥여역엮연열엶엷염", 5, "옅옆옇예옌옐옘옙옛옜오옥온올옭옮옰옳옴옵옷옹옻와왁완왈왐왑왓왔왕왜왝왠왬왯왱외왹왼욀욈욉욋욍요욕욘욜욤욥욧용우욱운울욹욺움웁웃웅워웍원월웜웝웠웡웨"],
        ["c041", "퓾", 5, "픅픆픇픉픊픋픍", 6, "픖픘", 5],
        ["c061", "픞", 25],
        ["c081", "픸픹픺픻픾픿핁핂핃핅", 6, "핎핐핒", 5, "핚핛핝핞핟핡핢핣웩웬웰웸웹웽위윅윈윌윔윕윗윙유육윤율윰윱윳융윷으윽은을읊음읍읏응", 7, "읜읠읨읫이익인일읽읾잃임입잇있잉잊잎자작잔잖잗잘잚잠잡잣잤장잦재잭잰잴잼잽잿쟀쟁쟈쟉쟌쟎쟐쟘쟝쟤쟨쟬저적전절젊"],
        ["c141", "핤핦핧핪핬핮", 5, "핶핷핹핺핻핽", 6, "햆햊햋"],
        ["c161", "햌햍햎햏햑", 19, "햦햧"],
        ["c181", "햨", 31, "점접젓정젖제젝젠젤젬젭젯젱져젼졀졈졉졌졍졔조족존졸졺좀좁좃종좆좇좋좌좍좔좝좟좡좨좼좽죄죈죌죔죕죗죙죠죡죤죵주죽준줄줅줆줌줍줏중줘줬줴쥐쥑쥔쥘쥠쥡쥣쥬쥰쥴쥼즈즉즌즐즘즙즛증지직진짇질짊짐집짓"],
        ["c241", "헊헋헍헎헏헑헓", 4, "헚헜헞", 5, "헦헧헩헪헫헭헮"],
        ["c261", "헯", 4, "헶헸헺", 5, "혂혃혅혆혇혉", 6, "혒"],
        ["c281", "혖", 5, "혝혞혟혡혢혣혥", 7, "혮", 9, "혺혻징짖짙짚짜짝짠짢짤짧짬짭짯짰짱째짹짼쨀쨈쨉쨋쨌쨍쨔쨘쨩쩌쩍쩐쩔쩜쩝쩟쩠쩡쩨쩽쪄쪘쪼쪽쫀쫄쫌쫍쫏쫑쫓쫘쫙쫠쫬쫴쬈쬐쬔쬘쬠쬡쭁쭈쭉쭌쭐쭘쭙쭝쭤쭸쭹쮜쮸쯔쯤쯧쯩찌찍찐찔찜찝찡찢찧차착찬찮찰참찹찻"],
        ["c341", "혽혾혿홁홂홃홄홆홇홊홌홎홏홐홒홓홖홗홙홚홛홝", 4],
        ["c361", "홢", 4, "홨홪", 5, "홲홳홵", 11],
        ["c381", "횁횂횄횆", 5, "횎횏횑횒횓횕", 7, "횞횠횢", 5, "횩횪찼창찾채책챈챌챔챕챗챘챙챠챤챦챨챰챵처척천철첨첩첫첬청체첵첸첼쳄쳅쳇쳉쳐쳔쳤쳬쳰촁초촉촌촐촘촙촛총촤촨촬촹최쵠쵤쵬쵭쵯쵱쵸춈추축춘출춤춥춧충춰췄췌췐취췬췰췸췹췻췽츄츈츌츔츙츠측츤츨츰츱츳층"],
        ["c441", "횫횭횮횯횱", 7, "횺횼", 7, "훆훇훉훊훋"],
        ["c461", "훍훎훏훐훒훓훕훖훘훚", 5, "훡훢훣훥훦훧훩", 4],
        ["c481", "훮훯훱훲훳훴훶", 5, "훾훿휁휂휃휅", 11, "휒휓휔치칙친칟칠칡침칩칫칭카칵칸칼캄캅캇캉캐캑캔캘캠캡캣캤캥캬캭컁커컥컨컫컬컴컵컷컸컹케켁켄켈켐켑켓켕켜켠켤켬켭켯켰켱켸코콕콘콜콤콥콧콩콰콱콴콸쾀쾅쾌쾡쾨쾰쿄쿠쿡쿤쿨쿰쿱쿳쿵쿼퀀퀄퀑퀘퀭퀴퀵퀸퀼"],
        ["c541", "휕휖휗휚휛휝휞휟휡", 6, "휪휬휮", 5, "휶휷휹"],
        ["c561", "휺휻휽", 6, "흅흆흈흊", 5, "흒흓흕흚", 4],
        ["c581", "흟흢흤흦흧흨흪흫흭흮흯흱흲흳흵", 6, "흾흿힀힂", 5, "힊힋큄큅큇큉큐큔큘큠크큭큰클큼큽킁키킥킨킬킴킵킷킹타탁탄탈탉탐탑탓탔탕태택탠탤탬탭탯탰탱탸턍터턱턴털턺텀텁텃텄텅테텍텐텔템텝텟텡텨텬텼톄톈토톡톤톨톰톱톳통톺톼퇀퇘퇴퇸툇툉툐투툭툰툴툼툽툿퉁퉈퉜"],
        ["c641", "힍힎힏힑", 6, "힚힜힞", 5],
        ["c6a1", "퉤튀튁튄튈튐튑튕튜튠튤튬튱트특튼튿틀틂틈틉틋틔틘틜틤틥티틱틴틸팀팁팃팅파팍팎판팔팖팜팝팟팠팡팥패팩팬팰팸팹팻팼팽퍄퍅퍼퍽펀펄펌펍펏펐펑페펙펜펠펨펩펫펭펴편펼폄폅폈평폐폘폡폣포폭폰폴폼폽폿퐁"],
        ["c7a1", "퐈퐝푀푄표푠푤푭푯푸푹푼푿풀풂품풉풋풍풔풩퓌퓐퓔퓜퓟퓨퓬퓰퓸퓻퓽프픈플픔픕픗피픽핀필핌핍핏핑하학한할핥함합핫항해핵핸핼햄햅햇했행햐향허헉헌헐헒험헙헛헝헤헥헨헬헴헵헷헹혀혁현혈혐협혓혔형혜혠"],
        ["c8a1", "혤혭호혹혼홀홅홈홉홋홍홑화확환활홧황홰홱홴횃횅회획횐횔횝횟횡효횬횰횹횻후훅훈훌훑훔훗훙훠훤훨훰훵훼훽휀휄휑휘휙휜휠휨휩휫휭휴휵휸휼흄흇흉흐흑흔흖흗흘흙흠흡흣흥흩희흰흴흼흽힁히힉힌힐힘힙힛힝"],
        ["caa1", "伽佳假價加可呵哥嘉嫁家暇架枷柯歌珂痂稼苛茄街袈訶賈跏軻迦駕刻却各恪慤殼珏脚覺角閣侃刊墾奸姦干幹懇揀杆柬桿澗癎看磵稈竿簡肝艮艱諫間乫喝曷渴碣竭葛褐蝎鞨勘坎堪嵌感憾戡敢柑橄減甘疳監瞰紺邯鑑鑒龕"],
        ["cba1", "匣岬甲胛鉀閘剛堈姜岡崗康强彊慷江畺疆糠絳綱羌腔舡薑襁講鋼降鱇介价個凱塏愷愾慨改槪漑疥皆盖箇芥蓋豈鎧開喀客坑更粳羹醵倨去居巨拒据據擧渠炬祛距踞車遽鉅鋸乾件健巾建愆楗腱虔蹇鍵騫乞傑杰桀儉劍劒檢"],
        ["cca1", "瞼鈐黔劫怯迲偈憩揭擊格檄激膈覡隔堅牽犬甄絹繭肩見譴遣鵑抉決潔結缺訣兼慊箝謙鉗鎌京俓倞傾儆勁勍卿坰境庚徑慶憬擎敬景暻更梗涇炅烱璟璥瓊痙硬磬竟競絅經耕耿脛莖警輕逕鏡頃頸驚鯨係啓堺契季屆悸戒桂械"],
        ["cda1", "棨溪界癸磎稽系繫繼計誡谿階鷄古叩告呱固姑孤尻庫拷攷故敲暠枯槁沽痼皐睾稿羔考股膏苦苽菰藁蠱袴誥賈辜錮雇顧高鼓哭斛曲梏穀谷鵠困坤崑昆梱棍滾琨袞鯤汨滑骨供公共功孔工恐恭拱控攻珙空蚣貢鞏串寡戈果瓜"],
        ["cea1", "科菓誇課跨過鍋顆廓槨藿郭串冠官寬慣棺款灌琯瓘管罐菅觀貫關館刮恝括适侊光匡壙廣曠洸炚狂珖筐胱鑛卦掛罫乖傀塊壞怪愧拐槐魁宏紘肱轟交僑咬喬嬌嶠巧攪敎校橋狡皎矯絞翹膠蕎蛟較轎郊餃驕鮫丘久九仇俱具勾"],
        ["cfa1", "區口句咎嘔坵垢寇嶇廐懼拘救枸柩構歐毆毬求溝灸狗玖球瞿矩究絿耉臼舅舊苟衢謳購軀逑邱鉤銶駒驅鳩鷗龜國局菊鞠鞫麴君窘群裙軍郡堀屈掘窟宮弓穹窮芎躬倦券勸卷圈拳捲權淃眷厥獗蕨蹶闕机櫃潰詭軌饋句晷歸貴"],
        ["d0a1", "鬼龜叫圭奎揆槻珪硅窺竅糾葵規赳逵閨勻均畇筠菌鈞龜橘克剋劇戟棘極隙僅劤勤懃斤根槿瑾筋芹菫覲謹近饉契今妗擒昑檎琴禁禽芩衾衿襟金錦伋及急扱汲級給亘兢矜肯企伎其冀嗜器圻基埼夔奇妓寄岐崎己幾忌技旗旣"],
        ["d1a1", "朞期杞棋棄機欺氣汽沂淇玘琦琪璂璣畸畿碁磯祁祇祈祺箕紀綺羈耆耭肌記譏豈起錡錤飢饑騎騏驥麒緊佶吉拮桔金喫儺喇奈娜懦懶拏拿癩", 5, "那樂", 4, "諾酪駱亂卵暖欄煖爛蘭難鸞捏捺南嵐枏楠湳濫男藍襤拉"],
        ["d2a1", "納臘蠟衲囊娘廊", 4, "乃來內奈柰耐冷女年撚秊念恬拈捻寧寗努勞奴弩怒擄櫓爐瑙盧", 5, "駑魯", 10, "濃籠聾膿農惱牢磊腦賂雷尿壘", 7, "嫩訥杻紐勒", 5, "能菱陵尼泥匿溺多茶"],
        ["d3a1", "丹亶但單團壇彖斷旦檀段湍短端簞緞蛋袒鄲鍛撻澾獺疸達啖坍憺擔曇淡湛潭澹痰聃膽蕁覃談譚錟沓畓答踏遝唐堂塘幢戇撞棠當糖螳黨代垈坮大對岱帶待戴擡玳臺袋貸隊黛宅德悳倒刀到圖堵塗導屠島嶋度徒悼挑掉搗桃"],
        ["d4a1", "棹櫂淘渡滔濤燾盜睹禱稻萄覩賭跳蹈逃途道都鍍陶韜毒瀆牘犢獨督禿篤纛讀墩惇敦旽暾沌焞燉豚頓乭突仝冬凍動同憧東桐棟洞潼疼瞳童胴董銅兜斗杜枓痘竇荳讀豆逗頭屯臀芚遁遯鈍得嶝橙燈登等藤謄鄧騰喇懶拏癩羅"],
        ["d5a1", "蘿螺裸邏樂洛烙珞絡落諾酪駱丹亂卵欄欒瀾爛蘭鸞剌辣嵐擥攬欖濫籃纜藍襤覽拉臘蠟廊朗浪狼琅瑯螂郞來崍徠萊冷掠略亮倆兩凉梁樑粮粱糧良諒輛量侶儷勵呂廬慮戾旅櫚濾礪藜蠣閭驢驪麗黎力曆歷瀝礫轢靂憐戀攣漣"],
        ["d6a1", "煉璉練聯蓮輦連鍊冽列劣洌烈裂廉斂殮濂簾獵令伶囹寧岺嶺怜玲笭羚翎聆逞鈴零靈領齡例澧禮醴隷勞怒撈擄櫓潞瀘爐盧老蘆虜路輅露魯鷺鹵碌祿綠菉錄鹿麓論壟弄朧瀧瓏籠聾儡瀨牢磊賂賚賴雷了僚寮廖料燎療瞭聊蓼"],
        ["d7a1", "遼鬧龍壘婁屢樓淚漏瘻累縷蔞褸鏤陋劉旒柳榴流溜瀏琉瑠留瘤硫謬類六戮陸侖倫崙淪綸輪律慄栗率隆勒肋凜凌楞稜綾菱陵俚利厘吏唎履悧李梨浬犁狸理璃異痢籬罹羸莉裏裡里釐離鯉吝潾燐璘藺躪隣鱗麟林淋琳臨霖砬"],
        ["d8a1", "立笠粒摩瑪痲碼磨馬魔麻寞幕漠膜莫邈万卍娩巒彎慢挽晩曼滿漫灣瞞萬蔓蠻輓饅鰻唜抹末沫茉襪靺亡妄忘忙望網罔芒茫莽輞邙埋妹媒寐昧枚梅每煤罵買賣邁魅脈貊陌驀麥孟氓猛盲盟萌冪覓免冕勉棉沔眄眠綿緬面麵滅"],
        ["d9a1", "蔑冥名命明暝椧溟皿瞑茗蓂螟酩銘鳴袂侮冒募姆帽慕摸摹暮某模母毛牟牡瑁眸矛耗芼茅謀謨貌木沐牧目睦穆鶩歿沒夢朦蒙卯墓妙廟描昴杳渺猫竗苗錨務巫憮懋戊拇撫无楙武毋無珷畝繆舞茂蕪誣貿霧鵡墨默們刎吻問文"],
        ["daa1", "汶紊紋聞蚊門雯勿沕物味媚尾嵋彌微未梶楣渼湄眉米美薇謎迷靡黴岷悶愍憫敏旻旼民泯玟珉緡閔密蜜謐剝博拍搏撲朴樸泊珀璞箔粕縛膊舶薄迫雹駁伴半反叛拌搬攀斑槃泮潘班畔瘢盤盼磐磻礬絆般蟠返頒飯勃拔撥渤潑"],
        ["dba1", "發跋醱鉢髮魃倣傍坊妨尨幇彷房放方旁昉枋榜滂磅紡肪膀舫芳蒡蚌訪謗邦防龐倍俳北培徘拜排杯湃焙盃背胚裴裵褙賠輩配陪伯佰帛柏栢白百魄幡樊煩燔番磻繁蕃藩飜伐筏罰閥凡帆梵氾汎泛犯範范法琺僻劈壁擘檗璧癖"],
        ["dca1", "碧蘗闢霹便卞弁變辨辯邊別瞥鱉鼈丙倂兵屛幷昞昺柄棅炳甁病秉竝輧餠騈保堡報寶普步洑湺潽珤甫菩補褓譜輔伏僕匐卜宓復服福腹茯蔔複覆輹輻馥鰒本乶俸奉封峯峰捧棒烽熢琫縫蓬蜂逢鋒鳳不付俯傅剖副否咐埠夫婦"],
        ["dda1", "孚孵富府復扶敷斧浮溥父符簿缶腐腑膚艀芙莩訃負賦賻赴趺部釜阜附駙鳧北分吩噴墳奔奮忿憤扮昐汾焚盆粉糞紛芬賁雰不佛弗彿拂崩朋棚硼繃鵬丕備匕匪卑妃婢庇悲憊扉批斐枇榧比毖毗毘沸泌琵痺砒碑秕秘粃緋翡肥"],
        ["dea1", "脾臂菲蜚裨誹譬費鄙非飛鼻嚬嬪彬斌檳殯浜濱瀕牝玭貧賓頻憑氷聘騁乍事些仕伺似使俟僿史司唆嗣四士奢娑寫寺射巳師徙思捨斜斯柶査梭死沙泗渣瀉獅砂社祀祠私篩紗絲肆舍莎蓑蛇裟詐詞謝賜赦辭邪飼駟麝削數朔索"],
        ["dfa1", "傘刪山散汕珊産疝算蒜酸霰乷撒殺煞薩三參杉森渗芟蔘衫揷澁鈒颯上傷像償商喪嘗孀尙峠常床庠廂想桑橡湘爽牀狀相祥箱翔裳觴詳象賞霜塞璽賽嗇塞穡索色牲生甥省笙墅壻嶼序庶徐恕抒捿敍暑曙書栖棲犀瑞筮絮緖署"],
        ["e0a1", "胥舒薯西誓逝鋤黍鼠夕奭席惜昔晳析汐淅潟石碩蓆釋錫仙僊先善嬋宣扇敾旋渲煽琁瑄璇璿癬禪線繕羨腺膳船蘚蟬詵跣選銑鐥饍鮮卨屑楔泄洩渫舌薛褻設說雪齧剡暹殲纖蟾贍閃陝攝涉燮葉城姓宬性惺成星晟猩珹盛省筬"],
        ["e1a1", "聖聲腥誠醒世勢歲洗稅笹細說貰召嘯塑宵小少巢所掃搔昭梳沼消溯瀟炤燒甦疏疎瘙笑篠簫素紹蔬蕭蘇訴逍遡邵銷韶騷俗屬束涑粟續謖贖速孫巽損蓀遜飡率宋悚松淞訟誦送頌刷殺灑碎鎖衰釗修受嗽囚垂壽嫂守岫峀帥愁"],
        ["e2a1", "戍手授搜收數樹殊水洙漱燧狩獸琇璲瘦睡秀穗竪粹綏綬繡羞脩茱蒐蓚藪袖誰讐輸遂邃酬銖銹隋隧隨雖需須首髓鬚叔塾夙孰宿淑潚熟琡璹肅菽巡徇循恂旬栒楯橓殉洵淳珣盾瞬筍純脣舜荀蓴蕣詢諄醇錞順馴戌術述鉥崇崧"],
        ["e3a1", "嵩瑟膝蝨濕拾習褶襲丞乘僧勝升承昇繩蠅陞侍匙嘶始媤尸屎屍市弑恃施是時枾柴猜矢示翅蒔蓍視試詩諡豕豺埴寔式息拭植殖湜熄篒蝕識軾食飾伸侁信呻娠宸愼新晨燼申神紳腎臣莘薪藎蜃訊身辛辰迅失室實悉審尋心沁"],
        ["e4a1", "沈深瀋甚芯諶什十拾雙氏亞俄兒啞娥峨我牙芽莪蛾衙訝阿雅餓鴉鵝堊岳嶽幄惡愕握樂渥鄂鍔顎鰐齷安岸按晏案眼雁鞍顔鮟斡謁軋閼唵岩巖庵暗癌菴闇壓押狎鴨仰央怏昻殃秧鴦厓哀埃崖愛曖涯碍艾隘靄厄扼掖液縊腋額"],
        ["e5a1", "櫻罌鶯鸚也倻冶夜惹揶椰爺耶若野弱掠略約若葯蒻藥躍亮佯兩凉壤孃恙揚攘敭暘梁楊樣洋瀁煬痒瘍禳穰糧羊良襄諒讓釀陽量養圄御於漁瘀禦語馭魚齬億憶抑檍臆偃堰彦焉言諺孼蘖俺儼嚴奄掩淹嶪業円予余勵呂女如廬"],
        ["e6a1", "旅歟汝濾璵礖礪與艅茹輿轝閭餘驪麗黎亦力域役易曆歷疫繹譯轢逆驛嚥堧姸娟宴年延憐戀捐挻撚椽沇沿涎涓淵演漣烟然煙煉燃燕璉硏硯秊筵緣練縯聯衍軟輦蓮連鉛鍊鳶列劣咽悅涅烈熱裂說閱厭廉念捻染殮炎焰琰艶苒"],
        ["e7a1", "簾閻髥鹽曄獵燁葉令囹塋寧嶺嶸影怜映暎楹榮永泳渶潁濚瀛瀯煐營獰玲瑛瑩瓔盈穎纓羚聆英詠迎鈴鍈零霙靈領乂倪例刈叡曳汭濊猊睿穢芮藝蘂禮裔詣譽豫醴銳隸霓預五伍俉傲午吾吳嗚塢墺奧娛寤悟惡懊敖旿晤梧汚澳"],
        ["e8a1", "烏熬獒筽蜈誤鰲鼇屋沃獄玉鈺溫瑥瘟穩縕蘊兀壅擁瓮甕癰翁邕雍饔渦瓦窩窪臥蛙蝸訛婉完宛梡椀浣玩琓琬碗緩翫脘腕莞豌阮頑曰往旺枉汪王倭娃歪矮外嵬巍猥畏了僚僥凹堯夭妖姚寥寮尿嶢拗搖撓擾料曜樂橈燎燿瑤療"],
        ["e9a1", "窈窯繇繞耀腰蓼蟯要謠遙遼邀饒慾欲浴縟褥辱俑傭冗勇埇墉容庸慂榕涌湧溶熔瑢用甬聳茸蓉踊鎔鏞龍于佑偶優又友右宇寓尤愚憂旴牛玗瑀盂祐禑禹紆羽芋藕虞迂遇郵釪隅雨雩勖彧旭昱栯煜稶郁頊云暈橒殞澐熉耘芸蕓"],
        ["eaa1", "運隕雲韻蔚鬱亐熊雄元原員圓園垣媛嫄寃怨愿援沅洹湲源爰猿瑗苑袁轅遠阮院願鴛月越鉞位偉僞危圍委威尉慰暐渭爲瑋緯胃萎葦蔿蝟衛褘謂違韋魏乳侑儒兪劉唯喩孺宥幼幽庾悠惟愈愉揄攸有杻柔柚柳楡楢油洧流游溜"],
        ["eba1", "濡猶猷琉瑜由留癒硫紐維臾萸裕誘諛諭踰蹂遊逾遺酉釉鍮類六堉戮毓肉育陸倫允奫尹崙淪潤玧胤贇輪鈗閏律慄栗率聿戎瀜絨融隆垠恩慇殷誾銀隱乙吟淫蔭陰音飮揖泣邑凝應膺鷹依倚儀宜意懿擬椅毅疑矣義艤薏蟻衣誼"],
        ["eca1", "議醫二以伊利吏夷姨履已弛彛怡易李梨泥爾珥理異痍痢移罹而耳肄苡荑裏裡貽貳邇里離飴餌匿溺瀷益翊翌翼謚人仁刃印吝咽因姻寅引忍湮燐璘絪茵藺蚓認隣靭靷鱗麟一佚佾壹日溢逸鎰馹任壬妊姙恁林淋稔臨荏賃入卄"],
        ["eda1", "立笠粒仍剩孕芿仔刺咨姉姿子字孜恣慈滋炙煮玆瓷疵磁紫者自茨蔗藉諮資雌作勺嚼斫昨灼炸爵綽芍酌雀鵲孱棧殘潺盞岑暫潛箴簪蠶雜丈仗匠場墻壯奬將帳庄張掌暲杖樟檣欌漿牆狀獐璋章粧腸臟臧莊葬蔣薔藏裝贓醬長"],
        ["eea1", "障再哉在宰才材栽梓渽滓災縡裁財載齋齎爭箏諍錚佇低儲咀姐底抵杵楮樗沮渚狙猪疽箸紵苧菹著藷詛貯躇這邸雎齟勣吊嫡寂摘敵滴狄炙的積笛籍績翟荻謫賊赤跡蹟迪迹適鏑佃佺傳全典前剪塡塼奠專展廛悛戰栓殿氈澱"],
        ["efa1", "煎琠田甸畑癲筌箋箭篆纏詮輾轉鈿銓錢鐫電顚顫餞切截折浙癤竊節絶占岾店漸点粘霑鮎點接摺蝶丁井亭停偵呈姃定幀庭廷征情挺政整旌晶晸柾楨檉正汀淀淨渟湞瀞炡玎珽町睛碇禎程穽精綎艇訂諪貞鄭酊釘鉦鋌錠霆靖"],
        ["f0a1", "靜頂鼎制劑啼堤帝弟悌提梯濟祭第臍薺製諸蹄醍除際霽題齊俎兆凋助嘲弔彫措操早晁曺曹朝條棗槽漕潮照燥爪璪眺祖祚租稠窕粗糟組繰肇藻蚤詔調趙躁造遭釣阻雕鳥族簇足鏃存尊卒拙猝倧宗從悰慫棕淙琮種終綜縱腫"],
        ["f1a1", "踪踵鍾鐘佐坐左座挫罪主住侏做姝胄呪周嗾奏宙州廚晝朱柱株注洲湊澍炷珠疇籌紂紬綢舟蛛註誅走躊輳週酎酒鑄駐竹粥俊儁准埈寯峻晙樽浚準濬焌畯竣蠢逡遵雋駿茁中仲衆重卽櫛楫汁葺增憎曾拯烝甑症繒蒸證贈之只"],
        ["f2a1", "咫地址志持指摯支旨智枝枳止池沚漬知砥祉祗紙肢脂至芝芷蜘誌識贄趾遲直稙稷織職唇嗔塵振搢晉晋桭榛殄津溱珍瑨璡畛疹盡眞瞋秦縉縝臻蔯袗診賑軫辰進鎭陣陳震侄叱姪嫉帙桎瓆疾秩窒膣蛭質跌迭斟朕什執潗緝輯"],
        ["f3a1", "鏶集徵懲澄且侘借叉嗟嵯差次此磋箚茶蹉車遮捉搾着窄錯鑿齪撰澯燦璨瓚竄簒纂粲纘讚贊鑽餐饌刹察擦札紮僭參塹慘慙懺斬站讒讖倉倡創唱娼廠彰愴敞昌昶暢槍滄漲猖瘡窓脹艙菖蒼債埰寀寨彩採砦綵菜蔡采釵冊柵策"],
        ["f4a1", "責凄妻悽處倜刺剔尺慽戚拓擲斥滌瘠脊蹠陟隻仟千喘天川擅泉淺玔穿舛薦賤踐遷釧闡阡韆凸哲喆徹撤澈綴輟轍鐵僉尖沾添甛瞻簽籤詹諂堞妾帖捷牒疊睫諜貼輒廳晴淸聽菁請靑鯖切剃替涕滯締諦逮遞體初剿哨憔抄招梢"],
        ["f5a1", "椒楚樵炒焦硝礁礎秒稍肖艸苕草蕉貂超酢醋醮促囑燭矗蜀觸寸忖村邨叢塚寵悤憁摠總聰蔥銃撮催崔最墜抽推椎楸樞湫皺秋芻萩諏趨追鄒酋醜錐錘鎚雛騶鰍丑畜祝竺筑築縮蓄蹙蹴軸逐春椿瑃出朮黜充忠沖蟲衝衷悴膵萃"],
        ["f6a1", "贅取吹嘴娶就炊翠聚脆臭趣醉驟鷲側仄厠惻測層侈値嗤峙幟恥梔治淄熾痔痴癡稚穉緇緻置致蚩輜雉馳齒則勅飭親七柒漆侵寢枕沈浸琛砧針鍼蟄秤稱快他咤唾墮妥惰打拖朶楕舵陀馱駝倬卓啄坼度托拓擢晫柝濁濯琢琸託"],
        ["f7a1", "鐸呑嘆坦彈憚歎灘炭綻誕奪脫探眈耽貪塔搭榻宕帑湯糖蕩兌台太怠態殆汰泰笞胎苔跆邰颱宅擇澤撑攄兎吐土討慟桶洞痛筒統通堆槌腿褪退頹偸套妬投透鬪慝特闖坡婆巴把播擺杷波派爬琶破罷芭跛頗判坂板版瓣販辦鈑"],
        ["f8a1", "阪八叭捌佩唄悖敗沛浿牌狽稗覇貝彭澎烹膨愎便偏扁片篇編翩遍鞭騙貶坪平枰萍評吠嬖幣廢弊斃肺蔽閉陛佈包匍匏咆哺圃布怖抛抱捕暴泡浦疱砲胞脯苞葡蒲袍褒逋鋪飽鮑幅暴曝瀑爆輻俵剽彪慓杓標漂瓢票表豹飇飄驃"],
        ["f9a1", "品稟楓諷豊風馮彼披疲皮被避陂匹弼必泌珌畢疋筆苾馝乏逼下何厦夏廈昰河瑕荷蝦賀遐霞鰕壑學虐謔鶴寒恨悍旱汗漢澣瀚罕翰閑閒限韓割轄函含咸啣喊檻涵緘艦銜陷鹹合哈盒蛤閤闔陜亢伉姮嫦巷恒抗杭桁沆港缸肛航"],
        ["faa1", "行降項亥偕咳垓奚孩害懈楷海瀣蟹解該諧邂駭骸劾核倖幸杏荇行享向嚮珦鄕響餉饗香噓墟虛許憲櫶獻軒歇險驗奕爀赫革俔峴弦懸晛泫炫玄玹現眩睍絃絢縣舷衒見賢鉉顯孑穴血頁嫌俠協夾峽挾浹狹脅脇莢鋏頰亨兄刑型"],
        ["fba1", "形泂滎瀅灐炯熒珩瑩荊螢衡逈邢鎣馨兮彗惠慧暳蕙蹊醯鞋乎互呼壕壺好岵弧戶扈昊晧毫浩淏湖滸澔濠濩灝狐琥瑚瓠皓祜糊縞胡芦葫蒿虎號蝴護豪鎬頀顥惑或酷婚昏混渾琿魂忽惚笏哄弘汞泓洪烘紅虹訌鴻化和嬅樺火畵"],
        ["fca1", "禍禾花華話譁貨靴廓擴攫確碻穫丸喚奐宦幻患換歡晥桓渙煥環紈還驩鰥活滑猾豁闊凰幌徨恍惶愰慌晃晄榥況湟滉潢煌璜皇篁簧荒蝗遑隍黃匯回廻徊恢悔懷晦會檜淮澮灰獪繪膾茴蛔誨賄劃獲宖橫鐄哮嚆孝效斅曉梟涍淆"],
        ["fda1", "爻肴酵驍侯候厚后吼喉嗅帿後朽煦珝逅勛勳塤壎焄熏燻薰訓暈薨喧暄煊萱卉喙毁彙徽揮暉煇諱輝麾休携烋畦虧恤譎鷸兇凶匈洶胸黑昕欣炘痕吃屹紇訖欠欽歆吸恰洽翕興僖凞喜噫囍姬嬉希憙憘戱晞曦熙熹熺犧禧稀羲詰"]
    ];
    module.exports = json;
},
/* iconv-lite/encodings/tables/cp950.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = [
        ["0", "\u0000", 127],
        ["a140", "　，、。．‧；：？！︰…‥﹐﹑﹒·﹔﹕﹖﹗｜–︱—︳╴︴﹏（）︵︶｛｝︷︸〔〕︹︺【】︻︼《》︽︾〈〉︿﹀「」﹁﹂『』﹃﹄﹙﹚"],
        ["a1a1", "﹛﹜﹝﹞‘’“”〝〞‵′＃＆＊※§〃○●△▲◎☆★◇◆□■▽▼㊣℅¯￣＿ˍ﹉﹊﹍﹎﹋﹌﹟﹠﹡＋－×÷±√＜＞＝≦≧≠∞≒≡﹢", 4, "～∩∪⊥∠∟⊿㏒㏑∫∮∵∴♀♂⊕⊙↑↓←→↖↗↙↘∥∣／"],
        ["a240", "＼∕﹨＄￥〒￠￡％＠℃℉﹩﹪﹫㏕㎜㎝㎞㏎㎡㎎㎏㏄°兙兛兞兝兡兣嗧瓩糎▁", 7, "▏▎▍▌▋▊▉┼┴┬┤├▔─│▕┌┐└┘╭"],
        ["a2a1", "╮╰╯═╞╪╡◢◣◥◤╱╲╳０", 9, "Ⅰ", 9, "〡", 8, "十卄卅Ａ", 25, "ａ", 21],
        ["a340", "ｗｘｙｚΑ", 16, "Σ", 6, "α", 16, "σ", 6, "ㄅ", 10],
        ["a3a1", "ㄐ", 25, "˙ˉˊˇˋ"],
        ["a3e1", "€"],
        ["a440", "一乙丁七乃九了二人儿入八几刀刁力匕十卜又三下丈上丫丸凡久么也乞于亡兀刃勺千叉口土士夕大女子孑孓寸小尢尸山川工己已巳巾干廾弋弓才"],
        ["a4a1", "丑丐不中丰丹之尹予云井互五亢仁什仃仆仇仍今介仄元允內六兮公冗凶分切刈勻勾勿化匹午升卅卞厄友及反壬天夫太夭孔少尤尺屯巴幻廿弔引心戈戶手扎支文斗斤方日曰月木欠止歹毋比毛氏水火爪父爻片牙牛犬王丙"],
        ["a540", "世丕且丘主乍乏乎以付仔仕他仗代令仙仞充兄冉冊冬凹出凸刊加功包匆北匝仟半卉卡占卯卮去可古右召叮叩叨叼司叵叫另只史叱台句叭叻四囚外"],
        ["a5a1", "央失奴奶孕它尼巨巧左市布平幼弁弘弗必戊打扔扒扑斥旦朮本未末札正母民氐永汁汀氾犯玄玉瓜瓦甘生用甩田由甲申疋白皮皿目矛矢石示禾穴立丞丟乒乓乩亙交亦亥仿伉伙伊伕伍伐休伏仲件任仰仳份企伋光兇兆先全"],
        ["a640", "共再冰列刑划刎刖劣匈匡匠印危吉吏同吊吐吁吋各向名合吃后吆吒因回囝圳地在圭圬圯圩夙多夷夸妄奸妃好她如妁字存宇守宅安寺尖屹州帆并年"],
        ["a6a1", "式弛忙忖戎戌戍成扣扛托收早旨旬旭曲曳有朽朴朱朵次此死氖汝汗汙江池汐汕污汛汍汎灰牟牝百竹米糸缶羊羽老考而耒耳聿肉肋肌臣自至臼舌舛舟艮色艾虫血行衣西阡串亨位住佇佗佞伴佛何估佐佑伽伺伸佃佔似但佣"],
        ["a740", "作你伯低伶余佝佈佚兌克免兵冶冷別判利刪刨劫助努劬匣即卵吝吭吞吾否呎吧呆呃吳呈呂君吩告吹吻吸吮吵吶吠吼呀吱含吟听囪困囤囫坊坑址坍"],
        ["a7a1", "均坎圾坐坏圻壯夾妝妒妨妞妣妙妖妍妤妓妊妥孝孜孚孛完宋宏尬局屁尿尾岐岑岔岌巫希序庇床廷弄弟彤形彷役忘忌志忍忱快忸忪戒我抄抗抖技扶抉扭把扼找批扳抒扯折扮投抓抑抆改攻攸旱更束李杏材村杜杖杞杉杆杠"],
        ["a840", "杓杗步每求汞沙沁沈沉沅沛汪決沐汰沌汨沖沒汽沃汲汾汴沆汶沍沔沘沂灶灼災灸牢牡牠狄狂玖甬甫男甸皂盯矣私秀禿究系罕肖肓肝肘肛肚育良芒"],
        ["a8a1", "芋芍見角言谷豆豕貝赤走足身車辛辰迂迆迅迄巡邑邢邪邦那酉釆里防阮阱阪阬並乖乳事些亞享京佯依侍佳使佬供例來侃佰併侈佩佻侖佾侏侑佺兔兒兕兩具其典冽函刻券刷刺到刮制剁劾劻卒協卓卑卦卷卸卹取叔受味呵"],
        ["a940", "咖呸咕咀呻呷咄咒咆呼咐呱呶和咚呢周咋命咎固垃坷坪坩坡坦坤坼夜奉奇奈奄奔妾妻委妹妮姑姆姐姍始姓姊妯妳姒姅孟孤季宗定官宜宙宛尚屈居"],
        ["a9a1", "屆岷岡岸岩岫岱岳帘帚帖帕帛帑幸庚店府底庖延弦弧弩往征彿彼忝忠忽念忿怏怔怯怵怖怪怕怡性怩怫怛或戕房戾所承拉拌拄抿拂抹拒招披拓拔拋拈抨抽押拐拙拇拍抵拚抱拘拖拗拆抬拎放斧於旺昔易昌昆昂明昀昏昕昊"],
        ["aa40", "昇服朋杭枋枕東果杳杷枇枝林杯杰板枉松析杵枚枓杼杪杲欣武歧歿氓氛泣注泳沱泌泥河沽沾沼波沫法泓沸泄油況沮泗泅泱沿治泡泛泊沬泯泜泖泠"],
        ["aaa1", "炕炎炒炊炙爬爭爸版牧物狀狎狙狗狐玩玨玟玫玥甽疝疙疚的盂盲直知矽社祀祁秉秈空穹竺糾罔羌羋者肺肥肢肱股肫肩肴肪肯臥臾舍芳芝芙芭芽芟芹花芬芥芯芸芣芰芾芷虎虱初表軋迎返近邵邸邱邶采金長門阜陀阿阻附"],
        ["ab40", "陂隹雨青非亟亭亮信侵侯便俠俑俏保促侶俘俟俊俗侮俐俄係俚俎俞侷兗冒冑冠剎剃削前剌剋則勇勉勃勁匍南卻厚叛咬哀咨哎哉咸咦咳哇哂咽咪品"],
        ["aba1", "哄哈咯咫咱咻咩咧咿囿垂型垠垣垢城垮垓奕契奏奎奐姜姘姿姣姨娃姥姪姚姦威姻孩宣宦室客宥封屎屏屍屋峙峒巷帝帥帟幽庠度建弈弭彥很待徊律徇後徉怒思怠急怎怨恍恰恨恢恆恃恬恫恪恤扁拜挖按拼拭持拮拽指拱拷"],
        ["ac40", "拯括拾拴挑挂政故斫施既春昭映昧是星昨昱昤曷柿染柱柔某柬架枯柵柩柯柄柑枴柚查枸柏柞柳枰柙柢柝柒歪殃殆段毒毗氟泉洋洲洪流津洌洱洞洗"],
        ["aca1", "活洽派洶洛泵洹洧洸洩洮洵洎洫炫為炳炬炯炭炸炮炤爰牲牯牴狩狠狡玷珊玻玲珍珀玳甚甭畏界畎畋疫疤疥疢疣癸皆皇皈盈盆盃盅省盹相眉看盾盼眇矜砂研砌砍祆祉祈祇禹禺科秒秋穿突竿竽籽紂紅紀紉紇約紆缸美羿耄"],
        ["ad40", "耐耍耑耶胖胥胚胃胄背胡胛胎胞胤胝致舢苧范茅苣苛苦茄若茂茉苒苗英茁苜苔苑苞苓苟苯茆虐虹虻虺衍衫要觔計訂訃貞負赴赳趴軍軌述迦迢迪迥"],
        ["ada1", "迭迫迤迨郊郎郁郃酋酊重閂限陋陌降面革韋韭音頁風飛食首香乘亳倌倍倣俯倦倥俸倩倖倆值借倚倒們俺倀倔倨俱倡個候倘俳修倭倪俾倫倉兼冤冥冢凍凌准凋剖剜剔剛剝匪卿原厝叟哨唐唁唷哼哥哲唆哺唔哩哭員唉哮哪"],
        ["ae40", "哦唧唇哽唏圃圄埂埔埋埃堉夏套奘奚娑娘娜娟娛娓姬娠娣娩娥娌娉孫屘宰害家宴宮宵容宸射屑展屐峭峽峻峪峨峰島崁峴差席師庫庭座弱徒徑徐恙"],
        ["aea1", "恣恥恐恕恭恩息悄悟悚悍悔悌悅悖扇拳挈拿捎挾振捕捂捆捏捉挺捐挽挪挫挨捍捌效敉料旁旅時晉晏晃晒晌晅晁書朔朕朗校核案框桓根桂桔栩梳栗桌桑栽柴桐桀格桃株桅栓栘桁殊殉殷氣氧氨氦氤泰浪涕消涇浦浸海浙涓"],
        ["af40", "浬涉浮浚浴浩涌涊浹涅浥涔烊烘烤烙烈烏爹特狼狹狽狸狷玆班琉珮珠珪珞畔畝畜畚留疾病症疲疳疽疼疹痂疸皋皰益盍盎眩真眠眨矩砰砧砸砝破砷"],
        ["afa1", "砥砭砠砟砲祕祐祠祟祖神祝祗祚秤秣秧租秦秩秘窄窈站笆笑粉紡紗紋紊素索純紐紕級紜納紙紛缺罟羔翅翁耆耘耕耙耗耽耿胱脂胰脅胭胴脆胸胳脈能脊胼胯臭臬舀舐航舫舨般芻茫荒荔荊茸荐草茵茴荏茲茹茶茗荀茱茨荃"],
        ["b040", "虔蚊蚪蚓蚤蚩蚌蚣蚜衰衷袁袂衽衹記訐討訌訕訊託訓訖訏訑豈豺豹財貢起躬軒軔軏辱送逆迷退迺迴逃追逅迸邕郡郝郢酒配酌釘針釗釜釙閃院陣陡"],
        ["b0a1", "陛陝除陘陞隻飢馬骨高鬥鬲鬼乾偺偽停假偃偌做偉健偶偎偕偵側偷偏倏偯偭兜冕凰剪副勒務勘動匐匏匙匿區匾參曼商啪啦啄啞啡啃啊唱啖問啕唯啤唸售啜唬啣唳啁啗圈國圉域堅堊堆埠埤基堂堵執培夠奢娶婁婉婦婪婀"],
        ["b140", "娼婢婚婆婊孰寇寅寄寂宿密尉專將屠屜屝崇崆崎崛崖崢崑崩崔崙崤崧崗巢常帶帳帷康庸庶庵庾張強彗彬彩彫得徙從徘御徠徜恿患悉悠您惋悴惦悽"],
        ["b1a1", "情悻悵惜悼惘惕惆惟悸惚惇戚戛扈掠控捲掖探接捷捧掘措捱掩掉掃掛捫推掄授掙採掬排掏掀捻捩捨捺敝敖救教敗啟敏敘敕敔斜斛斬族旋旌旎晝晚晤晨晦晞曹勗望梁梯梢梓梵桿桶梱梧梗械梃棄梭梆梅梔條梨梟梡梂欲殺"],
        ["b240", "毫毬氫涎涼淳淙液淡淌淤添淺清淇淋涯淑涮淞淹涸混淵淅淒渚涵淚淫淘淪深淮淨淆淄涪淬涿淦烹焉焊烽烯爽牽犁猜猛猖猓猙率琅琊球理現琍瓠瓶"],
        ["b2a1", "瓷甜產略畦畢異疏痔痕疵痊痍皎盔盒盛眷眾眼眶眸眺硫硃硎祥票祭移窒窕笠笨笛第符笙笞笮粒粗粕絆絃統紮紹紼絀細紳組累終紲紱缽羞羚翌翎習耜聊聆脯脖脣脫脩脰脤舂舵舷舶船莎莞莘荸莢莖莽莫莒莊莓莉莠荷荻荼"],
        ["b340", "莆莧處彪蛇蛀蚶蛄蚵蛆蛋蚱蚯蛉術袞袈被袒袖袍袋覓規訪訝訣訥許設訟訛訢豉豚販責貫貨貪貧赧赦趾趺軛軟這逍通逗連速逝逐逕逞造透逢逖逛途"],
        ["b3a1", "部郭都酗野釵釦釣釧釭釩閉陪陵陳陸陰陴陶陷陬雀雪雩章竟頂頃魚鳥鹵鹿麥麻傢傍傅備傑傀傖傘傚最凱割剴創剩勞勝勛博厥啻喀喧啼喊喝喘喂喜喪喔喇喋喃喳單喟唾喲喚喻喬喱啾喉喫喙圍堯堪場堤堰報堡堝堠壹壺奠"],
        ["b440", "婷媚婿媒媛媧孳孱寒富寓寐尊尋就嵌嵐崴嵇巽幅帽幀幃幾廊廁廂廄弼彭復循徨惑惡悲悶惠愜愣惺愕惰惻惴慨惱愎惶愉愀愒戟扉掣掌描揀揩揉揆揍"],
        ["b4a1", "插揣提握揖揭揮捶援揪換摒揚揹敞敦敢散斑斐斯普晰晴晶景暑智晾晷曾替期朝棺棕棠棘棗椅棟棵森棧棹棒棲棣棋棍植椒椎棉棚楮棻款欺欽殘殖殼毯氮氯氬港游湔渡渲湧湊渠渥渣減湛湘渤湖湮渭渦湯渴湍渺測湃渝渾滋"],
        ["b540", "溉渙湎湣湄湲湩湟焙焚焦焰無然煮焜牌犄犀猶猥猴猩琺琪琳琢琥琵琶琴琯琛琦琨甥甦畫番痢痛痣痙痘痞痠登發皖皓皴盜睏短硝硬硯稍稈程稅稀窘"],
        ["b5a1", "窗窖童竣等策筆筐筒答筍筋筏筑粟粥絞結絨絕紫絮絲絡給絢絰絳善翔翕耋聒肅腕腔腋腑腎脹腆脾腌腓腴舒舜菩萃菸萍菠菅萋菁華菱菴著萊菰萌菌菽菲菊萸萎萄菜萇菔菟虛蛟蛙蛭蛔蛛蛤蛐蛞街裁裂袱覃視註詠評詞証詁"],
        ["b640", "詔詛詐詆訴診訶詖象貂貯貼貳貽賁費賀貴買貶貿貸越超趁跎距跋跚跑跌跛跆軻軸軼辜逮逵週逸進逶鄂郵鄉郾酣酥量鈔鈕鈣鈉鈞鈍鈐鈇鈑閔閏開閑"],
        ["b6a1", "間閒閎隊階隋陽隅隆隍陲隄雁雅雄集雇雯雲韌項順須飧飪飯飩飲飭馮馭黃黍黑亂傭債傲傳僅傾催傷傻傯僇剿剷剽募勦勤勢勣匯嗟嗨嗓嗦嗎嗜嗇嗑嗣嗤嗯嗚嗡嗅嗆嗥嗉園圓塞塑塘塗塚塔填塌塭塊塢塒塋奧嫁嫉嫌媾媽媼"],
        ["b740", "媳嫂媲嵩嵯幌幹廉廈弒彙徬微愚意慈感想愛惹愁愈慎慌慄慍愾愴愧愍愆愷戡戢搓搾搞搪搭搽搬搏搜搔損搶搖搗搆敬斟新暗暉暇暈暖暄暘暍會榔業"],
        ["b7a1", "楚楷楠楔極椰概楊楨楫楞楓楹榆楝楣楛歇歲毀殿毓毽溢溯滓溶滂源溝滇滅溥溘溼溺溫滑準溜滄滔溪溧溴煎煙煩煤煉照煜煬煦煌煥煞煆煨煖爺牒猷獅猿猾瑯瑚瑕瑟瑞瑁琿瑙瑛瑜當畸瘀痰瘁痲痱痺痿痴痳盞盟睛睫睦睞督"],
        ["b840", "睹睪睬睜睥睨睢矮碎碰碗碘碌碉硼碑碓硿祺祿禁萬禽稜稚稠稔稟稞窟窠筷節筠筮筧粱粳粵經絹綑綁綏絛置罩罪署義羨群聖聘肆肄腱腰腸腥腮腳腫"],
        ["b8a1", "腹腺腦舅艇蒂葷落萱葵葦葫葉葬葛萼萵葡董葩葭葆虞虜號蛹蜓蜈蜇蜀蛾蛻蜂蜃蜆蜊衙裟裔裙補裘裝裡裊裕裒覜解詫該詳試詩詰誇詼詣誠話誅詭詢詮詬詹詻訾詨豢貊貉賊資賈賄貲賃賂賅跡跟跨路跳跺跪跤跦躲較載軾輊"],
        ["b940", "辟農運遊道遂達逼違遐遇遏過遍遑逾遁鄒鄗酬酪酩釉鈷鉗鈸鈽鉀鈾鉛鉋鉤鉑鈴鉉鉍鉅鈹鈿鉚閘隘隔隕雍雋雉雊雷電雹零靖靴靶預頑頓頊頒頌飼飴"],
        ["b9a1", "飽飾馳馱馴髡鳩麂鼎鼓鼠僧僮僥僖僭僚僕像僑僱僎僩兢凳劃劂匱厭嗾嘀嘛嘗嗽嘔嘆嘉嘍嘎嗷嘖嘟嘈嘐嗶團圖塵塾境墓墊塹墅塽壽夥夢夤奪奩嫡嫦嫩嫗嫖嫘嫣孵寞寧寡寥實寨寢寤察對屢嶄嶇幛幣幕幗幔廓廖弊彆彰徹慇"],
        ["ba40", "愿態慷慢慣慟慚慘慵截撇摘摔撤摸摟摺摑摧搴摭摻敲斡旗旖暢暨暝榜榨榕槁榮槓構榛榷榻榫榴槐槍榭槌榦槃榣歉歌氳漳演滾漓滴漩漾漠漬漏漂漢"],
        ["baa1", "滿滯漆漱漸漲漣漕漫漯澈漪滬漁滲滌滷熔熙煽熊熄熒爾犒犖獄獐瑤瑣瑪瑰瑭甄疑瘧瘍瘋瘉瘓盡監瞄睽睿睡磁碟碧碳碩碣禎福禍種稱窪窩竭端管箕箋筵算箝箔箏箸箇箄粹粽精綻綰綜綽綾綠緊綴網綱綺綢綿綵綸維緒緇綬"],
        ["bb40", "罰翠翡翟聞聚肇腐膀膏膈膊腿膂臧臺與舔舞艋蓉蒿蓆蓄蒙蒞蒲蒜蓋蒸蓀蓓蒐蒼蓑蓊蜿蜜蜻蜢蜥蜴蜘蝕蜷蜩裳褂裴裹裸製裨褚裯誦誌語誣認誡誓誤"],
        ["bba1", "說誥誨誘誑誚誧豪貍貌賓賑賒赫趙趕跼輔輒輕輓辣遠遘遜遣遙遞遢遝遛鄙鄘鄞酵酸酷酴鉸銀銅銘銖鉻銓銜銨鉼銑閡閨閩閣閥閤隙障際雌雒需靼鞅韶頗領颯颱餃餅餌餉駁骯骰髦魁魂鳴鳶鳳麼鼻齊億儀僻僵價儂儈儉儅凜"],
        ["bc40", "劇劈劉劍劊勰厲嘮嘻嘹嘲嘿嘴嘩噓噎噗噴嘶嘯嘰墀墟增墳墜墮墩墦奭嬉嫻嬋嫵嬌嬈寮寬審寫層履嶝嶔幢幟幡廢廚廟廝廣廠彈影德徵慶慧慮慝慕憂"],
        ["bca1", "慼慰慫慾憧憐憫憎憬憚憤憔憮戮摩摯摹撞撲撈撐撰撥撓撕撩撒撮播撫撚撬撙撢撳敵敷數暮暫暴暱樣樟槨樁樞標槽模樓樊槳樂樅槭樑歐歎殤毅毆漿潼澄潑潦潔澆潭潛潸潮澎潺潰潤澗潘滕潯潠潟熟熬熱熨牖犛獎獗瑩璋璃"],
        ["bd40", "瑾璀畿瘠瘩瘟瘤瘦瘡瘢皚皺盤瞎瞇瞌瞑瞋磋磅確磊碾磕碼磐稿稼穀稽稷稻窯窮箭箱範箴篆篇篁箠篌糊締練緯緻緘緬緝編緣線緞緩綞緙緲緹罵罷羯"],
        ["bda1", "翩耦膛膜膝膠膚膘蔗蔽蔚蓮蔬蔭蔓蔑蔣蔡蔔蓬蔥蓿蔆螂蝴蝶蝠蝦蝸蝨蝙蝗蝌蝓衛衝褐複褒褓褕褊誼諒談諄誕請諸課諉諂調誰論諍誶誹諛豌豎豬賠賞賦賤賬賭賢賣賜質賡赭趟趣踫踐踝踢踏踩踟踡踞躺輝輛輟輩輦輪輜輞"],
        ["be40", "輥適遮遨遭遷鄰鄭鄧鄱醇醉醋醃鋅銻銷鋪銬鋤鋁銳銼鋒鋇鋰銲閭閱霄霆震霉靠鞍鞋鞏頡頫頜颳養餓餒餘駝駐駟駛駑駕駒駙骷髮髯鬧魅魄魷魯鴆鴉"],
        ["bea1", "鴃麩麾黎墨齒儒儘儔儐儕冀冪凝劑劓勳噙噫噹噩噤噸噪器噥噱噯噬噢噶壁墾壇壅奮嬝嬴學寰導彊憲憑憩憊懍憶憾懊懈戰擅擁擋撻撼據擄擇擂操撿擒擔撾整曆曉暹曄曇暸樽樸樺橙橫橘樹橄橢橡橋橇樵機橈歙歷氅濂澱澡"],
        ["bf40", "濃澤濁澧澳激澹澶澦澠澴熾燉燐燒燈燕熹燎燙燜燃燄獨璜璣璘璟璞瓢甌甍瘴瘸瘺盧盥瞠瞞瞟瞥磨磚磬磧禦積穎穆穌穋窺篙簑築篤篛篡篩篦糕糖縊"],
        ["bfa1", "縑縈縛縣縞縝縉縐罹羲翰翱翮耨膳膩膨臻興艘艙蕊蕙蕈蕨蕩蕃蕉蕭蕪蕞螃螟螞螢融衡褪褲褥褫褡親覦諦諺諫諱謀諜諧諮諾謁謂諷諭諳諶諼豫豭貓賴蹄踱踴蹂踹踵輻輯輸輳辨辦遵遴選遲遼遺鄴醒錠錶鋸錳錯錢鋼錫錄錚"],
        ["c040", "錐錦錡錕錮錙閻隧隨險雕霎霑霖霍霓霏靛靜靦鞘頰頸頻頷頭頹頤餐館餞餛餡餚駭駢駱骸骼髻髭鬨鮑鴕鴣鴦鴨鴒鴛默黔龍龜優償儡儲勵嚎嚀嚐嚅嚇"],
        ["c0a1", "嚏壕壓壑壎嬰嬪嬤孺尷屨嶼嶺嶽嶸幫彌徽應懂懇懦懋戲戴擎擊擘擠擰擦擬擱擢擭斂斃曙曖檀檔檄檢檜櫛檣橾檗檐檠歜殮毚氈濘濱濟濠濛濤濫濯澀濬濡濩濕濮濰燧營燮燦燥燭燬燴燠爵牆獰獲璩環璦璨癆療癌盪瞳瞪瞰瞬"],
        ["c140", "瞧瞭矯磷磺磴磯礁禧禪穗窿簇簍篾篷簌篠糠糜糞糢糟糙糝縮績繆縷縲繃縫總縱繅繁縴縹繈縵縿縯罄翳翼聱聲聰聯聳臆臃膺臂臀膿膽臉膾臨舉艱薪"],
        ["c1a1", "薄蕾薜薑薔薯薛薇薨薊虧蟀蟑螳蟒蟆螫螻螺蟈蟋褻褶襄褸褽覬謎謗謙講謊謠謝謄謐豁谿豳賺賽購賸賻趨蹉蹋蹈蹊轄輾轂轅輿避遽還邁邂邀鄹醣醞醜鍍鎂錨鍵鍊鍥鍋錘鍾鍬鍛鍰鍚鍔闊闋闌闈闆隱隸雖霜霞鞠韓顆颶餵騁"],
        ["c240", "駿鮮鮫鮪鮭鴻鴿麋黏點黜黝黛鼾齋叢嚕嚮壙壘嬸彝懣戳擴擲擾攆擺擻擷斷曜朦檳檬櫃檻檸櫂檮檯歟歸殯瀉瀋濾瀆濺瀑瀏燻燼燾燸獷獵璧璿甕癖癘"],
        ["c2a1", "癒瞽瞿瞻瞼礎禮穡穢穠竄竅簫簧簪簞簣簡糧織繕繞繚繡繒繙罈翹翻職聶臍臏舊藏薩藍藐藉薰薺薹薦蟯蟬蟲蟠覆覲觴謨謹謬謫豐贅蹙蹣蹦蹤蹟蹕軀轉轍邇邃邈醫醬釐鎔鎊鎖鎢鎳鎮鎬鎰鎘鎚鎗闔闖闐闕離雜雙雛雞霤鞣鞦"],
        ["c340", "鞭韹額顏題顎顓颺餾餿餽餮馥騎髁鬃鬆魏魎魍鯊鯉鯽鯈鯀鵑鵝鵠黠鼕鼬儳嚥壞壟壢寵龐廬懲懷懶懵攀攏曠曝櫥櫝櫚櫓瀛瀟瀨瀚瀝瀕瀘爆爍牘犢獸"],
        ["c3a1", "獺璽瓊瓣疇疆癟癡矇礙禱穫穩簾簿簸簽簷籀繫繭繹繩繪羅繳羶羹羸臘藩藝藪藕藤藥藷蟻蠅蠍蟹蟾襠襟襖襞譁譜識證譚譎譏譆譙贈贊蹼蹲躇蹶蹬蹺蹴轔轎辭邊邋醱醮鏡鏑鏟鏃鏈鏜鏝鏖鏢鏍鏘鏤鏗鏨關隴難霪霧靡韜韻類"],
        ["c440", "願顛颼饅饉騖騙鬍鯨鯧鯖鯛鶉鵡鵲鵪鵬麒麗麓麴勸嚨嚷嚶嚴嚼壤孀孃孽寶巉懸懺攘攔攙曦朧櫬瀾瀰瀲爐獻瓏癢癥礦礪礬礫竇競籌籃籍糯糰辮繽繼"],
        ["c4a1", "纂罌耀臚艦藻藹蘑藺蘆蘋蘇蘊蠔蠕襤覺觸議譬警譯譟譫贏贍躉躁躅躂醴釋鐘鐃鏽闡霰飄饒饑馨騫騰騷騵鰓鰍鹹麵黨鼯齟齣齡儷儸囁囀囂夔屬巍懼懾攝攜斕曩櫻欄櫺殲灌爛犧瓖瓔癩矓籐纏續羼蘗蘭蘚蠣蠢蠡蠟襪襬覽譴"],
        ["c540", "護譽贓躊躍躋轟辯醺鐮鐳鐵鐺鐸鐲鐫闢霸霹露響顧顥饗驅驃驀騾髏魔魑鰭鰥鶯鶴鷂鶸麝黯鼙齜齦齧儼儻囈囊囉孿巔巒彎懿攤權歡灑灘玀瓤疊癮癬"],
        ["c5a1", "禳籠籟聾聽臟襲襯觼讀贖贗躑躓轡酈鑄鑑鑒霽霾韃韁顫饕驕驍髒鬚鱉鰱鰾鰻鷓鷗鼴齬齪龔囌巖戀攣攫攪曬欐瓚竊籤籣籥纓纖纔臢蘸蘿蠱變邐邏鑣鑠鑤靨顯饜驚驛驗髓體髑鱔鱗鱖鷥麟黴囑壩攬灞癱癲矗罐羈蠶蠹衢讓讒"],
        ["c640", "讖艷贛釀鑪靂靈靄韆顰驟鬢魘鱟鷹鷺鹼鹽鼇齷齲廳欖灣籬籮蠻觀躡釁鑲鑰顱饞髖鬣黌灤矚讚鑷韉驢驥纜讜躪釅鑽鑾鑼鱷鱸黷豔鑿鸚爨驪鬱鸛鸞籲"],
        ["c940", "乂乜凵匚厂万丌乇亍囗兀屮彳丏冇与丮亓仂仉仈冘勼卬厹圠夃夬尐巿旡殳毌气爿丱丼仨仜仩仡仝仚刌匜卌圢圣夗夯宁宄尒尻屴屳帄庀庂忉戉扐氕"],
        ["c9a1", "氶汃氿氻犮犰玊禸肊阞伎优伬仵伔仱伀价伈伝伂伅伢伓伄仴伒冱刓刉刐劦匢匟卍厊吇囡囟圮圪圴夼妀奼妅奻奾奷奿孖尕尥屼屺屻屾巟幵庄异弚彴忕忔忏扜扞扤扡扦扢扙扠扚扥旯旮朾朹朸朻机朿朼朳氘汆汒汜汏汊汔汋"],
        ["ca40", "汌灱牞犴犵玎甪癿穵网艸艼芀艽艿虍襾邙邗邘邛邔阢阤阠阣佖伻佢佉体佤伾佧佒佟佁佘伭伳伿佡冏冹刜刞刡劭劮匉卣卲厎厏吰吷吪呔呅吙吜吥吘"],
        ["caa1", "吽呏呁吨吤呇囮囧囥坁坅坌坉坋坒夆奀妦妘妠妗妎妢妐妏妧妡宎宒尨尪岍岏岈岋岉岒岊岆岓岕巠帊帎庋庉庌庈庍弅弝彸彶忒忑忐忭忨忮忳忡忤忣忺忯忷忻怀忴戺抃抌抎抏抔抇扱扻扺扰抁抈扷扽扲扴攷旰旴旳旲旵杅杇"],
        ["cb40", "杙杕杌杈杝杍杚杋毐氙氚汸汧汫沄沋沏汱汯汩沚汭沇沕沜汦汳汥汻沎灴灺牣犿犽狃狆狁犺狅玕玗玓玔玒町甹疔疕皁礽耴肕肙肐肒肜芐芏芅芎芑芓"],
        ["cba1", "芊芃芄豸迉辿邟邡邥邞邧邠阰阨阯阭丳侘佼侅佽侀侇佶佴侉侄佷佌侗佪侚佹侁佸侐侜侔侞侒侂侕佫佮冞冼冾刵刲刳剆刱劼匊匋匼厒厔咇呿咁咑咂咈呫呺呾呥呬呴呦咍呯呡呠咘呣呧呤囷囹坯坲坭坫坱坰坶垀坵坻坳坴坢"],
        ["cc40", "坨坽夌奅妵妺姏姎妲姌姁妶妼姃姖妱妽姀姈妴姇孢孥宓宕屄屇岮岤岠岵岯岨岬岟岣岭岢岪岧岝岥岶岰岦帗帔帙弨弢弣弤彔徂彾彽忞忥怭怦怙怲怋"],
        ["cca1", "怴怊怗怳怚怞怬怢怍怐怮怓怑怌怉怜戔戽抭抴拑抾抪抶拊抮抳抯抻抩抰抸攽斨斻昉旼昄昒昈旻昃昋昍昅旽昑昐曶朊枅杬枎枒杶杻枘枆构杴枍枌杺枟枑枙枃杽极杸杹枔欥殀歾毞氝沓泬泫泮泙沶泔沭泧沷泐泂沺泃泆泭泲"],
        ["cd40", "泒泝沴沊沝沀泞泀洰泍泇沰泹泏泩泑炔炘炅炓炆炄炑炖炂炚炃牪狖狋狘狉狜狒狔狚狌狑玤玡玭玦玢玠玬玝瓝瓨甿畀甾疌疘皯盳盱盰盵矸矼矹矻矺"],
        ["cda1", "矷祂礿秅穸穻竻籵糽耵肏肮肣肸肵肭舠芠苀芫芚芘芛芵芧芮芼芞芺芴芨芡芩苂芤苃芶芢虰虯虭虮豖迒迋迓迍迖迕迗邲邴邯邳邰阹阽阼阺陃俍俅俓侲俉俋俁俔俜俙侻侳俛俇俖侺俀侹俬剄剉勀勂匽卼厗厖厙厘咺咡咭咥哏"],
        ["ce40", "哃茍咷咮哖咶哅哆咠呰咼咢咾呲哞咰垵垞垟垤垌垗垝垛垔垘垏垙垥垚垕壴复奓姡姞姮娀姱姝姺姽姼姶姤姲姷姛姩姳姵姠姾姴姭宨屌峐峘峌峗峋峛"],
        ["cea1", "峞峚峉峇峊峖峓峔峏峈峆峎峟峸巹帡帢帣帠帤庰庤庢庛庣庥弇弮彖徆怷怹恔恲恞恅恓恇恉恛恌恀恂恟怤恄恘恦恮扂扃拏挍挋拵挎挃拫拹挏挌拸拶挀挓挔拺挕拻拰敁敃斪斿昶昡昲昵昜昦昢昳昫昺昝昴昹昮朏朐柁柲柈枺"],
        ["cf40", "柜枻柸柘柀枷柅柫柤柟枵柍枳柷柶柮柣柂枹柎柧柰枲柼柆柭柌枮柦柛柺柉柊柃柪柋欨殂殄殶毖毘毠氠氡洨洴洭洟洼洿洒洊泚洳洄洙洺洚洑洀洝浂"],
        ["cfa1", "洁洘洷洃洏浀洇洠洬洈洢洉洐炷炟炾炱炰炡炴炵炩牁牉牊牬牰牳牮狊狤狨狫狟狪狦狣玅珌珂珈珅玹玶玵玴珫玿珇玾珃珆玸珋瓬瓮甮畇畈疧疪癹盄眈眃眄眅眊盷盻盺矧矨砆砑砒砅砐砏砎砉砃砓祊祌祋祅祄秕种秏秖秎窀"],
        ["d040", "穾竑笀笁籺籸籹籿粀粁紃紈紁罘羑羍羾耇耎耏耔耷胘胇胠胑胈胂胐胅胣胙胜胊胕胉胏胗胦胍臿舡芔苙苾苹茇苨茀苕茺苫苖苴苬苡苲苵茌苻苶苰苪"],
        ["d0a1", "苤苠苺苳苭虷虴虼虳衁衎衧衪衩觓訄訇赲迣迡迮迠郱邽邿郕郅邾郇郋郈釔釓陔陏陑陓陊陎倞倅倇倓倢倰倛俵俴倳倷倬俶俷倗倜倠倧倵倯倱倎党冔冓凊凄凅凈凎剡剚剒剞剟剕剢勍匎厞唦哢唗唒哧哳哤唚哿唄唈哫唑唅哱"],
        ["d140", "唊哻哷哸哠唎唃唋圁圂埌堲埕埒垺埆垽垼垸垶垿埇埐垹埁夎奊娙娖娭娮娕娏娗娊娞娳孬宧宭宬尃屖屔峬峿峮峱峷崀峹帩帨庨庮庪庬弳弰彧恝恚恧"],
        ["d1a1", "恁悢悈悀悒悁悝悃悕悛悗悇悜悎戙扆拲挐捖挬捄捅挶捃揤挹捋捊挼挩捁挴捘捔捙挭捇挳捚捑挸捗捀捈敊敆旆旃旄旂晊晟晇晑朒朓栟栚桉栲栳栻桋桏栖栱栜栵栫栭栯桎桄栴栝栒栔栦栨栮桍栺栥栠欬欯欭欱欴歭肂殈毦毤"],
        ["d240", "毨毣毢毧氥浺浣浤浶洍浡涒浘浢浭浯涑涍淯浿涆浞浧浠涗浰浼浟涂涘洯浨涋浾涀涄洖涃浻浽浵涐烜烓烑烝烋缹烢烗烒烞烠烔烍烅烆烇烚烎烡牂牸"],
        ["d2a1", "牷牶猀狺狴狾狶狳狻猁珓珙珥珖玼珧珣珩珜珒珛珔珝珚珗珘珨瓞瓟瓴瓵甡畛畟疰痁疻痄痀疿疶疺皊盉眝眛眐眓眒眣眑眕眙眚眢眧砣砬砢砵砯砨砮砫砡砩砳砪砱祔祛祏祜祓祒祑秫秬秠秮秭秪秜秞秝窆窉窅窋窌窊窇竘笐"],
        ["d340", "笄笓笅笏笈笊笎笉笒粄粑粊粌粈粍粅紞紝紑紎紘紖紓紟紒紏紌罜罡罞罠罝罛羖羒翃翂翀耖耾耹胺胲胹胵脁胻脀舁舯舥茳茭荄茙荑茥荖茿荁茦茜茢"],
        ["d3a1", "荂荎茛茪茈茼荍茖茤茠茷茯茩荇荅荌荓茞茬荋茧荈虓虒蚢蚨蚖蚍蚑蚞蚇蚗蚆蚋蚚蚅蚥蚙蚡蚧蚕蚘蚎蚝蚐蚔衃衄衭衵衶衲袀衱衿衯袃衾衴衼訒豇豗豻貤貣赶赸趵趷趶軑軓迾迵适迿迻逄迼迶郖郠郙郚郣郟郥郘郛郗郜郤酐"],
        ["d440", "酎酏釕釢釚陜陟隼飣髟鬯乿偰偪偡偞偠偓偋偝偲偈偍偁偛偊偢倕偅偟偩偫偣偤偆偀偮偳偗偑凐剫剭剬剮勖勓匭厜啵啶唼啍啐唴唪啑啢唶唵唰啒啅"],
        ["d4a1", "唌唲啥啎唹啈唭唻啀啋圊圇埻堔埢埶埜埴堀埭埽堈埸堋埳埏堇埮埣埲埥埬埡堎埼堐埧堁堌埱埩埰堍堄奜婠婘婕婧婞娸娵婭婐婟婥婬婓婤婗婃婝婒婄婛婈媎娾婍娹婌婰婩婇婑婖婂婜孲孮寁寀屙崞崋崝崚崠崌崨崍崦崥崏"],
        ["d540", "崰崒崣崟崮帾帴庱庴庹庲庳弶弸徛徖徟悊悐悆悾悰悺惓惔惏惤惙惝惈悱惛悷惊悿惃惍惀挲捥掊掂捽掽掞掭掝掗掫掎捯掇掐据掯捵掜捭掮捼掤挻掟"],
        ["d5a1", "捸掅掁掑掍捰敓旍晥晡晛晙晜晢朘桹梇梐梜桭桮梮梫楖桯梣梬梩桵桴梲梏桷梒桼桫桲梪梀桱桾梛梖梋梠梉梤桸桻梑梌梊桽欶欳欷欸殑殏殍殎殌氪淀涫涴涳湴涬淩淢涷淶淔渀淈淠淟淖涾淥淜淝淛淴淊涽淭淰涺淕淂淏淉"],
        ["d640", "淐淲淓淽淗淍淣涻烺焍烷焗烴焌烰焄烳焐烼烿焆焓焀烸烶焋焂焎牾牻牼牿猝猗猇猑猘猊猈狿猏猞玈珶珸珵琄琁珽琇琀珺珼珿琌琋珴琈畤畣痎痒痏"],
        ["d6a1", "痋痌痑痐皏皉盓眹眯眭眱眲眴眳眽眥眻眵硈硒硉硍硊硌砦硅硐祤祧祩祪祣祫祡离秺秸秶秷窏窔窐笵筇笴笥笰笢笤笳笘笪笝笱笫笭笯笲笸笚笣粔粘粖粣紵紽紸紶紺絅紬紩絁絇紾紿絊紻紨罣羕羜羝羛翊翋翍翐翑翇翏翉耟"],
        ["d740", "耞耛聇聃聈脘脥脙脛脭脟脬脞脡脕脧脝脢舑舸舳舺舴舲艴莐莣莨莍荺荳莤荴莏莁莕莙荵莔莩荽莃莌莝莛莪莋荾莥莯莈莗莰荿莦莇莮荶莚虙虖蚿蚷"],
        ["d7a1", "蛂蛁蛅蚺蚰蛈蚹蚳蚸蛌蚴蚻蚼蛃蚽蚾衒袉袕袨袢袪袚袑袡袟袘袧袙袛袗袤袬袌袓袎覂觖觙觕訰訧訬訞谹谻豜豝豽貥赽赻赹趼跂趹趿跁軘軞軝軜軗軠軡逤逋逑逜逌逡郯郪郰郴郲郳郔郫郬郩酖酘酚酓酕釬釴釱釳釸釤釹釪"],
        ["d840", "釫釷釨釮镺閆閈陼陭陫陱陯隿靪頄飥馗傛傕傔傞傋傣傃傌傎傝偨傜傒傂傇兟凔匒匑厤厧喑喨喥喭啷噅喢喓喈喏喵喁喣喒喤啽喌喦啿喕喡喎圌堩堷"],
        ["d8a1", "堙堞堧堣堨埵塈堥堜堛堳堿堶堮堹堸堭堬堻奡媯媔媟婺媢媞婸媦婼媥媬媕媮娷媄媊媗媃媋媩婻婽媌媜媏媓媝寪寍寋寔寑寊寎尌尰崷嵃嵫嵁嵋崿崵嵑嵎嵕崳崺嵒崽崱嵙嵂崹嵉崸崼崲崶嵀嵅幄幁彘徦徥徫惉悹惌惢惎惄愔"],
        ["d940", "惲愊愖愅惵愓惸惼惾惁愃愘愝愐惿愄愋扊掔掱掰揎揥揨揯揃撝揳揊揠揶揕揲揵摡揟掾揝揜揄揘揓揂揇揌揋揈揰揗揙攲敧敪敤敜敨敥斌斝斞斮旐旒"],
        ["d9a1", "晼晬晻暀晱晹晪晲朁椌棓椄棜椪棬棪棱椏棖棷棫棤棶椓椐棳棡椇棌椈楰梴椑棯棆椔棸棐棽棼棨椋椊椗棎棈棝棞棦棴棑椆棔棩椕椥棇欹欻欿欼殔殗殙殕殽毰毲毳氰淼湆湇渟湉溈渼渽湅湢渫渿湁湝湳渜渳湋湀湑渻渃渮湞"],
        ["da40", "湨湜湡渱渨湠湱湫渹渢渰湓湥渧湸湤湷湕湹湒湦渵渶湚焠焞焯烻焮焱焣焥焢焲焟焨焺焛牋牚犈犉犆犅犋猒猋猰猢猱猳猧猲猭猦猣猵猌琮琬琰琫琖"],
        ["daa1", "琚琡琭琱琤琣琝琩琠琲瓻甯畯畬痧痚痡痦痝痟痤痗皕皒盚睆睇睄睍睅睊睎睋睌矞矬硠硤硥硜硭硱硪确硰硩硨硞硢祴祳祲祰稂稊稃稌稄窙竦竤筊笻筄筈筌筎筀筘筅粢粞粨粡絘絯絣絓絖絧絪絏絭絜絫絒絔絩絑絟絎缾缿罥"],
        ["db40", "罦羢羠羡翗聑聏聐胾胔腃腊腒腏腇脽腍脺臦臮臷臸臹舄舼舽舿艵茻菏菹萣菀菨萒菧菤菼菶萐菆菈菫菣莿萁菝菥菘菿菡菋菎菖菵菉萉萏菞萑萆菂菳"],
        ["dba1", "菕菺菇菑菪萓菃菬菮菄菻菗菢萛菛菾蛘蛢蛦蛓蛣蛚蛪蛝蛫蛜蛬蛩蛗蛨蛑衈衖衕袺裗袹袸裀袾袶袼袷袽袲褁裉覕覘覗觝觚觛詎詍訹詙詀詗詘詄詅詒詈詑詊詌詏豟貁貀貺貾貰貹貵趄趀趉跘跓跍跇跖跜跏跕跙跈跗跅軯軷軺"],
        ["dc40", "軹軦軮軥軵軧軨軶軫軱軬軴軩逭逴逯鄆鄬鄄郿郼鄈郹郻鄁鄀鄇鄅鄃酡酤酟酢酠鈁鈊鈥鈃鈚鈦鈏鈌鈀鈒釿釽鈆鈄鈧鈂鈜鈤鈙鈗鈅鈖镻閍閌閐隇陾隈"],
        ["dca1", "隉隃隀雂雈雃雱雰靬靰靮頇颩飫鳦黹亃亄亶傽傿僆傮僄僊傴僈僂傰僁傺傱僋僉傶傸凗剺剸剻剼嗃嗛嗌嗐嗋嗊嗝嗀嗔嗄嗩喿嗒喍嗏嗕嗢嗖嗈嗲嗍嗙嗂圔塓塨塤塏塍塉塯塕塎塝塙塥塛堽塣塱壼嫇嫄嫋媺媸媱媵媰媿嫈媻嫆"],
        ["dd40", "媷嫀嫊媴媶嫍媹媐寖寘寙尟尳嵱嵣嵊嵥嵲嵬嵞嵨嵧嵢巰幏幎幊幍幋廅廌廆廋廇彀徯徭惷慉慊愫慅愶愲愮慆愯慏愩慀戠酨戣戥戤揅揱揫搐搒搉搠搤"],
        ["dda1", "搳摃搟搕搘搹搷搢搣搌搦搰搨摁搵搯搊搚摀搥搧搋揧搛搮搡搎敯斒旓暆暌暕暐暋暊暙暔晸朠楦楟椸楎楢楱椿楅楪椹楂楗楙楺楈楉椵楬椳椽楥棰楸椴楩楀楯楄楶楘楁楴楌椻楋椷楜楏楑椲楒椯楻椼歆歅歃歂歈歁殛嗀毻毼"],
        ["de40", "毹毷毸溛滖滈溏滀溟溓溔溠溱溹滆滒溽滁溞滉溷溰滍溦滏溲溾滃滜滘溙溒溎溍溤溡溿溳滐滊溗溮溣煇煔煒煣煠煁煝煢煲煸煪煡煂煘煃煋煰煟煐煓"],
        ["dea1", "煄煍煚牏犍犌犑犐犎猼獂猻猺獀獊獉瑄瑊瑋瑒瑑瑗瑀瑏瑐瑎瑂瑆瑍瑔瓡瓿瓾瓽甝畹畷榃痯瘏瘃痷痾痼痹痸瘐痻痶痭痵痽皙皵盝睕睟睠睒睖睚睩睧睔睙睭矠碇碚碔碏碄碕碅碆碡碃硹碙碀碖硻祼禂祽祹稑稘稙稒稗稕稢稓"],
        ["df40", "稛稐窣窢窞竫筦筤筭筴筩筲筥筳筱筰筡筸筶筣粲粴粯綈綆綀綍絿綅絺綎絻綃絼綌綔綄絽綒罭罫罧罨罬羦羥羧翛翜耡腤腠腷腜腩腛腢腲朡腞腶腧腯"],
        ["dfa1", "腄腡舝艉艄艀艂艅蓱萿葖葶葹蒏蒍葥葑葀蒆葧萰葍葽葚葙葴葳葝蔇葞萷萺萴葺葃葸萲葅萩菙葋萯葂萭葟葰萹葎葌葒葯蓅蒎萻葇萶萳葨葾葄萫葠葔葮葐蜋蜄蛷蜌蛺蛖蛵蝍蛸蜎蜉蜁蛶蜍蜅裖裋裍裎裞裛裚裌裐覅覛觟觥觤"],
        ["e040", "觡觠觢觜触詶誆詿詡訿詷誂誄詵誃誁詴詺谼豋豊豥豤豦貆貄貅賌赨赩趑趌趎趏趍趓趔趐趒跰跠跬跱跮跐跩跣跢跧跲跫跴輆軿輁輀輅輇輈輂輋遒逿"],
        ["e0a1", "遄遉逽鄐鄍鄏鄑鄖鄔鄋鄎酮酯鉈鉒鈰鈺鉦鈳鉥鉞銃鈮鉊鉆鉭鉬鉏鉠鉧鉯鈶鉡鉰鈱鉔鉣鉐鉲鉎鉓鉌鉖鈲閟閜閞閛隒隓隑隗雎雺雽雸雵靳靷靸靲頏頍頎颬飶飹馯馲馰馵骭骫魛鳪鳭鳧麀黽僦僔僗僨僳僛僪僝僤僓僬僰僯僣僠"],
        ["e140", "凘劀劁勩勫匰厬嘧嘕嘌嘒嗼嘏嘜嘁嘓嘂嗺嘝嘄嗿嗹墉塼墐墘墆墁塿塴墋塺墇墑墎塶墂墈塻墔墏壾奫嫜嫮嫥嫕嫪嫚嫭嫫嫳嫢嫠嫛嫬嫞嫝嫙嫨嫟孷寠"],
        ["e1a1", "寣屣嶂嶀嵽嶆嵺嶁嵷嶊嶉嶈嵾嵼嶍嵹嵿幘幙幓廘廑廗廎廜廕廙廒廔彄彃彯徶愬愨慁慞慱慳慒慓慲慬憀慴慔慺慛慥愻慪慡慖戩戧戫搫摍摛摝摴摶摲摳摽摵摦撦摎撂摞摜摋摓摠摐摿搿摬摫摙摥摷敳斠暡暠暟朅朄朢榱榶槉"],
        ["e240", "榠槎榖榰榬榼榑榙榎榧榍榩榾榯榿槄榽榤槔榹槊榚槏榳榓榪榡榞槙榗榐槂榵榥槆歊歍歋殞殟殠毃毄毾滎滵滱漃漥滸漷滻漮漉潎漙漚漧漘漻漒滭漊"],
        ["e2a1", "漶潳滹滮漭潀漰漼漵滫漇漎潃漅滽滶漹漜滼漺漟漍漞漈漡熇熐熉熀熅熂熏煻熆熁熗牄牓犗犕犓獃獍獑獌瑢瑳瑱瑵瑲瑧瑮甀甂甃畽疐瘖瘈瘌瘕瘑瘊瘔皸瞁睼瞅瞂睮瞀睯睾瞃碲碪碴碭碨硾碫碞碥碠碬碢碤禘禊禋禖禕禔禓"],
        ["e340", "禗禈禒禐稫穊稰稯稨稦窨窫窬竮箈箜箊箑箐箖箍箌箛箎箅箘劄箙箤箂粻粿粼粺綧綷緂綣綪緁緀緅綝緎緄緆緋緌綯綹綖綼綟綦綮綩綡緉罳翢翣翥翞"],
        ["e3a1", "耤聝聜膉膆膃膇膍膌膋舕蒗蒤蒡蒟蒺蓎蓂蒬蒮蒫蒹蒴蓁蓍蒪蒚蒱蓐蒝蒧蒻蒢蒔蓇蓌蒛蒩蒯蒨蓖蒘蒶蓏蒠蓗蓔蓒蓛蒰蒑虡蜳蜣蜨蝫蝀蜮蜞蜡蜙蜛蝃蜬蝁蜾蝆蜠蜲蜪蜭蜼蜒蜺蜱蜵蝂蜦蜧蜸蜤蜚蜰蜑裷裧裱裲裺裾裮裼裶裻"],
        ["e440", "裰裬裫覝覡覟覞觩觫觨誫誙誋誒誏誖谽豨豩賕賏賗趖踉踂跿踍跽踊踃踇踆踅跾踀踄輐輑輎輍鄣鄜鄠鄢鄟鄝鄚鄤鄡鄛酺酲酹酳銥銤鉶銛鉺銠銔銪銍"],
        ["e4a1", "銦銚銫鉹銗鉿銣鋮銎銂銕銢鉽銈銡銊銆銌銙銧鉾銇銩銝銋鈭隞隡雿靘靽靺靾鞃鞀鞂靻鞄鞁靿韎韍頖颭颮餂餀餇馝馜駃馹馻馺駂馽駇骱髣髧鬾鬿魠魡魟鳱鳲鳵麧僿儃儰僸儆儇僶僾儋儌僽儊劋劌勱勯噈噂噌嘵噁噊噉噆噘"],
        ["e540", "噚噀嘳嘽嘬嘾嘸嘪嘺圚墫墝墱墠墣墯墬墥墡壿嫿嫴嫽嫷嫶嬃嫸嬂嫹嬁嬇嬅嬏屧嶙嶗嶟嶒嶢嶓嶕嶠嶜嶡嶚嶞幩幝幠幜緳廛廞廡彉徲憋憃慹憱憰憢憉"],
        ["e5a1", "憛憓憯憭憟憒憪憡憍慦憳戭摮摰撖撠撅撗撜撏撋撊撌撣撟摨撱撘敶敺敹敻斲斳暵暰暩暲暷暪暯樀樆樗槥槸樕槱槤樠槿槬槢樛樝槾樧槲槮樔槷槧橀樈槦槻樍槼槫樉樄樘樥樏槶樦樇槴樖歑殥殣殢殦氁氀毿氂潁漦潾澇濆澒"],
        ["e640", "澍澉澌潢潏澅潚澖潶潬澂潕潲潒潐潗澔澓潝漀潡潫潽潧澐潓澋潩潿澕潣潷潪潻熲熯熛熰熠熚熩熵熝熥熞熤熡熪熜熧熳犘犚獘獒獞獟獠獝獛獡獚獙"],
        ["e6a1", "獢璇璉璊璆璁瑽璅璈瑼瑹甈甇畾瘥瘞瘙瘝瘜瘣瘚瘨瘛皜皝皞皛瞍瞏瞉瞈磍碻磏磌磑磎磔磈磃磄磉禚禡禠禜禢禛歶稹窲窴窳箷篋箾箬篎箯箹篊箵糅糈糌糋緷緛緪緧緗緡縃緺緦緶緱緰緮緟罶羬羰羭翭翫翪翬翦翨聤聧膣膟"],
        ["e740", "膞膕膢膙膗舖艏艓艒艐艎艑蔤蔻蔏蔀蔩蔎蔉蔍蔟蔊蔧蔜蓻蔫蓺蔈蔌蓴蔪蓲蔕蓷蓫蓳蓼蔒蓪蓩蔖蓾蔨蔝蔮蔂蓽蔞蓶蔱蔦蓧蓨蓰蓯蓹蔘蔠蔰蔋蔙蔯虢"],
        ["e7a1", "蝖蝣蝤蝷蟡蝳蝘蝔蝛蝒蝡蝚蝑蝞蝭蝪蝐蝎蝟蝝蝯蝬蝺蝮蝜蝥蝏蝻蝵蝢蝧蝩衚褅褌褔褋褗褘褙褆褖褑褎褉覢覤覣觭觰觬諏諆誸諓諑諔諕誻諗誾諀諅諘諃誺誽諙谾豍貏賥賟賙賨賚賝賧趠趜趡趛踠踣踥踤踮踕踛踖踑踙踦踧"],
        ["e840", "踔踒踘踓踜踗踚輬輤輘輚輠輣輖輗遳遰遯遧遫鄯鄫鄩鄪鄲鄦鄮醅醆醊醁醂醄醀鋐鋃鋄鋀鋙銶鋏鋱鋟鋘鋩鋗鋝鋌鋯鋂鋨鋊鋈鋎鋦鋍鋕鋉鋠鋞鋧鋑鋓"],
        ["e8a1", "銵鋡鋆銴镼閬閫閮閰隤隢雓霅霈霂靚鞊鞎鞈韐韏頞頝頦頩頨頠頛頧颲餈飺餑餔餖餗餕駜駍駏駓駔駎駉駖駘駋駗駌骳髬髫髳髲髱魆魃魧魴魱魦魶魵魰魨魤魬鳼鳺鳽鳿鳷鴇鴀鳹鳻鴈鴅鴄麃黓鼏鼐儜儓儗儚儑凞匴叡噰噠噮"],
        ["e940", "噳噦噣噭噲噞噷圜圛壈墽壉墿墺壂墼壆嬗嬙嬛嬡嬔嬓嬐嬖嬨嬚嬠嬞寯嶬嶱嶩嶧嶵嶰嶮嶪嶨嶲嶭嶯嶴幧幨幦幯廩廧廦廨廥彋徼憝憨憖懅憴懆懁懌憺"],
        ["e9a1", "憿憸憌擗擖擐擏擉撽撉擃擛擳擙攳敿敼斢曈暾曀曊曋曏暽暻暺曌朣樴橦橉橧樲橨樾橝橭橶橛橑樨橚樻樿橁橪橤橐橏橔橯橩橠樼橞橖橕橍橎橆歕歔歖殧殪殫毈毇氄氃氆澭濋澣濇澼濎濈潞濄澽澞濊澨瀄澥澮澺澬澪濏澿澸"],
        ["ea40", "澢濉澫濍澯澲澰燅燂熿熸燖燀燁燋燔燊燇燏熽燘熼燆燚燛犝犞獩獦獧獬獥獫獪瑿璚璠璔璒璕璡甋疀瘯瘭瘱瘽瘳瘼瘵瘲瘰皻盦瞚瞝瞡瞜瞛瞢瞣瞕瞙"],
        ["eaa1", "瞗磝磩磥磪磞磣磛磡磢磭磟磠禤穄穈穇窶窸窵窱窷篞篣篧篝篕篥篚篨篹篔篪篢篜篫篘篟糒糔糗糐糑縒縡縗縌縟縠縓縎縜縕縚縢縋縏縖縍縔縥縤罃罻罼罺羱翯耪耩聬膱膦膮膹膵膫膰膬膴膲膷膧臲艕艖艗蕖蕅蕫蕍蕓蕡蕘"],
        ["eb40", "蕀蕆蕤蕁蕢蕄蕑蕇蕣蔾蕛蕱蕎蕮蕵蕕蕧蕠薌蕦蕝蕔蕥蕬虣虥虤螛螏螗螓螒螈螁螖螘蝹螇螣螅螐螑螝螄螔螜螚螉褞褦褰褭褮褧褱褢褩褣褯褬褟觱諠"],
        ["eba1", "諢諲諴諵諝謔諤諟諰諈諞諡諨諿諯諻貑貒貐賵賮賱賰賳赬赮趥趧踳踾踸蹀蹅踶踼踽蹁踰踿躽輶輮輵輲輹輷輴遶遹遻邆郺鄳鄵鄶醓醐醑醍醏錧錞錈錟錆錏鍺錸錼錛錣錒錁鍆錭錎錍鋋錝鋺錥錓鋹鋷錴錂錤鋿錩錹錵錪錔錌"],
        ["ec40", "錋鋾錉錀鋻錖閼闍閾閹閺閶閿閵閽隩雔霋霒霐鞙鞗鞔韰韸頵頯頲餤餟餧餩馞駮駬駥駤駰駣駪駩駧骹骿骴骻髶髺髹髷鬳鮀鮅鮇魼魾魻鮂鮓鮒鮐魺鮕"],
        ["eca1", "魽鮈鴥鴗鴠鴞鴔鴩鴝鴘鴢鴐鴙鴟麈麆麇麮麭黕黖黺鼒鼽儦儥儢儤儠儩勴嚓嚌嚍嚆嚄嚃噾嚂噿嚁壖壔壏壒嬭嬥嬲嬣嬬嬧嬦嬯嬮孻寱寲嶷幬幪徾徻懃憵憼懧懠懥懤懨懞擯擩擣擫擤擨斁斀斶旚曒檍檖檁檥檉檟檛檡檞檇檓檎"],
        ["ed40", "檕檃檨檤檑橿檦檚檅檌檒歛殭氉濌澩濴濔濣濜濭濧濦濞濲濝濢濨燡燱燨燲燤燰燢獳獮獯璗璲璫璐璪璭璱璥璯甐甑甒甏疄癃癈癉癇皤盩瞵瞫瞲瞷瞶"],
        ["eda1", "瞴瞱瞨矰磳磽礂磻磼磲礅磹磾礄禫禨穜穛穖穘穔穚窾竀竁簅簏篲簀篿篻簎篴簋篳簂簉簃簁篸篽簆篰篱簐簊糨縭縼繂縳顈縸縪繉繀繇縩繌縰縻縶繄縺罅罿罾罽翴翲耬膻臄臌臊臅臇膼臩艛艚艜薃薀薏薧薕薠薋薣蕻薤薚薞"],
        ["ee40", "蕷蕼薉薡蕺蕸蕗薎薖薆薍薙薝薁薢薂薈薅蕹蕶薘薐薟虨螾螪螭蟅螰螬螹螵螼螮蟉蟃蟂蟌螷螯蟄蟊螴螶螿螸螽蟞螲褵褳褼褾襁襒褷襂覭覯覮觲觳謞"],
        ["eea1", "謘謖謑謅謋謢謏謒謕謇謍謈謆謜謓謚豏豰豲豱豯貕貔賹赯蹎蹍蹓蹐蹌蹇轃轀邅遾鄸醚醢醛醙醟醡醝醠鎡鎃鎯鍤鍖鍇鍼鍘鍜鍶鍉鍐鍑鍠鍭鎏鍌鍪鍹鍗鍕鍒鍏鍱鍷鍻鍡鍞鍣鍧鎀鍎鍙闇闀闉闃闅閷隮隰隬霠霟霘霝霙鞚鞡鞜"],
        ["ef40", "鞞鞝韕韔韱顁顄顊顉顅顃餥餫餬餪餳餲餯餭餱餰馘馣馡騂駺駴駷駹駸駶駻駽駾駼騃骾髾髽鬁髼魈鮚鮨鮞鮛鮦鮡鮥鮤鮆鮢鮠鮯鴳鵁鵧鴶鴮鴯鴱鴸鴰"],
        ["efa1", "鵅鵂鵃鴾鴷鵀鴽翵鴭麊麉麍麰黈黚黻黿鼤鼣鼢齔龠儱儭儮嚘嚜嚗嚚嚝嚙奰嬼屩屪巀幭幮懘懟懭懮懱懪懰懫懖懩擿攄擽擸攁攃擼斔旛曚曛曘櫅檹檽櫡櫆檺檶檷櫇檴檭歞毉氋瀇瀌瀍瀁瀅瀔瀎濿瀀濻瀦濼濷瀊爁燿燹爃燽獶"],
        ["f040", "璸瓀璵瓁璾璶璻瓂甔甓癜癤癙癐癓癗癚皦皽盬矂瞺磿礌礓礔礉礐礒礑禭禬穟簜簩簙簠簟簭簝簦簨簢簥簰繜繐繖繣繘繢繟繑繠繗繓羵羳翷翸聵臑臒"],
        ["f0a1", "臐艟艞薴藆藀藃藂薳薵薽藇藄薿藋藎藈藅薱薶藒蘤薸薷薾虩蟧蟦蟢蟛蟫蟪蟥蟟蟳蟤蟔蟜蟓蟭蟘蟣螤蟗蟙蠁蟴蟨蟝襓襋襏襌襆襐襑襉謪謧謣謳謰謵譇謯謼謾謱謥謷謦謶謮謤謻謽謺豂豵貙貘貗賾贄贂贀蹜蹢蹠蹗蹖蹞蹥蹧"],
        ["f140", "蹛蹚蹡蹝蹩蹔轆轇轈轋鄨鄺鄻鄾醨醥醧醯醪鎵鎌鎒鎷鎛鎝鎉鎧鎎鎪鎞鎦鎕鎈鎙鎟鎍鎱鎑鎲鎤鎨鎴鎣鎥闒闓闑隳雗雚巂雟雘雝霣霢霥鞬鞮鞨鞫鞤鞪"],
        ["f1a1", "鞢鞥韗韙韖韘韺顐顑顒颸饁餼餺騏騋騉騍騄騑騊騅騇騆髀髜鬈鬄鬅鬩鬵魊魌魋鯇鯆鯃鮿鯁鮵鮸鯓鮶鯄鮹鮽鵜鵓鵏鵊鵛鵋鵙鵖鵌鵗鵒鵔鵟鵘鵚麎麌黟鼁鼀鼖鼥鼫鼪鼩鼨齌齕儴儵劖勷厴嚫嚭嚦嚧嚪嚬壚壝壛夒嬽嬾嬿巃幰"],
        ["f240", "徿懻攇攐攍攉攌攎斄旞旝曞櫧櫠櫌櫑櫙櫋櫟櫜櫐櫫櫏櫍櫞歠殰氌瀙瀧瀠瀖瀫瀡瀢瀣瀩瀗瀤瀜瀪爌爊爇爂爅犥犦犤犣犡瓋瓅璷瓃甖癠矉矊矄矱礝礛"],
        ["f2a1", "礡礜礗礞禰穧穨簳簼簹簬簻糬糪繶繵繸繰繷繯繺繲繴繨罋罊羃羆羷翽翾聸臗臕艤艡艣藫藱藭藙藡藨藚藗藬藲藸藘藟藣藜藑藰藦藯藞藢蠀蟺蠃蟶蟷蠉蠌蠋蠆蟼蠈蟿蠊蠂襢襚襛襗襡襜襘襝襙覈覷覶觶譐譈譊譀譓譖譔譋譕"],
        ["f340", "譑譂譒譗豃豷豶貚贆贇贉趬趪趭趫蹭蹸蹳蹪蹯蹻軂轒轑轏轐轓辴酀鄿醰醭鏞鏇鏏鏂鏚鏐鏹鏬鏌鏙鎩鏦鏊鏔鏮鏣鏕鏄鏎鏀鏒鏧镽闚闛雡霩霫霬霨霦"],
        ["f3a1", "鞳鞷鞶韝韞韟顜顙顝顗颿颽颻颾饈饇饃馦馧騚騕騥騝騤騛騢騠騧騣騞騜騔髂鬋鬊鬎鬌鬷鯪鯫鯠鯞鯤鯦鯢鯰鯔鯗鯬鯜鯙鯥鯕鯡鯚鵷鶁鶊鶄鶈鵱鶀鵸鶆鶋鶌鵽鵫鵴鵵鵰鵩鶅鵳鵻鶂鵯鵹鵿鶇鵨麔麑黀黼鼭齀齁齍齖齗齘匷嚲"],
        ["f440", "嚵嚳壣孅巆巇廮廯忀忁懹攗攖攕攓旟曨曣曤櫳櫰櫪櫨櫹櫱櫮櫯瀼瀵瀯瀷瀴瀱灂瀸瀿瀺瀹灀瀻瀳灁爓爔犨獽獼璺皫皪皾盭矌矎矏矍矲礥礣礧礨礤礩"],
        ["f4a1", "禲穮穬穭竷籉籈籊籇籅糮繻繾纁纀羺翿聹臛臙舋艨艩蘢藿蘁藾蘛蘀藶蘄蘉蘅蘌藽蠙蠐蠑蠗蠓蠖襣襦覹觷譠譪譝譨譣譥譧譭趮躆躈躄轙轖轗轕轘轚邍酃酁醷醵醲醳鐋鐓鏻鐠鐏鐔鏾鐕鐐鐨鐙鐍鏵鐀鏷鐇鐎鐖鐒鏺鐉鏸鐊鏿"],
        ["f540", "鏼鐌鏶鐑鐆闞闠闟霮霯鞹鞻韽韾顠顢顣顟飁飂饐饎饙饌饋饓騲騴騱騬騪騶騩騮騸騭髇髊髆鬐鬒鬑鰋鰈鯷鰅鰒鯸鱀鰇鰎鰆鰗鰔鰉鶟鶙鶤鶝鶒鶘鶐鶛"],
        ["f5a1", "鶠鶔鶜鶪鶗鶡鶚鶢鶨鶞鶣鶿鶩鶖鶦鶧麙麛麚黥黤黧黦鼰鼮齛齠齞齝齙龑儺儹劘劗囃嚽嚾孈孇巋巏廱懽攛欂櫼欃櫸欀灃灄灊灈灉灅灆爝爚爙獾甗癪矐礭礱礯籔籓糲纊纇纈纋纆纍罍羻耰臝蘘蘪蘦蘟蘣蘜蘙蘧蘮蘡蘠蘩蘞蘥"],
        ["f640", "蠩蠝蠛蠠蠤蠜蠫衊襭襩襮襫觺譹譸譅譺譻贐贔趯躎躌轞轛轝酆酄酅醹鐿鐻鐶鐩鐽鐼鐰鐹鐪鐷鐬鑀鐱闥闤闣霵霺鞿韡顤飉飆飀饘饖騹騽驆驄驂驁騺"],
        ["f6a1", "騿髍鬕鬗鬘鬖鬺魒鰫鰝鰜鰬鰣鰨鰩鰤鰡鶷鶶鶼鷁鷇鷊鷏鶾鷅鷃鶻鶵鷎鶹鶺鶬鷈鶱鶭鷌鶳鷍鶲鹺麜黫黮黭鼛鼘鼚鼱齎齥齤龒亹囆囅囋奱孋孌巕巑廲攡攠攦攢欋欈欉氍灕灖灗灒爞爟犩獿瓘瓕瓙瓗癭皭礵禴穰穱籗籜籙籛籚"],
        ["f740", "糴糱纑罏羇臞艫蘴蘵蘳蘬蘲蘶蠬蠨蠦蠪蠥襱覿覾觻譾讄讂讆讅譿贕躕躔躚躒躐躖躗轠轢酇鑌鑐鑊鑋鑏鑇鑅鑈鑉鑆霿韣顪顩飋饔饛驎驓驔驌驏驈驊"],
        ["f7a1", "驉驒驐髐鬙鬫鬻魖魕鱆鱈鰿鱄鰹鰳鱁鰼鰷鰴鰲鰽鰶鷛鷒鷞鷚鷋鷐鷜鷑鷟鷩鷙鷘鷖鷵鷕鷝麶黰鼵鼳鼲齂齫龕龢儽劙壨壧奲孍巘蠯彏戁戃戄攩攥斖曫欑欒欏毊灛灚爢玂玁玃癰矔籧籦纕艬蘺虀蘹蘼蘱蘻蘾蠰蠲蠮蠳襶襴襳觾"],
        ["f840", "讌讎讋讈豅贙躘轤轣醼鑢鑕鑝鑗鑞韄韅頀驖驙鬞鬟鬠鱒鱘鱐鱊鱍鱋鱕鱙鱌鱎鷻鷷鷯鷣鷫鷸鷤鷶鷡鷮鷦鷲鷰鷢鷬鷴鷳鷨鷭黂黐黲黳鼆鼜鼸鼷鼶齃齏"],
        ["f8a1", "齱齰齮齯囓囍孎屭攭曭曮欓灟灡灝灠爣瓛瓥矕礸禷禶籪纗羉艭虃蠸蠷蠵衋讔讕躞躟躠躝醾醽釂鑫鑨鑩雥靆靃靇韇韥驞髕魙鱣鱧鱦鱢鱞鱠鸂鷾鸇鸃鸆鸅鸀鸁鸉鷿鷽鸄麠鼞齆齴齵齶囔攮斸欘欙欗欚灢爦犪矘矙礹籩籫糶纚"],
        ["f940", "纘纛纙臠臡虆虇虈襹襺襼襻觿讘讙躥躤躣鑮鑭鑯鑱鑳靉顲饟鱨鱮鱭鸋鸍鸐鸏鸒鸑麡黵鼉齇齸齻齺齹圞灦籯蠼趲躦釃鑴鑸鑶鑵驠鱴鱳鱱鱵鸔鸓黶鼊"],
        ["f9a1", "龤灨灥糷虪蠾蠽蠿讞貜躩軉靋顳顴飌饡馫驤驦驧鬤鸕鸗齈戇欞爧虌躨钂钀钁驩驨鬮鸙爩虋讟钃鱹麷癵驫鱺鸝灩灪麤齾齉龘碁銹裏墻恒粧嫺╔╦╗╠╬╣╚╩╝╒╤╕╞╪╡╘╧╛╓╥╖╟╫╢╙╨╜║═╭╮╰╯▓"]
    ];
    module.exports = json;
},
/* iconv-lite/encodings/tables/big5-added.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = [
        ["8740", "䏰䰲䘃䖦䕸𧉧䵷䖳𧲱䳢𧳅㮕䜶䝄䱇䱀𤊿𣘗𧍒𦺋𧃒䱗𪍑䝏䗚䲅𧱬䴇䪤䚡𦬣爥𥩔𡩣𣸆𣽡晍囻"],
        ["8767", "綕夝𨮹㷴霴𧯯寛𡵞媤㘥𩺰嫑宷峼杮薓𩥅瑡璝㡵𡵓𣚞𦀡㻬"],
        ["87a1", "𥣞㫵竼龗𤅡𨤍𣇪𠪊𣉞䌊蒄龖鐯䤰蘓墖靊鈘秐稲晠権袝瑌篅枂稬剏遆㓦珄𥶹瓆鿇垳䤯呌䄱𣚎堘穲𧭥讏䚮𦺈䆁𥶙箮𢒼鿈𢓁𢓉𢓌鿉蔄𣖻䂴鿊䓡𪷿拁灮鿋"],
        ["8840", "㇀", 4, "𠄌㇅𠃑𠃍㇆㇇𠃋𡿨㇈𠃊㇉㇊㇋㇌𠄎㇍㇎ĀÁǍÀĒÉĚÈŌÓǑÒ࿿Ê̄Ế࿿Ê̌ỀÊāáǎàɑēéěèīíǐìōóǒòūúǔùǖǘǚ"],
        ["88a1", "ǜü࿿ê̄ế࿿ê̌ềêɡ⏚⏛"],
        ["8940", "𪎩𡅅"],
        ["8943", "攊"],
        ["8946", "丽滝鵎釟"],
        ["894c", "𧜵撑会伨侨兖兴农凤务动医华发变团声处备夲头学实実岚庆总斉柾栄桥济炼电纤纬纺织经统缆缷艺苏药视设询车轧轮"],
        ["89a1", "琑糼緍楆竉刧"],
        ["89ab", "醌碸酞肼"],
        ["89b0", "贋胶𠧧"],
        ["89b5", "肟黇䳍鷉鸌䰾𩷶𧀎鸊𪄳㗁"],
        ["89c1", "溚舾甙"],
        ["89c5", "䤑马骏龙禇𨑬𡷊𠗐𢫦两亁亀亇亿仫伷㑌侽㹈倃傈㑽㒓㒥円夅凛凼刅争剹劐匧㗇厩㕑厰㕓参吣㕭㕲㚁咓咣咴咹哐哯唘唣唨㖘唿㖥㖿嗗㗅"],
        ["8a40", "𧶄唥"],
        ["8a43", "𠱂𠴕𥄫喐𢳆㧬𠍁蹆𤶸𩓥䁓𨂾睺𢰸㨴䟕𨅝𦧲𤷪擝𠵼𠾴𠳕𡃴撍蹾𠺖𠰋𠽤𢲩𨉖𤓓"],
        ["8a64", "𠵆𩩍𨃩䟴𤺧𢳂骲㩧𩗴㿭㔆𥋇𩟔𧣈𢵄鵮頕"],
        ["8a76", "䏙𦂥撴哣𢵌𢯊𡁷㧻𡁯"],
        ["8aa1", "𦛚𦜖𧦠擪𥁒𠱃蹨𢆡𨭌𠜱"],
        ["8aac", "䠋𠆩㿺塳𢶍"],
        ["8ab2", "𤗈𠓼𦂗𠽌𠶖啹䂻䎺"],
        ["8abb", "䪴𢩦𡂝膪飵𠶜捹㧾𢝵跀嚡摼㹃"],
        ["8ac9", "𪘁𠸉𢫏𢳉"],
        ["8ace", "𡃈𣧂㦒㨆𨊛㕸𥹉𢃇噒𠼱𢲲𩜠㒼氽𤸻"],
        ["8adf", "𧕴𢺋𢈈𪙛𨳍𠹺𠰴𦠜羓𡃏𢠃𢤹㗻𥇣𠺌𠾍𠺪㾓𠼰𠵇𡅏𠹌"],
        ["8af6", "𠺫𠮩𠵈𡃀𡄽㿹𢚖搲𠾭"],
        ["8b40", "𣏴𧘹𢯎𠵾𠵿𢱑𢱕㨘𠺘𡃇𠼮𪘲𦭐𨳒𨶙𨳊閪哌苄喹"],
        ["8b55", "𩻃鰦骶𧝞𢷮煀腭胬尜𦕲脴㞗卟𨂽醶𠻺𠸏𠹷𠻻㗝𤷫㘉𠳖嚯𢞵𡃉𠸐𠹸𡁸𡅈𨈇𡑕𠹹𤹐𢶤婔𡀝𡀞𡃵𡃶垜𠸑"],
        ["8ba1", "𧚔𨋍𠾵𠹻𥅾㜃𠾶𡆀𥋘𪊽𤧚𡠺𤅷𨉼墙剨㘚𥜽箲孨䠀䬬鼧䧧鰟鮍𥭴𣄽嗻㗲嚉丨夂𡯁屮靑𠂆乛亻㔾尣彑忄㣺扌攵歺氵氺灬爫丬犭𤣩罒礻糹罓𦉪㓁"],
        ["8bde", "𦍋耂肀𦘒𦥑卝衤见𧢲讠贝钅镸长门𨸏韦页风飞饣𩠐鱼鸟黄歯龜丷𠂇阝户钢"],
        ["8c40", "倻淾𩱳龦㷉袏𤅎灷峵䬠𥇍㕙𥴰愢𨨲辧釶熑朙玺𣊁𪄇㲋𡦀䬐磤琂冮𨜏䀉橣𪊺䈣蘏𠩯稪𩥇𨫪靕灍匤𢁾鏴盙𨧣龧矝亣俰傼丯众龨吴綋墒壐𡶶庒庙忂𢜒斋"],
        ["8ca1", "𣏹椙橃𣱣泿"],
        ["8ca7", "爀𤔅玌㻛𤨓嬕璹讃𥲤𥚕窓篬糃繬苸薗龩袐龪躹龫迏蕟駠鈡龬𨶹𡐿䁱䊢娚"],
        ["8cc9", "顨杫䉶圽"],
        ["8cce", "藖𤥻芿𧄍䲁𦵴嵻𦬕𦾾龭龮宖龯曧繛湗秊㶈䓃𣉖𢞖䎚䔶"],
        ["8ce6", "峕𣬚諹屸㴒𣕑嵸龲煗䕘𤃬𡸣䱷㥸㑊𠆤𦱁諌侴𠈹妿腬顖𩣺弻"],
        ["8d40", "𠮟"],
        ["8d42", "𢇁𨥭䄂䚻𩁹㼇龳𪆵䃸㟖䛷𦱆䅼𨚲𧏿䕭㣔𥒚䕡䔛䶉䱻䵶䗪㿈𤬏㙡䓞䒽䇭崾嵈嵖㷼㠏嶤嶹㠠㠸幂庽弥徃㤈㤔㤿㥍惗愽峥㦉憷憹懏㦸戬抐拥挘㧸嚱"],
        ["8da1", "㨃揢揻搇摚㩋擀崕嘡龟㪗斆㪽旿晓㫲暒㬢朖㭂枤栀㭘桊梄㭲㭱㭻椉楃牜楤榟榅㮼槖㯝橥橴橱檂㯬檙㯲檫檵櫔櫶殁毁毪汵沪㳋洂洆洦涁㳯涤涱渕渘温溆𨧀溻滢滚齿滨滩漤漴㵆𣽁澁澾㵪㵵熷岙㶊瀬㶑灐灔灯灿炉𠌥䏁㗱𠻘"],
        ["8e40", "𣻗垾𦻓焾𥟠㙎榢𨯩孴穉𥣡𩓙穥穽𥦬窻窰竂竃燑𦒍䇊竚竝竪䇯咲𥰁笋筕笩𥌎𥳾箢筯莜𥮴𦱿篐萡箒箸𥴠㶭𥱥蒒篺簆簵𥳁籄粃𤢂粦晽𤕸糉糇糦籴糳糵糎"],
        ["8ea1", "繧䔝𦹄絝𦻖璍綉綫焵綳緒𤁗𦀩緤㴓緵𡟹緥𨍭縝𦄡𦅚繮纒䌫鑬縧罀罁罇礶𦋐駡羗𦍑羣𡙡𠁨䕜𣝦䔃𨌺翺𦒉者耈耝耨耯𪂇𦳃耻耼聡𢜔䦉𦘦𣷣𦛨朥肧𨩈脇脚墰𢛶汿𦒘𤾸擧𡒊舘𡡞橓𤩥𤪕䑺舩𠬍𦩒𣵾俹𡓽蓢荢𦬊𤦧𣔰𡝳𣷸芪椛芳䇛"],
        ["8f40", "蕋苐茚𠸖𡞴㛁𣅽𣕚艻苢茘𣺋𦶣𦬅𦮗𣗎㶿茝嗬莅䔋𦶥莬菁菓㑾𦻔橗蕚㒖𦹂𢻯葘𥯤葱㷓䓤檧葊𣲵祘蒨𦮖𦹷𦹃蓞萏莑䒠蒓蓤𥲑䉀𥳀䕃蔴嫲𦺙䔧蕳䔖枿蘖"],
        ["8fa1", "𨘥𨘻藁𧂈蘂𡖂𧃍䕫䕪蘨㙈𡢢号𧎚虾蝱𪃸蟮𢰧螱蟚蠏噡虬桖䘏衅衆𧗠𣶹𧗤衞袜䙛袴袵揁装睷𧜏覇覊覦覩覧覼𨨥觧𧤤𧪽誜瞓釾誐𧩙竩𧬺𣾏䜓𧬸煼謌謟𥐰𥕥謿譌譍誩𤩺讐讛誯𡛟䘕衏貛𧵔𧶏貫㜥𧵓賖𧶘𧶽贒贃𡤐賛灜贑𤳉㻐起"],
        ["9040", "趩𨀂𡀔𤦊㭼𨆼𧄌竧躭躶軃鋔輙輭𨍥𨐒辥錃𪊟𠩐辳䤪𨧞𨔽𣶻廸𣉢迹𪀔𨚼𨔁𢌥㦀𦻗逷𨔼𧪾遡𨕬𨘋邨𨜓郄𨛦邮都酧㫰醩釄粬𨤳𡺉鈎沟鉁鉢𥖹銹𨫆𣲛𨬌𥗛"],
        ["90a1", "𠴱錬鍫𨫡𨯫炏嫃𨫢𨫥䥥鉄𨯬𨰹𨯿鍳鑛躼閅閦鐦閠濶䊹𢙺𨛘𡉼𣸮䧟氜陻隖䅬隣𦻕懚隶磵𨫠隽双䦡𦲸𠉴𦐐𩂯𩃥𤫑𡤕𣌊霱虂霶䨏䔽䖅𤫩灵孁霛靜𩇕靗孊𩇫靟鐥僐𣂷𣂼鞉鞟鞱鞾韀韒韠𥑬韮琜𩐳響韵𩐝𧥺䫑頴頳顋顦㬎𧅵㵑𠘰𤅜"],
        ["9140", "𥜆飊颷飈飇䫿𦴧𡛓喰飡飦飬鍸餹𤨩䭲𩡗𩤅駵騌騻騐驘𥜥㛄𩂱𩯕髠髢𩬅髴䰎鬔鬭𨘀倴鬴𦦨㣃𣁽魐魀𩴾婅𡡣鮎𤉋鰂鯿鰌𩹨鷔𩾷𪆒𪆫𪃡𪄣𪇟鵾鶃𪄴鸎梈"],
        ["91a1", "鷄𢅛𪆓𪈠𡤻𪈳鴹𪂹𪊴麐麕麞麢䴴麪麯𤍤黁㭠㧥㴝伲㞾𨰫鼂鼈䮖鐤𦶢鼗鼖鼹嚟嚊齅馸𩂋韲葿齢齩竜龎爖䮾𤥵𤦻煷𤧸𤍈𤩑玞𨯚𡣺禟𨥾𨸶鍩鏳𨩄鋬鎁鏋𨥬𤒹爗㻫睲穃烐𤑳𤏸煾𡟯炣𡢾𣖙㻇𡢅𥐯𡟸㜢𡛻𡠹㛡𡝴𡣑𥽋㜣𡛀坛𤨥𡏾𡊨"],
        ["9240", "𡏆𡒶蔃𣚦蔃葕𤦔𧅥𣸱𥕜𣻻𧁒䓴𣛮𩦝𦼦柹㜳㰕㷧塬𡤢栐䁗𣜿𤃡𤂋𤄏𦰡哋嚞𦚱嚒𠿟𠮨𠸍鏆𨬓鎜仸儫㠙𤐶亼𠑥𠍿佋侊𥙑婨𠆫𠏋㦙𠌊𠐔㐵伩𠋀𨺳𠉵諚𠈌亘"],
        ["92a1", "働儍侢伃𤨎𣺊佂倮偬傁俌俥偘僼兙兛兝兞湶𣖕𣸹𣺿浲𡢄𣺉冨凃𠗠䓝𠒣𠒒𠒑赺𨪜𠜎剙劤𠡳勡鍮䙺熌𤎌𠰠𤦬𡃤槑𠸝瑹㻞璙琔瑖玘䮎𤪼𤂍叐㖄爏𤃉喴𠍅响𠯆圝鉝雴鍦埝垍坿㘾壋媙𨩆𡛺𡝯𡜐娬妸銏婾嫏娒𥥆𡧳𡡡𤊕㛵洅瑃娡𥺃"],
        ["9340", "媁𨯗𠐓鏠璌𡌃焅䥲鐈𨧻鎽㞠尞岞幞幈𡦖𡥼𣫮廍孏𡤃𡤄㜁𡢠㛝𡛾㛓脪𨩇𡶺𣑲𨦨弌弎𡤧𡞫婫𡜻孄蘔𧗽衠恾𢡠𢘫忛㺸𢖯𢖾𩂈𦽳懀𠀾𠁆𢘛憙憘恵𢲛𢴇𤛔𩅍"],
        ["93a1", "摱𤙥𢭪㨩𢬢𣑐𩣪𢹸挷𪑛撶挱揑𤧣𢵧护𢲡搻敫楲㯴𣂎𣊭𤦉𣊫唍𣋠𡣙𩐿曎𣊉𣆳㫠䆐𥖄𨬢𥖏𡛼𥕛𥐥磮𣄃𡠪𣈴㑤𣈏𣆂𤋉暎𦴤晫䮓昰𧡰𡷫晣𣋒𣋡昞𥡲㣑𣠺𣞼㮙𣞢𣏾瓐㮖枏𤘪梶栞㯄檾㡣𣟕𤒇樳橒櫉欅𡤒攑梘橌㯗橺歗𣿀𣲚鎠鋲𨯪𨫋"],
        ["9440", "銉𨀞𨧜鑧涥漋𤧬浧𣽿㶏渄𤀼娽渊塇洤硂焻𤌚𤉶烱牐犇犔𤞏𤜥兹𤪤𠗫瑺𣻸𣙟𤩊𤤗𥿡㼆㺱𤫟𨰣𣼵悧㻳瓌琼鎇琷䒟𦷪䕑疃㽣𤳙𤴆㽘畕癳𪗆㬙瑨𨫌𤦫𤦎㫻"],
        ["94a1", "㷍𤩎㻿𤧅𤣳釺圲鍂𨫣𡡤僟𥈡𥇧睸𣈲眎眏睻𤚗𣞁㩞𤣰琸璛㺿𤪺𤫇䃈𤪖𦆮錇𥖁砞碍碈磒珐祙𧝁𥛣䄎禛蒖禥樭𣻺稺秴䅮𡛦䄲鈵秱𠵌𤦌𠊙𣶺𡝮㖗啫㕰㚪𠇔𠰍竢婙𢛵𥪯𥪜娍𠉛磰娪𥯆竾䇹籝籭䈑𥮳𥺼𥺦糍𤧹𡞰粎籼粮檲緜縇緓罎𦉡"],
        ["9540", "𦅜𧭈綗𥺂䉪𦭵𠤖柖𠁎𣗏埄𦐒𦏸𤥢翝笧𠠬𥫩𥵃笌𥸎駦虅驣樜𣐿㧢𤧷𦖭騟𦖠蒀𧄧𦳑䓪脷䐂胆脉腂𦞴飃𦩂艢艥𦩑葓𦶧蘐𧈛媆䅿𡡀嬫𡢡嫤𡣘蚠蜨𣶏蠭𧐢娂"],
        ["95a1", "衮佅袇袿裦襥襍𥚃襔𧞅𧞄𨯵𨯙𨮜𨧹㺭蒣䛵䛏㟲訽訜𩑈彍鈫𤊄旔焩烄𡡅鵭貟賩𧷜妚矃姰䍮㛔踪躧𤰉輰轊䋴汘澻𢌡䢛潹溋𡟚鯩㚵𤤯邻邗啱䤆醻鐄𨩋䁢𨫼鐧𨰝𨰻蓥訫閙閧閗閖𨴴瑅㻂𤣿𤩂𤏪㻧𣈥随𨻧𨹦𨹥㻌𤧭𤩸𣿮琒瑫㻼靁𩂰"],
        ["9640", "桇䨝𩂓𥟟靝鍨𨦉𨰦𨬯𦎾銺嬑譩䤼珹𤈛鞛靱餸𠼦巁𨯅𤪲頟𩓚鋶𩗗釥䓀𨭐𤩧𨭤飜𨩅㼀鈪䤥萔餻饍𧬆㷽馛䭯馪驜𨭥𥣈檏騡嫾騯𩣱䮐𩥈馼䮽䮗鍽塲𡌂堢𤦸"],
        ["96a1", "𡓨硄𢜟𣶸棅㵽鑘㤧慐𢞁𢥫愇鱏鱓鱻鰵鰐魿鯏𩸭鮟𪇵𪃾鴡䲮𤄄鸘䲰鴌𪆴𪃭𪃳𩤯鶥蒽𦸒𦿟𦮂藼䔳𦶤𦺄𦷰萠藮𦸀𣟗𦁤秢𣖜𣙀䤭𤧞㵢鏛銾鍈𠊿碹鉷鑍俤㑀遤𥕝砽硔碶硋𡝗𣇉𤥁㚚佲濚濙瀞瀞吔𤆵垻壳垊鴖埗焴㒯𤆬燫𦱀𤾗嬨𡞵𨩉"],
        ["9740", "愌嫎娋䊼𤒈㜬䭻𨧼鎻鎸𡣖𠼝葲𦳀𡐓𤋺𢰦𤏁妔𣶷𦝁綨𦅛𦂤𤦹𤦋𨧺鋥珢㻩璴𨭣𡢟㻡𤪳櫘珳珻㻖𤨾𤪔𡟙𤩦𠎧𡐤𤧥瑈𤤖炥𤥶銄珦鍟𠓾錱𨫎𨨖鎆𨯧𥗕䤵𨪂煫"],
        ["97a1", "𤥃𠳿嚤𠘚𠯫𠲸唂秄𡟺緾𡛂𤩐𡡒䔮鐁㜊𨫀𤦭妰𡢿𡢃𧒄媡㛢𣵛㚰鉟婹𨪁𡡢鍴㳍𠪴䪖㦊僴㵩㵌𡎜煵䋻𨈘渏𩃤䓫浗𧹏灧沯㳖𣿭𣸭渂漌㵯𠏵畑㚼㓈䚀㻚䡱姄鉮䤾轁𨰜𦯀堒埈㛖𡑒烾𤍢𤩱𢿣𡊰𢎽梹楧𡎘𣓥𧯴𣛟𨪃𣟖𣏺𤲟樚𣚭𦲷萾䓟䓎"],
        ["9840", "𦴦𦵑𦲂𦿞漗𧄉茽𡜺菭𦲀𧁓𡟛妉媂𡞳婡婱𡤅𤇼㜭姯𡜼㛇熎鎐暚𤊥婮娫𤊓樫𣻹𧜶𤑛𤋊焝𤉙𨧡侰𦴨峂𤓎𧹍𤎽樌𤉖𡌄炦焳𤏩㶥泟勇𤩏繥姫崯㷳彜𤩝𡟟綤萦"],
        ["98a1", "咅𣫺𣌀𠈔坾𠣕𠘙㿥𡾞𪊶瀃𩅛嵰玏糓𨩙𩐠俈翧狍猐𧫴猸猹𥛶獁獈㺩𧬘遬燵𤣲珡臶㻊県㻑沢国琙琞琟㻢㻰㻴㻺瓓㼎㽓畂畭畲疍㽼痈痜㿀癍㿗癴㿜発𤽜熈嘣覀塩䀝睃䀹条䁅㗛瞘䁪䁯属瞾矋売砘点砜䂨砹硇硑硦葈𥔵礳栃礲䄃"],
        ["9940", "䄉禑禙辻稆込䅧窑䆲窼艹䇄竏竛䇏両筢筬筻簒簛䉠䉺类粜䊌粸䊔糭输烀𠳏総緔緐緽羮羴犟䎗耠耥笹耮耱联㷌垴炠肷胩䏭脌猪脎脒畠脔䐁㬹腖腙腚"],
        ["99a1", "䐓堺腼膄䐥膓䐭膥埯臁臤艔䒏芦艶苊苘苿䒰荗险榊萅烵葤惣蒈䔄蒾蓡蓸蔐蔸蕒䔻蕯蕰藠䕷虲蚒蚲蛯际螋䘆䘗袮裿褤襇覑𧥧訩訸誔誴豑賔賲贜䞘塟跃䟭仮踺嗘坔蹱嗵躰䠷軎転軤軭軲辷迁迊迌逳駄䢭飠鈓䤞鈨鉘鉫銱銮銿"],
        ["9a40", "鋣鋫鋳鋴鋽鍃鎄鎭䥅䥑麿鐗匁鐝鐭鐾䥪鑔鑹锭関䦧间阳䧥枠䨤靀䨵鞲韂噔䫤惨颹䬙飱塄餎餙冴餜餷饂饝饢䭰駅䮝騼鬏窃魩鮁鯝鯱鯴䱭鰠㝯𡯂鵉鰺"],
        ["9aa1", "黾噐鶓鶽鷀鷼银辶鹻麬麱麽黆铜黢黱黸竈齄𠂔𠊷𠎠椚铃妬𠓗塀铁㞹𠗕𠘕𠙶𡚺块煳𠫂𠫍𠮿呪吆𠯋咞𠯻𠰻𠱓𠱥𠱼惧𠲍噺𠲵𠳝𠳭𠵯𠶲𠷈楕鰯螥𠸄𠸎𠻗𠾐𠼭𠹳尠𠾼帋𡁜𡁏𡁶朞𡁻𡂈𡂖㙇𡂿𡃓𡄯𡄻卤蒭𡋣𡍵𡌶讁𡕷𡘙𡟃𡟇乸炻𡠭𡥪"],
        ["9b40", "𡨭𡩅𡰪𡱰𡲬𡻈拃𡻕𡼕熘桕𢁅槩㛈𢉼𢏗𢏺𢜪𢡱𢥏苽𢥧𢦓𢫕覥𢫨辠𢬎鞸𢬿顇骽𢱌"],
        ["9b62", "𢲈𢲷𥯨𢴈𢴒𢶷𢶕𢹂𢽴𢿌𣀳𣁦𣌟𣏞徱晈暿𧩹𣕧𣗳爁𤦺矗𣘚𣜖纇𠍆墵朎"],
        ["9ba1", "椘𣪧𧙗𥿢𣸑𣺹𧗾𢂚䣐䪸𤄙𨪚𤋮𤌍𤀻𤌴𤎖𤩅𠗊凒𠘑妟𡺨㮾𣳿𤐄𤓖垈𤙴㦛𤜯𨗨𩧉㝢𢇃譞𨭎駖𤠒𤣻𤨕爉𤫀𠱸奥𤺥𤾆𠝹軚𥀬劏圿煱𥊙𥐙𣽊𤪧喼𥑆𥑮𦭒釔㑳𥔿𧘲𥕞䜘𥕢𥕦𥟇𤤿𥡝偦㓻𣏌惞𥤃䝼𨥈𥪮𥮉𥰆𡶐垡煑澶𦄂𧰒遖𦆲𤾚譢𦐂𦑊"],
        ["9c40", "嵛𦯷輶𦒄𡤜諪𤧶𦒈𣿯𦔒䯀𦖿𦚵𢜛鑥𥟡憕娧晉侻嚹𤔡𦛼乪𤤴陖涏𦲽㘘襷𦞙𦡮𦐑𦡞營𦣇筂𩃀𠨑𦤦鄄𦤹穅鷰𦧺騦𦨭㙟𦑩𠀡禃𦨴𦭛崬𣔙菏𦮝䛐𦲤画补𦶮墶"],
        ["9ca1", "㜜𢖍𧁋𧇍㱔𧊀𧊅銁𢅺𧊋錰𧋦𤧐氹钟𧑐𠻸蠧裵𢤦𨑳𡞱溸𤨪𡠠㦤㚹尐秣䔿暶𩲭𩢤襃𧟌𧡘囖䃟𡘊㦡𣜯𨃨𡏅熭荦𧧝𩆨婧䲷𧂯𨦫𧧽𧨊𧬋𧵦𤅺筃祾𨀉澵𪋟樃𨌘厢𦸇鎿栶靝𨅯𨀣𦦵𡏭𣈯𨁈嶅𨰰𨂃圕頣𨥉嶫𤦈斾槕叒𤪥𣾁㰑朶𨂐𨃴𨄮𡾡𨅏"],
        ["9d40", "𨆉𨆯𨈚𨌆𨌯𨎊㗊𨑨𨚪䣺揦𨥖砈鉕𨦸䏲𨧧䏟𨧨𨭆𨯔姸𨰉輋𨿅𩃬筑𩄐𩄼㷷𩅞𤫊运犏嚋𩓧𩗩𩖰𩖸𩜲𩣑𩥉𩥪𩧃𩨨𩬎𩵚𩶛纟𩻸𩼣䲤镇𪊓熢𪋿䶑递𪗋䶜𠲜达嗁"],
        ["9da1", "辺𢒰边𤪓䔉繿潖檱仪㓤𨬬𧢝㜺躀𡟵𨀤𨭬𨮙𧨾𦚯㷫𧙕𣲷𥘵𥥖亚𥺁𦉘嚿𠹭踎孭𣺈𤲞揞拐𡟶𡡻攰嘭𥱊吚𥌑㷆𩶘䱽嘢嘞罉𥻘奵𣵀蝰东𠿪𠵉𣚺脗鵞贘瘻鱅癎瞹鍅吲腈苷嘥脲萘肽嗪祢噃吖𠺝㗎嘅嗱曱𨋢㘭甴嗰喺咗啲𠱁𠲖廐𥅈𠹶𢱢"],
        ["9e40", "𠺢麫絚嗞𡁵抝靭咔賍燶酶揼掹揾啩𢭃鱲𢺳冚㓟𠶧冧呍唞唓癦踭𦢊疱肶蠄螆裇膶萜𡃁䓬猄𤜆宐茋𦢓噻𢛴𧴯𤆣𧵳𦻐𧊶酰𡇙鈈𣳼𪚩𠺬𠻹牦𡲢䝎𤿂𧿹𠿫䃺"],
        ["9ea1", "鱝攟𢶠䣳𤟠𩵼𠿬𠸊恢𧖣𠿭"],
        ["9ead", "𦁈𡆇熣纎鵐业丄㕷嬍沲卧㚬㧜卽㚥𤘘墚𤭮舭呋垪𥪕𠥹"],
        ["9ec5", "㩒𢑥獴𩺬䴉鯭𣳾𩼰䱛𤾩𩖞𩿞葜𣶶𧊲𦞳𣜠挮紥𣻷𣸬㨪逈勌㹴㙺䗩𠒎癀嫰𠺶硺𧼮墧䂿噼鮋嵴癔𪐴麅䳡痹㟻愙𣃚𤏲"],
        ["9ef5", "噝𡊩垧𤥣𩸆刴𧂮㖭汊鵼"],
        ["9f40", "籖鬹埞𡝬屓擓𩓐𦌵𧅤蚭𠴨𦴢𤫢𠵱"],
        ["9f4f", "凾𡼏嶎霃𡷑麁遌笟鬂峑箣扨挵髿篏鬪籾鬮籂粆鰕篼鬉鼗鰛𤤾齚啳寃俽麘俲剠㸆勑坧偖妷帒韈鶫轜呩鞴饀鞺匬愰"],
        ["9fa1", "椬叚鰊鴂䰻陁榀傦畆𡝭駚剳"],
        ["9fae", "酙隁酜"],
        ["9fb2", "酑𨺗捿𦴣櫊嘑醎畺抅𠏼獏籰𥰡𣳽"],
        ["9fc1", "𤤙盖鮝个𠳔莾衂"],
        ["9fc9", "届槀僭坺刟巵从氱𠇲伹咜哚劚趂㗾弌㗳"],
        ["9fdb", "歒酼龥鮗頮颴骺麨麄煺笔"],
        ["9fe7", "毺蠘罸"],
        ["9feb", "嘠𪙊蹷齓"],
        ["9ff0", "跔蹏鸜踁抂𨍽踨蹵竓𤩷稾磘泪詧瘇"],
        ["a040", "𨩚鼦泎蟖痃𪊲硓咢贌狢獱謭猂瓱賫𤪻蘯徺袠䒷"],
        ["a055", "𡠻𦸅"],
        ["a058", "詾𢔛"],
        ["a05b", "惽癧髗鵄鍮鮏蟵"],
        ["a063", "蠏賷猬霡鮰㗖犲䰇籑饊𦅙慙䰄麖慽"],
        ["a073", "坟慯抦戹拎㩜懢厪𣏵捤栂㗒"],
        ["a0a1", "嵗𨯂迚𨸹"],
        ["a0a6", "僙𡵆礆匲阸𠼻䁥"],
        ["a0ae", "矾"],
        ["a0b0", "糂𥼚糚稭聦聣絍甅瓲覔舚朌聢𧒆聛瓰脃眤覉𦟌畓𦻑螩蟎臈螌詉貭譃眫瓸蓚㘵榲趦"],
        ["a0d4", "覩瑨涹蟁𤀑瓧㷛煶悤憜㳑煢恷"],
        ["a0e2", "罱𨬭牐惩䭾删㰘𣳇𥻗𧙖𥔱𡥄𡋾𩤃𦷜𧂭峁𦆭𨨏𣙷𠃮𦡆𤼎䕢嬟𦍌齐麦𦉫"],
        ["a3c0", "␀", 31, "␡"],
        ["c6a1", "①", 9, "⑴", 9, "ⅰ", 9, "丶丿亅亠冂冖冫勹匸卩厶夊宀巛⼳广廴彐彡攴无疒癶辵隶¨ˆヽヾゝゞ〃仝々〆〇ー［］✽ぁ", 23],
        ["c740", "す", 58, "ァアィイ"],
        ["c7a1", "ゥ", 81, "А", 5, "ЁЖ", 4],
        ["c840", "Л", 26, "ёж", 25, "⇧↸↹㇏𠃌乚𠂊刂䒑"],
        ["c8a1", "龰冈龱𧘇"],
        ["c8cd", "￢￤＇＂㈱№℡゛゜⺀⺄⺆⺇⺈⺊⺌⺍⺕⺜⺝⺥⺧⺪⺬⺮⺶⺼⺾⻆⻊⻌⻍⻏⻖⻗⻞⻣"],
        ["c8f5", "ʃɐɛɔɵœøŋʊɪ"],
        ["f9fe", "￭"],
        ["fa40", "𠕇鋛𠗟𣿅蕌䊵珯况㙉𤥂𨧤鍄𡧛苮𣳈砼杄拟𤤳𨦪𠊠𦮳𡌅侫𢓭倈𦴩𧪄𣘀𤪱𢔓倩𠍾徤𠎀𠍇滛𠐟偽儁㑺儎顬㝃萖𤦤𠒇兠𣎴兪𠯿𢃼𠋥𢔰𠖎𣈳𡦃宂蝽𠖳𣲙冲冸"],
        ["faa1", "鴴凉减凑㳜凓𤪦决凢卂凭菍椾𣜭彻刋刦刼劵剗劔効勅簕蕂勠蘍𦬓包𨫞啉滙𣾀𠥔𣿬匳卄𠯢泋𡜦栛珕恊㺪㣌𡛨燝䒢卭却𨚫卾卿𡖖𡘓矦厓𨪛厠厫厮玧𥝲㽙玜叁叅汉义埾叙㪫𠮏叠𣿫𢶣叶𠱷吓灹唫晗浛呭𦭓𠵴啝咏咤䞦𡜍𠻝㶴𠵍"],
        ["fb40", "𨦼𢚘啇䳭启琗喆喩嘅𡣗𤀺䕒𤐵暳𡂴嘷曍𣊊暤暭噍噏磱囱鞇叾圀囯园𨭦㘣𡉏坆𤆥汮炋坂㚱𦱾埦𡐖堃𡑔𤍣堦𤯵塜墪㕡壠壜𡈼壻寿坃𪅐𤉸鏓㖡够梦㛃湙"],
        ["fba1", "𡘾娤啓𡚒蔅姉𠵎𦲁𦴪𡟜姙𡟻𡞲𦶦浱𡠨𡛕姹𦹅媫婣㛦𤦩婷㜈媖瑥嫓𦾡𢕔㶅𡤑㜲𡚸広勐孶斈孼𧨎䀄䡝𠈄寕慠𡨴𥧌𠖥寳宝䴐尅𡭄尓珎尔𡲥𦬨屉䣝岅峩峯嶋𡷹𡸷崐崘嵆𡺤岺巗苼㠭𤤁𢁉𢅳芇㠶㯂帮檊幵幺𤒼𠳓厦亷廐厨𡝱帉廴𨒂"],
        ["fc40", "廹廻㢠廼栾鐛弍𠇁弢㫞䢮𡌺强𦢈𢏐彘𢑱彣鞽𦹮彲鍀𨨶徧嶶㵟𥉐𡽪𧃸𢙨釖𠊞𨨩怱暅𡡷㥣㷇㘹垐𢞴祱㹀悞悤悳𤦂𤦏𧩓璤僡媠慤萤慂慈𦻒憁凴𠙖憇宪𣾷"],
        ["fca1", "𢡟懓𨮝𩥝懐㤲𢦀𢣁怣慜攞掋𠄘担𡝰拕𢸍捬𤧟㨗搸揸𡎎𡟼撐澊𢸶頔𤂌𥜝擡擥鑻㩦携㩗敍漖𤨨𤨣斅敭敟𣁾斵𤥀䬷旑䃘𡠩无旣忟𣐀昘𣇷𣇸晄𣆤𣆥晋𠹵晧𥇦晳晴𡸽𣈱𨗴𣇈𥌓矅𢣷馤朂𤎜𤨡㬫槺𣟂杞杧杢𤇍𩃭柗䓩栢湐鈼栁𣏦𦶠桝"],
        ["fd40", "𣑯槡樋𨫟楳棃𣗍椁椀㴲㨁𣘼㮀枬楡𨩊䋼椶榘㮡𠏉荣傐槹𣙙𢄪橅𣜃檝㯳枱櫈𩆜㰍欝𠤣惞欵歴𢟍溵𣫛𠎵𡥘㝀吡𣭚毡𣻼毜氷𢒋𤣱𦭑汚舦汹𣶼䓅𣶽𤆤𤤌𤤀"],
        ["fda1", "𣳉㛥㳫𠴲鮃𣇹𢒑羏样𦴥𦶡𦷫涖浜湼漄𤥿𤂅𦹲蔳𦽴凇沜渝萮𨬡港𣸯瑓𣾂秌湏媑𣁋濸㜍澝𣸰滺𡒗𤀽䕕鏰潄潜㵎潴𩅰㴻澟𤅄濓𤂑𤅕𤀹𣿰𣾴𤄿凟𤅖𤅗𤅀𦇝灋灾炧炁烌烕烖烟䄄㷨熴熖𤉷焫煅媈煊煮岜𤍥煏鍢𤋁焬𤑚𤨧𤨢熺𨯨炽爎"],
        ["fe40", "鑂爕夑鑃爤鍁𥘅爮牀𤥴梽牕牗㹕𣁄栍漽犂猪猫𤠣𨠫䣭𨠄猨献珏玪𠰺𦨮珉瑉𤇢𡛧𤨤昣㛅𤦷𤦍𤧻珷琕椃𤨦琹𠗃㻗瑜𢢭瑠𨺲瑇珤瑶莹瑬㜰瑴鏱樬璂䥓𤪌"],
        ["fea1", "𤅟𤩹𨮏孆𨰃𡢞瓈𡦈甎瓩甞𨻙𡩋寗𨺬鎅畍畊畧畮𤾂㼄𤴓疎瑝疞疴瘂瘬癑癏癯癶𦏵皐臯㟸𦤑𦤎皡皥皷盌𦾟葢𥂝𥅽𡸜眞眦着撯𥈠睘𣊬瞯𨥤𨥨𡛁矴砉𡍶𤨒棊碯磇磓隥礮𥗠磗礴碱𧘌辸袄𨬫𦂃𢘜禆褀椂禀𥡗禝𧬹礼禩渪𧄦㺨秆𩄍秔"]
    ];
    module.exports = json;
},
/* iconv-lite/lib/streams.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var Buffer = require("buffer").Buffer, Transform = require("stream").Transform;
    // == Exports ==================================================================
    module.exports = function (iconv) {
        // Additional Public API.
        iconv.encodeStream = function encodeStream(encoding, options) {
            return new IconvLiteEncoderStream(iconv.getEncoder(encoding, options), options);
        };
        iconv.decodeStream = function decodeStream(encoding, options) {
            return new IconvLiteDecoderStream(iconv.getDecoder(encoding, options), options);
        };
        iconv.supportsStreams = true;
        // Not published yet.
        iconv.IconvLiteEncoderStream = IconvLiteEncoderStream;
        iconv.IconvLiteDecoderStream = IconvLiteDecoderStream;
        iconv._collect = IconvLiteDecoderStream.prototype.collect;
    };
    // == Encoder stream =======================================================
    function IconvLiteEncoderStream(conv, options) {
        this.conv = conv;
        options = options || {};
        options.decodeStrings = false; // We accept only strings, so we don't need to decode them.
        Transform.call(this, options);
    }
    IconvLiteEncoderStream.prototype = Object.create(Transform.prototype, {
        constructor: { value: IconvLiteEncoderStream }
    });
    IconvLiteEncoderStream.prototype._transform = function (chunk, encoding, done) {
        if (typeof chunk != 'string')
            return done(new Error("Iconv encoding stream needs strings as its input."));
        try {
            var res = this.conv.write(chunk);
            if (res && res.length)
                this.push(res);
            done();
        }
        catch (e) {
            done(e);
        }
    };
    IconvLiteEncoderStream.prototype._flush = function (done) {
        try {
            var res = this.conv.end();
            if (res && res.length)
                this.push(res);
            done();
        }
        catch (e) {
            done(e);
        }
    };
    IconvLiteEncoderStream.prototype.collect = function (cb) {
        var chunks = [];
        this.on('error', cb);
        this.on('data', function (chunk) { chunks.push(chunk); });
        this.on('end', function () {
            cb(null, Buffer.concat(chunks));
        });
        return this;
    };
    // == Decoder stream =======================================================
    function IconvLiteDecoderStream(conv, options) {
        this.conv = conv;
        options = options || {};
        options.encoding = this.encoding = 'utf8'; // We output strings.
        Transform.call(this, options);
    }
    IconvLiteDecoderStream.prototype = Object.create(Transform.prototype, {
        constructor: { value: IconvLiteDecoderStream }
    });
    IconvLiteDecoderStream.prototype._transform = function (chunk, encoding, done) {
        if (!Buffer.isBuffer(chunk))
            return done(new Error("Iconv decoding stream needs buffers as its input."));
        try {
            var res = this.conv.write(chunk);
            if (res && res.length)
                this.push(res, this.encoding);
            done();
        }
        catch (e) {
            done(e);
        }
    };
    IconvLiteDecoderStream.prototype._flush = function (done) {
        try {
            var res = this.conv.end();
            if (res && res.length)
                this.push(res, this.encoding);
            done();
        }
        catch (e) {
            done(e);
        }
    };
    IconvLiteDecoderStream.prototype.collect = function (cb) {
        var res = '';
        this.on('error', cb);
        this.on('data', function (chunk) { res += chunk; });
        this.on('end', function () {
            cb(null, res);
        });
        return this;
    };
},
/* iconv-lite/lib/extend-node.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var Buffer = require("buffer").Buffer;
    // Note: not polyfilled with safer-buffer on a purpose, as overrides Buffer
    // == Extend Node primitives to use iconv-lite =================================
    module.exports = function (iconv) {
        var original = undefined; // Place to keep original methods.
        // Node authors rewrote Buffer internals to make it compatible with
        // Uint8Array and we cannot patch key functions since then.
        // Note: this does use older Buffer API on a purpose
        iconv.supportsNodeEncodingsExtension = !(Buffer.from || new Buffer(0) instanceof Uint8Array);
        iconv.extendNodeEncodings = function extendNodeEncodings() {
            if (original)
                return;
            original = {};
            if (!iconv.supportsNodeEncodingsExtension) {
                console.error("ACTION NEEDED: require('iconv-lite').extendNodeEncodings() is not supported in your version of Node");
                console.error("See more info at https://github.com/ashtuchkin/iconv-lite/wiki/Node-v4-compatibility");
                return;
            }
            var nodeNativeEncodings = {
                'hex': true, 'utf8': true, 'utf-8': true, 'ascii': true, 'binary': true,
                'base64': true, 'ucs2': true, 'ucs-2': true, 'utf16le': true, 'utf-16le': true,
            };
            Buffer.isNativeEncoding = function (enc) {
                return enc && nodeNativeEncodings[enc.toLowerCase()];
            };
            // -- SlowBuffer -----------------------------------------------------------
            var SlowBuffer = require('buffer').SlowBuffer;
            original.SlowBufferToString = SlowBuffer.prototype.toString;
            SlowBuffer.prototype.toString = function (encoding, start, end) {
                encoding = String(encoding || 'utf8').toLowerCase();
                // Use native conversion when possible
                if (Buffer.isNativeEncoding(encoding))
                    return original.SlowBufferToString.call(this, encoding, start, end);
                // Otherwise, use our decoding method.
                if (typeof start == 'undefined')
                    start = 0;
                if (typeof end == 'undefined')
                    end = this.length;
                return iconv.decode(this.slice(start, end), encoding);
            };
            original.SlowBufferWrite = SlowBuffer.prototype.write;
            SlowBuffer.prototype.write = function (string, offset, length, encoding) {
                // Support both (string, offset, length, encoding)
                // and the legacy (string, encoding, offset, length)
                if (isFinite(offset)) {
                    if (!isFinite(length)) {
                        encoding = length;
                        length = undefined;
                    }
                }
                else { // legacy
                    var swap = encoding;
                    encoding = offset;
                    offset = length;
                    length = swap;
                }
                offset = +offset || 0;
                var remaining = this.length - offset;
                if (!length) {
                    length = remaining;
                }
                else {
                    length = +length;
                    if (length > remaining) {
                        length = remaining;
                    }
                }
                encoding = String(encoding || 'utf8').toLowerCase();
                // Use native conversion when possible
                if (Buffer.isNativeEncoding(encoding))
                    return original.SlowBufferWrite.call(this, string, offset, length, encoding);
                if (string.length > 0 && (length < 0 || offset < 0))
                    throw new RangeError('attempt to write beyond buffer bounds');
                // Otherwise, use our encoding method.
                var buf = iconv.encode(string, encoding);
                if (buf.length < length)
                    length = buf.length;
                buf.copy(this, offset, 0, length);
                return length;
            };
            // -- Buffer ---------------------------------------------------------------
            original.BufferIsEncoding = Buffer.isEncoding;
            Buffer.isEncoding = function (encoding) {
                return Buffer.isNativeEncoding(encoding) || iconv.encodingExists(encoding);
            };
            original.BufferByteLength = Buffer.byteLength;
            Buffer.byteLength = SlowBuffer.byteLength = function (str, encoding) {
                encoding = String(encoding || 'utf8').toLowerCase();
                // Use native conversion when possible
                if (Buffer.isNativeEncoding(encoding))
                    return original.BufferByteLength.call(this, str, encoding);
                // Slow, I know, but we don't have a better way yet.
                return iconv.encode(str, encoding).length;
            };
            original.BufferToString = Buffer.prototype.toString;
            Buffer.prototype.toString = function (encoding, start, end) {
                encoding = String(encoding || 'utf8').toLowerCase();
                // Use native conversion when possible
                if (Buffer.isNativeEncoding(encoding))
                    return original.BufferToString.call(this, encoding, start, end);
                // Otherwise, use our decoding method.
                if (typeof start == 'undefined')
                    start = 0;
                if (typeof end == 'undefined')
                    end = this.length;
                return iconv.decode(this.slice(start, end), encoding);
            };
            original.BufferWrite = Buffer.prototype.write;
            Buffer.prototype.write = function (string, offset, length, encoding) {
                var _offset = offset, _length = length, _encoding = encoding;
                // Support both (string, offset, length, encoding)
                // and the legacy (string, encoding, offset, length)
                if (isFinite(offset)) {
                    if (!isFinite(length)) {
                        encoding = length;
                        length = undefined;
                    }
                }
                else { // legacy
                    var swap = encoding;
                    encoding = offset;
                    offset = length;
                    length = swap;
                }
                encoding = String(encoding || 'utf8').toLowerCase();
                // Use native conversion when possible
                if (Buffer.isNativeEncoding(encoding))
                    return original.BufferWrite.call(this, string, _offset, _length, _encoding);
                offset = +offset || 0;
                var remaining = this.length - offset;
                if (!length) {
                    length = remaining;
                }
                else {
                    length = +length;
                    if (length > remaining) {
                        length = remaining;
                    }
                }
                if (string.length > 0 && (length < 0 || offset < 0))
                    throw new RangeError('attempt to write beyond buffer bounds');
                // Otherwise, use our encoding method.
                var buf = iconv.encode(string, encoding);
                if (buf.length < length)
                    length = buf.length;
                buf.copy(this, offset, 0, length);
                return length;
                // TODO: Set _charsWritten.
            };
            // -- Readable -------------------------------------------------------------
            if (iconv.supportsStreams) {
                var Readable = require('stream').Readable;
                original.ReadableSetEncoding = Readable.prototype.setEncoding;
                Readable.prototype.setEncoding = function setEncoding(enc, options) {
                    // Use our own decoder, it has the same interface.
                    // We cannot use original function as it doesn't handle BOM-s.
                    this._readableState.decoder = iconv.getDecoder(enc, options);
                    this._readableState.encoding = enc;
                };
                Readable.prototype.collect = iconv._collect;
            }
        };
        // Remove iconv-lite Node primitive extensions.
        iconv.undoExtendNodeEncodings = function undoExtendNodeEncodings() {
            if (!iconv.supportsNodeEncodingsExtension)
                return;
            if (!original)
                throw new Error("require('iconv-lite').undoExtendNodeEncodings(): Nothing to undo; extendNodeEncodings() is not called.");
            delete Buffer.isNativeEncoding;
            var SlowBuffer = require('buffer').SlowBuffer;
            SlowBuffer.prototype.toString = original.SlowBufferToString;
            SlowBuffer.prototype.write = original.SlowBufferWrite;
            Buffer.isEncoding = original.BufferIsEncoding;
            Buffer.byteLength = original.BufferByteLength;
            Buffer.prototype.toString = original.BufferToString;
            Buffer.prototype.write = original.BufferWrite;
            if (iconv.supportsStreams) {
                var Readable = require('stream').Readable;
                Readable.prototype.setEncoding = original.ReadableSetEncoding;
                delete Readable.prototype.collect;
            }
            original = undefined;
        };
    };
},
/* needle/lib/utils.js */ function _(require, module, exports, __esModule, __esExport) {
    var fs = require('fs'), url = require('url'), stream = require('stream');
    function resolve_url(href, base) {
        if (url.URL)
            return new url.URL(href, base);
        // older Node version (< v6.13)
        return base ? url.resolve(base, href) : href;
    }
    function host_and_ports_match(url1, url2) {
        if (url1.indexOf('http') < 0)
            url1 = 'http://' + url1;
        if (url2.indexOf('http') < 0)
            url2 = 'http://' + url2;
        var a = url.parse(url1), b = url.parse(url2);
        return a.host == b.host
            && String(a.port || (a.protocol == 'https:' ? 443 : 80))
                == String(b.port || (b.protocol == 'https:' ? 443 : 80));
    }
    // returns false if a no_proxy host or pattern matches given url
    function should_proxy_to(uri) {
        var no_proxy = get_env_var(['NO_PROXY'], true);
        if (!no_proxy)
            return true;
        // previous (naive, simple) strategy
        // var host, hosts = no_proxy.split(',');
        // for (var i in hosts) {
        //   host = hosts[i];
        //   if (host_and_ports_match(host, uri)) {
        //     return false;
        //   }
        // }
        var pattern, pattern_list = no_proxy.split(/[\s,]+/);
        for (var i in pattern_list) {
            pattern = pattern_list[i];
            if (pattern.trim().length == 0)
                continue;
            // replace leading dot by asterisk, escape dots and finally replace asterisk by .*
            var regex = new RegExp(pattern.replace(/^\./, "*").replace(/[.]/g, '\\$&').replace(/\*/g, '.*'));
            if (uri.match(regex))
                return false;
        }
        return true;
    }
    function get_env_var(keys, try_lower) {
        var val, i = -1, env = process.env;
        while (!val && i < keys.length - 1) {
            val = env[keys[++i]];
            if (!val && try_lower) {
                val = env[keys[i].toLowerCase()];
            }
        }
        return val;
    }
    function parse_content_type(header) {
        if (!header || header === '')
            return {};
        var found, charset = 'utf8', arr = header.split(';');
        if (arr.length > 1 && (found = arr[1].match(/charset=(.+)/)))
            charset = found[1];
        return { type: arr[0], charset: charset };
    }
    function is_stream(obj) {
        return typeof obj.pipe === 'function';
    }
    function get_stream_length(stream, given_length, cb) {
        if (given_length > 0)
            return cb(given_length);
        if (stream.end !== void 0 && stream.end !== Infinity && stream.start !== void 0)
            return cb((stream.end + 1) - (stream.start || 0));
        fs.stat(stream.path, function (err, stat) {
            cb(stat ? stat.size - (stream.start || 0) : null);
        });
    }
    function pump_streams(streams, cb) {
        if (stream.pipeline)
            return stream.pipeline.apply(null, streams.concat(cb));
        var tmp = streams.shift();
        while (streams.length) {
            tmp = tmp.pipe(streams.shift());
            tmp.once('error', function (e) {
                cb && cb(e);
                cb = null;
            });
        }
    }
    module.exports = {
        resolve_url: resolve_url,
        get_env_var: get_env_var,
        host_and_ports_match: host_and_ports_match,
        should_proxy_to: should_proxy_to,
        parse_content_type: parse_content_type,
        is_stream: is_stream,
        get_stream_length: get_stream_length,
        pump_streams: pump_streams
    };
},
/* needle/package.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = {
        "name": "needle",
        "version": "3.3.1",
        "description": "The leanest and most handsome HTTP client in the Nodelands.",
        "keywords": [
            "http",
            "https",
            "simple",
            "request",
            "client",
            "multipart",
            "upload",
            "proxy",
            "deflate",
            "timeout",
            "charset",
            "iconv",
            "cookie",
            "redirect"
        ],
        "tags": [
            "http",
            "https",
            "simple",
            "request",
            "client",
            "multipart",
            "upload",
            "proxy",
            "deflate",
            "timeout",
            "charset",
            "iconv",
            "cookie",
            "redirect"
        ],
        "author": "Tomás Pollak <tomas@forkhq.com>",
        "repository": {
            "type": "git",
            "url": "https://github.com/tomas/needle.git"
        },
        "dependencies": {
            "iconv-lite": "^0.6.3",
            "sax": "^1.2.4"
        },
        "devDependencies": {
            "JSONStream": "^1.3.5",
            "jschardet": "^1.6.0",
            "mocha": "^5.2.0",
            "pump": "^3.0.0",
            "q": "^1.5.1",
            "should": "^13.2.3",
            "sinon": "^2.3.0",
            "xml2js": "^0.4.19"
        },
        "scripts": {
            "test": "mocha test"
        },
        "directories": {
            "lib": "./lib"
        },
        "main": "./lib/needle",
        "bin": {
            "needle": "./bin/needle"
        },
        "license": "MIT",
        "engines": {
            "node": ">= 4.4.x"
        }
    };
    module.exports = json;
},
/* less/lib/less/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var environment_1 = tslib_1.__importDefault(require(109) /* ./environment/environment */);
    var data_1 = tslib_1.__importDefault(require(110) /* ./data */);
    var tree_1 = tslib_1.__importDefault(require(113) /* ./tree */);
    var abstract_file_manager_1 = tslib_1.__importDefault(require(73) /* ./environment/abstract-file-manager */);
    var abstract_plugin_loader_1 = tslib_1.__importDefault(require(176) /* ./environment/abstract-plugin-loader */);
    var visitors_1 = tslib_1.__importDefault(require(127) /* ./visitors */);
    var parser_1 = tslib_1.__importDefault(require(126) /* ./parser/parser */);
    var functions_1 = tslib_1.__importDefault(require(177) /* ./functions */);
    var contexts_1 = tslib_1.__importDefault(require(130) /* ./contexts */);
    var less_error_1 = tslib_1.__importDefault(require(121) /* ./less-error */);
    var transform_tree_1 = tslib_1.__importDefault(require(189) /* ./transform-tree */);
    var utils = tslib_1.__importStar(require(122) /* ./utils */);
    var plugin_manager_1 = tslib_1.__importDefault(require(190) /* ./plugin-manager */);
    var logger_1 = tslib_1.__importDefault(require(75) /* ./logger */);
    var source_map_output_1 = tslib_1.__importDefault(require(191) /* ./source-map-output */);
    var source_map_builder_1 = tslib_1.__importDefault(require(192) /* ./source-map-builder */);
    var parse_tree_1 = tslib_1.__importDefault(require(193) /* ./parse-tree */);
    var import_manager_1 = tslib_1.__importDefault(require(194) /* ./import-manager */);
    var parse_1 = tslib_1.__importDefault(require(195) /* ./parse */);
    var render_1 = tslib_1.__importDefault(require(196) /* ./render */);
    var package_json_1 = require(197) /* ../../package.json */;
    var parse_node_version_1 = tslib_1.__importDefault(require(198) /* parse-node-version */);
    function default_1(environment, fileManagers) {
        var sourceMapOutput, sourceMapBuilder, parseTree, importManager;
        environment = new environment_1.default(environment, fileManagers);
        sourceMapOutput = source_map_output_1.default(environment);
        sourceMapBuilder = source_map_builder_1.default(sourceMapOutput, environment);
        parseTree = parse_tree_1.default(sourceMapBuilder);
        importManager = import_manager_1.default(environment);
        var render = render_1.default(environment, parseTree, importManager);
        var parse = parse_1.default(environment, parseTree, importManager);
        var v = parse_node_version_1.default("v" + package_json_1.version);
        var initial = {
            version: [v.major, v.minor, v.patch],
            data: data_1.default,
            tree: tree_1.default,
            Environment: environment_1.default,
            AbstractFileManager: abstract_file_manager_1.default,
            AbstractPluginLoader: abstract_plugin_loader_1.default,
            environment: environment,
            visitors: visitors_1.default,
            Parser: parser_1.default,
            functions: functions_1.default(environment),
            contexts: contexts_1.default,
            SourceMapOutput: sourceMapOutput,
            SourceMapBuilder: sourceMapBuilder,
            ParseTree: parseTree,
            ImportManager: importManager,
            render: render,
            parse: parse,
            LessError: less_error_1.default,
            transformTree: transform_tree_1.default,
            utils: utils,
            PluginManager: plugin_manager_1.default,
            logger: logger_1.default
        };
        // Create a public API
        var ctor = function (t) {
            return function () {
                var obj = Object.create(t.prototype);
                t.apply(obj, Array.prototype.slice.call(arguments, 0));
                return obj;
            };
        };
        var t;
        var api = Object.create(initial);
        for (var n in initial.tree) {
            /* eslint guard-for-in: 0 */
            t = initial.tree[n];
            if (typeof t === 'function') {
                api[n.toLowerCase()] = ctor(t);
            }
            else {
                api[n] = Object.create(null);
                for (var o in t) {
                    /* eslint guard-for-in: 0 */
                    api[n][o.toLowerCase()] = ctor(t[o]);
                }
            }
        }
        /**
         * Some of the functions assume a `this` context of the API object,
         * which causes it to fail when wrapped for ES6 imports.
         *
         * An assumed `this` should be removed in the future.
         */
        initial.parse = initial.parse.bind(api);
        initial.render = initial.render.bind(api);
        return api;
    }
    exports.default = default_1;
    
},
/* less/lib/less/environment/environment.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    /**
     * @todo Document why this abstraction exists, and the relationship between
     *       environment, file managers, and plugin manager
     */
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var logger_1 = tslib_1.__importDefault(require(75) /* ../logger */);
    var Environment = /** @class */ (function () {
        function Environment(externalEnvironment, fileManagers) {
            this.fileManagers = fileManagers || [];
            externalEnvironment = externalEnvironment || {};
            var optionalFunctions = ['encodeBase64', 'mimeLookup', 'charsetLookup', 'getSourceMapGenerator'];
            var requiredFunctions = [];
            var functions = requiredFunctions.concat(optionalFunctions);
            for (var i = 0; i < functions.length; i++) {
                var propName = functions[i];
                var environmentFunc = externalEnvironment[propName];
                if (environmentFunc) {
                    this[propName] = environmentFunc.bind(externalEnvironment);
                }
                else if (i < requiredFunctions.length) {
                    this.warn("missing required function in environment - " + propName);
                }
            }
        }
        Environment.prototype.getFileManager = function (filename, currentDirectory, options, environment, isSync) {
            if (!filename) {
                logger_1.default.warn('getFileManager called with no filename.. Please report this issue. continuing.');
            }
            if (currentDirectory === undefined) {
                logger_1.default.warn('getFileManager called with null directory.. Please report this issue. continuing.');
            }
            var fileManagers = this.fileManagers;
            if (options.pluginManager) {
                fileManagers = [].concat(fileManagers).concat(options.pluginManager.getFileManagers());
            }
            for (var i = fileManagers.length - 1; i >= 0; i--) {
                var fileManager = fileManagers[i];
                if (fileManager[isSync ? 'supportsSync' : 'supports'](filename, currentDirectory, options, environment)) {
                    return fileManager;
                }
            }
            return null;
        };
        Environment.prototype.addFileManager = function (fileManager) {
            this.fileManagers.push(fileManager);
        };
        Environment.prototype.clearFileManagers = function () {
            this.fileManagers = [];
        };
        return Environment;
    }());
    exports.default = Environment;
    
},
/* less/lib/less/data/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var colors_1 = tslib_1.__importDefault(require(111) /* ./colors */);
    var unit_conversions_1 = tslib_1.__importDefault(require(112) /* ./unit-conversions */);
    exports.default = { colors: colors_1.default, unitConversions: unit_conversions_1.default };
    
},
/* less/lib/less/data/colors.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.default = {
        'aliceblue': '#f0f8ff',
        'antiquewhite': '#faebd7',
        'aqua': '#00ffff',
        'aquamarine': '#7fffd4',
        'azure': '#f0ffff',
        'beige': '#f5f5dc',
        'bisque': '#ffe4c4',
        'black': '#000000',
        'blanchedalmond': '#ffebcd',
        'blue': '#0000ff',
        'blueviolet': '#8a2be2',
        'brown': '#a52a2a',
        'burlywood': '#deb887',
        'cadetblue': '#5f9ea0',
        'chartreuse': '#7fff00',
        'chocolate': '#d2691e',
        'coral': '#ff7f50',
        'cornflowerblue': '#6495ed',
        'cornsilk': '#fff8dc',
        'crimson': '#dc143c',
        'cyan': '#00ffff',
        'darkblue': '#00008b',
        'darkcyan': '#008b8b',
        'darkgoldenrod': '#b8860b',
        'darkgray': '#a9a9a9',
        'darkgrey': '#a9a9a9',
        'darkgreen': '#006400',
        'darkkhaki': '#bdb76b',
        'darkmagenta': '#8b008b',
        'darkolivegreen': '#556b2f',
        'darkorange': '#ff8c00',
        'darkorchid': '#9932cc',
        'darkred': '#8b0000',
        'darksalmon': '#e9967a',
        'darkseagreen': '#8fbc8f',
        'darkslateblue': '#483d8b',
        'darkslategray': '#2f4f4f',
        'darkslategrey': '#2f4f4f',
        'darkturquoise': '#00ced1',
        'darkviolet': '#9400d3',
        'deeppink': '#ff1493',
        'deepskyblue': '#00bfff',
        'dimgray': '#696969',
        'dimgrey': '#696969',
        'dodgerblue': '#1e90ff',
        'firebrick': '#b22222',
        'floralwhite': '#fffaf0',
        'forestgreen': '#228b22',
        'fuchsia': '#ff00ff',
        'gainsboro': '#dcdcdc',
        'ghostwhite': '#f8f8ff',
        'gold': '#ffd700',
        'goldenrod': '#daa520',
        'gray': '#808080',
        'grey': '#808080',
        'green': '#008000',
        'greenyellow': '#adff2f',
        'honeydew': '#f0fff0',
        'hotpink': '#ff69b4',
        'indianred': '#cd5c5c',
        'indigo': '#4b0082',
        'ivory': '#fffff0',
        'khaki': '#f0e68c',
        'lavender': '#e6e6fa',
        'lavenderblush': '#fff0f5',
        'lawngreen': '#7cfc00',
        'lemonchiffon': '#fffacd',
        'lightblue': '#add8e6',
        'lightcoral': '#f08080',
        'lightcyan': '#e0ffff',
        'lightgoldenrodyellow': '#fafad2',
        'lightgray': '#d3d3d3',
        'lightgrey': '#d3d3d3',
        'lightgreen': '#90ee90',
        'lightpink': '#ffb6c1',
        'lightsalmon': '#ffa07a',
        'lightseagreen': '#20b2aa',
        'lightskyblue': '#87cefa',
        'lightslategray': '#778899',
        'lightslategrey': '#778899',
        'lightsteelblue': '#b0c4de',
        'lightyellow': '#ffffe0',
        'lime': '#00ff00',
        'limegreen': '#32cd32',
        'linen': '#faf0e6',
        'magenta': '#ff00ff',
        'maroon': '#800000',
        'mediumaquamarine': '#66cdaa',
        'mediumblue': '#0000cd',
        'mediumorchid': '#ba55d3',
        'mediumpurple': '#9370d8',
        'mediumseagreen': '#3cb371',
        'mediumslateblue': '#7b68ee',
        'mediumspringgreen': '#00fa9a',
        'mediumturquoise': '#48d1cc',
        'mediumvioletred': '#c71585',
        'midnightblue': '#191970',
        'mintcream': '#f5fffa',
        'mistyrose': '#ffe4e1',
        'moccasin': '#ffe4b5',
        'navajowhite': '#ffdead',
        'navy': '#000080',
        'oldlace': '#fdf5e6',
        'olive': '#808000',
        'olivedrab': '#6b8e23',
        'orange': '#ffa500',
        'orangered': '#ff4500',
        'orchid': '#da70d6',
        'palegoldenrod': '#eee8aa',
        'palegreen': '#98fb98',
        'paleturquoise': '#afeeee',
        'palevioletred': '#d87093',
        'papayawhip': '#ffefd5',
        'peachpuff': '#ffdab9',
        'peru': '#cd853f',
        'pink': '#ffc0cb',
        'plum': '#dda0dd',
        'powderblue': '#b0e0e6',
        'purple': '#800080',
        'rebeccapurple': '#663399',
        'red': '#ff0000',
        'rosybrown': '#bc8f8f',
        'royalblue': '#4169e1',
        'saddlebrown': '#8b4513',
        'salmon': '#fa8072',
        'sandybrown': '#f4a460',
        'seagreen': '#2e8b57',
        'seashell': '#fff5ee',
        'sienna': '#a0522d',
        'silver': '#c0c0c0',
        'skyblue': '#87ceeb',
        'slateblue': '#6a5acd',
        'slategray': '#708090',
        'slategrey': '#708090',
        'snow': '#fffafa',
        'springgreen': '#00ff7f',
        'steelblue': '#4682b4',
        'tan': '#d2b48c',
        'teal': '#008080',
        'thistle': '#d8bfd8',
        'tomato': '#ff6347',
        'turquoise': '#40e0d0',
        'violet': '#ee82ee',
        'wheat': '#f5deb3',
        'white': '#ffffff',
        'whitesmoke': '#f5f5f5',
        'yellow': '#ffff00',
        'yellowgreen': '#9acd32'
    };
    
},
/* less/lib/less/data/unit-conversions.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.default = {
        length: {
            'm': 1,
            'cm': 0.01,
            'mm': 0.001,
            'in': 0.0254,
            'px': 0.0254 / 96,
            'pt': 0.0254 / 72,
            'pc': 0.0254 / 72 * 12
        },
        duration: {
            's': 1,
            'ms': 0.001
        },
        angle: {
            'rad': 1 / (2 * Math.PI),
            'deg': 1 / 360,
            'grad': 1 / 400,
            'turn': 1
        }
    };
    
},
/* less/lib/less/tree/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var color_1 = tslib_1.__importDefault(require(115) /* ./color */);
    var atrule_1 = tslib_1.__importDefault(require(116) /* ./atrule */);
    var detached_ruleset_1 = tslib_1.__importDefault(require(148) /* ./detached-ruleset */);
    var operation_1 = tslib_1.__importDefault(require(149) /* ./operation */);
    var dimension_1 = tslib_1.__importDefault(require(150) /* ./dimension */);
    var unit_1 = tslib_1.__importDefault(require(151) /* ./unit */);
    var keyword_1 = tslib_1.__importDefault(require(143) /* ./keyword */);
    var variable_1 = tslib_1.__importDefault(require(152) /* ./variable */);
    var property_1 = tslib_1.__importDefault(require(156) /* ./property */);
    var ruleset_1 = tslib_1.__importDefault(require(140) /* ./ruleset */);
    var element_1 = tslib_1.__importDefault(require(118) /* ./element */);
    var attribute_1 = tslib_1.__importDefault(require(157) /* ./attribute */);
    var combinator_1 = tslib_1.__importDefault(require(120) /* ./combinator */);
    var selector_1 = tslib_1.__importDefault(require(117) /* ./selector */);
    var quoted_1 = tslib_1.__importDefault(require(158) /* ./quoted */);
    var expression_1 = tslib_1.__importDefault(require(155) /* ./expression */);
    var declaration_1 = tslib_1.__importDefault(require(141) /* ./declaration */);
    var call_1 = tslib_1.__importDefault(require(153) /* ./call */);
    var url_1 = tslib_1.__importDefault(require(159) /* ./url */);
    var import_1 = tslib_1.__importDefault(require(160) /* ./import */);
    var comment_1 = tslib_1.__importDefault(require(145) /* ./comment */);
    var anonymous_1 = tslib_1.__importDefault(require(144) /* ./anonymous */);
    var value_1 = tslib_1.__importDefault(require(142) /* ./value */);
    var javascript_1 = tslib_1.__importDefault(require(163) /* ./javascript */);
    var assignment_1 = tslib_1.__importDefault(require(165) /* ./assignment */);
    var condition_1 = tslib_1.__importDefault(require(166) /* ./condition */);
    var query_in_parens_1 = tslib_1.__importDefault(require(167) /* ./query-in-parens */);
    var paren_1 = tslib_1.__importDefault(require(119) /* ./paren */);
    var media_1 = tslib_1.__importDefault(require(161) /* ./media */);
    var container_1 = tslib_1.__importDefault(require(168) /* ./container */);
    var unicode_descriptor_1 = tslib_1.__importDefault(require(169) /* ./unicode-descriptor */);
    var negative_1 = tslib_1.__importDefault(require(170) /* ./negative */);
    var extend_1 = tslib_1.__importDefault(require(171) /* ./extend */);
    var variable_call_1 = tslib_1.__importDefault(require(172) /* ./variable-call */);
    var namespace_value_1 = tslib_1.__importDefault(require(173) /* ./namespace-value */);
    // mixins
    var mixin_call_1 = tslib_1.__importDefault(require(174) /* ./mixin-call */);
    var mixin_definition_1 = tslib_1.__importDefault(require(175) /* ./mixin-definition */);
    exports.default = {
        Node: node_1.default,
        Color: color_1.default,
        AtRule: atrule_1.default,
        DetachedRuleset: detached_ruleset_1.default,
        Operation: operation_1.default,
        Dimension: dimension_1.default,
        Unit: unit_1.default,
        Keyword: keyword_1.default,
        Variable: variable_1.default,
        Property: property_1.default,
        Ruleset: ruleset_1.default,
        Element: element_1.default,
        Attribute: attribute_1.default,
        Combinator: combinator_1.default,
        Selector: selector_1.default,
        Quoted: quoted_1.default,
        Expression: expression_1.default,
        Declaration: declaration_1.default,
        Call: call_1.default,
        URL: url_1.default,
        Import: import_1.default,
        Comment: comment_1.default,
        Anonymous: anonymous_1.default,
        Value: value_1.default,
        JavaScript: javascript_1.default,
        Assignment: assignment_1.default,
        Condition: condition_1.default,
        Paren: paren_1.default,
        Media: media_1.default,
        Container: container_1.default,
        QueryInParens: query_in_parens_1.default,
        UnicodeDescriptor: unicode_descriptor_1.default,
        Negative: negative_1.default,
        Extend: extend_1.default,
        VariableCall: variable_call_1.default,
        NamespaceValue: namespace_value_1.default,
        mixin: {
            Call: mixin_call_1.default,
            Definition: mixin_definition_1.default
        }
    };
    
},
/* less/lib/less/tree/node.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    /**
     * The reason why Node is a class and other nodes simply do not extend
     * from Node (since we're transpiling) is due to this issue:
     *
     * @see https://github.com/less/less.js/issues/3434
     */
    var Node = /** @class */ (function () {
        function Node() {
            this.parent = null;
            this.visibilityBlocks = undefined;
            this.nodeVisible = undefined;
            this.rootNode = null;
            this.parsed = null;
        }
        Object.defineProperty(Node.prototype, "currentFileInfo", {
            get: function () {
                return this.fileInfo();
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(Node.prototype, "index", {
            get: function () {
                return this.getIndex();
            },
            enumerable: false,
            configurable: true
        });
        Node.prototype.setParent = function (nodes, parent) {
            function set(node) {
                if (node && node instanceof Node) {
                    node.parent = parent;
                }
            }
            if (Array.isArray(nodes)) {
                nodes.forEach(set);
            }
            else {
                set(nodes);
            }
        };
        Node.prototype.getIndex = function () {
            return this._index || (this.parent && this.parent.getIndex()) || 0;
        };
        Node.prototype.fileInfo = function () {
            return this._fileInfo || (this.parent && this.parent.fileInfo()) || {};
        };
        Node.prototype.isRulesetLike = function () { return false; };
        Node.prototype.toCSS = function (context) {
            var strs = [];
            this.genCSS(context, {
                // remove when genCSS has JSDoc types
                // eslint-disable-next-line no-unused-vars
                add: function (chunk, fileInfo, index) {
                    strs.push(chunk);
                },
                isEmpty: function () {
                    return strs.length === 0;
                }
            });
            return strs.join('');
        };
        Node.prototype.genCSS = function (context, output) {
            output.add(this.value);
        };
        Node.prototype.accept = function (visitor) {
            this.value = visitor.visit(this.value);
        };
        Node.prototype.eval = function () { return this; };
        Node.prototype._operate = function (context, op, a, b) {
            switch (op) {
                case '+': return a + b;
                case '-': return a - b;
                case '*': return a * b;
                case '/': return a / b;
            }
        };
        Node.prototype.fround = function (context, value) {
            var precision = context && context.numPrecision;
            // add "epsilon" to ensure numbers like 1.000000005 (represented as 1.000000004999...) are properly rounded:
            return (precision) ? Number((value + 2e-16).toFixed(precision)) : value;
        };
        Node.compare = function (a, b) {
            /* returns:
             -1: a < b
             0: a = b
             1: a > b
             and *any* other value for a != b (e.g. undefined, NaN, -2 etc.) */
            if ((a.compare) &&
                // for "symmetric results" force toCSS-based comparison
                // of Quoted or Anonymous if either value is one of those
                !(b.type === 'Quoted' || b.type === 'Anonymous')) {
                return a.compare(b);
            }
            else if (b.compare) {
                return -b.compare(a);
            }
            else if (a.type !== b.type) {
                return undefined;
            }
            a = a.value;
            b = b.value;
            if (!Array.isArray(a)) {
                return a === b ? 0 : undefined;
            }
            if (a.length !== b.length) {
                return undefined;
            }
            for (var i = 0; i < a.length; i++) {
                if (Node.compare(a[i], b[i]) !== 0) {
                    return undefined;
                }
            }
            return 0;
        };
        Node.numericCompare = function (a, b) {
            return a < b ? -1
                : a === b ? 0
                    : a > b ? 1 : undefined;
        };
        // Returns true if this node represents root of ast imported by reference
        Node.prototype.blocksVisibility = function () {
            if (this.visibilityBlocks === undefined) {
                this.visibilityBlocks = 0;
            }
            return this.visibilityBlocks !== 0;
        };
        Node.prototype.addVisibilityBlock = function () {
            if (this.visibilityBlocks === undefined) {
                this.visibilityBlocks = 0;
            }
            this.visibilityBlocks = this.visibilityBlocks + 1;
        };
        Node.prototype.removeVisibilityBlock = function () {
            if (this.visibilityBlocks === undefined) {
                this.visibilityBlocks = 0;
            }
            this.visibilityBlocks = this.visibilityBlocks - 1;
        };
        // Turns on node visibility - if called node will be shown in output regardless
        // of whether it comes from import by reference or not
        Node.prototype.ensureVisibility = function () {
            this.nodeVisible = true;
        };
        // Turns off node visibility - if called node will NOT be shown in output regardless
        // of whether it comes from import by reference or not
        Node.prototype.ensureInvisibility = function () {
            this.nodeVisible = false;
        };
        // return values:
        // false - the node must not be visible
        // true - the node must be visible
        // undefined or null - the node has the same visibility as its parent
        Node.prototype.isVisible = function () {
            return this.nodeVisible;
        };
        Node.prototype.visibilityInfo = function () {
            return {
                visibilityBlocks: this.visibilityBlocks,
                nodeVisible: this.nodeVisible
            };
        };
        Node.prototype.copyVisibilityInfo = function (info) {
            if (!info) {
                return;
            }
            this.visibilityBlocks = info.visibilityBlocks;
            this.nodeVisible = info.nodeVisible;
        };
        return Node;
    }());
    exports.default = Node;
    
},
/* less/lib/less/tree/color.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var colors_1 = tslib_1.__importDefault(require(111) /* ../data/colors */);
    //
    // RGB Colors - #ff0014, #eee
    //
    var Color = function (rgb, a, originalForm) {
        var self = this;
        //
        // The end goal here, is to parse the arguments
        // into an integer triplet, such as `128, 255, 0`
        //
        // This facilitates operations and conversions.
        //
        if (Array.isArray(rgb)) {
            this.rgb = rgb;
        }
        else if (rgb.length >= 6) {
            this.rgb = [];
            rgb.match(/.{2}/g).map(function (c, i) {
                if (i < 3) {
                    self.rgb.push(parseInt(c, 16));
                }
                else {
                    self.alpha = (parseInt(c, 16)) / 255;
                }
            });
        }
        else {
            this.rgb = [];
            rgb.split('').map(function (c, i) {
                if (i < 3) {
                    self.rgb.push(parseInt(c + c, 16));
                }
                else {
                    self.alpha = (parseInt(c + c, 16)) / 255;
                }
            });
        }
        this.alpha = this.alpha || (typeof a === 'number' ? a : 1);
        if (typeof originalForm !== 'undefined') {
            this.value = originalForm;
        }
    };
    Color.prototype = Object.assign(new node_1.default(), {
        type: 'Color',
        luma: function () {
            var r = this.rgb[0] / 255, g = this.rgb[1] / 255, b = this.rgb[2] / 255;
            r = (r <= 0.03928) ? r / 12.92 : Math.pow(((r + 0.055) / 1.055), 2.4);
            g = (g <= 0.03928) ? g / 12.92 : Math.pow(((g + 0.055) / 1.055), 2.4);
            b = (b <= 0.03928) ? b / 12.92 : Math.pow(((b + 0.055) / 1.055), 2.4);
            return 0.2126 * r + 0.7152 * g + 0.0722 * b;
        },
        genCSS: function (context, output) {
            output.add(this.toCSS(context));
        },
        toCSS: function (context, doNotCompress) {
            var compress = context && context.compress && !doNotCompress;
            var color;
            var alpha;
            var colorFunction;
            var args = [];
            // `value` is set if this color was originally
            // converted from a named color string so we need
            // to respect this and try to output named color too.
            alpha = this.fround(context, this.alpha);
            if (this.value) {
                if (this.value.indexOf('rgb') === 0) {
                    if (alpha < 1) {
                        colorFunction = 'rgba';
                    }
                }
                else if (this.value.indexOf('hsl') === 0) {
                    if (alpha < 1) {
                        colorFunction = 'hsla';
                    }
                    else {
                        colorFunction = 'hsl';
                    }
                }
                else {
                    return this.value;
                }
            }
            else {
                if (alpha < 1) {
                    colorFunction = 'rgba';
                }
            }
            switch (colorFunction) {
                case 'rgba':
                    args = this.rgb.map(function (c) {
                        return clamp(Math.round(c), 255);
                    }).concat(clamp(alpha, 1));
                    break;
                case 'hsla':
                    args.push(clamp(alpha, 1));
                // eslint-disable-next-line no-fallthrough
                case 'hsl':
                    color = this.toHSL();
                    args = [
                        this.fround(context, color.h),
                        this.fround(context, color.s * 100) + "%",
                        this.fround(context, color.l * 100) + "%"
                    ].concat(args);
            }
            if (colorFunction) {
                // Values are capped between `0` and `255`, rounded and zero-padded.
                return colorFunction + "(" + args.join("," + (compress ? '' : ' ')) + ")";
            }
            color = this.toRGB();
            if (compress) {
                var splitcolor = color.split('');
                // Convert color to short format
                if (splitcolor[1] === splitcolor[2] && splitcolor[3] === splitcolor[4] && splitcolor[5] === splitcolor[6]) {
                    color = "#" + splitcolor[1] + splitcolor[3] + splitcolor[5];
                }
            }
            return color;
        },
        //
        // Operations have to be done per-channel, if not,
        // channels will spill onto each other. Once we have
        // our result, in the form of an integer triplet,
        // we create a new Color node to hold the result.
        //
        operate: function (context, op, other) {
            var rgb = new Array(3);
            var alpha = this.alpha * (1 - other.alpha) + other.alpha;
            for (var c = 0; c < 3; c++) {
                rgb[c] = this._operate(context, op, this.rgb[c], other.rgb[c]);
            }
            return new Color(rgb, alpha);
        },
        toRGB: function () {
            return toHex(this.rgb);
        },
        toHSL: function () {
            var r = this.rgb[0] / 255, g = this.rgb[1] / 255, b = this.rgb[2] / 255, a = this.alpha;
            var max = Math.max(r, g, b), min = Math.min(r, g, b);
            var h;
            var s;
            var l = (max + min) / 2;
            var d = max - min;
            if (max === min) {
                h = s = 0;
            }
            else {
                s = l > 0.5 ? d / (2 - max - min) : d / (max + min);
                switch (max) {
                    case r:
                        h = (g - b) / d + (g < b ? 6 : 0);
                        break;
                    case g:
                        h = (b - r) / d + 2;
                        break;
                    case b:
                        h = (r - g) / d + 4;
                        break;
                }
                h /= 6;
            }
            return { h: h * 360, s: s, l: l, a: a };
        },
        // Adapted from http://mjijackson.com/2008/02/rgb-to-hsl-and-rgb-to-hsv-color-model-conversion-algorithms-in-javascript
        toHSV: function () {
            var r = this.rgb[0] / 255, g = this.rgb[1] / 255, b = this.rgb[2] / 255, a = this.alpha;
            var max = Math.max(r, g, b), min = Math.min(r, g, b);
            var h;
            var s;
            var v = max;
            var d = max - min;
            if (max === 0) {
                s = 0;
            }
            else {
                s = d / max;
            }
            if (max === min) {
                h = 0;
            }
            else {
                switch (max) {
                    case r:
                        h = (g - b) / d + (g < b ? 6 : 0);
                        break;
                    case g:
                        h = (b - r) / d + 2;
                        break;
                    case b:
                        h = (r - g) / d + 4;
                        break;
                }
                h /= 6;
            }
            return { h: h * 360, s: s, v: v, a: a };
        },
        toARGB: function () {
            return toHex([this.alpha * 255].concat(this.rgb));
        },
        compare: function (x) {
            return (x.rgb &&
                x.rgb[0] === this.rgb[0] &&
                x.rgb[1] === this.rgb[1] &&
                x.rgb[2] === this.rgb[2] &&
                x.alpha === this.alpha) ? 0 : undefined;
        }
    });
    Color.fromKeyword = function (keyword) {
        var c;
        var key = keyword.toLowerCase();
        // eslint-disable-next-line no-prototype-builtins
        if (colors_1.default.hasOwnProperty(key)) {
            c = new Color(colors_1.default[key].slice(1));
        }
        else if (key === 'transparent') {
            c = new Color([0, 0, 0], 0);
        }
        if (c) {
            c.value = keyword;
            return c;
        }
    };
    function clamp(v, max) {
        return Math.min(Math.max(v, 0), max);
    }
    function toHex(v) {
        return "#" + v.map(function (c) {
            c = clamp(Math.round(c), 255);
            return (c < 16 ? '0' : '') + c.toString(16);
        }).join('');
    }
    exports.default = Color;
    
},
/* less/lib/less/tree/atrule.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var selector_1 = tslib_1.__importDefault(require(117) /* ./selector */);
    var ruleset_1 = tslib_1.__importDefault(require(140) /* ./ruleset */);
    var anonymous_1 = tslib_1.__importDefault(require(144) /* ./anonymous */);
    var AtRule = function (name, value, rules, index, currentFileInfo, debugInfo, isRooted, visibilityInfo) {
        var i;
        this.name = name;
        this.value = (value instanceof node_1.default) ? value : (value ? new anonymous_1.default(value) : value);
        if (rules) {
            if (Array.isArray(rules)) {
                this.rules = rules;
            }
            else {
                this.rules = [rules];
                this.rules[0].selectors = (new selector_1.default([], null, null, index, currentFileInfo)).createEmptySelectors();
            }
            for (i = 0; i < this.rules.length; i++) {
                this.rules[i].allowImports = true;
            }
            this.setParent(this.rules, this);
        }
        this._index = index;
        this._fileInfo = currentFileInfo;
        this.debugInfo = debugInfo;
        this.isRooted = isRooted || false;
        this.copyVisibilityInfo(visibilityInfo);
        this.allowRoot = true;
    };
    AtRule.prototype = Object.assign(new node_1.default(), {
        type: 'AtRule',
        accept: function (visitor) {
            var value = this.value, rules = this.rules;
            if (rules) {
                this.rules = visitor.visitArray(rules);
            }
            if (value) {
                this.value = visitor.visit(value);
            }
        },
        isRulesetLike: function () {
            return this.rules || !this.isCharset();
        },
        isCharset: function () {
            return '@charset' === this.name;
        },
        genCSS: function (context, output) {
            var value = this.value, rules = this.rules;
            output.add(this.name, this.fileInfo(), this.getIndex());
            if (value) {
                output.add(' ');
                value.genCSS(context, output);
            }
            if (rules) {
                this.outputRuleset(context, output, rules);
            }
            else {
                output.add(';');
            }
        },
        eval: function (context) {
            var mediaPathBackup, mediaBlocksBackup, value = this.value, rules = this.rules;
            // media stored inside other atrule should not bubble over it
            // backpup media bubbling information
            mediaPathBackup = context.mediaPath;
            mediaBlocksBackup = context.mediaBlocks;
            // deleted media bubbling information
            context.mediaPath = [];
            context.mediaBlocks = [];
            if (value) {
                value = value.eval(context);
            }
            if (rules) {
                // assuming that there is only one rule at this point - that is how parser constructs the rule
                rules = [rules[0].eval(context)];
                rules[0].root = true;
            }
            // restore media bubbling information
            context.mediaPath = mediaPathBackup;
            context.mediaBlocks = mediaBlocksBackup;
            return new AtRule(this.name, value, rules, this.getIndex(), this.fileInfo(), this.debugInfo, this.isRooted, this.visibilityInfo());
        },
        variable: function (name) {
            if (this.rules) {
                // assuming that there is only one rule at this point - that is how parser constructs the rule
                return ruleset_1.default.prototype.variable.call(this.rules[0], name);
            }
        },
        find: function () {
            if (this.rules) {
                // assuming that there is only one rule at this point - that is how parser constructs the rule
                return ruleset_1.default.prototype.find.apply(this.rules[0], arguments);
            }
        },
        rulesets: function () {
            if (this.rules) {
                // assuming that there is only one rule at this point - that is how parser constructs the rule
                return ruleset_1.default.prototype.rulesets.apply(this.rules[0]);
            }
        },
        outputRuleset: function (context, output, rules) {
            var ruleCnt = rules.length;
            var i;
            context.tabLevel = (context.tabLevel | 0) + 1;
            // Compressed
            if (context.compress) {
                output.add('{');
                for (i = 0; i < ruleCnt; i++) {
                    rules[i].genCSS(context, output);
                }
                output.add('}');
                context.tabLevel--;
                return;
            }
            // Non-compressed
            var tabSetStr = "\n" + Array(context.tabLevel).join('  '), tabRuleStr = tabSetStr + "  ";
            if (!ruleCnt) {
                output.add(" {" + tabSetStr + "}");
            }
            else {
                output.add(" {" + tabRuleStr);
                rules[0].genCSS(context, output);
                for (i = 1; i < ruleCnt; i++) {
                    output.add(tabRuleStr);
                    rules[i].genCSS(context, output);
                }
                output.add(tabSetStr + "}");
            }
            context.tabLevel--;
        }
    });
    exports.default = AtRule;
    
},
/* less/lib/less/tree/selector.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var element_1 = tslib_1.__importDefault(require(118) /* ./element */);
    var less_error_1 = tslib_1.__importDefault(require(121) /* ../less-error */);
    var utils = tslib_1.__importStar(require(122) /* ../utils */);
    var parser_1 = tslib_1.__importDefault(require(126) /* ../parser/parser */);
    var Selector = function (elements, extendList, condition, index, currentFileInfo, visibilityInfo) {
        this.extendList = extendList;
        this.condition = condition;
        this.evaldCondition = !condition;
        this._index = index;
        this._fileInfo = currentFileInfo;
        this.elements = this.getElements(elements);
        this.mixinElements_ = undefined;
        this.copyVisibilityInfo(visibilityInfo);
        this.setParent(this.elements, this);
    };
    Selector.prototype = Object.assign(new node_1.default(), {
        type: 'Selector',
        accept: function (visitor) {
            if (this.elements) {
                this.elements = visitor.visitArray(this.elements);
            }
            if (this.extendList) {
                this.extendList = visitor.visitArray(this.extendList);
            }
            if (this.condition) {
                this.condition = visitor.visit(this.condition);
            }
        },
        createDerived: function (elements, extendList, evaldCondition) {
            elements = this.getElements(elements);
            var newSelector = new Selector(elements, extendList || this.extendList, null, this.getIndex(), this.fileInfo(), this.visibilityInfo());
            newSelector.evaldCondition = (!utils.isNullOrUndefined(evaldCondition)) ? evaldCondition : this.evaldCondition;
            newSelector.mediaEmpty = this.mediaEmpty;
            return newSelector;
        },
        getElements: function (els) {
            if (!els) {
                return [new element_1.default('', '&', false, this._index, this._fileInfo)];
            }
            if (typeof els === 'string') {
                new parser_1.default(this.parse.context, this.parse.importManager, this._fileInfo, this._index).parseNode(els, ['selector'], function (err, result) {
                    if (err) {
                        throw new less_error_1.default({
                            index: err.index,
                            message: err.message
                        }, this.parse.imports, this._fileInfo.filename);
                    }
                    els = result[0].elements;
                });
            }
            return els;
        },
        createEmptySelectors: function () {
            var el = new element_1.default('', '&', false, this._index, this._fileInfo), sels = [new Selector([el], null, null, this._index, this._fileInfo)];
            sels[0].mediaEmpty = true;
            return sels;
        },
        match: function (other) {
            var elements = this.elements;
            var len = elements.length;
            var olen;
            var i;
            other = other.mixinElements();
            olen = other.length;
            if (olen === 0 || len < olen) {
                return 0;
            }
            else {
                for (i = 0; i < olen; i++) {
                    if (elements[i].value !== other[i]) {
                        return 0;
                    }
                }
            }
            return olen; // return number of matched elements
        },
        mixinElements: function () {
            if (this.mixinElements_) {
                return this.mixinElements_;
            }
            var elements = this.elements.map(function (v) {
                return v.combinator.value + (v.value.value || v.value);
            }).join('').match(/[,&#*.\w-]([\w-]|(\\.))*/g);
            if (elements) {
                if (elements[0] === '&') {
                    elements.shift();
                }
            }
            else {
                elements = [];
            }
            return (this.mixinElements_ = elements);
        },
        isJustParentSelector: function () {
            return !this.mediaEmpty &&
                this.elements.length === 1 &&
                this.elements[0].value === '&' &&
                (this.elements[0].combinator.value === ' ' || this.elements[0].combinator.value === '');
        },
        eval: function (context) {
            var evaldCondition = this.condition && this.condition.eval(context);
            var elements = this.elements;
            var extendList = this.extendList;
            elements = elements && elements.map(function (e) { return e.eval(context); });
            extendList = extendList && extendList.map(function (extend) { return extend.eval(context); });
            return this.createDerived(elements, extendList, evaldCondition);
        },
        genCSS: function (context, output) {
            var i, element;
            if ((!context || !context.firstSelector) && this.elements[0].combinator.value === '') {
                output.add(' ', this.fileInfo(), this.getIndex());
            }
            for (i = 0; i < this.elements.length; i++) {
                element = this.elements[i];
                element.genCSS(context, output);
            }
        },
        getIsOutput: function () {
            return this.evaldCondition;
        }
    });
    exports.default = Selector;
    
},
/* less/lib/less/tree/element.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var paren_1 = tslib_1.__importDefault(require(119) /* ./paren */);
    var combinator_1 = tslib_1.__importDefault(require(120) /* ./combinator */);
    var Element = function (combinator, value, isVariable, index, currentFileInfo, visibilityInfo) {
        this.combinator = combinator instanceof combinator_1.default ?
            combinator : new combinator_1.default(combinator);
        if (typeof value === 'string') {
            this.value = value.trim();
        }
        else if (value) {
            this.value = value;
        }
        else {
            this.value = '';
        }
        this.isVariable = isVariable;
        this._index = index;
        this._fileInfo = currentFileInfo;
        this.copyVisibilityInfo(visibilityInfo);
        this.setParent(this.combinator, this);
    };
    Element.prototype = Object.assign(new node_1.default(), {
        type: 'Element',
        accept: function (visitor) {
            var value = this.value;
            this.combinator = visitor.visit(this.combinator);
            if (typeof value === 'object') {
                this.value = visitor.visit(value);
            }
        },
        eval: function (context) {
            return new Element(this.combinator, this.value.eval ? this.value.eval(context) : this.value, this.isVariable, this.getIndex(), this.fileInfo(), this.visibilityInfo());
        },
        clone: function () {
            return new Element(this.combinator, this.value, this.isVariable, this.getIndex(), this.fileInfo(), this.visibilityInfo());
        },
        genCSS: function (context, output) {
            output.add(this.toCSS(context), this.fileInfo(), this.getIndex());
        },
        toCSS: function (context) {
            context = context || {};
            var value = this.value;
            var firstSelector = context.firstSelector;
            if (value instanceof paren_1.default) {
                // selector in parens should not be affected by outer selector
                // flags (breaks only interpolated selectors - see #1973)
                context.firstSelector = true;
            }
            value = value.toCSS ? value.toCSS(context) : value;
            context.firstSelector = firstSelector;
            if (value === '' && this.combinator.value.charAt(0) === '&') {
                return '';
            }
            else {
                return this.combinator.toCSS(context) + value;
            }
        }
    });
    exports.default = Element;
    
},
/* less/lib/less/tree/paren.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var Paren = function (node) {
        this.value = node;
    };
    Paren.prototype = Object.assign(new node_1.default(), {
        type: 'Paren',
        genCSS: function (context, output) {
            output.add('(');
            this.value.genCSS(context, output);
            output.add(')');
        },
        eval: function (context) {
            return new Paren(this.value.eval(context));
        }
    });
    exports.default = Paren;
    
},
/* less/lib/less/tree/combinator.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var _noSpaceCombinators = {
        '': true,
        ' ': true,
        '|': true
    };
    var Combinator = function (value) {
        if (value === ' ') {
            this.value = ' ';
            this.emptyOrWhitespace = true;
        }
        else {
            this.value = value ? value.trim() : '';
            this.emptyOrWhitespace = this.value === '';
        }
    };
    Combinator.prototype = Object.assign(new node_1.default(), {
        type: 'Combinator',
        genCSS: function (context, output) {
            var spaceOrEmpty = (context.compress || _noSpaceCombinators[this.value]) ? '' : ' ';
            output.add(spaceOrEmpty + this.value + spaceOrEmpty);
        }
    });
    exports.default = Combinator;
    
},
/* less/lib/less/less-error.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var utils = tslib_1.__importStar(require(122) /* ./utils */);
    var anonymousFunc = /(<anonymous>|Function):(\d+):(\d+)/;
    /**
     * This is a centralized class of any error that could be thrown internally (mostly by the parser).
     * Besides standard .message it keeps some additional data like a path to the file where the error
     * occurred along with line and column numbers.
     *
     * @class
     * @extends Error
     * @type {module.LessError}
     *
     * @prop {string} type
     * @prop {string} filename
     * @prop {number} index
     * @prop {number} line
     * @prop {number} column
     * @prop {number} callLine
     * @prop {number} callExtract
     * @prop {string[]} extract
     *
     * @param {Object} e              - An error object to wrap around or just a descriptive object
     * @param {Object} fileContentMap - An object with file contents in 'contents' property (like importManager) @todo - move to fileManager?
     * @param {string} [currentFilename]
     */
    var LessError = function (e, fileContentMap, currentFilename) {
        Error.call(this);
        var filename = e.filename || currentFilename;
        this.message = e.message;
        this.stack = e.stack;
        if (fileContentMap && filename) {
            var input = fileContentMap.contents[filename];
            var loc = utils.getLocation(e.index, input);
            var line = loc.line;
            var col = loc.column;
            var callLine = e.call && utils.getLocation(e.call, input).line;
            var lines = input ? input.split('\n') : '';
            this.type = e.type || 'Syntax';
            this.filename = filename;
            this.index = e.index;
            this.line = typeof line === 'number' ? line + 1 : null;
            this.column = col;
            if (!this.line && this.stack) {
                var found = this.stack.match(anonymousFunc);
                /**
                 * We have to figure out how this environment stringifies anonymous functions
                 * so we can correctly map plugin errors.
                 *
                 * Note, in Node 8, the output of anonymous funcs varied based on parameters
                 * being present or not, so we inject dummy params.
                 */
                var func = new Function('a', 'throw new Error()');
                var lineAdjust = 0;
                try {
                    func();
                }
                catch (e) {
                    var match = e.stack.match(anonymousFunc);
                    lineAdjust = 1 - parseInt(match[2]);
                }
                if (found) {
                    if (found[2]) {
                        this.line = parseInt(found[2]) + lineAdjust;
                    }
                    if (found[3]) {
                        this.column = parseInt(found[3]);
                    }
                }
            }
            this.callLine = callLine + 1;
            this.callExtract = lines[callLine];
            this.extract = [
                lines[this.line - 2],
                lines[this.line - 1],
                lines[this.line]
            ];
        }
    };
    if (typeof Object.create === 'undefined') {
        var F = function () { };
        F.prototype = Error.prototype;
        LessError.prototype = new F();
    }
    else {
        LessError.prototype = Object.create(Error.prototype);
    }
    LessError.prototype.constructor = LessError;
    /**
     * An overridden version of the default Object.prototype.toString
     * which uses additional information to create a helpful message.
     *
     * @param {Object} options
     * @returns {string}
     */
    LessError.prototype.toString = function (options) {
        options = options || {};
        var message = '';
        var extract = this.extract || [];
        var error = [];
        var stylize = function (str) { return str; };
        if (options.stylize) {
            var type = typeof options.stylize;
            if (type !== 'function') {
                throw Error("options.stylize should be a function, got a " + type + "!");
            }
            stylize = options.stylize;
        }
        if (this.line !== null) {
            if (typeof extract[0] === 'string') {
                error.push(stylize(this.line - 1 + " " + extract[0], 'grey'));
            }
            if (typeof extract[1] === 'string') {
                var errorTxt = this.line + " ";
                if (extract[1]) {
                    errorTxt += extract[1].slice(0, this.column) +
                        stylize(stylize(stylize(extract[1].substr(this.column, 1), 'bold') +
                            extract[1].slice(this.column + 1), 'red'), 'inverse');
                }
                error.push(errorTxt);
            }
            if (typeof extract[2] === 'string') {
                error.push(stylize(this.line + 1 + " " + extract[2], 'grey'));
            }
            error = error.join('\n') + stylize('', 'reset') + "\n";
        }
        message += stylize(this.type + "Error: " + this.message, 'red');
        if (this.filename) {
            message += stylize(' in ', 'red') + this.filename;
        }
        if (this.line) {
            message += stylize(" on line " + this.line + ", column " + (this.column + 1) + ":", 'grey');
        }
        message += "\n" + error;
        if (this.callLine) {
            message += stylize('from ', 'red') + (this.filename || '') + "/n";
            message += stylize(this.callLine, 'grey') + " " + this.callExtract + "/n";
        }
        return message;
    };
    exports.default = LessError;
    
},
/* less/lib/less/utils.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.isNullOrUndefined = exports.flattenArray = exports.merge = exports.copyOptions = exports.defaults = exports.clone = exports.copyArray = exports.getLocation = void 0;
    var tslib_1 = require(63) /* tslib */;
    /* jshint proto: true */
    var Constants = tslib_1.__importStar(require(123) /* ./constants */);
    var copy_anything_1 = require(124) /* copy-anything */;
    function getLocation(index, inputStream) {
        var n = index + 1;
        var line = null;
        var column = -1;
        while (--n >= 0 && inputStream.charAt(n) !== '\n') {
            column++;
        }
        if (typeof index === 'number') {
            line = (inputStream.slice(0, index).match(/\n/g) || '').length;
        }
        return {
            line: line,
            column: column
        };
    }
    exports.getLocation = getLocation;
    function copyArray(arr) {
        var i;
        var length = arr.length;
        var copy = new Array(length);
        for (i = 0; i < length; i++) {
            copy[i] = arr[i];
        }
        return copy;
    }
    exports.copyArray = copyArray;
    function clone(obj) {
        var cloned = {};
        for (var prop in obj) {
            if (Object.prototype.hasOwnProperty.call(obj, prop)) {
                cloned[prop] = obj[prop];
            }
        }
        return cloned;
    }
    exports.clone = clone;
    function defaults(obj1, obj2) {
        var newObj = obj2 || {};
        if (!obj2._defaults) {
            newObj = {};
            var defaults_1 = copy_anything_1.copy(obj1);
            newObj._defaults = defaults_1;
            var cloned = obj2 ? copy_anything_1.copy(obj2) : {};
            Object.assign(newObj, defaults_1, cloned);
        }
        return newObj;
    }
    exports.defaults = defaults;
    function copyOptions(obj1, obj2) {
        if (obj2 && obj2._defaults) {
            return obj2;
        }
        var opts = defaults(obj1, obj2);
        if (opts.strictMath) {
            opts.math = Constants.Math.PARENS;
        }
        // Back compat with changed relativeUrls option
        if (opts.relativeUrls) {
            opts.rewriteUrls = Constants.RewriteUrls.ALL;
        }
        if (typeof opts.math === 'string') {
            switch (opts.math.toLowerCase()) {
                case 'always':
                    opts.math = Constants.Math.ALWAYS;
                    break;
                case 'parens-division':
                    opts.math = Constants.Math.PARENS_DIVISION;
                    break;
                case 'strict':
                case 'parens':
                    opts.math = Constants.Math.PARENS;
                    break;
                default:
                    opts.math = Constants.Math.PARENS;
            }
        }
        if (typeof opts.rewriteUrls === 'string') {
            switch (opts.rewriteUrls.toLowerCase()) {
                case 'off':
                    opts.rewriteUrls = Constants.RewriteUrls.OFF;
                    break;
                case 'local':
                    opts.rewriteUrls = Constants.RewriteUrls.LOCAL;
                    break;
                case 'all':
                    opts.rewriteUrls = Constants.RewriteUrls.ALL;
                    break;
            }
        }
        return opts;
    }
    exports.copyOptions = copyOptions;
    function merge(obj1, obj2) {
        for (var prop in obj2) {
            if (Object.prototype.hasOwnProperty.call(obj2, prop)) {
                obj1[prop] = obj2[prop];
            }
        }
        return obj1;
    }
    exports.merge = merge;
    function flattenArray(arr, result) {
        if (result === void 0) {
            result = [];
        }
        for (var i = 0, length_1 = arr.length; i < length_1; i++) {
            var value = arr[i];
            if (Array.isArray(value)) {
                flattenArray(value, result);
            }
            else {
                if (value !== undefined) {
                    result.push(value);
                }
            }
        }
        return result;
    }
    exports.flattenArray = flattenArray;
    function isNullOrUndefined(val) {
        return val === null || val === undefined;
    }
    exports.isNullOrUndefined = isNullOrUndefined;
    
},
/* less/lib/less/constants.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.RewriteUrls = exports.Math = void 0;
    exports.Math = {
        ALWAYS: 0,
        PARENS_DIVISION: 1,
        PARENS: 2
        // removed - STRICT_LEGACY: 3
    };
    exports.RewriteUrls = {
        OFF: 0,
        LOCAL: 1,
        ALL: 2
    };
    
},
/* copy-anything/dist/index.cjs */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    Object.defineProperty(exports, '__esModule', { value: true });
    var isWhat = require(125) /* is-what */;
    function assignProp(carry, key, newVal, originalObject, includeNonenumerable) {
        const propType = {}.propertyIsEnumerable.call(originalObject, key)
            ? 'enumerable'
            : 'nonenumerable';
        if (propType === 'enumerable')
            carry[key] = newVal;
        if (includeNonenumerable && propType === 'nonenumerable') {
            Object.defineProperty(carry, key, {
                value: newVal,
                enumerable: false,
                writable: true,
                configurable: true,
            });
        }
    }
    /**
     * Copy (clone) an object and all its props recursively to get rid of any prop referenced of the original object. Arrays are also cloned, however objects inside arrays are still linked.
     *
     * @export
     * @template T
     * @param {T} target Target can be anything
     * @param {Options} [options = {}] Options can be `props` or `nonenumerable`
     * @returns {T} the target with replaced values
     * @export
     */
    function copy(target, options = {}) {
        if (isWhat.isArray(target)) {
            return target.map((item) => copy(item, options));
        }
        if (!isWhat.isPlainObject(target)) {
            return target;
        }
        const props = Object.getOwnPropertyNames(target);
        const symbols = Object.getOwnPropertySymbols(target);
        return [...props, ...symbols].reduce((carry, key) => {
            if (isWhat.isArray(options.props) && !options.props.includes(key)) {
                return carry;
            }
            const val = target[key];
            const newVal = copy(val, options);
            assignProp(carry, key, newVal, target, options.nonenumerable);
            return carry;
        }, {});
    }
    exports.copy = copy;
},
/* is-what/dist/index.cjs.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    Object.defineProperty(exports, '__esModule', { value: true });
    /**
     * Returns the object type of the given payload
     *
     * @param {*} payload
     * @returns {string}
     */
    function getType(payload) {
        return Object.prototype.toString.call(payload).slice(8, -1);
    }
    /**
     * Returns whether the payload is undefined
     *
     * @param {*} payload
     * @returns {payload is undefined}
     */
    function isUndefined(payload) {
        return getType(payload) === 'Undefined';
    }
    /**
     * Returns whether the payload is null
     *
     * @param {*} payload
     * @returns {payload is null}
     */
    function isNull(payload) {
        return getType(payload) === 'Null';
    }
    /**
     * Returns whether the payload is a plain JavaScript object (excluding special classes or objects with other prototypes)
     *
     * @param {*} payload
     * @returns {payload is PlainObject}
     */
    function isPlainObject(payload) {
        if (getType(payload) !== 'Object')
            return false;
        return payload.constructor === Object && Object.getPrototypeOf(payload) === Object.prototype;
    }
    /**
     * Returns whether the payload is a plain JavaScript object (excluding special classes or objects with other prototypes)
     *
     * @param {*} payload
     * @returns {payload is PlainObject}
     */
    function isObject(payload) {
        return isPlainObject(payload);
    }
    /**
     * Returns whether the payload is a an empty object (excluding special classes or objects with other prototypes)
     *
     * @param {*} payload
     * @returns {payload is { [K in any]: never }}
     */
    function isEmptyObject(payload) {
        return isPlainObject(payload) && Object.keys(payload).length === 0;
    }
    /**
     * Returns whether the payload is a an empty object (excluding special classes or objects with other prototypes)
     *
     * @param {*} payload
     * @returns {payload is PlainObject}
     */
    function isFullObject(payload) {
        return isPlainObject(payload) && Object.keys(payload).length > 0;
    }
    /**
     * Returns whether the payload is an any kind of object (including special classes or objects with different prototypes)
     *
     * @param {*} payload
     * @returns {payload is PlainObject}
     */
    function isAnyObject(payload) {
        return getType(payload) === 'Object';
    }
    /**
     * Returns whether the payload is an object like a type passed in < >
     *
     * Usage: isObjectLike<{id: any}>(payload) // will make sure it's an object and has an `id` prop.
     *
     * @template T this must be passed in < >
     * @param {*} payload
     * @returns {payload is T}
     */
    function isObjectLike(payload) {
        return isAnyObject(payload);
    }
    /**
     * Returns whether the payload is a function (regular or async)
     *
     * @param {*} payload
     * @returns {payload is AnyFunction}
     */
    function isFunction(payload) {
        return typeof payload === 'function';
    }
    /**
     * Returns whether the payload is an array
     *
     * @param {any} payload
     * @returns {payload is any[]}
     */
    function isArray(payload) {
        return getType(payload) === 'Array';
    }
    /**
     * Returns whether the payload is a an array with at least 1 item
     *
     * @param {*} payload
     * @returns {payload is any[]}
     */
    function isFullArray(payload) {
        return isArray(payload) && payload.length > 0;
    }
    /**
     * Returns whether the payload is a an empty array
     *
     * @param {*} payload
     * @returns {payload is []}
     */
    function isEmptyArray(payload) {
        return isArray(payload) && payload.length === 0;
    }
    /**
     * Returns whether the payload is a string
     *
     * @param {*} payload
     * @returns {payload is string}
     */
    function isString(payload) {
        return getType(payload) === 'String';
    }
    /**
     * Returns whether the payload is a string, BUT returns false for ''
     *
     * @param {*} payload
     * @returns {payload is string}
     */
    function isFullString(payload) {
        return isString(payload) && payload !== '';
    }
    /**
     * Returns whether the payload is ''
     *
     * @param {*} payload
     * @returns {payload is string}
     */
    function isEmptyString(payload) {
        return payload === '';
    }
    /**
     * Returns whether the payload is a number (but not NaN)
     *
     * This will return `false` for `NaN`!!
     *
     * @param {*} payload
     * @returns {payload is number}
     */
    function isNumber(payload) {
        return getType(payload) === 'Number' && !isNaN(payload);
    }
    /**
     * Returns whether the payload is a boolean
     *
     * @param {*} payload
     * @returns {payload is boolean}
     */
    function isBoolean(payload) {
        return getType(payload) === 'Boolean';
    }
    /**
     * Returns whether the payload is a regular expression (RegExp)
     *
     * @param {*} payload
     * @returns {payload is RegExp}
     */
    function isRegExp(payload) {
        return getType(payload) === 'RegExp';
    }
    /**
     * Returns whether the payload is a Map
     *
     * @param {*} payload
     * @returns {payload is Map<any, any>}
     */
    function isMap(payload) {
        return getType(payload) === 'Map';
    }
    /**
     * Returns whether the payload is a WeakMap
     *
     * @param {*} payload
     * @returns {payload is WeakMap<any, any>}
     */
    function isWeakMap(payload) {
        return getType(payload) === 'WeakMap';
    }
    /**
     * Returns whether the payload is a Set
     *
     * @param {*} payload
     * @returns {payload is Set<any>}
     */
    function isSet(payload) {
        return getType(payload) === 'Set';
    }
    /**
     * Returns whether the payload is a WeakSet
     *
     * @param {*} payload
     * @returns {payload is WeakSet<any>}
     */
    function isWeakSet(payload) {
        return getType(payload) === 'WeakSet';
    }
    /**
     * Returns whether the payload is a Symbol
     *
     * @param {*} payload
     * @returns {payload is symbol}
     */
    function isSymbol(payload) {
        return getType(payload) === 'Symbol';
    }
    /**
     * Returns whether the payload is a Date, and that the date is valid
     *
     * @param {*} payload
     * @returns {payload is Date}
     */
    function isDate(payload) {
        return getType(payload) === 'Date' && !isNaN(payload);
    }
    /**
     * Returns whether the payload is a Blob
     *
     * @param {*} payload
     * @returns {payload is Blob}
     */
    function isBlob(payload) {
        return getType(payload) === 'Blob';
    }
    /**
     * Returns whether the payload is a File
     *
     * @param {*} payload
     * @returns {payload is File}
     */
    function isFile(payload) {
        return getType(payload) === 'File';
    }
    /**
     * Returns whether the payload is a Promise
     *
     * @param {*} payload
     * @returns {payload is Promise<any>}
     */
    function isPromise(payload) {
        return getType(payload) === 'Promise';
    }
    /**
     * Returns whether the payload is an Error
     *
     * @param {*} payload
     * @returns {payload is Error}
     */
    function isError(payload) {
        return getType(payload) === 'Error';
    }
    /**
     * Returns whether the payload is literally the value `NaN` (it's `NaN` and also a `number`)
     *
     * @param {*} payload
     * @returns {payload is typeof NaN}
     */
    function isNaNValue(payload) {
        return getType(payload) === 'Number' && isNaN(payload);
    }
    /**
     * Returns whether the payload is a primitive type (eg. Boolean | Null | Undefined | Number | String | Symbol)
     *
     * @param {*} payload
     * @returns {(payload is boolean | null | undefined | number | string | symbol)}
     */
    function isPrimitive(payload) {
        return (isBoolean(payload) ||
            isNull(payload) ||
            isUndefined(payload) ||
            isNumber(payload) ||
            isString(payload) ||
            isSymbol(payload));
    }
    /**
     * Returns true whether the payload is null or undefined
     *
     * @param {*} payload
     * @returns {(payload is null | undefined)}
     */
    var isNullOrUndefined = isOneOf(isNull, isUndefined);
    function isOneOf(a, b, c, d, e) {
        return function (value) {
            return a(value) || b(value) || (!!c && c(value)) || (!!d && d(value)) || (!!e && e(value));
        };
    }
    /**
     * Does a generic check to check that the given payload is of a given type.
     * In cases like Number, it will return true for NaN as NaN is a Number (thanks javascript!);
     * It will, however, differentiate between object and null
     *
     * @template T
     * @param {*} payload
     * @param {T} type
     * @throws {TypeError} Will throw type error if type is an invalid type
     * @returns {payload is T}
     */
    function isType(payload, type) {
        if (!(type instanceof Function)) {
            throw new TypeError('Type must be a function');
        }
        if (!Object.prototype.hasOwnProperty.call(type, 'prototype')) {
            throw new TypeError('Type is not a class');
        }
        // Classes usually have names (as functions usually have names)
        var name = type.name;
        return getType(payload) === name || Boolean(payload && payload.constructor === type);
    }
    exports.getType = getType;
    exports.isAnyObject = isAnyObject;
    exports.isArray = isArray;
    exports.isBlob = isBlob;
    exports.isBoolean = isBoolean;
    exports.isDate = isDate;
    exports.isEmptyArray = isEmptyArray;
    exports.isEmptyObject = isEmptyObject;
    exports.isEmptyString = isEmptyString;
    exports.isError = isError;
    exports.isFile = isFile;
    exports.isFullArray = isFullArray;
    exports.isFullObject = isFullObject;
    exports.isFullString = isFullString;
    exports.isFunction = isFunction;
    exports.isMap = isMap;
    exports.isNaNValue = isNaNValue;
    exports.isNull = isNull;
    exports.isNullOrUndefined = isNullOrUndefined;
    exports.isNumber = isNumber;
    exports.isObject = isObject;
    exports.isObjectLike = isObjectLike;
    exports.isOneOf = isOneOf;
    exports.isPlainObject = isPlainObject;
    exports.isPrimitive = isPrimitive;
    exports.isPromise = isPromise;
    exports.isRegExp = isRegExp;
    exports.isSet = isSet;
    exports.isString = isString;
    exports.isSymbol = isSymbol;
    exports.isType = isType;
    exports.isUndefined = isUndefined;
    exports.isWeakMap = isWeakMap;
    exports.isWeakSet = isWeakSet;
},
/* less/lib/less/parser/parser.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var less_error_1 = tslib_1.__importDefault(require(121) /* ../less-error */);
    var tree_1 = tslib_1.__importDefault(require(113) /* ../tree */);
    var visitors_1 = tslib_1.__importDefault(require(127) /* ../visitors */);
    var parser_input_1 = tslib_1.__importDefault(require(136) /* ./parser-input */);
    var utils = tslib_1.__importStar(require(122) /* ../utils */);
    var function_registry_1 = tslib_1.__importDefault(require(138) /* ../functions/function-registry */);
    var atrule_syntax_1 = require(139) /* ../tree/atrule-syntax */;
    //
    // less.js - parser
    //
    //    A relatively straight-forward predictive parser.
    //    There is no tokenization/lexing stage, the input is parsed
    //    in one sweep.
    //
    //    To make the parser fast enough to run in the browser, several
    //    optimization had to be made:
    //
    //    - Matching and slicing on a huge input is often cause of slowdowns.
    //      The solution is to chunkify the input into smaller strings.
    //      The chunks are stored in the `chunks` var,
    //      `j` holds the current chunk index, and `currentPos` holds
    //      the index of the current chunk in relation to `input`.
    //      This gives us an almost 4x speed-up.
    //
    //    - In many cases, we don't need to match individual tokens;
    //      for example, if a value doesn't hold any variables, operations
    //      or dynamic references, the parser can effectively 'skip' it,
    //      treating it as a literal.
    //      An example would be '1px solid #000' - which evaluates to itself,
    //      we don't need to know what the individual components are.
    //      The drawback, of course is that you don't get the benefits of
    //      syntax-checking on the CSS. This gives us a 50% speed-up in the parser,
    //      and a smaller speed-up in the code-gen.
    //
    //
    //    Token matching is done with the `$` function, which either takes
    //    a terminal string or regexp, or a non-terminal function to call.
    //    It also takes care of moving all the indices forwards.
    //
    var Parser = function Parser(context, imports, fileInfo, currentIndex) {
        currentIndex = currentIndex || 0;
        var parsers;
        var parserInput = parser_input_1.default();
        function error(msg, type) {
            throw new less_error_1.default({
                index: parserInput.i,
                filename: fileInfo.filename,
                type: type || 'Syntax',
                message: msg
            }, imports);
        }
        function expect(arg, msg) {
            // some older browsers return typeof 'function' for RegExp
            var result = (arg instanceof Function) ? arg.call(parsers) : parserInput.$re(arg);
            if (result) {
                return result;
            }
            error(msg || (typeof arg === 'string'
                ? "expected '" + arg + "' got '" + parserInput.currentChar() + "'"
                : 'unexpected token'));
        }
        // Specialization of expect()
        function expectChar(arg, msg) {
            if (parserInput.$char(arg)) {
                return arg;
            }
            error(msg || "expected '" + arg + "' got '" + parserInput.currentChar() + "'");
        }
        function getDebugInfo(index) {
            var filename = fileInfo.filename;
            return {
                lineNumber: utils.getLocation(index, parserInput.getInput()).line + 1,
                fileName: filename
            };
        }
        /**
         *  Used after initial parsing to create nodes on the fly
         *
         *  @param {String} str          - string to parse
         *  @param {Array}  parseList    - array of parsers to run input through e.g. ["value", "important"]
         *  @param {Number} currentIndex - start number to begin indexing
         *  @param {Object} fileInfo     - fileInfo to attach to created nodes
         */
        function parseNode(str, parseList, callback) {
            var result;
            var returnNodes = [];
            var parser = parserInput;
            try {
                parser.start(str, false, function fail(msg, index) {
                    callback({
                        message: msg,
                        index: index + currentIndex
                    });
                });
                for (var x = 0, p = void 0; (p = parseList[x]); x++) {
                    result = parsers[p]();
                    returnNodes.push(result || null);
                }
                var endInfo = parser.end();
                if (endInfo.isFinished) {
                    callback(null, returnNodes);
                }
                else {
                    callback(true, null);
                }
            }
            catch (e) {
                throw new less_error_1.default({
                    index: e.index + currentIndex,
                    message: e.message
                }, imports, fileInfo.filename);
            }
        }
        //
        // The Parser
        //
        return {
            parserInput: parserInput,
            imports: imports,
            fileInfo: fileInfo,
            parseNode: parseNode,
            //
            // Parse an input string into an abstract syntax tree,
            // @param str A string containing 'less' markup
            // @param callback call `callback` when done.
            // @param [additionalData] An optional map which can contains vars - a map (key, value) of variables to apply
            //
            parse: function (str, callback, additionalData) {
                var root;
                var err = null;
                var globalVars;
                var modifyVars;
                var ignored;
                var preText = '';
                // Optionally disable @plugin parsing
                if (additionalData && additionalData.disablePluginRule) {
                    parsers.plugin = function () {
                        var dir = parserInput.$re(/^@plugin?\s+/);
                        if (dir) {
                            error('@plugin statements are not allowed when disablePluginRule is set to true');
                        }
                    };
                }
                globalVars = (additionalData && additionalData.globalVars) ? Parser.serializeVars(additionalData.globalVars) + "\n" : '';
                modifyVars = (additionalData && additionalData.modifyVars) ? "\n" + Parser.serializeVars(additionalData.modifyVars) : '';
                if (context.pluginManager) {
                    var preProcessors = context.pluginManager.getPreProcessors();
                    for (var i = 0; i < preProcessors.length; i++) {
                        str = preProcessors[i].process(str, { context: context, imports: imports, fileInfo: fileInfo });
                    }
                }
                if (globalVars || (additionalData && additionalData.banner)) {
                    preText = ((additionalData && additionalData.banner) ? additionalData.banner : '') + globalVars;
                    ignored = imports.contentsIgnoredChars;
                    ignored[fileInfo.filename] = ignored[fileInfo.filename] || 0;
                    ignored[fileInfo.filename] += preText.length;
                }
                str = str.replace(/\r\n?/g, '\n');
                // Remove potential UTF Byte Order Mark
                str = preText + str.replace(/^\uFEFF/, '') + modifyVars;
                imports.contents[fileInfo.filename] = str;
                // Start with the primary rule.
                // The whole syntax tree is held under a Ruleset node,
                // with the `root` property set to true, so no `{}` are
                // output. The callback is called when the input is parsed.
                try {
                    parserInput.start(str, context.chunkInput, function fail(msg, index) {
                        throw new less_error_1.default({
                            index: index,
                            type: 'Parse',
                            message: msg,
                            filename: fileInfo.filename
                        }, imports);
                    });
                    tree_1.default.Node.prototype.parse = this;
                    root = new tree_1.default.Ruleset(null, this.parsers.primary());
                    tree_1.default.Node.prototype.rootNode = root;
                    root.root = true;
                    root.firstRoot = true;
                    root.functionRegistry = function_registry_1.default.inherit();
                }
                catch (e) {
                    return callback(new less_error_1.default(e, imports, fileInfo.filename));
                }
                // If `i` is smaller than the `input.length - 1`,
                // it means the parser wasn't able to parse the whole
                // string, so we've got a parsing error.
                //
                // We try to extract a \n delimited string,
                // showing the line where the parse error occurred.
                // We split it up into two parts (the part which parsed,
                // and the part which didn't), so we can color them differently.
                var endInfo = parserInput.end();
                if (!endInfo.isFinished) {
                    var message = endInfo.furthestPossibleErrorMessage;
                    if (!message) {
                        message = 'Unrecognised input';
                        if (endInfo.furthestChar === '}') {
                            message += '. Possibly missing opening \'{\'';
                        }
                        else if (endInfo.furthestChar === ')') {
                            message += '. Possibly missing opening \'(\'';
                        }
                        else if (endInfo.furthestReachedEnd) {
                            message += '. Possibly missing something';
                        }
                    }
                    err = new less_error_1.default({
                        type: 'Parse',
                        message: message,
                        index: endInfo.furthest,
                        filename: fileInfo.filename
                    }, imports);
                }
                var finish = function (e) {
                    e = err || e || imports.error;
                    if (e) {
                        if (!(e instanceof less_error_1.default)) {
                            e = new less_error_1.default(e, imports, fileInfo.filename);
                        }
                        return callback(e);
                    }
                    else {
                        return callback(null, root);
                    }
                };
                if (context.processImports !== false) {
                    new visitors_1.default.ImportVisitor(imports, finish)
                        .run(root);
                }
                else {
                    return finish();
                }
            },
            //
            // Here in, the parsing rules/functions
            //
            // The basic structure of the syntax tree generated is as follows:
            //
            //   Ruleset ->  Declaration -> Value -> Expression -> Entity
            //
            // Here's some Less code:
            //
            //    .class {
            //      color: #fff;
            //      border: 1px solid #000;
            //      width: @w + 4px;
            //      > .child {...}
            //    }
            //
            // And here's what the parse tree might look like:
            //
            //     Ruleset (Selector '.class', [
            //         Declaration ("color",  Value ([Expression [Color #fff]]))
            //         Declaration ("border", Value ([Expression [Dimension 1px][Keyword "solid"][Color #000]]))
            //         Declaration ("width",  Value ([Expression [Operation " + " [Variable "@w"][Dimension 4px]]]))
            //         Ruleset (Selector [Element '>', '.child'], [...])
            //     ])
            //
            //  In general, most rules will try to parse a token with the `$re()` function, and if the return
            //  value is truly, will return a new node, of the relevant type. Sometimes, we need to check
            //  first, before parsing, that's when we use `peek()`.
            //
            parsers: parsers = {
                //
                // The `primary` rule is the *entry* and *exit* point of the parser.
                // The rules here can appear at any level of the parse tree.
                //
                // The recursive nature of the grammar is an interplay between the `block`
                // rule, which represents `{ ... }`, the `ruleset` rule, and this `primary` rule,
                // as represented by this simplified grammar:
                //
                //     primary  →  (ruleset | declaration)+
                //     ruleset  →  selector+ block
                //     block    →  '{' primary '}'
                //
                // Only at one point is the primary rule not called from the
                // block rule: at the root level.
                //
                primary: function () {
                    var mixin = this.mixin;
                    var root = [];
                    var node;
                    while (true) {
                        while (true) {
                            node = this.comment();
                            if (!node) {
                                break;
                            }
                            root.push(node);
                        }
                        // always process comments before deciding if finished
                        if (parserInput.finished) {
                            break;
                        }
                        if (parserInput.peek('}')) {
                            break;
                        }
                        node = this.extendRule();
                        if (node) {
                            root = root.concat(node);
                            continue;
                        }
                        node = mixin.definition() || this.declaration() || mixin.call(false, false) ||
                            this.ruleset() || this.variableCall() || this.entities.call() || this.atrule();
                        if (node) {
                            root.push(node);
                        }
                        else {
                            var foundSemiColon = false;
                            while (parserInput.$char(';')) {
                                foundSemiColon = true;
                            }
                            if (!foundSemiColon) {
                                break;
                            }
                        }
                    }
                    return root;
                },
                // comments are collected by the main parsing mechanism and then assigned to nodes
                // where the current structure allows it
                comment: function () {
                    if (parserInput.commentStore.length) {
                        var comment = parserInput.commentStore.shift();
                        return new (tree_1.default.Comment)(comment.text, comment.isLineComment, comment.index + currentIndex, fileInfo);
                    }
                },
                //
                // Entities are tokens which can be found inside an Expression
                //
                entities: {
                    mixinLookup: function () {
                        return parsers.mixin.call(true, true);
                    },
                    //
                    // A string, which supports escaping " and '
                    //
                    //     "milky way" 'he\'s the one!'
                    //
                    quoted: function (forceEscaped) {
                        var str;
                        var index = parserInput.i;
                        var isEscaped = false;
                        parserInput.save();
                        if (parserInput.$char('~')) {
                            isEscaped = true;
                        }
                        else if (forceEscaped) {
                            parserInput.restore();
                            return;
                        }
                        str = parserInput.$quoted();
                        if (!str) {
                            parserInput.restore();
                            return;
                        }
                        parserInput.forget();
                        return new (tree_1.default.Quoted)(str.charAt(0), str.substr(1, str.length - 2), isEscaped, index + currentIndex, fileInfo);
                    },
                    //
                    // A catch-all word, such as:
                    //
                    //     black border-collapse
                    //
                    keyword: function () {
                        var k = parserInput.$char('%') || parserInput.$re(/^\[?(?:[\w-]|\\(?:[A-Fa-f0-9]{1,6} ?|[^A-Fa-f0-9]))+\]?/);
                        if (k) {
                            return tree_1.default.Color.fromKeyword(k) || new (tree_1.default.Keyword)(k);
                        }
                    },
                    //
                    // A function call
                    //
                    //     rgb(255, 0, 255)
                    //
                    // The arguments are parsed with the `entities.arguments` parser.
                    //
                    call: function () {
                        var name;
                        var args;
                        var func;
                        var index = parserInput.i;
                        // http://jsperf.com/case-insensitive-regex-vs-strtolower-then-regex/18
                        if (parserInput.peek(/^url\(/i)) {
                            return;
                        }
                        parserInput.save();
                        name = parserInput.$re(/^([\w-]+|%|~|progid:[\w.]+)\(/);
                        if (!name) {
                            parserInput.forget();
                            return;
                        }
                        name = name[1];
                        func = this.customFuncCall(name);
                        if (func) {
                            args = func.parse();
                            if (args && func.stop) {
                                parserInput.forget();
                                return args;
                            }
                        }
                        args = this.arguments(args);
                        if (!parserInput.$char(')')) {
                            parserInput.restore('Could not parse call arguments or missing \')\'');
                            return;
                        }
                        parserInput.forget();
                        return new (tree_1.default.Call)(name, args, index + currentIndex, fileInfo);
                    },
                    //
                    // Parsing rules for functions with non-standard args, e.g.:
                    //
                    //     boolean(not(2 > 1))
                    //
                    //     This is a quick prototype, to be modified/improved when
                    //     more custom-parsed funcs come (e.g. `selector(...)`)
                    //
                    customFuncCall: function (name) {
                        /* Ideally the table is to be moved out of here for faster perf.,
                           but it's quite tricky since it relies on all these `parsers`
                           and `expect` available only here */
                        return {
                            alpha: f(parsers.ieAlpha, true),
                            boolean: f(condition),
                            'if': f(condition)
                        }[name.toLowerCase()];
                        function f(parse, stop) {
                            return {
                                parse: parse,
                                stop: stop // when true - stop after parse() and return its result,
                                // otherwise continue for plain args
                            };
                        }
                        function condition() {
                            return [expect(parsers.condition, 'expected condition')];
                        }
                    },
                    arguments: function (prevArgs) {
                        var argsComma = prevArgs || [];
                        var argsSemiColon = [];
                        var isSemiColonSeparated;
                        var value;
                        parserInput.save();
                        while (true) {
                            if (prevArgs) {
                                prevArgs = false;
                            }
                            else {
                                value = parsers.detachedRuleset() || this.assignment() || parsers.expression();
                                if (!value) {
                                    break;
                                }
                                if (value.value && value.value.length == 1) {
                                    value = value.value[0];
                                }
                                argsComma.push(value);
                            }
                            if (parserInput.$char(',')) {
                                continue;
                            }
                            if (parserInput.$char(';') || isSemiColonSeparated) {
                                isSemiColonSeparated = true;
                                value = (argsComma.length < 1) ? argsComma[0]
                                    : new tree_1.default.Value(argsComma);
                                argsSemiColon.push(value);
                                argsComma = [];
                            }
                        }
                        parserInput.forget();
                        return isSemiColonSeparated ? argsSemiColon : argsComma;
                    },
                    literal: function () {
                        return this.dimension() ||
                            this.color() ||
                            this.quoted() ||
                            this.unicodeDescriptor();
                    },
                    // Assignments are argument entities for calls.
                    // They are present in ie filter properties as shown below.
                    //
                    //     filter: progid:DXImageTransform.Microsoft.Alpha( *opacity=50* )
                    //
                    assignment: function () {
                        var key;
                        var value;
                        parserInput.save();
                        key = parserInput.$re(/^\w+(?=\s?=)/i);
                        if (!key) {
                            parserInput.restore();
                            return;
                        }
                        if (!parserInput.$char('=')) {
                            parserInput.restore();
                            return;
                        }
                        value = parsers.entity();
                        if (value) {
                            parserInput.forget();
                            return new (tree_1.default.Assignment)(key, value);
                        }
                        else {
                            parserInput.restore();
                        }
                    },
                    //
                    // Parse url() tokens
                    //
                    // We use a specific rule for urls, because they don't really behave like
                    // standard function calls. The difference is that the argument doesn't have
                    // to be enclosed within a string, so it can't be parsed as an Expression.
                    //
                    url: function () {
                        var value;
                        var index = parserInput.i;
                        parserInput.autoCommentAbsorb = false;
                        if (!parserInput.$str('url(')) {
                            parserInput.autoCommentAbsorb = true;
                            return;
                        }
                        value = this.quoted() || this.variable() || this.property() ||
                            parserInput.$re(/^(?:(?:\\[()'"])|[^()'"])+/) || '';
                        parserInput.autoCommentAbsorb = true;
                        expectChar(')');
                        return new (tree_1.default.URL)((value.value !== undefined ||
                            value instanceof tree_1.default.Variable ||
                            value instanceof tree_1.default.Property) ?
                            value : new (tree_1.default.Anonymous)(value, index), index + currentIndex, fileInfo);
                    },
                    //
                    // A Variable entity, such as `@fink`, in
                    //
                    //     width: @fink + 2px
                    //
                    // We use a different parser for variable definitions,
                    // see `parsers.variable`.
                    //
                    variable: function () {
                        var ch;
                        var name;
                        var index = parserInput.i;
                        parserInput.save();
                        if (parserInput.currentChar() === '@' && (name = parserInput.$re(/^@@?[\w-]+/))) {
                            ch = parserInput.currentChar();
                            if (ch === '(' || ch === '[' && !parserInput.prevChar().match(/^\s/)) {
                                // this may be a VariableCall lookup
                                var result = parsers.variableCall(name);
                                if (result) {
                                    parserInput.forget();
                                    return result;
                                }
                            }
                            parserInput.forget();
                            return new (tree_1.default.Variable)(name, index + currentIndex, fileInfo);
                        }
                        parserInput.restore();
                    },
                    // A variable entity using the protective {} e.g. @{var}
                    variableCurly: function () {
                        var curly;
                        var index = parserInput.i;
                        if (parserInput.currentChar() === '@' && (curly = parserInput.$re(/^@\{([\w-]+)\}/))) {
                            return new (tree_1.default.Variable)("@" + curly[1], index + currentIndex, fileInfo);
                        }
                    },
                    //
                    // A Property accessor, such as `$color`, in
                    //
                    //     background-color: $color
                    //
                    property: function () {
                        var name;
                        var index = parserInput.i;
                        if (parserInput.currentChar() === '$' && (name = parserInput.$re(/^\$[\w-]+/))) {
                            return new (tree_1.default.Property)(name, index + currentIndex, fileInfo);
                        }
                    },
                    // A property entity useing the protective {} e.g. ${prop}
                    propertyCurly: function () {
                        var curly;
                        var index = parserInput.i;
                        if (parserInput.currentChar() === '$' && (curly = parserInput.$re(/^\$\{([\w-]+)\}/))) {
                            return new (tree_1.default.Property)("$" + curly[1], index + currentIndex, fileInfo);
                        }
                    },
                    //
                    // A Hexadecimal color
                    //
                    //     #4F3C2F
                    //
                    // `rgb` and `hsl` colors are parsed through the `entities.call` parser.
                    //
                    color: function () {
                        var rgb;
                        parserInput.save();
                        if (parserInput.currentChar() === '#' && (rgb = parserInput.$re(/^#([A-Fa-f0-9]{8}|[A-Fa-f0-9]{6}|[A-Fa-f0-9]{3,4})([\w.#[])?/))) {
                            if (!rgb[2]) {
                                parserInput.forget();
                                return new (tree_1.default.Color)(rgb[1], undefined, rgb[0]);
                            }
                        }
                        parserInput.restore();
                    },
                    colorKeyword: function () {
                        parserInput.save();
                        var autoCommentAbsorb = parserInput.autoCommentAbsorb;
                        parserInput.autoCommentAbsorb = false;
                        var k = parserInput.$re(/^[_A-Za-z-][_A-Za-z0-9-]+/);
                        parserInput.autoCommentAbsorb = autoCommentAbsorb;
                        if (!k) {
                            parserInput.forget();
                            return;
                        }
                        parserInput.restore();
                        var color = tree_1.default.Color.fromKeyword(k);
                        if (color) {
                            parserInput.$str(k);
                            return color;
                        }
                    },
                    //
                    // A Dimension, that is, a number and a unit
                    //
                    //     0.5em 95%
                    //
                    dimension: function () {
                        if (parserInput.peekNotNumeric()) {
                            return;
                        }
                        var value = parserInput.$re(/^([+-]?\d*\.?\d+)(%|[a-z_]+)?/i);
                        if (value) {
                            return new (tree_1.default.Dimension)(value[1], value[2]);
                        }
                    },
                    //
                    // A unicode descriptor, as is used in unicode-range
                    //
                    // U+0??  or U+00A1-00A9
                    //
                    unicodeDescriptor: function () {
                        var ud;
                        ud = parserInput.$re(/^U\+[0-9a-fA-F?]+(-[0-9a-fA-F?]+)?/);
                        if (ud) {
                            return new (tree_1.default.UnicodeDescriptor)(ud[0]);
                        }
                    },
                    //
                    // JavaScript code to be evaluated
                    //
                    //     `window.location.href`
                    //
                    javascript: function () {
                        var js;
                        var index = parserInput.i;
                        parserInput.save();
                        var escape = parserInput.$char('~');
                        var jsQuote = parserInput.$char('`');
                        if (!jsQuote) {
                            parserInput.restore();
                            return;
                        }
                        js = parserInput.$re(/^[^`]*`/);
                        if (js) {
                            parserInput.forget();
                            return new (tree_1.default.JavaScript)(js.substr(0, js.length - 1), Boolean(escape), index + currentIndex, fileInfo);
                        }
                        parserInput.restore('invalid javascript definition');
                    }
                },
                //
                // The variable part of a variable definition. Used in the `rule` parser
                //
                //     @fink:
                //
                variable: function () {
                    var name;
                    if (parserInput.currentChar() === '@' && (name = parserInput.$re(/^(@[\w-]+)\s*:/))) {
                        return name[1];
                    }
                },
                //
                // Call a variable value to retrieve a detached ruleset
                // or a value from a detached ruleset's rules.
                //
                //     @fink();
                //     @fink;
                //     color: @fink[@color];
                //
                variableCall: function (parsedName) {
                    var lookups;
                    var i = parserInput.i;
                    var inValue = !!parsedName;
                    var name = parsedName;
                    parserInput.save();
                    if (name || (parserInput.currentChar() === '@'
                        && (name = parserInput.$re(/^(@[\w-]+)(\(\s*\))?/)))) {
                        lookups = this.mixin.ruleLookups();
                        if (!lookups && ((inValue && parserInput.$str('()') !== '()') || (name[2] !== '()'))) {
                            parserInput.restore('Missing \'[...]\' lookup in variable call');
                            return;
                        }
                        if (!inValue) {
                            name = name[1];
                        }
                        var call = new tree_1.default.VariableCall(name, i, fileInfo);
                        if (!inValue && parsers.end()) {
                            parserInput.forget();
                            return call;
                        }
                        else {
                            parserInput.forget();
                            return new tree_1.default.NamespaceValue(call, lookups, i, fileInfo);
                        }
                    }
                    parserInput.restore();
                },
                //
                // extend syntax - used to extend selectors
                //
                extend: function (isRule) {
                    var elements;
                    var e;
                    var index = parserInput.i;
                    var option;
                    var extendList;
                    var extend;
                    if (!parserInput.$str(isRule ? '&:extend(' : ':extend(')) {
                        return;
                    }
                    do {
                        option = null;
                        elements = null;
                        while (!(option = parserInput.$re(/^(all)(?=\s*(\)|,))/))) {
                            e = this.element();
                            if (!e) {
                                break;
                            }
                            if (elements) {
                                elements.push(e);
                            }
                            else {
                                elements = [e];
                            }
                        }
                        option = option && option[1];
                        if (!elements) {
                            error('Missing target selector for :extend().');
                        }
                        extend = new (tree_1.default.Extend)(new (tree_1.default.Selector)(elements), option, index + currentIndex, fileInfo);
                        if (extendList) {
                            extendList.push(extend);
                        }
                        else {
                            extendList = [extend];
                        }
                    } while (parserInput.$char(','));
                    expect(/^\)/);
                    if (isRule) {
                        expect(/^;/);
                    }
                    return extendList;
                },
                //
                // extendRule - used in a rule to extend all the parent selectors
                //
                extendRule: function () {
                    return this.extend(true);
                },
                //
                // Mixins
                //
                mixin: {
                    //
                    // A Mixin call, with an optional argument list
                    //
                    //     #mixins > .square(#fff);
                    //     #mixins.square(#fff);
                    //     .rounded(4px, black);
                    //     .button;
                    //
                    // We can lookup / return a value using the lookup syntax:
                    //
                    //     color: #mixin.square(#fff)[@color];
                    //
                    // The `while` loop is there because mixins can be
                    // namespaced, but we only support the child and descendant
                    // selector for now.
                    //
                    call: function (inValue, getLookup) {
                        var s = parserInput.currentChar();
                        var important = false;
                        var lookups;
                        var index = parserInput.i;
                        var elements;
                        var args;
                        var hasParens;
                        if (s !== '.' && s !== '#') {
                            return;
                        }
                        parserInput.save(); // stop us absorbing part of an invalid selector
                        elements = this.elements();
                        if (elements) {
                            if (parserInput.$char('(')) {
                                args = this.args(true).args;
                                expectChar(')');
                                hasParens = true;
                            }
                            if (getLookup !== false) {
                                lookups = this.ruleLookups();
                            }
                            if (getLookup === true && !lookups) {
                                parserInput.restore();
                                return;
                            }
                            if (inValue && !lookups && !hasParens) {
                                // This isn't a valid in-value mixin call
                                parserInput.restore();
                                return;
                            }
                            if (!inValue && parsers.important()) {
                                important = true;
                            }
                            if (inValue || parsers.end()) {
                                parserInput.forget();
                                var mixin = new (tree_1.default.mixin.Call)(elements, args, index + currentIndex, fileInfo, !lookups && important);
                                if (lookups) {
                                    return new tree_1.default.NamespaceValue(mixin, lookups);
                                }
                                else {
                                    return mixin;
                                }
                            }
                        }
                        parserInput.restore();
                    },
                    /**
                     * Matching elements for mixins
                     * (Start with . or # and can have > )
                     */
                    elements: function () {
                        var elements;
                        var e;
                        var c;
                        var elem;
                        var elemIndex;
                        var re = /^[#.](?:[\w-]|\\(?:[A-Fa-f0-9]{1,6} ?|[^A-Fa-f0-9]))+/;
                        while (true) {
                            elemIndex = parserInput.i;
                            e = parserInput.$re(re);
                            if (!e) {
                                break;
                            }
                            elem = new (tree_1.default.Element)(c, e, false, elemIndex + currentIndex, fileInfo);
                            if (elements) {
                                elements.push(elem);
                            }
                            else {
                                elements = [elem];
                            }
                            c = parserInput.$char('>');
                        }
                        return elements;
                    },
                    args: function (isCall) {
                        var entities = parsers.entities;
                        var returner = { args: null, variadic: false };
                        var expressions = [];
                        var argsSemiColon = [];
                        var argsComma = [];
                        var isSemiColonSeparated;
                        var expressionContainsNamed;
                        var name;
                        var nameLoop;
                        var value;
                        var arg;
                        var expand;
                        var hasSep = true;
                        parserInput.save();
                        while (true) {
                            if (isCall) {
                                arg = parsers.detachedRuleset() || parsers.expression();
                            }
                            else {
                                parserInput.commentStore.length = 0;
                                if (parserInput.$str('...')) {
                                    returner.variadic = true;
                                    if (parserInput.$char(';') && !isSemiColonSeparated) {
                                        isSemiColonSeparated = true;
                                    }
                                    (isSemiColonSeparated ? argsSemiColon : argsComma)
                                        .push({ variadic: true });
                                    break;
                                }
                                arg = entities.variable() || entities.property() || entities.literal() || entities.keyword() || this.call(true);
                            }
                            if (!arg || !hasSep) {
                                break;
                            }
                            nameLoop = null;
                            if (arg.throwAwayComments) {
                                arg.throwAwayComments();
                            }
                            value = arg;
                            var val = null;
                            if (isCall) {
                                // Variable
                                if (arg.value && arg.value.length == 1) {
                                    val = arg.value[0];
                                }
                            }
                            else {
                                val = arg;
                            }
                            if (val && (val instanceof tree_1.default.Variable || val instanceof tree_1.default.Property)) {
                                if (parserInput.$char(':')) {
                                    if (expressions.length > 0) {
                                        if (isSemiColonSeparated) {
                                            error('Cannot mix ; and , as delimiter types');
                                        }
                                        expressionContainsNamed = true;
                                    }
                                    value = parsers.detachedRuleset() || parsers.expression();
                                    if (!value) {
                                        if (isCall) {
                                            error('could not understand value for named argument');
                                        }
                                        else {
                                            parserInput.restore();
                                            returner.args = [];
                                            return returner;
                                        }
                                    }
                                    nameLoop = (name = val.name);
                                }
                                else if (parserInput.$str('...')) {
                                    if (!isCall) {
                                        returner.variadic = true;
                                        if (parserInput.$char(';') && !isSemiColonSeparated) {
                                            isSemiColonSeparated = true;
                                        }
                                        (isSemiColonSeparated ? argsSemiColon : argsComma)
                                            .push({ name: arg.name, variadic: true });
                                        break;
                                    }
                                    else {
                                        expand = true;
                                    }
                                }
                                else if (!isCall) {
                                    name = nameLoop = val.name;
                                    value = null;
                                }
                            }
                            if (value) {
                                expressions.push(value);
                            }
                            argsComma.push({ name: nameLoop, value: value, expand: expand });
                            if (parserInput.$char(',')) {
                                hasSep = true;
                                continue;
                            }
                            hasSep = parserInput.$char(';') === ';';
                            if (hasSep || isSemiColonSeparated) {
                                if (expressionContainsNamed) {
                                    error('Cannot mix ; and , as delimiter types');
                                }
                                isSemiColonSeparated = true;
                                if (expressions.length > 1) {
                                    value = new (tree_1.default.Value)(expressions);
                                }
                                argsSemiColon.push({ name: name, value: value, expand: expand });
                                name = null;
                                expressions = [];
                                expressionContainsNamed = false;
                            }
                        }
                        parserInput.forget();
                        returner.args = isSemiColonSeparated ? argsSemiColon : argsComma;
                        return returner;
                    },
                    //
                    // A Mixin definition, with a list of parameters
                    //
                    //     .rounded (@radius: 2px, @color) {
                    //        ...
                    //     }
                    //
                    // Until we have a finer grained state-machine, we have to
                    // do a look-ahead, to make sure we don't have a mixin call.
                    // See the `rule` function for more information.
                    //
                    // We start by matching `.rounded (`, and then proceed on to
                    // the argument list, which has optional default values.
                    // We store the parameters in `params`, with a `value` key,
                    // if there is a value, such as in the case of `@radius`.
                    //
                    // Once we've got our params list, and a closing `)`, we parse
                    // the `{...}` block.
                    //
                    definition: function () {
                        var name;
                        var params = [];
                        var match;
                        var ruleset;
                        var cond;
                        var variadic = false;
                        if ((parserInput.currentChar() !== '.' && parserInput.currentChar() !== '#') ||
                            parserInput.peek(/^[^{]*\}/)) {
                            return;
                        }
                        parserInput.save();
                        match = parserInput.$re(/^([#.](?:[\w-]|\\(?:[A-Fa-f0-9]{1,6} ?|[^A-Fa-f0-9]))+)\s*\(/);
                        if (match) {
                            name = match[1];
                            var argInfo = this.args(false);
                            params = argInfo.args;
                            variadic = argInfo.variadic;
                            // .mixincall("@{a}");
                            // looks a bit like a mixin definition..
                            // also
                            // .mixincall(@a: {rule: set;});
                            // so we have to be nice and restore
                            if (!parserInput.$char(')')) {
                                parserInput.restore('Missing closing \')\'');
                                return;
                            }
                            parserInput.commentStore.length = 0;
                            if (parserInput.$str('when')) { // Guard
                                cond = expect(parsers.conditions, 'expected condition');
                            }
                            ruleset = parsers.block();
                            if (ruleset) {
                                parserInput.forget();
                                return new (tree_1.default.mixin.Definition)(name, params, ruleset, cond, variadic);
                            }
                            else {
                                parserInput.restore();
                            }
                        }
                        else {
                            parserInput.restore();
                        }
                    },
                    ruleLookups: function () {
                        var rule;
                        var lookups = [];
                        if (parserInput.currentChar() !== '[') {
                            return;
                        }
                        while (true) {
                            parserInput.save();
                            rule = this.lookupValue();
                            if (!rule && rule !== '') {
                                parserInput.restore();
                                break;
                            }
                            lookups.push(rule);
                            parserInput.forget();
                        }
                        if (lookups.length > 0) {
                            return lookups;
                        }
                    },
                    lookupValue: function () {
                        parserInput.save();
                        if (!parserInput.$char('[')) {
                            parserInput.restore();
                            return;
                        }
                        var name = parserInput.$re(/^(?:[@$]{0,2})[_a-zA-Z0-9-]*/);
                        if (!parserInput.$char(']')) {
                            parserInput.restore();
                            return;
                        }
                        if (name || name === '') {
                            parserInput.forget();
                            return name;
                        }
                        parserInput.restore();
                    }
                },
                //
                // Entities are the smallest recognized token,
                // and can be found inside a rule's value.
                //
                entity: function () {
                    var entities = this.entities;
                    return this.comment() || entities.literal() || entities.variable() || entities.url() ||
                        entities.property() || entities.call() || entities.keyword() || this.mixin.call(true) ||
                        entities.javascript();
                },
                //
                // A Declaration terminator. Note that we use `peek()` to check for '}',
                // because the `block` rule will be expecting it, but we still need to make sure
                // it's there, if ';' was omitted.
                //
                end: function () {
                    return parserInput.$char(';') || parserInput.peek('}');
                },
                //
                // IE's alpha function
                //
                //     alpha(opacity=88)
                //
                ieAlpha: function () {
                    var value;
                    // http://jsperf.com/case-insensitive-regex-vs-strtolower-then-regex/18
                    if (!parserInput.$re(/^opacity=/i)) {
                        return;
                    }
                    value = parserInput.$re(/^\d+/);
                    if (!value) {
                        value = expect(parsers.entities.variable, 'Could not parse alpha');
                        value = "@{" + value.name.slice(1) + "}";
                    }
                    expectChar(')');
                    return new tree_1.default.Quoted('', "alpha(opacity=" + value + ")");
                },
                //
                // A Selector Element
                //
                //     div
                //     + h1
                //     #socks
                //     input[type="text"]
                //
                // Elements are the building blocks for Selectors,
                // they are made out of a `Combinator` (see combinator rule),
                // and an element name, such as a tag a class, or `*`.
                //
                element: function () {
                    var e;
                    var c;
                    var v;
                    var index = parserInput.i;
                    c = this.combinator();
                    e = parserInput.$re(/^(?:\d+\.\d+|\d+)%/) ||
                        // eslint-disable-next-line no-control-regex
                        parserInput.$re(/^(?:[.#]?|:*)(?:[\w-]|[^\x00-\x9f]|\\(?:[A-Fa-f0-9]{1,6} ?|[^A-Fa-f0-9]))+/) ||
                        parserInput.$char('*') || parserInput.$char('&') || this.attribute() ||
                        parserInput.$re(/^\([^&()@]+\)/) || parserInput.$re(/^[.#:](?=@)/) ||
                        this.entities.variableCurly();
                    if (!e) {
                        parserInput.save();
                        if (parserInput.$char('(')) {
                            if ((v = this.selector(false)) && parserInput.$char(')')) {
                                e = new (tree_1.default.Paren)(v);
                                parserInput.forget();
                            }
                            else {
                                parserInput.restore('Missing closing \')\'');
                            }
                        }
                        else {
                            parserInput.forget();
                        }
                    }
                    if (e) {
                        return new (tree_1.default.Element)(c, e, e instanceof tree_1.default.Variable, index + currentIndex, fileInfo);
                    }
                },
                //
                // Combinators combine elements together, in a Selector.
                //
                // Because our parser isn't white-space sensitive, special care
                // has to be taken, when parsing the descendant combinator, ` `,
                // as it's an empty space. We have to check the previous character
                // in the input, to see if it's a ` ` character. More info on how
                // we deal with this in *combinator.js*.
                //
                combinator: function () {
                    var c = parserInput.currentChar();
                    if (c === '/') {
                        parserInput.save();
                        var slashedCombinator = parserInput.$re(/^\/[a-z]+\//i);
                        if (slashedCombinator) {
                            parserInput.forget();
                            return new (tree_1.default.Combinator)(slashedCombinator);
                        }
                        parserInput.restore();
                    }
                    if (c === '>' || c === '+' || c === '~' || c === '|' || c === '^') {
                        parserInput.i++;
                        if (c === '^' && parserInput.currentChar() === '^') {
                            c = '^^';
                            parserInput.i++;
                        }
                        while (parserInput.isWhitespace()) {
                            parserInput.i++;
                        }
                        return new (tree_1.default.Combinator)(c);
                    }
                    else if (parserInput.isWhitespace(-1)) {
                        return new (tree_1.default.Combinator)(' ');
                    }
                    else {
                        return new (tree_1.default.Combinator)(null);
                    }
                },
                //
                // A CSS Selector
                // with less extensions e.g. the ability to extend and guard
                //
                //     .class > div + h1
                //     li a:hover
                //
                // Selectors are made out of one or more Elements, see above.
                //
                selector: function (isLess) {
                    var index = parserInput.i;
                    var elements;
                    var extendList;
                    var c;
                    var e;
                    var allExtends;
                    var when;
                    var condition;
                    isLess = isLess !== false;
                    while ((isLess && (extendList = this.extend())) || (isLess && (when = parserInput.$str('when'))) || (e = this.element())) {
                        if (when) {
                            condition = expect(this.conditions, 'expected condition');
                        }
                        else if (condition) {
                            error('CSS guard can only be used at the end of selector');
                        }
                        else if (extendList) {
                            if (allExtends) {
                                allExtends = allExtends.concat(extendList);
                            }
                            else {
                                allExtends = extendList;
                            }
                        }
                        else {
                            if (allExtends) {
                                error('Extend can only be used at the end of selector');
                            }
                            c = parserInput.currentChar();
                            if (elements) {
                                elements.push(e);
                            }
                            else {
                                elements = [e];
                            }
                            e = null;
                        }
                        if (c === '{' || c === '}' || c === ';' || c === ',' || c === ')') {
                            break;
                        }
                    }
                    if (elements) {
                        return new (tree_1.default.Selector)(elements, allExtends, condition, index + currentIndex, fileInfo);
                    }
                    if (allExtends) {
                        error('Extend must be used to extend a selector, it cannot be used on its own');
                    }
                },
                selectors: function () {
                    var s;
                    var selectors;
                    while (true) {
                        s = this.selector();
                        if (!s) {
                            break;
                        }
                        if (selectors) {
                            selectors.push(s);
                        }
                        else {
                            selectors = [s];
                        }
                        parserInput.commentStore.length = 0;
                        if (s.condition && selectors.length > 1) {
                            error('Guards are only currently allowed on a single selector.');
                        }
                        if (!parserInput.$char(',')) {
                            break;
                        }
                        if (s.condition) {
                            error('Guards are only currently allowed on a single selector.');
                        }
                        parserInput.commentStore.length = 0;
                    }
                    return selectors;
                },
                attribute: function () {
                    if (!parserInput.$char('[')) {
                        return;
                    }
                    var entities = this.entities;
                    var key;
                    var val;
                    var op;
                    //
                    // case-insensitive flag
                    // e.g. [attr operator value i]
                    //
                    var cif;
                    if (!(key = entities.variableCurly())) {
                        key = expect(/^(?:[_A-Za-z0-9-*]*\|)?(?:[_A-Za-z0-9-]|\\.)+/);
                    }
                    op = parserInput.$re(/^[|~*$^]?=/);
                    if (op) {
                        val = entities.quoted() || parserInput.$re(/^[0-9]+%/) || parserInput.$re(/^[\w-]+/) || entities.variableCurly();
                        if (val) {
                            cif = parserInput.$re(/^[iIsS]/);
                        }
                    }
                    expectChar(']');
                    return new (tree_1.default.Attribute)(key, op, val, cif);
                },
                //
                // The `block` rule is used by `ruleset` and `mixin.definition`.
                // It's a wrapper around the `primary` rule, with added `{}`.
                //
                block: function () {
                    var content;
                    if (parserInput.$char('{') && (content = this.primary()) && parserInput.$char('}')) {
                        return content;
                    }
                },
                blockRuleset: function () {
                    var block = this.block();
                    if (block) {
                        block = new tree_1.default.Ruleset(null, block);
                    }
                    return block;
                },
                detachedRuleset: function () {
                    var argInfo;
                    var params;
                    var variadic;
                    parserInput.save();
                    if (parserInput.$re(/^[.#]\(/)) {
                        /**
                         * DR args currently only implemented for each() function, and not
                         * yet settable as `@dr: #(@arg) {}`
                         * This should be done when DRs are merged with mixins.
                         * See: https://github.com/less/less-meta/issues/16
                         */
                        argInfo = this.mixin.args(false);
                        params = argInfo.args;
                        variadic = argInfo.variadic;
                        if (!parserInput.$char(')')) {
                            parserInput.restore();
                            return;
                        }
                    }
                    var blockRuleset = this.blockRuleset();
                    if (blockRuleset) {
                        parserInput.forget();
                        if (params) {
                            return new tree_1.default.mixin.Definition(null, params, blockRuleset, null, variadic);
                        }
                        return new tree_1.default.DetachedRuleset(blockRuleset);
                    }
                    parserInput.restore();
                },
                //
                // div, .class, body > p {...}
                //
                ruleset: function () {
                    var selectors;
                    var rules;
                    var debugInfo;
                    parserInput.save();
                    if (context.dumpLineNumbers) {
                        debugInfo = getDebugInfo(parserInput.i);
                    }
                    selectors = this.selectors();
                    if (selectors && (rules = this.block())) {
                        parserInput.forget();
                        var ruleset = new (tree_1.default.Ruleset)(selectors, rules, context.strictImports);
                        if (context.dumpLineNumbers) {
                            ruleset.debugInfo = debugInfo;
                        }
                        return ruleset;
                    }
                    else {
                        parserInput.restore();
                    }
                },
                declaration: function () {
                    var name;
                    var value;
                    var index = parserInput.i;
                    var hasDR;
                    var c = parserInput.currentChar();
                    var important;
                    var merge;
                    var isVariable;
                    if (c === '.' || c === '#' || c === '&' || c === ':') {
                        return;
                    }
                    parserInput.save();
                    name = this.variable() || this.ruleProperty();
                    if (name) {
                        isVariable = typeof name === 'string';
                        if (isVariable) {
                            value = this.detachedRuleset();
                            if (value) {
                                hasDR = true;
                            }
                        }
                        parserInput.commentStore.length = 0;
                        if (!value) {
                            // a name returned by this.ruleProperty() is always an array of the form:
                            // [string-1, ..., string-n, ""] or [string-1, ..., string-n, "+"]
                            // where each item is a tree.Keyword or tree.Variable
                            merge = !isVariable && name.length > 1 && name.pop().value;
                            // Custom property values get permissive parsing
                            if (name[0].value && name[0].value.slice(0, 2) === '--') {
                                value = this.permissiveValue(/[;}]/);
                            }
                            // Try to store values as anonymous
                            // If we need the value later we'll re-parse it in ruleset.parseValue
                            else {
                                value = this.anonymousValue();
                            }
                            if (value) {
                                parserInput.forget();
                                // anonymous values absorb the end ';' which is required for them to work
                                return new (tree_1.default.Declaration)(name, value, false, merge, index + currentIndex, fileInfo);
                            }
                            if (!value) {
                                value = this.value();
                            }
                            if (value) {
                                important = this.important();
                            }
                            else if (isVariable) {
                                // As a last resort, try permissiveValue
                                value = this.permissiveValue();
                            }
                        }
                        if (value && (this.end() || hasDR)) {
                            parserInput.forget();
                            return new (tree_1.default.Declaration)(name, value, important, merge, index + currentIndex, fileInfo);
                        }
                        else {
                            parserInput.restore();
                        }
                    }
                    else {
                        parserInput.restore();
                    }
                },
                anonymousValue: function () {
                    var index = parserInput.i;
                    var match = parserInput.$re(/^([^.#@$+/'"*`(;{}-]*);/);
                    if (match) {
                        return new (tree_1.default.Anonymous)(match[1], index + currentIndex);
                    }
                },
                /**
                 * Used for custom properties, at-rules, and variables (as fallback)
                 * Parses almost anything inside of {} [] () "" blocks
                 * until it reaches outer-most tokens.
                 *
                 * First, it will try to parse comments and entities to reach
                 * the end. This is mostly like the Expression parser except no
                 * math is allowed.
                 */
                permissiveValue: function (untilTokens) {
                    var i;
                    var e;
                    var done;
                    var value;
                    var tok = untilTokens || ';';
                    var index = parserInput.i;
                    var result = [];
                    function testCurrentChar() {
                        var char = parserInput.currentChar();
                        if (typeof tok === 'string') {
                            return char === tok;
                        }
                        else {
                            return tok.test(char);
                        }
                    }
                    if (testCurrentChar()) {
                        return;
                    }
                    value = [];
                    do {
                        e = this.comment();
                        if (e) {
                            value.push(e);
                            continue;
                        }
                        e = this.entity();
                        if (e) {
                            value.push(e);
                        }
                    } while (e);
                    done = testCurrentChar();
                    if (value.length > 0) {
                        value = new (tree_1.default.Expression)(value);
                        if (done) {
                            return value;
                        }
                        else {
                            result.push(value);
                        }
                        // Preserve space before $parseUntil as it will not
                        if (parserInput.prevChar() === ' ') {
                            result.push(new tree_1.default.Anonymous(' ', index));
                        }
                    }
                    parserInput.save();
                    value = parserInput.$parseUntil(tok);
                    if (value) {
                        if (typeof value === 'string') {
                            error("Expected '" + value + "'", 'Parse');
                        }
                        if (value.length === 1 && value[0] === ' ') {
                            parserInput.forget();
                            return new tree_1.default.Anonymous('', index);
                        }
                        var item = void 0;
                        for (i = 0; i < value.length; i++) {
                            item = value[i];
                            if (Array.isArray(item)) {
                                // Treat actual quotes as normal quoted values
                                result.push(new tree_1.default.Quoted(item[0], item[1], true, index, fileInfo));
                            }
                            else {
                                if (i === value.length - 1) {
                                    item = item.trim();
                                }
                                // Treat like quoted values, but replace vars like unquoted expressions
                                var quote = new tree_1.default.Quoted('\'', item, true, index, fileInfo);
                                quote.variableRegex = /@([\w-]+)/g;
                                quote.propRegex = /\$([\w-]+)/g;
                                result.push(quote);
                            }
                        }
                        parserInput.forget();
                        return new tree_1.default.Expression(result, true);
                    }
                    parserInput.restore();
                },
                //
                // An @import atrule
                //
                //     @import "lib";
                //
                // Depending on our environment, importing is done differently:
                // In the browser, it's an XHR request, in Node, it would be a
                // file-system operation. The function used for importing is
                // stored in `import`, which we pass to the Import constructor.
                //
                'import': function () {
                    var path;
                    var features;
                    var index = parserInput.i;
                    var dir = parserInput.$re(/^@import\s+/);
                    if (dir) {
                        var options = (dir ? this.importOptions() : null) || {};
                        if ((path = this.entities.quoted() || this.entities.url())) {
                            features = this.mediaFeatures({});
                            if (!parserInput.$char(';')) {
                                parserInput.i = index;
                                error('missing semi-colon or unrecognised media features on import');
                            }
                            features = features && new (tree_1.default.Value)(features);
                            return new (tree_1.default.Import)(path, features, options, index + currentIndex, fileInfo);
                        }
                        else {
                            parserInput.i = index;
                            error('malformed import statement');
                        }
                    }
                },
                importOptions: function () {
                    var o;
                    var options = {};
                    var optionName;
                    var value;
                    // list of options, surrounded by parens
                    if (!parserInput.$char('(')) {
                        return null;
                    }
                    do {
                        o = this.importOption();
                        if (o) {
                            optionName = o;
                            value = true;
                            switch (optionName) {
                                case 'css':
                                    optionName = 'less';
                                    value = false;
                                    break;
                                case 'once':
                                    optionName = 'multiple';
                                    value = false;
                                    break;
                            }
                            options[optionName] = value;
                            if (!parserInput.$char(',')) {
                                break;
                            }
                        }
                    } while (o);
                    expectChar(')');
                    return options;
                },
                importOption: function () {
                    var opt = parserInput.$re(/^(less|css|multiple|once|inline|reference|optional)/);
                    if (opt) {
                        return opt[1];
                    }
                },
                mediaFeature: function (syntaxOptions) {
                    var entities = this.entities;
                    var nodes = [];
                    var e;
                    var p;
                    var rangeP;
                    parserInput.save();
                    do {
                        e = entities.keyword() || entities.variable() || entities.mixinLookup();
                        if (e) {
                            nodes.push(e);
                        }
                        else if (parserInput.$char('(')) {
                            p = this.property();
                            parserInput.save();
                            if (!p && syntaxOptions.queryInParens && parserInput.$re(/^[0-9a-z-]*\s*([<>]=|<=|>=|[<>]|=)/)) {
                                parserInput.restore();
                                p = this.condition();
                                parserInput.save();
                                rangeP = this.atomicCondition(null, p.rvalue);
                                if (!rangeP) {
                                    parserInput.restore();
                                }
                            }
                            else {
                                parserInput.restore();
                                e = this.value();
                            }
                            if (parserInput.$char(')')) {
                                if (p && !e) {
                                    nodes.push(new (tree_1.default.Paren)(new (tree_1.default.QueryInParens)(p.op, p.lvalue, p.rvalue, rangeP ? rangeP.op : null, rangeP ? rangeP.rvalue : null, p._index)));
                                    e = p;
                                }
                                else if (p && e) {
                                    nodes.push(new (tree_1.default.Paren)(new (tree_1.default.Declaration)(p, e, null, null, parserInput.i + currentIndex, fileInfo, true)));
                                }
                                else if (e) {
                                    nodes.push(new (tree_1.default.Paren)(e));
                                }
                                else {
                                    error('badly formed media feature definition');
                                }
                            }
                            else {
                                error('Missing closing \')\'', 'Parse');
                            }
                        }
                    } while (e);
                    parserInput.forget();
                    if (nodes.length > 0) {
                        return new (tree_1.default.Expression)(nodes);
                    }
                },
                mediaFeatures: function (syntaxOptions) {
                    var entities = this.entities;
                    var features = [];
                    var e;
                    do {
                        e = this.mediaFeature(syntaxOptions);
                        if (e) {
                            features.push(e);
                            if (!parserInput.$char(',')) {
                                break;
                            }
                        }
                        else {
                            e = entities.variable() || entities.mixinLookup();
                            if (e) {
                                features.push(e);
                                if (!parserInput.$char(',')) {
                                    break;
                                }
                            }
                        }
                    } while (e);
                    return features.length > 0 ? features : null;
                },
                prepareAndGetNestableAtRule: function (treeType, index, debugInfo, syntaxOptions) {
                    var features = this.mediaFeatures(syntaxOptions);
                    var rules = this.block();
                    if (!rules) {
                        error('media definitions require block statements after any features');
                    }
                    parserInput.forget();
                    var atRule = new (treeType)(rules, features, index + currentIndex, fileInfo);
                    if (context.dumpLineNumbers) {
                        atRule.debugInfo = debugInfo;
                    }
                    return atRule;
                },
                nestableAtRule: function () {
                    var debugInfo;
                    var index = parserInput.i;
                    if (context.dumpLineNumbers) {
                        debugInfo = getDebugInfo(index);
                    }
                    parserInput.save();
                    if (parserInput.$peekChar('@')) {
                        if (parserInput.$str('@media')) {
                            return this.prepareAndGetNestableAtRule(tree_1.default.Media, index, debugInfo, atrule_syntax_1.MediaSyntaxOptions);
                        }
                        if (parserInput.$str('@container')) {
                            return this.prepareAndGetNestableAtRule(tree_1.default.Container, index, debugInfo, atrule_syntax_1.ContainerSyntaxOptions);
                        }
                    }
                    parserInput.restore();
                },
                //
                // A @plugin directive, used to import plugins dynamically.
                //
                //     @plugin (args) "lib";
                //
                plugin: function () {
                    var path;
                    var args;
                    var options;
                    var index = parserInput.i;
                    var dir = parserInput.$re(/^@plugin\s+/);
                    if (dir) {
                        args = this.pluginArgs();
                        if (args) {
                            options = {
                                pluginArgs: args,
                                isPlugin: true
                            };
                        }
                        else {
                            options = { isPlugin: true };
                        }
                        if ((path = this.entities.quoted() || this.entities.url())) {
                            if (!parserInput.$char(';')) {
                                parserInput.i = index;
                                error('missing semi-colon on @plugin');
                            }
                            return new (tree_1.default.Import)(path, null, options, index + currentIndex, fileInfo);
                        }
                        else {
                            parserInput.i = index;
                            error('malformed @plugin statement');
                        }
                    }
                },
                pluginArgs: function () {
                    // list of options, surrounded by parens
                    parserInput.save();
                    if (!parserInput.$char('(')) {
                        parserInput.restore();
                        return null;
                    }
                    var args = parserInput.$re(/^\s*([^);]+)\)\s*/);
                    if (args[1]) {
                        parserInput.forget();
                        return args[1].trim();
                    }
                    else {
                        parserInput.restore();
                        return null;
                    }
                },
                //
                // A CSS AtRule
                //
                //     @charset "utf-8";
                //
                atrule: function () {
                    var index = parserInput.i;
                    var name;
                    var value;
                    var rules;
                    var nonVendorSpecificName;
                    var hasIdentifier;
                    var hasExpression;
                    var hasUnknown;
                    var hasBlock = true;
                    var isRooted = true;
                    if (parserInput.currentChar() !== '@') {
                        return;
                    }
                    value = this['import']() || this.plugin() || this.nestableAtRule();
                    if (value) {
                        return value;
                    }
                    parserInput.save();
                    name = parserInput.$re(/^@[a-z-]+/);
                    if (!name) {
                        return;
                    }
                    nonVendorSpecificName = name;
                    if (name.charAt(1) == '-' && name.indexOf('-', 2) > 0) {
                        nonVendorSpecificName = "@" + name.slice(name.indexOf('-', 2) + 1);
                    }
                    switch (nonVendorSpecificName) {
                        case '@charset':
                            hasIdentifier = true;
                            hasBlock = false;
                            break;
                        case '@namespace':
                            hasExpression = true;
                            hasBlock = false;
                            break;
                        case '@keyframes':
                        case '@counter-style':
                            hasIdentifier = true;
                            break;
                        case '@document':
                        case '@supports':
                            hasUnknown = true;
                            isRooted = false;
                            break;
                        default:
                            hasUnknown = true;
                            break;
                    }
                    parserInput.commentStore.length = 0;
                    if (hasIdentifier) {
                        value = this.entity();
                        if (!value) {
                            error("expected " + name + " identifier");
                        }
                    }
                    else if (hasExpression) {
                        value = this.expression();
                        if (!value) {
                            error("expected " + name + " expression");
                        }
                    }
                    else if (hasUnknown) {
                        value = this.permissiveValue(/^[{;]/);
                        hasBlock = (parserInput.currentChar() === '{');
                        if (!value) {
                            if (!hasBlock && parserInput.currentChar() !== ';') {
                                error(name + " rule is missing block or ending semi-colon");
                            }
                        }
                        else if (!value.value) {
                            value = null;
                        }
                    }
                    if (hasBlock) {
                        rules = this.blockRuleset();
                    }
                    if (rules || (!hasBlock && value && parserInput.$char(';'))) {
                        parserInput.forget();
                        return new (tree_1.default.AtRule)(name, value, rules, index + currentIndex, fileInfo, context.dumpLineNumbers ? getDebugInfo(index) : null, isRooted);
                    }
                    parserInput.restore('at-rule options not recognised');
                },
                //
                // A Value is a comma-delimited list of Expressions
                //
                //     font-family: Baskerville, Georgia, serif;
                //
                // In a Rule, a Value represents everything after the `:`,
                // and before the `;`.
                //
                value: function () {
                    var e;
                    var expressions = [];
                    var index = parserInput.i;
                    do {
                        e = this.expression();
                        if (e) {
                            expressions.push(e);
                            if (!parserInput.$char(',')) {
                                break;
                            }
                        }
                    } while (e);
                    if (expressions.length > 0) {
                        return new (tree_1.default.Value)(expressions, index + currentIndex);
                    }
                },
                important: function () {
                    if (parserInput.currentChar() === '!') {
                        return parserInput.$re(/^! *important/);
                    }
                },
                sub: function () {
                    var a;
                    var e;
                    parserInput.save();
                    if (parserInput.$char('(')) {
                        a = this.addition();
                        if (a && parserInput.$char(')')) {
                            parserInput.forget();
                            e = new (tree_1.default.Expression)([a]);
                            e.parens = true;
                            return e;
                        }
                        parserInput.restore('Expected \')\'');
                        return;
                    }
                    parserInput.restore();
                },
                multiplication: function () {
                    var m;
                    var a;
                    var op;
                    var operation;
                    var isSpaced;
                    m = this.operand();
                    if (m) {
                        isSpaced = parserInput.isWhitespace(-1);
                        while (true) {
                            if (parserInput.peek(/^\/[*/]/)) {
                                break;
                            }
                            parserInput.save();
                            op = parserInput.$char('/') || parserInput.$char('*') || parserInput.$str('./');
                            if (!op) {
                                parserInput.forget();
                                break;
                            }
                            a = this.operand();
                            if (!a) {
                                parserInput.restore();
                                break;
                            }
                            parserInput.forget();
                            m.parensInOp = true;
                            a.parensInOp = true;
                            operation = new (tree_1.default.Operation)(op, [operation || m, a], isSpaced);
                            isSpaced = parserInput.isWhitespace(-1);
                        }
                        return operation || m;
                    }
                },
                addition: function () {
                    var m;
                    var a;
                    var op;
                    var operation;
                    var isSpaced;
                    m = this.multiplication();
                    if (m) {
                        isSpaced = parserInput.isWhitespace(-1);
                        while (true) {
                            op = parserInput.$re(/^[-+]\s+/) || (!isSpaced && (parserInput.$char('+') || parserInput.$char('-')));
                            if (!op) {
                                break;
                            }
                            a = this.multiplication();
                            if (!a) {
                                break;
                            }
                            m.parensInOp = true;
                            a.parensInOp = true;
                            operation = new (tree_1.default.Operation)(op, [operation || m, a], isSpaced);
                            isSpaced = parserInput.isWhitespace(-1);
                        }
                        return operation || m;
                    }
                },
                conditions: function () {
                    var a;
                    var b;
                    var index = parserInput.i;
                    var condition;
                    a = this.condition(true);
                    if (a) {
                        while (true) {
                            if (!parserInput.peek(/^,\s*(not\s*)?\(/) || !parserInput.$char(',')) {
                                break;
                            }
                            b = this.condition(true);
                            if (!b) {
                                break;
                            }
                            condition = new (tree_1.default.Condition)('or', condition || a, b, index + currentIndex);
                        }
                        return condition || a;
                    }
                },
                condition: function (needsParens) {
                    var result;
                    var logical;
                    var next;
                    function or() {
                        return parserInput.$str('or');
                    }
                    result = this.conditionAnd(needsParens);
                    if (!result) {
                        return;
                    }
                    logical = or();
                    if (logical) {
                        next = this.condition(needsParens);
                        if (next) {
                            result = new (tree_1.default.Condition)(logical, result, next);
                        }
                        else {
                            return;
                        }
                    }
                    return result;
                },
                conditionAnd: function (needsParens) {
                    var result;
                    var logical;
                    var next;
                    var self = this;
                    function insideCondition() {
                        var cond = self.negatedCondition(needsParens) || self.parenthesisCondition(needsParens);
                        if (!cond && !needsParens) {
                            return self.atomicCondition(needsParens);
                        }
                        return cond;
                    }
                    function and() {
                        return parserInput.$str('and');
                    }
                    result = insideCondition();
                    if (!result) {
                        return;
                    }
                    logical = and();
                    if (logical) {
                        next = this.conditionAnd(needsParens);
                        if (next) {
                            result = new (tree_1.default.Condition)(logical, result, next);
                        }
                        else {
                            return;
                        }
                    }
                    return result;
                },
                negatedCondition: function (needsParens) {
                    if (parserInput.$str('not')) {
                        var result = this.parenthesisCondition(needsParens);
                        if (result) {
                            result.negate = !result.negate;
                        }
                        return result;
                    }
                },
                parenthesisCondition: function (needsParens) {
                    function tryConditionFollowedByParenthesis(me) {
                        var body;
                        parserInput.save();
                        body = me.condition(needsParens);
                        if (!body) {
                            parserInput.restore();
                            return;
                        }
                        if (!parserInput.$char(')')) {
                            parserInput.restore();
                            return;
                        }
                        parserInput.forget();
                        return body;
                    }
                    var body;
                    parserInput.save();
                    if (!parserInput.$str('(')) {
                        parserInput.restore();
                        return;
                    }
                    body = tryConditionFollowedByParenthesis(this);
                    if (body) {
                        parserInput.forget();
                        return body;
                    }
                    body = this.atomicCondition(needsParens);
                    if (!body) {
                        parserInput.restore();
                        return;
                    }
                    if (!parserInput.$char(')')) {
                        parserInput.restore("expected ')' got '" + parserInput.currentChar() + "'");
                        return;
                    }
                    parserInput.forget();
                    return body;
                },
                atomicCondition: function (needsParens, preparsedCond) {
                    var entities = this.entities;
                    var index = parserInput.i;
                    var a;
                    var b;
                    var c;
                    var op;
                    var cond = (function () {
                        return this.addition() || entities.keyword() || entities.quoted() || entities.mixinLookup();
                    }).bind(this);
                    if (preparsedCond) {
                        a = preparsedCond;
                    }
                    else {
                        a = cond();
                    }
                    if (a) {
                        if (parserInput.$char('>')) {
                            if (parserInput.$char('=')) {
                                op = '>=';
                            }
                            else {
                                op = '>';
                            }
                        }
                        else if (parserInput.$char('<')) {
                            if (parserInput.$char('=')) {
                                op = '<=';
                            }
                            else {
                                op = '<';
                            }
                        }
                        else if (parserInput.$char('=')) {
                            if (parserInput.$char('>')) {
                                op = '=>';
                            }
                            else if (parserInput.$char('<')) {
                                op = '=<';
                            }
                            else {
                                op = '=';
                            }
                        }
                        if (op) {
                            b = cond();
                            if (b) {
                                c = new (tree_1.default.Condition)(op, a, b, index + currentIndex, false);
                            }
                            else {
                                error('expected expression');
                            }
                        }
                        else if (!preparsedCond) {
                            c = new (tree_1.default.Condition)('=', a, new (tree_1.default.Keyword)('true'), index + currentIndex, false);
                        }
                        return c;
                    }
                },
                //
                // An operand is anything that can be part of an operation,
                // such as a Color, or a Variable
                //
                operand: function () {
                    var entities = this.entities;
                    var negate;
                    if (parserInput.peek(/^-[@$(]/)) {
                        negate = parserInput.$char('-');
                    }
                    var o = this.sub() || entities.dimension() ||
                        entities.color() || entities.variable() ||
                        entities.property() || entities.call() ||
                        entities.quoted(true) || entities.colorKeyword() ||
                        entities.mixinLookup();
                    if (negate) {
                        o.parensInOp = true;
                        o = new (tree_1.default.Negative)(o);
                    }
                    return o;
                },
                //
                // Expressions either represent mathematical operations,
                // or white-space delimited Entities.
                //
                //     1px solid black
                //     @var * 2
                //
                expression: function () {
                    var entities = [];
                    var e;
                    var delim;
                    var index = parserInput.i;
                    do {
                        e = this.comment();
                        if (e) {
                            entities.push(e);
                            continue;
                        }
                        e = this.addition() || this.entity();
                        if (e instanceof tree_1.default.Comment) {
                            e = null;
                        }
                        if (e) {
                            entities.push(e);
                            // operations do not allow keyword "/" dimension (e.g. small/20px) so we support that here
                            if (!parserInput.peek(/^\/[/*]/)) {
                                delim = parserInput.$char('/');
                                if (delim) {
                                    entities.push(new (tree_1.default.Anonymous)(delim, index + currentIndex));
                                }
                            }
                        }
                    } while (e);
                    if (entities.length > 0) {
                        return new (tree_1.default.Expression)(entities);
                    }
                },
                property: function () {
                    var name = parserInput.$re(/^(\*?-?[_a-zA-Z0-9-]+)\s*:/);
                    if (name) {
                        return name[1];
                    }
                },
                ruleProperty: function () {
                    var name = [];
                    var index = [];
                    var s;
                    var k;
                    parserInput.save();
                    var simpleProperty = parserInput.$re(/^([_a-zA-Z0-9-]+)\s*:/);
                    if (simpleProperty) {
                        name = [new (tree_1.default.Keyword)(simpleProperty[1])];
                        parserInput.forget();
                        return name;
                    }
                    function match(re) {
                        var i = parserInput.i;
                        var chunk = parserInput.$re(re);
                        if (chunk) {
                            index.push(i);
                            return name.push(chunk[1]);
                        }
                    }
                    match(/^(\*?)/);
                    while (true) {
                        if (!match(/^((?:[\w-]+)|(?:[@$]\{[\w-]+\}))/)) {
                            break;
                        }
                    }
                    if ((name.length > 1) && match(/^((?:\+_|\+)?)\s*:/)) {
                        parserInput.forget();
                        // at last, we have the complete match now. move forward,
                        // convert name particles to tree objects and return:
                        if (name[0] === '') {
                            name.shift();
                            index.shift();
                        }
                        for (k = 0; k < name.length; k++) {
                            s = name[k];
                            name[k] = (s.charAt(0) !== '@' && s.charAt(0) !== '$') ?
                                new (tree_1.default.Keyword)(s) :
                                (s.charAt(0) === '@' ?
                                    new (tree_1.default.Variable)("@" + s.slice(2, -1), index[k] + currentIndex, fileInfo) :
                                    new (tree_1.default.Property)("$" + s.slice(2, -1), index[k] + currentIndex, fileInfo));
                        }
                        return name;
                    }
                    parserInput.restore();
                }
            }
        };
    };
    Parser.serializeVars = function (vars) {
        var s = '';
        for (var name_1 in vars) {
            if (Object.hasOwnProperty.call(vars, name_1)) {
                var value = vars[name_1];
                s += ((name_1[0] === '@') ? '' : '@') + name_1 + ": " + value + ((String(value).slice(-1) === ';') ? '' : ';');
            }
        }
        return s;
    };
    exports.default = Parser;
    
},
/* less/lib/less/visitors/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var visitor_1 = tslib_1.__importDefault(require(128) /* ./visitor */);
    var import_visitor_1 = tslib_1.__importDefault(require(129) /* ./import-visitor */);
    var set_tree_visibility_visitor_1 = tslib_1.__importDefault(require(132) /* ./set-tree-visibility-visitor */);
    var extend_visitor_1 = tslib_1.__importDefault(require(133) /* ./extend-visitor */);
    var join_selector_visitor_1 = tslib_1.__importDefault(require(134) /* ./join-selector-visitor */);
    var to_css_visitor_1 = tslib_1.__importDefault(require(135) /* ./to-css-visitor */);
    exports.default = {
        Visitor: visitor_1.default,
        ImportVisitor: import_visitor_1.default,
        MarkVisibleSelectorsVisitor: set_tree_visibility_visitor_1.default,
        ExtendVisitor: extend_visitor_1.default,
        JoinSelectorVisitor: join_selector_visitor_1.default,
        ToCSSVisitor: to_css_visitor_1.default
    };
    
},
/* less/lib/less/visitors/visitor.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var tree_1 = tslib_1.__importDefault(require(113) /* ../tree */);
    var _visitArgs = { visitDeeper: true };
    var _hasIndexed = false;
    function _noop(node) {
        return node;
    }
    function indexNodeTypes(parent, ticker) {
        // add .typeIndex to tree node types for lookup table
        var key, child;
        for (key in parent) {
            /* eslint guard-for-in: 0 */
            child = parent[key];
            switch (typeof child) {
                case 'function':
                    // ignore bound functions directly on tree which do not have a prototype
                    // or aren't nodes
                    if (child.prototype && child.prototype.type) {
                        child.prototype.typeIndex = ticker++;
                    }
                    break;
                case 'object':
                    ticker = indexNodeTypes(child, ticker);
                    break;
            }
        }
        return ticker;
    }
    var Visitor = /** @class */ (function () {
        function Visitor(implementation) {
            this._implementation = implementation;
            this._visitInCache = {};
            this._visitOutCache = {};
            if (!_hasIndexed) {
                indexNodeTypes(tree_1.default, 1);
                _hasIndexed = true;
            }
        }
        Visitor.prototype.visit = function (node) {
            if (!node) {
                return node;
            }
            var nodeTypeIndex = node.typeIndex;
            if (!nodeTypeIndex) {
                // MixinCall args aren't a node type?
                if (node.value && node.value.typeIndex) {
                    this.visit(node.value);
                }
                return node;
            }
            var impl = this._implementation;
            var func = this._visitInCache[nodeTypeIndex];
            var funcOut = this._visitOutCache[nodeTypeIndex];
            var visitArgs = _visitArgs;
            var fnName;
            visitArgs.visitDeeper = true;
            if (!func) {
                fnName = "visit" + node.type;
                func = impl[fnName] || _noop;
                funcOut = impl[fnName + "Out"] || _noop;
                this._visitInCache[nodeTypeIndex] = func;
                this._visitOutCache[nodeTypeIndex] = funcOut;
            }
            if (func !== _noop) {
                var newNode = func.call(impl, node, visitArgs);
                if (node && impl.isReplacing) {
                    node = newNode;
                }
            }
            if (visitArgs.visitDeeper && node) {
                if (node.length) {
                    for (var i = 0, cnt = node.length; i < cnt; i++) {
                        if (node[i].accept) {
                            node[i].accept(this);
                        }
                    }
                }
                else if (node.accept) {
                    node.accept(this);
                }
            }
            if (funcOut != _noop) {
                funcOut.call(impl, node);
            }
            return node;
        };
        Visitor.prototype.visitArray = function (nodes, nonReplacing) {
            if (!nodes) {
                return nodes;
            }
            var cnt = nodes.length;
            var i;
            // Non-replacing
            if (nonReplacing || !this._implementation.isReplacing) {
                for (i = 0; i < cnt; i++) {
                    this.visit(nodes[i]);
                }
                return nodes;
            }
            // Replacing
            var out = [];
            for (i = 0; i < cnt; i++) {
                var evald = this.visit(nodes[i]);
                if (evald === undefined) {
                    continue;
                }
                if (!evald.splice) {
                    out.push(evald);
                }
                else if (evald.length) {
                    this.flatten(evald, out);
                }
            }
            return out;
        };
        Visitor.prototype.flatten = function (arr, out) {
            if (!out) {
                out = [];
            }
            var cnt, i, item, nestedCnt, j, nestedItem;
            for (i = 0, cnt = arr.length; i < cnt; i++) {
                item = arr[i];
                if (item === undefined) {
                    continue;
                }
                if (!item.splice) {
                    out.push(item);
                    continue;
                }
                for (j = 0, nestedCnt = item.length; j < nestedCnt; j++) {
                    nestedItem = item[j];
                    if (nestedItem === undefined) {
                        continue;
                    }
                    if (!nestedItem.splice) {
                        out.push(nestedItem);
                    }
                    else if (nestedItem.length) {
                        this.flatten(nestedItem, out);
                    }
                }
            }
            return out;
        };
        return Visitor;
    }());
    exports.default = Visitor;
    
},
/* less/lib/less/visitors/import-visitor.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    /* eslint-disable no-unused-vars */
    /**
     * @todo - Remove unused when JSDoc types are added for visitor methods
     */
    var contexts_1 = tslib_1.__importDefault(require(130) /* ../contexts */);
    var visitor_1 = tslib_1.__importDefault(require(128) /* ./visitor */);
    var import_sequencer_1 = tslib_1.__importDefault(require(131) /* ./import-sequencer */);
    var utils = tslib_1.__importStar(require(122) /* ../utils */);
    var ImportVisitor = function (importer, finish) {
        this._visitor = new visitor_1.default(this);
        this._importer = importer;
        this._finish = finish;
        this.context = new contexts_1.default.Eval();
        this.importCount = 0;
        this.onceFileDetectionMap = {};
        this.recursionDetector = {};
        this._sequencer = new import_sequencer_1.default(this._onSequencerEmpty.bind(this));
    };
    ImportVisitor.prototype = {
        isReplacing: false,
        run: function (root) {
            try {
                // process the contents
                this._visitor.visit(root);
            }
            catch (e) {
                this.error = e;
            }
            this.isFinished = true;
            this._sequencer.tryRun();
        },
        _onSequencerEmpty: function () {
            if (!this.isFinished) {
                return;
            }
            this._finish(this.error);
        },
        visitImport: function (importNode, visitArgs) {
            var inlineCSS = importNode.options.inline;
            if (!importNode.css || inlineCSS) {
                var context = new contexts_1.default.Eval(this.context, utils.copyArray(this.context.frames));
                var importParent = context.frames[0];
                this.importCount++;
                if (importNode.isVariableImport()) {
                    this._sequencer.addVariableImport(this.processImportNode.bind(this, importNode, context, importParent));
                }
                else {
                    this.processImportNode(importNode, context, importParent);
                }
            }
            visitArgs.visitDeeper = false;
        },
        processImportNode: function (importNode, context, importParent) {
            var evaldImportNode;
            var inlineCSS = importNode.options.inline;
            try {
                evaldImportNode = importNode.evalForImport(context);
            }
            catch (e) {
                if (!e.filename) {
                    e.index = importNode.getIndex();
                    e.filename = importNode.fileInfo().filename;
                }
                // attempt to eval properly and treat as css
                importNode.css = true;
                // if that fails, this error will be thrown
                importNode.error = e;
            }
            if (evaldImportNode && (!evaldImportNode.css || inlineCSS)) {
                if (evaldImportNode.options.multiple) {
                    context.importMultiple = true;
                }
                // try appending if we haven't determined if it is css or not
                var tryAppendLessExtension = evaldImportNode.css === undefined;
                for (var i = 0; i < importParent.rules.length; i++) {
                    if (importParent.rules[i] === importNode) {
                        importParent.rules[i] = evaldImportNode;
                        break;
                    }
                }
                var onImported = this.onImported.bind(this, evaldImportNode, context), sequencedOnImported = this._sequencer.addImport(onImported);
                this._importer.push(evaldImportNode.getPath(), tryAppendLessExtension, evaldImportNode.fileInfo(), evaldImportNode.options, sequencedOnImported);
            }
            else {
                this.importCount--;
                if (this.isFinished) {
                    this._sequencer.tryRun();
                }
            }
        },
        onImported: function (importNode, context, e, root, importedAtRoot, fullPath) {
            if (e) {
                if (!e.filename) {
                    e.index = importNode.getIndex();
                    e.filename = importNode.fileInfo().filename;
                }
                this.error = e;
            }
            var importVisitor = this, inlineCSS = importNode.options.inline, isPlugin = importNode.options.isPlugin, isOptional = importNode.options.optional, duplicateImport = importedAtRoot || fullPath in importVisitor.recursionDetector;
            if (!context.importMultiple) {
                if (duplicateImport) {
                    importNode.skip = true;
                }
                else {
                    importNode.skip = function () {
                        if (fullPath in importVisitor.onceFileDetectionMap) {
                            return true;
                        }
                        importVisitor.onceFileDetectionMap[fullPath] = true;
                        return false;
                    };
                }
            }
            if (!fullPath && isOptional) {
                importNode.skip = true;
            }
            if (root) {
                importNode.root = root;
                importNode.importedFilename = fullPath;
                if (!inlineCSS && !isPlugin && (context.importMultiple || !duplicateImport)) {
                    importVisitor.recursionDetector[fullPath] = true;
                    var oldContext = this.context;
                    this.context = context;
                    try {
                        this._visitor.visit(root);
                    }
                    catch (e) {
                        this.error = e;
                    }
                    this.context = oldContext;
                }
            }
            importVisitor.importCount--;
            if (importVisitor.isFinished) {
                importVisitor._sequencer.tryRun();
            }
        },
        visitDeclaration: function (declNode, visitArgs) {
            if (declNode.value.type === 'DetachedRuleset') {
                this.context.frames.unshift(declNode);
            }
            else {
                visitArgs.visitDeeper = false;
            }
        },
        visitDeclarationOut: function (declNode) {
            if (declNode.value.type === 'DetachedRuleset') {
                this.context.frames.shift();
            }
        },
        visitAtRule: function (atRuleNode, visitArgs) {
            this.context.frames.unshift(atRuleNode);
        },
        visitAtRuleOut: function (atRuleNode) {
            this.context.frames.shift();
        },
        visitMixinDefinition: function (mixinDefinitionNode, visitArgs) {
            this.context.frames.unshift(mixinDefinitionNode);
        },
        visitMixinDefinitionOut: function (mixinDefinitionNode) {
            this.context.frames.shift();
        },
        visitRuleset: function (rulesetNode, visitArgs) {
            this.context.frames.unshift(rulesetNode);
        },
        visitRulesetOut: function (rulesetNode) {
            this.context.frames.shift();
        },
        visitMedia: function (mediaNode, visitArgs) {
            this.context.frames.unshift(mediaNode.rules[0]);
        },
        visitMediaOut: function (mediaNode) {
            this.context.frames.shift();
        }
    };
    exports.default = ImportVisitor;
    
},
/* less/lib/less/contexts.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var contexts = {};
    exports.default = contexts;
    var Constants = tslib_1.__importStar(require(123) /* ./constants */);
    var copyFromOriginal = function copyFromOriginal(original, destination, propertiesToCopy) {
        if (!original) {
            return;
        }
        for (var i = 0; i < propertiesToCopy.length; i++) {
            if (Object.prototype.hasOwnProperty.call(original, propertiesToCopy[i])) {
                destination[propertiesToCopy[i]] = original[propertiesToCopy[i]];
            }
        }
    };
    /*
     parse is used whilst parsing
     */
    var parseCopyProperties = [
        // options
        'paths',
        'rewriteUrls',
        'rootpath',
        'strictImports',
        'insecure',
        'dumpLineNumbers',
        'compress',
        'syncImport',
        'chunkInput',
        'mime',
        'useFileCache',
        // context
        'processImports',
        // Used by the import manager to stop multiple import visitors being created.
        'pluginManager' // Used as the plugin manager for the session
    ];
    contexts.Parse = function (options) {
        copyFromOriginal(options, this, parseCopyProperties);
        if (typeof this.paths === 'string') {
            this.paths = [this.paths];
        }
    };
    var evalCopyProperties = [
        'paths',
        'compress',
        'math',
        'strictUnits',
        'sourceMap',
        'importMultiple',
        'urlArgs',
        'javascriptEnabled',
        'pluginManager',
        'importantScope',
        'rewriteUrls' // option - whether to adjust URL's to be relative
    ];
    contexts.Eval = function (options, frames) {
        copyFromOriginal(options, this, evalCopyProperties);
        if (typeof this.paths === 'string') {
            this.paths = [this.paths];
        }
        this.frames = frames || [];
        this.importantScope = this.importantScope || [];
    };
    contexts.Eval.prototype.enterCalc = function () {
        if (!this.calcStack) {
            this.calcStack = [];
        }
        this.calcStack.push(true);
        this.inCalc = true;
    };
    contexts.Eval.prototype.exitCalc = function () {
        this.calcStack.pop();
        if (!this.calcStack.length) {
            this.inCalc = false;
        }
    };
    contexts.Eval.prototype.inParenthesis = function () {
        if (!this.parensStack) {
            this.parensStack = [];
        }
        this.parensStack.push(true);
    };
    contexts.Eval.prototype.outOfParenthesis = function () {
        this.parensStack.pop();
    };
    contexts.Eval.prototype.inCalc = false;
    contexts.Eval.prototype.mathOn = true;
    contexts.Eval.prototype.isMathOn = function (op) {
        if (!this.mathOn) {
            return false;
        }
        if (op === '/' && this.math !== Constants.Math.ALWAYS && (!this.parensStack || !this.parensStack.length)) {
            return false;
        }
        if (this.math > Constants.Math.PARENS_DIVISION) {
            return this.parensStack && this.parensStack.length;
        }
        return true;
    };
    contexts.Eval.prototype.pathRequiresRewrite = function (path) {
        var isRelative = this.rewriteUrls === Constants.RewriteUrls.LOCAL ? isPathLocalRelative : isPathRelative;
        return isRelative(path);
    };
    contexts.Eval.prototype.rewritePath = function (path, rootpath) {
        var newPath;
        rootpath = rootpath || '';
        newPath = this.normalizePath(rootpath + path);
        // If a path was explicit relative and the rootpath was not an absolute path
        // we must ensure that the new path is also explicit relative.
        if (isPathLocalRelative(path) &&
            isPathRelative(rootpath) &&
            isPathLocalRelative(newPath) === false) {
            newPath = "./" + newPath;
        }
        return newPath;
    };
    contexts.Eval.prototype.normalizePath = function (path) {
        var segments = path.split('/').reverse();
        var segment;
        path = [];
        while (segments.length !== 0) {
            segment = segments.pop();
            switch (segment) {
                case '.':
                    break;
                case '..':
                    if ((path.length === 0) || (path[path.length - 1] === '..')) {
                        path.push(segment);
                    }
                    else {
                        path.pop();
                    }
                    break;
                default:
                    path.push(segment);
                    break;
            }
        }
        return path.join('/');
    };
    function isPathRelative(path) {
        return !/^(?:[a-z-]+:|\/|#)/i.test(path);
    }
    function isPathLocalRelative(path) {
        return path.charAt(0) === '.';
    }
    // todo - do the same for the toCSS ?
    
},
/* less/lib/less/visitors/import-sequencer.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var ImportSequencer = /** @class */ (function () {
        function ImportSequencer(onSequencerEmpty) {
            this.imports = [];
            this.variableImports = [];
            this._onSequencerEmpty = onSequencerEmpty;
            this._currentDepth = 0;
        }
        ImportSequencer.prototype.addImport = function (callback) {
            var importSequencer = this, importItem = {
                callback: callback,
                args: null,
                isReady: false
            };
            this.imports.push(importItem);
            return function () {
                importItem.args = Array.prototype.slice.call(arguments, 0);
                importItem.isReady = true;
                importSequencer.tryRun();
            };
        };
        ImportSequencer.prototype.addVariableImport = function (callback) {
            this.variableImports.push(callback);
        };
        ImportSequencer.prototype.tryRun = function () {
            this._currentDepth++;
            try {
                while (true) {
                    while (this.imports.length > 0) {
                        var importItem = this.imports[0];
                        if (!importItem.isReady) {
                            return;
                        }
                        this.imports = this.imports.slice(1);
                        importItem.callback.apply(null, importItem.args);
                    }
                    if (this.variableImports.length === 0) {
                        break;
                    }
                    var variableImport = this.variableImports[0];
                    this.variableImports = this.variableImports.slice(1);
                    variableImport();
                }
            }
            finally {
                this._currentDepth--;
            }
            if (this._currentDepth === 0 && this._onSequencerEmpty) {
                this._onSequencerEmpty();
            }
        };
        return ImportSequencer;
    }());
    exports.default = ImportSequencer;
    
},
/* less/lib/less/visitors/set-tree-visibility-visitor.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var SetTreeVisibilityVisitor = /** @class */ (function () {
        function SetTreeVisibilityVisitor(visible) {
            this.visible = visible;
        }
        SetTreeVisibilityVisitor.prototype.run = function (root) {
            this.visit(root);
        };
        SetTreeVisibilityVisitor.prototype.visitArray = function (nodes) {
            if (!nodes) {
                return nodes;
            }
            var cnt = nodes.length;
            var i;
            for (i = 0; i < cnt; i++) {
                this.visit(nodes[i]);
            }
            return nodes;
        };
        SetTreeVisibilityVisitor.prototype.visit = function (node) {
            if (!node) {
                return node;
            }
            if (node.constructor === Array) {
                return this.visitArray(node);
            }
            if (!node.blocksVisibility || node.blocksVisibility()) {
                return node;
            }
            if (this.visible) {
                node.ensureVisibility();
            }
            else {
                node.ensureInvisibility();
            }
            node.accept(this);
            return node;
        };
        return SetTreeVisibilityVisitor;
    }());
    exports.default = SetTreeVisibilityVisitor;
    
},
/* less/lib/less/visitors/extend-visitor.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    /* eslint-disable no-unused-vars */
    /**
     * @todo - Remove unused when JSDoc types are added for visitor methods
     */
    var tree_1 = tslib_1.__importDefault(require(113) /* ../tree */);
    var visitor_1 = tslib_1.__importDefault(require(128) /* ./visitor */);
    var logger_1 = tslib_1.__importDefault(require(75) /* ../logger */);
    var utils = tslib_1.__importStar(require(122) /* ../utils */);
    /* jshint loopfunc:true */
    var ExtendFinderVisitor = /** @class */ (function () {
        function ExtendFinderVisitor() {
            this._visitor = new visitor_1.default(this);
            this.contexts = [];
            this.allExtendsStack = [[]];
        }
        ExtendFinderVisitor.prototype.run = function (root) {
            root = this._visitor.visit(root);
            root.allExtends = this.allExtendsStack[0];
            return root;
        };
        ExtendFinderVisitor.prototype.visitDeclaration = function (declNode, visitArgs) {
            visitArgs.visitDeeper = false;
        };
        ExtendFinderVisitor.prototype.visitMixinDefinition = function (mixinDefinitionNode, visitArgs) {
            visitArgs.visitDeeper = false;
        };
        ExtendFinderVisitor.prototype.visitRuleset = function (rulesetNode, visitArgs) {
            if (rulesetNode.root) {
                return;
            }
            var i;
            var j;
            var extend;
            var allSelectorsExtendList = [];
            var extendList;
            // get &:extend(.a); rules which apply to all selectors in this ruleset
            var rules = rulesetNode.rules, ruleCnt = rules ? rules.length : 0;
            for (i = 0; i < ruleCnt; i++) {
                if (rulesetNode.rules[i] instanceof tree_1.default.Extend) {
                    allSelectorsExtendList.push(rules[i]);
                    rulesetNode.extendOnEveryPath = true;
                }
            }
            // now find every selector and apply the extends that apply to all extends
            // and the ones which apply to an individual extend
            var paths = rulesetNode.paths;
            for (i = 0; i < paths.length; i++) {
                var selectorPath = paths[i], selector = selectorPath[selectorPath.length - 1], selExtendList = selector.extendList;
                extendList = selExtendList ? utils.copyArray(selExtendList).concat(allSelectorsExtendList)
                    : allSelectorsExtendList;
                if (extendList) {
                    extendList = extendList.map(function (allSelectorsExtend) {
                        return allSelectorsExtend.clone();
                    });
                }
                for (j = 0; j < extendList.length; j++) {
                    this.foundExtends = true;
                    extend = extendList[j];
                    extend.findSelfSelectors(selectorPath);
                    extend.ruleset = rulesetNode;
                    if (j === 0) {
                        extend.firstExtendOnThisSelectorPath = true;
                    }
                    this.allExtendsStack[this.allExtendsStack.length - 1].push(extend);
                }
            }
            this.contexts.push(rulesetNode.selectors);
        };
        ExtendFinderVisitor.prototype.visitRulesetOut = function (rulesetNode) {
            if (!rulesetNode.root) {
                this.contexts.length = this.contexts.length - 1;
            }
        };
        ExtendFinderVisitor.prototype.visitMedia = function (mediaNode, visitArgs) {
            mediaNode.allExtends = [];
            this.allExtendsStack.push(mediaNode.allExtends);
        };
        ExtendFinderVisitor.prototype.visitMediaOut = function (mediaNode) {
            this.allExtendsStack.length = this.allExtendsStack.length - 1;
        };
        ExtendFinderVisitor.prototype.visitAtRule = function (atRuleNode, visitArgs) {
            atRuleNode.allExtends = [];
            this.allExtendsStack.push(atRuleNode.allExtends);
        };
        ExtendFinderVisitor.prototype.visitAtRuleOut = function (atRuleNode) {
            this.allExtendsStack.length = this.allExtendsStack.length - 1;
        };
        return ExtendFinderVisitor;
    }());
    var ProcessExtendsVisitor = /** @class */ (function () {
        function ProcessExtendsVisitor() {
            this._visitor = new visitor_1.default(this);
        }
        ProcessExtendsVisitor.prototype.run = function (root) {
            var extendFinder = new ExtendFinderVisitor();
            this.extendIndices = {};
            extendFinder.run(root);
            if (!extendFinder.foundExtends) {
                return root;
            }
            root.allExtends = root.allExtends.concat(this.doExtendChaining(root.allExtends, root.allExtends));
            this.allExtendsStack = [root.allExtends];
            var newRoot = this._visitor.visit(root);
            this.checkExtendsForNonMatched(root.allExtends);
            return newRoot;
        };
        ProcessExtendsVisitor.prototype.checkExtendsForNonMatched = function (extendList) {
            var indices = this.extendIndices;
            extendList.filter(function (extend) {
                return !extend.hasFoundMatches && extend.parent_ids.length == 1;
            }).forEach(function (extend) {
                var selector = '_unknown_';
                try {
                    selector = extend.selector.toCSS({});
                }
                catch (_) { }
                if (!indices[extend.index + " " + selector]) {
                    indices[extend.index + " " + selector] = true;
                    logger_1.default.warn("extend '" + selector + "' has no matches");
                }
            });
        };
        ProcessExtendsVisitor.prototype.doExtendChaining = function (extendsList, extendsListTarget, iterationCount) {
            //
            // chaining is different from normal extension.. if we extend an extend then we are not just copying, altering
            // and pasting the selector we would do normally, but we are also adding an extend with the same target selector
            // this means this new extend can then go and alter other extends
            //
            // this method deals with all the chaining work - without it, extend is flat and doesn't work on other extend selectors
            // this is also the most expensive.. and a match on one selector can cause an extension of a selector we had already
            // processed if we look at each selector at a time, as is done in visitRuleset
            var extendIndex;
            var targetExtendIndex;
            var matches;
            var extendsToAdd = [];
            var newSelector;
            var extendVisitor = this;
            var selectorPath;
            var extend;
            var targetExtend;
            var newExtend;
            iterationCount = iterationCount || 0;
            // loop through comparing every extend with every target extend.
            // a target extend is the one on the ruleset we are looking at copy/edit/pasting in place
            // e.g.  .a:extend(.b) {}  and .b:extend(.c) {} then the first extend extends the second one
            // and the second is the target.
            // the separation into two lists allows us to process a subset of chains with a bigger set, as is the
            // case when processing media queries
            for (extendIndex = 0; extendIndex < extendsList.length; extendIndex++) {
                for (targetExtendIndex = 0; targetExtendIndex < extendsListTarget.length; targetExtendIndex++) {
                    extend = extendsList[extendIndex];
                    targetExtend = extendsListTarget[targetExtendIndex];
                    // look for circular references
                    if (extend.parent_ids.indexOf(targetExtend.object_id) >= 0) {
                        continue;
                    }
                    // find a match in the target extends self selector (the bit before :extend)
                    selectorPath = [targetExtend.selfSelectors[0]];
                    matches = extendVisitor.findMatch(extend, selectorPath);
                    if (matches.length) {
                        extend.hasFoundMatches = true;
                        // we found a match, so for each self selector..
                        extend.selfSelectors.forEach(function (selfSelector) {
                            var info = targetExtend.visibilityInfo();
                            // process the extend as usual
                            newSelector = extendVisitor.extendSelector(matches, selectorPath, selfSelector, extend.isVisible());
                            // but now we create a new extend from it
                            newExtend = new (tree_1.default.Extend)(targetExtend.selector, targetExtend.option, 0, targetExtend.fileInfo(), info);
                            newExtend.selfSelectors = newSelector;
                            // add the extend onto the list of extends for that selector
                            newSelector[newSelector.length - 1].extendList = [newExtend];
                            // record that we need to add it.
                            extendsToAdd.push(newExtend);
                            newExtend.ruleset = targetExtend.ruleset;
                            // remember its parents for circular references
                            newExtend.parent_ids = newExtend.parent_ids.concat(targetExtend.parent_ids, extend.parent_ids);
                            // only process the selector once.. if we have :extend(.a,.b) then multiple
                            // extends will look at the same selector path, so when extending
                            // we know that any others will be duplicates in terms of what is added to the css
                            if (targetExtend.firstExtendOnThisSelectorPath) {
                                newExtend.firstExtendOnThisSelectorPath = true;
                                targetExtend.ruleset.paths.push(newSelector);
                            }
                        });
                    }
                }
            }
            if (extendsToAdd.length) {
                // try to detect circular references to stop a stack overflow.
                // may no longer be needed.
                this.extendChainCount++;
                if (iterationCount > 100) {
                    var selectorOne = '{unable to calculate}';
                    var selectorTwo = '{unable to calculate}';
                    try {
                        selectorOne = extendsToAdd[0].selfSelectors[0].toCSS();
                        selectorTwo = extendsToAdd[0].selector.toCSS();
                    }
                    catch (e) { }
                    throw { message: "extend circular reference detected. One of the circular extends is currently:" + selectorOne + ":extend(" + selectorTwo + ")" };
                }
                // now process the new extends on the existing rules so that we can handle a extending b extending c extending
                // d extending e...
                return extendsToAdd.concat(extendVisitor.doExtendChaining(extendsToAdd, extendsListTarget, iterationCount + 1));
            }
            else {
                return extendsToAdd;
            }
        };
        ProcessExtendsVisitor.prototype.visitDeclaration = function (ruleNode, visitArgs) {
            visitArgs.visitDeeper = false;
        };
        ProcessExtendsVisitor.prototype.visitMixinDefinition = function (mixinDefinitionNode, visitArgs) {
            visitArgs.visitDeeper = false;
        };
        ProcessExtendsVisitor.prototype.visitSelector = function (selectorNode, visitArgs) {
            visitArgs.visitDeeper = false;
        };
        ProcessExtendsVisitor.prototype.visitRuleset = function (rulesetNode, visitArgs) {
            if (rulesetNode.root) {
                return;
            }
            var matches;
            var pathIndex;
            var extendIndex;
            var allExtends = this.allExtendsStack[this.allExtendsStack.length - 1];
            var selectorsToAdd = [];
            var extendVisitor = this;
            var selectorPath;
            // look at each selector path in the ruleset, find any extend matches and then copy, find and replace
            for (extendIndex = 0; extendIndex < allExtends.length; extendIndex++) {
                for (pathIndex = 0; pathIndex < rulesetNode.paths.length; pathIndex++) {
                    selectorPath = rulesetNode.paths[pathIndex];
                    // extending extends happens initially, before the main pass
                    if (rulesetNode.extendOnEveryPath) {
                        continue;
                    }
                    var extendList = selectorPath[selectorPath.length - 1].extendList;
                    if (extendList && extendList.length) {
                        continue;
                    }
                    matches = this.findMatch(allExtends[extendIndex], selectorPath);
                    if (matches.length) {
                        allExtends[extendIndex].hasFoundMatches = true;
                        allExtends[extendIndex].selfSelectors.forEach(function (selfSelector) {
                            var extendedSelectors;
                            extendedSelectors = extendVisitor.extendSelector(matches, selectorPath, selfSelector, allExtends[extendIndex].isVisible());
                            selectorsToAdd.push(extendedSelectors);
                        });
                    }
                }
            }
            rulesetNode.paths = rulesetNode.paths.concat(selectorsToAdd);
        };
        ProcessExtendsVisitor.prototype.findMatch = function (extend, haystackSelectorPath) {
            //
            // look through the haystack selector path to try and find the needle - extend.selector
            // returns an array of selector matches that can then be replaced
            //
            var haystackSelectorIndex;
            var hackstackSelector;
            var hackstackElementIndex;
            var haystackElement;
            var targetCombinator;
            var i;
            var extendVisitor = this;
            var needleElements = extend.selector.elements;
            var potentialMatches = [];
            var potentialMatch;
            var matches = [];
            // loop through the haystack elements
            for (haystackSelectorIndex = 0; haystackSelectorIndex < haystackSelectorPath.length; haystackSelectorIndex++) {
                hackstackSelector = haystackSelectorPath[haystackSelectorIndex];
                for (hackstackElementIndex = 0; hackstackElementIndex < hackstackSelector.elements.length; hackstackElementIndex++) {
                    haystackElement = hackstackSelector.elements[hackstackElementIndex];
                    // if we allow elements before our match we can add a potential match every time. otherwise only at the first element.
                    if (extend.allowBefore || (haystackSelectorIndex === 0 && hackstackElementIndex === 0)) {
                        potentialMatches.push({ pathIndex: haystackSelectorIndex, index: hackstackElementIndex, matched: 0,
                            initialCombinator: haystackElement.combinator });
                    }
                    for (i = 0; i < potentialMatches.length; i++) {
                        potentialMatch = potentialMatches[i];
                        // selectors add " " onto the first element. When we use & it joins the selectors together, but if we don't
                        // then each selector in haystackSelectorPath has a space before it added in the toCSS phase. so we need to
                        // work out what the resulting combinator will be
                        targetCombinator = haystackElement.combinator.value;
                        if (targetCombinator === '' && hackstackElementIndex === 0) {
                            targetCombinator = ' ';
                        }
                        // if we don't match, null our match to indicate failure
                        if (!extendVisitor.isElementValuesEqual(needleElements[potentialMatch.matched].value, haystackElement.value) ||
                            (potentialMatch.matched > 0 && needleElements[potentialMatch.matched].combinator.value !== targetCombinator)) {
                            potentialMatch = null;
                        }
                        else {
                            potentialMatch.matched++;
                        }
                        // if we are still valid and have finished, test whether we have elements after and whether these are allowed
                        if (potentialMatch) {
                            potentialMatch.finished = potentialMatch.matched === needleElements.length;
                            if (potentialMatch.finished &&
                                (!extend.allowAfter &&
                                    (hackstackElementIndex + 1 < hackstackSelector.elements.length || haystackSelectorIndex + 1 < haystackSelectorPath.length))) {
                                potentialMatch = null;
                            }
                        }
                        // if null we remove, if not, we are still valid, so either push as a valid match or continue
                        if (potentialMatch) {
                            if (potentialMatch.finished) {
                                potentialMatch.length = needleElements.length;
                                potentialMatch.endPathIndex = haystackSelectorIndex;
                                potentialMatch.endPathElementIndex = hackstackElementIndex + 1; // index after end of match
                                potentialMatches.length = 0; // we don't allow matches to overlap, so start matching again
                                matches.push(potentialMatch);
                            }
                        }
                        else {
                            potentialMatches.splice(i, 1);
                            i--;
                        }
                    }
                }
            }
            return matches;
        };
        ProcessExtendsVisitor.prototype.isElementValuesEqual = function (elementValue1, elementValue2) {
            if (typeof elementValue1 === 'string' || typeof elementValue2 === 'string') {
                return elementValue1 === elementValue2;
            }
            if (elementValue1 instanceof tree_1.default.Attribute) {
                if (elementValue1.op !== elementValue2.op || elementValue1.key !== elementValue2.key) {
                    return false;
                }
                if (!elementValue1.value || !elementValue2.value) {
                    if (elementValue1.value || elementValue2.value) {
                        return false;
                    }
                    return true;
                }
                elementValue1 = elementValue1.value.value || elementValue1.value;
                elementValue2 = elementValue2.value.value || elementValue2.value;
                return elementValue1 === elementValue2;
            }
            elementValue1 = elementValue1.value;
            elementValue2 = elementValue2.value;
            if (elementValue1 instanceof tree_1.default.Selector) {
                if (!(elementValue2 instanceof tree_1.default.Selector) || elementValue1.elements.length !== elementValue2.elements.length) {
                    return false;
                }
                for (var i = 0; i < elementValue1.elements.length; i++) {
                    if (elementValue1.elements[i].combinator.value !== elementValue2.elements[i].combinator.value) {
                        if (i !== 0 || (elementValue1.elements[i].combinator.value || ' ') !== (elementValue2.elements[i].combinator.value || ' ')) {
                            return false;
                        }
                    }
                    if (!this.isElementValuesEqual(elementValue1.elements[i].value, elementValue2.elements[i].value)) {
                        return false;
                    }
                }
                return true;
            }
            return false;
        };
        ProcessExtendsVisitor.prototype.extendSelector = function (matches, selectorPath, replacementSelector, isVisible) {
            // for a set of matches, replace each match with the replacement selector
            var currentSelectorPathIndex = 0, currentSelectorPathElementIndex = 0, path = [], matchIndex, selector, firstElement, match, newElements;
            for (matchIndex = 0; matchIndex < matches.length; matchIndex++) {
                match = matches[matchIndex];
                selector = selectorPath[match.pathIndex];
                firstElement = new tree_1.default.Element(match.initialCombinator, replacementSelector.elements[0].value, replacementSelector.elements[0].isVariable, replacementSelector.elements[0].getIndex(), replacementSelector.elements[0].fileInfo());
                if (match.pathIndex > currentSelectorPathIndex && currentSelectorPathElementIndex > 0) {
                    path[path.length - 1].elements = path[path.length - 1]
                        .elements.concat(selectorPath[currentSelectorPathIndex].elements.slice(currentSelectorPathElementIndex));
                    currentSelectorPathElementIndex = 0;
                    currentSelectorPathIndex++;
                }
                newElements = selector.elements
                    .slice(currentSelectorPathElementIndex, match.index)
                    .concat([firstElement])
                    .concat(replacementSelector.elements.slice(1));
                if (currentSelectorPathIndex === match.pathIndex && matchIndex > 0) {
                    path[path.length - 1].elements =
                        path[path.length - 1].elements.concat(newElements);
                }
                else {
                    path = path.concat(selectorPath.slice(currentSelectorPathIndex, match.pathIndex));
                    path.push(new tree_1.default.Selector(newElements));
                }
                currentSelectorPathIndex = match.endPathIndex;
                currentSelectorPathElementIndex = match.endPathElementIndex;
                if (currentSelectorPathElementIndex >= selectorPath[currentSelectorPathIndex].elements.length) {
                    currentSelectorPathElementIndex = 0;
                    currentSelectorPathIndex++;
                }
            }
            if (currentSelectorPathIndex < selectorPath.length && currentSelectorPathElementIndex > 0) {
                path[path.length - 1].elements = path[path.length - 1]
                    .elements.concat(selectorPath[currentSelectorPathIndex].elements.slice(currentSelectorPathElementIndex));
                currentSelectorPathIndex++;
            }
            path = path.concat(selectorPath.slice(currentSelectorPathIndex, selectorPath.length));
            path = path.map(function (currentValue) {
                // we can re-use elements here, because the visibility property matters only for selectors
                var derived = currentValue.createDerived(currentValue.elements);
                if (isVisible) {
                    derived.ensureVisibility();
                }
                else {
                    derived.ensureInvisibility();
                }
                return derived;
            });
            return path;
        };
        ProcessExtendsVisitor.prototype.visitMedia = function (mediaNode, visitArgs) {
            var newAllExtends = mediaNode.allExtends.concat(this.allExtendsStack[this.allExtendsStack.length - 1]);
            newAllExtends = newAllExtends.concat(this.doExtendChaining(newAllExtends, mediaNode.allExtends));
            this.allExtendsStack.push(newAllExtends);
        };
        ProcessExtendsVisitor.prototype.visitMediaOut = function (mediaNode) {
            var lastIndex = this.allExtendsStack.length - 1;
            this.allExtendsStack.length = lastIndex;
        };
        ProcessExtendsVisitor.prototype.visitAtRule = function (atRuleNode, visitArgs) {
            var newAllExtends = atRuleNode.allExtends.concat(this.allExtendsStack[this.allExtendsStack.length - 1]);
            newAllExtends = newAllExtends.concat(this.doExtendChaining(newAllExtends, atRuleNode.allExtends));
            this.allExtendsStack.push(newAllExtends);
        };
        ProcessExtendsVisitor.prototype.visitAtRuleOut = function (atRuleNode) {
            var lastIndex = this.allExtendsStack.length - 1;
            this.allExtendsStack.length = lastIndex;
        };
        return ProcessExtendsVisitor;
    }());
    exports.default = ProcessExtendsVisitor;
    
},
/* less/lib/less/visitors/join-selector-visitor.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    /* eslint-disable no-unused-vars */
    /**
     * @todo - Remove unused when JSDoc types are added for visitor methods
     */
    var visitor_1 = tslib_1.__importDefault(require(128) /* ./visitor */);
    var JoinSelectorVisitor = /** @class */ (function () {
        function JoinSelectorVisitor() {
            this.contexts = [[]];
            this._visitor = new visitor_1.default(this);
        }
        JoinSelectorVisitor.prototype.run = function (root) {
            return this._visitor.visit(root);
        };
        JoinSelectorVisitor.prototype.visitDeclaration = function (declNode, visitArgs) {
            visitArgs.visitDeeper = false;
        };
        JoinSelectorVisitor.prototype.visitMixinDefinition = function (mixinDefinitionNode, visitArgs) {
            visitArgs.visitDeeper = false;
        };
        JoinSelectorVisitor.prototype.visitRuleset = function (rulesetNode, visitArgs) {
            var context = this.contexts[this.contexts.length - 1];
            var paths = [];
            var selectors;
            this.contexts.push(paths);
            if (!rulesetNode.root) {
                selectors = rulesetNode.selectors;
                if (selectors) {
                    selectors = selectors.filter(function (selector) { return selector.getIsOutput(); });
                    rulesetNode.selectors = selectors.length ? selectors : (selectors = null);
                    if (selectors) {
                        rulesetNode.joinSelectors(paths, context, selectors);
                    }
                }
                if (!selectors) {
                    rulesetNode.rules = null;
                }
                rulesetNode.paths = paths;
            }
        };
        JoinSelectorVisitor.prototype.visitRulesetOut = function (rulesetNode) {
            this.contexts.length = this.contexts.length - 1;
        };
        JoinSelectorVisitor.prototype.visitMedia = function (mediaNode, visitArgs) {
            var context = this.contexts[this.contexts.length - 1];
            mediaNode.rules[0].root = (context.length === 0 || context[0].multiMedia);
        };
        JoinSelectorVisitor.prototype.visitAtRule = function (atRuleNode, visitArgs) {
            var context = this.contexts[this.contexts.length - 1];
            if (atRuleNode.rules && atRuleNode.rules.length) {
                atRuleNode.rules[0].root = (atRuleNode.isRooted || context.length === 0 || null);
            }
        };
        return JoinSelectorVisitor;
    }());
    exports.default = JoinSelectorVisitor;
    
},
/* less/lib/less/visitors/to-css-visitor.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    /* eslint-disable no-unused-vars */
    /**
     * @todo - Remove unused when JSDoc types are added for visitor methods
     */
    var tree_1 = tslib_1.__importDefault(require(113) /* ../tree */);
    var visitor_1 = tslib_1.__importDefault(require(128) /* ./visitor */);
    var CSSVisitorUtils = /** @class */ (function () {
        function CSSVisitorUtils(context) {
            this._visitor = new visitor_1.default(this);
            this._context = context;
        }
        CSSVisitorUtils.prototype.containsSilentNonBlockedChild = function (bodyRules) {
            var rule;
            if (!bodyRules) {
                return false;
            }
            for (var r = 0; r < bodyRules.length; r++) {
                rule = bodyRules[r];
                if (rule.isSilent && rule.isSilent(this._context) && !rule.blocksVisibility()) {
                    // the atrule contains something that was referenced (likely by extend)
                    // therefore it needs to be shown in output too
                    return true;
                }
            }
            return false;
        };
        CSSVisitorUtils.prototype.keepOnlyVisibleChilds = function (owner) {
            if (owner && owner.rules) {
                owner.rules = owner.rules.filter(function (thing) { return thing.isVisible(); });
            }
        };
        CSSVisitorUtils.prototype.isEmpty = function (owner) {
            return (owner && owner.rules)
                ? (owner.rules.length === 0) : true;
        };
        CSSVisitorUtils.prototype.hasVisibleSelector = function (rulesetNode) {
            return (rulesetNode && rulesetNode.paths)
                ? (rulesetNode.paths.length > 0) : false;
        };
        CSSVisitorUtils.prototype.resolveVisibility = function (node) {
            if (!node.blocksVisibility()) {
                if (this.isEmpty(node)) {
                    return;
                }
                return node;
            }
            var compiledRulesBody = node.rules[0];
            this.keepOnlyVisibleChilds(compiledRulesBody);
            if (this.isEmpty(compiledRulesBody)) {
                return;
            }
            node.ensureVisibility();
            node.removeVisibilityBlock();
            return node;
        };
        CSSVisitorUtils.prototype.isVisibleRuleset = function (rulesetNode) {
            if (rulesetNode.firstRoot) {
                return true;
            }
            if (this.isEmpty(rulesetNode)) {
                return false;
            }
            if (!rulesetNode.root && !this.hasVisibleSelector(rulesetNode)) {
                return false;
            }
            return true;
        };
        return CSSVisitorUtils;
    }());
    var ToCSSVisitor = function (context) {
        this._visitor = new visitor_1.default(this);
        this._context = context;
        this.utils = new CSSVisitorUtils(context);
    };
    ToCSSVisitor.prototype = {
        isReplacing: true,
        run: function (root) {
            return this._visitor.visit(root);
        },
        visitDeclaration: function (declNode, visitArgs) {
            if (declNode.blocksVisibility() || declNode.variable) {
                return;
            }
            return declNode;
        },
        visitMixinDefinition: function (mixinNode, visitArgs) {
            // mixin definitions do not get eval'd - this means they keep state
            // so we have to clear that state here so it isn't used if toCSS is called twice
            mixinNode.frames = [];
        },
        visitExtend: function (extendNode, visitArgs) {
        },
        visitComment: function (commentNode, visitArgs) {
            if (commentNode.blocksVisibility() || commentNode.isSilent(this._context)) {
                return;
            }
            return commentNode;
        },
        visitMedia: function (mediaNode, visitArgs) {
            var originalRules = mediaNode.rules[0].rules;
            mediaNode.accept(this._visitor);
            visitArgs.visitDeeper = false;
            return this.utils.resolveVisibility(mediaNode, originalRules);
        },
        visitImport: function (importNode, visitArgs) {
            if (importNode.blocksVisibility()) {
                return;
            }
            return importNode;
        },
        visitAtRule: function (atRuleNode, visitArgs) {
            if (atRuleNode.rules && atRuleNode.rules.length) {
                return this.visitAtRuleWithBody(atRuleNode, visitArgs);
            }
            else {
                return this.visitAtRuleWithoutBody(atRuleNode, visitArgs);
            }
        },
        visitAnonymous: function (anonymousNode, visitArgs) {
            if (!anonymousNode.blocksVisibility()) {
                anonymousNode.accept(this._visitor);
                return anonymousNode;
            }
        },
        visitAtRuleWithBody: function (atRuleNode, visitArgs) {
            // if there is only one nested ruleset and that one has no path, then it is
            // just fake ruleset
            function hasFakeRuleset(atRuleNode) {
                var bodyRules = atRuleNode.rules;
                return bodyRules.length === 1 && (!bodyRules[0].paths || bodyRules[0].paths.length === 0);
            }
            function getBodyRules(atRuleNode) {
                var nodeRules = atRuleNode.rules;
                if (hasFakeRuleset(atRuleNode)) {
                    return nodeRules[0].rules;
                }
                return nodeRules;
            }
            // it is still true that it is only one ruleset in array
            // this is last such moment
            // process childs
            var originalRules = getBodyRules(atRuleNode);
            atRuleNode.accept(this._visitor);
            visitArgs.visitDeeper = false;
            if (!this.utils.isEmpty(atRuleNode)) {
                this._mergeRules(atRuleNode.rules[0].rules);
            }
            return this.utils.resolveVisibility(atRuleNode, originalRules);
        },
        visitAtRuleWithoutBody: function (atRuleNode, visitArgs) {
            if (atRuleNode.blocksVisibility()) {
                return;
            }
            if (atRuleNode.name === '@charset') {
                // Only output the debug info together with subsequent @charset definitions
                // a comment (or @media statement) before the actual @charset atrule would
                // be considered illegal css as it has to be on the first line
                if (this.charset) {
                    if (atRuleNode.debugInfo) {
                        var comment = new tree_1.default.Comment("/* " + atRuleNode.toCSS(this._context).replace(/\n/g, '') + " */\n");
                        comment.debugInfo = atRuleNode.debugInfo;
                        return this._visitor.visit(comment);
                    }
                    return;
                }
                this.charset = true;
            }
            return atRuleNode;
        },
        checkValidNodes: function (rules, isRoot) {
            if (!rules) {
                return;
            }
            for (var i = 0; i < rules.length; i++) {
                var ruleNode = rules[i];
                if (isRoot && ruleNode instanceof tree_1.default.Declaration && !ruleNode.variable) {
                    throw { message: 'Properties must be inside selector blocks. They cannot be in the root',
                        index: ruleNode.getIndex(), filename: ruleNode.fileInfo() && ruleNode.fileInfo().filename };
                }
                if (ruleNode instanceof tree_1.default.Call) {
                    throw { message: "Function '" + ruleNode.name + "' did not return a root node",
                        index: ruleNode.getIndex(), filename: ruleNode.fileInfo() && ruleNode.fileInfo().filename };
                }
                if (ruleNode.type && !ruleNode.allowRoot) {
                    throw { message: ruleNode.type + " node returned by a function is not valid here",
                        index: ruleNode.getIndex(), filename: ruleNode.fileInfo() && ruleNode.fileInfo().filename };
                }
            }
        },
        visitRuleset: function (rulesetNode, visitArgs) {
            // at this point rulesets are nested into each other
            var rule;
            var rulesets = [];
            this.checkValidNodes(rulesetNode.rules, rulesetNode.firstRoot);
            if (!rulesetNode.root) {
                // remove invisible paths
                this._compileRulesetPaths(rulesetNode);
                // remove rulesets from this ruleset body and compile them separately
                var nodeRules = rulesetNode.rules;
                var nodeRuleCnt = nodeRules ? nodeRules.length : 0;
                for (var i = 0; i < nodeRuleCnt;) {
                    rule = nodeRules[i];
                    if (rule && rule.rules) {
                        // visit because we are moving them out from being a child
                        rulesets.push(this._visitor.visit(rule));
                        nodeRules.splice(i, 1);
                        nodeRuleCnt--;
                        continue;
                    }
                    i++;
                }
                // accept the visitor to remove rules and refactor itself
                // then we can decide nogw whether we want it or not
                // compile body
                if (nodeRuleCnt > 0) {
                    rulesetNode.accept(this._visitor);
                }
                else {
                    rulesetNode.rules = null;
                }
                visitArgs.visitDeeper = false;
            }
            else { // if (! rulesetNode.root) {
                rulesetNode.accept(this._visitor);
                visitArgs.visitDeeper = false;
            }
            if (rulesetNode.rules) {
                this._mergeRules(rulesetNode.rules);
                this._removeDuplicateRules(rulesetNode.rules);
            }
            // now decide whether we keep the ruleset
            if (this.utils.isVisibleRuleset(rulesetNode)) {
                rulesetNode.ensureVisibility();
                rulesets.splice(0, 0, rulesetNode);
            }
            if (rulesets.length === 1) {
                return rulesets[0];
            }
            return rulesets;
        },
        _compileRulesetPaths: function (rulesetNode) {
            if (rulesetNode.paths) {
                rulesetNode.paths = rulesetNode.paths
                    .filter(function (p) {
                    var i;
                    if (p[0].elements[0].combinator.value === ' ') {
                        p[0].elements[0].combinator = new (tree_1.default.Combinator)('');
                    }
                    for (i = 0; i < p.length; i++) {
                        if (p[i].isVisible() && p[i].getIsOutput()) {
                            return true;
                        }
                    }
                    return false;
                });
            }
        },
        _removeDuplicateRules: function (rules) {
            if (!rules) {
                return;
            }
            // remove duplicates
            var ruleCache = {};
            var ruleList;
            var rule;
            var i;
            for (i = rules.length - 1; i >= 0; i--) {
                rule = rules[i];
                if (rule instanceof tree_1.default.Declaration) {
                    if (!ruleCache[rule.name]) {
                        ruleCache[rule.name] = rule;
                    }
                    else {
                        ruleList = ruleCache[rule.name];
                        if (ruleList instanceof tree_1.default.Declaration) {
                            ruleList = ruleCache[rule.name] = [ruleCache[rule.name].toCSS(this._context)];
                        }
                        var ruleCSS = rule.toCSS(this._context);
                        if (ruleList.indexOf(ruleCSS) !== -1) {
                            rules.splice(i, 1);
                        }
                        else {
                            ruleList.push(ruleCSS);
                        }
                    }
                }
            }
        },
        _mergeRules: function (rules) {
            if (!rules) {
                return;
            }
            var groups = {};
            var groupsArr = [];
            for (var i = 0; i < rules.length; i++) {
                var rule = rules[i];
                if (rule.merge) {
                    var key = rule.name;
                    groups[key] ? rules.splice(i--, 1) :
                        groupsArr.push(groups[key] = []);
                    groups[key].push(rule);
                }
            }
            groupsArr.forEach(function (group) {
                if (group.length > 0) {
                    var result_1 = group[0];
                    var space_1 = [];
                    var comma_1 = [new tree_1.default.Expression(space_1)];
                    group.forEach(function (rule) {
                        if ((rule.merge === '+') && (space_1.length > 0)) {
                            comma_1.push(new tree_1.default.Expression(space_1 = []));
                        }
                        space_1.push(rule.value);
                        result_1.important = result_1.important || rule.important;
                    });
                    result_1.value = new tree_1.default.Value(comma_1);
                }
            });
        }
    };
    exports.default = ToCSSVisitor;
    
},
/* less/lib/less/parser/parser-input.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var chunker_1 = tslib_1.__importDefault(require(137) /* ./chunker */);
    exports.default = (function () {
        var // Less input string
        input;
        var // current chunk
        j;
        var // holds state for backtracking
        saveStack = [];
        var // furthest index the parser has gone to
        furthest;
        var // if this is furthest we got to, this is the probably cause
        furthestPossibleErrorMessage;
        var // chunkified input
        chunks;
        var // current chunk
        current;
        var // index of current chunk, in `input`
        currentPos;
        var parserInput = {};
        var CHARCODE_SPACE = 32;
        var CHARCODE_TAB = 9;
        var CHARCODE_LF = 10;
        var CHARCODE_CR = 13;
        var CHARCODE_PLUS = 43;
        var CHARCODE_COMMA = 44;
        var CHARCODE_FORWARD_SLASH = 47;
        var CHARCODE_9 = 57;
        function skipWhitespace(length) {
            var oldi = parserInput.i;
            var oldj = j;
            var curr = parserInput.i - currentPos;
            var endIndex = parserInput.i + current.length - curr;
            var mem = (parserInput.i += length);
            var inp = input;
            var c;
            var nextChar;
            var comment;
            for (; parserInput.i < endIndex; parserInput.i++) {
                c = inp.charCodeAt(parserInput.i);
                if (parserInput.autoCommentAbsorb && c === CHARCODE_FORWARD_SLASH) {
                    nextChar = inp.charAt(parserInput.i + 1);
                    if (nextChar === '/') {
                        comment = { index: parserInput.i, isLineComment: true };
                        var nextNewLine = inp.indexOf('\n', parserInput.i + 2);
                        if (nextNewLine < 0) {
                            nextNewLine = endIndex;
                        }
                        parserInput.i = nextNewLine;
                        comment.text = inp.substr(comment.index, parserInput.i - comment.index);
                        parserInput.commentStore.push(comment);
                        continue;
                    }
                    else if (nextChar === '*') {
                        var nextStarSlash = inp.indexOf('*/', parserInput.i + 2);
                        if (nextStarSlash >= 0) {
                            comment = {
                                index: parserInput.i,
                                text: inp.substr(parserInput.i, nextStarSlash + 2 - parserInput.i),
                                isLineComment: false
                            };
                            parserInput.i += comment.text.length - 1;
                            parserInput.commentStore.push(comment);
                            continue;
                        }
                    }
                    break;
                }
                if ((c !== CHARCODE_SPACE) && (c !== CHARCODE_LF) && (c !== CHARCODE_TAB) && (c !== CHARCODE_CR)) {
                    break;
                }
            }
            current = current.slice(length + parserInput.i - mem + curr);
            currentPos = parserInput.i;
            if (!current.length) {
                if (j < chunks.length - 1) {
                    current = chunks[++j];
                    skipWhitespace(0); // skip space at the beginning of a chunk
                    return true; // things changed
                }
                parserInput.finished = true;
            }
            return oldi !== parserInput.i || oldj !== j;
        }
        parserInput.save = function () {
            currentPos = parserInput.i;
            saveStack.push({ current: current, i: parserInput.i, j: j });
        };
        parserInput.restore = function (possibleErrorMessage) {
            if (parserInput.i > furthest || (parserInput.i === furthest && possibleErrorMessage && !furthestPossibleErrorMessage)) {
                furthest = parserInput.i;
                furthestPossibleErrorMessage = possibleErrorMessage;
            }
            var state = saveStack.pop();
            current = state.current;
            currentPos = parserInput.i = state.i;
            j = state.j;
        };
        parserInput.forget = function () {
            saveStack.pop();
        };
        parserInput.isWhitespace = function (offset) {
            var pos = parserInput.i + (offset || 0);
            var code = input.charCodeAt(pos);
            return (code === CHARCODE_SPACE || code === CHARCODE_CR || code === CHARCODE_TAB || code === CHARCODE_LF);
        };
        // Specialization of $(tok)
        parserInput.$re = function (tok) {
            if (parserInput.i > currentPos) {
                current = current.slice(parserInput.i - currentPos);
                currentPos = parserInput.i;
            }
            var m = tok.exec(current);
            if (!m) {
                return null;
            }
            skipWhitespace(m[0].length);
            if (typeof m === 'string') {
                return m;
            }
            return m.length === 1 ? m[0] : m;
        };
        parserInput.$char = function (tok) {
            if (input.charAt(parserInput.i) !== tok) {
                return null;
            }
            skipWhitespace(1);
            return tok;
        };
        parserInput.$peekChar = function (tok) {
            if (input.charAt(parserInput.i) !== tok) {
                return null;
            }
            return tok;
        };
        parserInput.$str = function (tok) {
            var tokLength = tok.length;
            // https://jsperf.com/string-startswith/21
            for (var i = 0; i < tokLength; i++) {
                if (input.charAt(parserInput.i + i) !== tok.charAt(i)) {
                    return null;
                }
            }
            skipWhitespace(tokLength);
            return tok;
        };
        parserInput.$quoted = function (loc) {
            var pos = loc || parserInput.i;
            var startChar = input.charAt(pos);
            if (startChar !== '\'' && startChar !== '"') {
                return;
            }
            var length = input.length;
            var currentPosition = pos;
            for (var i = 1; i + currentPosition < length; i++) {
                var nextChar = input.charAt(i + currentPosition);
                switch (nextChar) {
                    case '\\':
                        i++;
                        continue;
                    case '\r':
                    case '\n':
                        break;
                    case startChar: {
                        var str = input.substr(currentPosition, i + 1);
                        if (!loc && loc !== 0) {
                            skipWhitespace(i + 1);
                            return str;
                        }
                        return [startChar, str];
                    }
                    default:
                }
            }
            return null;
        };
        /**
         * Permissive parsing. Ignores everything except matching {} [] () and quotes
         * until matching token (outside of blocks)
         */
        parserInput.$parseUntil = function (tok) {
            var quote = '';
            var returnVal = null;
            var inComment = false;
            var blockDepth = 0;
            var blockStack = [];
            var parseGroups = [];
            var length = input.length;
            var startPos = parserInput.i;
            var lastPos = parserInput.i;
            var i = parserInput.i;
            var loop = true;
            var testChar;
            if (typeof tok === 'string') {
                testChar = function (char) { return char === tok; };
            }
            else {
                testChar = function (char) { return tok.test(char); };
            }
            do {
                var nextChar = input.charAt(i);
                if (blockDepth === 0 && testChar(nextChar)) {
                    returnVal = input.substr(lastPos, i - lastPos);
                    if (returnVal) {
                        parseGroups.push(returnVal);
                    }
                    else {
                        parseGroups.push(' ');
                    }
                    returnVal = parseGroups;
                    skipWhitespace(i - startPos);
                    loop = false;
                }
                else {
                    if (inComment) {
                        if (nextChar === '*' &&
                            input.charAt(i + 1) === '/') {
                            i++;
                            blockDepth--;
                            inComment = false;
                        }
                        i++;
                        continue;
                    }
                    switch (nextChar) {
                        case '\\':
                            i++;
                            nextChar = input.charAt(i);
                            parseGroups.push(input.substr(lastPos, i - lastPos + 1));
                            lastPos = i + 1;
                            break;
                        case '/':
                            if (input.charAt(i + 1) === '*') {
                                i++;
                                inComment = true;
                                blockDepth++;
                            }
                            break;
                        case '\'':
                        case '"':
                            quote = parserInput.$quoted(i);
                            if (quote) {
                                parseGroups.push(input.substr(lastPos, i - lastPos), quote);
                                i += quote[1].length - 1;
                                lastPos = i + 1;
                            }
                            else {
                                skipWhitespace(i - startPos);
                                returnVal = nextChar;
                                loop = false;
                            }
                            break;
                        case '{':
                            blockStack.push('}');
                            blockDepth++;
                            break;
                        case '(':
                            blockStack.push(')');
                            blockDepth++;
                            break;
                        case '[':
                            blockStack.push(']');
                            blockDepth++;
                            break;
                        case '}':
                        case ')':
                        case ']': {
                            var expected = blockStack.pop();
                            if (nextChar === expected) {
                                blockDepth--;
                            }
                            else {
                                // move the parser to the error and return expected
                                skipWhitespace(i - startPos);
                                returnVal = expected;
                                loop = false;
                            }
                        }
                    }
                    i++;
                    if (i > length) {
                        loop = false;
                    }
                }
            } while (loop);
            return returnVal ? returnVal : null;
        };
        parserInput.autoCommentAbsorb = true;
        parserInput.commentStore = [];
        parserInput.finished = false;
        // Same as $(), but don't change the state of the parser,
        // just return the match.
        parserInput.peek = function (tok) {
            if (typeof tok === 'string') {
                // https://jsperf.com/string-startswith/21
                for (var i = 0; i < tok.length; i++) {
                    if (input.charAt(parserInput.i + i) !== tok.charAt(i)) {
                        return false;
                    }
                }
                return true;
            }
            else {
                return tok.test(current);
            }
        };
        // Specialization of peek()
        // TODO remove or change some currentChar calls to peekChar
        parserInput.peekChar = function (tok) { return input.charAt(parserInput.i) === tok; };
        parserInput.currentChar = function () { return input.charAt(parserInput.i); };
        parserInput.prevChar = function () { return input.charAt(parserInput.i - 1); };
        parserInput.getInput = function () { return input; };
        parserInput.peekNotNumeric = function () {
            var c = input.charCodeAt(parserInput.i);
            // Is the first char of the dimension 0-9, '.', '+' or '-'
            return (c > CHARCODE_9 || c < CHARCODE_PLUS) || c === CHARCODE_FORWARD_SLASH || c === CHARCODE_COMMA;
        };
        parserInput.start = function (str, chunkInput, failFunction) {
            input = str;
            parserInput.i = j = currentPos = furthest = 0;
            // chunking apparently makes things quicker (but my tests indicate
            // it might actually make things slower in node at least)
            // and it is a non-perfect parse - it can't recognise
            // unquoted urls, meaning it can't distinguish comments
            // meaning comments with quotes or {}() in them get 'counted'
            // and then lead to parse errors.
            // In addition if the chunking chunks in the wrong place we might
            // not be able to parse a parser statement in one go
            // this is officially deprecated but can be switched on via an option
            // in the case it causes too much performance issues.
            if (chunkInput) {
                chunks = chunker_1.default(str, failFunction);
            }
            else {
                chunks = [str];
            }
            current = chunks[0];
            skipWhitespace(0);
        };
        parserInput.end = function () {
            var message;
            var isFinished = parserInput.i >= input.length;
            if (parserInput.i < furthest) {
                message = furthestPossibleErrorMessage;
                parserInput.i = furthest;
            }
            return {
                isFinished: isFinished,
                furthest: parserInput.i,
                furthestPossibleErrorMessage: message,
                furthestReachedEnd: parserInput.i >= input.length - 1,
                furthestChar: input[parserInput.i]
            };
        };
        return parserInput;
    });
    
},
/* less/lib/less/parser/chunker.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    // Split the input into chunks.
    function default_1(input, fail) {
        var len = input.length;
        var level = 0;
        var parenLevel = 0;
        var lastOpening;
        var lastOpeningParen;
        var lastMultiComment;
        var lastMultiCommentEndBrace;
        var chunks = [];
        var emitFrom = 0;
        var chunkerCurrentIndex;
        var currentChunkStartIndex;
        var cc;
        var cc2;
        var matched;
        function emitChunk(force) {
            var len = chunkerCurrentIndex - emitFrom;
            if (((len < 512) && !force) || !len) {
                return;
            }
            chunks.push(input.slice(emitFrom, chunkerCurrentIndex + 1));
            emitFrom = chunkerCurrentIndex + 1;
        }
        for (chunkerCurrentIndex = 0; chunkerCurrentIndex < len; chunkerCurrentIndex++) {
            cc = input.charCodeAt(chunkerCurrentIndex);
            if (((cc >= 97) && (cc <= 122)) || (cc < 34)) {
                // a-z or whitespace
                continue;
            }
            switch (cc) {
                case 40: // (
                    parenLevel++;
                    lastOpeningParen = chunkerCurrentIndex;
                    continue;
                case 41: // )
                    if (--parenLevel < 0) {
                        return fail('missing opening `(`', chunkerCurrentIndex);
                    }
                    continue;
                case 59: // ;
                    if (!parenLevel) {
                        emitChunk();
                    }
                    continue;
                case 123: // {
                    level++;
                    lastOpening = chunkerCurrentIndex;
                    continue;
                case 125: // }
                    if (--level < 0) {
                        return fail('missing opening `{`', chunkerCurrentIndex);
                    }
                    if (!level && !parenLevel) {
                        emitChunk();
                    }
                    continue;
                case 92: // \
                    if (chunkerCurrentIndex < len - 1) {
                        chunkerCurrentIndex++;
                        continue;
                    }
                    return fail('unescaped `\\`', chunkerCurrentIndex);
                case 34:
                case 39:
                case 96: // ", ' and `
                    matched = 0;
                    currentChunkStartIndex = chunkerCurrentIndex;
                    for (chunkerCurrentIndex = chunkerCurrentIndex + 1; chunkerCurrentIndex < len; chunkerCurrentIndex++) {
                        cc2 = input.charCodeAt(chunkerCurrentIndex);
                        if (cc2 > 96) {
                            continue;
                        }
                        if (cc2 == cc) {
                            matched = 1;
                            break;
                        }
                        if (cc2 == 92) { // \
                            if (chunkerCurrentIndex == len - 1) {
                                return fail('unescaped `\\`', chunkerCurrentIndex);
                            }
                            chunkerCurrentIndex++;
                        }
                    }
                    if (matched) {
                        continue;
                    }
                    return fail("unmatched `" + String.fromCharCode(cc) + "`", currentChunkStartIndex);
                case 47: // /, check for comment
                    if (parenLevel || (chunkerCurrentIndex == len - 1)) {
                        continue;
                    }
                    cc2 = input.charCodeAt(chunkerCurrentIndex + 1);
                    if (cc2 == 47) {
                        // //, find lnfeed
                        for (chunkerCurrentIndex = chunkerCurrentIndex + 2; chunkerCurrentIndex < len; chunkerCurrentIndex++) {
                            cc2 = input.charCodeAt(chunkerCurrentIndex);
                            if ((cc2 <= 13) && ((cc2 == 10) || (cc2 == 13))) {
                                break;
                            }
                        }
                    }
                    else if (cc2 == 42) {
                        // /*, find */
                        lastMultiComment = currentChunkStartIndex = chunkerCurrentIndex;
                        for (chunkerCurrentIndex = chunkerCurrentIndex + 2; chunkerCurrentIndex < len - 1; chunkerCurrentIndex++) {
                            cc2 = input.charCodeAt(chunkerCurrentIndex);
                            if (cc2 == 125) {
                                lastMultiCommentEndBrace = chunkerCurrentIndex;
                            }
                            if (cc2 != 42) {
                                continue;
                            }
                            if (input.charCodeAt(chunkerCurrentIndex + 1) == 47) {
                                break;
                            }
                        }
                        if (chunkerCurrentIndex == len - 1) {
                            return fail('missing closing `*/`', currentChunkStartIndex);
                        }
                        chunkerCurrentIndex++;
                    }
                    continue;
                case 42: // *, check for unmatched */
                    if ((chunkerCurrentIndex < len - 1) && (input.charCodeAt(chunkerCurrentIndex + 1) == 47)) {
                        return fail('unmatched `/*`', chunkerCurrentIndex);
                    }
                    continue;
            }
        }
        if (level !== 0) {
            if ((lastMultiComment > lastOpening) && (lastMultiCommentEndBrace > lastMultiComment)) {
                return fail('missing closing `}` or `*/`', lastOpening);
            }
            else {
                return fail('missing closing `}`', lastOpening);
            }
        }
        else if (parenLevel !== 0) {
            return fail('missing closing `)`', lastOpeningParen);
        }
        emitChunk(true);
        return chunks;
    }
    exports.default = default_1;
    
},
/* less/lib/less/functions/function-registry.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    function makeRegistry(base) {
        return {
            _data: {},
            add: function (name, func) {
                // precautionary case conversion, as later querying of
                // the registry by function-caller uses lower case as well.
                name = name.toLowerCase();
                // eslint-disable-next-line no-prototype-builtins
                if (this._data.hasOwnProperty(name)) {
                    // TODO warn
                }
                this._data[name] = func;
            },
            addMultiple: function (functions) {
                var _this = this;
                Object.keys(functions).forEach(function (name) {
                    _this.add(name, functions[name]);
                });
            },
            get: function (name) {
                return this._data[name] || (base && base.get(name));
            },
            getLocalFunctions: function () {
                return this._data;
            },
            inherit: function () {
                return makeRegistry(this);
            },
            create: function (base) {
                return makeRegistry(base);
            }
        };
    }
    exports.default = makeRegistry(null);
    
},
/* less/lib/less/tree/atrule-syntax.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.ContainerSyntaxOptions = exports.MediaSyntaxOptions = void 0;
    exports.MediaSyntaxOptions = {
        queryInParens: true
    };
    exports.ContainerSyntaxOptions = {
        queryInParens: true
    };
    
},
/* less/lib/less/tree/ruleset.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var declaration_1 = tslib_1.__importDefault(require(141) /* ./declaration */);
    var keyword_1 = tslib_1.__importDefault(require(143) /* ./keyword */);
    var comment_1 = tslib_1.__importDefault(require(145) /* ./comment */);
    var paren_1 = tslib_1.__importDefault(require(119) /* ./paren */);
    var selector_1 = tslib_1.__importDefault(require(117) /* ./selector */);
    var element_1 = tslib_1.__importDefault(require(118) /* ./element */);
    var anonymous_1 = tslib_1.__importDefault(require(144) /* ./anonymous */);
    var contexts_1 = tslib_1.__importDefault(require(130) /* ../contexts */);
    var function_registry_1 = tslib_1.__importDefault(require(138) /* ../functions/function-registry */);
    var default_1 = tslib_1.__importDefault(require(147) /* ../functions/default */);
    var debug_info_1 = tslib_1.__importDefault(require(146) /* ./debug-info */);
    var utils = tslib_1.__importStar(require(122) /* ../utils */);
    var parser_1 = tslib_1.__importDefault(require(126) /* ../parser/parser */);
    var Ruleset = function (selectors, rules, strictImports, visibilityInfo) {
        this.selectors = selectors;
        this.rules = rules;
        this._lookups = {};
        this._variables = null;
        this._properties = null;
        this.strictImports = strictImports;
        this.copyVisibilityInfo(visibilityInfo);
        this.allowRoot = true;
        this.setParent(this.selectors, this);
        this.setParent(this.rules, this);
    };
    Ruleset.prototype = Object.assign(new node_1.default(), {
        type: 'Ruleset',
        isRuleset: true,
        isRulesetLike: function () { return true; },
        accept: function (visitor) {
            if (this.paths) {
                this.paths = visitor.visitArray(this.paths, true);
            }
            else if (this.selectors) {
                this.selectors = visitor.visitArray(this.selectors);
            }
            if (this.rules && this.rules.length) {
                this.rules = visitor.visitArray(this.rules);
            }
        },
        eval: function (context) {
            var selectors;
            var selCnt;
            var selector;
            var i;
            var hasVariable;
            var hasOnePassingSelector = false;
            if (this.selectors && (selCnt = this.selectors.length)) {
                selectors = new Array(selCnt);
                default_1.default.error({
                    type: 'Syntax',
                    message: 'it is currently only allowed in parametric mixin guards,'
                });
                for (i = 0; i < selCnt; i++) {
                    selector = this.selectors[i].eval(context);
                    for (var j = 0; j < selector.elements.length; j++) {
                        if (selector.elements[j].isVariable) {
                            hasVariable = true;
                            break;
                        }
                    }
                    selectors[i] = selector;
                    if (selector.evaldCondition) {
                        hasOnePassingSelector = true;
                    }
                }
                if (hasVariable) {
                    var toParseSelectors = new Array(selCnt);
                    for (i = 0; i < selCnt; i++) {
                        selector = selectors[i];
                        toParseSelectors[i] = selector.toCSS(context);
                    }
                    var startingIndex = selectors[0].getIndex();
                    var selectorFileInfo = selectors[0].fileInfo();
                    new parser_1.default(context, this.parse.importManager, selectorFileInfo, startingIndex).parseNode(toParseSelectors.join(','), ['selectors'], function (err, result) {
                        if (result) {
                            selectors = utils.flattenArray(result);
                        }
                    });
                }
                default_1.default.reset();
            }
            else {
                hasOnePassingSelector = true;
            }
            var rules = this.rules ? utils.copyArray(this.rules) : null;
            var ruleset = new Ruleset(selectors, rules, this.strictImports, this.visibilityInfo());
            var rule;
            var subRule;
            ruleset.originalRuleset = this;
            ruleset.root = this.root;
            ruleset.firstRoot = this.firstRoot;
            ruleset.allowImports = this.allowImports;
            if (this.debugInfo) {
                ruleset.debugInfo = this.debugInfo;
            }
            if (!hasOnePassingSelector) {
                rules.length = 0;
            }
            // inherit a function registry from the frames stack when possible;
            // otherwise from the global registry
            ruleset.functionRegistry = (function (frames) {
                var i = 0;
                var n = frames.length;
                var found;
                for (; i !== n; ++i) {
                    found = frames[i].functionRegistry;
                    if (found) {
                        return found;
                    }
                }
                return function_registry_1.default;
            }(context.frames)).inherit();
            // push the current ruleset to the frames stack
            var ctxFrames = context.frames;
            ctxFrames.unshift(ruleset);
            // currrent selectors
            var ctxSelectors = context.selectors;
            if (!ctxSelectors) {
                context.selectors = ctxSelectors = [];
            }
            ctxSelectors.unshift(this.selectors);
            // Evaluate imports
            if (ruleset.root || ruleset.allowImports || !ruleset.strictImports) {
                ruleset.evalImports(context);
            }
            // Store the frames around mixin definitions,
            // so they can be evaluated like closures when the time comes.
            var rsRules = ruleset.rules;
            for (i = 0; (rule = rsRules[i]); i++) {
                if (rule.evalFirst) {
                    rsRules[i] = rule.eval(context);
                }
            }
            var mediaBlockCount = (context.mediaBlocks && context.mediaBlocks.length) || 0;
            // Evaluate mixin calls.
            for (i = 0; (rule = rsRules[i]); i++) {
                if (rule.type === 'MixinCall') {
                    /* jshint loopfunc:true */
                    rules = rule.eval(context).filter(function (r) {
                        if ((r instanceof declaration_1.default) && r.variable) {
                            // do not pollute the scope if the variable is
                            // already there. consider returning false here
                            // but we need a way to "return" variable from mixins
                            return !(ruleset.variable(r.name));
                        }
                        return true;
                    });
                    rsRules.splice.apply(rsRules, [i, 1].concat(rules));
                    i += rules.length - 1;
                    ruleset.resetCache();
                }
                else if (rule.type === 'VariableCall') {
                    /* jshint loopfunc:true */
                    rules = rule.eval(context).rules.filter(function (r) {
                        if ((r instanceof declaration_1.default) && r.variable) {
                            // do not pollute the scope at all
                            return false;
                        }
                        return true;
                    });
                    rsRules.splice.apply(rsRules, [i, 1].concat(rules));
                    i += rules.length - 1;
                    ruleset.resetCache();
                }
            }
            // Evaluate everything else
            for (i = 0; (rule = rsRules[i]); i++) {
                if (!rule.evalFirst) {
                    rsRules[i] = rule = rule.eval ? rule.eval(context) : rule;
                }
            }
            // Evaluate everything else
            for (i = 0; (rule = rsRules[i]); i++) {
                // for rulesets, check if it is a css guard and can be removed
                if (rule instanceof Ruleset && rule.selectors && rule.selectors.length === 1) {
                    // check if it can be folded in (e.g. & where)
                    if (rule.selectors[0] && rule.selectors[0].isJustParentSelector()) {
                        rsRules.splice(i--, 1);
                        for (var j = 0; (subRule = rule.rules[j]); j++) {
                            if (subRule instanceof node_1.default) {
                                subRule.copyVisibilityInfo(rule.visibilityInfo());
                                if (!(subRule instanceof declaration_1.default) || !subRule.variable) {
                                    rsRules.splice(++i, 0, subRule);
                                }
                            }
                        }
                    }
                }
            }
            // Pop the stack
            ctxFrames.shift();
            ctxSelectors.shift();
            if (context.mediaBlocks) {
                for (i = mediaBlockCount; i < context.mediaBlocks.length; i++) {
                    context.mediaBlocks[i].bubbleSelectors(selectors);
                }
            }
            return ruleset;
        },
        evalImports: function (context) {
            var rules = this.rules;
            var i;
            var importRules;
            if (!rules) {
                return;
            }
            for (i = 0; i < rules.length; i++) {
                if (rules[i].type === 'Import') {
                    importRules = rules[i].eval(context);
                    if (importRules && (importRules.length || importRules.length === 0)) {
                        rules.splice.apply(rules, [i, 1].concat(importRules));
                        i += importRules.length - 1;
                    }
                    else {
                        rules.splice(i, 1, importRules);
                    }
                    this.resetCache();
                }
            }
        },
        makeImportant: function () {
            var result = new Ruleset(this.selectors, this.rules.map(function (r) {
                if (r.makeImportant) {
                    return r.makeImportant();
                }
                else {
                    return r;
                }
            }), this.strictImports, this.visibilityInfo());
            return result;
        },
        matchArgs: function (args) {
            return !args || args.length === 0;
        },
        // lets you call a css selector with a guard
        matchCondition: function (args, context) {
            var lastSelector = this.selectors[this.selectors.length - 1];
            if (!lastSelector.evaldCondition) {
                return false;
            }
            if (lastSelector.condition &&
                !lastSelector.condition.eval(new contexts_1.default.Eval(context, context.frames))) {
                return false;
            }
            return true;
        },
        resetCache: function () {
            this._rulesets = null;
            this._variables = null;
            this._properties = null;
            this._lookups = {};
        },
        variables: function () {
            if (!this._variables) {
                this._variables = !this.rules ? {} : this.rules.reduce(function (hash, r) {
                    if (r instanceof declaration_1.default && r.variable === true) {
                        hash[r.name] = r;
                    }
                    // when evaluating variables in an import statement, imports have not been eval'd
                    // so we need to go inside import statements.
                    // guard against root being a string (in the case of inlined less)
                    if (r.type === 'Import' && r.root && r.root.variables) {
                        var vars = r.root.variables();
                        for (var name_1 in vars) {
                            // eslint-disable-next-line no-prototype-builtins
                            if (vars.hasOwnProperty(name_1)) {
                                hash[name_1] = r.root.variable(name_1);
                            }
                        }
                    }
                    return hash;
                }, {});
            }
            return this._variables;
        },
        properties: function () {
            if (!this._properties) {
                this._properties = !this.rules ? {} : this.rules.reduce(function (hash, r) {
                    if (r instanceof declaration_1.default && r.variable !== true) {
                        var name_2 = (r.name.length === 1) && (r.name[0] instanceof keyword_1.default) ?
                            r.name[0].value : r.name;
                        // Properties don't overwrite as they can merge
                        if (!hash["$" + name_2]) {
                            hash["$" + name_2] = [r];
                        }
                        else {
                            hash["$" + name_2].push(r);
                        }
                    }
                    return hash;
                }, {});
            }
            return this._properties;
        },
        variable: function (name) {
            var decl = this.variables()[name];
            if (decl) {
                return this.parseValue(decl);
            }
        },
        property: function (name) {
            var decl = this.properties()[name];
            if (decl) {
                return this.parseValue(decl);
            }
        },
        lastDeclaration: function () {
            for (var i = this.rules.length; i > 0; i--) {
                var decl = this.rules[i - 1];
                if (decl instanceof declaration_1.default) {
                    return this.parseValue(decl);
                }
            }
        },
        parseValue: function (toParse) {
            var self = this;
            function transformDeclaration(decl) {
                if (decl.value instanceof anonymous_1.default && !decl.parsed) {
                    if (typeof decl.value.value === 'string') {
                        new parser_1.default(this.parse.context, this.parse.importManager, decl.fileInfo(), decl.value.getIndex()).parseNode(decl.value.value, ['value', 'important'], function (err, result) {
                            if (err) {
                                decl.parsed = true;
                            }
                            if (result) {
                                decl.value = result[0];
                                decl.important = result[1] || '';
                                decl.parsed = true;
                            }
                        });
                    }
                    else {
                        decl.parsed = true;
                    }
                    return decl;
                }
                else {
                    return decl;
                }
            }
            if (!Array.isArray(toParse)) {
                return transformDeclaration.call(self, toParse);
            }
            else {
                var nodes_1 = [];
                toParse.forEach(function (n) {
                    nodes_1.push(transformDeclaration.call(self, n));
                });
                return nodes_1;
            }
        },
        rulesets: function () {
            if (!this.rules) {
                return [];
            }
            var filtRules = [];
            var rules = this.rules;
            var i;
            var rule;
            for (i = 0; (rule = rules[i]); i++) {
                if (rule.isRuleset) {
                    filtRules.push(rule);
                }
            }
            return filtRules;
        },
        prependRule: function (rule) {
            var rules = this.rules;
            if (rules) {
                rules.unshift(rule);
            }
            else {
                this.rules = [rule];
            }
            this.setParent(rule, this);
        },
        find: function (selector, self, filter) {
            self = self || this;
            var rules = [];
            var match;
            var foundMixins;
            var key = selector.toCSS();
            if (key in this._lookups) {
                return this._lookups[key];
            }
            this.rulesets().forEach(function (rule) {
                if (rule !== self) {
                    for (var j = 0; j < rule.selectors.length; j++) {
                        match = selector.match(rule.selectors[j]);
                        if (match) {
                            if (selector.elements.length > match) {
                                if (!filter || filter(rule)) {
                                    foundMixins = rule.find(new selector_1.default(selector.elements.slice(match)), self, filter);
                                    for (var i = 0; i < foundMixins.length; ++i) {
                                        foundMixins[i].path.push(rule);
                                    }
                                    Array.prototype.push.apply(rules, foundMixins);
                                }
                            }
                            else {
                                rules.push({ rule: rule, path: [] });
                            }
                            break;
                        }
                    }
                }
            });
            this._lookups[key] = rules;
            return rules;
        },
        genCSS: function (context, output) {
            var i;
            var j;
            var charsetRuleNodes = [];
            var ruleNodes = [];
            var // Line number debugging
            debugInfo;
            var rule;
            var path;
            context.tabLevel = (context.tabLevel || 0);
            if (!this.root) {
                context.tabLevel++;
            }
            var tabRuleStr = context.compress ? '' : Array(context.tabLevel + 1).join('  ');
            var tabSetStr = context.compress ? '' : Array(context.tabLevel).join('  ');
            var sep;
            var charsetNodeIndex = 0;
            var importNodeIndex = 0;
            for (i = 0; (rule = this.rules[i]); i++) {
                if (rule instanceof comment_1.default) {
                    if (importNodeIndex === i) {
                        importNodeIndex++;
                    }
                    ruleNodes.push(rule);
                }
                else if (rule.isCharset && rule.isCharset()) {
                    ruleNodes.splice(charsetNodeIndex, 0, rule);
                    charsetNodeIndex++;
                    importNodeIndex++;
                }
                else if (rule.type === 'Import') {
                    ruleNodes.splice(importNodeIndex, 0, rule);
                    importNodeIndex++;
                }
                else {
                    ruleNodes.push(rule);
                }
            }
            ruleNodes = charsetRuleNodes.concat(ruleNodes);
            // If this is the root node, we don't render
            // a selector, or {}.
            if (!this.root) {
                debugInfo = debug_info_1.default(context, this, tabSetStr);
                if (debugInfo) {
                    output.add(debugInfo);
                    output.add(tabSetStr);
                }
                var paths = this.paths;
                var pathCnt = paths.length;
                var pathSubCnt = void 0;
                sep = context.compress ? ',' : (",\n" + tabSetStr);
                for (i = 0; i < pathCnt; i++) {
                    path = paths[i];
                    if (!(pathSubCnt = path.length)) {
                        continue;
                    }
                    if (i > 0) {
                        output.add(sep);
                    }
                    context.firstSelector = true;
                    path[0].genCSS(context, output);
                    context.firstSelector = false;
                    for (j = 1; j < pathSubCnt; j++) {
                        path[j].genCSS(context, output);
                    }
                }
                output.add((context.compress ? '{' : ' {\n') + tabRuleStr);
            }
            // Compile rules and rulesets
            for (i = 0; (rule = ruleNodes[i]); i++) {
                if (i + 1 === ruleNodes.length) {
                    context.lastRule = true;
                }
                var currentLastRule = context.lastRule;
                if (rule.isRulesetLike(rule)) {
                    context.lastRule = false;
                }
                if (rule.genCSS) {
                    rule.genCSS(context, output);
                }
                else if (rule.value) {
                    output.add(rule.value.toString());
                }
                context.lastRule = currentLastRule;
                if (!context.lastRule && rule.isVisible()) {
                    output.add(context.compress ? '' : ("\n" + tabRuleStr));
                }
                else {
                    context.lastRule = false;
                }
            }
            if (!this.root) {
                output.add((context.compress ? '}' : "\n" + tabSetStr + "}"));
                context.tabLevel--;
            }
            if (!output.isEmpty() && !context.compress && this.firstRoot) {
                output.add('\n');
            }
        },
        joinSelectors: function (paths, context, selectors) {
            for (var s = 0; s < selectors.length; s++) {
                this.joinSelector(paths, context, selectors[s]);
            }
        },
        joinSelector: function (paths, context, selector) {
            function createParenthesis(elementsToPak, originalElement) {
                var replacementParen, j;
                if (elementsToPak.length === 0) {
                    replacementParen = new paren_1.default(elementsToPak[0]);
                }
                else {
                    var insideParent = new Array(elementsToPak.length);
                    for (j = 0; j < elementsToPak.length; j++) {
                        insideParent[j] = new element_1.default(null, elementsToPak[j], originalElement.isVariable, originalElement._index, originalElement._fileInfo);
                    }
                    replacementParen = new paren_1.default(new selector_1.default(insideParent));
                }
                return replacementParen;
            }
            function createSelector(containedElement, originalElement) {
                var element, selector;
                element = new element_1.default(null, containedElement, originalElement.isVariable, originalElement._index, originalElement._fileInfo);
                selector = new selector_1.default([element]);
                return selector;
            }
            // joins selector path from `beginningPath` with selector path in `addPath`
            // `replacedElement` contains element that is being replaced by `addPath`
            // returns concatenated path
            function addReplacementIntoPath(beginningPath, addPath, replacedElement, originalSelector) {
                var newSelectorPath, lastSelector, newJoinedSelector;
                // our new selector path
                newSelectorPath = [];
                // construct the joined selector - if & is the first thing this will be empty,
                // if not newJoinedSelector will be the last set of elements in the selector
                if (beginningPath.length > 0) {
                    newSelectorPath = utils.copyArray(beginningPath);
                    lastSelector = newSelectorPath.pop();
                    newJoinedSelector = originalSelector.createDerived(utils.copyArray(lastSelector.elements));
                }
                else {
                    newJoinedSelector = originalSelector.createDerived([]);
                }
                if (addPath.length > 0) {
                    // /deep/ is a CSS4 selector - (removed, so should deprecate)
                    // that is valid without anything in front of it
                    // so if the & does not have a combinator that is "" or " " then
                    // and there is a combinator on the parent, then grab that.
                    // this also allows + a { & .b { .a & { ... though not sure why you would want to do that
                    var combinator = replacedElement.combinator;
                    var parentEl = addPath[0].elements[0];
                    if (combinator.emptyOrWhitespace && !parentEl.combinator.emptyOrWhitespace) {
                        combinator = parentEl.combinator;
                    }
                    // join the elements so far with the first part of the parent
                    newJoinedSelector.elements.push(new element_1.default(combinator, parentEl.value, replacedElement.isVariable, replacedElement._index, replacedElement._fileInfo));
                    newJoinedSelector.elements = newJoinedSelector.elements.concat(addPath[0].elements.slice(1));
                }
                // now add the joined selector - but only if it is not empty
                if (newJoinedSelector.elements.length !== 0) {
                    newSelectorPath.push(newJoinedSelector);
                }
                // put together the parent selectors after the join (e.g. the rest of the parent)
                if (addPath.length > 1) {
                    var restOfPath = addPath.slice(1);
                    restOfPath = restOfPath.map(function (selector) {
                        return selector.createDerived(selector.elements, []);
                    });
                    newSelectorPath = newSelectorPath.concat(restOfPath);
                }
                return newSelectorPath;
            }
            // joins selector path from `beginningPath` with every selector path in `addPaths` array
            // `replacedElement` contains element that is being replaced by `addPath`
            // returns array with all concatenated paths
            function addAllReplacementsIntoPath(beginningPath, addPaths, replacedElement, originalSelector, result) {
                var j;
                for (j = 0; j < beginningPath.length; j++) {
                    var newSelectorPath = addReplacementIntoPath(beginningPath[j], addPaths, replacedElement, originalSelector);
                    result.push(newSelectorPath);
                }
                return result;
            }
            function mergeElementsOnToSelectors(elements, selectors) {
                var i, sel;
                if (elements.length === 0) {
                    return;
                }
                if (selectors.length === 0) {
                    selectors.push([new selector_1.default(elements)]);
                    return;
                }
                for (i = 0; (sel = selectors[i]); i++) {
                    // if the previous thing in sel is a parent this needs to join on to it
                    if (sel.length > 0) {
                        sel[sel.length - 1] = sel[sel.length - 1].createDerived(sel[sel.length - 1].elements.concat(elements));
                    }
                    else {
                        sel.push(new selector_1.default(elements));
                    }
                }
            }
            // replace all parent selectors inside `inSelector` by content of `context` array
            // resulting selectors are returned inside `paths` array
            // returns true if `inSelector` contained at least one parent selector
            function replaceParentSelector(paths, context, inSelector) {
                // The paths are [[Selector]]
                // The first list is a list of comma separated selectors
                // The inner list is a list of inheritance separated selectors
                // e.g.
                // .a, .b {
                //   .c {
                //   }
                // }
                // == [[.a] [.c]] [[.b] [.c]]
                //
                var i, j, k, currentElements, newSelectors, selectorsMultiplied, sel, el, hadParentSelector = false, length, lastSelector;
                function findNestedSelector(element) {
                    var maybeSelector;
                    if (!(element.value instanceof paren_1.default)) {
                        return null;
                    }
                    maybeSelector = element.value.value;
                    if (!(maybeSelector instanceof selector_1.default)) {
                        return null;
                    }
                    return maybeSelector;
                }
                // the elements from the current selector so far
                currentElements = [];
                // the current list of new selectors to add to the path.
                // We will build it up. We initiate it with one empty selector as we "multiply" the new selectors
                // by the parents
                newSelectors = [
                    []
                ];
                for (i = 0; (el = inSelector.elements[i]); i++) {
                    // non parent reference elements just get added
                    if (el.value !== '&') {
                        var nestedSelector = findNestedSelector(el);
                        if (nestedSelector !== null) {
                            // merge the current list of non parent selector elements
                            // on to the current list of selectors to add
                            mergeElementsOnToSelectors(currentElements, newSelectors);
                            var nestedPaths = [];
                            var replaced = void 0;
                            var replacedNewSelectors = [];
                            replaced = replaceParentSelector(nestedPaths, context, nestedSelector);
                            hadParentSelector = hadParentSelector || replaced;
                            // the nestedPaths array should have only one member - replaceParentSelector does not multiply selectors
                            for (k = 0; k < nestedPaths.length; k++) {
                                var replacementSelector = createSelector(createParenthesis(nestedPaths[k], el), el);
                                addAllReplacementsIntoPath(newSelectors, [replacementSelector], el, inSelector, replacedNewSelectors);
                            }
                            newSelectors = replacedNewSelectors;
                            currentElements = [];
                        }
                        else {
                            currentElements.push(el);
                        }
                    }
                    else {
                        hadParentSelector = true;
                        // the new list of selectors to add
                        selectorsMultiplied = [];
                        // merge the current list of non parent selector elements
                        // on to the current list of selectors to add
                        mergeElementsOnToSelectors(currentElements, newSelectors);
                        // loop through our current selectors
                        for (j = 0; j < newSelectors.length; j++) {
                            sel = newSelectors[j];
                            // if we don't have any parent paths, the & might be in a mixin so that it can be used
                            // whether there are parents or not
                            if (context.length === 0) {
                                // the combinator used on el should now be applied to the next element instead so that
                                // it is not lost
                                if (sel.length > 0) {
                                    sel[0].elements.push(new element_1.default(el.combinator, '', el.isVariable, el._index, el._fileInfo));
                                }
                                selectorsMultiplied.push(sel);
                            }
                            else {
                                // and the parent selectors
                                for (k = 0; k < context.length; k++) {
                                    // We need to put the current selectors
                                    // then join the last selector's elements on to the parents selectors
                                    var newSelectorPath = addReplacementIntoPath(sel, context[k], el, inSelector);
                                    // add that to our new set of selectors
                                    selectorsMultiplied.push(newSelectorPath);
                                }
                            }
                        }
                        // our new selectors has been multiplied, so reset the state
                        newSelectors = selectorsMultiplied;
                        currentElements = [];
                    }
                }
                // if we have any elements left over (e.g. .a& .b == .b)
                // add them on to all the current selectors
                mergeElementsOnToSelectors(currentElements, newSelectors);
                for (i = 0; i < newSelectors.length; i++) {
                    length = newSelectors[i].length;
                    if (length > 0) {
                        paths.push(newSelectors[i]);
                        lastSelector = newSelectors[i][length - 1];
                        newSelectors[i][length - 1] = lastSelector.createDerived(lastSelector.elements, inSelector.extendList);
                    }
                }
                return hadParentSelector;
            }
            function deriveSelector(visibilityInfo, deriveFrom) {
                var newSelector = deriveFrom.createDerived(deriveFrom.elements, deriveFrom.extendList, deriveFrom.evaldCondition);
                newSelector.copyVisibilityInfo(visibilityInfo);
                return newSelector;
            }
            // joinSelector code follows
            var i, newPaths, hadParentSelector;
            newPaths = [];
            hadParentSelector = replaceParentSelector(newPaths, context, selector);
            if (!hadParentSelector) {
                if (context.length > 0) {
                    newPaths = [];
                    for (i = 0; i < context.length; i++) {
                        var concatenated = context[i].map(deriveSelector.bind(this, selector.visibilityInfo()));
                        concatenated.push(selector);
                        newPaths.push(concatenated);
                    }
                }
                else {
                    newPaths = [[selector]];
                }
            }
            for (i = 0; i < newPaths.length; i++) {
                paths.push(newPaths[i]);
            }
        }
    });
    exports.default = Ruleset;
    
},
/* less/lib/less/tree/declaration.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var value_1 = tslib_1.__importDefault(require(142) /* ./value */);
    var keyword_1 = tslib_1.__importDefault(require(143) /* ./keyword */);
    var anonymous_1 = tslib_1.__importDefault(require(144) /* ./anonymous */);
    var Constants = tslib_1.__importStar(require(123) /* ../constants */);
    var MATH = Constants.Math;
    function evalName(context, name) {
        var value = '';
        var i;
        var n = name.length;
        var output = { add: function (s) { value += s; } };
        for (i = 0; i < n; i++) {
            name[i].eval(context).genCSS(context, output);
        }
        return value;
    }
    var Declaration = function (name, value, important, merge, index, currentFileInfo, inline, variable) {
        this.name = name;
        this.value = (value instanceof node_1.default) ? value : new value_1.default([value ? new anonymous_1.default(value) : null]);
        this.important = important ? " " + important.trim() : '';
        this.merge = merge;
        this._index = index;
        this._fileInfo = currentFileInfo;
        this.inline = inline || false;
        this.variable = (variable !== undefined) ? variable
            : (name.charAt && (name.charAt(0) === '@'));
        this.allowRoot = true;
        this.setParent(this.value, this);
    };
    Declaration.prototype = Object.assign(new node_1.default(), {
        type: 'Declaration',
        genCSS: function (context, output) {
            output.add(this.name + (context.compress ? ':' : ': '), this.fileInfo(), this.getIndex());
            try {
                this.value.genCSS(context, output);
            }
            catch (e) {
                e.index = this._index;
                e.filename = this._fileInfo.filename;
                throw e;
            }
            output.add(this.important + ((this.inline || (context.lastRule && context.compress)) ? '' : ';'), this._fileInfo, this._index);
        },
        eval: function (context) {
            var mathBypass = false, prevMath, name = this.name, evaldValue, variable = this.variable;
            if (typeof name !== 'string') {
                // expand 'primitive' name directly to get
                // things faster (~10% for benchmark.less):
                name = (name.length === 1) && (name[0] instanceof keyword_1.default) ?
                    name[0].value : evalName(context, name);
                variable = false; // never treat expanded interpolation as new variable name
            }
            // @todo remove when parens-division is default
            if (name === 'font' && context.math === MATH.ALWAYS) {
                mathBypass = true;
                prevMath = context.math;
                context.math = MATH.PARENS_DIVISION;
            }
            try {
                context.importantScope.push({});
                evaldValue = this.value.eval(context);
                if (!this.variable && evaldValue.type === 'DetachedRuleset') {
                    throw { message: 'Rulesets cannot be evaluated on a property.',
                        index: this.getIndex(), filename: this.fileInfo().filename };
                }
                var important = this.important;
                var importantResult = context.importantScope.pop();
                if (!important && importantResult.important) {
                    important = importantResult.important;
                }
                return new Declaration(name, evaldValue, important, this.merge, this.getIndex(), this.fileInfo(), this.inline, variable);
            }
            catch (e) {
                if (typeof e.index !== 'number') {
                    e.index = this.getIndex();
                    e.filename = this.fileInfo().filename;
                }
                throw e;
            }
            finally {
                if (mathBypass) {
                    context.math = prevMath;
                }
            }
        },
        makeImportant: function () {
            return new Declaration(this.name, this.value, '!important', this.merge, this.getIndex(), this.fileInfo(), this.inline);
        }
    });
    exports.default = Declaration;
    
},
/* less/lib/less/tree/value.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var Value = function (value) {
        if (!value) {
            throw new Error('Value requires an array argument');
        }
        if (!Array.isArray(value)) {
            this.value = [value];
        }
        else {
            this.value = value;
        }
    };
    Value.prototype = Object.assign(new node_1.default(), {
        type: 'Value',
        accept: function (visitor) {
            if (this.value) {
                this.value = visitor.visitArray(this.value);
            }
        },
        eval: function (context) {
            if (this.value.length === 1) {
                return this.value[0].eval(context);
            }
            else {
                return new Value(this.value.map(function (v) {
                    return v.eval(context);
                }));
            }
        },
        genCSS: function (context, output) {
            var i;
            for (i = 0; i < this.value.length; i++) {
                this.value[i].genCSS(context, output);
                if (i + 1 < this.value.length) {
                    output.add((context && context.compress) ? ',' : ', ');
                }
            }
        }
    });
    exports.default = Value;
    
},
/* less/lib/less/tree/keyword.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var Keyword = function (value) {
        this.value = value;
    };
    Keyword.prototype = Object.assign(new node_1.default(), {
        type: 'Keyword',
        genCSS: function (context, output) {
            if (this.value === '%') {
                throw { type: 'Syntax', message: 'Invalid % without number' };
            }
            output.add(this.value);
        }
    });
    Keyword.True = new Keyword('true');
    Keyword.False = new Keyword('false');
    exports.default = Keyword;
    
},
/* less/lib/less/tree/anonymous.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var Anonymous = function (value, index, currentFileInfo, mapLines, rulesetLike, visibilityInfo) {
        this.value = value;
        this._index = index;
        this._fileInfo = currentFileInfo;
        this.mapLines = mapLines;
        this.rulesetLike = (typeof rulesetLike === 'undefined') ? false : rulesetLike;
        this.allowRoot = true;
        this.copyVisibilityInfo(visibilityInfo);
    };
    Anonymous.prototype = Object.assign(new node_1.default(), {
        type: 'Anonymous',
        eval: function () {
            return new Anonymous(this.value, this._index, this._fileInfo, this.mapLines, this.rulesetLike, this.visibilityInfo());
        },
        compare: function (other) {
            return other.toCSS && this.toCSS() === other.toCSS() ? 0 : undefined;
        },
        isRulesetLike: function () {
            return this.rulesetLike;
        },
        genCSS: function (context, output) {
            this.nodeVisible = Boolean(this.value);
            if (this.nodeVisible) {
                output.add(this.value, this._fileInfo, this._index, this.mapLines);
            }
        }
    });
    exports.default = Anonymous;
    
},
/* less/lib/less/tree/comment.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var debug_info_1 = tslib_1.__importDefault(require(146) /* ./debug-info */);
    var Comment = function (value, isLineComment, index, currentFileInfo) {
        this.value = value;
        this.isLineComment = isLineComment;
        this._index = index;
        this._fileInfo = currentFileInfo;
        this.allowRoot = true;
    };
    Comment.prototype = Object.assign(new node_1.default(), {
        type: 'Comment',
        genCSS: function (context, output) {
            if (this.debugInfo) {
                output.add(debug_info_1.default(context, this), this.fileInfo(), this.getIndex());
            }
            output.add(this.value);
        },
        isSilent: function (context) {
            var isCompressed = context.compress && this.value[2] !== '!';
            return this.isLineComment || isCompressed;
        }
    });
    exports.default = Comment;
    
},
/* less/lib/less/tree/debug-info.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    function asComment(ctx) {
        return "/* line " + ctx.debugInfo.lineNumber + ", " + ctx.debugInfo.fileName + " */\n";
    }
    function asMediaQuery(ctx) {
        var filenameWithProtocol = ctx.debugInfo.fileName;
        if (!/^[a-z]+:\/\//i.test(filenameWithProtocol)) {
            filenameWithProtocol = "file://" + filenameWithProtocol;
        }
        return "@media -sass-debug-info{filename{font-family:" + filenameWithProtocol.replace(/([.:/\\])/g, function (a) {
            if (a == '\\') {
                a = '/';
            }
            return "\\" + a;
        }) + "}line{font-family:\\00003" + ctx.debugInfo.lineNumber + "}}\n";
    }
    function debugInfo(context, ctx, lineSeparator) {
        var result = '';
        if (context.dumpLineNumbers && !context.compress) {
            switch (context.dumpLineNumbers) {
                case 'comments':
                    result = asComment(ctx);
                    break;
                case 'mediaquery':
                    result = asMediaQuery(ctx);
                    break;
                case 'all':
                    result = asComment(ctx) + (lineSeparator || '') + asMediaQuery(ctx);
                    break;
            }
        }
        return result;
    }
    exports.default = debugInfo;
    
},
/* less/lib/less/functions/default.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var keyword_1 = tslib_1.__importDefault(require(143) /* ../tree/keyword */);
    var utils = tslib_1.__importStar(require(122) /* ../utils */);
    var defaultFunc = {
        eval: function () {
            var v = this.value_;
            var e = this.error_;
            if (e) {
                throw e;
            }
            if (!utils.isNullOrUndefined(v)) {
                return v ? keyword_1.default.True : keyword_1.default.False;
            }
        },
        value: function (v) {
            this.value_ = v;
        },
        error: function (e) {
            this.error_ = e;
        },
        reset: function () {
            this.value_ = this.error_ = null;
        }
    };
    exports.default = defaultFunc;
    
},
/* less/lib/less/tree/detached-ruleset.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var contexts_1 = tslib_1.__importDefault(require(130) /* ../contexts */);
    var utils = tslib_1.__importStar(require(122) /* ../utils */);
    var DetachedRuleset = function (ruleset, frames) {
        this.ruleset = ruleset;
        this.frames = frames;
        this.setParent(this.ruleset, this);
    };
    DetachedRuleset.prototype = Object.assign(new node_1.default(), {
        type: 'DetachedRuleset',
        evalFirst: true,
        accept: function (visitor) {
            this.ruleset = visitor.visit(this.ruleset);
        },
        eval: function (context) {
            var frames = this.frames || utils.copyArray(context.frames);
            return new DetachedRuleset(this.ruleset, frames);
        },
        callEval: function (context) {
            return this.ruleset.eval(this.frames ? new contexts_1.default.Eval(context, this.frames.concat(context.frames)) : context);
        }
    });
    exports.default = DetachedRuleset;
    
},
/* less/lib/less/tree/operation.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var color_1 = tslib_1.__importDefault(require(115) /* ./color */);
    var dimension_1 = tslib_1.__importDefault(require(150) /* ./dimension */);
    var Constants = tslib_1.__importStar(require(123) /* ../constants */);
    var MATH = Constants.Math;
    var Operation = function (op, operands, isSpaced) {
        this.op = op.trim();
        this.operands = operands;
        this.isSpaced = isSpaced;
    };
    Operation.prototype = Object.assign(new node_1.default(), {
        type: 'Operation',
        accept: function (visitor) {
            this.operands = visitor.visitArray(this.operands);
        },
        eval: function (context) {
            var a = this.operands[0].eval(context), b = this.operands[1].eval(context), op;
            if (context.isMathOn(this.op)) {
                op = this.op === './' ? '/' : this.op;
                if (a instanceof dimension_1.default && b instanceof color_1.default) {
                    a = a.toColor();
                }
                if (b instanceof dimension_1.default && a instanceof color_1.default) {
                    b = b.toColor();
                }
                if (!a.operate || !b.operate) {
                    if ((a instanceof Operation || b instanceof Operation)
                        && a.op === '/' && context.math === MATH.PARENS_DIVISION) {
                        return new Operation(this.op, [a, b], this.isSpaced);
                    }
                    throw { type: 'Operation',
                        message: 'Operation on an invalid type' };
                }
                return a.operate(context, op, b);
            }
            else {
                return new Operation(this.op, [a, b], this.isSpaced);
            }
        },
        genCSS: function (context, output) {
            this.operands[0].genCSS(context, output);
            if (this.isSpaced) {
                output.add(' ');
            }
            output.add(this.op);
            if (this.isSpaced) {
                output.add(' ');
            }
            this.operands[1].genCSS(context, output);
        }
    });
    exports.default = Operation;
    
},
/* less/lib/less/tree/dimension.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    /* eslint-disable no-prototype-builtins */
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var unit_conversions_1 = tslib_1.__importDefault(require(112) /* ../data/unit-conversions */);
    var unit_1 = tslib_1.__importDefault(require(151) /* ./unit */);
    var color_1 = tslib_1.__importDefault(require(115) /* ./color */);
    //
    // A number with a unit
    //
    var Dimension = function (value, unit) {
        this.value = parseFloat(value);
        if (isNaN(this.value)) {
            throw new Error('Dimension is not a number.');
        }
        this.unit = (unit && unit instanceof unit_1.default) ? unit :
            new unit_1.default(unit ? [unit] : undefined);
        this.setParent(this.unit, this);
    };
    Dimension.prototype = Object.assign(new node_1.default(), {
        type: 'Dimension',
        accept: function (visitor) {
            this.unit = visitor.visit(this.unit);
        },
        // remove when Nodes have JSDoc types
        // eslint-disable-next-line no-unused-vars
        eval: function (context) {
            return this;
        },
        toColor: function () {
            return new color_1.default([this.value, this.value, this.value]);
        },
        genCSS: function (context, output) {
            if ((context && context.strictUnits) && !this.unit.isSingular()) {
                throw new Error("Multiple units in dimension. Correct the units or use the unit function. Bad unit: " + this.unit.toString());
            }
            var value = this.fround(context, this.value);
            var strValue = String(value);
            if (value !== 0 && value < 0.000001 && value > -0.000001) {
                // would be output 1e-6 etc.
                strValue = value.toFixed(20).replace(/0+$/, '');
            }
            if (context && context.compress) {
                // Zero values doesn't need a unit
                if (value === 0 && this.unit.isLength()) {
                    output.add(strValue);
                    return;
                }
                // Float values doesn't need a leading zero
                if (value > 0 && value < 1) {
                    strValue = (strValue).substr(1);
                }
            }
            output.add(strValue);
            this.unit.genCSS(context, output);
        },
        // In an operation between two Dimensions,
        // we default to the first Dimension's unit,
        // so `1px + 2` will yield `3px`.
        operate: function (context, op, other) {
            /* jshint noempty:false */
            var value = this._operate(context, op, this.value, other.value);
            var unit = this.unit.clone();
            if (op === '+' || op === '-') {
                if (unit.numerator.length === 0 && unit.denominator.length === 0) {
                    unit = other.unit.clone();
                    if (this.unit.backupUnit) {
                        unit.backupUnit = this.unit.backupUnit;
                    }
                }
                else if (other.unit.numerator.length === 0 && unit.denominator.length === 0) {
                    // do nothing
                }
                else {
                    other = other.convertTo(this.unit.usedUnits());
                    if (context.strictUnits && other.unit.toString() !== unit.toString()) {
                        throw new Error('Incompatible units. Change the units or use the unit function. '
                            + ("Bad units: '" + unit.toString() + "' and '" + other.unit.toString() + "'."));
                    }
                    value = this._operate(context, op, this.value, other.value);
                }
            }
            else if (op === '*') {
                unit.numerator = unit.numerator.concat(other.unit.numerator).sort();
                unit.denominator = unit.denominator.concat(other.unit.denominator).sort();
                unit.cancel();
            }
            else if (op === '/') {
                unit.numerator = unit.numerator.concat(other.unit.denominator).sort();
                unit.denominator = unit.denominator.concat(other.unit.numerator).sort();
                unit.cancel();
            }
            return new Dimension(value, unit);
        },
        compare: function (other) {
            var a, b;
            if (!(other instanceof Dimension)) {
                return undefined;
            }
            if (this.unit.isEmpty() || other.unit.isEmpty()) {
                a = this;
                b = other;
            }
            else {
                a = this.unify();
                b = other.unify();
                if (a.unit.compare(b.unit) !== 0) {
                    return undefined;
                }
            }
            return node_1.default.numericCompare(a.value, b.value);
        },
        unify: function () {
            return this.convertTo({ length: 'px', duration: 's', angle: 'rad' });
        },
        convertTo: function (conversions) {
            var value = this.value;
            var unit = this.unit.clone();
            var i;
            var groupName;
            var group;
            var targetUnit;
            var derivedConversions = {};
            var applyUnit;
            if (typeof conversions === 'string') {
                for (i in unit_conversions_1.default) {
                    if (unit_conversions_1.default[i].hasOwnProperty(conversions)) {
                        derivedConversions = {};
                        derivedConversions[i] = conversions;
                    }
                }
                conversions = derivedConversions;
            }
            applyUnit = function (atomicUnit, denominator) {
                if (group.hasOwnProperty(atomicUnit)) {
                    if (denominator) {
                        value = value / (group[atomicUnit] / group[targetUnit]);
                    }
                    else {
                        value = value * (group[atomicUnit] / group[targetUnit]);
                    }
                    return targetUnit;
                }
                return atomicUnit;
            };
            for (groupName in conversions) {
                if (conversions.hasOwnProperty(groupName)) {
                    targetUnit = conversions[groupName];
                    group = unit_conversions_1.default[groupName];
                    unit.map(applyUnit);
                }
            }
            unit.cancel();
            return new Dimension(value, unit);
        }
    });
    exports.default = Dimension;
    
},
/* less/lib/less/tree/unit.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var unit_conversions_1 = tslib_1.__importDefault(require(112) /* ../data/unit-conversions */);
    var utils = tslib_1.__importStar(require(122) /* ../utils */);
    var Unit = function (numerator, denominator, backupUnit) {
        this.numerator = numerator ? utils.copyArray(numerator).sort() : [];
        this.denominator = denominator ? utils.copyArray(denominator).sort() : [];
        if (backupUnit) {
            this.backupUnit = backupUnit;
        }
        else if (numerator && numerator.length) {
            this.backupUnit = numerator[0];
        }
    };
    Unit.prototype = Object.assign(new node_1.default(), {
        type: 'Unit',
        clone: function () {
            return new Unit(utils.copyArray(this.numerator), utils.copyArray(this.denominator), this.backupUnit);
        },
        genCSS: function (context, output) {
            // Dimension checks the unit is singular and throws an error if in strict math mode.
            var strictUnits = context && context.strictUnits;
            if (this.numerator.length === 1) {
                output.add(this.numerator[0]); // the ideal situation
            }
            else if (!strictUnits && this.backupUnit) {
                output.add(this.backupUnit);
            }
            else if (!strictUnits && this.denominator.length) {
                output.add(this.denominator[0]);
            }
        },
        toString: function () {
            var i, returnStr = this.numerator.join('*');
            for (i = 0; i < this.denominator.length; i++) {
                returnStr += "/" + this.denominator[i];
            }
            return returnStr;
        },
        compare: function (other) {
            return this.is(other.toString()) ? 0 : undefined;
        },
        is: function (unitString) {
            return this.toString().toUpperCase() === unitString.toUpperCase();
        },
        isLength: function () {
            return RegExp('^(px|em|ex|ch|rem|in|cm|mm|pc|pt|ex|vw|vh|vmin|vmax)$', 'gi').test(this.toCSS());
        },
        isEmpty: function () {
            return this.numerator.length === 0 && this.denominator.length === 0;
        },
        isSingular: function () {
            return this.numerator.length <= 1 && this.denominator.length === 0;
        },
        map: function (callback) {
            var i;
            for (i = 0; i < this.numerator.length; i++) {
                this.numerator[i] = callback(this.numerator[i], false);
            }
            for (i = 0; i < this.denominator.length; i++) {
                this.denominator[i] = callback(this.denominator[i], true);
            }
        },
        usedUnits: function () {
            var group;
            var result = {};
            var mapUnit;
            var groupName;
            mapUnit = function (atomicUnit) {
                // eslint-disable-next-line no-prototype-builtins
                if (group.hasOwnProperty(atomicUnit) && !result[groupName]) {
                    result[groupName] = atomicUnit;
                }
                return atomicUnit;
            };
            for (groupName in unit_conversions_1.default) {
                // eslint-disable-next-line no-prototype-builtins
                if (unit_conversions_1.default.hasOwnProperty(groupName)) {
                    group = unit_conversions_1.default[groupName];
                    this.map(mapUnit);
                }
            }
            return result;
        },
        cancel: function () {
            var counter = {};
            var atomicUnit;
            var i;
            for (i = 0; i < this.numerator.length; i++) {
                atomicUnit = this.numerator[i];
                counter[atomicUnit] = (counter[atomicUnit] || 0) + 1;
            }
            for (i = 0; i < this.denominator.length; i++) {
                atomicUnit = this.denominator[i];
                counter[atomicUnit] = (counter[atomicUnit] || 0) - 1;
            }
            this.numerator = [];
            this.denominator = [];
            for (atomicUnit in counter) {
                // eslint-disable-next-line no-prototype-builtins
                if (counter.hasOwnProperty(atomicUnit)) {
                    var count = counter[atomicUnit];
                    if (count > 0) {
                        for (i = 0; i < count; i++) {
                            this.numerator.push(atomicUnit);
                        }
                    }
                    else if (count < 0) {
                        for (i = 0; i < -count; i++) {
                            this.denominator.push(atomicUnit);
                        }
                    }
                }
            }
            this.numerator.sort();
            this.denominator.sort();
        }
    });
    exports.default = Unit;
    
},
/* less/lib/less/tree/variable.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var call_1 = tslib_1.__importDefault(require(153) /* ./call */);
    var Variable = function (name, index, currentFileInfo) {
        this.name = name;
        this._index = index;
        this._fileInfo = currentFileInfo;
    };
    Variable.prototype = Object.assign(new node_1.default(), {
        type: 'Variable',
        eval: function (context) {
            var variable, name = this.name;
            if (name.indexOf('@@') === 0) {
                name = "@" + new Variable(name.slice(1), this.getIndex(), this.fileInfo()).eval(context).value;
            }
            if (this.evaluating) {
                throw { type: 'Name',
                    message: "Recursive variable definition for " + name,
                    filename: this.fileInfo().filename,
                    index: this.getIndex() };
            }
            this.evaluating = true;
            variable = this.find(context.frames, function (frame) {
                var v = frame.variable(name);
                if (v) {
                    if (v.important) {
                        var importantScope = context.importantScope[context.importantScope.length - 1];
                        importantScope.important = v.important;
                    }
                    // If in calc, wrap vars in a function call to cascade evaluate args first
                    if (context.inCalc) {
                        return (new call_1.default('_SELF', [v.value])).eval(context);
                    }
                    else {
                        return v.value.eval(context);
                    }
                }
            });
            if (variable) {
                this.evaluating = false;
                return variable;
            }
            else {
                throw { type: 'Name',
                    message: "variable " + name + " is undefined",
                    filename: this.fileInfo().filename,
                    index: this.getIndex() };
            }
        },
        find: function (obj, fun) {
            for (var i = 0, r = void 0; i < obj.length; i++) {
                r = fun.call(obj, obj[i]);
                if (r) {
                    return r;
                }
            }
            return null;
        }
    });
    exports.default = Variable;
    
},
/* less/lib/less/tree/call.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var anonymous_1 = tslib_1.__importDefault(require(144) /* ./anonymous */);
    var function_caller_1 = tslib_1.__importDefault(require(154) /* ../functions/function-caller */);
    //
    // A function call node.
    //
    var Call = function (name, args, index, currentFileInfo) {
        this.name = name;
        this.args = args;
        this.calc = name === 'calc';
        this._index = index;
        this._fileInfo = currentFileInfo;
    };
    Call.prototype = Object.assign(new node_1.default(), {
        type: 'Call',
        accept: function (visitor) {
            if (this.args) {
                this.args = visitor.visitArray(this.args);
            }
        },
        //
        // When evaluating a function call,
        // we either find the function in the functionRegistry,
        // in which case we call it, passing the  evaluated arguments,
        // if this returns null or we cannot find the function, we
        // simply print it out as it appeared originally [2].
        //
        // The reason why we evaluate the arguments, is in the case where
        // we try to pass a variable to a function, like: `saturate(@color)`.
        // The function should receive the value, not the variable.
        //
        eval: function (context) {
            var _this = this;
            /**
             * Turn off math for calc(), and switch back on for evaluating nested functions
             */
            var currentMathContext = context.mathOn;
            context.mathOn = !this.calc;
            if (this.calc || context.inCalc) {
                context.enterCalc();
            }
            var exitCalc = function () {
                if (_this.calc || context.inCalc) {
                    context.exitCalc();
                }
                context.mathOn = currentMathContext;
            };
            var result;
            var funcCaller = new function_caller_1.default(this.name, context, this.getIndex(), this.fileInfo());
            if (funcCaller.isValid()) {
                try {
                    result = funcCaller.call(this.args);
                    exitCalc();
                }
                catch (e) {
                    // eslint-disable-next-line no-prototype-builtins
                    if (e.hasOwnProperty('line') && e.hasOwnProperty('column')) {
                        throw e;
                    }
                    throw {
                        type: e.type || 'Runtime',
                        message: "Error evaluating function `" + this.name + "`" + (e.message ? ": " + e.message : ''),
                        index: this.getIndex(),
                        filename: this.fileInfo().filename,
                        line: e.lineNumber,
                        column: e.columnNumber
                    };
                }
            }
            if (result !== null && result !== undefined) {
                // Results that that are not nodes are cast as Anonymous nodes
                // Falsy values or booleans are returned as empty nodes
                if (!(result instanceof node_1.default)) {
                    if (!result || result === true) {
                        result = new anonymous_1.default(null);
                    }
                    else {
                        result = new anonymous_1.default(result.toString());
                    }
                }
                result._index = this._index;
                result._fileInfo = this._fileInfo;
                return result;
            }
            var args = this.args.map(function (a) { return a.eval(context); });
            exitCalc();
            return new Call(this.name, args, this.getIndex(), this.fileInfo());
        },
        genCSS: function (context, output) {
            output.add(this.name + "(", this.fileInfo(), this.getIndex());
            for (var i = 0; i < this.args.length; i++) {
                this.args[i].genCSS(context, output);
                if (i + 1 < this.args.length) {
                    output.add(', ');
                }
            }
            output.add(')');
        }
    });
    exports.default = Call;
    
},
/* less/lib/less/functions/function-caller.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var expression_1 = tslib_1.__importDefault(require(155) /* ../tree/expression */);
    var functionCaller = /** @class */ (function () {
        function functionCaller(name, context, index, currentFileInfo) {
            this.name = name.toLowerCase();
            this.index = index;
            this.context = context;
            this.currentFileInfo = currentFileInfo;
            this.func = context.frames[0].functionRegistry.get(this.name);
        }
        functionCaller.prototype.isValid = function () {
            return Boolean(this.func);
        };
        functionCaller.prototype.call = function (args) {
            var _this = this;
            if (!(Array.isArray(args))) {
                args = [args];
            }
            var evalArgs = this.func.evalArgs;
            if (evalArgs !== false) {
                args = args.map(function (a) { return a.eval(_this.context); });
            }
            var commentFilter = function (item) { return !(item.type === 'Comment'); };
            // This code is terrible and should be replaced as per this issue...
            // https://github.com/less/less.js/issues/2477
            args = args
                .filter(commentFilter)
                .map(function (item) {
                if (item.type === 'Expression') {
                    var subNodes = item.value.filter(commentFilter);
                    if (subNodes.length === 1) {
                        // https://github.com/less/less.js/issues/3616
                        if (item.parens && subNodes[0].op === '/') {
                            return item;
                        }
                        return subNodes[0];
                    }
                    else {
                        return new expression_1.default(subNodes);
                    }
                }
                return item;
            });
            if (evalArgs === false) {
                return this.func.apply(this, tslib_1.__spreadArray([this.context], args));
            }
            return this.func.apply(this, args);
        };
        return functionCaller;
    }());
    exports.default = functionCaller;
    
},
/* less/lib/less/tree/expression.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var paren_1 = tslib_1.__importDefault(require(119) /* ./paren */);
    var comment_1 = tslib_1.__importDefault(require(145) /* ./comment */);
    var dimension_1 = tslib_1.__importDefault(require(150) /* ./dimension */);
    var Expression = function (value, noSpacing) {
        this.value = value;
        this.noSpacing = noSpacing;
        if (!value) {
            throw new Error('Expression requires an array parameter');
        }
    };
    Expression.prototype = Object.assign(new node_1.default(), {
        type: 'Expression',
        accept: function (visitor) {
            this.value = visitor.visitArray(this.value);
        },
        eval: function (context) {
            var returnValue;
            var mathOn = context.isMathOn();
            var inParenthesis = this.parens;
            var doubleParen = false;
            if (inParenthesis) {
                context.inParenthesis();
            }
            if (this.value.length > 1) {
                returnValue = new Expression(this.value.map(function (e) {
                    if (!e.eval) {
                        return e;
                    }
                    return e.eval(context);
                }), this.noSpacing);
            }
            else if (this.value.length === 1) {
                if (this.value[0].parens && !this.value[0].parensInOp && !context.inCalc) {
                    doubleParen = true;
                }
                returnValue = this.value[0].eval(context);
            }
            else {
                returnValue = this;
            }
            if (inParenthesis) {
                context.outOfParenthesis();
            }
            if (this.parens && this.parensInOp && !mathOn && !doubleParen
                && (!(returnValue instanceof dimension_1.default))) {
                returnValue = new paren_1.default(returnValue);
            }
            return returnValue;
        },
        genCSS: function (context, output) {
            for (var i = 0; i < this.value.length; i++) {
                this.value[i].genCSS(context, output);
                if (!this.noSpacing && i + 1 < this.value.length) {
                    output.add(' ');
                }
            }
        },
        throwAwayComments: function () {
            this.value = this.value.filter(function (v) {
                return !(v instanceof comment_1.default);
            });
        }
    });
    exports.default = Expression;
    
},
/* less/lib/less/tree/property.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var declaration_1 = tslib_1.__importDefault(require(141) /* ./declaration */);
    var Property = function (name, index, currentFileInfo) {
        this.name = name;
        this._index = index;
        this._fileInfo = currentFileInfo;
    };
    Property.prototype = Object.assign(new node_1.default(), {
        type: 'Property',
        eval: function (context) {
            var property;
            var name = this.name;
            // TODO: shorten this reference
            var mergeRules = context.pluginManager.less.visitors.ToCSSVisitor.prototype._mergeRules;
            if (this.evaluating) {
                throw { type: 'Name',
                    message: "Recursive property reference for " + name,
                    filename: this.fileInfo().filename,
                    index: this.getIndex() };
            }
            this.evaluating = true;
            property = this.find(context.frames, function (frame) {
                var v;
                var vArr = frame.property(name);
                if (vArr) {
                    for (var i = 0; i < vArr.length; i++) {
                        v = vArr[i];
                        vArr[i] = new declaration_1.default(v.name, v.value, v.important, v.merge, v.index, v.currentFileInfo, v.inline, v.variable);
                    }
                    mergeRules(vArr);
                    v = vArr[vArr.length - 1];
                    if (v.important) {
                        var importantScope = context.importantScope[context.importantScope.length - 1];
                        importantScope.important = v.important;
                    }
                    v = v.value.eval(context);
                    return v;
                }
            });
            if (property) {
                this.evaluating = false;
                return property;
            }
            else {
                throw { type: 'Name',
                    message: "Property '" + name + "' is undefined",
                    filename: this.currentFileInfo.filename,
                    index: this.index };
            }
        },
        find: function (obj, fun) {
            for (var i = 0, r = void 0; i < obj.length; i++) {
                r = fun.call(obj, obj[i]);
                if (r) {
                    return r;
                }
            }
            return null;
        }
    });
    exports.default = Property;
    
},
/* less/lib/less/tree/attribute.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var Attribute = function (key, op, value, cif) {
        this.key = key;
        this.op = op;
        this.value = value;
        this.cif = cif;
    };
    Attribute.prototype = Object.assign(new node_1.default(), {
        type: 'Attribute',
        eval: function (context) {
            return new Attribute(this.key.eval ? this.key.eval(context) : this.key, this.op, (this.value && this.value.eval) ? this.value.eval(context) : this.value, this.cif);
        },
        genCSS: function (context, output) {
            output.add(this.toCSS(context));
        },
        toCSS: function (context) {
            var value = this.key.toCSS ? this.key.toCSS(context) : this.key;
            if (this.op) {
                value += this.op;
                value += (this.value.toCSS ? this.value.toCSS(context) : this.value);
            }
            if (this.cif) {
                value = value + ' ' + this.cif;
            }
            return "[" + value + "]";
        }
    });
    exports.default = Attribute;
    
},
/* less/lib/less/tree/quoted.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var variable_1 = tslib_1.__importDefault(require(152) /* ./variable */);
    var property_1 = tslib_1.__importDefault(require(156) /* ./property */);
    var Quoted = function (str, content, escaped, index, currentFileInfo) {
        this.escaped = (escaped === undefined) ? true : escaped;
        this.value = content || '';
        this.quote = str.charAt(0);
        this._index = index;
        this._fileInfo = currentFileInfo;
        this.variableRegex = /@\{([\w-]+)\}/g;
        this.propRegex = /\$\{([\w-]+)\}/g;
        this.allowRoot = escaped;
    };
    Quoted.prototype = Object.assign(new node_1.default(), {
        type: 'Quoted',
        genCSS: function (context, output) {
            if (!this.escaped) {
                output.add(this.quote, this.fileInfo(), this.getIndex());
            }
            output.add(this.value);
            if (!this.escaped) {
                output.add(this.quote);
            }
        },
        containsVariables: function () {
            return this.value.match(this.variableRegex);
        },
        eval: function (context) {
            var that = this;
            var value = this.value;
            var variableReplacement = function (_, name) {
                var v = new variable_1.default("@" + name, that.getIndex(), that.fileInfo()).eval(context, true);
                return (v instanceof Quoted) ? v.value : v.toCSS();
            };
            var propertyReplacement = function (_, name) {
                var v = new property_1.default("$" + name, that.getIndex(), that.fileInfo()).eval(context, true);
                return (v instanceof Quoted) ? v.value : v.toCSS();
            };
            function iterativeReplace(value, regexp, replacementFnc) {
                var evaluatedValue = value;
                do {
                    value = evaluatedValue.toString();
                    evaluatedValue = value.replace(regexp, replacementFnc);
                } while (value !== evaluatedValue);
                return evaluatedValue;
            }
            value = iterativeReplace(value, this.variableRegex, variableReplacement);
            value = iterativeReplace(value, this.propRegex, propertyReplacement);
            return new Quoted(this.quote + value + this.quote, value, this.escaped, this.getIndex(), this.fileInfo());
        },
        compare: function (other) {
            // when comparing quoted strings allow the quote to differ
            if (other.type === 'Quoted' && !this.escaped && !other.escaped) {
                return node_1.default.numericCompare(this.value, other.value);
            }
            else {
                return other.toCSS && this.toCSS() === other.toCSS() ? 0 : undefined;
            }
        }
    });
    exports.default = Quoted;
    
},
/* less/lib/less/tree/url.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    function escapePath(path) {
        return path.replace(/[()'"\s]/g, function (match) { return "\\" + match; });
    }
    var URL = function (val, index, currentFileInfo, isEvald) {
        this.value = val;
        this._index = index;
        this._fileInfo = currentFileInfo;
        this.isEvald = isEvald;
    };
    URL.prototype = Object.assign(new node_1.default(), {
        type: 'Url',
        accept: function (visitor) {
            this.value = visitor.visit(this.value);
        },
        genCSS: function (context, output) {
            output.add('url(');
            this.value.genCSS(context, output);
            output.add(')');
        },
        eval: function (context) {
            var val = this.value.eval(context);
            var rootpath;
            if (!this.isEvald) {
                // Add the rootpath if the URL requires a rewrite
                rootpath = this.fileInfo() && this.fileInfo().rootpath;
                if (typeof rootpath === 'string' &&
                    typeof val.value === 'string' &&
                    context.pathRequiresRewrite(val.value)) {
                    if (!val.quote) {
                        rootpath = escapePath(rootpath);
                    }
                    val.value = context.rewritePath(val.value, rootpath);
                }
                else {
                    val.value = context.normalizePath(val.value);
                }
                // Add url args if enabled
                if (context.urlArgs) {
                    if (!val.value.match(/^\s*data:/)) {
                        var delimiter = val.value.indexOf('?') === -1 ? '?' : '&';
                        var urlArgs = delimiter + context.urlArgs;
                        if (val.value.indexOf('#') !== -1) {
                            val.value = val.value.replace('#', urlArgs + "#");
                        }
                        else {
                            val.value += urlArgs;
                        }
                    }
                }
            }
            return new URL(val, this.getIndex(), this.fileInfo(), true);
        }
    });
    exports.default = URL;
    
},
/* less/lib/less/tree/import.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var media_1 = tslib_1.__importDefault(require(161) /* ./media */);
    var url_1 = tslib_1.__importDefault(require(159) /* ./url */);
    var quoted_1 = tslib_1.__importDefault(require(158) /* ./quoted */);
    var ruleset_1 = tslib_1.__importDefault(require(140) /* ./ruleset */);
    var anonymous_1 = tslib_1.__importDefault(require(144) /* ./anonymous */);
    var utils = tslib_1.__importStar(require(122) /* ../utils */);
    var less_error_1 = tslib_1.__importDefault(require(121) /* ../less-error */);
    //
    // CSS @import node
    //
    // The general strategy here is that we don't want to wait
    // for the parsing to be completed, before we start importing
    // the file. That's because in the context of a browser,
    // most of the time will be spent waiting for the server to respond.
    //
    // On creation, we push the import path to our import queue, though
    // `import,push`, we also pass it a callback, which it'll call once
    // the file has been fetched, and parsed.
    //
    var Import = function (path, features, options, index, currentFileInfo, visibilityInfo) {
        this.options = options;
        this._index = index;
        this._fileInfo = currentFileInfo;
        this.path = path;
        this.features = features;
        this.allowRoot = true;
        if (this.options.less !== undefined || this.options.inline) {
            this.css = !this.options.less || this.options.inline;
        }
        else {
            var pathValue = this.getPath();
            if (pathValue && /[#.&?]css([?;].*)?$/.test(pathValue)) {
                this.css = true;
            }
        }
        this.copyVisibilityInfo(visibilityInfo);
        this.setParent(this.features, this);
        this.setParent(this.path, this);
    };
    Import.prototype = Object.assign(new node_1.default(), {
        type: 'Import',
        accept: function (visitor) {
            if (this.features) {
                this.features = visitor.visit(this.features);
            }
            this.path = visitor.visit(this.path);
            if (!this.options.isPlugin && !this.options.inline && this.root) {
                this.root = visitor.visit(this.root);
            }
        },
        genCSS: function (context, output) {
            if (this.css && this.path._fileInfo.reference === undefined) {
                output.add('@import ', this._fileInfo, this._index);
                this.path.genCSS(context, output);
                if (this.features) {
                    output.add(' ');
                    this.features.genCSS(context, output);
                }
                output.add(';');
            }
        },
        getPath: function () {
            return (this.path instanceof url_1.default) ?
                this.path.value.value : this.path.value;
        },
        isVariableImport: function () {
            var path = this.path;
            if (path instanceof url_1.default) {
                path = path.value;
            }
            if (path instanceof quoted_1.default) {
                return path.containsVariables();
            }
            return true;
        },
        evalForImport: function (context) {
            var path = this.path;
            if (path instanceof url_1.default) {
                path = path.value;
            }
            return new Import(path.eval(context), this.features, this.options, this._index, this._fileInfo, this.visibilityInfo());
        },
        evalPath: function (context) {
            var path = this.path.eval(context);
            var fileInfo = this._fileInfo;
            if (!(path instanceof url_1.default)) {
                // Add the rootpath if the URL requires a rewrite
                var pathValue = path.value;
                if (fileInfo &&
                    pathValue &&
                    context.pathRequiresRewrite(pathValue)) {
                    path.value = context.rewritePath(pathValue, fileInfo.rootpath);
                }
                else {
                    path.value = context.normalizePath(path.value);
                }
            }
            return path;
        },
        eval: function (context) {
            var result = this.doEval(context);
            if (this.options.reference || this.blocksVisibility()) {
                if (result.length || result.length === 0) {
                    result.forEach(function (node) {
                        node.addVisibilityBlock();
                    });
                }
                else {
                    result.addVisibilityBlock();
                }
            }
            return result;
        },
        doEval: function (context) {
            var ruleset;
            var registry;
            var features = this.features && this.features.eval(context);
            if (this.options.isPlugin) {
                if (this.root && this.root.eval) {
                    try {
                        this.root.eval(context);
                    }
                    catch (e) {
                        e.message = 'Plugin error during evaluation';
                        throw new less_error_1.default(e, this.root.imports, this.root.filename);
                    }
                }
                registry = context.frames[0] && context.frames[0].functionRegistry;
                if (registry && this.root && this.root.functions) {
                    registry.addMultiple(this.root.functions);
                }
                return [];
            }
            if (this.skip) {
                if (typeof this.skip === 'function') {
                    this.skip = this.skip();
                }
                if (this.skip) {
                    return [];
                }
            }
            if (this.options.inline) {
                var contents = new anonymous_1.default(this.root, 0, {
                    filename: this.importedFilename,
                    reference: this.path._fileInfo && this.path._fileInfo.reference
                }, true, true);
                return this.features ? new media_1.default([contents], this.features.value) : [contents];
            }
            else if (this.css) {
                var newImport = new Import(this.evalPath(context), features, this.options, this._index);
                if (!newImport.css && this.error) {
                    throw this.error;
                }
                return newImport;
            }
            else if (this.root) {
                ruleset = new ruleset_1.default(null, utils.copyArray(this.root.rules));
                ruleset.evalImports(context);
                return this.features ? new media_1.default(ruleset.rules, this.features.value) : ruleset.rules;
            }
            else {
                return [];
            }
        }
    });
    exports.default = Import;
    
},
/* less/lib/less/tree/media.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var ruleset_1 = tslib_1.__importDefault(require(140) /* ./ruleset */);
    var value_1 = tslib_1.__importDefault(require(142) /* ./value */);
    var selector_1 = tslib_1.__importDefault(require(117) /* ./selector */);
    var atrule_1 = tslib_1.__importDefault(require(116) /* ./atrule */);
    var nested_at_rule_1 = tslib_1.__importDefault(require(162) /* ./nested-at-rule */);
    var Media = function (value, features, index, currentFileInfo, visibilityInfo) {
        this._index = index;
        this._fileInfo = currentFileInfo;
        var selectors = (new selector_1.default([], null, null, this._index, this._fileInfo)).createEmptySelectors();
        this.features = new value_1.default(features);
        this.rules = [new ruleset_1.default(selectors, value)];
        this.rules[0].allowImports = true;
        this.copyVisibilityInfo(visibilityInfo);
        this.allowRoot = true;
        this.setParent(selectors, this);
        this.setParent(this.features, this);
        this.setParent(this.rules, this);
    };
    Media.prototype = Object.assign(new atrule_1.default(), tslib_1.__assign(tslib_1.__assign({ type: 'Media' }, nested_at_rule_1.default), { genCSS: function (context, output) {
            output.add('@media ', this._fileInfo, this._index);
            this.features.genCSS(context, output);
            this.outputRuleset(context, output, this.rules);
        }, eval: function (context) {
            if (!context.mediaBlocks) {
                context.mediaBlocks = [];
                context.mediaPath = [];
            }
            var media = new Media(null, [], this._index, this._fileInfo, this.visibilityInfo());
            if (this.debugInfo) {
                this.rules[0].debugInfo = this.debugInfo;
                media.debugInfo = this.debugInfo;
            }
            media.features = this.features.eval(context);
            context.mediaPath.push(media);
            context.mediaBlocks.push(media);
            this.rules[0].functionRegistry = context.frames[0].functionRegistry.inherit();
            context.frames.unshift(this.rules[0]);
            media.rules = [this.rules[0].eval(context)];
            context.frames.shift();
            context.mediaPath.pop();
            return context.mediaPath.length === 0 ? media.evalTop(context) :
                media.evalNested(context);
        } }));
    exports.default = Media;
    
},
/* less/lib/less/tree/nested-at-rule.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var ruleset_1 = tslib_1.__importDefault(require(140) /* ./ruleset */);
    var value_1 = tslib_1.__importDefault(require(142) /* ./value */);
    var selector_1 = tslib_1.__importDefault(require(117) /* ./selector */);
    var anonymous_1 = tslib_1.__importDefault(require(144) /* ./anonymous */);
    var expression_1 = tslib_1.__importDefault(require(155) /* ./expression */);
    var utils = tslib_1.__importStar(require(122) /* ../utils */);
    var NestableAtRulePrototype = {
        isRulesetLike: function () {
            return true;
        },
        accept: function (visitor) {
            if (this.features) {
                this.features = visitor.visit(this.features);
            }
            if (this.rules) {
                this.rules = visitor.visitArray(this.rules);
            }
        },
        evalTop: function (context) {
            var result = this;
            // Render all dependent Media blocks.
            if (context.mediaBlocks.length > 1) {
                var selectors = (new selector_1.default([], null, null, this.getIndex(), this.fileInfo())).createEmptySelectors();
                result = new ruleset_1.default(selectors, context.mediaBlocks);
                result.multiMedia = true;
                result.copyVisibilityInfo(this.visibilityInfo());
                this.setParent(result, this);
            }
            delete context.mediaBlocks;
            delete context.mediaPath;
            return result;
        },
        evalNested: function (context) {
            var i;
            var value;
            var path = context.mediaPath.concat([this]);
            // Extract the media-query conditions separated with `,` (OR).
            for (i = 0; i < path.length; i++) {
                value = path[i].features instanceof value_1.default ?
                    path[i].features.value : path[i].features;
                path[i] = Array.isArray(value) ? value : [value];
            }
            // Trace all permutations to generate the resulting media-query.
            //
            // (a, b and c) with nested (d, e) ->
            //    a and d
            //    a and e
            //    b and c and d
            //    b and c and e
            this.features = new value_1.default(this.permute(path).map(function (path) {
                path = path.map(function (fragment) { return fragment.toCSS ? fragment : new anonymous_1.default(fragment); });
                for (i = path.length - 1; i > 0; i--) {
                    path.splice(i, 0, new anonymous_1.default('and'));
                }
                return new expression_1.default(path);
            }));
            this.setParent(this.features, this);
            // Fake a tree-node that doesn't output anything.
            return new ruleset_1.default([], []);
        },
        permute: function (arr) {
            if (arr.length === 0) {
                return [];
            }
            else if (arr.length === 1) {
                return arr[0];
            }
            else {
                var result = [];
                var rest = this.permute(arr.slice(1));
                for (var i = 0; i < rest.length; i++) {
                    for (var j = 0; j < arr[0].length; j++) {
                        result.push([arr[0][j]].concat(rest[i]));
                    }
                }
                return result;
            }
        },
        bubbleSelectors: function (selectors) {
            if (!selectors) {
                return;
            }
            this.rules = [new ruleset_1.default(utils.copyArray(selectors), [this.rules[0]])];
            this.setParent(this.rules, this);
        }
    };
    exports.default = NestableAtRulePrototype;
    
},
/* less/lib/less/tree/javascript.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var js_eval_node_1 = tslib_1.__importDefault(require(164) /* ./js-eval-node */);
    var dimension_1 = tslib_1.__importDefault(require(150) /* ./dimension */);
    var quoted_1 = tslib_1.__importDefault(require(158) /* ./quoted */);
    var anonymous_1 = tslib_1.__importDefault(require(144) /* ./anonymous */);
    var JavaScript = function (string, escaped, index, currentFileInfo) {
        this.escaped = escaped;
        this.expression = string;
        this._index = index;
        this._fileInfo = currentFileInfo;
    };
    JavaScript.prototype = Object.assign(new js_eval_node_1.default(), {
        type: 'JavaScript',
        eval: function (context) {
            var result = this.evaluateJavaScript(this.expression, context);
            var type = typeof result;
            if (type === 'number' && !isNaN(result)) {
                return new dimension_1.default(result);
            }
            else if (type === 'string') {
                return new quoted_1.default("\"" + result + "\"", result, this.escaped, this._index);
            }
            else if (Array.isArray(result)) {
                return new anonymous_1.default(result.join(', '));
            }
            else {
                return new anonymous_1.default(result);
            }
        }
    });
    exports.default = JavaScript;
    
},
/* less/lib/less/tree/js-eval-node.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var variable_1 = tslib_1.__importDefault(require(152) /* ./variable */);
    var JsEvalNode = function () { };
    JsEvalNode.prototype = Object.assign(new node_1.default(), {
        evaluateJavaScript: function (expression, context) {
            var result;
            var that = this;
            var evalContext = {};
            if (!context.javascriptEnabled) {
                throw { message: 'Inline JavaScript is not enabled. Is it set in your options?',
                    filename: this.fileInfo().filename,
                    index: this.getIndex() };
            }
            expression = expression.replace(/@\{([\w-]+)\}/g, function (_, name) {
                return that.jsify(new variable_1.default("@" + name, that.getIndex(), that.fileInfo()).eval(context));
            });
            try {
                expression = new Function("return (" + expression + ")");
            }
            catch (e) {
                throw { message: "JavaScript evaluation error: " + e.message + " from `" + expression + "`",
                    filename: this.fileInfo().filename,
                    index: this.getIndex() };
            }
            var variables = context.frames[0].variables();
            for (var k in variables) {
                // eslint-disable-next-line no-prototype-builtins
                if (variables.hasOwnProperty(k)) {
                    evalContext[k.slice(1)] = {
                        value: variables[k].value,
                        toJS: function () {
                            return this.value.eval(context).toCSS();
                        }
                    };
                }
            }
            try {
                result = expression.call(evalContext);
            }
            catch (e) {
                throw { message: "JavaScript evaluation error: '" + e.name + ": " + e.message.replace(/["]/g, '\'') + "'",
                    filename: this.fileInfo().filename,
                    index: this.getIndex() };
            }
            return result;
        },
        jsify: function (obj) {
            if (Array.isArray(obj.value) && (obj.value.length > 1)) {
                return "[" + obj.value.map(function (v) { return v.toCSS(); }).join(', ') + "]";
            }
            else {
                return obj.toCSS();
            }
        }
    });
    exports.default = JsEvalNode;
    
},
/* less/lib/less/tree/assignment.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var Assignment = function (key, val) {
        this.key = key;
        this.value = val;
    };
    Assignment.prototype = Object.assign(new node_1.default(), {
        type: 'Assignment',
        accept: function (visitor) {
            this.value = visitor.visit(this.value);
        },
        eval: function (context) {
            if (this.value.eval) {
                return new Assignment(this.key, this.value.eval(context));
            }
            return this;
        },
        genCSS: function (context, output) {
            output.add(this.key + "=");
            if (this.value.genCSS) {
                this.value.genCSS(context, output);
            }
            else {
                output.add(this.value);
            }
        }
    });
    exports.default = Assignment;
    
},
/* less/lib/less/tree/condition.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var Condition = function (op, l, r, i, negate) {
        this.op = op.trim();
        this.lvalue = l;
        this.rvalue = r;
        this._index = i;
        this.negate = negate;
    };
    Condition.prototype = Object.assign(new node_1.default(), {
        type: 'Condition',
        accept: function (visitor) {
            this.lvalue = visitor.visit(this.lvalue);
            this.rvalue = visitor.visit(this.rvalue);
        },
        eval: function (context) {
            var result = (function (op, a, b) {
                switch (op) {
                    case 'and': return a && b;
                    case 'or': return a || b;
                    default:
                        switch (node_1.default.compare(a, b)) {
                            case -1:
                                return op === '<' || op === '=<' || op === '<=';
                            case 0:
                                return op === '=' || op === '>=' || op === '=<' || op === '<=';
                            case 1:
                                return op === '>' || op === '>=';
                            default:
                                return false;
                        }
                }
            })(this.op, this.lvalue.eval(context), this.rvalue.eval(context));
            return this.negate ? !result : result;
        }
    });
    exports.default = Condition;
    
},
/* less/lib/less/tree/query-in-parens.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var QueryInParens = function (op, l, m, op2, r, i) {
        this.op = op.trim();
        this.lvalue = l;
        this.mvalue = m;
        this.op2 = op2 ? op2.trim() : null;
        this.rvalue = r;
        this._index = i;
    };
    QueryInParens.prototype = Object.assign(new node_1.default(), {
        type: 'QueryInParens',
        accept: function (visitor) {
            this.lvalue = visitor.visit(this.lvalue);
            this.mvalue = visitor.visit(this.mvalue);
            if (this.rvalue) {
                this.rvalue = visitor.visit(this.rvalue);
            }
        },
        eval: function (context) {
            this.lvalue = this.lvalue.eval(context);
            this.mvalue = this.mvalue.eval(context);
            if (this.rvalue) {
                this.rvalue = this.rvalue.eval(context);
            }
            return this;
        },
        genCSS: function (context, output) {
            this.lvalue.genCSS(context, output);
            output.add(' ' + this.op + ' ');
            this.mvalue.genCSS(context, output);
            if (this.rvalue) {
                output.add(' ' + this.op2 + ' ');
                this.rvalue.genCSS(context, output);
            }
        },
    });
    exports.default = QueryInParens;
    
},
/* less/lib/less/tree/container.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var ruleset_1 = tslib_1.__importDefault(require(140) /* ./ruleset */);
    var value_1 = tslib_1.__importDefault(require(142) /* ./value */);
    var selector_1 = tslib_1.__importDefault(require(117) /* ./selector */);
    var atrule_1 = tslib_1.__importDefault(require(116) /* ./atrule */);
    var nested_at_rule_1 = tslib_1.__importDefault(require(162) /* ./nested-at-rule */);
    var Container = function (value, features, index, currentFileInfo, visibilityInfo) {
        this._index = index;
        this._fileInfo = currentFileInfo;
        var selectors = (new selector_1.default([], null, null, this._index, this._fileInfo)).createEmptySelectors();
        this.features = new value_1.default(features);
        this.rules = [new ruleset_1.default(selectors, value)];
        this.rules[0].allowImports = true;
        this.copyVisibilityInfo(visibilityInfo);
        this.allowRoot = true;
        this.setParent(selectors, this);
        this.setParent(this.features, this);
        this.setParent(this.rules, this);
    };
    Container.prototype = Object.assign(new atrule_1.default(), tslib_1.__assign(tslib_1.__assign({ type: 'Container' }, nested_at_rule_1.default), { genCSS: function (context, output) {
            output.add('@container ', this._fileInfo, this._index);
            this.features.genCSS(context, output);
            this.outputRuleset(context, output, this.rules);
        }, eval: function (context) {
            if (!context.mediaBlocks) {
                context.mediaBlocks = [];
                context.mediaPath = [];
            }
            var media = new Container(null, [], this._index, this._fileInfo, this.visibilityInfo());
            if (this.debugInfo) {
                this.rules[0].debugInfo = this.debugInfo;
                media.debugInfo = this.debugInfo;
            }
            media.features = this.features.eval(context);
            context.mediaPath.push(media);
            context.mediaBlocks.push(media);
            this.rules[0].functionRegistry = context.frames[0].functionRegistry.inherit();
            context.frames.unshift(this.rules[0]);
            media.rules = [this.rules[0].eval(context)];
            context.frames.shift();
            context.mediaPath.pop();
            return context.mediaPath.length === 0 ? media.evalTop(context) :
                media.evalNested(context);
        } }));
    exports.default = Container;
    
},
/* less/lib/less/tree/unicode-descriptor.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var UnicodeDescriptor = function (value) {
        this.value = value;
    };
    UnicodeDescriptor.prototype = Object.assign(new node_1.default(), {
        type: 'UnicodeDescriptor'
    });
    exports.default = UnicodeDescriptor;
    
},
/* less/lib/less/tree/negative.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var operation_1 = tslib_1.__importDefault(require(149) /* ./operation */);
    var dimension_1 = tslib_1.__importDefault(require(150) /* ./dimension */);
    var Negative = function (node) {
        this.value = node;
    };
    Negative.prototype = Object.assign(new node_1.default(), {
        type: 'Negative',
        genCSS: function (context, output) {
            output.add('-');
            this.value.genCSS(context, output);
        },
        eval: function (context) {
            if (context.isMathOn()) {
                return (new operation_1.default('*', [new dimension_1.default(-1), this.value])).eval(context);
            }
            return new Negative(this.value.eval(context));
        }
    });
    exports.default = Negative;
    
},
/* less/lib/less/tree/extend.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var selector_1 = tslib_1.__importDefault(require(117) /* ./selector */);
    var Extend = function (selector, option, index, currentFileInfo, visibilityInfo) {
        this.selector = selector;
        this.option = option;
        this.object_id = Extend.next_id++;
        this.parent_ids = [this.object_id];
        this._index = index;
        this._fileInfo = currentFileInfo;
        this.copyVisibilityInfo(visibilityInfo);
        this.allowRoot = true;
        switch (option) {
            case 'all':
                this.allowBefore = true;
                this.allowAfter = true;
                break;
            default:
                this.allowBefore = false;
                this.allowAfter = false;
                break;
        }
        this.setParent(this.selector, this);
    };
    Extend.prototype = Object.assign(new node_1.default(), {
        type: 'Extend',
        accept: function (visitor) {
            this.selector = visitor.visit(this.selector);
        },
        eval: function (context) {
            return new Extend(this.selector.eval(context), this.option, this.getIndex(), this.fileInfo(), this.visibilityInfo());
        },
        // remove when Nodes have JSDoc types
        // eslint-disable-next-line no-unused-vars
        clone: function (context) {
            return new Extend(this.selector, this.option, this.getIndex(), this.fileInfo(), this.visibilityInfo());
        },
        // it concatenates (joins) all selectors in selector array
        findSelfSelectors: function (selectors) {
            var selfElements = [], i, selectorElements;
            for (i = 0; i < selectors.length; i++) {
                selectorElements = selectors[i].elements;
                // duplicate the logic in genCSS function inside the selector node.
                // future TODO - move both logics into the selector joiner visitor
                if (i > 0 && selectorElements.length && selectorElements[0].combinator.value === '') {
                    selectorElements[0].combinator.value = ' ';
                }
                selfElements = selfElements.concat(selectors[i].elements);
            }
            this.selfSelectors = [new selector_1.default(selfElements)];
            this.selfSelectors[0].copyVisibilityInfo(this.visibilityInfo());
        }
    });
    Extend.next_id = 0;
    exports.default = Extend;
    
},
/* less/lib/less/tree/variable-call.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var variable_1 = tslib_1.__importDefault(require(152) /* ./variable */);
    var ruleset_1 = tslib_1.__importDefault(require(140) /* ./ruleset */);
    var detached_ruleset_1 = tslib_1.__importDefault(require(148) /* ./detached-ruleset */);
    var less_error_1 = tslib_1.__importDefault(require(121) /* ../less-error */);
    var VariableCall = function (variable, index, currentFileInfo) {
        this.variable = variable;
        this._index = index;
        this._fileInfo = currentFileInfo;
        this.allowRoot = true;
    };
    VariableCall.prototype = Object.assign(new node_1.default(), {
        type: 'VariableCall',
        eval: function (context) {
            var rules;
            var detachedRuleset = new variable_1.default(this.variable, this.getIndex(), this.fileInfo()).eval(context);
            var error = new less_error_1.default({ message: "Could not evaluate variable call " + this.variable });
            if (!detachedRuleset.ruleset) {
                if (detachedRuleset.rules) {
                    rules = detachedRuleset;
                }
                else if (Array.isArray(detachedRuleset)) {
                    rules = new ruleset_1.default('', detachedRuleset);
                }
                else if (Array.isArray(detachedRuleset.value)) {
                    rules = new ruleset_1.default('', detachedRuleset.value);
                }
                else {
                    throw error;
                }
                detachedRuleset = new detached_ruleset_1.default(rules);
            }
            if (detachedRuleset.ruleset) {
                return detachedRuleset.callEval(context);
            }
            throw error;
        }
    });
    exports.default = VariableCall;
    
},
/* less/lib/less/tree/namespace-value.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var variable_1 = tslib_1.__importDefault(require(152) /* ./variable */);
    var ruleset_1 = tslib_1.__importDefault(require(140) /* ./ruleset */);
    var selector_1 = tslib_1.__importDefault(require(117) /* ./selector */);
    var NamespaceValue = function (ruleCall, lookups, index, fileInfo) {
        this.value = ruleCall;
        this.lookups = lookups;
        this._index = index;
        this._fileInfo = fileInfo;
    };
    NamespaceValue.prototype = Object.assign(new node_1.default(), {
        type: 'NamespaceValue',
        eval: function (context) {
            var i, name, rules = this.value.eval(context);
            for (i = 0; i < this.lookups.length; i++) {
                name = this.lookups[i];
                /**
                 * Eval'd DRs return rulesets.
                 * Eval'd mixins return rules, so let's make a ruleset if we need it.
                 * We need to do this because of late parsing of values
                 */
                if (Array.isArray(rules)) {
                    rules = new ruleset_1.default([new selector_1.default()], rules);
                }
                if (name === '') {
                    rules = rules.lastDeclaration();
                }
                else if (name.charAt(0) === '@') {
                    if (name.charAt(1) === '@') {
                        name = "@" + new variable_1.default(name.substr(1)).eval(context).value;
                    }
                    if (rules.variables) {
                        rules = rules.variable(name);
                    }
                    if (!rules) {
                        throw { type: 'Name',
                            message: "variable " + name + " not found",
                            filename: this.fileInfo().filename,
                            index: this.getIndex() };
                    }
                }
                else {
                    if (name.substring(0, 2) === '$@') {
                        name = "$" + new variable_1.default(name.substr(1)).eval(context).value;
                    }
                    else {
                        name = name.charAt(0) === '$' ? name : "$" + name;
                    }
                    if (rules.properties) {
                        rules = rules.property(name);
                    }
                    if (!rules) {
                        throw { type: 'Name',
                            message: "property \"" + name.substr(1) + "\" not found",
                            filename: this.fileInfo().filename,
                            index: this.getIndex() };
                    }
                    // Properties are an array of values, since a ruleset can have multiple props.
                    // We pick the last one (the "cascaded" value)
                    rules = rules[rules.length - 1];
                }
                if (rules.value) {
                    rules = rules.eval(context).value;
                }
                if (rules.ruleset) {
                    rules = rules.ruleset.eval(context);
                }
            }
            return rules;
        }
    });
    exports.default = NamespaceValue;
    
},
/* less/lib/less/tree/mixin-call.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var node_1 = tslib_1.__importDefault(require(114) /* ./node */);
    var selector_1 = tslib_1.__importDefault(require(117) /* ./selector */);
    var mixin_definition_1 = tslib_1.__importDefault(require(175) /* ./mixin-definition */);
    var default_1 = tslib_1.__importDefault(require(147) /* ../functions/default */);
    var MixinCall = function (elements, args, index, currentFileInfo, important) {
        this.selector = new selector_1.default(elements);
        this.arguments = args || [];
        this._index = index;
        this._fileInfo = currentFileInfo;
        this.important = important;
        this.allowRoot = true;
        this.setParent(this.selector, this);
    };
    MixinCall.prototype = Object.assign(new node_1.default(), {
        type: 'MixinCall',
        accept: function (visitor) {
            if (this.selector) {
                this.selector = visitor.visit(this.selector);
            }
            if (this.arguments.length) {
                this.arguments = visitor.visitArray(this.arguments);
            }
        },
        eval: function (context) {
            var mixins;
            var mixin;
            var mixinPath;
            var args = [];
            var arg;
            var argValue;
            var rules = [];
            var match = false;
            var i;
            var m;
            var f;
            var isRecursive;
            var isOneFound;
            var candidates = [];
            var candidate;
            var conditionResult = [];
            var defaultResult;
            var defFalseEitherCase = -1;
            var defNone = 0;
            var defTrue = 1;
            var defFalse = 2;
            var count;
            var originalRuleset;
            var noArgumentsFilter;
            this.selector = this.selector.eval(context);
            function calcDefGroup(mixin, mixinPath) {
                var f, p, namespace;
                for (f = 0; f < 2; f++) {
                    conditionResult[f] = true;
                    default_1.default.value(f);
                    for (p = 0; p < mixinPath.length && conditionResult[f]; p++) {
                        namespace = mixinPath[p];
                        if (namespace.matchCondition) {
                            conditionResult[f] = conditionResult[f] && namespace.matchCondition(null, context);
                        }
                    }
                    if (mixin.matchCondition) {
                        conditionResult[f] = conditionResult[f] && mixin.matchCondition(args, context);
                    }
                }
                if (conditionResult[0] || conditionResult[1]) {
                    if (conditionResult[0] != conditionResult[1]) {
                        return conditionResult[1] ?
                            defTrue : defFalse;
                    }
                    return defNone;
                }
                return defFalseEitherCase;
            }
            for (i = 0; i < this.arguments.length; i++) {
                arg = this.arguments[i];
                argValue = arg.value.eval(context);
                if (arg.expand && Array.isArray(argValue.value)) {
                    argValue = argValue.value;
                    for (m = 0; m < argValue.length; m++) {
                        args.push({ value: argValue[m] });
                    }
                }
                else {
                    args.push({ name: arg.name, value: argValue });
                }
            }
            noArgumentsFilter = function (rule) { return rule.matchArgs(null, context); };
            for (i = 0; i < context.frames.length; i++) {
                if ((mixins = context.frames[i].find(this.selector, null, noArgumentsFilter)).length > 0) {
                    isOneFound = true;
                    // To make `default()` function independent of definition order we have two "subpasses" here.
                    // At first we evaluate each guard *twice* (with `default() == true` and `default() == false`),
                    // and build candidate list with corresponding flags. Then, when we know all possible matches,
                    // we make a final decision.
                    for (m = 0; m < mixins.length; m++) {
                        mixin = mixins[m].rule;
                        mixinPath = mixins[m].path;
                        isRecursive = false;
                        for (f = 0; f < context.frames.length; f++) {
                            if ((!(mixin instanceof mixin_definition_1.default)) && mixin === (context.frames[f].originalRuleset || context.frames[f])) {
                                isRecursive = true;
                                break;
                            }
                        }
                        if (isRecursive) {
                            continue;
                        }
                        if (mixin.matchArgs(args, context)) {
                            candidate = { mixin: mixin, group: calcDefGroup(mixin, mixinPath) };
                            if (candidate.group !== defFalseEitherCase) {
                                candidates.push(candidate);
                            }
                            match = true;
                        }
                    }
                    default_1.default.reset();
                    count = [0, 0, 0];
                    for (m = 0; m < candidates.length; m++) {
                        count[candidates[m].group]++;
                    }
                    if (count[defNone] > 0) {
                        defaultResult = defFalse;
                    }
                    else {
                        defaultResult = defTrue;
                        if ((count[defTrue] + count[defFalse]) > 1) {
                            throw { type: 'Runtime',
                                message: "Ambiguous use of `default()` found when matching for `" + this.format(args) + "`",
                                index: this.getIndex(), filename: this.fileInfo().filename };
                        }
                    }
                    for (m = 0; m < candidates.length; m++) {
                        candidate = candidates[m].group;
                        if ((candidate === defNone) || (candidate === defaultResult)) {
                            try {
                                mixin = candidates[m].mixin;
                                if (!(mixin instanceof mixin_definition_1.default)) {
                                    originalRuleset = mixin.originalRuleset || mixin;
                                    mixin = new mixin_definition_1.default('', [], mixin.rules, null, false, null, originalRuleset.visibilityInfo());
                                    mixin.originalRuleset = originalRuleset;
                                }
                                var newRules = mixin.evalCall(context, args, this.important).rules;
                                this._setVisibilityToReplacement(newRules);
                                Array.prototype.push.apply(rules, newRules);
                            }
                            catch (e) {
                                throw { message: e.message, index: this.getIndex(), filename: this.fileInfo().filename, stack: e.stack };
                            }
                        }
                    }
                    if (match) {
                        return rules;
                    }
                }
            }
            if (isOneFound) {
                throw { type: 'Runtime',
                    message: "No matching definition was found for `" + this.format(args) + "`",
                    index: this.getIndex(), filename: this.fileInfo().filename };
            }
            else {
                throw { type: 'Name',
                    message: this.selector.toCSS().trim() + " is undefined",
                    index: this.getIndex(), filename: this.fileInfo().filename };
            }
        },
        _setVisibilityToReplacement: function (replacement) {
            var i, rule;
            if (this.blocksVisibility()) {
                for (i = 0; i < replacement.length; i++) {
                    rule = replacement[i];
                    rule.addVisibilityBlock();
                }
            }
        },
        format: function (args) {
            return this.selector.toCSS().trim() + "(" + (args ? args.map(function (a) {
                var argValue = '';
                if (a.name) {
                    argValue += a.name + ":";
                }
                if (a.value.toCSS) {
                    argValue += a.value.toCSS();
                }
                else {
                    argValue += '???';
                }
                return argValue;
            }).join(', ') : '') + ")";
        }
    });
    exports.default = MixinCall;
    
},
/* less/lib/less/tree/mixin-definition.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var selector_1 = tslib_1.__importDefault(require(117) /* ./selector */);
    var element_1 = tslib_1.__importDefault(require(118) /* ./element */);
    var ruleset_1 = tslib_1.__importDefault(require(140) /* ./ruleset */);
    var declaration_1 = tslib_1.__importDefault(require(141) /* ./declaration */);
    var detached_ruleset_1 = tslib_1.__importDefault(require(148) /* ./detached-ruleset */);
    var expression_1 = tslib_1.__importDefault(require(155) /* ./expression */);
    var contexts_1 = tslib_1.__importDefault(require(130) /* ../contexts */);
    var utils = tslib_1.__importStar(require(122) /* ../utils */);
    var Definition = function (name, params, rules, condition, variadic, frames, visibilityInfo) {
        this.name = name || 'anonymous mixin';
        this.selectors = [new selector_1.default([new element_1.default(null, name, false, this._index, this._fileInfo)])];
        this.params = params;
        this.condition = condition;
        this.variadic = variadic;
        this.arity = params.length;
        this.rules = rules;
        this._lookups = {};
        var optionalParameters = [];
        this.required = params.reduce(function (count, p) {
            if (!p.name || (p.name && !p.value)) {
                return count + 1;
            }
            else {
                optionalParameters.push(p.name);
                return count;
            }
        }, 0);
        this.optionalParameters = optionalParameters;
        this.frames = frames;
        this.copyVisibilityInfo(visibilityInfo);
        this.allowRoot = true;
    };
    Definition.prototype = Object.assign(new ruleset_1.default(), {
        type: 'MixinDefinition',
        evalFirst: true,
        accept: function (visitor) {
            if (this.params && this.params.length) {
                this.params = visitor.visitArray(this.params);
            }
            this.rules = visitor.visitArray(this.rules);
            if (this.condition) {
                this.condition = visitor.visit(this.condition);
            }
        },
        evalParams: function (context, mixinEnv, args, evaldArguments) {
            /* jshint boss:true */
            var frame = new ruleset_1.default(null, null);
            var varargs;
            var arg;
            var params = utils.copyArray(this.params);
            var i;
            var j;
            var val;
            var name;
            var isNamedFound;
            var argIndex;
            var argsLength = 0;
            if (mixinEnv.frames && mixinEnv.frames[0] && mixinEnv.frames[0].functionRegistry) {
                frame.functionRegistry = mixinEnv.frames[0].functionRegistry.inherit();
            }
            mixinEnv = new contexts_1.default.Eval(mixinEnv, [frame].concat(mixinEnv.frames));
            if (args) {
                args = utils.copyArray(args);
                argsLength = args.length;
                for (i = 0; i < argsLength; i++) {
                    arg = args[i];
                    if (name = (arg && arg.name)) {
                        isNamedFound = false;
                        for (j = 0; j < params.length; j++) {
                            if (!evaldArguments[j] && name === params[j].name) {
                                evaldArguments[j] = arg.value.eval(context);
                                frame.prependRule(new declaration_1.default(name, arg.value.eval(context)));
                                isNamedFound = true;
                                break;
                            }
                        }
                        if (isNamedFound) {
                            args.splice(i, 1);
                            i--;
                            continue;
                        }
                        else {
                            throw { type: 'Runtime', message: "Named argument for " + this.name + " " + args[i].name + " not found" };
                        }
                    }
                }
            }
            argIndex = 0;
            for (i = 0; i < params.length; i++) {
                if (evaldArguments[i]) {
                    continue;
                }
                arg = args && args[argIndex];
                if (name = params[i].name) {
                    if (params[i].variadic) {
                        varargs = [];
                        for (j = argIndex; j < argsLength; j++) {
                            varargs.push(args[j].value.eval(context));
                        }
                        frame.prependRule(new declaration_1.default(name, new expression_1.default(varargs).eval(context)));
                    }
                    else {
                        val = arg && arg.value;
                        if (val) {
                            // This was a mixin call, pass in a detached ruleset of it's eval'd rules
                            if (Array.isArray(val)) {
                                val = new detached_ruleset_1.default(new ruleset_1.default('', val));
                            }
                            else {
                                val = val.eval(context);
                            }
                        }
                        else if (params[i].value) {
                            val = params[i].value.eval(mixinEnv);
                            frame.resetCache();
                        }
                        else {
                            throw { type: 'Runtime', message: "wrong number of arguments for " + this.name + " (" + argsLength + " for " + this.arity + ")" };
                        }
                        frame.prependRule(new declaration_1.default(name, val));
                        evaldArguments[i] = val;
                    }
                }
                if (params[i].variadic && args) {
                    for (j = argIndex; j < argsLength; j++) {
                        evaldArguments[j] = args[j].value.eval(context);
                    }
                }
                argIndex++;
            }
            return frame;
        },
        makeImportant: function () {
            var rules = !this.rules ? this.rules : this.rules.map(function (r) {
                if (r.makeImportant) {
                    return r.makeImportant(true);
                }
                else {
                    return r;
                }
            });
            var result = new Definition(this.name, this.params, rules, this.condition, this.variadic, this.frames);
            return result;
        },
        eval: function (context) {
            return new Definition(this.name, this.params, this.rules, this.condition, this.variadic, this.frames || utils.copyArray(context.frames));
        },
        evalCall: function (context, args, important) {
            var _arguments = [];
            var mixinFrames = this.frames ? this.frames.concat(context.frames) : context.frames;
            var frame = this.evalParams(context, new contexts_1.default.Eval(context, mixinFrames), args, _arguments);
            var rules;
            var ruleset;
            frame.prependRule(new declaration_1.default('@arguments', new expression_1.default(_arguments).eval(context)));
            rules = utils.copyArray(this.rules);
            ruleset = new ruleset_1.default(null, rules);
            ruleset.originalRuleset = this;
            ruleset = ruleset.eval(new contexts_1.default.Eval(context, [this, frame].concat(mixinFrames)));
            if (important) {
                ruleset = ruleset.makeImportant();
            }
            return ruleset;
        },
        matchCondition: function (args, context) {
            if (this.condition && !this.condition.eval(new contexts_1.default.Eval(context, [this.evalParams(context, /* the parameter variables */ new contexts_1.default.Eval(context, this.frames ? this.frames.concat(context.frames) : context.frames), args, [])]
                .concat(this.frames || []) // the parent namespace/mixin frames
                .concat(context.frames)))) { // the current environment frames
                return false;
            }
            return true;
        },
        matchArgs: function (args, context) {
            var allArgsCnt = (args && args.length) || 0;
            var len;
            var optionalParameters = this.optionalParameters;
            var requiredArgsCnt = !args ? 0 : args.reduce(function (count, p) {
                if (optionalParameters.indexOf(p.name) < 0) {
                    return count + 1;
                }
                else {
                    return count;
                }
            }, 0);
            if (!this.variadic) {
                if (requiredArgsCnt < this.required) {
                    return false;
                }
                if (allArgsCnt > this.params.length) {
                    return false;
                }
            }
            else {
                if (requiredArgsCnt < (this.required - 1)) {
                    return false;
                }
            }
            // check patterns
            len = Math.min(requiredArgsCnt, this.arity);
            for (var i = 0; i < len; i++) {
                if (!this.params[i].name && !this.params[i].variadic) {
                    if (args[i].value.eval(context).toCSS() != this.params[i].value.eval(context).toCSS()) {
                        return false;
                    }
                }
            }
            return true;
        }
    });
    exports.default = Definition;
    
},
/* less/lib/less/environment/abstract-plugin-loader.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var function_registry_1 = tslib_1.__importDefault(require(138) /* ../functions/function-registry */);
    var less_error_1 = tslib_1.__importDefault(require(121) /* ../less-error */);
    var AbstractPluginLoader = /** @class */ (function () {
        function AbstractPluginLoader() {
            // Implemented by Node.js plugin loader
            this.require = function () {
                return null;
            };
        }
        AbstractPluginLoader.prototype.evalPlugin = function (contents, context, imports, pluginOptions, fileInfo) {
            var loader, registry, pluginObj, localModule, pluginManager, filename, result;
            pluginManager = context.pluginManager;
            if (fileInfo) {
                if (typeof fileInfo === 'string') {
                    filename = fileInfo;
                }
                else {
                    filename = fileInfo.filename;
                }
            }
            var shortname = (new this.less.FileManager()).extractUrlParts(filename).filename;
            if (filename) {
                pluginObj = pluginManager.get(filename);
                if (pluginObj) {
                    result = this.trySetOptions(pluginObj, filename, shortname, pluginOptions);
                    if (result) {
                        return result;
                    }
                    try {
                        if (pluginObj.use) {
                            pluginObj.use.call(this.context, pluginObj);
                        }
                    }
                    catch (e) {
                        e.message = e.message || 'Error during @plugin call';
                        return new less_error_1.default(e, imports, filename);
                    }
                    return pluginObj;
                }
            }
            localModule = {
                exports: {},
                pluginManager: pluginManager,
                fileInfo: fileInfo
            };
            registry = function_registry_1.default.create();
            var registerPlugin = function (obj) {
                pluginObj = obj;
            };
            try {
                loader = new Function('module', 'require', 'registerPlugin', 'functions', 'tree', 'less', 'fileInfo', contents);
                loader(localModule, this.require(filename), registerPlugin, registry, this.less.tree, this.less, fileInfo);
            }
            catch (e) {
                return new less_error_1.default(e, imports, filename);
            }
            if (!pluginObj) {
                pluginObj = localModule.exports;
            }
            pluginObj = this.validatePlugin(pluginObj, filename, shortname);
            if (pluginObj instanceof less_error_1.default) {
                return pluginObj;
            }
            if (pluginObj) {
                pluginObj.imports = imports;
                pluginObj.filename = filename;
                // For < 3.x (or unspecified minVersion) - setOptions() before install()
                if (!pluginObj.minVersion || this.compareVersion('3.0.0', pluginObj.minVersion) < 0) {
                    result = this.trySetOptions(pluginObj, filename, shortname, pluginOptions);
                    if (result) {
                        return result;
                    }
                }
                // Run on first load
                pluginManager.addPlugin(pluginObj, fileInfo.filename, registry);
                pluginObj.functions = registry.getLocalFunctions();
                // Need to call setOptions again because the pluginObj might have functions
                result = this.trySetOptions(pluginObj, filename, shortname, pluginOptions);
                if (result) {
                    return result;
                }
                // Run every @plugin call
                try {
                    if (pluginObj.use) {
                        pluginObj.use.call(this.context, pluginObj);
                    }
                }
                catch (e) {
                    e.message = e.message || 'Error during @plugin call';
                    return new less_error_1.default(e, imports, filename);
                }
            }
            else {
                return new less_error_1.default({ message: 'Not a valid plugin' }, imports, filename);
            }
            return pluginObj;
        };
        AbstractPluginLoader.prototype.trySetOptions = function (plugin, filename, name, options) {
            if (options && !plugin.setOptions) {
                return new less_error_1.default({
                    message: "Options have been provided but the plugin " + name + " does not support any options."
                });
            }
            try {
                plugin.setOptions && plugin.setOptions(options);
            }
            catch (e) {
                return new less_error_1.default(e);
            }
        };
        AbstractPluginLoader.prototype.validatePlugin = function (plugin, filename, name) {
            if (plugin) {
                // support plugins being a function
                // so that the plugin can be more usable programmatically
                if (typeof plugin === 'function') {
                    plugin = new plugin();
                }
                if (plugin.minVersion) {
                    if (this.compareVersion(plugin.minVersion, this.less.version) < 0) {
                        return new less_error_1.default({
                            message: "Plugin " + name + " requires version " + this.versionToString(plugin.minVersion)
                        });
                    }
                }
                return plugin;
            }
            return null;
        };
        AbstractPluginLoader.prototype.compareVersion = function (aVersion, bVersion) {
            if (typeof aVersion === 'string') {
                aVersion = aVersion.match(/^(\d+)\.?(\d+)?\.?(\d+)?/);
                aVersion.shift();
            }
            for (var i = 0; i < aVersion.length; i++) {
                if (aVersion[i] !== bVersion[i]) {
                    return parseInt(aVersion[i]) > parseInt(bVersion[i]) ? -1 : 1;
                }
            }
            return 0;
        };
        AbstractPluginLoader.prototype.versionToString = function (version) {
            var versionString = '';
            for (var i = 0; i < version.length; i++) {
                versionString += (versionString ? '.' : '') + version[i];
            }
            return versionString;
        };
        AbstractPluginLoader.prototype.printUsage = function (plugins) {
            for (var i = 0; i < plugins.length; i++) {
                var plugin = plugins[i];
                if (plugin.printUsage) {
                    plugin.printUsage();
                }
            }
        };
        return AbstractPluginLoader;
    }());
    exports.default = AbstractPluginLoader;
    
},
/* less/lib/less/functions/index.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var function_registry_1 = tslib_1.__importDefault(require(138) /* ./function-registry */);
    var function_caller_1 = tslib_1.__importDefault(require(154) /* ./function-caller */);
    var boolean_1 = tslib_1.__importDefault(require(178) /* ./boolean */);
    var default_1 = tslib_1.__importDefault(require(147) /* ./default */);
    var color_1 = tslib_1.__importDefault(require(179) /* ./color */);
    var color_blending_1 = tslib_1.__importDefault(require(180) /* ./color-blending */);
    var data_uri_1 = tslib_1.__importDefault(require(181) /* ./data-uri */);
    var list_1 = tslib_1.__importDefault(require(182) /* ./list */);
    var math_1 = tslib_1.__importDefault(require(183) /* ./math */);
    var number_1 = tslib_1.__importDefault(require(185) /* ./number */);
    var string_1 = tslib_1.__importDefault(require(186) /* ./string */);
    var svg_1 = tslib_1.__importDefault(require(187) /* ./svg */);
    var types_1 = tslib_1.__importDefault(require(188) /* ./types */);
    exports.default = (function (environment) {
        var functions = { functionRegistry: function_registry_1.default, functionCaller: function_caller_1.default };
        // register functions
        function_registry_1.default.addMultiple(boolean_1.default);
        function_registry_1.default.add('default', default_1.default.eval.bind(default_1.default));
        function_registry_1.default.addMultiple(color_1.default);
        function_registry_1.default.addMultiple(color_blending_1.default);
        function_registry_1.default.addMultiple(data_uri_1.default(environment));
        function_registry_1.default.addMultiple(list_1.default);
        function_registry_1.default.addMultiple(math_1.default);
        function_registry_1.default.addMultiple(number_1.default);
        function_registry_1.default.addMultiple(string_1.default);
        function_registry_1.default.addMultiple(svg_1.default(environment));
        function_registry_1.default.addMultiple(types_1.default);
        return functions;
    });
    
},
/* less/lib/less/functions/boolean.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var anonymous_1 = tslib_1.__importDefault(require(144) /* ../tree/anonymous */);
    var keyword_1 = tslib_1.__importDefault(require(143) /* ../tree/keyword */);
    function boolean(condition) {
        return condition ? keyword_1.default.True : keyword_1.default.False;
    }
    /**
     * Functions with evalArgs set to false are sent context
     * as the first argument.
     */
    function If(context, condition, trueValue, falseValue) {
        return condition.eval(context) ? trueValue.eval(context)
            : (falseValue ? falseValue.eval(context) : new anonymous_1.default);
    }
    If.evalArgs = false;
    function isdefined(context, variable) {
        try {
            variable.eval(context);
            return keyword_1.default.True;
        }
        catch (e) {
            return keyword_1.default.False;
        }
    }
    isdefined.evalArgs = false;
    exports.default = { isdefined: isdefined, boolean: boolean, 'if': If };
    
},
/* less/lib/less/functions/color.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var dimension_1 = tslib_1.__importDefault(require(150) /* ../tree/dimension */);
    var color_1 = tslib_1.__importDefault(require(115) /* ../tree/color */);
    var quoted_1 = tslib_1.__importDefault(require(158) /* ../tree/quoted */);
    var anonymous_1 = tslib_1.__importDefault(require(144) /* ../tree/anonymous */);
    var expression_1 = tslib_1.__importDefault(require(155) /* ../tree/expression */);
    var operation_1 = tslib_1.__importDefault(require(149) /* ../tree/operation */);
    var colorFunctions;
    function clamp(val) {
        return Math.min(1, Math.max(0, val));
    }
    function hsla(origColor, hsl) {
        var color = colorFunctions.hsla(hsl.h, hsl.s, hsl.l, hsl.a);
        if (color) {
            if (origColor.value &&
                /^(rgb|hsl)/.test(origColor.value)) {
                color.value = origColor.value;
            }
            else {
                color.value = 'rgb';
            }
            return color;
        }
    }
    function toHSL(color) {
        if (color.toHSL) {
            return color.toHSL();
        }
        else {
            throw new Error('Argument cannot be evaluated to a color');
        }
    }
    function toHSV(color) {
        if (color.toHSV) {
            return color.toHSV();
        }
        else {
            throw new Error('Argument cannot be evaluated to a color');
        }
    }
    function number(n) {
        if (n instanceof dimension_1.default) {
            return parseFloat(n.unit.is('%') ? n.value / 100 : n.value);
        }
        else if (typeof n === 'number') {
            return n;
        }
        else {
            throw {
                type: 'Argument',
                message: 'color functions take numbers as parameters'
            };
        }
    }
    function scaled(n, size) {
        if (n instanceof dimension_1.default && n.unit.is('%')) {
            return parseFloat(n.value * size / 100);
        }
        else {
            return number(n);
        }
    }
    colorFunctions = {
        rgb: function (r, g, b) {
            var a = 1;
            /**
             * Comma-less syntax
             *   e.g. rgb(0 128 255 / 50%)
             */
            if (r instanceof expression_1.default) {
                var val = r.value;
                r = val[0];
                g = val[1];
                b = val[2];
                /**
                 * @todo - should this be normalized in
                 *   function caller? Or parsed differently?
                 */
                if (b instanceof operation_1.default) {
                    var op = b;
                    b = op.operands[0];
                    a = op.operands[1];
                }
            }
            var color = colorFunctions.rgba(r, g, b, a);
            if (color) {
                color.value = 'rgb';
                return color;
            }
        },
        rgba: function (r, g, b, a) {
            try {
                if (r instanceof color_1.default) {
                    if (g) {
                        a = number(g);
                    }
                    else {
                        a = r.alpha;
                    }
                    return new color_1.default(r.rgb, a, 'rgba');
                }
                var rgb = [r, g, b].map(function (c) { return scaled(c, 255); });
                a = number(a);
                return new color_1.default(rgb, a, 'rgba');
            }
            catch (e) { }
        },
        hsl: function (h, s, l) {
            var a = 1;
            if (h instanceof expression_1.default) {
                var val = h.value;
                h = val[0];
                s = val[1];
                l = val[2];
                if (l instanceof operation_1.default) {
                    var op = l;
                    l = op.operands[0];
                    a = op.operands[1];
                }
            }
            var color = colorFunctions.hsla(h, s, l, a);
            if (color) {
                color.value = 'hsl';
                return color;
            }
        },
        hsla: function (h, s, l, a) {
            var m1;
            var m2;
            function hue(h) {
                h = h < 0 ? h + 1 : (h > 1 ? h - 1 : h);
                if (h * 6 < 1) {
                    return m1 + (m2 - m1) * h * 6;
                }
                else if (h * 2 < 1) {
                    return m2;
                }
                else if (h * 3 < 2) {
                    return m1 + (m2 - m1) * (2 / 3 - h) * 6;
                }
                else {
                    return m1;
                }
            }
            try {
                if (h instanceof color_1.default) {
                    if (s) {
                        a = number(s);
                    }
                    else {
                        a = h.alpha;
                    }
                    return new color_1.default(h.rgb, a, 'hsla');
                }
                h = (number(h) % 360) / 360;
                s = clamp(number(s));
                l = clamp(number(l));
                a = clamp(number(a));
                m2 = l <= 0.5 ? l * (s + 1) : l + s - l * s;
                m1 = l * 2 - m2;
                var rgb = [
                    hue(h + 1 / 3) * 255,
                    hue(h) * 255,
                    hue(h - 1 / 3) * 255
                ];
                a = number(a);
                return new color_1.default(rgb, a, 'hsla');
            }
            catch (e) { }
        },
        hsv: function (h, s, v) {
            return colorFunctions.hsva(h, s, v, 1.0);
        },
        hsva: function (h, s, v, a) {
            h = ((number(h) % 360) / 360) * 360;
            s = number(s);
            v = number(v);
            a = number(a);
            var i;
            var f;
            i = Math.floor((h / 60) % 6);
            f = (h / 60) - i;
            var vs = [v,
                v * (1 - s),
                v * (1 - f * s),
                v * (1 - (1 - f) * s)];
            var perm = [[0, 3, 1],
                [2, 0, 1],
                [1, 0, 3],
                [1, 2, 0],
                [3, 1, 0],
                [0, 1, 2]];
            return colorFunctions.rgba(vs[perm[i][0]] * 255, vs[perm[i][1]] * 255, vs[perm[i][2]] * 255, a);
        },
        hue: function (color) {
            return new dimension_1.default(toHSL(color).h);
        },
        saturation: function (color) {
            return new dimension_1.default(toHSL(color).s * 100, '%');
        },
        lightness: function (color) {
            return new dimension_1.default(toHSL(color).l * 100, '%');
        },
        hsvhue: function (color) {
            return new dimension_1.default(toHSV(color).h);
        },
        hsvsaturation: function (color) {
            return new dimension_1.default(toHSV(color).s * 100, '%');
        },
        hsvvalue: function (color) {
            return new dimension_1.default(toHSV(color).v * 100, '%');
        },
        red: function (color) {
            return new dimension_1.default(color.rgb[0]);
        },
        green: function (color) {
            return new dimension_1.default(color.rgb[1]);
        },
        blue: function (color) {
            return new dimension_1.default(color.rgb[2]);
        },
        alpha: function (color) {
            return new dimension_1.default(toHSL(color).a);
        },
        luma: function (color) {
            return new dimension_1.default(color.luma() * color.alpha * 100, '%');
        },
        luminance: function (color) {
            var luminance = (0.2126 * color.rgb[0] / 255) +
                (0.7152 * color.rgb[1] / 255) +
                (0.0722 * color.rgb[2] / 255);
            return new dimension_1.default(luminance * color.alpha * 100, '%');
        },
        saturate: function (color, amount, method) {
            // filter: saturate(3.2);
            // should be kept as is, so check for color
            if (!color.rgb) {
                return null;
            }
            var hsl = toHSL(color);
            if (typeof method !== 'undefined' && method.value === 'relative') {
                hsl.s += hsl.s * amount.value / 100;
            }
            else {
                hsl.s += amount.value / 100;
            }
            hsl.s = clamp(hsl.s);
            return hsla(color, hsl);
        },
        desaturate: function (color, amount, method) {
            var hsl = toHSL(color);
            if (typeof method !== 'undefined' && method.value === 'relative') {
                hsl.s -= hsl.s * amount.value / 100;
            }
            else {
                hsl.s -= amount.value / 100;
            }
            hsl.s = clamp(hsl.s);
            return hsla(color, hsl);
        },
        lighten: function (color, amount, method) {
            var hsl = toHSL(color);
            if (typeof method !== 'undefined' && method.value === 'relative') {
                hsl.l += hsl.l * amount.value / 100;
            }
            else {
                hsl.l += amount.value / 100;
            }
            hsl.l = clamp(hsl.l);
            return hsla(color, hsl);
        },
        darken: function (color, amount, method) {
            var hsl = toHSL(color);
            if (typeof method !== 'undefined' && method.value === 'relative') {
                hsl.l -= hsl.l * amount.value / 100;
            }
            else {
                hsl.l -= amount.value / 100;
            }
            hsl.l = clamp(hsl.l);
            return hsla(color, hsl);
        },
        fadein: function (color, amount, method) {
            var hsl = toHSL(color);
            if (typeof method !== 'undefined' && method.value === 'relative') {
                hsl.a += hsl.a * amount.value / 100;
            }
            else {
                hsl.a += amount.value / 100;
            }
            hsl.a = clamp(hsl.a);
            return hsla(color, hsl);
        },
        fadeout: function (color, amount, method) {
            var hsl = toHSL(color);
            if (typeof method !== 'undefined' && method.value === 'relative') {
                hsl.a -= hsl.a * amount.value / 100;
            }
            else {
                hsl.a -= amount.value / 100;
            }
            hsl.a = clamp(hsl.a);
            return hsla(color, hsl);
        },
        fade: function (color, amount) {
            var hsl = toHSL(color);
            hsl.a = amount.value / 100;
            hsl.a = clamp(hsl.a);
            return hsla(color, hsl);
        },
        spin: function (color, amount) {
            var hsl = toHSL(color);
            var hue = (hsl.h + amount.value) % 360;
            hsl.h = hue < 0 ? 360 + hue : hue;
            return hsla(color, hsl);
        },
        //
        // Copyright (c) 2006-2009 Hampton Catlin, Natalie Weizenbaum, and Chris Eppstein
        // http://sass-lang.com
        //
        mix: function (color1, color2, weight) {
            if (!weight) {
                weight = new dimension_1.default(50);
            }
            var p = weight.value / 100.0;
            var w = p * 2 - 1;
            var a = toHSL(color1).a - toHSL(color2).a;
            var w1 = (((w * a == -1) ? w : (w + a) / (1 + w * a)) + 1) / 2.0;
            var w2 = 1 - w1;
            var rgb = [color1.rgb[0] * w1 + color2.rgb[0] * w2,
                color1.rgb[1] * w1 + color2.rgb[1] * w2,
                color1.rgb[2] * w1 + color2.rgb[2] * w2];
            var alpha = color1.alpha * p + color2.alpha * (1 - p);
            return new color_1.default(rgb, alpha);
        },
        greyscale: function (color) {
            return colorFunctions.desaturate(color, new dimension_1.default(100));
        },
        contrast: function (color, dark, light, threshold) {
            // filter: contrast(3.2);
            // should be kept as is, so check for color
            if (!color.rgb) {
                return null;
            }
            if (typeof light === 'undefined') {
                light = colorFunctions.rgba(255, 255, 255, 1.0);
            }
            if (typeof dark === 'undefined') {
                dark = colorFunctions.rgba(0, 0, 0, 1.0);
            }
            // Figure out which is actually light and dark:
            if (dark.luma() > light.luma()) {
                var t = light;
                light = dark;
                dark = t;
            }
            if (typeof threshold === 'undefined') {
                threshold = 0.43;
            }
            else {
                threshold = number(threshold);
            }
            if (color.luma() < threshold) {
                return light;
            }
            else {
                return dark;
            }
        },
        // Changes made in 2.7.0 - Reverted in 3.0.0
        // contrast: function (color, color1, color2, threshold) {
        //     // Return which of `color1` and `color2` has the greatest contrast with `color`
        //     // according to the standard WCAG contrast ratio calculation.
        //     // http://www.w3.org/TR/WCAG20/#contrast-ratiodef
        //     // The threshold param is no longer used, in line with SASS.
        //     // filter: contrast(3.2);
        //     // should be kept as is, so check for color
        //     if (!color.rgb) {
        //         return null;
        //     }
        //     if (typeof color1 === 'undefined') {
        //         color1 = colorFunctions.rgba(0, 0, 0, 1.0);
        //     }
        //     if (typeof color2 === 'undefined') {
        //         color2 = colorFunctions.rgba(255, 255, 255, 1.0);
        //     }
        //     var contrast1, contrast2;
        //     var luma = color.luma();
        //     var luma1 = color1.luma();
        //     var luma2 = color2.luma();
        //     // Calculate contrast ratios for each color
        //     if (luma > luma1) {
        //         contrast1 = (luma + 0.05) / (luma1 + 0.05);
        //     } else {
        //         contrast1 = (luma1 + 0.05) / (luma + 0.05);
        //     }
        //     if (luma > luma2) {
        //         contrast2 = (luma + 0.05) / (luma2 + 0.05);
        //     } else {
        //         contrast2 = (luma2 + 0.05) / (luma + 0.05);
        //     }
        //     if (contrast1 > contrast2) {
        //         return color1;
        //     } else {
        //         return color2;
        //     }
        // },
        argb: function (color) {
            return new anonymous_1.default(color.toARGB());
        },
        color: function (c) {
            if ((c instanceof quoted_1.default) &&
                (/^#([A-Fa-f0-9]{8}|[A-Fa-f0-9]{6}|[A-Fa-f0-9]{3,4})$/i.test(c.value))) {
                var val = c.value.slice(1);
                return new color_1.default(val, undefined, "#" + val);
            }
            if ((c instanceof color_1.default) || (c = color_1.default.fromKeyword(c.value))) {
                c.value = undefined;
                return c;
            }
            throw {
                type: 'Argument',
                message: 'argument must be a color keyword or 3|4|6|8 digit hex e.g. #FFF'
            };
        },
        tint: function (color, amount) {
            return colorFunctions.mix(colorFunctions.rgb(255, 255, 255), color, amount);
        },
        shade: function (color, amount) {
            return colorFunctions.mix(colorFunctions.rgb(0, 0, 0), color, amount);
        }
    };
    exports.default = colorFunctions;
    
},
/* less/lib/less/functions/color-blending.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var color_1 = tslib_1.__importDefault(require(115) /* ../tree/color */);
    // Color Blending
    // ref: http://www.w3.org/TR/compositing-1
    function colorBlend(mode, color1, color2) {
        var ab = color1.alpha; // result
        var // backdrop
        cb;
        var as = color2.alpha;
        var // source
        cs;
        var ar;
        var cr;
        var r = [];
        ar = as + ab * (1 - as);
        for (var i = 0; i < 3; i++) {
            cb = color1.rgb[i] / 255;
            cs = color2.rgb[i] / 255;
            cr = mode(cb, cs);
            if (ar) {
                cr = (as * cs + ab * (cb -
                    as * (cb + cs - cr))) / ar;
            }
            r[i] = cr * 255;
        }
        return new color_1.default(r, ar);
    }
    var colorBlendModeFunctions = {
        multiply: function (cb, cs) {
            return cb * cs;
        },
        screen: function (cb, cs) {
            return cb + cs - cb * cs;
        },
        overlay: function (cb, cs) {
            cb *= 2;
            return (cb <= 1) ?
                colorBlendModeFunctions.multiply(cb, cs) :
                colorBlendModeFunctions.screen(cb - 1, cs);
        },
        softlight: function (cb, cs) {
            var d = 1;
            var e = cb;
            if (cs > 0.5) {
                e = 1;
                d = (cb > 0.25) ? Math.sqrt(cb)
                    : ((16 * cb - 12) * cb + 4) * cb;
            }
            return cb - (1 - 2 * cs) * e * (d - cb);
        },
        hardlight: function (cb, cs) {
            return colorBlendModeFunctions.overlay(cs, cb);
        },
        difference: function (cb, cs) {
            return Math.abs(cb - cs);
        },
        exclusion: function (cb, cs) {
            return cb + cs - 2 * cb * cs;
        },
        // non-w3c functions:
        average: function (cb, cs) {
            return (cb + cs) / 2;
        },
        negation: function (cb, cs) {
            return 1 - Math.abs(cb + cs - 1);
        }
    };
    for (var f in colorBlendModeFunctions) {
        // eslint-disable-next-line no-prototype-builtins
        if (colorBlendModeFunctions.hasOwnProperty(f)) {
            colorBlend[f] = colorBlend.bind(null, colorBlendModeFunctions[f]);
        }
    }
    exports.default = colorBlend;
    
},
/* less/lib/less/functions/data-uri.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var quoted_1 = tslib_1.__importDefault(require(158) /* ../tree/quoted */);
    var url_1 = tslib_1.__importDefault(require(159) /* ../tree/url */);
    var utils = tslib_1.__importStar(require(122) /* ../utils */);
    var logger_1 = tslib_1.__importDefault(require(75) /* ../logger */);
    exports.default = (function (environment) {
        var fallback = function (functionThis, node) { return new url_1.default(node, functionThis.index, functionThis.currentFileInfo).eval(functionThis.context); };
        return { 'data-uri': function (mimetypeNode, filePathNode) {
                if (!filePathNode) {
                    filePathNode = mimetypeNode;
                    mimetypeNode = null;
                }
                var mimetype = mimetypeNode && mimetypeNode.value;
                var filePath = filePathNode.value;
                var currentFileInfo = this.currentFileInfo;
                var currentDirectory = currentFileInfo.rewriteUrls ?
                    currentFileInfo.currentDirectory : currentFileInfo.entryPath;
                var fragmentStart = filePath.indexOf('#');
                var fragment = '';
                if (fragmentStart !== -1) {
                    fragment = filePath.slice(fragmentStart);
                    filePath = filePath.slice(0, fragmentStart);
                }
                var context = utils.clone(this.context);
                context.rawBuffer = true;
                var fileManager = environment.getFileManager(filePath, currentDirectory, context, environment, true);
                if (!fileManager) {
                    return fallback(this, filePathNode);
                }
                var useBase64 = false;
                // detect the mimetype if not given
                if (!mimetypeNode) {
                    mimetype = environment.mimeLookup(filePath);
                    if (mimetype === 'image/svg+xml') {
                        useBase64 = false;
                    }
                    else {
                        // use base 64 unless it's an ASCII or UTF-8 format
                        var charset = environment.charsetLookup(mimetype);
                        useBase64 = ['US-ASCII', 'UTF-8'].indexOf(charset) < 0;
                    }
                    if (useBase64) {
                        mimetype += ';base64';
                    }
                }
                else {
                    useBase64 = /;base64$/.test(mimetype);
                }
                var fileSync = fileManager.loadFileSync(filePath, currentDirectory, context, environment);
                if (!fileSync.contents) {
                    logger_1.default.warn("Skipped data-uri embedding of " + filePath + " because file not found");
                    return fallback(this, filePathNode || mimetypeNode);
                }
                var buf = fileSync.contents;
                if (useBase64 && !environment.encodeBase64) {
                    return fallback(this, filePathNode);
                }
                buf = useBase64 ? environment.encodeBase64(buf) : encodeURIComponent(buf);
                var uri = "data:" + mimetype + "," + buf + fragment;
                return new url_1.default(new quoted_1.default("\"" + uri + "\"", uri, false, this.index, this.currentFileInfo), this.index, this.currentFileInfo);
            } };
    });
    
},
/* less/lib/less/functions/list.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var comment_1 = tslib_1.__importDefault(require(145) /* ../tree/comment */);
    var node_1 = tslib_1.__importDefault(require(114) /* ../tree/node */);
    var dimension_1 = tslib_1.__importDefault(require(150) /* ../tree/dimension */);
    var declaration_1 = tslib_1.__importDefault(require(141) /* ../tree/declaration */);
    var expression_1 = tslib_1.__importDefault(require(155) /* ../tree/expression */);
    var ruleset_1 = tslib_1.__importDefault(require(140) /* ../tree/ruleset */);
    var selector_1 = tslib_1.__importDefault(require(117) /* ../tree/selector */);
    var element_1 = tslib_1.__importDefault(require(118) /* ../tree/element */);
    var quoted_1 = tslib_1.__importDefault(require(158) /* ../tree/quoted */);
    var value_1 = tslib_1.__importDefault(require(142) /* ../tree/value */);
    var getItemsFromNode = function (node) {
        // handle non-array values as an array of length 1
        // return 'undefined' if index is invalid
        var items = Array.isArray(node.value) ?
            node.value : Array(node);
        return items;
    };
    exports.default = {
        _SELF: function (n) {
            return n;
        },
        '~': function () {
            var expr = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                expr[_i] = arguments[_i];
            }
            if (expr.length === 1) {
                return expr[0];
            }
            return new value_1.default(expr);
        },
        extract: function (values, index) {
            // (1-based index)
            index = index.value - 1;
            return getItemsFromNode(values)[index];
        },
        length: function (values) {
            return new dimension_1.default(getItemsFromNode(values).length);
        },
        /**
         * Creates a Less list of incremental values.
         * Modeled after Lodash's range function, also exists natively in PHP
         *
         * @param {Dimension} [start=1]
         * @param {Dimension} end  - e.g. 10 or 10px - unit is added to output
         * @param {Dimension} [step=1]
         */
        range: function (start, end, step) {
            var from;
            var to;
            var stepValue = 1;
            var list = [];
            if (end) {
                to = end;
                from = start.value;
                if (step) {
                    stepValue = step.value;
                }
            }
            else {
                from = 1;
                to = start;
            }
            for (var i = from; i <= to.value; i += stepValue) {
                list.push(new dimension_1.default(i, to.unit));
            }
            return new expression_1.default(list);
        },
        each: function (list, rs) {
            var _this = this;
            var rules = [];
            var newRules;
            var iterator;
            var tryEval = function (val) {
                if (val instanceof node_1.default) {
                    return val.eval(_this.context);
                }
                return val;
            };
            if (list.value && !(list instanceof quoted_1.default)) {
                if (Array.isArray(list.value)) {
                    iterator = list.value.map(tryEval);
                }
                else {
                    iterator = [tryEval(list.value)];
                }
            }
            else if (list.ruleset) {
                iterator = tryEval(list.ruleset).rules;
            }
            else if (list.rules) {
                iterator = list.rules.map(tryEval);
            }
            else if (Array.isArray(list)) {
                iterator = list.map(tryEval);
            }
            else {
                iterator = [tryEval(list)];
            }
            var valueName = '@value';
            var keyName = '@key';
            var indexName = '@index';
            if (rs.params) {
                valueName = rs.params[0] && rs.params[0].name;
                keyName = rs.params[1] && rs.params[1].name;
                indexName = rs.params[2] && rs.params[2].name;
                rs = rs.rules;
            }
            else {
                rs = rs.ruleset;
            }
            for (var i = 0; i < iterator.length; i++) {
                var key = void 0;
                var value = void 0;
                var item = iterator[i];
                if (item instanceof declaration_1.default) {
                    key = typeof item.name === 'string' ? item.name : item.name[0].value;
                    value = item.value;
                }
                else {
                    key = new dimension_1.default(i + 1);
                    value = item;
                }
                if (item instanceof comment_1.default) {
                    continue;
                }
                newRules = rs.rules.slice(0);
                if (valueName) {
                    newRules.push(new declaration_1.default(valueName, value, false, false, this.index, this.currentFileInfo));
                }
                if (indexName) {
                    newRules.push(new declaration_1.default(indexName, new dimension_1.default(i + 1), false, false, this.index, this.currentFileInfo));
                }
                if (keyName) {
                    newRules.push(new declaration_1.default(keyName, key, false, false, this.index, this.currentFileInfo));
                }
                rules.push(new ruleset_1.default([new (selector_1.default)([new element_1.default('', '&')])], newRules, rs.strictImports, rs.visibilityInfo()));
            }
            return new ruleset_1.default([new (selector_1.default)([new element_1.default('', '&')])], rules, rs.strictImports, rs.visibilityInfo()).eval(this.context);
        }
    };
    
},
/* less/lib/less/functions/math.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var math_helper_js_1 = tslib_1.__importDefault(require(184) /* ./math-helper.js */);
    var mathFunctions = {
        // name,  unit
        ceil: null,
        floor: null,
        sqrt: null,
        abs: null,
        tan: '',
        sin: '',
        cos: '',
        atan: 'rad',
        asin: 'rad',
        acos: 'rad'
    };
    for (var f in mathFunctions) {
        // eslint-disable-next-line no-prototype-builtins
        if (mathFunctions.hasOwnProperty(f)) {
            mathFunctions[f] = math_helper_js_1.default.bind(null, Math[f], mathFunctions[f]);
        }
    }
    mathFunctions.round = function (n, f) {
        var fraction = typeof f === 'undefined' ? 0 : f.value;
        return math_helper_js_1.default(function (num) { return num.toFixed(fraction); }, null, n);
    };
    exports.default = mathFunctions;
    
},
/* less/lib/less/functions/math-helper.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var dimension_1 = tslib_1.__importDefault(require(150) /* ../tree/dimension */);
    var MathHelper = function (fn, unit, n) {
        if (!(n instanceof dimension_1.default)) {
            throw { type: 'Argument', message: 'argument must be a number' };
        }
        if (unit === null) {
            unit = n.unit;
        }
        else {
            n = n.unify();
        }
        return new dimension_1.default(fn(parseFloat(n.value)), unit);
    };
    exports.default = MathHelper;
    
},
/* less/lib/less/functions/number.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var dimension_1 = tslib_1.__importDefault(require(150) /* ../tree/dimension */);
    var anonymous_1 = tslib_1.__importDefault(require(144) /* ../tree/anonymous */);
    var math_helper_js_1 = tslib_1.__importDefault(require(184) /* ./math-helper.js */);
    var minMax = function (isMin, args) {
        var _this = this;
        args = Array.prototype.slice.call(args);
        switch (args.length) {
            case 0: throw { type: 'Argument', message: 'one or more arguments required' };
        }
        var i; // key is the unit.toString() for unified Dimension values,
        var j;
        var current;
        var currentUnified;
        var referenceUnified;
        var unit;
        var unitStatic;
        var unitClone;
        var // elems only contains original argument values.
        order = [];
        var values = {};
        // value is the index into the order array.
        for (i = 0; i < args.length; i++) {
            current = args[i];
            if (!(current instanceof dimension_1.default)) {
                if (Array.isArray(args[i].value)) {
                    Array.prototype.push.apply(args, Array.prototype.slice.call(args[i].value));
                }
                continue;
            }
            currentUnified = current.unit.toString() === '' && unitClone !== undefined ? new dimension_1.default(current.value, unitClone).unify() : current.unify();
            unit = currentUnified.unit.toString() === '' && unitStatic !== undefined ? unitStatic : currentUnified.unit.toString();
            unitStatic = unit !== '' && unitStatic === undefined || unit !== '' && order[0].unify().unit.toString() === '' ? unit : unitStatic;
            unitClone = unit !== '' && unitClone === undefined ? current.unit.toString() : unitClone;
            j = values[''] !== undefined && unit !== '' && unit === unitStatic ? values[''] : values[unit];
            if (j === undefined) {
                if (unitStatic !== undefined && unit !== unitStatic) {
                    throw { type: 'Argument', message: 'incompatible types' };
                }
                values[unit] = order.length;
                order.push(current);
                continue;
            }
            referenceUnified = order[j].unit.toString() === '' && unitClone !== undefined ? new dimension_1.default(order[j].value, unitClone).unify() : order[j].unify();
            if (isMin && currentUnified.value < referenceUnified.value ||
                !isMin && currentUnified.value > referenceUnified.value) {
                order[j] = current;
            }
        }
        if (order.length == 1) {
            return order[0];
        }
        args = order.map(function (a) { return a.toCSS(_this.context); }).join(this.context.compress ? ',' : ', ');
        return new anonymous_1.default((isMin ? 'min' : 'max') + "(" + args + ")");
    };
    exports.default = {
        min: function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            try {
                return minMax.call(this, true, args);
            }
            catch (e) { }
        },
        max: function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            try {
                return minMax.call(this, false, args);
            }
            catch (e) { }
        },
        convert: function (val, unit) {
            return val.convertTo(unit.value);
        },
        pi: function () {
            return new dimension_1.default(Math.PI);
        },
        mod: function (a, b) {
            return new dimension_1.default(a.value % b.value, a.unit);
        },
        pow: function (x, y) {
            if (typeof x === 'number' && typeof y === 'number') {
                x = new dimension_1.default(x);
                y = new dimension_1.default(y);
            }
            else if (!(x instanceof dimension_1.default) || !(y instanceof dimension_1.default)) {
                throw { type: 'Argument', message: 'arguments must be numbers' };
            }
            return new dimension_1.default(Math.pow(x.value, y.value), x.unit);
        },
        percentage: function (n) {
            var result = math_helper_js_1.default(function (num) { return num * 100; }, '%', n);
            return result;
        }
    };
    
},
/* less/lib/less/functions/string.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var quoted_1 = tslib_1.__importDefault(require(158) /* ../tree/quoted */);
    var anonymous_1 = tslib_1.__importDefault(require(144) /* ../tree/anonymous */);
    var javascript_1 = tslib_1.__importDefault(require(163) /* ../tree/javascript */);
    exports.default = {
        e: function (str) {
            return new quoted_1.default('"', str instanceof javascript_1.default ? str.evaluated : str.value, true);
        },
        escape: function (str) {
            return new anonymous_1.default(encodeURI(str.value).replace(/=/g, '%3D').replace(/:/g, '%3A').replace(/#/g, '%23').replace(/;/g, '%3B')
                .replace(/\(/g, '%28').replace(/\)/g, '%29'));
        },
        replace: function (string, pattern, replacement, flags) {
            var result = string.value;
            replacement = (replacement.type === 'Quoted') ?
                replacement.value : replacement.toCSS();
            result = result.replace(new RegExp(pattern.value, flags ? flags.value : ''), replacement);
            return new quoted_1.default(string.quote || '', result, string.escaped);
        },
        '%': function (string /* arg, arg, ... */) {
            var args = Array.prototype.slice.call(arguments, 1);
            var result = string.value;
            var _loop_1 = function (i) {
                /* jshint loopfunc:true */
                result = result.replace(/%[sda]/i, function (token) {
                    var value = ((args[i].type === 'Quoted') &&
                        token.match(/s/i)) ? args[i].value : args[i].toCSS();
                    return token.match(/[A-Z]$/) ? encodeURIComponent(value) : value;
                });
            };
            for (var i = 0; i < args.length; i++) {
                _loop_1(i);
            }
            result = result.replace(/%%/g, '%');
            return new quoted_1.default(string.quote || '', result, string.escaped);
        }
    };
    
},
/* less/lib/less/functions/svg.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var dimension_1 = tslib_1.__importDefault(require(150) /* ../tree/dimension */);
    var color_1 = tslib_1.__importDefault(require(115) /* ../tree/color */);
    var expression_1 = tslib_1.__importDefault(require(155) /* ../tree/expression */);
    var quoted_1 = tslib_1.__importDefault(require(158) /* ../tree/quoted */);
    var url_1 = tslib_1.__importDefault(require(159) /* ../tree/url */);
    exports.default = (function () {
        return { 'svg-gradient': function (direction) {
                var stops;
                var gradientDirectionSvg;
                var gradientType = 'linear';
                var rectangleDimension = 'x="0" y="0" width="1" height="1"';
                var renderEnv = { compress: false };
                var returner;
                var directionValue = direction.toCSS(renderEnv);
                var i;
                var color;
                var position;
                var positionValue;
                var alpha;
                function throwArgumentDescriptor() {
                    throw { type: 'Argument',
                        message: 'svg-gradient expects direction, start_color [start_position], [color position,]...,' +
                            ' end_color [end_position] or direction, color list' };
                }
                if (arguments.length == 2) {
                    if (arguments[1].value.length < 2) {
                        throwArgumentDescriptor();
                    }
                    stops = arguments[1].value;
                }
                else if (arguments.length < 3) {
                    throwArgumentDescriptor();
                }
                else {
                    stops = Array.prototype.slice.call(arguments, 1);
                }
                switch (directionValue) {
                    case 'to bottom':
                        gradientDirectionSvg = 'x1="0%" y1="0%" x2="0%" y2="100%"';
                        break;
                    case 'to right':
                        gradientDirectionSvg = 'x1="0%" y1="0%" x2="100%" y2="0%"';
                        break;
                    case 'to bottom right':
                        gradientDirectionSvg = 'x1="0%" y1="0%" x2="100%" y2="100%"';
                        break;
                    case 'to top right':
                        gradientDirectionSvg = 'x1="0%" y1="100%" x2="100%" y2="0%"';
                        break;
                    case 'ellipse':
                    case 'ellipse at center':
                        gradientType = 'radial';
                        gradientDirectionSvg = 'cx="50%" cy="50%" r="75%"';
                        rectangleDimension = 'x="-50" y="-50" width="101" height="101"';
                        break;
                    default:
                        throw { type: 'Argument', message: 'svg-gradient direction must be \'to bottom\', \'to right\',' +
                                ' \'to bottom right\', \'to top right\' or \'ellipse at center\'' };
                }
                returner = "<svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 1 1\"><" + gradientType + "Gradient id=\"g\" " + gradientDirectionSvg + ">";
                for (i = 0; i < stops.length; i += 1) {
                    if (stops[i] instanceof expression_1.default) {
                        color = stops[i].value[0];
                        position = stops[i].value[1];
                    }
                    else {
                        color = stops[i];
                        position = undefined;
                    }
                    if (!(color instanceof color_1.default) || (!((i === 0 || i + 1 === stops.length) && position === undefined) && !(position instanceof dimension_1.default))) {
                        throwArgumentDescriptor();
                    }
                    positionValue = position ? position.toCSS(renderEnv) : i === 0 ? '0%' : '100%';
                    alpha = color.alpha;
                    returner += "<stop offset=\"" + positionValue + "\" stop-color=\"" + color.toRGB() + "\"" + (alpha < 1 ? " stop-opacity=\"" + alpha + "\"" : '') + "/>";
                }
                returner += "</" + gradientType + "Gradient><rect " + rectangleDimension + " fill=\"url(#g)\" /></svg>";
                returner = encodeURIComponent(returner);
                returner = "data:image/svg+xml," + returner;
                return new url_1.default(new quoted_1.default("'" + returner + "'", returner, false, this.index, this.currentFileInfo), this.index, this.currentFileInfo);
            } };
    });
    
},
/* less/lib/less/functions/types.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var keyword_1 = tslib_1.__importDefault(require(143) /* ../tree/keyword */);
    var detached_ruleset_1 = tslib_1.__importDefault(require(148) /* ../tree/detached-ruleset */);
    var dimension_1 = tslib_1.__importDefault(require(150) /* ../tree/dimension */);
    var color_1 = tslib_1.__importDefault(require(115) /* ../tree/color */);
    var quoted_1 = tslib_1.__importDefault(require(158) /* ../tree/quoted */);
    var anonymous_1 = tslib_1.__importDefault(require(144) /* ../tree/anonymous */);
    var url_1 = tslib_1.__importDefault(require(159) /* ../tree/url */);
    var operation_1 = tslib_1.__importDefault(require(149) /* ../tree/operation */);
    var isa = function (n, Type) { return (n instanceof Type) ? keyword_1.default.True : keyword_1.default.False; };
    var isunit = function (n, unit) {
        if (unit === undefined) {
            throw { type: 'Argument', message: 'missing the required second argument to isunit.' };
        }
        unit = typeof unit.value === 'string' ? unit.value : unit;
        if (typeof unit !== 'string') {
            throw { type: 'Argument', message: 'Second argument to isunit should be a unit or a string.' };
        }
        return (n instanceof dimension_1.default) && n.unit.is(unit) ? keyword_1.default.True : keyword_1.default.False;
    };
    exports.default = {
        isruleset: function (n) {
            return isa(n, detached_ruleset_1.default);
        },
        iscolor: function (n) {
            return isa(n, color_1.default);
        },
        isnumber: function (n) {
            return isa(n, dimension_1.default);
        },
        isstring: function (n) {
            return isa(n, quoted_1.default);
        },
        iskeyword: function (n) {
            return isa(n, keyword_1.default);
        },
        isurl: function (n) {
            return isa(n, url_1.default);
        },
        ispixel: function (n) {
            return isunit(n, 'px');
        },
        ispercentage: function (n) {
            return isunit(n, '%');
        },
        isem: function (n) {
            return isunit(n, 'em');
        },
        isunit: isunit,
        unit: function (val, unit) {
            if (!(val instanceof dimension_1.default)) {
                throw { type: 'Argument',
                    message: "the first argument to unit must be a number" + (val instanceof operation_1.default ? '. Have you forgotten parenthesis?' : '') };
            }
            if (unit) {
                if (unit instanceof keyword_1.default) {
                    unit = unit.value;
                }
                else {
                    unit = unit.toCSS();
                }
            }
            else {
                unit = '';
            }
            return new dimension_1.default(val.value, unit);
        },
        'get-unit': function (n) {
            return new anonymous_1.default(n.unit);
        }
    };
    
},
/* less/lib/less/transform-tree.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var contexts_1 = tslib_1.__importDefault(require(130) /* ./contexts */);
    var visitors_1 = tslib_1.__importDefault(require(127) /* ./visitors */);
    var tree_1 = tslib_1.__importDefault(require(113) /* ./tree */);
    function default_1(root, options) {
        options = options || {};
        var evaldRoot;
        var variables = options.variables;
        var evalEnv = new contexts_1.default.Eval(options);
        //
        // Allows setting variables with a hash, so:
        //
        //   `{ color: new tree.Color('#f01') }` will become:
        //
        //   new tree.Declaration('@color',
        //     new tree.Value([
        //       new tree.Expression([
        //         new tree.Color('#f01')
        //       ])
        //     ])
        //   )
        //
        if (typeof variables === 'object' && !Array.isArray(variables)) {
            variables = Object.keys(variables).map(function (k) {
                var value = variables[k];
                if (!(value instanceof tree_1.default.Value)) {
                    if (!(value instanceof tree_1.default.Expression)) {
                        value = new tree_1.default.Expression([value]);
                    }
                    value = new tree_1.default.Value([value]);
                }
                return new tree_1.default.Declaration("@" + k, value, false, null, 0);
            });
            evalEnv.frames = [new tree_1.default.Ruleset(null, variables)];
        }
        var visitors = [
            new visitors_1.default.JoinSelectorVisitor(),
            new visitors_1.default.MarkVisibleSelectorsVisitor(true),
            new visitors_1.default.ExtendVisitor(),
            new visitors_1.default.ToCSSVisitor({ compress: Boolean(options.compress) })
        ];
        var preEvalVisitors = [];
        var v;
        var visitorIterator;
        /**
         * first() / get() allows visitors to be added while visiting
         *
         * @todo Add scoping for visitors just like functions for @plugin; right now they're global
         */
        if (options.pluginManager) {
            visitorIterator = options.pluginManager.visitor();
            for (var i = 0; i < 2; i++) {
                visitorIterator.first();
                while ((v = visitorIterator.get())) {
                    if (v.isPreEvalVisitor) {
                        if (i === 0 || preEvalVisitors.indexOf(v) === -1) {
                            preEvalVisitors.push(v);
                            v.run(root);
                        }
                    }
                    else {
                        if (i === 0 || visitors.indexOf(v) === -1) {
                            if (v.isPreVisitor) {
                                visitors.unshift(v);
                            }
                            else {
                                visitors.push(v);
                            }
                        }
                    }
                }
            }
        }
        evaldRoot = root.eval(evalEnv);
        for (var i = 0; i < visitors.length; i++) {
            visitors[i].run(evaldRoot);
        }
        // Run any remaining visitors added after eval pass
        if (options.pluginManager) {
            visitorIterator.first();
            while ((v = visitorIterator.get())) {
                if (visitors.indexOf(v) === -1 && preEvalVisitors.indexOf(v) === -1) {
                    v.run(evaldRoot);
                }
            }
        }
        return evaldRoot;
    }
    exports.default = default_1;
    
},
/* less/lib/less/plugin-manager.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    /**
     * Plugin Manager
     */
    var PluginManager = /** @class */ (function () {
        function PluginManager(less) {
            this.less = less;
            this.visitors = [];
            this.preProcessors = [];
            this.postProcessors = [];
            this.installedPlugins = [];
            this.fileManagers = [];
            this.iterator = -1;
            this.pluginCache = {};
            this.Loader = new less.PluginLoader(less);
        }
        /**
         * Adds all the plugins in the array
         * @param {Array} plugins
         */
        PluginManager.prototype.addPlugins = function (plugins) {
            if (plugins) {
                for (var i = 0; i < plugins.length; i++) {
                    this.addPlugin(plugins[i]);
                }
            }
        };
        /**
         *
         * @param plugin
         * @param {String} filename
         */
        PluginManager.prototype.addPlugin = function (plugin, filename, functionRegistry) {
            this.installedPlugins.push(plugin);
            if (filename) {
                this.pluginCache[filename] = plugin;
            }
            if (plugin.install) {
                plugin.install(this.less, this, functionRegistry || this.less.functions.functionRegistry);
            }
        };
        /**
         *
         * @param filename
         */
        PluginManager.prototype.get = function (filename) {
            return this.pluginCache[filename];
        };
        /**
         * Adds a visitor. The visitor object has options on itself to determine
         * when it should run.
         * @param visitor
         */
        PluginManager.prototype.addVisitor = function (visitor) {
            this.visitors.push(visitor);
        };
        /**
         * Adds a pre processor object
         * @param {object} preProcessor
         * @param {number} priority - guidelines 1 = before import, 1000 = import, 2000 = after import
         */
        PluginManager.prototype.addPreProcessor = function (preProcessor, priority) {
            var indexToInsertAt;
            for (indexToInsertAt = 0; indexToInsertAt < this.preProcessors.length; indexToInsertAt++) {
                if (this.preProcessors[indexToInsertAt].priority >= priority) {
                    break;
                }
            }
            this.preProcessors.splice(indexToInsertAt, 0, { preProcessor: preProcessor, priority: priority });
        };
        /**
         * Adds a post processor object
         * @param {object} postProcessor
         * @param {number} priority - guidelines 1 = before compression, 1000 = compression, 2000 = after compression
         */
        PluginManager.prototype.addPostProcessor = function (postProcessor, priority) {
            var indexToInsertAt;
            for (indexToInsertAt = 0; indexToInsertAt < this.postProcessors.length; indexToInsertAt++) {
                if (this.postProcessors[indexToInsertAt].priority >= priority) {
                    break;
                }
            }
            this.postProcessors.splice(indexToInsertAt, 0, { postProcessor: postProcessor, priority: priority });
        };
        /**
         *
         * @param manager
         */
        PluginManager.prototype.addFileManager = function (manager) {
            this.fileManagers.push(manager);
        };
        /**
         *
         * @returns {Array}
         * @private
         */
        PluginManager.prototype.getPreProcessors = function () {
            var preProcessors = [];
            for (var i = 0; i < this.preProcessors.length; i++) {
                preProcessors.push(this.preProcessors[i].preProcessor);
            }
            return preProcessors;
        };
        /**
         *
         * @returns {Array}
         * @private
         */
        PluginManager.prototype.getPostProcessors = function () {
            var postProcessors = [];
            for (var i = 0; i < this.postProcessors.length; i++) {
                postProcessors.push(this.postProcessors[i].postProcessor);
            }
            return postProcessors;
        };
        /**
         *
         * @returns {Array}
         * @private
         */
        PluginManager.prototype.getVisitors = function () {
            return this.visitors;
        };
        PluginManager.prototype.visitor = function () {
            var self = this;
            return {
                first: function () {
                    self.iterator = -1;
                    return self.visitors[self.iterator];
                },
                get: function () {
                    self.iterator += 1;
                    return self.visitors[self.iterator];
                }
            };
        };
        /**
         *
         * @returns {Array}
         * @private
         */
        PluginManager.prototype.getFileManagers = function () {
            return this.fileManagers;
        };
        return PluginManager;
    }());
    var pm;
    var PluginManagerFactory = function (less, newFactory) {
        if (newFactory || !pm) {
            pm = new PluginManager(less);
        }
        return pm;
    };
    //
    exports.default = PluginManagerFactory;
    
},
/* less/lib/less/source-map-output.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    function default_1(environment) {
        var SourceMapOutput = /** @class */ (function () {
            function SourceMapOutput(options) {
                this._css = [];
                this._rootNode = options.rootNode;
                this._contentsMap = options.contentsMap;
                this._contentsIgnoredCharsMap = options.contentsIgnoredCharsMap;
                if (options.sourceMapFilename) {
                    this._sourceMapFilename = options.sourceMapFilename.replace(/\\/g, '/');
                }
                this._outputFilename = options.outputFilename;
                this.sourceMapURL = options.sourceMapURL;
                if (options.sourceMapBasepath) {
                    this._sourceMapBasepath = options.sourceMapBasepath.replace(/\\/g, '/');
                }
                if (options.sourceMapRootpath) {
                    this._sourceMapRootpath = options.sourceMapRootpath.replace(/\\/g, '/');
                    if (this._sourceMapRootpath.charAt(this._sourceMapRootpath.length - 1) !== '/') {
                        this._sourceMapRootpath += '/';
                    }
                }
                else {
                    this._sourceMapRootpath = '';
                }
                this._outputSourceFiles = options.outputSourceFiles;
                this._sourceMapGeneratorConstructor = environment.getSourceMapGenerator();
                this._lineNumber = 0;
                this._column = 0;
            }
            SourceMapOutput.prototype.removeBasepath = function (path) {
                if (this._sourceMapBasepath && path.indexOf(this._sourceMapBasepath) === 0) {
                    path = path.substring(this._sourceMapBasepath.length);
                    if (path.charAt(0) === '\\' || path.charAt(0) === '/') {
                        path = path.substring(1);
                    }
                }
                return path;
            };
            SourceMapOutput.prototype.normalizeFilename = function (filename) {
                filename = filename.replace(/\\/g, '/');
                filename = this.removeBasepath(filename);
                return (this._sourceMapRootpath || '') + filename;
            };
            SourceMapOutput.prototype.add = function (chunk, fileInfo, index, mapLines) {
                // ignore adding empty strings
                if (!chunk) {
                    return;
                }
                var lines, sourceLines, columns, sourceColumns, i;
                if (fileInfo && fileInfo.filename) {
                    var inputSource = this._contentsMap[fileInfo.filename];
                    // remove vars/banner added to the top of the file
                    if (this._contentsIgnoredCharsMap[fileInfo.filename]) {
                        // adjust the index
                        index -= this._contentsIgnoredCharsMap[fileInfo.filename];
                        if (index < 0) {
                            index = 0;
                        }
                        // adjust the source
                        inputSource = inputSource.slice(this._contentsIgnoredCharsMap[fileInfo.filename]);
                    }
                    /**
                     * ignore empty content, or failsafe
                     * if contents map is incorrect
                     */
                    if (inputSource === undefined) {
                        this._css.push(chunk);
                        return;
                    }
                    inputSource = inputSource.substring(0, index);
                    sourceLines = inputSource.split('\n');
                    sourceColumns = sourceLines[sourceLines.length - 1];
                }
                lines = chunk.split('\n');
                columns = lines[lines.length - 1];
                if (fileInfo && fileInfo.filename) {
                    if (!mapLines) {
                        this._sourceMapGenerator.addMapping({ generated: { line: this._lineNumber + 1, column: this._column },
                            original: { line: sourceLines.length, column: sourceColumns.length },
                            source: this.normalizeFilename(fileInfo.filename) });
                    }
                    else {
                        for (i = 0; i < lines.length; i++) {
                            this._sourceMapGenerator.addMapping({ generated: { line: this._lineNumber + i + 1, column: i === 0 ? this._column : 0 },
                                original: { line: sourceLines.length + i, column: i === 0 ? sourceColumns.length : 0 },
                                source: this.normalizeFilename(fileInfo.filename) });
                        }
                    }
                }
                if (lines.length === 1) {
                    this._column += columns.length;
                }
                else {
                    this._lineNumber += lines.length - 1;
                    this._column = columns.length;
                }
                this._css.push(chunk);
            };
            SourceMapOutput.prototype.isEmpty = function () {
                return this._css.length === 0;
            };
            SourceMapOutput.prototype.toCSS = function (context) {
                this._sourceMapGenerator = new this._sourceMapGeneratorConstructor({ file: this._outputFilename, sourceRoot: null });
                if (this._outputSourceFiles) {
                    for (var filename in this._contentsMap) {
                        // eslint-disable-next-line no-prototype-builtins
                        if (this._contentsMap.hasOwnProperty(filename)) {
                            var source = this._contentsMap[filename];
                            if (this._contentsIgnoredCharsMap[filename]) {
                                source = source.slice(this._contentsIgnoredCharsMap[filename]);
                            }
                            this._sourceMapGenerator.setSourceContent(this.normalizeFilename(filename), source);
                        }
                    }
                }
                this._rootNode.genCSS(context, this);
                if (this._css.length > 0) {
                    var sourceMapURL = void 0;
                    var sourceMapContent = JSON.stringify(this._sourceMapGenerator.toJSON());
                    if (this.sourceMapURL) {
                        sourceMapURL = this.sourceMapURL;
                    }
                    else if (this._sourceMapFilename) {
                        sourceMapURL = this._sourceMapFilename;
                    }
                    this.sourceMapURL = sourceMapURL;
                    this.sourceMap = sourceMapContent;
                }
                return this._css.join('');
            };
            return SourceMapOutput;
        }());
        return SourceMapOutput;
    }
    exports.default = default_1;
    
},
/* less/lib/less/source-map-builder.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    function default_1(SourceMapOutput, environment) {
        var SourceMapBuilder = /** @class */ (function () {
            function SourceMapBuilder(options) {
                this.options = options;
            }
            SourceMapBuilder.prototype.toCSS = function (rootNode, options, imports) {
                var sourceMapOutput = new SourceMapOutput({
                    contentsIgnoredCharsMap: imports.contentsIgnoredChars,
                    rootNode: rootNode,
                    contentsMap: imports.contents,
                    sourceMapFilename: this.options.sourceMapFilename,
                    sourceMapURL: this.options.sourceMapURL,
                    outputFilename: this.options.sourceMapOutputFilename,
                    sourceMapBasepath: this.options.sourceMapBasepath,
                    sourceMapRootpath: this.options.sourceMapRootpath,
                    outputSourceFiles: this.options.outputSourceFiles,
                    sourceMapGenerator: this.options.sourceMapGenerator,
                    sourceMapFileInline: this.options.sourceMapFileInline,
                    disableSourcemapAnnotation: this.options.disableSourcemapAnnotation
                });
                var css = sourceMapOutput.toCSS(options);
                this.sourceMap = sourceMapOutput.sourceMap;
                this.sourceMapURL = sourceMapOutput.sourceMapURL;
                if (this.options.sourceMapInputFilename) {
                    this.sourceMapInputFilename = sourceMapOutput.normalizeFilename(this.options.sourceMapInputFilename);
                }
                if (this.options.sourceMapBasepath !== undefined && this.sourceMapURL !== undefined) {
                    this.sourceMapURL = sourceMapOutput.removeBasepath(this.sourceMapURL);
                }
                return css + this.getCSSAppendage();
            };
            SourceMapBuilder.prototype.getCSSAppendage = function () {
                var sourceMapURL = this.sourceMapURL;
                if (this.options.sourceMapFileInline) {
                    if (this.sourceMap === undefined) {
                        return '';
                    }
                    sourceMapURL = "data:application/json;base64," + environment.encodeBase64(this.sourceMap);
                }
                if (this.options.disableSourcemapAnnotation) {
                    return '';
                }
                if (sourceMapURL) {
                    return "/*# sourceMappingURL=" + sourceMapURL + " */";
                }
                return '';
            };
            SourceMapBuilder.prototype.getExternalSourceMap = function () {
                return this.sourceMap;
            };
            SourceMapBuilder.prototype.setExternalSourceMap = function (sourceMap) {
                this.sourceMap = sourceMap;
            };
            SourceMapBuilder.prototype.isInline = function () {
                return this.options.sourceMapFileInline;
            };
            SourceMapBuilder.prototype.getSourceMapURL = function () {
                return this.sourceMapURL;
            };
            SourceMapBuilder.prototype.getOutputFilename = function () {
                return this.options.sourceMapOutputFilename;
            };
            SourceMapBuilder.prototype.getInputFilename = function () {
                return this.sourceMapInputFilename;
            };
            return SourceMapBuilder;
        }());
        return SourceMapBuilder;
    }
    exports.default = default_1;
    
},
/* less/lib/less/parse-tree.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var less_error_1 = tslib_1.__importDefault(require(121) /* ./less-error */);
    var transform_tree_1 = tslib_1.__importDefault(require(189) /* ./transform-tree */);
    var logger_1 = tslib_1.__importDefault(require(75) /* ./logger */);
    function default_1(SourceMapBuilder) {
        var ParseTree = /** @class */ (function () {
            function ParseTree(root, imports) {
                this.root = root;
                this.imports = imports;
            }
            ParseTree.prototype.toCSS = function (options) {
                var evaldRoot;
                var result = {};
                var sourceMapBuilder;
                try {
                    evaldRoot = transform_tree_1.default(this.root, options);
                }
                catch (e) {
                    throw new less_error_1.default(e, this.imports);
                }
                try {
                    var compress = Boolean(options.compress);
                    if (compress) {
                        logger_1.default.warn('The compress option has been deprecated. ' +
                            'We recommend you use a dedicated css minifier, for instance see less-plugin-clean-css.');
                    }
                    var toCSSOptions = {
                        compress: compress,
                        dumpLineNumbers: options.dumpLineNumbers,
                        strictUnits: Boolean(options.strictUnits),
                        numPrecision: 8
                    };
                    if (options.sourceMap) {
                        sourceMapBuilder = new SourceMapBuilder(options.sourceMap);
                        result.css = sourceMapBuilder.toCSS(evaldRoot, toCSSOptions, this.imports);
                    }
                    else {
                        result.css = evaldRoot.toCSS(toCSSOptions);
                    }
                }
                catch (e) {
                    throw new less_error_1.default(e, this.imports);
                }
                if (options.pluginManager) {
                    var postProcessors = options.pluginManager.getPostProcessors();
                    for (var i = 0; i < postProcessors.length; i++) {
                        result.css = postProcessors[i].process(result.css, { sourceMap: sourceMapBuilder, options: options, imports: this.imports });
                    }
                }
                if (options.sourceMap) {
                    result.map = sourceMapBuilder.getExternalSourceMap();
                }
                result.imports = [];
                for (var file in this.imports.files) {
                    if (Object.prototype.hasOwnProperty.call(this.imports.files, file) && file !== this.imports.rootFilename) {
                        result.imports.push(file);
                    }
                }
                return result;
            };
            return ParseTree;
        }());
        return ParseTree;
    }
    exports.default = default_1;
    
},
/* less/lib/less/import-manager.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var contexts_1 = tslib_1.__importDefault(require(130) /* ./contexts */);
    var parser_1 = tslib_1.__importDefault(require(126) /* ./parser/parser */);
    var less_error_1 = tslib_1.__importDefault(require(121) /* ./less-error */);
    var utils = tslib_1.__importStar(require(122) /* ./utils */);
    var logger_1 = tslib_1.__importDefault(require(75) /* ./logger */);
    function default_1(environment) {
        // FileInfo = {
        //  'rewriteUrls' - option - whether to adjust URL's to be relative
        //  'filename' - full resolved filename of current file
        //  'rootpath' - path to append to normal URLs for this node
        //  'currentDirectory' - path to the current file, absolute
        //  'rootFilename' - filename of the base file
        //  'entryPath' - absolute path to the entry file
        //  'reference' - whether the file should not be output and only output parts that are referenced
        var ImportManager = /** @class */ (function () {
            function ImportManager(less, context, rootFileInfo) {
                this.less = less;
                this.rootFilename = rootFileInfo.filename;
                this.paths = context.paths || []; // Search paths, when importing
                this.contents = {}; // map - filename to contents of all the files
                this.contentsIgnoredChars = {}; // map - filename to lines at the beginning of each file to ignore
                this.mime = context.mime;
                this.error = null;
                this.context = context;
                // Deprecated? Unused outside of here, could be useful.
                this.queue = []; // Files which haven't been imported yet
                this.files = {}; // Holds the imported parse trees.
            }
            /**
             * Add an import to be imported
             * @param path - the raw path
             * @param tryAppendExtension - whether to try appending a file extension (.less or .js if the path has no extension)
             * @param currentFileInfo - the current file info (used for instance to work out relative paths)
             * @param importOptions - import options
             * @param callback - callback for when it is imported
             */
            ImportManager.prototype.push = function (path, tryAppendExtension, currentFileInfo, importOptions, callback) {
                var importManager = this, pluginLoader = this.context.pluginManager.Loader;
                this.queue.push(path);
                var fileParsedFunc = function (e, root, fullPath) {
                    importManager.queue.splice(importManager.queue.indexOf(path), 1); // Remove the path from the queue
                    var importedEqualsRoot = fullPath === importManager.rootFilename;
                    if (importOptions.optional && e) {
                        callback(null, { rules: [] }, false, null);
                        logger_1.default.info("The file " + fullPath + " was skipped because it was not found and the import was marked optional.");
                    }
                    else {
                        // Inline imports aren't cached here.
                        // If we start to cache them, please make sure they won't conflict with non-inline imports of the
                        // same name as they used to do before this comment and the condition below have been added.
                        if (!importManager.files[fullPath] && !importOptions.inline) {
                            importManager.files[fullPath] = { root: root, options: importOptions };
                        }
                        if (e && !importManager.error) {
                            importManager.error = e;
                        }
                        callback(e, root, importedEqualsRoot, fullPath);
                    }
                };
                var newFileInfo = {
                    rewriteUrls: this.context.rewriteUrls,
                    entryPath: currentFileInfo.entryPath,
                    rootpath: currentFileInfo.rootpath,
                    rootFilename: currentFileInfo.rootFilename
                };
                var fileManager = environment.getFileManager(path, currentFileInfo.currentDirectory, this.context, environment);
                if (!fileManager) {
                    fileParsedFunc({ message: "Could not find a file-manager for " + path });
                    return;
                }
                var loadFileCallback = function (loadedFile) {
                    var plugin;
                    var resolvedFilename = loadedFile.filename;
                    var contents = loadedFile.contents.replace(/^\uFEFF/, '');
                    // Pass on an updated rootpath if path of imported file is relative and file
                    // is in a (sub|sup) directory
                    //
                    // Examples:
                    // - If path of imported file is 'module/nav/nav.less' and rootpath is 'less/',
                    //   then rootpath should become 'less/module/nav/'
                    // - If path of imported file is '../mixins.less' and rootpath is 'less/',
                    //   then rootpath should become 'less/../'
                    newFileInfo.currentDirectory = fileManager.getPath(resolvedFilename);
                    if (newFileInfo.rewriteUrls) {
                        newFileInfo.rootpath = fileManager.join((importManager.context.rootpath || ''), fileManager.pathDiff(newFileInfo.currentDirectory, newFileInfo.entryPath));
                        if (!fileManager.isPathAbsolute(newFileInfo.rootpath) && fileManager.alwaysMakePathsAbsolute()) {
                            newFileInfo.rootpath = fileManager.join(newFileInfo.entryPath, newFileInfo.rootpath);
                        }
                    }
                    newFileInfo.filename = resolvedFilename;
                    var newEnv = new contexts_1.default.Parse(importManager.context);
                    newEnv.processImports = false;
                    importManager.contents[resolvedFilename] = contents;
                    if (currentFileInfo.reference || importOptions.reference) {
                        newFileInfo.reference = true;
                    }
                    if (importOptions.isPlugin) {
                        plugin = pluginLoader.evalPlugin(contents, newEnv, importManager, importOptions.pluginArgs, newFileInfo);
                        if (plugin instanceof less_error_1.default) {
                            fileParsedFunc(plugin, null, resolvedFilename);
                        }
                        else {
                            fileParsedFunc(null, plugin, resolvedFilename);
                        }
                    }
                    else if (importOptions.inline) {
                        fileParsedFunc(null, contents, resolvedFilename);
                    }
                    else {
                        // import (multiple) parse trees apparently get altered and can't be cached.
                        // TODO: investigate why this is
                        if (importManager.files[resolvedFilename]
                            && !importManager.files[resolvedFilename].options.multiple
                            && !importOptions.multiple) {
                            fileParsedFunc(null, importManager.files[resolvedFilename].root, resolvedFilename);
                        }
                        else {
                            new parser_1.default(newEnv, importManager, newFileInfo).parse(contents, function (e, root) {
                                fileParsedFunc(e, root, resolvedFilename);
                            });
                        }
                    }
                };
                var loadedFile;
                var promise;
                var context = utils.clone(this.context);
                if (tryAppendExtension) {
                    context.ext = importOptions.isPlugin ? '.js' : '.less';
                }
                if (importOptions.isPlugin) {
                    context.mime = 'application/javascript';
                    if (context.syncImport) {
                        loadedFile = pluginLoader.loadPluginSync(path, currentFileInfo.currentDirectory, context, environment, fileManager);
                    }
                    else {
                        promise = pluginLoader.loadPlugin(path, currentFileInfo.currentDirectory, context, environment, fileManager);
                    }
                }
                else {
                    if (context.syncImport) {
                        loadedFile = fileManager.loadFileSync(path, currentFileInfo.currentDirectory, context, environment);
                    }
                    else {
                        promise = fileManager.loadFile(path, currentFileInfo.currentDirectory, context, environment, function (err, loadedFile) {
                            if (err) {
                                fileParsedFunc(err);
                            }
                            else {
                                loadFileCallback(loadedFile);
                            }
                        });
                    }
                }
                if (loadedFile) {
                    if (!loadedFile.filename) {
                        fileParsedFunc(loadedFile);
                    }
                    else {
                        loadFileCallback(loadedFile);
                    }
                }
                else if (promise) {
                    promise.then(loadFileCallback, fileParsedFunc);
                }
            };
            return ImportManager;
        }());
        return ImportManager;
    }
    exports.default = default_1;
    
},
/* less/lib/less/parse.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var contexts_1 = tslib_1.__importDefault(require(130) /* ./contexts */);
    var parser_1 = tslib_1.__importDefault(require(126) /* ./parser/parser */);
    var plugin_manager_1 = tslib_1.__importDefault(require(190) /* ./plugin-manager */);
    var less_error_1 = tslib_1.__importDefault(require(121) /* ./less-error */);
    var utils = tslib_1.__importStar(require(122) /* ./utils */);
    function default_1(environment, ParseTree, ImportManager) {
        var parse = function (input, options, callback) {
            if (typeof options === 'function') {
                callback = options;
                options = utils.copyOptions(this.options, {});
            }
            else {
                options = utils.copyOptions(this.options, options || {});
            }
            if (!callback) {
                var self_1 = this;
                return new Promise(function (resolve, reject) {
                    parse.call(self_1, input, options, function (err, output) {
                        if (err) {
                            reject(err);
                        }
                        else {
                            resolve(output);
                        }
                    });
                });
            }
            else {
                var context_1;
                var rootFileInfo = void 0;
                var pluginManager_1 = new plugin_manager_1.default(this, !options.reUsePluginManager);
                options.pluginManager = pluginManager_1;
                context_1 = new contexts_1.default.Parse(options);
                if (options.rootFileInfo) {
                    rootFileInfo = options.rootFileInfo;
                }
                else {
                    var filename = options.filename || 'input';
                    var entryPath = filename.replace(/[^/\\]*$/, '');
                    rootFileInfo = {
                        filename: filename,
                        rewriteUrls: context_1.rewriteUrls,
                        rootpath: context_1.rootpath || '',
                        currentDirectory: entryPath,
                        entryPath: entryPath,
                        rootFilename: filename
                    };
                    // add in a missing trailing slash
                    if (rootFileInfo.rootpath && rootFileInfo.rootpath.slice(-1) !== '/') {
                        rootFileInfo.rootpath += '/';
                    }
                }
                var imports_1 = new ImportManager(this, context_1, rootFileInfo);
                this.importManager = imports_1;
                // TODO: allow the plugins to be just a list of paths or names
                // Do an async plugin queue like lessc
                if (options.plugins) {
                    options.plugins.forEach(function (plugin) {
                        var evalResult, contents;
                        if (plugin.fileContent) {
                            contents = plugin.fileContent.replace(/^\uFEFF/, '');
                            evalResult = pluginManager_1.Loader.evalPlugin(contents, context_1, imports_1, plugin.options, plugin.filename);
                            if (evalResult instanceof less_error_1.default) {
                                return callback(evalResult);
                            }
                        }
                        else {
                            pluginManager_1.addPlugin(plugin);
                        }
                    });
                }
                new parser_1.default(context_1, imports_1, rootFileInfo)
                    .parse(input, function (e, root) {
                    if (e) {
                        return callback(e);
                    }
                    callback(null, root, imports_1, options);
                }, options);
            }
        };
        return parse;
    }
    exports.default = default_1;
    
},
/* less/lib/less/render.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var utils = tslib_1.__importStar(require(122) /* ./utils */);
    function default_1(environment, ParseTree) {
        var render = function (input, options, callback) {
            if (typeof options === 'function') {
                callback = options;
                options = utils.copyOptions(this.options, {});
            }
            else {
                options = utils.copyOptions(this.options, options || {});
            }
            if (!callback) {
                var self_1 = this;
                return new Promise(function (resolve, reject) {
                    render.call(self_1, input, options, function (err, output) {
                        if (err) {
                            reject(err);
                        }
                        else {
                            resolve(output);
                        }
                    });
                });
            }
            else {
                this.parse(input, options, function (err, root, imports, options) {
                    if (err) {
                        return callback(err);
                    }
                    var result;
                    try {
                        var parseTree = new ParseTree(root, imports);
                        result = parseTree.toCSS(options);
                    }
                    catch (err) {
                        return callback(err);
                    }
                    callback(null, result);
                });
            }
        };
        return render;
    }
    exports.default = default_1;
    
},
/* less/package.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = {
        "name": "less",
        "version": "4.2.0",
        "description": "Leaner CSS",
        "homepage": "http://lesscss.org",
        "author": {
            "name": "Alexis Sellier",
            "email": "self@cloudhead.net"
        },
        "contributors": [
            "The Core Less Team"
        ],
        "bugs": {
            "url": "https://github.com/less/less.js/issues"
        },
        "repository": {
            "type": "git",
            "url": "https://github.com/less/less.js.git"
        },
        "master": {
            "url": "https://github.com/less/less.js/blob/master/",
            "raw": "https://raw.githubusercontent.com/less/less.js/master/"
        },
        "license": "Apache-2.0",
        "bin": {
            "lessc": "./bin/lessc"
        },
        "main": "index",
        "module": "./lib/less-node/index",
        "directories": {
            "test": "./test"
        },
        "browser": "./dist/less.js",
        "engines": {
            "node": ">=6"
        },
        "scripts": {
            "test": "grunt test",
            "grunt": "grunt",
            "lint": "eslint '**/*.{ts,js}'",
            "lint:fix": "eslint '**/*.{ts,js}' --fix",
            "build": "npm-run-all clean compile",
            "clean": "shx rm -rf ./lib tsconfig.tsbuildinfo",
            "compile": "tsc -p tsconfig.build.json",
            "copy:root": "shx cp -rf ./dist ../../",
            "dev": "tsc -p tsconfig.build.json -w",
            "prepublishOnly": "grunt dist"
        },
        "optionalDependencies": {
            "errno": "^0.1.1",
            "graceful-fs": "^4.1.2",
            "image-size": "~0.5.0",
            "make-dir": "^2.1.0",
            "mime": "^1.4.1",
            "needle": "^3.1.0",
            "source-map": "~0.6.0"
        },
        "devDependencies": {
            "@less/test-data": "^4.2.0",
            "@less/test-import-module": "^4.0.0",
            "@rollup/plugin-commonjs": "^17.0.0",
            "@rollup/plugin-json": "^4.1.0",
            "@rollup/plugin-node-resolve": "^11.0.0",
            "@typescript-eslint/eslint-plugin": "^4.28.0",
            "@typescript-eslint/parser": "^4.28.0",
            "benny": "^3.6.12",
            "bootstrap-less-port": "0.3.0",
            "chai": "^4.2.0",
            "cross-env": "^7.0.3",
            "diff": "^3.2.0",
            "eslint": "^7.29.0",
            "fs-extra": "^8.1.0",
            "git-rev": "^0.2.1",
            "globby": "^10.0.1",
            "grunt": "^1.0.4",
            "grunt-cli": "^1.3.2",
            "grunt-contrib-clean": "^1.0.0",
            "grunt-contrib-connect": "^1.0.2",
            "grunt-eslint": "^23.0.0",
            "grunt-saucelabs": "^9.0.1",
            "grunt-shell": "^1.3.0",
            "html-template-tag": "^3.2.0",
            "jit-grunt": "^0.10.0",
            "less-plugin-autoprefix": "^1.5.1",
            "less-plugin-clean-css": "^1.5.1",
            "minimist": "^1.2.0",
            "mocha": "^6.2.1",
            "mocha-headless-chrome": "^4.0.0",
            "mocha-teamcity-reporter": "^3.0.0",
            "nock": "^11.8.2",
            "npm-run-all": "^4.1.5",
            "performance-now": "^0.2.0",
            "phin": "^2.2.3",
            "promise": "^7.1.1",
            "read-glob": "^3.0.0",
            "resolve": "^1.17.0",
            "rollup": "^2.52.2",
            "rollup-plugin-terser": "^5.1.1",
            "rollup-plugin-typescript2": "^0.29.0",
            "semver": "^6.3.0",
            "shx": "^0.3.2",
            "time-grunt": "^1.3.0",
            "ts-node": "^9.1.1",
            "typescript": "^4.3.4",
            "uikit": "2.27.4"
        },
        "keywords": [
            "compile less",
            "css nesting",
            "css variable",
            "css",
            "gradients css",
            "gradients css3",
            "less compiler",
            "less css",
            "less mixins",
            "less",
            "less.js",
            "lesscss",
            "mixins",
            "nested css",
            "parser",
            "preprocessor",
            "bootstrap css",
            "bootstrap less",
            "style",
            "styles",
            "stylesheet",
            "variables in css",
            "css less"
        ],
        "rawcurrent": "https://raw.github.com/less/less.js/v",
        "sourcearchive": "https://github.com/less/less.js/archive/v",
        "dependencies": {
            "copy-anything": "^2.0.1",
            "parse-node-version": "^1.0.1",
            "tslib": "^2.3.0"
        },
        "gitHead": "1df9072ee9ebdadc791bf35dfb1dbc3ef9f1948f"
    };
    module.exports = json;
},
/* parse-node-version/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    function parseNodeVersion(version) {
        var match = version.match(/^v(\d{1,2})\.(\d{1,2})\.(\d{1,2})(?:-([0-9A-Za-z-.]+))?(?:\+([0-9A-Za-z-.]+))?$/); // eslint-disable-line max-len
        if (!match) {
            throw new Error('Unable to parse: ' + version);
        }
        var res = {
            major: parseInt(match[1], 10),
            minor: parseInt(match[2], 10),
            patch: parseInt(match[3], 10),
            pre: match[4] || '',
            build: match[5] || '',
        };
        return res;
    }
    module.exports = parseNodeVersion;
},
/* less/lib/less-node/lessc-helper.js */ function _(require, module, exports, __esModule, __esExport) {
    // lessc_helper.js
    //
    //      helper functions for lessc
    var lessc_helper = {
        // Stylize a string
        stylize: function (str, style) {
            var styles = {
                'reset': [0, 0],
                'bold': [1, 22],
                'inverse': [7, 27],
                'underline': [4, 24],
                'yellow': [33, 39],
                'green': [32, 39],
                'red': [31, 39],
                'grey': [90, 39]
            };
            return "\u001B[" + styles[style][0] + "m" + str + "\u001B[" + styles[style][1] + "m";
        },
        // Print command line options
        printUsage: function () {
            console.log('usage: lessc [option option=parameter ...] <source> [destination]');
            console.log('');
            console.log('If source is set to `-\' (dash or hyphen-minus), input is read from stdin.');
            console.log('');
            console.log('options:');
            console.log('  -h, --help                   Prints help (this message) and exit.');
            console.log('  --include-path=PATHS         Sets include paths. Separated by `:\'. `;\' also supported on windows.');
            console.log('  -M, --depends                Outputs a makefile import dependency list to stdout.');
            console.log('  --no-color                   Disables colorized output.');
            console.log('  --ie-compat                  Enables IE8 compatibility checks.');
            console.log('  --js                         Enables inline JavaScript in less files');
            console.log('  -l, --lint                   Syntax check only (lint).');
            console.log('  -s, --silent                 Suppresses output of error messages.');
            console.log('  --strict-imports             Forces evaluation of imports.');
            console.log('  --insecure                   Allows imports from insecure https hosts.');
            console.log('  -v, --version                Prints version number and exit.');
            console.log('  --verbose                    Be verbose.');
            console.log('  --source-map[=FILENAME]      Outputs a v3 sourcemap to the filename (or output filename.map).');
            console.log('  --source-map-rootpath=X      Adds this path onto the sourcemap filename and less file paths.');
            console.log('  --source-map-basepath=X      Sets sourcemap base path, defaults to current working directory.');
            console.log('  --source-map-include-source  Puts the less files into the map instead of referencing them.');
            console.log('  --source-map-inline          Puts the map (and any less files) as a base64 data uri into the output css file.');
            console.log('  --source-map-url=URL         Sets a custom URL to map file, for sourceMappingURL comment');
            console.log('                               in generated CSS file.');
            console.log('  --source-map-no-annotation   Excludes the sourceMappingURL comment from the output css file.');
            console.log('  -rp, --rootpath=URL          Sets rootpath for url rewriting in relative imports and urls');
            console.log('                               Works with or without the relative-urls option.');
            console.log('  -ru=, --rewrite-urls=        Rewrites URLs to make them relative to the base less file.');
            console.log('    all|local|off              \'all\' rewrites all URLs, \'local\' just those starting with a \'.\'');
            console.log('');
            console.log('  -m=, --math=');
            console.log('     always                    Less will eagerly perform math operations always.');
            console.log('     parens-division           Math performed except for division (/) operator');
            console.log('     parens | strict           Math only performed inside parentheses');
            console.log('     strict-legacy             Parens required in very strict terms (legacy --strict-math)');
            console.log('');
            console.log('  -su=on|off                   Allows mixed units, e.g. 1px+1em or 1px*1px which have units');
            console.log('  --strict-units=on|off        that cannot be represented.');
            console.log('  --global-var=\'VAR=VALUE\'     Defines a variable that can be referenced by the file.');
            console.log('  --modify-var=\'VAR=VALUE\'     Modifies a variable already declared in the file.');
            console.log('  --url-args=\'QUERYSTRING\'     Adds params into url tokens (e.g. 42, cb=42 or \'a=1&b=2\')');
            console.log('  --plugin=PLUGIN=OPTIONS      Loads a plugin. You can also omit the --plugin= if the plugin begins');
            console.log('                               less-plugin. E.g. the clean css plugin is called less-plugin-clean-css');
            console.log('                               once installed (npm install less-plugin-clean-css), use either with');
            console.log('                               --plugin=less-plugin-clean-css or just --clean-css');
            console.log('                               specify options afterwards e.g. --plugin=less-plugin-clean-css="advanced"');
            console.log('                               or --clean-css="advanced"');
            console.log('  --disable-plugin-rule        Disallow @plugin statements');
            console.log('');
            console.log('-------------------------- Deprecated ----------------');
            console.log('  -sm=on|off               Legacy parens-only math. Use --math');
            console.log('  --strict-math=on|off     ');
            console.log('');
            console.log('  --line-numbers=TYPE      Outputs filename and line numbers.');
            console.log('                           TYPE can be either \'comments\', which will output');
            console.log('                           the debug info within comments, \'mediaquery\'');
            console.log('                           that will output the information within a fake');
            console.log('                           media query which is compatible with the SASS');
            console.log('                           format, and \'all\' which will do both.');
            console.log('  -x, --compress           Compresses output by removing some whitespaces.');
            console.log('                           We recommend you use a dedicated minifer like less-plugin-clean-css');
            console.log('');
            console.log('Report bugs to: http://github.com/less/less.js/issues');
            console.log('Home page: <http://lesscss.org/>');
        }
    };
    // Exports helper functions
    // eslint-disable-next-line no-prototype-builtins
    for (var h in lessc_helper) {
        if (lessc_helper.hasOwnProperty(h)) {
            exports[h] = lessc_helper[h];
        }
    }
    
},
/* less/lib/less-node/plugin-loader.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var path_1 = tslib_1.__importDefault(require("path"));
    var abstract_plugin_loader_js_1 = tslib_1.__importDefault(require(176) /* ../less/environment/abstract-plugin-loader.js */);
    /**
     * Node Plugin Loader
     */
    var PluginLoader = function (less) {
        this.less = less;
        this.require = function (prefix) {
            prefix = path_1.default.dirname(prefix);
            return function (id) {
                var str = id.substr(0, 2);
                if (str === '..' || str === './') {
                    return require(path_1.default.join(prefix, id));
                }
                else {
                    return require(id);
                }
            };
        };
    };
    PluginLoader.prototype = Object.assign(new abstract_plugin_loader_js_1.default(), {
        loadPlugin: function (filename, basePath, context, environment, fileManager) {
            var prefix = filename.slice(0, 1);
            var explicit = prefix === '.' || prefix === '/' || filename.slice(-3).toLowerCase() === '.js';
            if (!explicit) {
                context.prefixes = ['less-plugin-', ''];
            }
            if (context.syncImport) {
                return fileManager.loadFileSync(filename, basePath, context, environment);
            }
            return new Promise(function (fulfill, reject) {
                fileManager.loadFile(filename, basePath, context, environment).then(function (data) {
                    try {
                        fulfill(data);
                    }
                    catch (e) {
                        console.log(e);
                        reject(e);
                    }
                }).catch(function (err) {
                    reject(err);
                });
            });
        },
        loadPluginSync: function (filename, basePath, context, environment, fileManager) {
            context.syncImport = true;
            return this.loadPlugin(filename, basePath, context, environment, fileManager);
        }
    });
    exports.default = PluginLoader;
    
},
/* less/lib/less/default-options.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    // Export a new default each time
    function default_1() {
        return {
            /* Inline Javascript - @plugin still allowed */
            javascriptEnabled: false,
            /* Outputs a makefile import dependency list to stdout. */
            depends: false,
            /* (DEPRECATED) Compress using less built-in compression.
             * This does an okay job but does not utilise all the tricks of
             * dedicated css compression. */
            compress: false,
            /* Runs the less parser and just reports errors without any output. */
            lint: false,
            /* Sets available include paths.
             * If the file in an @import rule does not exist at that exact location,
             * less will look for it at the location(s) passed to this option.
             * You might use this for instance to specify a path to a library which
             * you want to be referenced simply and relatively in the less files. */
            paths: [],
            /* color output in the terminal */
            color: true,
            /* The strictImports controls whether the compiler will allow an @import inside of either
             * @media blocks or (a later addition) other selector blocks.
             * See: https://github.com/less/less.js/issues/656 */
            strictImports: false,
            /* Allow Imports from Insecure HTTPS Hosts */
            insecure: false,
            /* Allows you to add a path to every generated import and url in your css.
             * This does not affect less import statements that are processed, just ones
             * that are left in the output css. */
            rootpath: '',
            /* By default URLs are kept as-is, so if you import a file in a sub-directory
             * that references an image, exactly the same URL will be output in the css.
             * This option allows you to re-write URL's in imported files so that the
             * URL is always relative to the base imported file */
            rewriteUrls: false,
            /* How to process math
             *   0 always           - eagerly try to solve all operations
             *   1 parens-division  - require parens for division "/"
             *   2 parens | strict  - require parens for all operations
             *   3 strict-legacy    - legacy strict behavior (super-strict)
             */
            math: 1,
            /* Without this option, less attempts to guess at the output unit when it does maths. */
            strictUnits: false,
            /* Effectively the declaration is put at the top of your base Less file,
             * meaning it can be used but it also can be overridden if this variable
             * is defined in the file. */
            globalVars: null,
            /* As opposed to the global variable option, this puts the declaration at the
             * end of your base file, meaning it will override anything defined in your Less file. */
            modifyVars: null,
            /* This option allows you to specify a argument to go on to every URL.  */
            urlArgs: ''
        };
    }
    exports.default = default_1;
    
},
/* less/lib/less-node/image-size.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require(63) /* tslib */;
    var dimension_1 = tslib_1.__importDefault(require(150) /* ../less/tree/dimension */);
    var expression_1 = tslib_1.__importDefault(require(155) /* ../less/tree/expression */);
    var function_registry_1 = tslib_1.__importDefault(require(138) /* ./../less/functions/function-registry */);
    exports.default = (function (environment) {
        function imageSize(functionContext, filePathNode) {
            var filePath = filePathNode.value;
            var currentFileInfo = functionContext.currentFileInfo;
            var currentDirectory = currentFileInfo.rewriteUrls ?
                currentFileInfo.currentDirectory : currentFileInfo.entryPath;
            var fragmentStart = filePath.indexOf('#');
            if (fragmentStart !== -1) {
                filePath = filePath.slice(0, fragmentStart);
            }
            var fileManager = environment.getFileManager(filePath, currentDirectory, functionContext.context, environment, true);
            if (!fileManager) {
                throw {
                    type: 'File',
                    message: "Can not set up FileManager for " + filePathNode
                };
            }
            var fileSync = fileManager.loadFileSync(filePath, currentDirectory, functionContext.context, environment);
            if (fileSync.error) {
                throw fileSync.error;
            }
            var sizeOf = require(203) /* image-size */;
            return sizeOf(fileSync.filename);
        }
        var imageFunctions = {
            'image-size': function (filePathNode) {
                var size = imageSize(this, filePathNode);
                return new expression_1.default([
                    new dimension_1.default(size.width, 'px'),
                    new dimension_1.default(size.height, 'px')
                ]);
            },
            'image-width': function (filePathNode) {
                var size = imageSize(this, filePathNode);
                return new dimension_1.default(size.width, 'px');
            },
            'image-height': function (filePathNode) {
                var size = imageSize(this, filePathNode);
                return new dimension_1.default(size.height, 'px');
            }
        };
        function_registry_1.default.addMultiple(imageFunctions);
    });
    
},
/* image-size/lib/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    var fs = require('fs');
    var path = require('path');
    var detector = require(204) /* ./detector */;
    var handlers = {};
    var types = require(205) /* ./types */;
    // load all available handlers
    types.forEach(function (type) {
        handlers[type] = require('./types/' + type);
    });
    // Maximum buffer size, with a default of 128 kilobytes.
    // TO-DO: make this adaptive based on the initial signature of the image
    var MaxBufferSize = 128 * 1024;
    function lookup(buffer, filepath) {
        // detect the file type.. don't rely on the extension
        var type = detector(buffer, filepath);
        // find an appropriate handler for this file type
        if (type in handlers) {
            var size = handlers[type].calculate(buffer, filepath);
            if (size !== false) {
                size.type = type;
                return size;
            }
        }
        // throw up, if we don't understand the file
        throw new TypeError('unsupported file type: ' + type + ' (file: ' + filepath + ')');
    }
    function asyncFileToBuffer(filepath, callback) {
        // open the file in read only mode
        fs.open(filepath, 'r', function (err, descriptor) {
            if (err) {
                return callback(err);
            }
            var size = fs.fstatSync(descriptor).size;
            if (size <= 0) {
                return callback(new Error("File size is not greater than 0 —— " + filepath));
            }
            var bufferSize = Math.min(size, MaxBufferSize);
            var buffer = new Buffer(bufferSize);
            // read first buffer block from the file, asynchronously
            fs.read(descriptor, buffer, 0, bufferSize, 0, function (err) {
                if (err) {
                    return callback(err);
                }
                // close the file, we are done
                fs.close(descriptor, function (err) {
                    callback(err, buffer);
                });
            });
        });
    }
    function syncFileToBuffer(filepath) {
        // read from the file, synchronously
        var descriptor = fs.openSync(filepath, 'r');
        var size = fs.fstatSync(descriptor).size;
        var bufferSize = Math.min(size, MaxBufferSize);
        var buffer = new Buffer(bufferSize);
        fs.readSync(descriptor, buffer, 0, bufferSize, 0);
        fs.closeSync(descriptor);
        return buffer;
    }
    /**
     * @params input - buffer or relative/absolute path of the image file
     * @params callback - optional function for async detection
     */
    module.exports = function (input, callback) {
        // Handle buffer input
        if (Buffer.isBuffer(input)) {
            return lookup(input);
        }
        // input should be a string at this point
        if (typeof input !== 'string') {
            throw new TypeError('invalid invocation');
        }
        // resolve the file path
        var filepath = path.resolve(input);
        if (typeof callback === 'function') {
            asyncFileToBuffer(filepath, function (err, buffer) {
                if (err) {
                    return callback(err);
                }
                // return the dimensions
                var dimensions;
                try {
                    dimensions = lookup(buffer, filepath);
                }
                catch (e) {
                    err = e;
                }
                callback(err, dimensions);
            });
        }
        else {
            var buffer = syncFileToBuffer(filepath);
            return lookup(buffer, filepath);
        }
    };
    module.exports.types = types;
},
/* image-size/lib/detector.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    var typeMap = {};
    var types = require(205) /* ./types */;
    // load all available handlers
    types.forEach(function (type) {
        typeMap[type] = require('./types/' + type).detect;
    });
    module.exports = function (buffer, filepath) {
        var type, result;
        for (type in typeMap) {
            result = typeMap[type](buffer, filepath);
            if (result) {
                return type;
            }
        }
    };
},
/* image-size/lib/types.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    module.exports = [
        'bmp',
        'gif',
        'jpg',
        'png',
        'psd',
        'svg',
        'tiff',
        'webp',
        'dds'
    ];
},
/* css/index.js */ function _(require, module, exports, __esModule, __esExport) {
    exports.parse = require(207) /* ./lib/parse */;
    exports.stringify = require(208) /* ./lib/stringify */;
},
/* css/lib/parse/index.js */ function _(require, module, exports, __esModule, __esExport) {
    // http://www.w3.org/TR/CSS21/grammar.html
    // https://github.com/visionmedia/css-parse/pull/49#issuecomment-30088027
    var commentre = /\/\*[^*]*\*+([^/*][^*]*\*+)*\//g;
    module.exports = function (css, options) {
        options = options || {};
        /**
         * Positional.
         */
        var lineno = 1;
        var column = 1;
        /**
         * Update lineno and column based on `str`.
         */
        function updatePosition(str) {
            var lines = str.match(/\n/g);
            if (lines)
                lineno += lines.length;
            var i = str.lastIndexOf('\n');
            column = ~i ? str.length - i : column + str.length;
        }
        /**
         * Mark position and patch `node.position`.
         */
        function position() {
            var start = { line: lineno, column: column };
            return function (node) {
                node.position = new Position(start);
                whitespace();
                return node;
            };
        }
        /**
         * Store position information for a node
         */
        function Position(start) {
            this.start = start;
            this.end = { line: lineno, column: column };
            this.source = options.source;
        }
        /**
         * Non-enumerable source string
         */
        Position.prototype.content = css;
        /**
         * Error `msg`.
         */
        var errorsList = [];
        function error(msg) {
            var err = new Error(options.source + ':' + lineno + ':' + column + ': ' + msg);
            err.reason = msg;
            err.filename = options.source;
            err.line = lineno;
            err.column = column;
            err.source = css;
            if (options.silent) {
                errorsList.push(err);
            }
            else {
                throw err;
            }
        }
        /**
         * Parse stylesheet.
         */
        function stylesheet() {
            var rulesList = rules();
            return {
                type: 'stylesheet',
                stylesheet: {
                    source: options.source,
                    rules: rulesList,
                    parsingErrors: errorsList
                }
            };
        }
        /**
         * Opening brace.
         */
        function open() {
            return match(/^{\s*/);
        }
        /**
         * Closing brace.
         */
        function close() {
            return match(/^}/);
        }
        /**
         * Parse ruleset.
         */
        function rules() {
            var node;
            var rules = [];
            whitespace();
            comments(rules);
            while (css.length && css.charAt(0) != '}' && (node = atrule() || rule())) {
                if (node !== false) {
                    rules.push(node);
                    comments(rules);
                }
            }
            return rules;
        }
        /**
         * Match `re` and return captures.
         */
        function match(re) {
            var m = re.exec(css);
            if (!m)
                return;
            var str = m[0];
            updatePosition(str);
            css = css.slice(str.length);
            return m;
        }
        /**
         * Parse whitespace.
         */
        function whitespace() {
            match(/^\s*/);
        }
        /**
         * Parse comments;
         */
        function comments(rules) {
            var c;
            rules = rules || [];
            while (c = comment()) {
                if (c !== false) {
                    rules.push(c);
                }
            }
            return rules;
        }
        /**
         * Parse comment.
         */
        function comment() {
            var pos = position();
            if ('/' != css.charAt(0) || '*' != css.charAt(1))
                return;
            var i = 2;
            while ("" != css.charAt(i) && ('*' != css.charAt(i) || '/' != css.charAt(i + 1)))
                ++i;
            i += 2;
            if ("" === css.charAt(i - 1)) {
                return error('End of comment missing');
            }
            var str = css.slice(2, i - 2);
            column += 2;
            updatePosition(str);
            css = css.slice(i);
            column += 2;
            return pos({
                type: 'comment',
                comment: str
            });
        }
        /**
         * Parse selector.
         */
        function selector() {
            var m = match(/^([^{]+)/);
            if (!m)
                return;
            /* @fix Remove all comments from selectors
             * http://ostermiller.org/findcomment.html */
            return trim(m[0])
                .replace(/\/\*([^*]|[\r\n]|(\*+([^*/]|[\r\n])))*\*\/+/g, '')
                .replace(/"(?:\\"|[^"])*"|'(?:\\'|[^'])*'/g, function (m) {
                return m.replace(/,/g, '\u200C');
            })
                .split(/\s*(?![^(]*\)),\s*/)
                .map(function (s) {
                return s.replace(/\u200C/g, ',');
            });
        }
        /**
         * Parse declaration.
         */
        function declaration() {
            var pos = position();
            // prop
            var prop = match(/^(\*?[-#\/\*\\\w]+(\[[0-9a-z_-]+\])?)\s*/);
            if (!prop)
                return;
            prop = trim(prop[0]);
            // :
            if (!match(/^:\s*/))
                return error("property missing ':'");
            // val
            var val = match(/^((?:'(?:\\'|.)*?'|"(?:\\"|.)*?"|\([^\)]*?\)|[^};])+)/);
            var ret = pos({
                type: 'declaration',
                property: prop.replace(commentre, ''),
                value: val ? trim(val[0]).replace(commentre, '') : ''
            });
            // ;
            match(/^[;\s]*/);
            return ret;
        }
        /**
         * Parse declarations.
         */
        function declarations() {
            var decls = [];
            if (!open())
                return error("missing '{'");
            comments(decls);
            // declarations
            var decl;
            while (decl = declaration()) {
                if (decl !== false) {
                    decls.push(decl);
                    comments(decls);
                }
            }
            if (!close())
                return error("missing '}'");
            return decls;
        }
        /**
         * Parse keyframe.
         */
        function keyframe() {
            var m;
            var vals = [];
            var pos = position();
            while (m = match(/^((\d+\.\d+|\.\d+|\d+)%?|[a-z]+)\s*/)) {
                vals.push(m[1]);
                match(/^,\s*/);
            }
            if (!vals.length)
                return;
            return pos({
                type: 'keyframe',
                values: vals,
                declarations: declarations()
            });
        }
        /**
         * Parse keyframes.
         */
        function atkeyframes() {
            var pos = position();
            var m = match(/^@([-\w]+)?keyframes\s*/);
            if (!m)
                return;
            var vendor = m[1];
            // identifier
            var m = match(/^([-\w]+)\s*/);
            if (!m)
                return error("@keyframes missing name");
            var name = m[1];
            if (!open())
                return error("@keyframes missing '{'");
            var frame;
            var frames = comments();
            while (frame = keyframe()) {
                frames.push(frame);
                frames = frames.concat(comments());
            }
            if (!close())
                return error("@keyframes missing '}'");
            return pos({
                type: 'keyframes',
                name: name,
                vendor: vendor,
                keyframes: frames
            });
        }
        /**
         * Parse supports.
         */
        function atsupports() {
            var pos = position();
            var m = match(/^@supports *([^{]+)/);
            if (!m)
                return;
            var supports = trim(m[1]);
            if (!open())
                return error("@supports missing '{'");
            var style = comments().concat(rules());
            if (!close())
                return error("@supports missing '}'");
            return pos({
                type: 'supports',
                supports: supports,
                rules: style
            });
        }
        /**
         * Parse host.
         */
        function athost() {
            var pos = position();
            var m = match(/^@host\s*/);
            if (!m)
                return;
            if (!open())
                return error("@host missing '{'");
            var style = comments().concat(rules());
            if (!close())
                return error("@host missing '}'");
            return pos({
                type: 'host',
                rules: style
            });
        }
        /**
         * Parse media.
         */
        function atmedia() {
            var pos = position();
            var m = match(/^@media *([^{]+)/);
            if (!m)
                return;
            var media = trim(m[1]);
            if (!open())
                return error("@media missing '{'");
            var style = comments().concat(rules());
            if (!close())
                return error("@media missing '}'");
            return pos({
                type: 'media',
                media: media,
                rules: style
            });
        }
        /**
         * Parse custom-media.
         */
        function atcustommedia() {
            var pos = position();
            var m = match(/^@custom-media\s+(--[^\s]+)\s*([^{;]+);/);
            if (!m)
                return;
            return pos({
                type: 'custom-media',
                name: trim(m[1]),
                media: trim(m[2])
            });
        }
        /**
         * Parse paged media.
         */
        function atpage() {
            var pos = position();
            var m = match(/^@page */);
            if (!m)
                return;
            var sel = selector() || [];
            if (!open())
                return error("@page missing '{'");
            var decls = comments();
            // declarations
            var decl;
            while (decl = declaration()) {
                decls.push(decl);
                decls = decls.concat(comments());
            }
            if (!close())
                return error("@page missing '}'");
            return pos({
                type: 'page',
                selectors: sel,
                declarations: decls
            });
        }
        /**
         * Parse document.
         */
        function atdocument() {
            var pos = position();
            var m = match(/^@([-\w]+)?document *([^{]+)/);
            if (!m)
                return;
            var vendor = trim(m[1]);
            var doc = trim(m[2]);
            if (!open())
                return error("@document missing '{'");
            var style = comments().concat(rules());
            if (!close())
                return error("@document missing '}'");
            return pos({
                type: 'document',
                document: doc,
                vendor: vendor,
                rules: style
            });
        }
        /**
         * Parse font-face.
         */
        function atfontface() {
            var pos = position();
            var m = match(/^@font-face\s*/);
            if (!m)
                return;
            if (!open())
                return error("@font-face missing '{'");
            var decls = comments();
            // declarations
            var decl;
            while (decl = declaration()) {
                decls.push(decl);
                decls = decls.concat(comments());
            }
            if (!close())
                return error("@font-face missing '}'");
            return pos({
                type: 'font-face',
                declarations: decls
            });
        }
        /**
         * Parse import
         */
        var atimport = _compileAtrule('import');
        /**
         * Parse charset
         */
        var atcharset = _compileAtrule('charset');
        /**
         * Parse namespace
         */
        var atnamespace = _compileAtrule('namespace');
        /**
         * Parse non-block at-rules
         */
        function _compileAtrule(name) {
            var re = new RegExp('^@' + name + '\\s*([^;]+);');
            return function () {
                var pos = position();
                var m = match(re);
                if (!m)
                    return;
                var ret = { type: name };
                ret[name] = m[1].trim();
                return pos(ret);
            };
        }
        /**
         * Parse at rule.
         */
        function atrule() {
            if (css[0] != '@')
                return;
            return atkeyframes()
                || atmedia()
                || atcustommedia()
                || atsupports()
                || atimport()
                || atcharset()
                || atnamespace()
                || atdocument()
                || atpage()
                || athost()
                || atfontface();
        }
        /**
         * Parse rule.
         */
        function rule() {
            var pos = position();
            var sel = selector();
            if (!sel)
                return error('selector missing');
            comments();
            return pos({
                type: 'rule',
                selectors: sel,
                declarations: declarations()
            });
        }
        return addParent(stylesheet());
    };
    /**
     * Trim `str`.
     */
    function trim(str) {
        return str ? str.replace(/^\s+|\s+$/g, '') : '';
    }
    /**
     * Adds non-enumerable parent node reference to each node.
     */
    function addParent(obj, parent) {
        var isNode = obj && typeof obj.type === 'string';
        var childParent = isNode ? obj : parent;
        for (var k in obj) {
            var value = obj[k];
            if (Array.isArray(value)) {
                value.forEach(function (v) { addParent(v, childParent); });
            }
            else if (value && typeof value === 'object') {
                addParent(value, childParent);
            }
        }
        if (isNode) {
            Object.defineProperty(obj, 'parent', {
                configurable: true,
                writable: true,
                enumerable: false,
                value: parent || null
            });
        }
        return obj;
    }
},
/* css/lib/stringify/index.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * Module dependencies.
     */
    var Compressed = require(209) /* ./compress */;
    var Identity = require(213) /* ./identity */;
    /**
     * Stringfy the given AST `node`.
     *
     * Options:
     *
     *  - `compress` space-optimized output
     *  - `sourcemap` return an object with `.code` and `.map`
     *
     * @param {Object} node
     * @param {Object} [options]
     * @return {String}
     * @api public
     */
    module.exports = function (node, options) {
        options = options || {};
        var compiler = options.compress
            ? new Compressed(options)
            : new Identity(options);
        // source maps
        if (options.sourcemap) {
            var sourcemaps = require(214) /* ./source-map-support */;
            sourcemaps(compiler);
            var code = compiler.compile(node);
            compiler.applySourceMaps();
            var map = options.sourcemap === 'generator'
                ? compiler.map
                : compiler.map.toJSON();
            return { code: code, map: map };
        }
        var code = compiler.compile(node);
        return code;
    };
},
/* css/lib/stringify/compress.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * Module dependencies.
     */
    var Base = require(210) /* ./compiler */;
    var inherits = require(211) /* inherits */;
    /**
     * Expose compiler.
     */
    module.exports = Compiler;
    /**
     * Initialize a new `Compiler`.
     */
    function Compiler(options) {
        Base.call(this, options);
    }
    /**
     * Inherit from `Base.prototype`.
     */
    inherits(Compiler, Base);
    /**
     * Compile `node`.
     */
    Compiler.prototype.compile = function (node) {
        return node.stylesheet
            .rules.map(this.visit, this)
            .join('');
    };
    /**
     * Visit comment node.
     */
    Compiler.prototype.comment = function (node) {
        return this.emit('', node.position);
    };
    /**
     * Visit import node.
     */
    Compiler.prototype.import = function (node) {
        return this.emit('@import ' + node.import + ';', node.position);
    };
    /**
     * Visit media node.
     */
    Compiler.prototype.media = function (node) {
        return this.emit('@media ' + node.media, node.position)
            + this.emit('{')
            + this.mapVisit(node.rules)
            + this.emit('}');
    };
    /**
     * Visit document node.
     */
    Compiler.prototype.document = function (node) {
        var doc = '@' + (node.vendor || '') + 'document ' + node.document;
        return this.emit(doc, node.position)
            + this.emit('{')
            + this.mapVisit(node.rules)
            + this.emit('}');
    };
    /**
     * Visit charset node.
     */
    Compiler.prototype.charset = function (node) {
        return this.emit('@charset ' + node.charset + ';', node.position);
    };
    /**
     * Visit namespace node.
     */
    Compiler.prototype.namespace = function (node) {
        return this.emit('@namespace ' + node.namespace + ';', node.position);
    };
    /**
     * Visit supports node.
     */
    Compiler.prototype.supports = function (node) {
        return this.emit('@supports ' + node.supports, node.position)
            + this.emit('{')
            + this.mapVisit(node.rules)
            + this.emit('}');
    };
    /**
     * Visit keyframes node.
     */
    Compiler.prototype.keyframes = function (node) {
        return this.emit('@'
            + (node.vendor || '')
            + 'keyframes '
            + node.name, node.position)
            + this.emit('{')
            + this.mapVisit(node.keyframes)
            + this.emit('}');
    };
    /**
     * Visit keyframe node.
     */
    Compiler.prototype.keyframe = function (node) {
        var decls = node.declarations;
        return this.emit(node.values.join(','), node.position)
            + this.emit('{')
            + this.mapVisit(decls)
            + this.emit('}');
    };
    /**
     * Visit page node.
     */
    Compiler.prototype.page = function (node) {
        var sel = node.selectors.length
            ? node.selectors.join(', ')
            : '';
        return this.emit('@page ' + sel, node.position)
            + this.emit('{')
            + this.mapVisit(node.declarations)
            + this.emit('}');
    };
    /**
     * Visit font-face node.
     */
    Compiler.prototype['font-face'] = function (node) {
        return this.emit('@font-face', node.position)
            + this.emit('{')
            + this.mapVisit(node.declarations)
            + this.emit('}');
    };
    /**
     * Visit host node.
     */
    Compiler.prototype.host = function (node) {
        return this.emit('@host', node.position)
            + this.emit('{')
            + this.mapVisit(node.rules)
            + this.emit('}');
    };
    /**
     * Visit custom-media node.
     */
    Compiler.prototype['custom-media'] = function (node) {
        return this.emit('@custom-media ' + node.name + ' ' + node.media + ';', node.position);
    };
    /**
     * Visit rule node.
     */
    Compiler.prototype.rule = function (node) {
        var decls = node.declarations;
        if (!decls.length)
            return '';
        return this.emit(node.selectors.join(','), node.position)
            + this.emit('{')
            + this.mapVisit(decls)
            + this.emit('}');
    };
    /**
     * Visit declaration node.
     */
    Compiler.prototype.declaration = function (node) {
        return this.emit(node.property + ':' + node.value, node.position) + this.emit(';');
    };
},
/* css/lib/stringify/compiler.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * Expose `Compiler`.
     */
    module.exports = Compiler;
    /**
     * Initialize a compiler.
     *
     * @param {Type} name
     * @return {Type}
     * @api public
     */
    function Compiler(opts) {
        this.options = opts || {};
    }
    /**
     * Emit `str`
     */
    Compiler.prototype.emit = function (str) {
        return str;
    };
    /**
     * Visit `node`.
     */
    Compiler.prototype.visit = function (node) {
        return this[node.type](node);
    };
    /**
     * Map visit over array of `nodes`, optionally using a `delim`
     */
    Compiler.prototype.mapVisit = function (nodes, delim) {
        var buf = '';
        delim = delim || '';
        for (var i = 0, length = nodes.length; i < length; i++) {
            buf += this.visit(nodes[i]);
            if (delim && i < length - 1)
                buf += this.emit(delim);
        }
        return buf;
    };
},
/* inherits/inherits.js */ function _(require, module, exports, __esModule, __esExport) {
    try {
        var util = require('util');
        /* istanbul ignore next */
        if (typeof util.inherits !== 'function')
            throw '';
        module.exports = util.inherits;
    }
    catch (e) {
        /* istanbul ignore next */
        module.exports = require(212) /* ./inherits_browser.js */;
    }
},
/* inherits/inherits_browser.js */ function _(require, module, exports, __esModule, __esExport) {
    if (typeof Object.create === 'function') {
        // implementation from standard node.js 'util' module
        module.exports = function inherits(ctor, superCtor) {
            if (superCtor) {
                ctor.super_ = superCtor;
                ctor.prototype = Object.create(superCtor.prototype, {
                    constructor: {
                        value: ctor,
                        enumerable: false,
                        writable: true,
                        configurable: true
                    }
                });
            }
        };
    }
    else {
        // old school shim for old browsers
        module.exports = function inherits(ctor, superCtor) {
            if (superCtor) {
                ctor.super_ = superCtor;
                var TempCtor = function () { };
                TempCtor.prototype = superCtor.prototype;
                ctor.prototype = new TempCtor();
                ctor.prototype.constructor = ctor;
            }
        };
    }
},
/* css/lib/stringify/identity.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * Module dependencies.
     */
    var Base = require(210) /* ./compiler */;
    var inherits = require(211) /* inherits */;
    /**
     * Expose compiler.
     */
    module.exports = Compiler;
    /**
     * Initialize a new `Compiler`.
     */
    function Compiler(options) {
        options = options || {};
        Base.call(this, options);
        this.indentation = options.indent;
    }
    /**
     * Inherit from `Base.prototype`.
     */
    inherits(Compiler, Base);
    /**
     * Compile `node`.
     */
    Compiler.prototype.compile = function (node) {
        return this.stylesheet(node);
    };
    /**
     * Visit stylesheet node.
     */
    Compiler.prototype.stylesheet = function (node) {
        return this.mapVisit(node.stylesheet.rules, '\n\n');
    };
    /**
     * Visit comment node.
     */
    Compiler.prototype.comment = function (node) {
        return this.emit(this.indent() + '/*' + node.comment + '*/', node.position);
    };
    /**
     * Visit import node.
     */
    Compiler.prototype.import = function (node) {
        return this.emit('@import ' + node.import + ';', node.position);
    };
    /**
     * Visit media node.
     */
    Compiler.prototype.media = function (node) {
        return this.emit('@media ' + node.media, node.position)
            + this.emit(' {\n'
                + this.indent(1))
            + this.mapVisit(node.rules, '\n\n')
            + this.emit(this.indent(-1)
                + '\n}');
    };
    /**
     * Visit document node.
     */
    Compiler.prototype.document = function (node) {
        var doc = '@' + (node.vendor || '') + 'document ' + node.document;
        return this.emit(doc, node.position)
            + this.emit(' '
                + ' {\n'
                + this.indent(1))
            + this.mapVisit(node.rules, '\n\n')
            + this.emit(this.indent(-1)
                + '\n}');
    };
    /**
     * Visit charset node.
     */
    Compiler.prototype.charset = function (node) {
        return this.emit('@charset ' + node.charset + ';', node.position);
    };
    /**
     * Visit namespace node.
     */
    Compiler.prototype.namespace = function (node) {
        return this.emit('@namespace ' + node.namespace + ';', node.position);
    };
    /**
     * Visit supports node.
     */
    Compiler.prototype.supports = function (node) {
        return this.emit('@supports ' + node.supports, node.position)
            + this.emit(' {\n'
                + this.indent(1))
            + this.mapVisit(node.rules, '\n\n')
            + this.emit(this.indent(-1)
                + '\n}');
    };
    /**
     * Visit keyframes node.
     */
    Compiler.prototype.keyframes = function (node) {
        return this.emit('@' + (node.vendor || '') + 'keyframes ' + node.name, node.position)
            + this.emit(' {\n'
                + this.indent(1))
            + this.mapVisit(node.keyframes, '\n')
            + this.emit(this.indent(-1)
                + '}');
    };
    /**
     * Visit keyframe node.
     */
    Compiler.prototype.keyframe = function (node) {
        var decls = node.declarations;
        return this.emit(this.indent())
            + this.emit(node.values.join(', '), node.position)
            + this.emit(' {\n'
                + this.indent(1))
            + this.mapVisit(decls, '\n')
            + this.emit(this.indent(-1)
                + '\n'
                + this.indent() + '}\n');
    };
    /**
     * Visit page node.
     */
    Compiler.prototype.page = function (node) {
        var sel = node.selectors.length
            ? node.selectors.join(', ') + ' '
            : '';
        return this.emit('@page ' + sel, node.position)
            + this.emit('{\n')
            + this.emit(this.indent(1))
            + this.mapVisit(node.declarations, '\n')
            + this.emit(this.indent(-1))
            + this.emit('\n}');
    };
    /**
     * Visit font-face node.
     */
    Compiler.prototype['font-face'] = function (node) {
        return this.emit('@font-face ', node.position)
            + this.emit('{\n')
            + this.emit(this.indent(1))
            + this.mapVisit(node.declarations, '\n')
            + this.emit(this.indent(-1))
            + this.emit('\n}');
    };
    /**
     * Visit host node.
     */
    Compiler.prototype.host = function (node) {
        return this.emit('@host', node.position)
            + this.emit(' {\n'
                + this.indent(1))
            + this.mapVisit(node.rules, '\n\n')
            + this.emit(this.indent(-1)
                + '\n}');
    };
    /**
     * Visit custom-media node.
     */
    Compiler.prototype['custom-media'] = function (node) {
        return this.emit('@custom-media ' + node.name + ' ' + node.media + ';', node.position);
    };
    /**
     * Visit rule node.
     */
    Compiler.prototype.rule = function (node) {
        var indent = this.indent();
        var decls = node.declarations;
        if (!decls.length)
            return '';
        return this.emit(node.selectors.map(function (s) { return indent + s; }).join(',\n'), node.position)
            + this.emit(' {\n')
            + this.emit(this.indent(1))
            + this.mapVisit(decls, '\n')
            + this.emit(this.indent(-1))
            + this.emit('\n' + this.indent() + '}');
    };
    /**
     * Visit declaration node.
     */
    Compiler.prototype.declaration = function (node) {
        return this.emit(this.indent())
            + this.emit(node.property + ': ' + node.value, node.position)
            + this.emit(';');
    };
    /**
     * Increase, decrease or return current indentation.
     */
    Compiler.prototype.indent = function (level) {
        this.level = this.level || 1;
        if (null != level) {
            this.level += level;
            return '';
        }
        return Array(this.level).join(this.indentation || '  ');
    };
},
/* css/lib/stringify/source-map-support.js */ function _(require, module, exports, __esModule, __esExport) {
    /**
     * Module dependencies.
     */
    var SourceMap = require(23) /* source-map */.SourceMapGenerator;
    var SourceMapConsumer = require(23) /* source-map */.SourceMapConsumer;
    var sourceMapResolve = require(215) /* source-map-resolve */;
    var fs = require('fs');
    var path = require('path');
    /**
     * Expose `mixin()`.
     */
    module.exports = mixin;
    /**
     * Ensure Windows-style paths are formatted properly
     */
    const makeFriendlyPath = function (aPath) {
        return path.sep === "\\" ? aPath.replace(/\\/g, "/").replace(/^[a-z]:\/?/i, "/") : aPath;
    };
    /**
     * Mixin source map support into `compiler`.
     *
     * @param {Compiler} compiler
     * @api public
     */
    function mixin(compiler) {
        compiler._comment = compiler.comment;
        compiler.map = new SourceMap();
        compiler.position = { line: 1, column: 1 };
        compiler.files = {};
        for (var k in exports)
            compiler[k] = exports[k];
    }
    /**
     * Update position.
     *
     * @param {String} str
     * @api private
     */
    exports.updatePosition = function (str) {
        var lines = str.match(/\n/g);
        if (lines)
            this.position.line += lines.length;
        var i = str.lastIndexOf('\n');
        this.position.column = ~i ? str.length - i : this.position.column + str.length;
    };
    /**
     * Emit `str`.
     *
     * @param {String} str
     * @param {Object} [pos]
     * @return {String}
     * @api private
     */
    exports.emit = function (str, pos) {
        if (pos) {
            var sourceFile = makeFriendlyPath(pos.source || 'source.css');
            this.map.addMapping({
                source: sourceFile,
                generated: {
                    line: this.position.line,
                    column: Math.max(this.position.column - 1, 0)
                },
                original: {
                    line: pos.start.line,
                    column: pos.start.column - 1
                }
            });
            this.addFile(sourceFile, pos);
        }
        this.updatePosition(str);
        return str;
    };
    /**
     * Adds a file to the source map output if it has not already been added
     * @param {String} file
     * @param {Object} pos
     */
    exports.addFile = function (file, pos) {
        if (typeof pos.content !== 'string')
            return;
        if (Object.prototype.hasOwnProperty.call(this.files, file))
            return;
        this.files[file] = pos.content;
    };
    /**
     * Applies any original source maps to the output and embeds the source file
     * contents in the source map.
     */
    exports.applySourceMaps = function () {
        Object.keys(this.files).forEach(function (file) {
            var content = this.files[file];
            this.map.setSourceContent(file, content);
            if (this.options.inputSourcemaps !== false) {
                var originalMap = sourceMapResolve.resolveSync(content, file, fs.readFileSync);
                if (originalMap) {
                    var map = new SourceMapConsumer(originalMap.map);
                    var relativeTo = originalMap.sourcesRelativeTo;
                    this.map.applySourceMap(map, file, makeFriendlyPath(path.dirname(relativeTo)));
                }
            }
        }, this);
    };
    /**
     * Process comments, drops sourceMap comments.
     * @param {Object} node
     */
    exports.comment = function (node) {
        if (/^# sourceMappingURL=/.test(node.comment))
            return this.emit('', node.position);
        else
            return this._comment(node);
    };
},
/* source-map-resolve/index.js */ function _(require, module, exports, __esModule, __esExport) {
    var atob = require(216) /* atob */;
    var urlLib = require("url");
    var pathLib = require("path");
    var decodeUriComponentLib = require(217) /* decode-uri-component */;
    function resolveUrl( /* ...urls */) {
        return Array.prototype.reduce.call(arguments, function (resolved, nextUrl) {
            return urlLib.resolve(resolved, nextUrl);
        });
    }
    function convertWindowsPath(aPath) {
        return pathLib.sep === "\\" ? aPath.replace(/\\/g, "/").replace(/^[a-z]:\/?/i, "/") : aPath;
    }
    function customDecodeUriComponent(string) {
        // `decodeUriComponentLib` turns `+` into ` `, but that's not wanted.
        return decodeUriComponentLib(string.replace(/\+/g, "%2B"));
    }
    function callbackAsync(callback, error, result) {
        setImmediate(function () { callback(error, result); });
    }
    function parseMapToJSON(string, data) {
        try {
            return JSON.parse(string.replace(/^\)\]\}'/, ""));
        }
        catch (error) {
            error.sourceMapData = data;
            throw error;
        }
    }
    function readSync(read, url, data) {
        var readUrl = customDecodeUriComponent(url);
        try {
            return String(read(readUrl));
        }
        catch (error) {
            error.sourceMapData = data;
            throw error;
        }
    }
    var innerRegex = /[#@] sourceMappingURL=([^\s'"]*)/;
    var sourceMappingURLRegex = RegExp("(?:" +
        "/\\*" +
        "(?:\\s*\r?\n(?://)?)?" +
        "(?:" + innerRegex.source + ")" +
        "\\s*" +
        "\\*/" +
        "|" +
        "//(?:" + innerRegex.source + ")" +
        ")" +
        "\\s*");
    function getSourceMappingUrl(code) {
        var match = code.match(sourceMappingURLRegex);
        return match ? match[1] || match[2] || "" : null;
    }
    function resolveSourceMap(code, codeUrl, read, callback) {
        var mapData;
        try {
            mapData = resolveSourceMapHelper(code, codeUrl);
        }
        catch (error) {
            return callbackAsync(callback, error);
        }
        if (!mapData || mapData.map) {
            return callbackAsync(callback, null, mapData);
        }
        var readUrl = customDecodeUriComponent(mapData.url);
        read(readUrl, function (error, result) {
            if (error) {
                error.sourceMapData = mapData;
                return callback(error);
            }
            mapData.map = String(result);
            try {
                mapData.map = parseMapToJSON(mapData.map, mapData);
            }
            catch (error) {
                return callback(error);
            }
            callback(null, mapData);
        });
    }
    function resolveSourceMapSync(code, codeUrl, read) {
        var mapData = resolveSourceMapHelper(code, codeUrl);
        if (!mapData || mapData.map) {
            return mapData;
        }
        mapData.map = readSync(read, mapData.url, mapData);
        mapData.map = parseMapToJSON(mapData.map, mapData);
        return mapData;
    }
    var dataUriRegex = /^data:([^,;]*)(;[^,;]*)*(?:,(.*))?$/;
    /**
     * The media type for JSON text is application/json.
     *
     * {@link https://tools.ietf.org/html/rfc8259#section-11 | IANA Considerations }
     *
     * `text/json` is non-standard media type
     */
    var jsonMimeTypeRegex = /^(?:application|text)\/json$/;
    /**
     * JSON text exchanged between systems that are not part of a closed ecosystem
     * MUST be encoded using UTF-8.
     *
     * {@link https://tools.ietf.org/html/rfc8259#section-8.1 | Character Encoding}
     */
    var jsonCharacterEncoding = "utf-8";
    function base64ToBuf(b64) {
        var binStr = atob(b64);
        var len = binStr.length;
        var arr = new Uint8Array(len);
        for (var i = 0; i < len; i++) {
            arr[i] = binStr.charCodeAt(i);
        }
        return arr;
    }
    function decodeBase64String(b64) {
        if (typeof TextDecoder === "undefined" || typeof Uint8Array === "undefined") {
            return atob(b64);
        }
        var buf = base64ToBuf(b64);
        // Note: `decoder.decode` method will throw a `DOMException` with the
        // `"EncodingError"` value when an coding error is found.
        var decoder = new TextDecoder(jsonCharacterEncoding, { fatal: true });
        return decoder.decode(buf);
    }
    function resolveSourceMapHelper(code, codeUrl) {
        codeUrl = convertWindowsPath(codeUrl);
        var url = getSourceMappingUrl(code);
        if (!url) {
            return null;
        }
        var dataUri = url.match(dataUriRegex);
        if (dataUri) {
            var mimeType = dataUri[1] || "text/plain";
            var lastParameter = dataUri[2] || "";
            var encoded = dataUri[3] || "";
            var data = {
                sourceMappingURL: url,
                url: null,
                sourcesRelativeTo: codeUrl,
                map: encoded
            };
            if (!jsonMimeTypeRegex.test(mimeType)) {
                var error = new Error("Unuseful data uri mime type: " + mimeType);
                error.sourceMapData = data;
                throw error;
            }
            try {
                data.map = parseMapToJSON(lastParameter === ";base64" ? decodeBase64String(encoded) : decodeURIComponent(encoded), data);
            }
            catch (error) {
                error.sourceMapData = data;
                throw error;
            }
            return data;
        }
        var mapUrl = resolveUrl(codeUrl, url);
        return {
            sourceMappingURL: url,
            url: mapUrl,
            sourcesRelativeTo: mapUrl,
            map: null
        };
    }
    function resolveSources(map, mapUrl, read, options, callback) {
        if (typeof options === "function") {
            callback = options;
            options = {};
        }
        var pending = map.sources ? map.sources.length : 0;
        var result = {
            sourcesResolved: [],
            sourcesContent: []
        };
        if (pending === 0) {
            callbackAsync(callback, null, result);
            return;
        }
        var done = function () {
            pending--;
            if (pending === 0) {
                callback(null, result);
            }
        };
        resolveSourcesHelper(map, mapUrl, options, function (fullUrl, sourceContent, index) {
            result.sourcesResolved[index] = fullUrl;
            if (typeof sourceContent === "string") {
                result.sourcesContent[index] = sourceContent;
                callbackAsync(done, null);
            }
            else {
                var readUrl = customDecodeUriComponent(fullUrl);
                read(readUrl, function (error, source) {
                    result.sourcesContent[index] = error ? error : String(source);
                    done();
                });
            }
        });
    }
    function resolveSourcesSync(map, mapUrl, read, options) {
        var result = {
            sourcesResolved: [],
            sourcesContent: []
        };
        if (!map.sources || map.sources.length === 0) {
            return result;
        }
        resolveSourcesHelper(map, mapUrl, options, function (fullUrl, sourceContent, index) {
            result.sourcesResolved[index] = fullUrl;
            if (read !== null) {
                if (typeof sourceContent === "string") {
                    result.sourcesContent[index] = sourceContent;
                }
                else {
                    var readUrl = customDecodeUriComponent(fullUrl);
                    try {
                        result.sourcesContent[index] = String(read(readUrl));
                    }
                    catch (error) {
                        result.sourcesContent[index] = error;
                    }
                }
            }
        });
        return result;
    }
    var endingSlash = /\/?$/;
    function resolveSourcesHelper(map, mapUrl, options, fn) {
        options = options || {};
        mapUrl = convertWindowsPath(mapUrl);
        var fullUrl;
        var sourceContent;
        var sourceRoot;
        for (var index = 0, len = map.sources.length; index < len; index++) {
            sourceRoot = null;
            if (typeof options.sourceRoot === "string") {
                sourceRoot = options.sourceRoot;
            }
            else if (typeof map.sourceRoot === "string" && options.sourceRoot !== false) {
                sourceRoot = map.sourceRoot;
            }
            // If the sourceRoot is the empty string, it is equivalent to not setting
            // the property at all.
            if (sourceRoot === null || sourceRoot === '') {
                fullUrl = resolveUrl(mapUrl, map.sources[index]);
            }
            else {
                // Make sure that the sourceRoot ends with a slash, so that `/scripts/subdir` becomes
                // `/scripts/subdir/<source>`, not `/scripts/<source>`. Pointing to a file as source root
                // does not make sense.
                fullUrl = resolveUrl(mapUrl, sourceRoot.replace(endingSlash, "/"), map.sources[index]);
            }
            sourceContent = (map.sourcesContent || [])[index];
            fn(fullUrl, sourceContent, index);
        }
    }
    function resolve(code, codeUrl, read, options, callback) {
        if (typeof options === "function") {
            callback = options;
            options = {};
        }
        if (code === null) {
            var mapUrl = codeUrl;
            var data = {
                sourceMappingURL: null,
                url: mapUrl,
                sourcesRelativeTo: mapUrl,
                map: null
            };
            var readUrl = customDecodeUriComponent(mapUrl);
            read(readUrl, function (error, result) {
                if (error) {
                    error.sourceMapData = data;
                    return callback(error);
                }
                data.map = String(result);
                try {
                    data.map = parseMapToJSON(data.map, data);
                }
                catch (error) {
                    return callback(error);
                }
                _resolveSources(data);
            });
        }
        else {
            resolveSourceMap(code, codeUrl, read, function (error, mapData) {
                if (error) {
                    return callback(error);
                }
                if (!mapData) {
                    return callback(null, null);
                }
                _resolveSources(mapData);
            });
        }
        function _resolveSources(mapData) {
            resolveSources(mapData.map, mapData.sourcesRelativeTo, read, options, function (error, result) {
                if (error) {
                    return callback(error);
                }
                mapData.sourcesResolved = result.sourcesResolved;
                mapData.sourcesContent = result.sourcesContent;
                callback(null, mapData);
            });
        }
    }
    function resolveSync(code, codeUrl, read, options) {
        var mapData;
        if (code === null) {
            var mapUrl = codeUrl;
            mapData = {
                sourceMappingURL: null,
                url: mapUrl,
                sourcesRelativeTo: mapUrl,
                map: null
            };
            mapData.map = readSync(read, mapUrl, mapData);
            mapData.map = parseMapToJSON(mapData.map, mapData);
        }
        else {
            mapData = resolveSourceMapSync(code, codeUrl, read);
            if (!mapData) {
                return null;
            }
        }
        var result = resolveSourcesSync(mapData.map, mapData.sourcesRelativeTo, read, options);
        mapData.sourcesResolved = result.sourcesResolved;
        mapData.sourcesContent = result.sourcesContent;
        return mapData;
    }
    module.exports = {
        resolveSourceMap: resolveSourceMap,
        resolveSourceMapSync: resolveSourceMapSync,
        resolveSources: resolveSources,
        resolveSourcesSync: resolveSourcesSync,
        resolve: resolve,
        resolveSync: resolveSync,
        parseMapToJSON: parseMapToJSON
    };
},
/* atob/node-atob.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    function atob(str) {
        return Buffer.from(str, 'base64').toString('binary');
    }
    module.exports = atob.atob = atob;
},
/* decode-uri-component/index.js */ function _(require, module, exports, __esModule, __esExport) {
    'use strict';
    var token = '%[a-f0-9]{2}';
    var singleMatcher = new RegExp('(' + token + ')|([^%]+?)', 'gi');
    var multiMatcher = new RegExp('(' + token + ')+', 'gi');
    function decodeComponents(components, split) {
        try {
            // Try to decode the entire string first
            return [decodeURIComponent(components.join(''))];
        }
        catch (err) {
            // Do nothing
        }
        if (components.length === 1) {
            return components;
        }
        split = split || 1;
        // Split the array in 2 parts
        var left = components.slice(0, split);
        var right = components.slice(split);
        return Array.prototype.concat.call([], decodeComponents(left), decodeComponents(right));
    }
    function decode(input) {
        try {
            return decodeURIComponent(input);
        }
        catch (err) {
            var tokens = input.match(singleMatcher) || [];
            for (var i = 1; i < tokens.length; i++) {
                input = decodeComponents(tokens, i).join('');
                tokens = input.match(singleMatcher) || [];
            }
            return input;
        }
    }
    function customDecodeURIComponent(input) {
        // Keep track of all the replacements and prefill the map with the `BOM`
        var replaceMap = {
            '%FE%FF': '\uFFFD\uFFFD',
            '%FF%FE': '\uFFFD\uFFFD'
        };
        var match = multiMatcher.exec(input);
        while (match) {
            try {
                // Decode as big chunks as possible
                replaceMap[match[0]] = decodeURIComponent(match[0]);
            }
            catch (err) {
                var result = decode(match[0]);
                if (result !== match[0]) {
                    replaceMap[match[0]] = result;
                }
            }
            match = multiMatcher.exec(input);
        }
        // Add `%C2` at the end of the map to make sure it does not replace the combinator before everything else
        replaceMap['%C2'] = '\uFFFD';
        var entries = Object.keys(replaceMap);
        for (var i = 0; i < entries.length; i++) {
            // Replace all decoded components
            var key = entries[i];
            input = input.replace(new RegExp(key, 'g'), replaceMap[key]);
        }
        return input;
    }
    module.exports = function (encodedURI) {
        if (typeof encodedURI !== 'string') {
            throw new TypeError('Expected `encodedURI` to be of type `string`, got `' + typeof encodedURI + '`');
        }
        try {
            encodedURI = encodedURI.replace(/\+/g, ' ');
            // Try the built in decoder first
            return decodeURIComponent(encodedURI);
        }
        catch (err) {
            // Fallback to a more advanced decoder
            return customDecodeURIComponent(encodedURI);
        }
    };
},
/* prelude.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.default_prelude = exports.plugin_prelude = exports.plugin_postlude = exports.postlude = exports.prelude = exports.plugin_postlude_esm = exports.plugin_prelude_esm = exports.postlude_esm = exports.prelude_esm = exports.comment = void 0;
    // TODO import license from "../../../LICENSE.txt"
    const license = `\
Copyright (c) Anaconda, Inc., and Bokeh Contributors
All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice,
this list of conditions and the following disclaimer.

Redistributions in binary form must reproduce the above copyright notice,
this list of conditions and the following disclaimer in the documentation
and/or other materials provided with the distribution.

Neither the name of Anaconda nor the names of any contributors
may be used to endorse or promote products derived from this software
without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
THE POSSIBILITY OF SUCH DAMAGE.
`;
    function comment(text) {
        return `/*!${"\n"}${text.trim().split("\n").map((line) => ` * ${line}`).join("\n")}${"\n"} */`;
    }
    exports.comment = comment;
    function str(obj) {
        return JSON.stringify(obj);
    }
    const loader = `\
(function(modules, entry, aliases, externals) {
  if (aliases === undefined) aliases = {};
  if (externals === undefined) externals = {};

  const cache = {};

  const normalize = function(name) {
    if (typeof name === "number")
      return name;

    if (name === "bokehjs")
      return entry;

    if (!externals[name]) {
      const prefix = "@bokehjs/"
      if (name.slice(0, prefix.length) === prefix)
        name = name.slice(prefix.length)
    }

    const alias = aliases[name]
    if (alias != null)
      return alias;

    const trailing = name.length > 0 && name[name.length-1] === "/";
    const index = aliases[name + (trailing ? "" : "/") + "index"];
    if (index != null)
      return index;

    return name;
  }

  const require = function(name) {
    let mod = cache[name];
    if (!mod) {
      const id = normalize(name);

      mod = cache[id];
      if (!mod) {
        if (!modules[id]) {
          if (externals[id] === false || (externals[id] == true && parent_require)) {
            try {
              mod = {exports: externals[id] ? parent_require(id) : {}};
              cache[id] = cache[name] = mod;
              return mod.exports;
            } catch (e) {}
          }

          const err = new Error("Cannot find module '" + name + "'");
          err.code = 'MODULE_NOT_FOUND';
          throw err;
        }

        mod = {exports: {}};
        cache[id] = cache[name] = mod;

        function __esModule() {
          Object.defineProperty(mod.exports, "__esModule", {value: true});
        }

        function __esExport(name, value) {
          Object.defineProperty(mod.exports, name, {
            enumerable: true, get: function () { return value; }
          });
        }

        modules[id].call(mod.exports, require, mod, mod.exports, __esModule, __esExport);
      } else {
        cache[name] = mod;
      }
    }

    return mod.exports;
  }
  require.resolve = function(name) {
    return ""
  }

  const main = require(entry);
  main.require = require;

  if (typeof Proxy !== "undefined") {
    // allow Bokeh.loader["@bokehjs/module/name"] syntax
    main.loader = new Proxy({}, {
      get: function(_obj, module) {
        return require(module);
      }
    });
  }

  main.register_plugin = function(plugin_modules, plugin_entry, plugin_aliases, plugin_externals) {
    if (plugin_aliases === undefined) plugin_aliases = {};
    if (plugin_externals === undefined) plugin_externals = {};

    for (let name in plugin_modules) {
      modules[name] = plugin_modules[name];
    }

    for (let name in plugin_aliases) {
      aliases[name] = plugin_aliases[name];
    }

    for (let name in plugin_externals) {
      externals[name] = plugin_externals[name];
    }

    const plugin = require(plugin_entry);

    for (let name in plugin) {
      main[name] = plugin[name];
    }

    return plugin;
  }

  return main;
})
`;
    function prelude_esm() {
        return `\
${comment(license)}
const main = ${loader}\
`;
    }
    exports.prelude_esm = prelude_esm;
    function postlude_esm() {
        return "export default main;";
    }
    exports.postlude_esm = postlude_esm;
    function plugin_prelude_esm() {
        return `\
${comment(license)}
import main from "./bokeh.esm.js";

const plugin = (function(modules, entry, aliases, externals) {
  main.register_plugin(modules, entry, aliases);
})\
`;
    }
    exports.plugin_prelude_esm = plugin_prelude_esm;
    function plugin_postlude_esm() {
        return "export default plugin;";
    }
    exports.plugin_postlude_esm = plugin_postlude_esm;
    function prelude() {
        return `\
'use strict';
${comment(license)}
(function(root, factory) {
  const bokeh = factory();
  bokeh.__bokeh__ = true;
  if (typeof root.Bokeh === "undefined" || typeof root.Bokeh.__bokeh__ === "undefined") {
    root.Bokeh = bokeh;
  }
  const Bokeh = root.Bokeh;
  Bokeh[bokeh.version] = bokeh;
})(this, function() {
  let define;
  const parent_require = typeof require === "function" && require
  return ${loader}\
`;
    }
    exports.prelude = prelude;
    function postlude() {
        return "});";
    }
    exports.postlude = postlude;
    function plugin_postlude() {
        return "});";
    }
    exports.plugin_postlude = plugin_postlude;
    function plugin_prelude(options) {
        return `\
'use strict';
${comment(license)}
(function(root, factory) {
  factory(root["Bokeh"], ${str(options?.version)});
})(this, function(Bokeh, version) {
  let define;
  return (function(modules, entry, aliases, externals) {
    const bokeh = typeof Bokeh !== "undefined" ? (version != null ? Bokeh[version] : Bokeh) : null;
    if (bokeh != null) {
      return bokeh.register_plugin(modules, entry, aliases);
    } else {
      throw new Error("Cannot find Bokeh" + (version != null ? " " + version : "") + ". You have to load it prior to loading plugins.");
    }
  })
`;
    }
    exports.plugin_prelude = plugin_prelude;
    function default_prelude(options) {
        return `\
(function(root, factory) {
  ${options?.global != null ? `root[${str(options.global)}] = factory()` : "Object.assign(root, factory())"};
})(this, function() {
  const parent_require = typeof require === "function" && require
  return ${loader}
`;
    }
    exports.default_prelude = default_prelude;
    
},
/* tsconfig.ext.json */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    const json = {
        "compilerOptions": {
            "noImplicitAny": true,
            "noImplicitThis": true,
            "noImplicitReturns": true,
            "noUnusedLocals": true,
            "noUnusedParameters": true,
            "noImplicitOverride": false,
            "strictNullChecks": true,
            "strictBindCallApply": true,
            "strictFunctionTypes": true,
            "strictPropertyInitialization": false,
            "useUnknownInCatchVariables": true,
            "alwaysStrict": true,
            "noErrorTruncation": true,
            "noEmitOnError": false,
            "allowJs": true,
            "declaration": true,
            "sourceMap": true,
            "declarationMap": true,
            "importHelpers": false,
            "experimentalDecorators": true,
            "module": "ES2022",
            "moduleResolution": "node",
            "isolatedModules": true,
            "verbatimModuleSyntax": false,
            "resolveJsonModule": true,
            "skipLibCheck": true,
            "esModuleInterop": true,
            "target": "ES2022",
            "lib": ["es2022", "dom", "dom.iterable"],
            "baseUrl": ".",
            "outDir": "./dist/lib"
        },
        "include": ["./**/*.ts"]
    };
    module.exports = json;
},
/* compile.js */ function _(require, module, exports, __esModule, __esExport) {
    "use strict";
    var __createBinding = (this && this.__createBinding) || (Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        var desc = Object.getOwnPropertyDescriptor(m, k);
        if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
            desc = { enumerable: true, get: function () { return m[k]; } };
        }
        Object.defineProperty(o, k2, desc);
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    }));
    var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    });
    var __importStar = (this && this.__importStar) || function (mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    };
    var __importDefault = (this && this.__importDefault) || function (mod) {
        return (mod && mod.__esModule) ? mod : { "default": mod };
    };
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.compile_and_resolve_deps = exports.compile_typescript = void 0;
    const path_1 = require("path");
    const typescript_1 = __importDefault(require(21) /* typescript */);
    const less_1 = __importDefault(require(61) /* less */);
    const compiler_1 = require(36) /* ./compiler */;
    const sys_1 = require(20) /* ./sys */;
    const transforms = __importStar(require(42) /* ./transforms */);
    const tsconfig_json = __importStar(require(219) /* ./tsconfig.ext.json */);
    function parse_patched_tsconfig(base_dir, preconfigure) {
        // XXX: silence the config validator. We are providing inputs through `inputs` argument anyway.
        const json = { ...tsconfig_json, include: undefined, files: ["dummy.ts"] };
        return (0, compiler_1.parse_tsconfig)(json, base_dir, preconfigure);
    }
    function compile_typescript(base_dir, inputs, bokehjs_dir) {
        const is_static_dir = (0, path_1.basename)(bokehjs_dir) == "static";
        const preconfigure = {
            module: typescript_1.default.ModuleKind.CommonJS,
            target: typescript_1.default.ScriptTarget.ES2020,
            paths: {
                "*": [
                    (0, path_1.join)(bokehjs_dir, "js/lib/*"),
                ],
            },
            outDir: undefined,
        };
        const tsconfig = parse_patched_tsconfig(base_dir, preconfigure);
        if (tsconfig.diagnostics != null) {
            return { diagnostics: tsconfig.diagnostics };
        }
        const tslib_dir = (() => {
            // bokeh/server/static or bokehjs/build
            if (is_static_dir) {
                return (0, path_1.join)(bokehjs_dir, "lib");
            }
            else {
                return (0, path_1.join)((0, path_1.dirname)(bokehjs_dir), "node_modules", "typescript", "lib");
            }
        })();
        const host = (0, compiler_1.compiler_host)(inputs, tsconfig.options, tslib_dir);
        const transformers = (0, compiler_1.default_transformers)(tsconfig.options);
        const outputs = new Map();
        host.writeFile = (name, data) => {
            outputs.set(name, data);
        };
        const files = [...inputs.keys()];
        return { outputs, ...(0, compiler_1.compile_files)(files, tsconfig.options, transformers, host) };
    }
    exports.compile_typescript = compile_typescript;
    function compile_javascript(base_dir, file, code) {
        const tsconfig = parse_patched_tsconfig(base_dir, {});
        if (tsconfig.diagnostics != null) {
            return { diagnostics: tsconfig.diagnostics };
        }
        const { outputText, diagnostics } = typescript_1.default.transpileModule(code, {
            fileName: file,
            reportDiagnostics: true,
            compilerOptions: {
                target: tsconfig.options.target,
                module: typescript_1.default.ModuleKind.CommonJS,
            },
        });
        return { output: outputText, diagnostics };
    }
    function normalize(path) {
        return path.replace(/\\/g, "/");
    }
    async function compile_and_resolve_deps(input) {
        const { file, lang, bokehjs_dir } = input;
        const { code } = input;
        let output;
        switch (lang) {
            case "typescript":
                const inputs = new Map([[normalize(file), code]]);
                const { outputs, diagnostics } = compile_typescript(".", inputs, bokehjs_dir);
                if (diagnostics != null && diagnostics.length != 0) {
                    const failure = (0, compiler_1.report_diagnostics)(diagnostics);
                    return { error: failure.text };
                }
                else {
                    const js_file = normalize((0, sys_1.rename)(file, { ext: ".js" }));
                    output = outputs.get(js_file);
                }
                break;
            case "javascript": {
                const result = compile_javascript(".", file, code);
                if (result.diagnostics != null && result.diagnostics.length != 0) {
                    const failure = (0, compiler_1.report_diagnostics)(result.diagnostics);
                    return { error: failure.text };
                }
                else {
                    output = result.output;
                }
                break;
            }
            case "less":
                try {
                    const { css } = await less_1.default.render(code, { filename: file, compress: true });
                    return { code: css };
                }
                catch (error) {
                    return { error: `${error}` };
                }
            default:
                throw new Error(`unsupported input type: ${lang}`);
        }
        const source = typescript_1.default.createSourceFile(file, output, typescript_1.default.ScriptTarget.ES2015, true, typescript_1.default.ScriptKind.JS);
        const deps = transforms.collect_deps(source);
        return { code: output, deps };
    }
    exports.compile_and_resolve_deps = compile_and_resolve_deps;
    
},
], 0, {"main":0,"sys":20,"build":35,"compiler":36,"transforms":42,"error":43,"linker":44,"graph":59,"styles":60,"prelude":218,"tsconfig.ext.json":219,"compile":220}, {"path":true,"assert":true,"fs":true,"util":true,"crypto":true,"perf_hooks":true,"os":true,"buffer":true,"inspector":true,"child_process":true,"readline":true,"tty":true,"module":true,"constants":true,"stream":true,"url":true,"http":true,"https":true,"zlib":true,"querystring":true,"string_decoder":true});});
//# sourceMappingURL=compiler.js.map
